/* Generated from c-backend.scm by the CHICKEN compiler
   http://www.call-cc.org
   Version 5.4.0rc1 (prerelease) (rev bc191a47)
   linux-unix-gnu-x86-64 [ 64bit dload ptables ]
   command line: c-backend.scm -optimize-level 2 -include-path . -include-path ./ -inline -ignore-repository -feature chicken-bootstrap -no-warnings -specialize -consult-types-file ./types.db -no-lambda-info -no-trace -emit-import-library chicken.compiler.c-backend -output-file c-backend.c
   unit: c-backend
   uses: eval support c-platform compiler data-structures internal extras library
*/
#include "chicken.h"

static C_PTABLE_ENTRY *create_ptable(void);
C_noret_decl(C_eval_toplevel)
C_externimport void C_ccall C_eval_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_support_toplevel)
C_externimport void C_ccall C_support_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_c_2dplatform_toplevel)
C_externimport void C_ccall C_c_2dplatform_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_compiler_toplevel)
C_externimport void C_ccall C_compiler_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_data_2dstructures_toplevel)
C_externimport void C_ccall C_data_2dstructures_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_internal_toplevel)
C_externimport void C_ccall C_internal_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_extras_toplevel)
C_externimport void C_ccall C_extras_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_library_toplevel)
C_externimport void C_ccall C_library_toplevel(C_word c,C_word *av) C_noret;

static C_TLS C_word lf[885];
static double C_possibly_force_alignment;


#define return(x) C_cblock C_r = (C_fix((C_word)(x))); goto C_ret; C_cblockend
C_regparm static C_word C_fcall stub2860(C_word C_buf,C_word C_a0){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
C_word lit=(C_word )(C_a0);
return(C_header_size(lit));
C_ret:
#undef return

return C_r;}

#define return(x) C_cblock C_r = (C_fix((C_word)(x))); goto C_ret; C_cblockend
C_regparm static C_word C_fcall stub2856(C_word C_buf,C_word C_a0){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
C_word lit=(C_word )(C_a0);

#ifdef C_SIXTY_FOUR
return((C_header_bits(lit) >> (24 + 32)) & 0xff);
#else
return((C_header_bits(lit) >> 24) & 0xff);
#endif

C_ret:
#undef return

return C_r;}

C_noret_decl(f14759)
static void C_ccall f14759(C_word c,C_word *av) C_noret;
C_noret_decl(f14764)
static void C_ccall f14764(C_word c,C_word *av) C_noret;
C_noret_decl(f14769)
static void C_ccall f14769(C_word c,C_word *av) C_noret;
C_noret_decl(f14777)
static void C_ccall f14777(C_word c,C_word *av) C_noret;
C_noret_decl(f14782)
static void C_ccall f14782(C_word c,C_word *av) C_noret;
C_noret_decl(f14787)
static void C_ccall f14787(C_word c,C_word *av) C_noret;
C_noret_decl(f14800)
static void C_ccall f14800(C_word c,C_word *av) C_noret;
C_noret_decl(f14804)
static void C_ccall f14804(C_word c,C_word *av) C_noret;
C_noret_decl(f14811)
static void C_ccall f14811(C_word c,C_word *av) C_noret;
C_noret_decl(f14816)
static void C_ccall f14816(C_word c,C_word *av) C_noret;
C_noret_decl(f14889)
static void C_ccall f14889(C_word c,C_word *av) C_noret;
C_noret_decl(f14896)
static void C_ccall f14896(C_word c,C_word *av) C_noret;
C_noret_decl(f14917)
static void C_ccall f14917(C_word c,C_word *av) C_noret;
C_noret_decl(f_10020)
static void C_fcall f_10020(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10376)
static void C_ccall f_10376(C_word c,C_word *av) C_noret;
C_noret_decl(f_10379)
static void C_ccall f_10379(C_word c,C_word *av) C_noret;
C_noret_decl(f_10382)
static void C_ccall f_10382(C_word c,C_word *av) C_noret;
C_noret_decl(f_10385)
static void C_ccall f_10385(C_word c,C_word *av) C_noret;
C_noret_decl(f_10388)
static void C_ccall f_10388(C_word c,C_word *av) C_noret;
C_noret_decl(f_10391)
static void C_ccall f_10391(C_word c,C_word *av) C_noret;
C_noret_decl(f_10400)
static void C_ccall f_10400(C_word c,C_word *av) C_noret;
C_noret_decl(f_10403)
static void C_ccall f_10403(C_word c,C_word *av) C_noret;
C_noret_decl(f_10406)
static void C_ccall f_10406(C_word c,C_word *av) C_noret;
C_noret_decl(f_10409)
static void C_ccall f_10409(C_word c,C_word *av) C_noret;
C_noret_decl(f_10412)
static void C_ccall f_10412(C_word c,C_word *av) C_noret;
C_noret_decl(f_10415)
static void C_ccall f_10415(C_word c,C_word *av) C_noret;
C_noret_decl(f_10418)
static void C_ccall f_10418(C_word c,C_word *av) C_noret;
C_noret_decl(f_10437)
static void C_ccall f_10437(C_word c,C_word *av) C_noret;
C_noret_decl(f_10439)
static void C_fcall f_10439(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10449)
static void C_ccall f_10449(C_word c,C_word *av) C_noret;
C_noret_decl(f_10488)
static void C_ccall f_10488(C_word c,C_word *av) C_noret;
C_noret_decl(f_10490)
static void C_fcall f_10490(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_10512)
static void C_ccall f_10512(C_word c,C_word *av) C_noret;
C_noret_decl(f_10524)
static void C_fcall f_10524(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10534)
static void C_ccall f_10534(C_word c,C_word *av) C_noret;
C_noret_decl(f_10547)
static void C_fcall f_10547(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10551)
static void C_ccall f_10551(C_word c,C_word *av) C_noret;
C_noret_decl(f_10554)
static void C_ccall f_10554(C_word c,C_word *av) C_noret;
C_noret_decl(f_10557)
static void C_ccall f_10557(C_word c,C_word *av) C_noret;
C_noret_decl(f_10560)
static void C_ccall f_10560(C_word c,C_word *av) C_noret;
C_noret_decl(f_10566)
static void C_ccall f_10566(C_word c,C_word *av) C_noret;
C_noret_decl(f_10569)
static void C_ccall f_10569(C_word c,C_word *av) C_noret;
C_noret_decl(f_10572)
static void C_ccall f_10572(C_word c,C_word *av) C_noret;
C_noret_decl(f_10577)
static void C_fcall f_10577(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10587)
static void C_ccall f_10587(C_word c,C_word *av) C_noret;
C_noret_decl(f_10590)
static void C_ccall f_10590(C_word c,C_word *av) C_noret;
C_noret_decl(f_10609)
static void C_ccall f_10609(C_word c,C_word *av) C_noret;
C_noret_decl(f_10621)
static void C_ccall f_10621(C_word c,C_word *av) C_noret;
C_noret_decl(f_10623)
static void C_ccall f_10623(C_word c,C_word *av) C_noret;
C_noret_decl(f_10625)
static void C_fcall f_10625(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10630)
static void C_fcall f_10630(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10700)
static void C_fcall f_10700(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10817)
static void C_fcall f_10817(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10838)
static void C_fcall f_10838(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10970)
static void C_fcall f_10970(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10982)
static void C_fcall f_10982(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10997)
static void C_ccall f_10997(C_word c,C_word *av) C_noret;
C_noret_decl(f_11001)
static void C_fcall f_11001(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11045)
static void C_ccall f_11045(C_word c,C_word *av) C_noret;
C_noret_decl(f_11062)
static void C_ccall f_11062(C_word c,C_word *av) C_noret;
C_noret_decl(f_11075)
static void C_ccall f_11075(C_word c,C_word *av) C_noret;
C_noret_decl(f_11079)
static void C_ccall f_11079(C_word c,C_word *av) C_noret;
C_noret_decl(f_11083)
static void C_ccall f_11083(C_word c,C_word *av) C_noret;
C_noret_decl(f_11101)
static void C_ccall f_11101(C_word c,C_word *av) C_noret;
C_noret_decl(f_11103)
static void C_fcall f_11103(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11128)
static void C_ccall f_11128(C_word c,C_word *av) C_noret;
C_noret_decl(f_11152)
static void C_ccall f_11152(C_word c,C_word *av) C_noret;
C_noret_decl(f_11169)
static void C_ccall f_11169(C_word c,C_word *av) C_noret;
C_noret_decl(f_11186)
static void C_ccall f_11186(C_word c,C_word *av) C_noret;
C_noret_decl(f_11203)
static void C_ccall f_11203(C_word c,C_word *av) C_noret;
C_noret_decl(f_11220)
static void C_ccall f_11220(C_word c,C_word *av) C_noret;
C_noret_decl(f_11237)
static void C_ccall f_11237(C_word c,C_word *av) C_noret;
C_noret_decl(f_11266)
static void C_ccall f_11266(C_word c,C_word *av) C_noret;
C_noret_decl(f_11270)
static void C_ccall f_11270(C_word c,C_word *av) C_noret;
C_noret_decl(f_11291)
static void C_ccall f_11291(C_word c,C_word *av) C_noret;
C_noret_decl(f_11293)
static void C_fcall f_11293(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11303)
static void C_fcall f_11303(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11318)
static void C_ccall f_11318(C_word c,C_word *av) C_noret;
C_noret_decl(f_11717)
static void C_fcall f_11717(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11719)
static void C_fcall f_11719(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11747)
static void C_fcall f_11747(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11774)
static void C_fcall f_11774(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11999)
static void C_fcall f_11999(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12008)
static void C_fcall f_12008(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12017)
static void C_ccall f_12017(C_word c,C_word *av) C_noret;
C_noret_decl(f_12115)
static void C_ccall f_12115(C_word c,C_word *av) C_noret;
C_noret_decl(f_12382)
static void C_fcall f_12382(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12384)
static void C_fcall f_12384(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12451)
static void C_ccall f_12451(C_word c,C_word *av) C_noret;
C_noret_decl(f_12457)
static void C_ccall f_12457(C_word c,C_word *av) C_noret;
C_noret_decl(f_12460)
static void C_ccall f_12460(C_word c,C_word *av) C_noret;
C_noret_decl(f_12463)
static void C_ccall f_12463(C_word c,C_word *av) C_noret;
C_noret_decl(f_12475)
static void C_ccall f_12475(C_word c,C_word *av) C_noret;
C_noret_decl(f_12481)
static void C_ccall f_12481(C_word c,C_word *av) C_noret;
C_noret_decl(f_12484)
static void C_ccall f_12484(C_word c,C_word *av) C_noret;
C_noret_decl(f_12487)
static void C_ccall f_12487(C_word c,C_word *av) C_noret;
C_noret_decl(f_12499)
static void C_fcall f_12499(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12502)
static void C_ccall f_12502(C_word c,C_word *av) C_noret;
C_noret_decl(f_12508)
static void C_ccall f_12508(C_word c,C_word *av) C_noret;
C_noret_decl(f_12511)
static void C_ccall f_12511(C_word c,C_word *av) C_noret;
C_noret_decl(f_12514)
static void C_ccall f_12514(C_word c,C_word *av) C_noret;
C_noret_decl(f_12526)
static void C_ccall f_12526(C_word c,C_word *av) C_noret;
C_noret_decl(f_12532)
static void C_ccall f_12532(C_word c,C_word *av) C_noret;
C_noret_decl(f_12535)
static void C_ccall f_12535(C_word c,C_word *av) C_noret;
C_noret_decl(f_12538)
static void C_ccall f_12538(C_word c,C_word *av) C_noret;
C_noret_decl(f_12553)
static void C_ccall f_12553(C_word c,C_word *av) C_noret;
C_noret_decl(f_12559)
static void C_ccall f_12559(C_word c,C_word *av) C_noret;
C_noret_decl(f_12562)
static void C_ccall f_12562(C_word c,C_word *av) C_noret;
C_noret_decl(f_12565)
static void C_ccall f_12565(C_word c,C_word *av) C_noret;
C_noret_decl(f_12580)
static void C_ccall f_12580(C_word c,C_word *av) C_noret;
C_noret_decl(f_12586)
static void C_ccall f_12586(C_word c,C_word *av) C_noret;
C_noret_decl(f_12589)
static void C_ccall f_12589(C_word c,C_word *av) C_noret;
C_noret_decl(f_12592)
static void C_ccall f_12592(C_word c,C_word *av) C_noret;
C_noret_decl(f_12607)
static void C_ccall f_12607(C_word c,C_word *av) C_noret;
C_noret_decl(f_12613)
static void C_ccall f_12613(C_word c,C_word *av) C_noret;
C_noret_decl(f_12616)
static void C_ccall f_12616(C_word c,C_word *av) C_noret;
C_noret_decl(f_12619)
static void C_ccall f_12619(C_word c,C_word *av) C_noret;
C_noret_decl(f_12634)
static void C_ccall f_12634(C_word c,C_word *av) C_noret;
C_noret_decl(f_12640)
static void C_ccall f_12640(C_word c,C_word *av) C_noret;
C_noret_decl(f_12643)
static void C_ccall f_12643(C_word c,C_word *av) C_noret;
C_noret_decl(f_12646)
static void C_ccall f_12646(C_word c,C_word *av) C_noret;
C_noret_decl(f_12658)
static void C_ccall f_12658(C_word c,C_word *av) C_noret;
C_noret_decl(f_12664)
static void C_ccall f_12664(C_word c,C_word *av) C_noret;
C_noret_decl(f_12667)
static void C_ccall f_12667(C_word c,C_word *av) C_noret;
C_noret_decl(f_12670)
static void C_ccall f_12670(C_word c,C_word *av) C_noret;
C_noret_decl(f_12682)
static void C_ccall f_12682(C_word c,C_word *av) C_noret;
C_noret_decl(f_12688)
static void C_ccall f_12688(C_word c,C_word *av) C_noret;
C_noret_decl(f_12691)
static void C_ccall f_12691(C_word c,C_word *av) C_noret;
C_noret_decl(f_12694)
static void C_ccall f_12694(C_word c,C_word *av) C_noret;
C_noret_decl(f_12715)
static void C_ccall f_12715(C_word c,C_word *av) C_noret;
C_noret_decl(f_12719)
static void C_fcall f_12719(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12751)
static void C_ccall f_12751(C_word c,C_word *av) C_noret;
C_noret_decl(f_12757)
static void C_ccall f_12757(C_word c,C_word *av) C_noret;
C_noret_decl(f_12760)
static void C_ccall f_12760(C_word c,C_word *av) C_noret;
C_noret_decl(f_12763)
static void C_ccall f_12763(C_word c,C_word *av) C_noret;
C_noret_decl(f_12775)
static void C_ccall f_12775(C_word c,C_word *av) C_noret;
C_noret_decl(f_12781)
static void C_ccall f_12781(C_word c,C_word *av) C_noret;
C_noret_decl(f_12784)
static void C_ccall f_12784(C_word c,C_word *av) C_noret;
C_noret_decl(f_12787)
static void C_ccall f_12787(C_word c,C_word *av) C_noret;
C_noret_decl(f_12799)
static void C_ccall f_12799(C_word c,C_word *av) C_noret;
C_noret_decl(f_12805)
static void C_ccall f_12805(C_word c,C_word *av) C_noret;
C_noret_decl(f_12808)
static void C_ccall f_12808(C_word c,C_word *av) C_noret;
C_noret_decl(f_12811)
static void C_ccall f_12811(C_word c,C_word *av) C_noret;
C_noret_decl(f_12823)
static void C_ccall f_12823(C_word c,C_word *av) C_noret;
C_noret_decl(f_12829)
static void C_ccall f_12829(C_word c,C_word *av) C_noret;
C_noret_decl(f_12832)
static void C_ccall f_12832(C_word c,C_word *av) C_noret;
C_noret_decl(f_12835)
static void C_ccall f_12835(C_word c,C_word *av) C_noret;
C_noret_decl(f_12847)
static void C_ccall f_12847(C_word c,C_word *av) C_noret;
C_noret_decl(f_12853)
static void C_ccall f_12853(C_word c,C_word *av) C_noret;
C_noret_decl(f_12856)
static void C_ccall f_12856(C_word c,C_word *av) C_noret;
C_noret_decl(f_12859)
static void C_ccall f_12859(C_word c,C_word *av) C_noret;
C_noret_decl(f_12887)
static void C_ccall f_12887(C_word c,C_word *av) C_noret;
C_noret_decl(f_12893)
static void C_ccall f_12893(C_word c,C_word *av) C_noret;
C_noret_decl(f_12896)
static void C_ccall f_12896(C_word c,C_word *av) C_noret;
C_noret_decl(f_12899)
static void C_ccall f_12899(C_word c,C_word *av) C_noret;
C_noret_decl(f_12911)
static void C_ccall f_12911(C_word c,C_word *av) C_noret;
C_noret_decl(f_12917)
static void C_ccall f_12917(C_word c,C_word *av) C_noret;
C_noret_decl(f_12920)
static void C_ccall f_12920(C_word c,C_word *av) C_noret;
C_noret_decl(f_12923)
static void C_ccall f_12923(C_word c,C_word *av) C_noret;
C_noret_decl(f_12935)
static void C_ccall f_12935(C_word c,C_word *av) C_noret;
C_noret_decl(f_12941)
static void C_ccall f_12941(C_word c,C_word *av) C_noret;
C_noret_decl(f_12944)
static void C_ccall f_12944(C_word c,C_word *av) C_noret;
C_noret_decl(f_12947)
static void C_ccall f_12947(C_word c,C_word *av) C_noret;
C_noret_decl(f_13169)
static void C_fcall f_13169(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13178)
static void C_fcall f_13178(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13244)
static void C_ccall f_13244(C_word c,C_word *av) C_noret;
C_noret_decl(f_13266)
static void C_ccall f_13266(C_word c,C_word *av) C_noret;
C_noret_decl(f_13294)
static void C_fcall f_13294(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13353)
static void C_ccall f_13353(C_word c,C_word *av) C_noret;
C_noret_decl(f_13360)
static void C_ccall f_13360(C_word c,C_word *av) C_noret;
C_noret_decl(f_13380)
static void C_ccall f_13380(C_word c,C_word *av) C_noret;
C_noret_decl(f_13387)
static void C_ccall f_13387(C_word c,C_word *av) C_noret;
C_noret_decl(f_13400)
static void C_ccall f_13400(C_word c,C_word *av) C_noret;
C_noret_decl(f_13407)
static void C_ccall f_13407(C_word c,C_word *av) C_noret;
C_noret_decl(f_13430)
static void C_ccall f_13430(C_word c,C_word *av) C_noret;
C_noret_decl(f_13438)
static void C_ccall f_13438(C_word c,C_word *av) C_noret;
C_noret_decl(f_13460)
static void C_ccall f_13460(C_word c,C_word *av) C_noret;
C_noret_decl(f_13468)
static void C_ccall f_13468(C_word c,C_word *av) C_noret;
C_noret_decl(f_13472)
static void C_ccall f_13472(C_word c,C_word *av) C_noret;
C_noret_decl(f_13474)
static void C_ccall f_13474(C_word c,C_word *av) C_noret;
C_noret_decl(f_13503)
static void C_ccall f_13503(C_word c,C_word *av) C_noret;
C_noret_decl(f_3247)
static void C_ccall f_3247(C_word c,C_word *av) C_noret;
C_noret_decl(f_3250)
static void C_ccall f_3250(C_word c,C_word *av) C_noret;
C_noret_decl(f_3253)
static void C_ccall f_3253(C_word c,C_word *av) C_noret;
C_noret_decl(f_3256)
static void C_ccall f_3256(C_word c,C_word *av) C_noret;
C_noret_decl(f_3259)
static void C_ccall f_3259(C_word c,C_word *av) C_noret;
C_noret_decl(f_3262)
static void C_ccall f_3262(C_word c,C_word *av) C_noret;
C_noret_decl(f_3265)
static void C_ccall f_3265(C_word c,C_word *av) C_noret;
C_noret_decl(f_3268)
static void C_ccall f_3268(C_word c,C_word *av) C_noret;
C_noret_decl(f_3709)
static void C_fcall f_3709(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_3723)
static void C_ccall f_3723(C_word c,C_word *av) C_noret;
C_noret_decl(f_4281)
static void C_fcall f_4281(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4287)
static void C_fcall f_4287(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4301)
static void C_ccall f_4301(C_word c,C_word *av) C_noret;
C_noret_decl(f_4305)
static void C_ccall f_4305(C_word c,C_word *av) C_noret;
C_noret_decl(f_4461)
static void C_ccall f_4461(C_word c,C_word *av) C_noret;
C_noret_decl(f_4473)
static void C_ccall f_4473(C_word c,C_word *av) C_noret;
C_noret_decl(f_4549)
static void C_ccall f_4549(C_word c,C_word *av) C_noret;
C_noret_decl(f_4569)
static void C_fcall f_4569(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4579)
static void C_ccall f_4579(C_word c,C_word *av) C_noret;
C_noret_decl(f_4592)
static void C_fcall f_4592(C_word t0,C_word t1) C_noret;
C_noret_decl(f_4601)
static void C_ccall f_4601(C_word c,C_word *av) C_noret;
C_noret_decl(f_4606)
static void C_fcall f_4606(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4616)
static void C_ccall f_4616(C_word c,C_word *av) C_noret;
C_noret_decl(f_4657)
static void C_ccall f_4657(C_word c,C_word *av) C_noret;
C_noret_decl(f_4663)
static void C_ccall f_4663(C_word c,C_word *av) C_noret;
C_noret_decl(f_4668)
static void C_ccall f_4668(C_word c,C_word *av) C_noret;
C_noret_decl(f_4676)
static void C_ccall f_4676(C_word c,C_word *av) C_noret;
C_noret_decl(f_4680)
static void C_ccall f_4680(C_word c,C_word *av) C_noret;
C_noret_decl(f_4690)
static void C_ccall f_4690(C_word c,C_word *av) C_noret;
C_noret_decl(f_4701)
static void C_ccall f_4701(C_word c,C_word *av) C_noret;
C_noret_decl(f_4705)
static void C_ccall f_4705(C_word c,C_word *av) C_noret;
C_noret_decl(f_4708)
static void C_ccall f_4708(C_word c,C_word *av) C_noret;
C_noret_decl(f_4710)
static void C_fcall f_4710(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4714)
static void C_ccall f_4714(C_word c,C_word *av) C_noret;
C_noret_decl(f_4722)
static void C_fcall f_4722(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_4725)
static void C_fcall f_4725(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_4729)
static void C_ccall f_4729(C_word c,C_word *av) C_noret;
C_noret_decl(f_4732)
static void C_ccall f_4732(C_word c,C_word *av) C_noret;
C_noret_decl(f_4735)
static void C_ccall f_4735(C_word c,C_word *av) C_noret;
C_noret_decl(f_4873)
static void C_ccall f_4873(C_word c,C_word *av) C_noret;
C_noret_decl(f_4887)
static void C_ccall f_4887(C_word c,C_word *av) C_noret;
C_noret_decl(f_4906)
static void C_ccall f_4906(C_word c,C_word *av) C_noret;
C_noret_decl(f_4909)
static void C_ccall f_4909(C_word c,C_word *av) C_noret;
C_noret_decl(f_4912)
static void C_ccall f_4912(C_word c,C_word *av) C_noret;
C_noret_decl(f_4915)
static void C_ccall f_4915(C_word c,C_word *av) C_noret;
C_noret_decl(f_4918)
static void C_ccall f_4918(C_word c,C_word *av) C_noret;
C_noret_decl(f_4921)
static void C_ccall f_4921(C_word c,C_word *av) C_noret;
C_noret_decl(f_4964)
static void C_fcall f_4964(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_4974)
static void C_ccall f_4974(C_word c,C_word *av) C_noret;
C_noret_decl(f_4977)
static void C_ccall f_4977(C_word c,C_word *av) C_noret;
C_noret_decl(f_4980)
static void C_ccall f_4980(C_word c,C_word *av) C_noret;
C_noret_decl(f_5012)
static void C_ccall f_5012(C_word c,C_word *av) C_noret;
C_noret_decl(f_5015)
static void C_ccall f_5015(C_word c,C_word *av) C_noret;
C_noret_decl(f_5018)
static void C_ccall f_5018(C_word c,C_word *av) C_noret;
C_noret_decl(f_5051)
static void C_ccall f_5051(C_word c,C_word *av) C_noret;
C_noret_decl(f_5054)
static void C_ccall f_5054(C_word c,C_word *av) C_noret;
C_noret_decl(f_5070)
static void C_ccall f_5070(C_word c,C_word *av) C_noret;
C_noret_decl(f_5073)
static void C_ccall f_5073(C_word c,C_word *av) C_noret;
C_noret_decl(f_5089)
static void C_ccall f_5089(C_word c,C_word *av) C_noret;
C_noret_decl(f_5092)
static void C_ccall f_5092(C_word c,C_word *av) C_noret;
C_noret_decl(f_5116)
static void C_ccall f_5116(C_word c,C_word *av) C_noret;
C_noret_decl(f_5122)
static void C_fcall f_5122(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5141)
static void C_ccall f_5141(C_word c,C_word *av) C_noret;
C_noret_decl(f_5144)
static void C_ccall f_5144(C_word c,C_word *av) C_noret;
C_noret_decl(f_5156)
static void C_ccall f_5156(C_word c,C_word *av) C_noret;
C_noret_decl(f_5162)
static void C_fcall f_5162(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5181)
static void C_ccall f_5181(C_word c,C_word *av) C_noret;
C_noret_decl(f_5184)
static void C_ccall f_5184(C_word c,C_word *av) C_noret;
C_noret_decl(f_5196)
static void C_ccall f_5196(C_word c,C_word *av) C_noret;
C_noret_decl(f_5202)
static void C_fcall f_5202(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5221)
static void C_ccall f_5221(C_word c,C_word *av) C_noret;
C_noret_decl(f_5224)
static void C_ccall f_5224(C_word c,C_word *av) C_noret;
C_noret_decl(f_5236)
static void C_ccall f_5236(C_word c,C_word *av) C_noret;
C_noret_decl(f_5239)
static void C_ccall f_5239(C_word c,C_word *av) C_noret;
C_noret_decl(f_5255)
static void C_ccall f_5255(C_word c,C_word *av) C_noret;
C_noret_decl(f_5258)
static void C_ccall f_5258(C_word c,C_word *av) C_noret;
C_noret_decl(f_5261)
static void C_ccall f_5261(C_word c,C_word *av) C_noret;
C_noret_decl(f_5264)
static void C_ccall f_5264(C_word c,C_word *av) C_noret;
C_noret_decl(f_5288)
static void C_ccall f_5288(C_word c,C_word *av) C_noret;
C_noret_decl(f_5291)
static void C_ccall f_5291(C_word c,C_word *av) C_noret;
C_noret_decl(f_5294)
static void C_ccall f_5294(C_word c,C_word *av) C_noret;
C_noret_decl(f_5297)
static void C_ccall f_5297(C_word c,C_word *av) C_noret;
C_noret_decl(f_5325)
static void C_ccall f_5325(C_word c,C_word *av) C_noret;
C_noret_decl(f_5328)
static void C_ccall f_5328(C_word c,C_word *av) C_noret;
C_noret_decl(f_5331)
static void C_ccall f_5331(C_word c,C_word *av) C_noret;
C_noret_decl(f_5334)
static void C_ccall f_5334(C_word c,C_word *av) C_noret;
C_noret_decl(f_5354)
static void C_ccall f_5354(C_word c,C_word *av) C_noret;
C_noret_decl(f_5357)
static void C_ccall f_5357(C_word c,C_word *av) C_noret;
C_noret_decl(f_5360)
static void C_ccall f_5360(C_word c,C_word *av) C_noret;
C_noret_decl(f_5363)
static void C_ccall f_5363(C_word c,C_word *av) C_noret;
C_noret_decl(f_5386)
static void C_ccall f_5386(C_word c,C_word *av) C_noret;
C_noret_decl(f_5387)
static void C_fcall f_5387(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_5391)
static void C_ccall f_5391(C_word c,C_word *av) C_noret;
C_noret_decl(f_5394)
static void C_ccall f_5394(C_word c,C_word *av) C_noret;
C_noret_decl(f_5400)
static void C_ccall f_5400(C_word c,C_word *av) C_noret;
C_noret_decl(f_5409)
static void C_ccall f_5409(C_word c,C_word *av) C_noret;
C_noret_decl(f_5416)
static void C_fcall f_5416(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_5426)
static void C_ccall f_5426(C_word c,C_word *av) C_noret;
C_noret_decl(f_5460)
static void C_ccall f_5460(C_word c,C_word *av) C_noret;
C_noret_decl(f_5463)
static void C_ccall f_5463(C_word c,C_word *av) C_noret;
C_noret_decl(f_5492)
static void C_ccall f_5492(C_word c,C_word *av) C_noret;
C_noret_decl(f_5534)
static void C_ccall f_5534(C_word c,C_word *av) C_noret;
C_noret_decl(f_5538)
static void C_ccall f_5538(C_word c,C_word *av) C_noret;
C_noret_decl(f_5569)
static void C_ccall f_5569(C_word c,C_word *av) C_noret;
C_noret_decl(f_5572)
static void C_ccall f_5572(C_word c,C_word *av) C_noret;
C_noret_decl(f_5575)
static void C_ccall f_5575(C_word c,C_word *av) C_noret;
C_noret_decl(f_5586)
static void C_ccall f_5586(C_word c,C_word *av) C_noret;
C_noret_decl(f_5590)
static void C_ccall f_5590(C_word c,C_word *av) C_noret;
C_noret_decl(f_5617)
static void C_ccall f_5617(C_word c,C_word *av) C_noret;
C_noret_decl(f_5620)
static void C_ccall f_5620(C_word c,C_word *av) C_noret;
C_noret_decl(f_5631)
static void C_ccall f_5631(C_word c,C_word *av) C_noret;
C_noret_decl(f_5635)
static void C_ccall f_5635(C_word c,C_word *av) C_noret;
C_noret_decl(f_5638)
static void C_ccall f_5638(C_word c,C_word *av) C_noret;
C_noret_decl(f_5641)
static void C_ccall f_5641(C_word c,C_word *av) C_noret;
C_noret_decl(f_5652)
static void C_ccall f_5652(C_word c,C_word *av) C_noret;
C_noret_decl(f_5656)
static void C_ccall f_5656(C_word c,C_word *av) C_noret;
C_noret_decl(f_5693)
static void C_ccall f_5693(C_word c,C_word *av) C_noret;
C_noret_decl(f_5696)
static void C_fcall f_5696(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5702)
static void C_fcall f_5702(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5706)
static void C_ccall f_5706(C_word c,C_word *av) C_noret;
C_noret_decl(f_5715)
static void C_ccall f_5715(C_word c,C_word *av) C_noret;
C_noret_decl(f_5718)
static void C_ccall f_5718(C_word c,C_word *av) C_noret;
C_noret_decl(f_5721)
static void C_ccall f_5721(C_word c,C_word *av) C_noret;
C_noret_decl(f_5737)
static void C_ccall f_5737(C_word c,C_word *av) C_noret;
C_noret_decl(f_5740)
static void C_ccall f_5740(C_word c,C_word *av) C_noret;
C_noret_decl(f_5743)
static void C_ccall f_5743(C_word c,C_word *av) C_noret;
C_noret_decl(f_5744)
static void C_fcall f_5744(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_5748)
static void C_ccall f_5748(C_word c,C_word *av) C_noret;
C_noret_decl(f_5751)
static void C_ccall f_5751(C_word c,C_word *av) C_noret;
C_noret_decl(f_5760)
static void C_ccall f_5760(C_word c,C_word *av) C_noret;
C_noret_decl(f_5768)
static void C_ccall f_5768(C_word c,C_word *av) C_noret;
C_noret_decl(f_5774)
static void C_ccall f_5774(C_word c,C_word *av) C_noret;
C_noret_decl(f_5777)
static void C_ccall f_5777(C_word c,C_word *av) C_noret;
C_noret_decl(f_5785)
static void C_fcall f_5785(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_5795)
static void C_ccall f_5795(C_word c,C_word *av) C_noret;
C_noret_decl(f_5822)
static void C_fcall f_5822(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_5832)
static void C_ccall f_5832(C_word c,C_word *av) C_noret;
C_noret_decl(f_5859)
static void C_ccall f_5859(C_word c,C_word *av) C_noret;
C_noret_decl(f_5866)
static void C_ccall f_5866(C_word c,C_word *av) C_noret;
C_noret_decl(f_5872)
static void C_ccall f_5872(C_word c,C_word *av) C_noret;
C_noret_decl(f_5875)
static void C_ccall f_5875(C_word c,C_word *av) C_noret;
C_noret_decl(f_5878)
static void C_ccall f_5878(C_word c,C_word *av) C_noret;
C_noret_decl(f_5887)
static void C_ccall f_5887(C_word c,C_word *av) C_noret;
C_noret_decl(f_5890)
static void C_ccall f_5890(C_word c,C_word *av) C_noret;
C_noret_decl(f_5893)
static void C_ccall f_5893(C_word c,C_word *av) C_noret;
C_noret_decl(f_5896)
static void C_ccall f_5896(C_word c,C_word *av) C_noret;
C_noret_decl(f_5906)
static void C_ccall f_5906(C_word c,C_word *av) C_noret;
C_noret_decl(f_5917)
static void C_ccall f_5917(C_word c,C_word *av) C_noret;
C_noret_decl(f_5921)
static void C_ccall f_5921(C_word c,C_word *av) C_noret;
C_noret_decl(f_5924)
static void C_ccall f_5924(C_word c,C_word *av) C_noret;
C_noret_decl(f_5937)
static void C_ccall f_5937(C_word c,C_word *av) C_noret;
C_noret_decl(f_5943)
static void C_fcall f_5943(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5946)
static void C_ccall f_5946(C_word c,C_word *av) C_noret;
C_noret_decl(f_5958)
static void C_ccall f_5958(C_word c,C_word *av) C_noret;
C_noret_decl(f_5961)
static void C_ccall f_5961(C_word c,C_word *av) C_noret;
C_noret_decl(f_5964)
static void C_ccall f_5964(C_word c,C_word *av) C_noret;
C_noret_decl(f_5967)
static void C_ccall f_5967(C_word c,C_word *av) C_noret;
C_noret_decl(f_5974)
static void C_ccall f_5974(C_word c,C_word *av) C_noret;
C_noret_decl(f_5984)
static void C_ccall f_5984(C_word c,C_word *av) C_noret;
C_noret_decl(f_5992)
static void C_ccall f_5992(C_word c,C_word *av) C_noret;
C_noret_decl(f_6000)
static void C_ccall f_6000(C_word c,C_word *av) C_noret;
C_noret_decl(f_6013)
static void C_ccall f_6013(C_word c,C_word *av) C_noret;
C_noret_decl(f_6017)
static void C_ccall f_6017(C_word c,C_word *av) C_noret;
C_noret_decl(f_6025)
static void C_ccall f_6025(C_word c,C_word *av) C_noret;
C_noret_decl(f_6033)
static void C_ccall f_6033(C_word c,C_word *av) C_noret;
C_noret_decl(f_6040)
static void C_ccall f_6040(C_word c,C_word *av) C_noret;
C_noret_decl(f_6045)
static void C_ccall f_6045(C_word c,C_word *av) C_noret;
C_noret_decl(f_6052)
static void C_ccall f_6052(C_word c,C_word *av) C_noret;
C_noret_decl(f_6056)
static void C_ccall f_6056(C_word c,C_word *av) C_noret;
C_noret_decl(f_6059)
static void C_ccall f_6059(C_word c,C_word *av) C_noret;
C_noret_decl(f_6062)
static void C_ccall f_6062(C_word c,C_word *av) C_noret;
C_noret_decl(f_6065)
static void C_ccall f_6065(C_word c,C_word *av) C_noret;
C_noret_decl(f_6068)
static void C_ccall f_6068(C_word c,C_word *av) C_noret;
C_noret_decl(f_6071)
static void C_ccall f_6071(C_word c,C_word *av) C_noret;
C_noret_decl(f_6077)
static void C_fcall f_6077(C_word t0,C_word t1) C_noret;
C_noret_decl(f_6090)
static void C_ccall f_6090(C_word c,C_word *av) C_noret;
C_noret_decl(f_6095)
static void C_ccall f_6095(C_word c,C_word *av) C_noret;
C_noret_decl(f_6118)
static void C_ccall f_6118(C_word c,C_word *av) C_noret;
C_noret_decl(f_6122)
static void C_ccall f_6122(C_word c,C_word *av) C_noret;
C_noret_decl(f_6125)
static void C_ccall f_6125(C_word c,C_word *av) C_noret;
C_noret_decl(f_6145)
static void C_ccall f_6145(C_word c,C_word *av) C_noret;
C_noret_decl(f_6152)
static void C_ccall f_6152(C_word c,C_word *av) C_noret;
C_noret_decl(f_6156)
static void C_ccall f_6156(C_word c,C_word *av) C_noret;
C_noret_decl(f_6160)
static void C_ccall f_6160(C_word c,C_word *av) C_noret;
C_noret_decl(f_6203)
static void C_ccall f_6203(C_word c,C_word *av) C_noret;
C_noret_decl(f_6209)
static void C_ccall f_6209(C_word c,C_word *av) C_noret;
C_noret_decl(f_6212)
static void C_ccall f_6212(C_word c,C_word *av) C_noret;
C_noret_decl(f_6213)
static void C_fcall f_6213(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6217)
static void C_ccall f_6217(C_word c,C_word *av) C_noret;
C_noret_decl(f_6220)
static void C_ccall f_6220(C_word c,C_word *av) C_noret;
C_noret_decl(f_6229)
static void C_ccall f_6229(C_word c,C_word *av) C_noret;
C_noret_decl(f_6237)
static void C_ccall f_6237(C_word c,C_word *av) C_noret;
C_noret_decl(f_6243)
static void C_ccall f_6243(C_word c,C_word *av) C_noret;
C_noret_decl(f_6248)
static void C_fcall f_6248(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6258)
static void C_ccall f_6258(C_word c,C_word *av) C_noret;
C_noret_decl(f_6285)
static void C_fcall f_6285(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6295)
static void C_ccall f_6295(C_word c,C_word *av) C_noret;
C_noret_decl(f_6322)
static void C_ccall f_6322(C_word c,C_word *av) C_noret;
C_noret_decl(f_6329)
static void C_ccall f_6329(C_word c,C_word *av) C_noret;
C_noret_decl(f_6332)
static void C_ccall f_6332(C_word c,C_word *av) C_noret;
C_noret_decl(f_6335)
static void C_ccall f_6335(C_word c,C_word *av) C_noret;
C_noret_decl(f_6363)
static void C_ccall f_6363(C_word c,C_word *av) C_noret;
C_noret_decl(f_6376)
static void C_ccall f_6376(C_word c,C_word *av) C_noret;
C_noret_decl(f_6380)
static void C_ccall f_6380(C_word c,C_word *av) C_noret;
C_noret_decl(f_6383)
static void C_ccall f_6383(C_word c,C_word *av) C_noret;
C_noret_decl(f_6386)
static void C_ccall f_6386(C_word c,C_word *av) C_noret;
C_noret_decl(f_6389)
static void C_ccall f_6389(C_word c,C_word *av) C_noret;
C_noret_decl(f_6392)
static void C_ccall f_6392(C_word c,C_word *av) C_noret;
C_noret_decl(f_6395)
static void C_ccall f_6395(C_word c,C_word *av) C_noret;
C_noret_decl(f_6398)
static void C_ccall f_6398(C_word c,C_word *av) C_noret;
C_noret_decl(f_6410)
static void C_ccall f_6410(C_word c,C_word *av) C_noret;
C_noret_decl(f_6422)
static void C_ccall f_6422(C_word c,C_word *av) C_noret;
C_noret_decl(f_6440)
static void C_ccall f_6440(C_word c,C_word *av) C_noret;
C_noret_decl(f_6460)
static void C_ccall f_6460(C_word c,C_word *av) C_noret;
C_noret_decl(f_6467)
static void C_ccall f_6467(C_word c,C_word *av) C_noret;
C_noret_decl(f_6471)
static void C_ccall f_6471(C_word c,C_word *av) C_noret;
C_noret_decl(f_6500)
static void C_ccall f_6500(C_word c,C_word *av) C_noret;
C_noret_decl(f_6503)
static void C_ccall f_6503(C_word c,C_word *av) C_noret;
C_noret_decl(f_6510)
static void C_ccall f_6510(C_word c,C_word *av) C_noret;
C_noret_decl(f_6523)
static void C_ccall f_6523(C_word c,C_word *av) C_noret;
C_noret_decl(f_6526)
static void C_ccall f_6526(C_word c,C_word *av) C_noret;
C_noret_decl(f_6542)
static void C_ccall f_6542(C_word c,C_word *av) C_noret;
C_noret_decl(f_6545)
static void C_ccall f_6545(C_word c,C_word *av) C_noret;
C_noret_decl(f_6578)
static void C_ccall f_6578(C_word c,C_word *av) C_noret;
C_noret_decl(f_6581)
static void C_ccall f_6581(C_word c,C_word *av) C_noret;
C_noret_decl(f_6590)
static void C_ccall f_6590(C_word c,C_word *av) C_noret;
C_noret_decl(f_6614)
static void C_ccall f_6614(C_word c,C_word *av) C_noret;
C_noret_decl(f_6634)
static void C_ccall f_6634(C_word c,C_word *av) C_noret;
C_noret_decl(f_6637)
static void C_ccall f_6637(C_word c,C_word *av) C_noret;
C_noret_decl(f_6652)
static void C_ccall f_6652(C_word c,C_word *av) C_noret;
C_noret_decl(f_6656)
static void C_ccall f_6656(C_word c,C_word *av) C_noret;
C_noret_decl(f_6668)
static void C_ccall f_6668(C_word c,C_word *av) C_noret;
C_noret_decl(f_6671)
static void C_ccall f_6671(C_word c,C_word *av) C_noret;
C_noret_decl(f_6682)
static void C_ccall f_6682(C_word c,C_word *av) C_noret;
C_noret_decl(f_6686)
static void C_ccall f_6686(C_word c,C_word *av) C_noret;
C_noret_decl(f_6698)
static void C_ccall f_6698(C_word c,C_word *av) C_noret;
C_noret_decl(f_6701)
static void C_ccall f_6701(C_word c,C_word *av) C_noret;
C_noret_decl(f_6704)
static void C_ccall f_6704(C_word c,C_word *av) C_noret;
C_noret_decl(f_6707)
static void C_ccall f_6707(C_word c,C_word *av) C_noret;
C_noret_decl(f_6718)
static void C_ccall f_6718(C_word c,C_word *av) C_noret;
C_noret_decl(f_6726)
static void C_ccall f_6726(C_word c,C_word *av) C_noret;
C_noret_decl(f_6735)
static void C_ccall f_6735(C_word c,C_word *av) C_noret;
C_noret_decl(f_6738)
static void C_ccall f_6738(C_word c,C_word *av) C_noret;
C_noret_decl(f_6741)
static void C_ccall f_6741(C_word c,C_word *av) C_noret;
C_noret_decl(f_6754)
static void C_fcall f_6754(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6762)
static void C_ccall f_6762(C_word c,C_word *av) C_noret;
C_noret_decl(f_6765)
static void C_ccall f_6765(C_word c,C_word *av) C_noret;
C_noret_decl(f_6775)
static void C_ccall f_6775(C_word c,C_word *av) C_noret;
C_noret_decl(f_6778)
static void C_ccall f_6778(C_word c,C_word *av) C_noret;
C_noret_decl(f_6781)
static void C_ccall f_6781(C_word c,C_word *av) C_noret;
C_noret_decl(f_6784)
static void C_ccall f_6784(C_word c,C_word *av) C_noret;
C_noret_decl(f_6814)
static void C_ccall f_6814(C_word c,C_word *av) C_noret;
C_noret_decl(f_6817)
static void C_ccall f_6817(C_word c,C_word *av) C_noret;
C_noret_decl(f_6820)
static void C_ccall f_6820(C_word c,C_word *av) C_noret;
C_noret_decl(f_6823)
static void C_ccall f_6823(C_word c,C_word *av) C_noret;
C_noret_decl(f_6826)
static void C_ccall f_6826(C_word c,C_word *av) C_noret;
C_noret_decl(f_6829)
static void C_ccall f_6829(C_word c,C_word *av) C_noret;
C_noret_decl(f_6851)
static void C_ccall f_6851(C_word c,C_word *av) C_noret;
C_noret_decl(f_6937)
static void C_fcall f_6937(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6943)
static void C_fcall f_6943(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6953)
static void C_ccall f_6953(C_word c,C_word *av) C_noret;
C_noret_decl(f_6956)
static void C_ccall f_6956(C_word c,C_word *av) C_noret;
C_noret_decl(f_6973)
static void C_fcall f_6973(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6979)
static void C_fcall f_6979(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6998)
static void C_ccall f_6998(C_word c,C_word *av) C_noret;
C_noret_decl(f_7010)
static void C_ccall f_7010(C_word c,C_word *av) C_noret;
C_noret_decl(f_7014)
static void C_ccall f_7014(C_word c,C_word *av) C_noret;
C_noret_decl(f_7016)
static void C_fcall f_7016(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_7028)
static void C_fcall f_7028(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7031)
static void C_ccall f_7031(C_word c,C_word *av) C_noret;
C_noret_decl(f_7034)
static void C_ccall f_7034(C_word c,C_word *av) C_noret;
C_noret_decl(f_7037)
static void C_ccall f_7037(C_word c,C_word *av) C_noret;
C_noret_decl(f_7040)
static void C_ccall f_7040(C_word c,C_word *av) C_noret;
C_noret_decl(f_7049)
static void C_fcall f_7049(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7059)
static void C_ccall f_7059(C_word c,C_word *av) C_noret;
C_noret_decl(f_7062)
static void C_ccall f_7062(C_word c,C_word *av) C_noret;
C_noret_decl(f_7065)
static void C_ccall f_7065(C_word c,C_word *av) C_noret;
C_noret_decl(f_7085)
static void C_ccall f_7085(C_word c,C_word *av) C_noret;
C_noret_decl(f_7100)
static void C_ccall f_7100(C_word c,C_word *av) C_noret;
C_noret_decl(f_7103)
static void C_ccall f_7103(C_word c,C_word *av) C_noret;
C_noret_decl(f_7106)
static void C_ccall f_7106(C_word c,C_word *av) C_noret;
C_noret_decl(f_7109)
static void C_ccall f_7109(C_word c,C_word *av) C_noret;
C_noret_decl(f_7112)
static void C_ccall f_7112(C_word c,C_word *av) C_noret;
C_noret_decl(f_7134)
static void C_ccall f_7134(C_word c,C_word *av) C_noret;
C_noret_decl(f_7137)
static void C_ccall f_7137(C_word c,C_word *av) C_noret;
C_noret_decl(f_7145)
static void C_fcall f_7145(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7149)
static void C_ccall f_7149(C_word c,C_word *av) C_noret;
C_noret_decl(f_7152)
static void C_ccall f_7152(C_word c,C_word *av) C_noret;
C_noret_decl(f_7155)
static void C_ccall f_7155(C_word c,C_word *av) C_noret;
C_noret_decl(f_7158)
static void C_ccall f_7158(C_word c,C_word *av) C_noret;
C_noret_decl(f_7161)
static void C_ccall f_7161(C_word c,C_word *av) C_noret;
C_noret_decl(f_7164)
static void C_ccall f_7164(C_word c,C_word *av) C_noret;
C_noret_decl(f_7167)
static void C_ccall f_7167(C_word c,C_word *av) C_noret;
C_noret_decl(f_7170)
static void C_ccall f_7170(C_word c,C_word *av) C_noret;
C_noret_decl(f_7182)
static void C_ccall f_7182(C_word c,C_word *av) C_noret;
C_noret_decl(f_7192)
static void C_fcall f_7192(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7202)
static void C_ccall f_7202(C_word c,C_word *av) C_noret;
C_noret_decl(f_7222)
static void C_ccall f_7222(C_word c,C_word *av) C_noret;
C_noret_decl(f_7235)
static void C_ccall f_7235(C_word c,C_word *av) C_noret;
C_noret_decl(f_7247)
static void C_ccall f_7247(C_word c,C_word *av) C_noret;
C_noret_decl(f_7250)
static void C_ccall f_7250(C_word c,C_word *av) C_noret;
C_noret_decl(f_7252)
static void C_fcall f_7252(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7277)
static void C_ccall f_7277(C_word c,C_word *av) C_noret;
C_noret_decl(f_7288)
static void C_ccall f_7288(C_word c,C_word *av) C_noret;
C_noret_decl(f_7298)
static void C_ccall f_7298(C_word c,C_word *av) C_noret;
C_noret_decl(f_7302)
static void C_ccall f_7302(C_word c,C_word *av) C_noret;
C_noret_decl(f_7304)
static void C_fcall f_7304(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7311)
static void C_ccall f_7311(C_word c,C_word *av) C_noret;
C_noret_decl(f_7325)
static void C_ccall f_7325(C_word c,C_word *av) C_noret;
C_noret_decl(f_7331)
static void C_ccall f_7331(C_word c,C_word *av) C_noret;
C_noret_decl(f_7334)
static void C_ccall f_7334(C_word c,C_word *av) C_noret;
C_noret_decl(f_7337)
static void C_ccall f_7337(C_word c,C_word *av) C_noret;
C_noret_decl(f_7342)
static void C_fcall f_7342(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7352)
static void C_ccall f_7352(C_word c,C_word *av) C_noret;
C_noret_decl(f_7358)
static void C_ccall f_7358(C_word c,C_word *av) C_noret;
C_noret_decl(f_7361)
static void C_ccall f_7361(C_word c,C_word *av) C_noret;
C_noret_decl(f_7364)
static void C_ccall f_7364(C_word c,C_word *av) C_noret;
C_noret_decl(f_7367)
static void C_ccall f_7367(C_word c,C_word *av) C_noret;
C_noret_decl(f_7382)
static void C_fcall f_7382(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7390)
static void C_ccall f_7390(C_word c,C_word *av) C_noret;
C_noret_decl(f_7400)
static void C_fcall f_7400(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7410)
static void C_ccall f_7410(C_word c,C_word *av) C_noret;
C_noret_decl(f_7451)
static void C_fcall f_7451(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7461)
static void C_ccall f_7461(C_word c,C_word *av) C_noret;
C_noret_decl(f_7474)
static void C_fcall f_7474(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7499)
static void C_ccall f_7499(C_word c,C_word *av) C_noret;
C_noret_decl(f_7508)
static void C_fcall f_7508(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7512)
static void C_ccall f_7512(C_word c,C_word *av) C_noret;
C_noret_decl(f_7521)
static void C_ccall f_7521(C_word c,C_word *av) C_noret;
C_noret_decl(f_7524)
static void C_ccall f_7524(C_word c,C_word *av) C_noret;
C_noret_decl(f_7527)
static void C_fcall f_7527(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7530)
static void C_ccall f_7530(C_word c,C_word *av) C_noret;
C_noret_decl(f_7533)
static void C_ccall f_7533(C_word c,C_word *av) C_noret;
C_noret_decl(f_7536)
static void C_ccall f_7536(C_word c,C_word *av) C_noret;
C_noret_decl(f_7539)
static void C_ccall f_7539(C_word c,C_word *av) C_noret;
C_noret_decl(f_7542)
static void C_ccall f_7542(C_word c,C_word *av) C_noret;
C_noret_decl(f_7545)
static void C_ccall f_7545(C_word c,C_word *av) C_noret;
C_noret_decl(f_7548)
static void C_ccall f_7548(C_word c,C_word *av) C_noret;
C_noret_decl(f_7551)
static void C_ccall f_7551(C_word c,C_word *av) C_noret;
C_noret_decl(f_7554)
static void C_ccall f_7554(C_word c,C_word *av) C_noret;
C_noret_decl(f_7557)
static void C_ccall f_7557(C_word c,C_word *av) C_noret;
C_noret_decl(f_7560)
static void C_ccall f_7560(C_word c,C_word *av) C_noret;
C_noret_decl(f_7581)
static void C_ccall f_7581(C_word c,C_word *av) C_noret;
C_noret_decl(f_7604)
static void C_ccall f_7604(C_word c,C_word *av) C_noret;
C_noret_decl(f_7607)
static void C_ccall f_7607(C_word c,C_word *av) C_noret;
C_noret_decl(f_7610)
static void C_ccall f_7610(C_word c,C_word *av) C_noret;
C_noret_decl(f_7613)
static void C_ccall f_7613(C_word c,C_word *av) C_noret;
C_noret_decl(f_7629)
static void C_ccall f_7629(C_word c,C_word *av) C_noret;
C_noret_decl(f_7632)
static void C_ccall f_7632(C_word c,C_word *av) C_noret;
C_noret_decl(f_7635)
static void C_ccall f_7635(C_word c,C_word *av) C_noret;
C_noret_decl(f_7646)
static void C_ccall f_7646(C_word c,C_word *av) C_noret;
C_noret_decl(f_7655)
static void C_ccall f_7655(C_word c,C_word *av) C_noret;
C_noret_decl(f_7663)
static void C_fcall f_7663(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7673)
static void C_ccall f_7673(C_word c,C_word *av) C_noret;
C_noret_decl(f_7686)
static void C_fcall f_7686(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7697)
static void C_fcall f_7697(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7707)
static void C_ccall f_7707(C_word c,C_word *av) C_noret;
C_noret_decl(f_7723)
static void C_ccall f_7723(C_word c,C_word *av) C_noret;
C_noret_decl(f_7726)
static void C_ccall f_7726(C_word c,C_word *av) C_noret;
C_noret_decl(f_7729)
static void C_fcall f_7729(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7732)
static void C_fcall f_7732(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7741)
static void C_ccall f_7741(C_word c,C_word *av) C_noret;
C_noret_decl(f_7744)
static void C_ccall f_7744(C_word c,C_word *av) C_noret;
C_noret_decl(f_7747)
static void C_ccall f_7747(C_word c,C_word *av) C_noret;
C_noret_decl(f_7750)
static void C_ccall f_7750(C_word c,C_word *av) C_noret;
C_noret_decl(f_7753)
static void C_ccall f_7753(C_word c,C_word *av) C_noret;
C_noret_decl(f_7756)
static void C_ccall f_7756(C_word c,C_word *av) C_noret;
C_noret_decl(f_7763)
static void C_ccall f_7763(C_word c,C_word *av) C_noret;
C_noret_decl(f_7770)
static void C_ccall f_7770(C_word c,C_word *av) C_noret;
C_noret_decl(f_7776)
static void C_ccall f_7776(C_word c,C_word *av) C_noret;
C_noret_decl(f_7784)
static void C_fcall f_7784(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7794)
static void C_ccall f_7794(C_word c,C_word *av) C_noret;
C_noret_decl(f_7807)
static void C_fcall f_7807(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7813)
static void C_fcall f_7813(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7823)
static void C_ccall f_7823(C_word c,C_word *av) C_noret;
C_noret_decl(f_7838)
static void C_ccall f_7838(C_word c,C_word *av) C_noret;
C_noret_decl(f_7844)
static void C_ccall f_7844(C_word c,C_word *av) C_noret;
C_noret_decl(f_7847)
static void C_ccall f_7847(C_word c,C_word *av) C_noret;
C_noret_decl(f_7850)
static void C_ccall f_7850(C_word c,C_word *av) C_noret;
C_noret_decl(f_7853)
static void C_ccall f_7853(C_word c,C_word *av) C_noret;
C_noret_decl(f_7861)
static void C_fcall f_7861(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7868)
static void C_ccall f_7868(C_word c,C_word *av) C_noret;
C_noret_decl(f_7874)
static void C_ccall f_7874(C_word c,C_word *av) C_noret;
C_noret_decl(f_7904)
static void C_ccall f_7904(C_word c,C_word *av) C_noret;
C_noret_decl(f_7917)
static void C_ccall f_7917(C_word c,C_word *av) C_noret;
C_noret_decl(f_7921)
static void C_ccall f_7921(C_word c,C_word *av) C_noret;
C_noret_decl(f_7945)
static void C_ccall f_7945(C_word c,C_word *av) C_noret;
C_noret_decl(f_7948)
static void C_ccall f_7948(C_word c,C_word *av) C_noret;
C_noret_decl(f_7954)
static void C_ccall f_7954(C_word c,C_word *av) C_noret;
C_noret_decl(f_7956)
static void C_fcall f_7956(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7980)
static void C_fcall f_7980(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8005)
static void C_ccall f_8005(C_word c,C_word *av) C_noret;
C_noret_decl(f_8019)
static void C_ccall f_8019(C_word c,C_word *av) C_noret;
C_noret_decl(f_8037)
static void C_ccall f_8037(C_word c,C_word *av) C_noret;
C_noret_decl(f_8044)
static void C_ccall f_8044(C_word c,C_word *av) C_noret;
C_noret_decl(f_8065)
static void C_fcall f_8065(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8085)
static void C_ccall f_8085(C_word c,C_word *av) C_noret;
C_noret_decl(f_8106)
static void C_ccall f_8106(C_word c,C_word *av) C_noret;
C_noret_decl(f_8110)
static void C_ccall f_8110(C_word c,C_word *av) C_noret;
C_noret_decl(f_8131)
static void C_ccall f_8131(C_word c,C_word *av) C_noret;
C_noret_decl(f_8135)
static void C_ccall f_8135(C_word c,C_word *av) C_noret;
C_noret_decl(f_8144)
static void C_fcall f_8144(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8151)
static void C_fcall f_8151(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8157)
static void C_ccall f_8157(C_word c,C_word *av) C_noret;
C_noret_decl(f_8201)
static void C_ccall f_8201(C_word c,C_word *av) C_noret;
C_noret_decl(f_8210)
static void C_ccall f_8210(C_word c,C_word *av) C_noret;
C_noret_decl(f_8219)
static void C_ccall f_8219(C_word c,C_word *av) C_noret;
C_noret_decl(f_8225)
static void C_ccall f_8225(C_word c,C_word *av) C_noret;
C_noret_decl(f_8252)
static void C_ccall f_8252(C_word c,C_word *av) C_noret;
C_noret_decl(f_8255)
static void C_ccall f_8255(C_word c,C_word *av) C_noret;
C_noret_decl(f_8262)
static void C_ccall f_8262(C_word c,C_word *av) C_noret;
C_noret_decl(f_8296)
static void C_ccall f_8296(C_word c,C_word *av) C_noret;
C_noret_decl(f_8298)
static void C_fcall f_8298(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8312)
static void C_fcall f_8312(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8333)
static void C_ccall f_8333(C_word c,C_word *av) C_noret;
C_noret_decl(f_8337)
static void C_ccall f_8337(C_word c,C_word *av) C_noret;
C_noret_decl(f_8349)
static void C_ccall f_8349(C_word c,C_word *av) C_noret;
C_noret_decl(f_8362)
static void C_ccall f_8362(C_word c,C_word *av) C_noret;
C_noret_decl(f_8366)
static void C_ccall f_8366(C_word c,C_word *av) C_noret;
C_noret_decl(f_8372)
static void C_fcall f_8372(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8379)
static void C_ccall f_8379(C_word c,C_word *av) C_noret;
C_noret_decl(f_8382)
static void C_ccall f_8382(C_word c,C_word *av) C_noret;
C_noret_decl(f_8384)
static void C_fcall f_8384(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8386)
static void C_fcall f_8386(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8394)
static void C_ccall f_8394(C_word c,C_word *av) C_noret;
C_noret_decl(f_8397)
static void C_ccall f_8397(C_word c,C_word *av) C_noret;
C_noret_decl(f_8400)
static void C_ccall f_8400(C_word c,C_word *av) C_noret;
C_noret_decl(f_8403)
static void C_ccall f_8403(C_word c,C_word *av) C_noret;
C_noret_decl(f_8406)
static void C_ccall f_8406(C_word c,C_word *av) C_noret;
C_noret_decl(f_8409)
static void C_ccall f_8409(C_word c,C_word *av) C_noret;
C_noret_decl(f_8412)
static void C_fcall f_8412(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8418)
static void C_ccall f_8418(C_word c,C_word *av) C_noret;
C_noret_decl(f_8421)
static void C_ccall f_8421(C_word c,C_word *av) C_noret;
C_noret_decl(f_8424)
static void C_ccall f_8424(C_word c,C_word *av) C_noret;
C_noret_decl(f_8427)
static void C_ccall f_8427(C_word c,C_word *av) C_noret;
C_noret_decl(f_8430)
static void C_ccall f_8430(C_word c,C_word *av) C_noret;
C_noret_decl(f_8433)
static void C_ccall f_8433(C_word c,C_word *av) C_noret;
C_noret_decl(f_8436)
static void C_ccall f_8436(C_word c,C_word *av) C_noret;
C_noret_decl(f_8439)
static void C_ccall f_8439(C_word c,C_word *av) C_noret;
C_noret_decl(f_8442)
static void C_ccall f_8442(C_word c,C_word *av) C_noret;
C_noret_decl(f_8445)
static void C_ccall f_8445(C_word c,C_word *av) C_noret;
C_noret_decl(f_8448)
static void C_ccall f_8448(C_word c,C_word *av) C_noret;
C_noret_decl(f_8451)
static void C_ccall f_8451(C_word c,C_word *av) C_noret;
C_noret_decl(f_8454)
static void C_ccall f_8454(C_word c,C_word *av) C_noret;
C_noret_decl(f_8457)
static void C_ccall f_8457(C_word c,C_word *av) C_noret;
C_noret_decl(f_8460)
static void C_ccall f_8460(C_word c,C_word *av) C_noret;
C_noret_decl(f_8463)
static void C_ccall f_8463(C_word c,C_word *av) C_noret;
C_noret_decl(f_8466)
static void C_ccall f_8466(C_word c,C_word *av) C_noret;
C_noret_decl(f_8469)
static void C_ccall f_8469(C_word c,C_word *av) C_noret;
C_noret_decl(f_8472)
static void C_ccall f_8472(C_word c,C_word *av) C_noret;
C_noret_decl(f_8475)
static void C_ccall f_8475(C_word c,C_word *av) C_noret;
C_noret_decl(f_8478)
static void C_fcall f_8478(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8481)
static void C_ccall f_8481(C_word c,C_word *av) C_noret;
C_noret_decl(f_8484)
static void C_ccall f_8484(C_word c,C_word *av) C_noret;
C_noret_decl(f_8487)
static void C_ccall f_8487(C_word c,C_word *av) C_noret;
C_noret_decl(f_8490)
static void C_ccall f_8490(C_word c,C_word *av) C_noret;
C_noret_decl(f_8493)
static void C_ccall f_8493(C_word c,C_word *av) C_noret;
C_noret_decl(f_8497)
static void C_ccall f_8497(C_word c,C_word *av) C_noret;
C_noret_decl(f_8504)
static void C_ccall f_8504(C_word c,C_word *av) C_noret;
C_noret_decl(f_8515)
static void C_ccall f_8515(C_word c,C_word *av) C_noret;
C_noret_decl(f_8521)
static void C_ccall f_8521(C_word c,C_word *av) C_noret;
C_noret_decl(f_8524)
static void C_ccall f_8524(C_word c,C_word *av) C_noret;
C_noret_decl(f_8533)
static void C_fcall f_8533(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8541)
static void C_ccall f_8541(C_word c,C_word *av) C_noret;
C_noret_decl(f_8555)
static void C_ccall f_8555(C_word c,C_word *av) C_noret;
C_noret_decl(f_8570)
static void C_ccall f_8570(C_word c,C_word *av) C_noret;
C_noret_decl(f_8573)
static void C_ccall f_8573(C_word c,C_word *av) C_noret;
C_noret_decl(f_8590)
static void C_fcall f_8590(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8600)
static void C_ccall f_8600(C_word c,C_word *av) C_noret;
C_noret_decl(f_8630)
static void C_ccall f_8630(C_word c,C_word *av) C_noret;
C_noret_decl(f_8634)
static void C_ccall f_8634(C_word c,C_word *av) C_noret;
C_noret_decl(f_8637)
static void C_ccall f_8637(C_word c,C_word *av) C_noret;
C_noret_decl(f_8640)
static void C_ccall f_8640(C_word c,C_word *av) C_noret;
C_noret_decl(f_8643)
static void C_ccall f_8643(C_word c,C_word *av) C_noret;
C_noret_decl(f_8646)
static void C_ccall f_8646(C_word c,C_word *av) C_noret;
C_noret_decl(f_8649)
static void C_ccall f_8649(C_word c,C_word *av) C_noret;
C_noret_decl(f_8658)
static void C_ccall f_8658(C_word c,C_word *av) C_noret;
C_noret_decl(f_8661)
static void C_ccall f_8661(C_word c,C_word *av) C_noret;
C_noret_decl(f_8672)
static void C_ccall f_8672(C_word c,C_word *av) C_noret;
C_noret_decl(f_8693)
static void C_fcall f_8693(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8709)
static void C_fcall f_8709(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8717)
static void C_ccall f_8717(C_word c,C_word *av) C_noret;
C_noret_decl(f_8720)
static void C_ccall f_8720(C_word c,C_word *av) C_noret;
C_noret_decl(f_8730)
static void C_ccall f_8730(C_word c,C_word *av) C_noret;
C_noret_decl(f_8733)
static void C_ccall f_8733(C_word c,C_word *av) C_noret;
C_noret_decl(f_8736)
static void C_ccall f_8736(C_word c,C_word *av) C_noret;
C_noret_decl(f_8745)
static void C_fcall f_8745(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8769)
static void C_ccall f_8769(C_word c,C_word *av) C_noret;
C_noret_decl(f_8772)
static void C_ccall f_8772(C_word c,C_word *av) C_noret;
C_noret_decl(f_8775)
static void C_ccall f_8775(C_word c,C_word *av) C_noret;
C_noret_decl(f_8778)
static void C_ccall f_8778(C_word c,C_word *av) C_noret;
C_noret_decl(f_8787)
static void C_ccall f_8787(C_word c,C_word *av) C_noret;
C_noret_decl(f_8803)
static void C_fcall f_8803(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8863)
static void C_ccall f_8863(C_word c,C_word *av) C_noret;
C_noret_decl(f_8876)
static void C_fcall f_8876(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8886)
static void C_ccall f_8886(C_word c,C_word *av) C_noret;
C_noret_decl(f_8901)
static void C_fcall f_8901(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8903)
static void C_fcall f_8903(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8911)
static void C_ccall f_8911(C_word c,C_word *av) C_noret;
C_noret_decl(f_8931)
static void C_fcall f_8931(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8941)
static void C_ccall f_8941(C_word c,C_word *av) C_noret;
C_noret_decl(f_8965)
static void C_ccall f_8965(C_word c,C_word *av) C_noret;
C_noret_decl(f_8988)
static void C_ccall f_8988(C_word c,C_word *av) C_noret;
C_noret_decl(f_8991)
static void C_ccall f_8991(C_word c,C_word *av) C_noret;
C_noret_decl(f_8994)
static void C_ccall f_8994(C_word c,C_word *av) C_noret;
C_noret_decl(f_9010)
static void C_ccall f_9010(C_word c,C_word *av) C_noret;
C_noret_decl(f_9013)
static void C_ccall f_9013(C_word c,C_word *av) C_noret;
C_noret_decl(f_9027)
static void C_ccall f_9027(C_word c,C_word *av) C_noret;
C_noret_decl(f_9052)
static void C_ccall f_9052(C_word c,C_word *av) C_noret;
C_noret_decl(f_9056)
static void C_ccall f_9056(C_word c,C_word *av) C_noret;
C_noret_decl(f_9064)
static void C_fcall f_9064(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9074)
static void C_ccall f_9074(C_word c,C_word *av) C_noret;
C_noret_decl(f_9088)
static void C_ccall f_9088(C_word c,C_word *av) C_noret;
C_noret_decl(f_9092)
static void C_ccall f_9092(C_word c,C_word *av) C_noret;
C_noret_decl(f_9095)
static void C_ccall f_9095(C_word c,C_word *av) C_noret;
C_noret_decl(f_9098)
static void C_ccall f_9098(C_word c,C_word *av) C_noret;
C_noret_decl(f_9101)
static void C_ccall f_9101(C_word c,C_word *av) C_noret;
C_noret_decl(f_9104)
static void C_ccall f_9104(C_word c,C_word *av) C_noret;
C_noret_decl(f_9107)
static void C_ccall f_9107(C_word c,C_word *av) C_noret;
C_noret_decl(f_9110)
static void C_ccall f_9110(C_word c,C_word *av) C_noret;
C_noret_decl(f_9113)
static void C_ccall f_9113(C_word c,C_word *av) C_noret;
C_noret_decl(f_9116)
static void C_ccall f_9116(C_word c,C_word *av) C_noret;
C_noret_decl(f_9119)
static void C_ccall f_9119(C_word c,C_word *av) C_noret;
C_noret_decl(f_9134)
static void C_ccall f_9134(C_word c,C_word *av) C_noret;
C_noret_decl(f_9139)
static void C_ccall f_9139(C_word c,C_word *av) C_noret;
C_noret_decl(f_9157)
static void C_ccall f_9157(C_word c,C_word *av) C_noret;
C_noret_decl(f_9161)
static void C_ccall f_9161(C_word c,C_word *av) C_noret;
C_noret_decl(f_9170)
static void C_ccall f_9170(C_word c,C_word *av) C_noret;
C_noret_decl(f_9175)
static void C_fcall f_9175(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9185)
static void C_ccall f_9185(C_word c,C_word *av) C_noret;
C_noret_decl(f_9203)
static void C_ccall f_9203(C_word c,C_word *av) C_noret;
C_noret_decl(f_9209)
static void C_ccall f_9209(C_word c,C_word *av) C_noret;
C_noret_decl(f_9214)
static void C_fcall f_9214(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9224)
static void C_ccall f_9224(C_word c,C_word *av) C_noret;
C_noret_decl(f_9237)
static void C_ccall f_9237(C_word c,C_word *av) C_noret;
C_noret_decl(f_9255)
static void C_ccall f_9255(C_word c,C_word *av) C_noret;
C_noret_decl(f_9256)
static void C_fcall f_9256(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9264)
static void C_ccall f_9264(C_word c,C_word *av) C_noret;
C_noret_decl(f_9277)
static void C_ccall f_9277(C_word c,C_word *av) C_noret;
C_noret_decl(f_9284)
static void C_ccall f_9284(C_word c,C_word *av) C_noret;
C_noret_decl(f_9287)
static void C_ccall f_9287(C_word c,C_word *av) C_noret;
C_noret_decl(f_9290)
static void C_ccall f_9290(C_word c,C_word *av) C_noret;
C_noret_decl(f_9293)
static void C_ccall f_9293(C_word c,C_word *av) C_noret;
C_noret_decl(f_9296)
static void C_ccall f_9296(C_word c,C_word *av) C_noret;
C_noret_decl(f_9301)
static void C_fcall f_9301(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9311)
static void C_ccall f_9311(C_word c,C_word *av) C_noret;
C_noret_decl(f_9329)
static void C_ccall f_9329(C_word c,C_word *av) C_noret;
C_noret_decl(f_9343)
static void C_ccall f_9343(C_word c,C_word *av) C_noret;
C_noret_decl(f_9345)
static void C_fcall f_9345(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9354)
static void C_fcall f_9354(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9380)
static void C_fcall f_9380(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9390)
static void C_ccall f_9390(C_word c,C_word *av) C_noret;
C_noret_decl(f_9421)
static void C_fcall f_9421(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9427)
static void C_ccall f_9427(C_word c,C_word *av) C_noret;
C_noret_decl(f_9435)
static void C_ccall f_9435(C_word c,C_word *av) C_noret;
C_noret_decl(f_9438)
static void C_fcall f_9438(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9444)
static void C_ccall f_9444(C_word c,C_word *av) C_noret;
C_noret_decl(f_9452)
static void C_ccall f_9452(C_word c,C_word *av) C_noret;
C_noret_decl(f_9459)
static void C_ccall f_9459(C_word c,C_word *av) C_noret;
C_noret_decl(f_9481)
static void C_ccall f_9481(C_word c,C_word *av) C_noret;
C_noret_decl(f_9489)
static void C_fcall f_9489(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9499)
static void C_ccall f_9499(C_word c,C_word *av) C_noret;
C_noret_decl(f_9512)
static void C_fcall f_9512(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9518)
static void C_ccall f_9518(C_word c,C_word *av) C_noret;
C_noret_decl(f_9521)
static void C_ccall f_9521(C_word c,C_word *av) C_noret;
C_noret_decl(f_9532)
static void C_fcall f_9532(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9542)
static void C_ccall f_9542(C_word c,C_word *av) C_noret;
C_noret_decl(f_9557)
static void C_fcall f_9557(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9561)
static void C_ccall f_9561(C_word c,C_word *av) C_noret;
C_noret_decl(f_9564)
static void C_ccall f_9564(C_word c,C_word *av) C_noret;
C_noret_decl(f_9567)
static void C_ccall f_9567(C_word c,C_word *av) C_noret;
C_noret_decl(f_9573)
static void C_ccall f_9573(C_word c,C_word *av) C_noret;
C_noret_decl(f_9576)
static void C_ccall f_9576(C_word c,C_word *av) C_noret;
C_noret_decl(f_9579)
static void C_ccall f_9579(C_word c,C_word *av) C_noret;
C_noret_decl(f_9582)
static void C_ccall f_9582(C_word c,C_word *av) C_noret;
C_noret_decl(f_9585)
static void C_ccall f_9585(C_word c,C_word *av) C_noret;
C_noret_decl(f_9588)
static void C_ccall f_9588(C_word c,C_word *av) C_noret;
C_noret_decl(f_9591)
static void C_ccall f_9591(C_word c,C_word *av) C_noret;
C_noret_decl(f_9594)
static void C_ccall f_9594(C_word c,C_word *av) C_noret;
C_noret_decl(f_9597)
static void C_ccall f_9597(C_word c,C_word *av) C_noret;
C_noret_decl(f_9600)
static void C_ccall f_9600(C_word c,C_word *av) C_noret;
C_noret_decl(f_9603)
static void C_ccall f_9603(C_word c,C_word *av) C_noret;
C_noret_decl(f_9606)
static void C_ccall f_9606(C_word c,C_word *av) C_noret;
C_noret_decl(f_9609)
static void C_ccall f_9609(C_word c,C_word *av) C_noret;
C_noret_decl(f_9618)
static void C_ccall f_9618(C_word c,C_word *av) C_noret;
C_noret_decl(f_9622)
static void C_ccall f_9622(C_word c,C_word *av) C_noret;
C_noret_decl(f_9626)
static void C_ccall f_9626(C_word c,C_word *av) C_noret;
C_noret_decl(f_9630)
static void C_ccall f_9630(C_word c,C_word *av) C_noret;
C_noret_decl(f_9636)
static void C_ccall f_9636(C_word c,C_word *av) C_noret;
C_noret_decl(f_9642)
static void C_ccall f_9642(C_word c,C_word *av) C_noret;
C_noret_decl(f_9645)
static void C_ccall f_9645(C_word c,C_word *av) C_noret;
C_noret_decl(f_9651)
static void C_ccall f_9651(C_word c,C_word *av) C_noret;
C_noret_decl(f_9660)
static void C_ccall f_9660(C_word c,C_word *av) C_noret;
C_noret_decl(f_9663)
static void C_ccall f_9663(C_word c,C_word *av) C_noret;
C_noret_decl(f_9666)
static void C_ccall f_9666(C_word c,C_word *av) C_noret;
C_noret_decl(f_9672)
static void C_ccall f_9672(C_word c,C_word *av) C_noret;
C_noret_decl(f_9675)
static void C_ccall f_9675(C_word c,C_word *av) C_noret;
C_noret_decl(f_9693)
static void C_ccall f_9693(C_word c,C_word *av) C_noret;
C_noret_decl(f_9696)
static void C_ccall f_9696(C_word c,C_word *av) C_noret;
C_noret_decl(f_9699)
static void C_ccall f_9699(C_word c,C_word *av) C_noret;
C_noret_decl(f_9702)
static void C_ccall f_9702(C_word c,C_word *av) C_noret;
C_noret_decl(f_9705)
static void C_ccall f_9705(C_word c,C_word *av) C_noret;
C_noret_decl(f_9730)
static void C_ccall f_9730(C_word c,C_word *av) C_noret;
C_noret_decl(f_9734)
static void C_ccall f_9734(C_word c,C_word *av) C_noret;
C_noret_decl(f_9752)
static void C_fcall f_9752(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_9759)
static void C_fcall f_9759(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9762)
static void C_ccall f_9762(C_word c,C_word *av) C_noret;
C_noret_decl(f_9804)
static void C_ccall f_9804(C_word c,C_word *av) C_noret;
C_noret_decl(f_9809)
static void C_fcall f_9809(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9819)
static void C_ccall f_9819(C_word c,C_word *av) C_noret;
C_noret_decl(f_9831)
static void C_ccall f_9831(C_word c,C_word *av) C_noret;
C_noret_decl(f_9834)
static void C_ccall f_9834(C_word c,C_word *av) C_noret;
C_noret_decl(f_9841)
static void C_ccall f_9841(C_word c,C_word *av) C_noret;
C_noret_decl(f_9849)
static void C_ccall f_9849(C_word c,C_word *av) C_noret;
C_noret_decl(f_9859)
static void C_ccall f_9859(C_word c,C_word *av) C_noret;
C_noret_decl(f_9870)
static void C_fcall f_9870(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9880)
static void C_ccall f_9880(C_word c,C_word *av) C_noret;
C_noret_decl(f_9895)
static void C_fcall f_9895(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9899)
static void C_ccall f_9899(C_word c,C_word *av) C_noret;
C_noret_decl(f_9902)
static void C_ccall f_9902(C_word c,C_word *av) C_noret;
C_noret_decl(f_9905)
static void C_ccall f_9905(C_word c,C_word *av) C_noret;
C_noret_decl(f_9908)
static void C_ccall f_9908(C_word c,C_word *av) C_noret;
C_noret_decl(f_9914)
static void C_ccall f_9914(C_word c,C_word *av) C_noret;
C_noret_decl(f_9916)
static void C_fcall f_9916(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_9926)
static void C_fcall f_9926(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9935)
static void C_fcall f_9935(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9947)
static void C_fcall f_9947(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9959)
static void C_fcall f_9959(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9971)
static void C_fcall f_9971(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9983)
static void C_fcall f_9983(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9989)
static void C_ccall f_9989(C_word c,C_word *av) C_noret;
C_noret_decl(f_9993)
static void C_fcall f_9993(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(C_c_2dbackend_toplevel)
C_externexport void C_ccall C_c_2dbackend_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(va15400)
static void C_fcall va15400(C_word t0,C_word t1) C_noret;
C_noret_decl(va15406)
static void C_fcall va15406(C_word t0,C_word t1) C_noret;
C_noret_decl(va15438)
static void C_fcall va15438(C_word t0,C_word t1) C_noret;
C_noret_decl(va15440)
static void C_fcall va15440(C_word t0,C_word t1) C_noret;
C_noret_decl(va15448)
static void C_fcall va15448(C_word t0,C_word t1) C_noret;
C_noret_decl(va15450)
static void C_fcall va15450(C_word t0,C_word t1) C_noret;

C_noret_decl(trf_10020)
static void C_ccall trf_10020(C_word c,C_word *av) C_noret;
static void C_ccall trf_10020(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10020(t0,t1);}

C_noret_decl(trf_10439)
static void C_ccall trf_10439(C_word c,C_word *av) C_noret;
static void C_ccall trf_10439(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10439(t0,t1,t2,t3);}

C_noret_decl(trf_10490)
static void C_ccall trf_10490(C_word c,C_word *av) C_noret;
static void C_ccall trf_10490(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_10490(t0,t1,t2,t3,t4);}

C_noret_decl(trf_10524)
static void C_ccall trf_10524(C_word c,C_word *av) C_noret;
static void C_ccall trf_10524(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10524(t0,t1,t2);}

C_noret_decl(trf_10547)
static void C_ccall trf_10547(C_word c,C_word *av) C_noret;
static void C_ccall trf_10547(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10547(t0,t1,t2);}

C_noret_decl(trf_10577)
static void C_ccall trf_10577(C_word c,C_word *av) C_noret;
static void C_ccall trf_10577(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10577(t0,t1,t2,t3);}

C_noret_decl(trf_10625)
static void C_ccall trf_10625(C_word c,C_word *av) C_noret;
static void C_ccall trf_10625(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10625(t0,t1);}

C_noret_decl(trf_10630)
static void C_ccall trf_10630(C_word c,C_word *av) C_noret;
static void C_ccall trf_10630(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10630(t0,t1,t2);}

C_noret_decl(trf_10700)
static void C_ccall trf_10700(C_word c,C_word *av) C_noret;
static void C_ccall trf_10700(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10700(t0,t1);}

C_noret_decl(trf_10817)
static void C_ccall trf_10817(C_word c,C_word *av) C_noret;
static void C_ccall trf_10817(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10817(t0,t1);}

C_noret_decl(trf_10838)
static void C_ccall trf_10838(C_word c,C_word *av) C_noret;
static void C_ccall trf_10838(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10838(t0,t1);}

C_noret_decl(trf_10970)
static void C_ccall trf_10970(C_word c,C_word *av) C_noret;
static void C_ccall trf_10970(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10970(t0,t1);}

C_noret_decl(trf_10982)
static void C_ccall trf_10982(C_word c,C_word *av) C_noret;
static void C_ccall trf_10982(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10982(t0,t1);}

C_noret_decl(trf_11001)
static void C_ccall trf_11001(C_word c,C_word *av) C_noret;
static void C_ccall trf_11001(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11001(t0,t1,t2);}

C_noret_decl(trf_11103)
static void C_ccall trf_11103(C_word c,C_word *av) C_noret;
static void C_ccall trf_11103(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11103(t0,t1,t2);}

C_noret_decl(trf_11293)
static void C_ccall trf_11293(C_word c,C_word *av) C_noret;
static void C_ccall trf_11293(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11293(t0,t1,t2);}

C_noret_decl(trf_11303)
static void C_ccall trf_11303(C_word c,C_word *av) C_noret;
static void C_ccall trf_11303(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11303(t0,t1);}

C_noret_decl(trf_11717)
static void C_ccall trf_11717(C_word c,C_word *av) C_noret;
static void C_ccall trf_11717(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11717(t0,t1);}

C_noret_decl(trf_11719)
static void C_ccall trf_11719(C_word c,C_word *av) C_noret;
static void C_ccall trf_11719(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11719(t0,t1);}

C_noret_decl(trf_11747)
static void C_ccall trf_11747(C_word c,C_word *av) C_noret;
static void C_ccall trf_11747(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11747(t0,t1);}

C_noret_decl(trf_11774)
static void C_ccall trf_11774(C_word c,C_word *av) C_noret;
static void C_ccall trf_11774(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11774(t0,t1);}

C_noret_decl(trf_11999)
static void C_ccall trf_11999(C_word c,C_word *av) C_noret;
static void C_ccall trf_11999(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11999(t0,t1);}

C_noret_decl(trf_12008)
static void C_ccall trf_12008(C_word c,C_word *av) C_noret;
static void C_ccall trf_12008(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12008(t0,t1);}

C_noret_decl(trf_12382)
static void C_ccall trf_12382(C_word c,C_word *av) C_noret;
static void C_ccall trf_12382(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12382(t0,t1,t2);}

C_noret_decl(trf_12384)
static void C_ccall trf_12384(C_word c,C_word *av) C_noret;
static void C_ccall trf_12384(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12384(t0,t1);}

C_noret_decl(trf_12499)
static void C_ccall trf_12499(C_word c,C_word *av) C_noret;
static void C_ccall trf_12499(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12499(t0,t1);}

C_noret_decl(trf_12719)
static void C_ccall trf_12719(C_word c,C_word *av) C_noret;
static void C_ccall trf_12719(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12719(t0,t1,t2);}

C_noret_decl(trf_13169)
static void C_ccall trf_13169(C_word c,C_word *av) C_noret;
static void C_ccall trf_13169(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13169(t0,t1);}

C_noret_decl(trf_13178)
static void C_ccall trf_13178(C_word c,C_word *av) C_noret;
static void C_ccall trf_13178(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13178(t0,t1);}

C_noret_decl(trf_13294)
static void C_ccall trf_13294(C_word c,C_word *av) C_noret;
static void C_ccall trf_13294(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13294(t0,t1);}

C_noret_decl(trf_3709)
static void C_ccall trf_3709(C_word c,C_word *av) C_noret;
static void C_ccall trf_3709(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_3709(t0,t1,t2,t3);}

C_noret_decl(trf_4281)
static void C_ccall trf_4281(C_word c,C_word *av) C_noret;
static void C_ccall trf_4281(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4281(t0,t1,t2);}

C_noret_decl(trf_4287)
static void C_ccall trf_4287(C_word c,C_word *av) C_noret;
static void C_ccall trf_4287(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4287(t0,t1,t2);}

C_noret_decl(trf_4569)
static void C_ccall trf_4569(C_word c,C_word *av) C_noret;
static void C_ccall trf_4569(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4569(t0,t1,t2);}

C_noret_decl(trf_4592)
static void C_ccall trf_4592(C_word c,C_word *av) C_noret;
static void C_ccall trf_4592(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_4592(t0,t1);}

C_noret_decl(trf_4606)
static void C_ccall trf_4606(C_word c,C_word *av) C_noret;
static void C_ccall trf_4606(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4606(t0,t1,t2);}

C_noret_decl(trf_4710)
static void C_ccall trf_4710(C_word c,C_word *av) C_noret;
static void C_ccall trf_4710(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4710(t0,t1,t2);}

C_noret_decl(trf_4722)
static void C_ccall trf_4722(C_word c,C_word *av) C_noret;
static void C_ccall trf_4722(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_4722(t0,t1,t2,t3,t4);}

C_noret_decl(trf_4725)
static void C_ccall trf_4725(C_word c,C_word *av) C_noret;
static void C_ccall trf_4725(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_4725(t0,t1,t2,t3);}

C_noret_decl(trf_4964)
static void C_ccall trf_4964(C_word c,C_word *av) C_noret;
static void C_ccall trf_4964(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_4964(t0,t1,t2,t3,t4);}

C_noret_decl(trf_5122)
static void C_ccall trf_5122(C_word c,C_word *av) C_noret;
static void C_ccall trf_5122(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5122(t0,t1);}

C_noret_decl(trf_5162)
static void C_ccall trf_5162(C_word c,C_word *av) C_noret;
static void C_ccall trf_5162(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5162(t0,t1);}

C_noret_decl(trf_5202)
static void C_ccall trf_5202(C_word c,C_word *av) C_noret;
static void C_ccall trf_5202(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5202(t0,t1);}

C_noret_decl(trf_5387)
static void C_ccall trf_5387(C_word c,C_word *av) C_noret;
static void C_ccall trf_5387(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_5387(t0,t1,t2,t3);}

C_noret_decl(trf_5416)
static void C_ccall trf_5416(C_word c,C_word *av) C_noret;
static void C_ccall trf_5416(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_5416(t0,t1,t2,t3);}

C_noret_decl(trf_5696)
static void C_ccall trf_5696(C_word c,C_word *av) C_noret;
static void C_ccall trf_5696(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5696(t0,t1);}

C_noret_decl(trf_5702)
static void C_ccall trf_5702(C_word c,C_word *av) C_noret;
static void C_ccall trf_5702(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5702(t0,t1);}

C_noret_decl(trf_5744)
static void C_ccall trf_5744(C_word c,C_word *av) C_noret;
static void C_ccall trf_5744(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_5744(t0,t1,t2,t3);}

C_noret_decl(trf_5785)
static void C_ccall trf_5785(C_word c,C_word *av) C_noret;
static void C_ccall trf_5785(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_5785(t0,t1,t2,t3);}

C_noret_decl(trf_5822)
static void C_ccall trf_5822(C_word c,C_word *av) C_noret;
static void C_ccall trf_5822(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_5822(t0,t1,t2,t3);}

C_noret_decl(trf_5943)
static void C_ccall trf_5943(C_word c,C_word *av) C_noret;
static void C_ccall trf_5943(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5943(t0,t1);}

C_noret_decl(trf_6077)
static void C_ccall trf_6077(C_word c,C_word *av) C_noret;
static void C_ccall trf_6077(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6077(t0,t1);}

C_noret_decl(trf_6213)
static void C_ccall trf_6213(C_word c,C_word *av) C_noret;
static void C_ccall trf_6213(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6213(t0,t1,t2,t3);}

C_noret_decl(trf_6248)
static void C_ccall trf_6248(C_word c,C_word *av) C_noret;
static void C_ccall trf_6248(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6248(t0,t1,t2,t3);}

C_noret_decl(trf_6285)
static void C_ccall trf_6285(C_word c,C_word *av) C_noret;
static void C_ccall trf_6285(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6285(t0,t1,t2,t3);}

C_noret_decl(trf_6754)
static void C_ccall trf_6754(C_word c,C_word *av) C_noret;
static void C_ccall trf_6754(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6754(t0,t1,t2,t3);}

C_noret_decl(trf_6937)
static void C_ccall trf_6937(C_word c,C_word *av) C_noret;
static void C_ccall trf_6937(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6937(t0,t1,t2,t3);}

C_noret_decl(trf_6943)
static void C_ccall trf_6943(C_word c,C_word *av) C_noret;
static void C_ccall trf_6943(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6943(t0,t1,t2);}

C_noret_decl(trf_6973)
static void C_ccall trf_6973(C_word c,C_word *av) C_noret;
static void C_ccall trf_6973(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6973(t0,t1,t2);}

C_noret_decl(trf_6979)
static void C_ccall trf_6979(C_word c,C_word *av) C_noret;
static void C_ccall trf_6979(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6979(t0,t1,t2);}

C_noret_decl(trf_7016)
static void C_ccall trf_7016(C_word c,C_word *av) C_noret;
static void C_ccall trf_7016(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_7016(t0,t1,t2,t3,t4);}

C_noret_decl(trf_7028)
static void C_ccall trf_7028(C_word c,C_word *av) C_noret;
static void C_ccall trf_7028(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7028(t0,t1);}

C_noret_decl(trf_7049)
static void C_ccall trf_7049(C_word c,C_word *av) C_noret;
static void C_ccall trf_7049(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7049(t0,t1,t2,t3);}

C_noret_decl(trf_7145)
static void C_ccall trf_7145(C_word c,C_word *av) C_noret;
static void C_ccall trf_7145(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7145(t0,t1);}

C_noret_decl(trf_7192)
static void C_ccall trf_7192(C_word c,C_word *av) C_noret;
static void C_ccall trf_7192(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7192(t0,t1,t2);}

C_noret_decl(trf_7252)
static void C_ccall trf_7252(C_word c,C_word *av) C_noret;
static void C_ccall trf_7252(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7252(t0,t1,t2);}

C_noret_decl(trf_7304)
static void C_ccall trf_7304(C_word c,C_word *av) C_noret;
static void C_ccall trf_7304(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7304(t0,t1);}

C_noret_decl(trf_7342)
static void C_ccall trf_7342(C_word c,C_word *av) C_noret;
static void C_ccall trf_7342(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7342(t0,t1,t2,t3);}

C_noret_decl(trf_7382)
static void C_ccall trf_7382(C_word c,C_word *av) C_noret;
static void C_ccall trf_7382(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7382(t0,t1,t2);}

C_noret_decl(trf_7400)
static void C_ccall trf_7400(C_word c,C_word *av) C_noret;
static void C_ccall trf_7400(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7400(t0,t1,t2);}

C_noret_decl(trf_7451)
static void C_ccall trf_7451(C_word c,C_word *av) C_noret;
static void C_ccall trf_7451(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7451(t0,t1,t2);}

C_noret_decl(trf_7474)
static void C_ccall trf_7474(C_word c,C_word *av) C_noret;
static void C_ccall trf_7474(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7474(t0,t1,t2);}

C_noret_decl(trf_7508)
static void C_ccall trf_7508(C_word c,C_word *av) C_noret;
static void C_ccall trf_7508(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7508(t0,t1);}

C_noret_decl(trf_7527)
static void C_ccall trf_7527(C_word c,C_word *av) C_noret;
static void C_ccall trf_7527(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7527(t0,t1);}

C_noret_decl(trf_7663)
static void C_ccall trf_7663(C_word c,C_word *av) C_noret;
static void C_ccall trf_7663(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7663(t0,t1,t2);}

C_noret_decl(trf_7686)
static void C_ccall trf_7686(C_word c,C_word *av) C_noret;
static void C_ccall trf_7686(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7686(t0,t1);}

C_noret_decl(trf_7697)
static void C_ccall trf_7697(C_word c,C_word *av) C_noret;
static void C_ccall trf_7697(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7697(t0,t1,t2,t3);}

C_noret_decl(trf_7729)
static void C_ccall trf_7729(C_word c,C_word *av) C_noret;
static void C_ccall trf_7729(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7729(t0,t1);}

C_noret_decl(trf_7732)
static void C_ccall trf_7732(C_word c,C_word *av) C_noret;
static void C_ccall trf_7732(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7732(t0,t1);}

C_noret_decl(trf_7784)
static void C_ccall trf_7784(C_word c,C_word *av) C_noret;
static void C_ccall trf_7784(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7784(t0,t1,t2);}

C_noret_decl(trf_7807)
static void C_ccall trf_7807(C_word c,C_word *av) C_noret;
static void C_ccall trf_7807(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7807(t0,t1);}

C_noret_decl(trf_7813)
static void C_ccall trf_7813(C_word c,C_word *av) C_noret;
static void C_ccall trf_7813(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7813(t0,t1,t2,t3);}

C_noret_decl(trf_7861)
static void C_ccall trf_7861(C_word c,C_word *av) C_noret;
static void C_ccall trf_7861(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7861(t0,t1,t2);}

C_noret_decl(trf_7956)
static void C_ccall trf_7956(C_word c,C_word *av) C_noret;
static void C_ccall trf_7956(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7956(t0,t1,t2,t3);}

C_noret_decl(trf_7980)
static void C_ccall trf_7980(C_word c,C_word *av) C_noret;
static void C_ccall trf_7980(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7980(t0,t1,t2);}

C_noret_decl(trf_8065)
static void C_ccall trf_8065(C_word c,C_word *av) C_noret;
static void C_ccall trf_8065(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8065(t0,t1,t2,t3);}

C_noret_decl(trf_8144)
static void C_ccall trf_8144(C_word c,C_word *av) C_noret;
static void C_ccall trf_8144(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8144(t0,t1,t2,t3);}

C_noret_decl(trf_8151)
static void C_ccall trf_8151(C_word c,C_word *av) C_noret;
static void C_ccall trf_8151(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8151(t0,t1);}

C_noret_decl(trf_8298)
static void C_ccall trf_8298(C_word c,C_word *av) C_noret;
static void C_ccall trf_8298(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8298(t0,t1,t2);}

C_noret_decl(trf_8312)
static void C_ccall trf_8312(C_word c,C_word *av) C_noret;
static void C_ccall trf_8312(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8312(t0,t1,t2,t3);}

C_noret_decl(trf_8372)
static void C_ccall trf_8372(C_word c,C_word *av) C_noret;
static void C_ccall trf_8372(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8372(t0,t1,t2,t3);}

C_noret_decl(trf_8384)
static void C_ccall trf_8384(C_word c,C_word *av) C_noret;
static void C_ccall trf_8384(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8384(t0,t1);}

C_noret_decl(trf_8386)
static void C_ccall trf_8386(C_word c,C_word *av) C_noret;
static void C_ccall trf_8386(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8386(t0,t1,t2);}

C_noret_decl(trf_8412)
static void C_ccall trf_8412(C_word c,C_word *av) C_noret;
static void C_ccall trf_8412(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8412(t0,t1);}

C_noret_decl(trf_8478)
static void C_ccall trf_8478(C_word c,C_word *av) C_noret;
static void C_ccall trf_8478(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8478(t0,t1);}

C_noret_decl(trf_8533)
static void C_ccall trf_8533(C_word c,C_word *av) C_noret;
static void C_ccall trf_8533(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8533(t0,t1,t2,t3);}

C_noret_decl(trf_8590)
static void C_ccall trf_8590(C_word c,C_word *av) C_noret;
static void C_ccall trf_8590(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8590(t0,t1,t2);}

C_noret_decl(trf_8693)
static void C_ccall trf_8693(C_word c,C_word *av) C_noret;
static void C_ccall trf_8693(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8693(t0,t1,t2,t3);}

C_noret_decl(trf_8709)
static void C_ccall trf_8709(C_word c,C_word *av) C_noret;
static void C_ccall trf_8709(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8709(t0,t1,t2,t3);}

C_noret_decl(trf_8745)
static void C_ccall trf_8745(C_word c,C_word *av) C_noret;
static void C_ccall trf_8745(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8745(t0,t1);}

C_noret_decl(trf_8803)
static void C_ccall trf_8803(C_word c,C_word *av) C_noret;
static void C_ccall trf_8803(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8803(t0,t1);}

C_noret_decl(trf_8876)
static void C_ccall trf_8876(C_word c,C_word *av) C_noret;
static void C_ccall trf_8876(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8876(t0,t1,t2);}

C_noret_decl(trf_8901)
static void C_ccall trf_8901(C_word c,C_word *av) C_noret;
static void C_ccall trf_8901(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8901(t0,t1);}

C_noret_decl(trf_8903)
static void C_ccall trf_8903(C_word c,C_word *av) C_noret;
static void C_ccall trf_8903(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8903(t0,t1,t2,t3);}

C_noret_decl(trf_8931)
static void C_ccall trf_8931(C_word c,C_word *av) C_noret;
static void C_ccall trf_8931(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8931(t0,t1,t2);}

C_noret_decl(trf_9064)
static void C_ccall trf_9064(C_word c,C_word *av) C_noret;
static void C_ccall trf_9064(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9064(t0,t1,t2);}

C_noret_decl(trf_9175)
static void C_ccall trf_9175(C_word c,C_word *av) C_noret;
static void C_ccall trf_9175(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9175(t0,t1,t2);}

C_noret_decl(trf_9214)
static void C_ccall trf_9214(C_word c,C_word *av) C_noret;
static void C_ccall trf_9214(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9214(t0,t1,t2);}

C_noret_decl(trf_9256)
static void C_ccall trf_9256(C_word c,C_word *av) C_noret;
static void C_ccall trf_9256(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9256(t0,t1,t2);}

C_noret_decl(trf_9301)
static void C_ccall trf_9301(C_word c,C_word *av) C_noret;
static void C_ccall trf_9301(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9301(t0,t1,t2);}

C_noret_decl(trf_9345)
static void C_ccall trf_9345(C_word c,C_word *av) C_noret;
static void C_ccall trf_9345(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9345(t0,t1);}

C_noret_decl(trf_9354)
static void C_ccall trf_9354(C_word c,C_word *av) C_noret;
static void C_ccall trf_9354(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9354(t0,t1,t2);}

C_noret_decl(trf_9380)
static void C_ccall trf_9380(C_word c,C_word *av) C_noret;
static void C_ccall trf_9380(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9380(t0,t1);}

C_noret_decl(trf_9421)
static void C_ccall trf_9421(C_word c,C_word *av) C_noret;
static void C_ccall trf_9421(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9421(t0,t1,t2);}

C_noret_decl(trf_9438)
static void C_ccall trf_9438(C_word c,C_word *av) C_noret;
static void C_ccall trf_9438(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9438(t0,t1,t2);}

C_noret_decl(trf_9489)
static void C_ccall trf_9489(C_word c,C_word *av) C_noret;
static void C_ccall trf_9489(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9489(t0,t1,t2);}

C_noret_decl(trf_9512)
static void C_ccall trf_9512(C_word c,C_word *av) C_noret;
static void C_ccall trf_9512(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9512(t0,t1);}

C_noret_decl(trf_9532)
static void C_ccall trf_9532(C_word c,C_word *av) C_noret;
static void C_ccall trf_9532(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9532(t0,t1,t2);}

C_noret_decl(trf_9557)
static void C_ccall trf_9557(C_word c,C_word *av) C_noret;
static void C_ccall trf_9557(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9557(t0,t1,t2);}

C_noret_decl(trf_9752)
static void C_ccall trf_9752(C_word c,C_word *av) C_noret;
static void C_ccall trf_9752(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_9752(t0,t1,t2,t3,t4);}

C_noret_decl(trf_9759)
static void C_ccall trf_9759(C_word c,C_word *av) C_noret;
static void C_ccall trf_9759(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9759(t0,t1);}

C_noret_decl(trf_9809)
static void C_ccall trf_9809(C_word c,C_word *av) C_noret;
static void C_ccall trf_9809(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9809(t0,t1,t2);}

C_noret_decl(trf_9870)
static void C_ccall trf_9870(C_word c,C_word *av) C_noret;
static void C_ccall trf_9870(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9870(t0,t1,t2);}

C_noret_decl(trf_9895)
static void C_ccall trf_9895(C_word c,C_word *av) C_noret;
static void C_ccall trf_9895(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9895(t0,t1,t2);}

C_noret_decl(trf_9916)
static void C_ccall trf_9916(C_word c,C_word *av) C_noret;
static void C_ccall trf_9916(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_9916(t0,t1,t2,t3,t4);}

C_noret_decl(trf_9926)
static void C_ccall trf_9926(C_word c,C_word *av) C_noret;
static void C_ccall trf_9926(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9926(t0,t1);}

C_noret_decl(trf_9935)
static void C_ccall trf_9935(C_word c,C_word *av) C_noret;
static void C_ccall trf_9935(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9935(t0,t1);}

C_noret_decl(trf_9947)
static void C_ccall trf_9947(C_word c,C_word *av) C_noret;
static void C_ccall trf_9947(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9947(t0,t1);}

C_noret_decl(trf_9959)
static void C_ccall trf_9959(C_word c,C_word *av) C_noret;
static void C_ccall trf_9959(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9959(t0,t1);}

C_noret_decl(trf_9971)
static void C_ccall trf_9971(C_word c,C_word *av) C_noret;
static void C_ccall trf_9971(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9971(t0,t1);}

C_noret_decl(trf_9983)
static void C_ccall trf_9983(C_word c,C_word *av) C_noret;
static void C_ccall trf_9983(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9983(t0,t1);}

C_noret_decl(trf_9993)
static void C_ccall trf_9993(C_word c,C_word *av) C_noret;
static void C_ccall trf_9993(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9993(t0,t1,t2);}

C_noret_decl(trva15400)
static void C_ccall trva15400(C_word c,C_word *av) C_noret;
static void C_ccall trva15400(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
va15400(t0,t1);}

C_noret_decl(trva15406)
static void C_ccall trva15406(C_word c,C_word *av) C_noret;
static void C_ccall trva15406(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
va15406(t0,t1);}

C_noret_decl(trva15438)
static void C_ccall trva15438(C_word c,C_word *av) C_noret;
static void C_ccall trva15438(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
va15438(t0,t1);}

C_noret_decl(trva15440)
static void C_ccall trva15440(C_word c,C_word *av) C_noret;
static void C_ccall trva15440(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
va15440(t0,t1);}

C_noret_decl(trva15448)
static void C_ccall trva15448(C_word c,C_word *av) C_noret;
static void C_ccall trva15448(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
va15448(t0,t1);}

C_noret_decl(trva15450)
static void C_ccall trva15450(C_word c,C_word *av) C_noret;
static void C_ccall trva15450(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
va15450(t0,t1);}

/* f14759 in k5588 in k5567 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14759,c,av);}
/* c-backend.scm:75: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[119];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14764 in k5633 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14764(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14764,c,av);}
/* c-backend.scm:75: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[119];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14769 in k5654 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14769,c,av);}
/* c-backend.scm:75: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[119];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14777 in k5870 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f14777(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f14777,c,av);}
/* c-backend.scm:359: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[142];
f_4549(3,av2);}}

/* f14782 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14782,c,av);}
/* c-backend.scm:74: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[196];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14787 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14787,c,av);}
/* c-backend.scm:75: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[119];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14800 in k6327 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f14800,c,av);}
/* c-backend.scm:433: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* f14804 in k6390 in k6387 in k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f14804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14804,c,av);}
/* c-backend.scm:465: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(41);
f_4549(4,av2);}}

/* f14811 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14811,c,av);}
/* c-backend.scm:74: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[196];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14816 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f14816(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14816,c,av);}
/* c-backend.scm:75: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[119];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14889 in k7300 in k9117 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f14889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14889,c,av);}
/* c-backend.scm:75: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[119];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14896 in k9159 in for-each-loop1782 in k9137 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f14896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f14896,c,av);}
/* c-backend.scm:74: chicken.string#string-translate* */
t2=C_fast_retrieve(lf[118]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[196];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f14917 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f14917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f14917,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10018 in k9987 in k9981 in k9969 in k9957 in k9945 in k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_fcall f_10020(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_10020,2,t0,t1);}
if(C_truep(t1)){
/* c-backend.scm:1199: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[549];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[550]);
if(C_truep(t2)){
/* c-backend.scm:1200: compute-size */
t3=((C_word*)((C_word*)t0)[5])[1];
f_9916(t3,((C_word*)t0)[2],C_i_cadr(((C_word*)t0)[6]),((C_word*)t0)[7],((C_word*)t0)[3]);}
else{
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_10376(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_10376,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10379,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:1209: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}

/* k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_10379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_10379,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10382,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[10])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10488,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1211: cleanup */
f_9345(t3,((C_word*)t0)[10]);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_10382(2,av2);}}}

/* k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_10382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_10382,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10385,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* c-backend.scm:1212: generate-foreign-callback-header */
f_10547(t2,lf[605],((C_word*)t0)[9]);}

/* k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_10385(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,7)))){
C_save_and_reclaim((void *)f_10385,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10388,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_string_equal_p(lf[599],((C_word*)t0)[8]))){
/* c-backend.scm:1213: gen */
t3=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(123);
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[600];
av2[5]=((C_word*)t0)[8];
av2[6]=lf[601];
av2[7]=lf[602];
f_4549(8,av2);}}
else{
/* c-backend.scm:1213: gen */
t3=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(123);
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[600];
av2[5]=((C_word*)t0)[8];
av2[6]=lf[601];
av2[7]=lf[603];
f_4549(8,av2);}}}

/* k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_ccall f_10388(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10388,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10391,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:1215: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[598];
f_4549(4,av2);}}

/* k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in ... */
static void C_ccall f_10391(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10391,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10403,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:1220: scheme#reverse */
t3=*((C_word*)lf[597]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10398 in for-each-loop2208 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in ... */
static void C_ccall f_10400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_10400,c,av);}
/* c-backend.scm:1218: gen */
t2=lf[4];{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[593];
av2[4]=t1;
av2[5]=((C_word*)t0)[3];
av2[6]=lf[594];
av2[7]=C_SCHEME_TRUE;
av2[8]=lf[595];
f_4549(9,av2);}}

/* k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in ... */
static void C_ccall f_10403(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10403,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10406,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:1221: scheme#reverse */
t3=*((C_word*)lf[597]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in ... */
static void C_ccall f_10406(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_10406,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10409,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10439,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_10439(t6,t2,((C_word*)t0)[6],t1);}

/* k10407 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_ccall f_10409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_10409,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10412,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_eqp(lf[582],((C_word*)t0)[3]);
if(C_truep(t3)){
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_10412(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10437,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1223: foreign-argument-conversion */
f_11717(t4,((C_word*)t0)[3]);}}

/* k10410 in k10407 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in ... */
static void C_ccall f_10412(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,6)))){
C_save_and_reclaim((void *)f_10412,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10415,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1224: gen */
t3=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[591];
av2[3]=((C_word*)t0)[4];
av2[4]=C_make_character(44);
av2[5]=((C_word*)t0)[5];
av2[6]=C_make_character(41);
f_4549(7,av2);}}

/* k10413 in k10410 in k10407 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in ... */
static void C_ccall f_10415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10415,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10418,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_eqp(lf[582],((C_word*)t0)[3]);
if(C_truep(t3)){
/* c-backend.scm:1226: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[590];
f_4549(3,av2);}}
else{
/* c-backend.scm:1225: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=C_make_character(41);
f_4549(3,av2);}}}

/* k10416 in k10413 in k10410 in k10407 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in ... */
static void C_ccall f_10418(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10418,c,av);}
/* c-backend.scm:1226: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[590];
f_4549(3,av2);}}

/* k10435 in k10407 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in ... */
static void C_ccall f_10437(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10437,c,av);}
/* c-backend.scm:1223: gen */
t2=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[592];
av2[4]=t1;
f_4549(5,av2);}}

/* for-each-loop2208 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_fcall f_10439(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_10439,4,t0,t1,t2,t3);}
a=C_alloc(10);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10449,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t7=C_slot(t2,C_fix(0));
t8=C_slot(t3,C_fix(0));
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10400,a[2]=t6,a[3]=t7,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1218: foreign-result-conversion */
f_12382(t9,t8,lf[596]);}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k10447 in for-each-loop2208 in k10404 in k10401 in k10389 in k10386 in k10383 in k10380 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in ... */
static void C_ccall f_10449(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10449,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_10439(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k10486 in k10377 in k10374 in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_10488(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_10488,c,av);}
/* c-backend.scm:1211: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[606];
av2[4]=t1;
av2[5]=lf[607];
f_4549(6,av2);}}

/* loop in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_fcall f_10490(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_10490,5,t0,t1,t2,t3,t4);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_cdr(t2);
t6=C_i_cdr(t3);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10512,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t5,a[5]=t6,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1208: compute-size */
t8=((C_word*)((C_word*)t0)[3])[1];
f_9916(t8,t7,C_u_i_car(t2),C_u_i_car(t3),t4);}}

/* k10510 in loop in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_10512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10512,c,av);}
/* c-backend.scm:1207: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10490(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* for-each-loop2031 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10524(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_10524,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10534,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1165: g2032 */
t4=((C_word*)t0)[3];
f_9895(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k10532 in for-each-loop2031 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10534(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10534,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_10524(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10547(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_10547,3,t1,t2,t3);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10551,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1230: chicken.compiler.support#foreign-callback-stub-name */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[678]);
C_word av2[3];
av2[0]=*((C_word*)lf[678]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}

/* k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_10551,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10554,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1231: chicken.compiler.support#foreign-callback-stub-qualifiers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[677]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[677]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10554(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10554,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10557,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:1232: chicken.compiler.support#foreign-callback-stub-return-type */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[611]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[611]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10557(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10557,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10560,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:1233: chicken.compiler.support#foreign-callback-stub-argument-types */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[610]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[610]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10560(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10560,c,av);}
a=C_alloc(8);
t2=C_i_length(t1);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10566,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:1235: make-argument-list */
f_9438(t3,t2,lf[676]);}

/* k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10566(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_10566,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10569,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10621,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1236: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=lf[675];
tp(4,av2);}}

/* k10567 in k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_10569,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10572,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10577,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_10577(t6,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k10570 in k10567 in k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10572,c,av);}
/* c-backend.scm:1242: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* loop in k10567 in k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10577(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_10577,4,t0,t1,t2,t3);}
a=C_alloc(9);
if(C_truep(C_i_nullp(t2))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10587,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10609,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1239: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t5;
av2[2]=C_i_car(t3);
av2[3]=C_i_car(t2);
tp(4,av2);}}}

/* k10585 in loop in k10567 in k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10587(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_10587,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10590,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[4])))){
/* c-backend.scm:1240: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(44);
f_4549(3,av2);}}
else{
/* c-backend.scm:1241: loop */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10577(t3,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}}

/* k10588 in k10585 in loop in k10567 in k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10590,c,av);}
/* c-backend.scm:1241: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10577(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}

/* k10607 in loop in k10567 in k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10609(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10609,c,av);}
/* c-backend.scm:1239: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
f_4549(3,av2);}}

/* k10619 in k10564 in k10558 in k10555 in k10552 in k10549 in chicken.compiler.c-backend#generate-foreign-callback-header in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10621(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_10621,c,av);}
/* c-backend.scm:1236: gen */
t2=lf[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[3];
av2[4]=C_make_character(32);
av2[5]=t1;
av2[6]=((C_word*)t0)[4];
av2[7]=C_make_character(32);
av2[8]=((C_word*)t0)[5];
av2[9]=C_make_character(40);
f_4549(10,av2);}}

/* chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10623(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_10623,c,av);}
a=C_alloc(13);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10625,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10630,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t6=C_eqp(t2,lf[584]);
if(C_truep(t6)){
/* c-backend.scm:1251: str */
t7=t5;
f_10630(t7,t1,lf[682]);}
else{
t7=C_eqp(t2,lf[17]);
t8=(C_truep(t7)?t7:C_eqp(t2,lf[588]));
if(C_truep(t8)){
/* c-backend.scm:1252: str */
t9=t5;
f_10630(t9,t1,lf[683]);}
else{
t9=C_eqp(t2,lf[585]);
t10=(C_truep(t9)?t9:C_eqp(t2,lf[589]));
if(C_truep(t10)){
/* c-backend.scm:1253: str */
t11=t5;
f_10630(t11,t1,lf[684]);}
else{
t11=C_eqp(t2,lf[586]);
t12=(C_truep(t11)?t11:C_eqp(t2,lf[537]));
if(C_truep(t12)){
/* c-backend.scm:1254: str */
t13=t5;
f_10630(t13,t1,lf[685]);}
else{
t13=C_eqp(t2,lf[587]);
t14=(C_truep(t13)?t13:C_eqp(t2,lf[570]));
if(C_truep(t14)){
/* c-backend.scm:1255: str */
t15=t5;
f_10630(t15,t1,lf[686]);}
else{
t15=C_eqp(t2,lf[579]);
t16=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10700,a[2]=t5,a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t15)){
t17=t16;
f_10700(t17,t15);}
else{
t17=C_eqp(t2,lf[572]);
t18=t16;
f_10700(t18,(C_truep(t17)?t17:C_eqp(t2,lf[14])));}}}}}}}

/* err in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10625(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_10625,2,t0,t1);}
/* c-backend.scm:1248: chicken.compiler.support#quit-compiling */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[679]);
C_word av2[4];
av2[0]=*((C_word*)lf[679]+1);
av2[1]=t1;
av2[2]=lf[680];
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}

/* str in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10630(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_10630,3,t0,t1,t2);}
/* c-backend.scm:1249: scheme#string-append */
t3=*((C_word*)lf[154]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[681];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10700(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_10700,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1256: str */
t2=((C_word*)t0)[2];
f_10630(t2,((C_word*)t0)[3],lf[687]);}
else{
t2=C_eqp(((C_word*)t0)[4],lf[568]);
if(C_truep(t2)){
/* c-backend.scm:1257: str */
t3=((C_word*)t0)[2];
f_10630(t3,((C_word*)t0)[3],lf[688]);}
else{
t3=C_eqp(((C_word*)t0)[4],lf[569]);
if(C_truep(t3)){
/* c-backend.scm:1258: str */
t4=((C_word*)t0)[2];
f_10630(t4,((C_word*)t0)[3],lf[689]);}
else{
t4=C_eqp(((C_word*)t0)[4],lf[580]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[4],lf[573]));
if(C_truep(t5)){
/* c-backend.scm:1259: str */
t6=((C_word*)t0)[2];
f_10630(t6,((C_word*)t0)[3],lf[690]);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[567]);
if(C_truep(t6)){
/* c-backend.scm:1260: str */
t7=((C_word*)t0)[2];
f_10630(t7,((C_word*)t0)[3],lf[691]);}
else{
t7=C_eqp(((C_word*)t0)[4],lf[539]);
if(C_truep(t7)){
/* c-backend.scm:1261: str */
t8=((C_word*)t0)[2];
f_10630(t8,((C_word*)t0)[3],lf[692]);}
else{
t8=C_eqp(((C_word*)t0)[4],lf[581]);
if(C_truep(t8)){
/* c-backend.scm:1262: str */
t9=((C_word*)t0)[2];
f_10630(t9,((C_word*)t0)[3],lf[693]);}
else{
t9=C_eqp(((C_word*)t0)[4],lf[571]);
if(C_truep(t9)){
/* c-backend.scm:1263: str */
t10=((C_word*)t0)[2];
f_10630(t10,((C_word*)t0)[3],lf[694]);}
else{
t10=C_eqp(((C_word*)t0)[4],lf[583]);
if(C_truep(t10)){
/* c-backend.scm:1264: str */
t11=((C_word*)t0)[2];
f_10630(t11,((C_word*)t0)[3],lf[695]);}
else{
t11=C_eqp(((C_word*)t0)[4],lf[574]);
if(C_truep(t11)){
/* c-backend.scm:1265: str */
t12=((C_word*)t0)[2];
f_10630(t12,((C_word*)t0)[3],lf[696]);}
else{
t12=C_eqp(((C_word*)t0)[4],lf[535]);
if(C_truep(t12)){
/* c-backend.scm:1266: str */
t13=((C_word*)t0)[2];
f_10630(t13,((C_word*)t0)[3],lf[697]);}
else{
t13=C_eqp(((C_word*)t0)[4],lf[576]);
t14=(C_truep(t13)?t13:C_eqp(((C_word*)t0)[4],lf[575]));
if(C_truep(t14)){
/* c-backend.scm:1267: str */
t15=((C_word*)t0)[2];
f_10630(t15,((C_word*)t0)[3],lf[698]);}
else{
t15=C_eqp(((C_word*)t0)[4],lf[552]);
t16=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10817,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t15)){
t17=t16;
f_10817(t17,t15);}
else{
t17=C_eqp(((C_word*)t0)[4],lf[554]);
if(C_truep(t17)){
t18=t16;
f_10817(t18,t17);}
else{
t18=C_eqp(((C_word*)t0)[4],lf[770]);
t19=t16;
f_10817(t19,(C_truep(t18)?t18:C_eqp(((C_word*)t0)[4],lf[771])));}}}}}}}}}}}}}}}

/* k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10817(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_10817,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1268: str */
t2=((C_word*)t0)[2];
f_10630(t2,((C_word*)t0)[3],lf[699]);}
else{
t2=C_eqp(((C_word*)t0)[4],lf[577]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[4],lf[578]));
if(C_truep(t3)){
t4=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t4;
av2[1]=lf[700];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_eqp(((C_word*)t0)[4],lf[701]);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10838,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t4)){
t6=t5;
f_10838(t6,t4);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[767]);
if(C_truep(t6)){
t7=t5;
f_10838(t7,t6);}
else{
t7=C_eqp(((C_word*)t0)[4],lf[768]);
t8=t5;
f_10838(t8,(C_truep(t7)?t7:C_eqp(((C_word*)t0)[4],lf[769])));}}}}}

/* k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10838(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_10838,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1270: str */
t2=((C_word*)t0)[2];
f_10630(t2,((C_word*)t0)[3],lf[702]);}
else{
t2=C_eqp(((C_word*)t0)[4],lf[703]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[4],lf[704]));
if(C_truep(t3)){
/* c-backend.scm:1271: str */
t4=((C_word*)t0)[2];
f_10630(t4,((C_word*)t0)[3],lf[705]);}
else{
t4=C_eqp(((C_word*)t0)[4],lf[706]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[4],lf[707]));
if(C_truep(t5)){
/* c-backend.scm:1272: str */
t6=((C_word*)t0)[2];
f_10630(t6,((C_word*)t0)[3],lf[708]);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[709]);
t7=(C_truep(t6)?t6:C_eqp(((C_word*)t0)[4],lf[710]));
if(C_truep(t7)){
/* c-backend.scm:1273: str */
t8=((C_word*)t0)[2];
f_10630(t8,((C_word*)t0)[3],lf[711]);}
else{
t8=C_eqp(((C_word*)t0)[4],lf[712]);
t9=(C_truep(t8)?t8:C_eqp(((C_word*)t0)[4],lf[713]));
if(C_truep(t9)){
/* c-backend.scm:1274: str */
t10=((C_word*)t0)[2];
f_10630(t10,((C_word*)t0)[3],lf[714]);}
else{
t10=C_eqp(((C_word*)t0)[4],lf[715]);
t11=(C_truep(t10)?t10:C_eqp(((C_word*)t0)[4],lf[716]));
if(C_truep(t11)){
/* c-backend.scm:1275: str */
t12=((C_word*)t0)[2];
f_10630(t12,((C_word*)t0)[3],lf[717]);}
else{
t12=C_eqp(((C_word*)t0)[4],lf[718]);
t13=(C_truep(t12)?t12:C_eqp(((C_word*)t0)[4],lf[719]));
if(C_truep(t13)){
/* c-backend.scm:1276: str */
t14=((C_word*)t0)[2];
f_10630(t14,((C_word*)t0)[3],lf[720]);}
else{
t14=C_eqp(((C_word*)t0)[4],lf[721]);
t15=(C_truep(t14)?t14:C_eqp(((C_word*)t0)[4],lf[722]));
if(C_truep(t15)){
/* c-backend.scm:1277: str */
t16=((C_word*)t0)[2];
f_10630(t16,((C_word*)t0)[3],lf[723]);}
else{
t16=C_eqp(((C_word*)t0)[4],lf[724]);
t17=(C_truep(t16)?t16:C_eqp(((C_word*)t0)[4],lf[725]));
if(C_truep(t17)){
/* c-backend.scm:1278: str */
t18=((C_word*)t0)[2];
f_10630(t18,((C_word*)t0)[3],lf[726]);}
else{
t18=C_eqp(((C_word*)t0)[4],lf[727]);
t19=(C_truep(t18)?t18:C_eqp(((C_word*)t0)[4],lf[728]));
if(C_truep(t19)){
/* c-backend.scm:1279: str */
t20=((C_word*)t0)[2];
f_10630(t20,((C_word*)t0)[3],lf[729]);}
else{
t20=C_eqp(((C_word*)t0)[4],lf[730]);
t21=(C_truep(t20)?t20:C_eqp(((C_word*)t0)[4],lf[731]));
if(C_truep(t21)){
/* c-backend.scm:1280: str */
t22=((C_word*)t0)[2];
f_10630(t22,((C_word*)t0)[3],lf[732]);}
else{
t22=C_eqp(((C_word*)t0)[4],lf[545]);
t23=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10970,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t22)){
t24=t23;
f_10970(t24,t22);}
else{
t24=C_eqp(((C_word*)t0)[4],lf[541]);
if(C_truep(t24)){
t25=t23;
f_10970(t25,t24);}
else{
t25=C_eqp(((C_word*)t0)[4],lf[560]);
if(C_truep(t25)){
t26=t23;
f_10970(t26,t25);}
else{
t26=C_eqp(((C_word*)t0)[4],lf[564]);
t27=t23;
f_10970(t27,(C_truep(t26)?t26:C_eqp(((C_word*)t0)[4],lf[563])));}}}}}}}}}}}}}}}

/* k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10970(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_10970,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1282: str */
t2=((C_word*)t0)[2];
f_10630(t2,((C_word*)t0)[3],lf[733]);}
else{
t2=C_eqp(((C_word*)t0)[4],lf[561]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10982,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_10982(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[4],lf[562]);
if(C_truep(t4)){
t5=t3;
f_10982(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[565]);
t6=t3;
f_10982(t6,(C_truep(t5)?t5:C_eqp(((C_word*)t0)[4],lf[566])));}}}}

/* k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_10982(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_10982,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1284: str */
t2=((C_word*)t0)[2];
f_10630(t2,((C_word*)t0)[3],lf[734]);}
else{
t2=C_eqp(((C_word*)t0)[4],lf[582]);
if(C_truep(t2)){
/* c-backend.scm:1285: str */
t3=((C_word*)t0)[2];
f_10630(t3,((C_word*)t0)[3],lf[735]);}
else{
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10997,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_symbolp(((C_word*)t0)[4]))){
/* c-backend.scm:1287: chicken.compiler.support#lookup-foreign-type */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[559]);
C_word av2[3];
av2[0]=*((C_word*)lf[559]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}
else{
t4=t3;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_10997(2,av2);}}}}}

/* k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_10997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10997,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11001,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1287: g2377 */
t3=t2;
f_11001(t3,((C_word*)t0)[3],t1);}
else{
if(C_truep(C_i_stringp(((C_word*)t0)[4]))){
/* c-backend.scm:1290: str */
t2=((C_word*)t0)[5];
f_10630(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}
else{
if(C_truep(C_i_listp(((C_word*)t0)[4]))){
t2=C_u_i_length(((C_word*)t0)[4]);
t3=C_eqp(C_fix(2),t2);
t4=(C_truep(t3)?C_u_i_memq(C_i_car(((C_word*)t0)[4]),lf[736]):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_i_cadr(((C_word*)t0)[4]);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11045,a[2]=((C_word*)t0)[3],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1298: scheme#string-append */
t7=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[737];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t5=C_eqp(C_fix(2),t2);
t6=(C_truep(t5)?C_eqp(lf[548],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=C_i_cadr(((C_word*)t0)[4]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11062,a[2]=((C_word*)t0)[3],a[3]=t7,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1301: scheme#string-append */
t9=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[738];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
t7=C_fixnum_greaterp(t2,C_fix(2));
t8=(C_truep(t7)?C_eqp(lf[739],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11075,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11079,a[2]=t9,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1306: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t10;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
av2[3]=lf[744];
tp(4,av2);}}
else{
t9=C_eqp(t2,C_fix(2));
t10=(C_truep(t9)?C_eqp(lf[550],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11152,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1313: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t11;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}
else{
t11=C_eqp(t2,C_fix(2));
t12=(C_truep(t11)?C_eqp(lf[746],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t12)){
t13=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11169,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1315: chicken.string#->string */
t14=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t14;
av2[1]=t13;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t14+1)))(3,av2);}}
else{
t13=C_eqp(t2,C_fix(2));
t14=(C_truep(t13)?C_eqp(lf[749],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t14)){
t15=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11186,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1317: chicken.string#->string */
t16=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t16;
av2[1]=t15;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t16+1)))(3,av2);}}
else{
t15=C_eqp(t2,C_fix(2));
t16=(C_truep(t15)?C_eqp(lf[752],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t16)){
t17=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11203,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1319: chicken.string#->string */
t18=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t18;
av2[1]=t17;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t18+1)))(3,av2);}}
else{
t17=C_eqp(t2,C_fix(3));
t18=(C_truep(t17)?C_u_i_memq(C_i_car(((C_word*)t0)[4]),lf[755]):C_SCHEME_FALSE);
if(C_truep(t18)){
t19=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11220,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1321: chicken.string#->string */
t20=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t20;
av2[1]=t19;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t20+1)))(3,av2);}}
else{
t19=C_eqp(t2,C_fix(3));
t20=(C_truep(t19)?C_eqp(lf[558],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t20)){
t21=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11237,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1323: chicken.string#->string */
t22=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t22;
av2[1]=t21;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t22+1)))(3,av2);}}
else{
t21=C_fixnum_greater_or_equal_p(t2,C_fix(3));
t22=(C_truep(t21)?C_eqp(lf[555],C_i_car(((C_word*)t0)[4])):C_SCHEME_FALSE);
if(C_truep(t22)){
t23=C_i_cadr(((C_word*)t0)[4]);
t24=C_i_caddr(((C_word*)t0)[4]);
t25=C_u_i_cdr(((C_word*)t0)[4]);
t26=C_u_i_cdr(t25);
t27=C_u_i_cdr(t26);
t28=C_i_nullp(t27);
t29=(C_truep(t28)?lf[758]:C_i_car(t27));
t30=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11266,a[2]=((C_word*)t0)[3],a[3]=t29,a[4]=((C_word*)t0)[2],a[5]=t24,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1329: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t30;
av2[2]=t23;
av2[3]=lf[766];
tp(4,av2);}}
else{
/* c-backend.scm:1340: err */
t23=((C_word*)t0)[6];
f_10625(t23,((C_word*)t0)[3]);}}}}}}}}}}}
else{
/* c-backend.scm:1341: err */
t2=((C_word*)t0)[6];
f_10625(t2,((C_word*)t0)[3]);}}}}

/* g2377 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11001(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_11001,3,t0,t1,t2);}
/* c-backend.scm:1289: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t1;
av2[2]=C_i_vector_ref(t2,C_fix(0));
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}

/* k11043 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11045(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11045,c,av);}
/* c-backend.scm:1298: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k11060 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11062(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11062,c,av);}
/* c-backend.scm:1301: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k11073 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11075(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11075,c,av);}
/* c-backend.scm:1304: str */
t2=((C_word*)t0)[2];
f_10630(t2,((C_word*)t0)[3],t1);}

/* k11077 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_11079,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11083,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_cddr(((C_word*)t0)[3]);
t8=C_i_check_list_2(t7,lf[310]);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11101,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11103,a[2]=t5,a[3]=t11,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t13=((C_word*)t11)[1];
f_11103(t13,t9,t7);}

/* k11081 in k11077 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11083(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11083,c,av);}
/* c-backend.scm:1305: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[740];
av2[4]=t1;
av2[5]=lf[741];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k11099 in k11077 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11101(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11101,c,av);}
/* c-backend.scm:1308: chicken.string#string-intersperse */
t2=C_fast_retrieve(lf[303]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[742];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop2390 in k11077 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11103(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_11103,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11128,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[245]+1);
/* c-backend.scm:1309: g2413 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[743];
tp(4,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11126 in map-loop2390 in k11077 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11128(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11128,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11103(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11150 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11152,c,av);}
/* c-backend.scm:1313: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[745];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k11167 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11169,c,av);}
/* c-backend.scm:1315: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[747];
av2[3]=t1;
av2[4]=lf[748];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k11184 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11186(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11186,c,av);}
/* c-backend.scm:1317: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[750];
av2[3]=t1;
av2[4]=lf[751];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k11201 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11203,c,av);}
/* c-backend.scm:1319: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[753];
av2[3]=t1;
av2[4]=lf[754];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k11218 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11220,c,av);}
/* c-backend.scm:1321: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[756];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k11235 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11237,c,av);}
/* c-backend.scm:1323: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[757];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k11264 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11266(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_11266,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11270,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(((C_word*)t0)[5],lf[310]);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11291,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11293,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_11293(t12,t8,((C_word*)t0)[5]);}

/* k11268 in k11264 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11270(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_11270,c,av);}
/* c-backend.scm:1328: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[759];
av2[5]=((C_word*)t0)[5];
av2[6]=lf[760];
av2[7]=t1;
av2[8]=lf[761];
((C_proc)(void*)(*((C_word*)t2+1)))(9,av2);}}

/* k11289 in k11264 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11291(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11291,c,av);}
/* c-backend.scm:1332: chicken.string#string-intersperse */
t2=C_fast_retrieve(lf[303]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[762];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop2438 in k11264 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11293(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_11293,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11303,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11318,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=C_slot(t2,C_fix(0));
t6=C_eqp(lf[763],t5);
if(C_truep(t6)){
t7=t3;
f_11303(t7,C_a_i_cons(&a,2,lf[764],C_SCHEME_END_OF_LIST));}
else{
/* c-backend.scm:1336: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t4;
av2[2]=t5;
av2[3]=lf[765];
tp(4,av2);}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11301 in map-loop2438 in k11264 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11303(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,2)))){
C_save_and_reclaim_args((void *)trf_11303,2,t0,t1);}
t2=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t1);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t4=((C_word*)((C_word*)t0)[3])[1];
f_11293(t4,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11316 in map-loop2438 in k11264 in k10995 in k10980 in k10968 in k10836 in k10815 in k10698 in chicken.compiler.c-backend#foreign-type-declaration in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_11318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_11318,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];
f_11303(t2,C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST));}

/* chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11717(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_11717,2,t1,t2);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11719,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=C_eqp(t2,lf[584]);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[773];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(t2,lf[17]);
t6=(C_truep(t5)?t5:C_eqp(t2,lf[585]));
if(C_truep(t6)){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=lf[774];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(t2,lf[588]);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11747,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t7)){
t9=t8;
f_11747(t9,t7);}
else{
t9=C_eqp(t2,lf[579]);
if(C_truep(t9)){
t10=t8;
f_11747(t10,t9);}
else{
t10=C_eqp(t2,lf[580]);
if(C_truep(t10)){
t11=t8;
f_11747(t11,t10);}
else{
t11=C_eqp(t2,lf[586]);
if(C_truep(t11)){
t12=t8;
f_11747(t12,t11);}
else{
t12=C_eqp(t2,lf[587]);
t13=t8;
f_11747(t13,(C_truep(t12)?t12:C_eqp(t2,lf[589])));}}}}}}}

/* err in chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11719(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_11719,2,t0,t1);}
/* c-backend.scm:1348: chicken.compiler.support#quit-compiling */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[679]);
C_word av2[4];
av2[0]=*((C_word*)lf[679]+1);
av2[1]=t1;
av2[2]=lf[772];
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}

/* k11745 in chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11747(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_11747,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=lf[775];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[3],lf[581]);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=lf[776];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_eqp(((C_word*)t0)[3],lf[583]);
if(C_truep(t3)){
t4=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t4;
av2[1]=lf[777];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_eqp(((C_word*)t0)[3],lf[574]);
if(C_truep(t4)){
t5=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[778];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(((C_word*)t0)[3],lf[576]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11774,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t5)){
t7=t6;
f_11774(t7,t5);}
else{
t7=C_eqp(((C_word*)t0)[3],lf[575]);
t8=t6;
f_11774(t8,(C_truep(t7)?t7:C_eqp(((C_word*)t0)[3],lf[535])));}}}}}}

/* k11772 in k11745 in chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11774(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_11774,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=lf[779];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[3],lf[572]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[3],lf[573]));
if(C_truep(t3)){
t4=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t4;
av2[1]=lf[780];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_eqp(((C_word*)t0)[3],lf[567]);
if(C_truep(t4)){
t5=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[781];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(((C_word*)t0)[3],lf[568]);
if(C_truep(t5)){
t6=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t6;
av2[1]=lf[782];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_eqp(((C_word*)t0)[3],lf[569]);
if(C_truep(t6)){
t7=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t7;
av2[1]=lf[783];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(((C_word*)t0)[3],lf[539]);
if(C_truep(t7)){
t8=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t8;
av2[1]=lf[784];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_eqp(((C_word*)t0)[3],lf[571]);
if(C_truep(t8)){
t9=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t9;
av2[1]=lf[785];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_eqp(((C_word*)t0)[3],lf[537]);
t10=(C_truep(t9)?t9:C_eqp(((C_word*)t0)[3],lf[570]));
if(C_truep(t10)){
t11=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t11;
av2[1]=lf[786];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t11=C_eqp(((C_word*)t0)[3],lf[770]);
if(C_truep(t11)){
t12=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t12;
av2[1]=lf[787];
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t12=C_eqp(((C_word*)t0)[3],lf[771]);
if(C_truep(t12)){
t13=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t13;
av2[1]=lf[788];
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t13=C_eqp(((C_word*)t0)[3],lf[552]);
if(C_truep(t13)){
t14=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t14;
av2[1]=lf[789];
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t14=C_eqp(((C_word*)t0)[3],lf[554]);
if(C_truep(t14)){
t15=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t15;
av2[1]=lf[790];
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t15=C_eqp(((C_word*)t0)[3],lf[701]);
if(C_truep(t15)){
t16=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t16;
av2[1]=lf[791];
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}
else{
t16=C_eqp(((C_word*)t0)[3],lf[767]);
if(C_truep(t16)){
t17=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t17;
av2[1]=lf[792];
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}
else{
t17=C_eqp(((C_word*)t0)[3],lf[768]);
if(C_truep(t17)){
t18=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t18;
av2[1]=lf[793];
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}
else{
t18=C_eqp(((C_word*)t0)[3],lf[769]);
if(C_truep(t18)){
t19=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t19;
av2[1]=lf[794];
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}
else{
t19=C_eqp(((C_word*)t0)[3],lf[703]);
if(C_truep(t19)){
t20=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t20;
av2[1]=lf[795];
((C_proc)(void*)(*((C_word*)t20+1)))(2,av2);}}
else{
t20=C_eqp(((C_word*)t0)[3],lf[704]);
if(C_truep(t20)){
t21=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t21;
av2[1]=lf[796];
((C_proc)(void*)(*((C_word*)t21+1)))(2,av2);}}
else{
t21=C_eqp(((C_word*)t0)[3],lf[709]);
if(C_truep(t21)){
t22=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t22;
av2[1]=lf[797];
((C_proc)(void*)(*((C_word*)t22+1)))(2,av2);}}
else{
t22=C_eqp(((C_word*)t0)[3],lf[710]);
if(C_truep(t22)){
t23=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t23;
av2[1]=lf[798];
((C_proc)(void*)(*((C_word*)t23+1)))(2,av2);}}
else{
t23=C_eqp(((C_word*)t0)[3],lf[712]);
if(C_truep(t23)){
t24=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t24;
av2[1]=lf[799];
((C_proc)(void*)(*((C_word*)t24+1)))(2,av2);}}
else{
t24=C_eqp(((C_word*)t0)[3],lf[713]);
if(C_truep(t24)){
t25=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t25;
av2[1]=lf[800];
((C_proc)(void*)(*((C_word*)t25+1)))(2,av2);}}
else{
t25=C_eqp(((C_word*)t0)[3],lf[706]);
if(C_truep(t25)){
t26=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t26;
av2[1]=lf[801];
((C_proc)(void*)(*((C_word*)t26+1)))(2,av2);}}
else{
t26=C_eqp(((C_word*)t0)[3],lf[707]);
if(C_truep(t26)){
t27=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t27;
av2[1]=lf[802];
((C_proc)(void*)(*((C_word*)t27+1)))(2,av2);}}
else{
t27=C_eqp(((C_word*)t0)[3],lf[715]);
if(C_truep(t27)){
t28=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t28;
av2[1]=lf[803];
((C_proc)(void*)(*((C_word*)t28+1)))(2,av2);}}
else{
t28=C_eqp(((C_word*)t0)[3],lf[716]);
if(C_truep(t28)){
t29=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t29;
av2[1]=lf[804];
((C_proc)(void*)(*((C_word*)t29+1)))(2,av2);}}
else{
t29=C_eqp(((C_word*)t0)[3],lf[718]);
if(C_truep(t29)){
t30=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t30;
av2[1]=lf[805];
((C_proc)(void*)(*((C_word*)t30+1)))(2,av2);}}
else{
t30=C_eqp(((C_word*)t0)[3],lf[719]);
if(C_truep(t30)){
t31=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t31;
av2[1]=lf[806];
((C_proc)(void*)(*((C_word*)t31+1)))(2,av2);}}
else{
t31=C_eqp(((C_word*)t0)[3],lf[721]);
if(C_truep(t31)){
t32=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t32;
av2[1]=lf[807];
((C_proc)(void*)(*((C_word*)t32+1)))(2,av2);}}
else{
t32=C_eqp(((C_word*)t0)[3],lf[722]);
if(C_truep(t32)){
t33=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t33;
av2[1]=lf[808];
((C_proc)(void*)(*((C_word*)t33+1)))(2,av2);}}
else{
t33=C_eqp(((C_word*)t0)[3],lf[724]);
if(C_truep(t33)){
t34=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t34;
av2[1]=lf[809];
((C_proc)(void*)(*((C_word*)t34+1)))(2,av2);}}
else{
t34=C_eqp(((C_word*)t0)[3],lf[725]);
if(C_truep(t34)){
t35=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t35;
av2[1]=lf[810];
((C_proc)(void*)(*((C_word*)t35+1)))(2,av2);}}
else{
t35=C_eqp(((C_word*)t0)[3],lf[727]);
if(C_truep(t35)){
t36=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t36;
av2[1]=lf[811];
((C_proc)(void*)(*((C_word*)t36+1)))(2,av2);}}
else{
t36=C_eqp(((C_word*)t0)[3],lf[728]);
if(C_truep(t36)){
t37=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t37;
av2[1]=lf[812];
((C_proc)(void*)(*((C_word*)t37+1)))(2,av2);}}
else{
t37=C_eqp(((C_word*)t0)[3],lf[730]);
if(C_truep(t37)){
t38=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t38;
av2[1]=lf[813];
((C_proc)(void*)(*((C_word*)t38+1)))(2,av2);}}
else{
t38=C_eqp(((C_word*)t0)[3],lf[731]);
if(C_truep(t38)){
t39=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t39;
av2[1]=lf[814];
((C_proc)(void*)(*((C_word*)t39+1)))(2,av2);}}
else{
t39=C_eqp(((C_word*)t0)[3],lf[541]);
t40=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11999,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t39)){
t41=t40;
f_11999(t41,t39);}
else{
t41=C_eqp(((C_word*)t0)[3],lf[564]);
if(C_truep(t41)){
t42=t40;
f_11999(t42,t41);}
else{
t42=C_eqp(((C_word*)t0)[3],lf[565]);
t43=t40;
f_11999(t43,(C_truep(t42)?t42:C_eqp(((C_word*)t0)[3],lf[566])));}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}

/* k11997 in k11772 in k11745 in chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_11999(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_11999,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=lf[815];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[3],lf[545]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12008,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t2)){
t4=t3;
f_12008(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[3],lf[560]);
if(C_truep(t4)){
t5=t3;
f_12008(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[3],lf[561]);
if(C_truep(t5)){
t6=t3;
f_12008(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[3],lf[562]);
t7=t3;
f_12008(t7,(C_truep(t6)?t6:C_eqp(((C_word*)t0)[3],lf[563])));}}}}}

/* k12006 in k11997 in k11772 in k11745 in chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_12008(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_12008,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=lf[816];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[3],lf[14]);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=lf[817];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12017,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_symbolp(((C_word*)t0)[3]))){
/* c-backend.scm:1397: chicken.compiler.support#lookup-foreign-type */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[559]);
C_word av2[3];
av2[0]=*((C_word*)lf[559]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t4=t3;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_12017(2,av2);}}}}}

/* k12015 in k12006 in k11997 in k11772 in k11745 in chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12017(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_12017,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
/* c-backend.scm:1399: foreign-argument-conversion */
f_11717(((C_word*)t0)[2],C_i_vector_ref(t1,C_fix(0)));}
else{
t2=C_i_listp(((C_word*)t0)[3]);
t3=(C_truep(t2)?C_fixnum_greater_or_equal_p(C_u_i_length(((C_word*)t0)[3]),C_fix(2)):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[3]);
t5=C_eqp(t4,lf[552]);
if(C_truep(t5)){
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=lf[818];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_eqp(t4,lf[554]);
if(C_truep(t6)){
t7=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t7;
av2[1]=lf[819];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(t4,lf[556]);
if(C_truep(t7)){
t8=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t8;
av2[1]=lf[820];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_eqp(t4,lf[557]);
if(C_truep(t8)){
t9=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t9;
av2[1]=lf[821];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_eqp(t4,lf[770]);
if(C_truep(t9)){
t10=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t10;
av2[1]=lf[822];
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t10=C_eqp(t4,lf[771]);
if(C_truep(t10)){
t11=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t11;
av2[1]=lf[823];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t11=C_eqp(t4,lf[555]);
if(C_truep(t11)){
t12=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t12;
av2[1]=lf[824];
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t12=C_eqp(t4,lf[550]);
if(C_truep(t12)){
/* c-backend.scm:1409: foreign-argument-conversion */
f_11717(((C_word*)t0)[2],C_i_cadr(((C_word*)t0)[3]));}
else{
t13=C_eqp(t4,lf[752]);
if(C_truep(t13)){
t14=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t14;
av2[1]=lf[825];
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t14=C_eqp(t4,lf[548]);
if(C_truep(t14)){
t15=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12115,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1412: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t15;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
av2[3]=lf[828];
tp(4,av2);}}
else{
t15=C_eqp(t4,lf[558]);
if(C_truep(t15)){
/* c-backend.scm:1415: scheme#string-append */
t16=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t16;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[829];
av2[3]=C_i_cadr(((C_word*)t0)[3]);
av2[4]=lf[830];
((C_proc)(void*)(*((C_word*)t16+1)))(5,av2);}}
else{
/* c-backend.scm:1416: err */
t16=((C_word*)t0)[4];
f_11719(t16,((C_word*)t0)[2]);}}}}}}}}}}}}
else{
/* c-backend.scm:1417: err */
t4=((C_word*)t0)[4];
f_11719(t4,((C_word*)t0)[2]);}}}

/* k12113 in k12015 in k12006 in k11997 in k11772 in k11745 in chicken.compiler.c-backend#foreign-argument-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12115(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12115,c,av);}
/* c-backend.scm:1412: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[826];
av2[3]=t1;
av2[4]=lf[827];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_12382(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_12382,3,t1,t2,t3);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12384,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t5=C_eqp(t2,lf[17]);
t6=(C_truep(t5)?t5:C_eqp(t2,lf[585]));
if(C_truep(t6)){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=lf[832];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(t2,lf[579]);
t8=(C_truep(t7)?t7:C_eqp(t2,lf[580]));
if(C_truep(t8)){
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=lf[833];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_eqp(t2,lf[586]);
t10=(C_truep(t9)?t9:C_eqp(t2,lf[587]));
if(C_truep(t10)){
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=lf[834];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t11=C_eqp(t2,lf[581]);
if(C_truep(t11)){
t12=t1;{
C_word av2[2];
av2[0]=t12;
av2[1]=lf[835];
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t12=C_eqp(t2,lf[583]);
if(C_truep(t12)){
t13=t1;{
C_word av2[2];
av2[0]=t13;
av2[1]=lf[836];
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t13=C_eqp(t2,lf[588]);
if(C_truep(t13)){
t14=t1;{
C_word av2[2];
av2[0]=t14;
av2[1]=lf[837];
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t14=C_eqp(t2,lf[589]);
if(C_truep(t14)){
t15=t1;{
C_word av2[2];
av2[0]=t15;
av2[1]=lf[838];
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t15=C_eqp(t2,lf[535]);
t16=(C_truep(t15)?t15:C_eqp(t2,lf[576]));
if(C_truep(t16)){
t17=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12451,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1433: chicken.base#open-output-string */
t18=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t18;
av2[1]=t17;
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}
else{
t17=C_eqp(t2,lf[575]);
if(C_truep(t17)){
t18=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12475,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1434: chicken.base#open-output-string */
t19=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t19;
av2[1]=t18;
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}
else{
t18=C_eqp(t2,lf[545]);
t19=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12499,a[2]=t1,a[3]=t3,a[4]=t2,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
if(C_truep(t18)){
t20=t19;
f_12499(t20,t18);}
else{
t20=C_eqp(t2,lf[541]);
if(C_truep(t20)){
t21=t19;
f_12499(t21,t20);}
else{
t21=C_eqp(t2,lf[554]);
if(C_truep(t21)){
t22=t19;
f_12499(t22,t21);}
else{
t22=C_eqp(t2,lf[564]);
if(C_truep(t22)){
t23=t19;
f_12499(t23,t22);}
else{
t23=C_eqp(t2,lf[560]);
if(C_truep(t23)){
t24=t19;
f_12499(t24,t23);}
else{
t24=C_eqp(t2,lf[565]);
if(C_truep(t24)){
t25=t19;
f_12499(t25,t24);}
else{
t25=C_eqp(t2,lf[566]);
if(C_truep(t25)){
t26=t19;
f_12499(t26,t25);}
else{
t26=C_eqp(t2,lf[561]);
if(C_truep(t26)){
t27=t19;
f_12499(t27,t26);}
else{
t27=C_eqp(t2,lf[562]);
if(C_truep(t27)){
t28=t19;
f_12499(t28,t27);}
else{
t28=C_eqp(t2,lf[563]);
if(C_truep(t28)){
t29=t19;
f_12499(t29,t28);}
else{
t29=C_eqp(t2,lf[577]);
t30=t19;
f_12499(t30,(C_truep(t29)?t29:C_eqp(t2,lf[578])));}}}}}}}}}}}}}}}}}}}}

/* err in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_12384(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_12384,2,t0,t1);}
/* c-backend.scm:1424: chicken.compiler.support#quit-compiling */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[679]);
C_word av2[4];
av2[0]=*((C_word*)lf[679]+1);
av2[1]=t1;
av2[2]=lf[831];
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}

/* k12449 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12451(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12451,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12457,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1433: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[839];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12455 in k12449 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12457,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12460,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1433: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12458 in k12455 in k12449 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12460,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12463,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1433: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12461 in k12458 in k12455 in k12449 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12463,c,av);}
/* c-backend.scm:1433: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12473 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12475(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12475,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12481,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1434: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[840];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12479 in k12473 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12481(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12481,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12484,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1434: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12482 in k12479 in k12473 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12484(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12484,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12487,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1434: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12485 in k12482 in k12479 in k12473 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12487,c,av);}
/* c-backend.scm:1434: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_12499(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_12499,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12502,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1438: chicken.base#open-output-string */
t3=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[552]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12526,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1439: chicken.base#open-output-string */
t4=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_eqp(((C_word*)t0)[4],lf[572]);
t4=(C_truep(t3)?t3:C_eqp(((C_word*)t0)[4],lf[573]));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12553,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1440: chicken.base#open-output-string */
t6=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=C_eqp(((C_word*)t0)[4],lf[567]);
t6=(C_truep(t5)?t5:C_eqp(((C_word*)t0)[4],lf[569]));
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12580,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1441: chicken.base#open-output-string */
t8=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t8;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t7=C_eqp(((C_word*)t0)[4],lf[539]);
t8=(C_truep(t7)?t7:C_eqp(((C_word*)t0)[4],lf[568]));
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12607,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1442: chicken.base#open-output-string */
t10=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t9=C_eqp(((C_word*)t0)[4],lf[537]);
t10=(C_truep(t9)?t9:C_eqp(((C_word*)t0)[4],lf[570]));
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12634,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1443: chicken.base#open-output-string */
t12=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t12;
av2[1]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t11=C_eqp(((C_word*)t0)[4],lf[571]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12658,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1444: chicken.base#open-output-string */
t13=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t13;
av2[1]=t12;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t12=C_eqp(((C_word*)t0)[4],lf[574]);
if(C_truep(t12)){
t13=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12682,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1445: chicken.base#open-output-string */
t14=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t14;
av2[1]=t13;
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t13=C_eqp(((C_word*)t0)[4],lf[14]);
if(C_truep(t13)){
t14=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t14;
av2[1]=lf[851];
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t14=C_eqp(((C_word*)t0)[4],lf[582]);
t15=(C_truep(t14)?t14:C_eqp(((C_word*)t0)[4],lf[584]));
if(C_truep(t15)){
t16=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t16;
av2[1]=lf[852];
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}
else{
t16=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12715,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_symbolp(((C_word*)t0)[4]))){
/* c-backend.scm:1449: chicken.compiler.support#lookup-foreign-type */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[559]);
C_word av2[3];
av2[0]=*((C_word*)lf[559]+1);
av2[1]=t16;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}
else{
t17=t16;{
C_word av2[2];
av2[0]=t17;
av2[1]=C_SCHEME_FALSE;
f_12715(2,av2);}}}}}}}}}}}}}

/* k12500 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12502(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12502,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12508,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1438: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[842];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12506 in k12500 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12508,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12511,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1438: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12509 in k12506 in k12500 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12511(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12511,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12514,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1438: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[841];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12512 in k12509 in k12506 in k12500 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12514(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12514,c,av);}
/* c-backend.scm:1438: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12524 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12526,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12532,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1439: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[844];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12530 in k12524 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12532(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12532,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12535,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1439: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12533 in k12530 in k12524 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12535,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12538,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1439: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[843];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12536 in k12533 in k12530 in k12524 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12538(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12538,c,av);}
/* c-backend.scm:1439: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12551 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12553(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12553,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12559,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1440: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[845];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12557 in k12551 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12559(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12559,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12562,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1440: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12560 in k12557 in k12551 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12562,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12565,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1440: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12563 in k12560 in k12557 in k12551 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12565(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12565,c,av);}
/* c-backend.scm:1440: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12578 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12580(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12580,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12586,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1441: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[846];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12584 in k12578 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12586,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12589,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1441: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12587 in k12584 in k12578 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12589(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12589,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12592,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1441: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12590 in k12587 in k12584 in k12578 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12592(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12592,c,av);}
/* c-backend.scm:1441: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12605 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12607(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12607,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12613,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1442: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[847];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12611 in k12605 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12613,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12616,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1442: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12614 in k12611 in k12605 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12616(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12616,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12619,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1442: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12617 in k12614 in k12611 in k12605 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12619(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12619,c,av);}
/* c-backend.scm:1442: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12632 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12634(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12634,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12640,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1443: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[848];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12638 in k12632 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12640(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12640,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12643,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1443: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12641 in k12638 in k12632 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12643,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12646,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1443: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12644 in k12641 in k12638 in k12632 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12646(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12646,c,av);}
/* c-backend.scm:1443: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12656 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12658(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12658,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12664,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1444: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[849];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12662 in k12656 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12664(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12664,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12667,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1444: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12665 in k12662 in k12656 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12667(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12667,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12670,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1444: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12668 in k12665 in k12662 in k12656 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12670(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12670,c,av);}
/* c-backend.scm:1444: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12680 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12682,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12688,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1445: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[850];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12686 in k12680 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12688(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12688,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12691,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1445: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12689 in k12686 in k12680 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12691(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12691,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12694,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1445: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12692 in k12689 in k12686 in k12680 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12694,c,av);}
/* c-backend.scm:1445: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12715,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12719,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1449: g2737 */
t3=t2;
f_12719(t3,((C_word*)t0)[3],t1);}
else{
t2=C_i_listp(((C_word*)t0)[4]);
t3=(C_truep(t2)?C_fixnum_greater_or_equal_p(C_u_i_length(((C_word*)t0)[4]),C_fix(2)):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[4]);
t5=C_eqp(t4,lf[553]);
t6=(C_truep(t5)?t5:C_eqp(t4,lf[554]));
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12751,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1455: chicken.base#open-output-string */
t8=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t7=C_eqp(t4,lf[548]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12775,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1457: chicken.base#open-output-string */
t9=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=C_eqp(t4,lf[556]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12799,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1459: chicken.base#open-output-string */
t10=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t9=C_eqp(t4,lf[557]);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12823,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1461: chicken.base#open-output-string */
t11=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t10=C_eqp(t4,lf[558]);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12847,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1463: chicken.base#open-output-string */
t12=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t11=C_eqp(t4,lf[550]);
if(C_truep(t11)){
/* c-backend.scm:1464: foreign-result-conversion */
f_12382(((C_word*)t0)[3],C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[2]);}
else{
t12=C_eqp(t4,lf[551]);
t13=(C_truep(t12)?t12:C_eqp(t4,lf[552]));
if(C_truep(t13)){
t14=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12887,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1466: chicken.base#open-output-string */
t15=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t15;
av2[1]=t14;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t14=C_eqp(t4,lf[555]);
if(C_truep(t14)){
t15=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12911,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1467: chicken.base#open-output-string */
t16=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t16;
av2[1]=t15;
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}
else{
t15=C_eqp(t4,lf[752]);
if(C_truep(t15)){
t16=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12935,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1468: chicken.base#open-output-string */
t17=C_fast_retrieve(lf[360]);{
C_word *av2=av;
av2[0]=t17;
av2[1]=t16;
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}
else{
/* c-backend.scm:1469: err */
t16=((C_word*)t0)[5];
f_12384(t16,((C_word*)t0)[3]);}}}}}}}}}}
else{
/* c-backend.scm:1470: err */
t4=((C_word*)t0)[5];
f_12384(t4,((C_word*)t0)[3]);}}}

/* g2737 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_12719(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_12719,3,t0,t1,t2);}
/* c-backend.scm:1451: foreign-result-conversion */
f_12382(t1,C_i_vector_ref(t2,C_fix(0)),((C_word*)t0)[2]);}

/* k12749 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12751(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12751,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12757,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1455: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[854];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12755 in k12749 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12757,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12760,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1455: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12758 in k12755 in k12749 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12760,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12763,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1455: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[853];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12761 in k12758 in k12755 in k12749 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12763,c,av);}
/* c-backend.scm:1455: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12773 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12775(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12775,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12781,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1457: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[856];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12779 in k12773 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12781,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12784,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1457: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12782 in k12779 in k12773 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12784,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12787,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1457: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[855];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12785 in k12782 in k12779 in k12773 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12787,c,av);}
/* c-backend.scm:1457: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12797 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12799,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12805,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1459: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[858];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12803 in k12797 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12805,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12808,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1459: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12806 in k12803 in k12797 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12808,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12811,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1459: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[857];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12809 in k12806 in k12803 in k12797 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12811,c,av);}
/* c-backend.scm:1459: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12821 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12823,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12829,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1461: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[860];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12827 in k12821 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12829,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12832,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1461: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12830 in k12827 in k12821 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12832,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12835,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1461: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[859];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12833 in k12830 in k12827 in k12821 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12835,c,av);}
/* c-backend.scm:1461: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12845 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12847,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12853,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1463: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[862];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12851 in k12845 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12853,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12856,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1463: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12854 in k12851 in k12845 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12856,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12859,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1463: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[861];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12857 in k12854 in k12851 in k12845 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12859,c,av);}
/* c-backend.scm:1463: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12885 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12887,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12893,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1466: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[864];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12891 in k12885 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12893(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12893,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12896,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1466: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12894 in k12891 in k12885 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12896,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12899,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1466: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[863];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12897 in k12894 in k12891 in k12885 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12899(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12899,c,av);}
/* c-backend.scm:1466: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12909 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12911(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12911,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12917,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1467: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[866];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12915 in k12909 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12917,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12920,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1467: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12918 in k12915 in k12909 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12920(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12920,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12923,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1467: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[865];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12921 in k12918 in k12915 in k12909 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12923,c,av);}
/* c-backend.scm:1467: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12933 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12935(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12935,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12941,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1468: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[867];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12939 in k12933 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12941(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12941,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12944,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1468: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12942 in k12939 in k12933 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12944,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12947,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1468: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k12945 in k12942 in k12939 in k12933 in k12713 in k12497 in chicken.compiler.c-backend#foreign-result-conversion in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_12947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12947,c,av);}
/* c-backend.scm:1468: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_13169(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_13169,2,t1,t2);}
a=C_alloc(13);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13178,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13244,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=C_eqp(C_SCHEME_TRUE,t2);
if(C_truep(t5)){
t6=C_a_i_string(&a,1,C_make_character(254));
/* c-backend.scm:1502: scheme#string-append */
t7=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=lf[869];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t6=C_eqp(C_SCHEME_FALSE,t2);
if(C_truep(t6)){
t7=C_a_i_string(&a,1,C_make_character(254));
/* c-backend.scm:1502: scheme#string-append */
t8=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t1;
av2[2]=t7;
av2[3]=lf[870];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
if(C_truep(C_charp(t2))){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13266,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1506: encode-size */
f_13178(t7,C_fix(C_character_code(t2)));}
else{
if(C_truep(C_i_nullp(t2))){
t7=C_a_i_string(&a,1,C_make_character(254));
/* c-backend.scm:1502: scheme#string-append */
t8=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t1;
av2[2]=t7;
av2[3]=lf[872];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
if(C_truep(C_eofp(t2))){
t7=C_a_i_string(&a,1,C_make_character(254));
/* c-backend.scm:1502: scheme#string-append */
t8=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t1;
av2[2]=t7;
av2[3]=lf[873];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
t7=*((C_word*)lf[373]+1);
t8=C_eqp(*((C_word*)lf[373]+1),t2);
if(C_truep(t8)){
t9=C_a_i_string(&a,1,C_make_character(254));
/* c-backend.scm:1502: scheme#string-append */
t10=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t10;
av2[1]=t1;
av2[2]=t9;
av2[3]=lf[874];
((C_proc)(void*)(*((C_word*)t10+1)))(4,av2);}}
else{
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13294,a[2]=t2,a[3]=t4,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnump(t2))){
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13503,a[2]=t9,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1511: chicken.compiler.support#big-fixnum? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[369]);
C_word av2[3];
av2[0]=*((C_word*)lf[369]+1);
av2[1]=t10;
av2[2]=t2;
tp(3,av2);}}
else{
t10=t9;
f_13294(t10,C_SCHEME_FALSE);}}}}}}}}

/* encode-size in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_13178(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,3)))){
C_save_and_reclaim_args((void *)trf_13178,2,t1,t2);}
a=C_alloc(29);
t3=C_i_fixnum_length(t2);
if(C_truep(C_fixnum_greaterp(t3,C_fix(24)))){
/* c-backend.scm:1495: chicken.compiler.support#quit-compiling */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[679]);
C_word av2[4];
av2[0]=*((C_word*)lf[679]+1);
av2[1]=t1;
av2[2]=lf[868];
av2[3]=t2;
tp(4,av2);}}
else{
t4=C_s_a_i_arithmetic_shift(&a,2,t2,C_fix(-16));
t5=C_s_a_i_bitwise_and(&a,2,C_fix(255),t4);
t6=C_make_character(C_unfix(t5));
t7=C_s_a_i_arithmetic_shift(&a,2,t2,C_fix(-8));
t8=C_s_a_i_bitwise_and(&a,2,C_fix(255),t7);
t9=C_make_character(C_unfix(t8));
t10=C_s_a_i_bitwise_and(&a,2,C_fix(255),t2);
t11=C_make_character(C_unfix(t10));
t12=t1;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_a_i_string(&a,3,t6,t9,t11);
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}

/* k13242 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(2,c,3)))){
C_save_and_reclaim((void *)f_13244,c,av);}
a=C_alloc(2);
t2=C_a_i_string(&a,1,C_make_character(254));
/* c-backend.scm:1502: scheme#string-append */
t3=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k13264 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13266(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13266,c,av);}
/* c-backend.scm:1506: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[871];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_13294(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(40,0,3)))){
C_save_and_reclaim_args((void *)trf_13294,2,t0,t1);}
a=C_alloc(40);
if(C_truep(t1)){
t2=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[2],C_fix(-24));
t3=C_s_a_i_bitwise_and(&a,2,C_fix(255),t2);
t4=C_make_character(C_unfix(t3));
t5=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[2],C_fix(-16));
t6=C_s_a_i_bitwise_and(&a,2,C_fix(255),t5);
t7=C_make_character(C_unfix(t6));
t8=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[2],C_fix(-8));
t9=C_s_a_i_bitwise_and(&a,2,C_fix(255),t8);
t10=C_make_character(C_unfix(t9));
t11=C_s_a_i_bitwise_and(&a,2,C_fix(255),((C_word*)t0)[2]);
t12=C_make_character(C_unfix(t11));
t13=C_a_i_string(&a,4,t4,t7,t10,t12);
/* ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[144]);
C_word av2[4];
av2[0]=*((C_word*)lf[144]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=lf[875];
av2[3]=t13;
tp(4,av2);}}
else{
if(C_truep(C_i_exact_integerp(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13353,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word av2[4];
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=C_fix(16);
tp(4,av2);}}
else{
if(C_truep(C_i_flonump(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13380,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* ##sys#flonum->string */
t3=C_fast_retrieve(lf[879]);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=C_fix(10);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13387,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1529: chicken.keyword#keyword? */
t3=C_fast_retrieve(lf[368]);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}}

/* k13351 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13353(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13353,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13360,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1526: encode-size */
f_13178(t2,C_block_size(t1));}

/* k13358 in k13351 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13360(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13360,c,av);}
/* c-backend.scm:1526: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[876];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k13378 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13380,c,av);}
/* c-backend.scm:1528: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[877];
av2[3]=t1;
av2[4]=lf[878];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_13387,c,av);}
a=C_alloc(11);
t2=(C_truep(t1)?t1:C_i_symbolp(((C_word*)t0)[2]));
if(C_truep(t2)){
t3=C_slot(((C_word*)t0)[2],C_fix(1));
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13400,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1533: encode-size */
f_13178(t4,C_i_string_length(t3));}
else{
if(C_truep(C_immp(((C_word*)t0)[2]))){
/* c-backend.scm:1537: chicken.compiler.support#bomb */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[10]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[10]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=lf[883];
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}
else{
if(C_truep(C_byteblockp(((C_word*)t0)[2]))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13430,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=stub2856(C_SCHEME_UNDEFINED,((C_word*)t0)[2]);
t5=C_make_character(C_unfix(t4));
t6=C_a_i_string(&a,1,t5);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13438,a[2]=t3,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1542: encode-size */
f_13178(t7,stub2860(C_SCHEME_UNDEFINED,((C_word*)t0)[2]));}
else{
t3=stub2860(C_SCHEME_UNDEFINED,((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13460,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t5=stub2856(C_SCHEME_UNDEFINED,((C_word*)t0)[2]);
t6=C_make_character(C_unfix(t5));
t7=C_a_i_string(&a,1,t6);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13468,a[2]=t4,a[3]=t7,a[4]=((C_word*)t0)[2],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1549: encode-size */
f_13178(t8,t3);}}}}

/* k13398 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_13400,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13407,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1534: chicken.keyword#keyword? */
t3=C_fast_retrieve(lf[368]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13405 in k13398 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13407(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_13407,c,av);}
if(C_truep(t1)){
/* c-backend.scm:1531: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[880];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[881];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
/* c-backend.scm:1531: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[880];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[882];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* k13428 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13430,c,av);}
/* c-backend.scm:1539: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[144]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[144]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k13436 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13438(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13438,c,av);}
/* c-backend.scm:1540: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13458 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13460,c,av);}
/* c-backend.scm:1546: chicken.string#string-intersperse */
t2=C_fast_retrieve(lf[303]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[884];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13466 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_13468,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13472,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13474,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1550: list-tabulate */
f_4281(t2,((C_word*)t0)[5],t3);}

/* k13470 in k13466 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13472(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_13472,c,av);}
a=C_alloc(11);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3709,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_3709(t6,((C_word*)t0)[3],((C_word*)t0)[4],t2);}

/* a13473 in k13466 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13474(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13474,c,av);}
/* c-backend.scm:1550: encode-literal */
f_13169(t1,C_slot(((C_word*)t0)[2],t2));}

/* k13501 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_13503(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13503,c,av);}
t2=((C_word*)t0)[2];
f_13294(t2,C_i_not(t1));}

/* k3245 */
static void C_ccall f_3247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3247,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3250,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_eval_toplevel(2,av2);}}

/* k3248 in k3245 */
static void C_ccall f_3250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3250,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3253,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_data_2dstructures_toplevel(2,av2);}}

/* k3251 in k3248 in k3245 */
static void C_ccall f_3253(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3253,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3256,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_extras_toplevel(2,av2);}}

/* k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_3256(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3256,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3259,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_c_2dplatform_toplevel(2,av2);}}

/* k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_3259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3259,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3262,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_compiler_toplevel(2,av2);}}

/* k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_3262(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3262,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3265,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_internal_toplevel(2,av2);}}

/* k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_3265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3265,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3268,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_support_toplevel(2,av2);}}

/* k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_3268(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(44,c,11)))){
C_save_and_reclaim((void *)f_3268,c,av);}
a=C_alloc(44);
t2=C_a_i_provide(&a,1,lf[0]);
t3=C_a_i_provide(&a,1,lf[1]);
t4=C_mutate(&lf[2] /* (set! chicken.compiler.c-backend#list-tabulate ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4281,tmp=(C_word)a,a+=2,tmp));
t5=lf[3] /* chicken.compiler.c-backend#output */ =C_SCHEME_FALSE;;
t6=C_mutate(&lf[4] /* (set! chicken.compiler.c-backend#gen ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4549,tmp=(C_word)a,a+=2,tmp));
t7=C_mutate(&lf[7] /* (set! chicken.compiler.c-backend#gen-list ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4592,tmp=(C_word)a,a+=2,tmp));
t8=C_mutate((C_word*)lf[9]+1 /* (set! chicken.compiler.c-backend#generate-code ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4701,tmp=(C_word)a,a+=2,tmp));
t9=C_mutate(&lf[224] /* (set! chicken.compiler.c-backend#toplevel ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9329,tmp=(C_word)a,a+=2,tmp));
t10=C_mutate(&lf[491] /* (set! chicken.compiler.c-backend#cleanup ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9345,tmp=(C_word)a,a+=2,tmp));
t11=C_mutate(&lf[341] /* (set! chicken.compiler.c-backend#make-variable-list ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9421,tmp=(C_word)a,a+=2,tmp));
t12=C_mutate(&lf[344] /* (set! chicken.compiler.c-backend#make-argument-list ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9438,tmp=(C_word)a,a+=2,tmp));
t13=C_mutate(&lf[288] /* (set! chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9512,tmp=(C_word)a,a+=2,tmp));
t14=C_mutate(&lf[604] /* (set! chicken.compiler.c-backend#generate-foreign-callback-header ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_10547,tmp=(C_word)a,a+=2,tmp));
t15=C_mutate((C_word*)lf[245]+1 /* (set! chicken.compiler.c-backend#foreign-type-declaration ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_10623,tmp=(C_word)a,a+=2,tmp));
t16=C_mutate(&lf[244] /* (set! chicken.compiler.c-backend#foreign-argument-conversion ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11717,tmp=(C_word)a,a+=2,tmp));
t17=C_mutate(&lf[239] /* (set! chicken.compiler.c-backend#foreign-result-conversion ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_12382,tmp=(C_word)a,a+=2,tmp));
t18=C_mutate(&lf[387] /* (set! chicken.compiler.c-backend#encode-literal ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13169,tmp=(C_word)a,a+=2,tmp));
t19=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t19;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}

/* loop in k13470 in k13466 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_3709(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_3709,4,t0,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3723,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:95: loop */
t6=t4;
t7=C_i_car(t3);
t8=C_u_i_cdr(t3);
t1=t6;
t2=t7;
t3=t8;
goto loop;}}

/* k3721 in loop in k13470 in k13466 in k13385 in k13292 in chicken.compiler.c-backend#encode-literal in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_3723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_3723,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.c-backend#list-tabulate in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4281(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_4281,3,t1,t2,t3);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4287,a[2]=t2,a[3]=t5,a[4]=t3,tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_4287(t7,t1,C_fix(0));}

/* loop in chicken.compiler.c-backend#list-tabulate in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4287(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_4287,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4301,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:190: proc */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}}

/* k4299 in loop in chicken.compiler.c-backend#list-tabulate in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4301(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_4301,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4305,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:190: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4287(t3,t2,C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* k4303 in k4299 in loop in chicken.compiler.c-backend#list-tabulate in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4305(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_4305,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a4460 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in ... */
static void C_ccall f_4461(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_4461,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a4472 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_4473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_4473,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.c-backend#gen in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_4549,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+5);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4569,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_4569(t6,t1,t2);}

/* for-each-loop642 in chicken.compiler.c-backend#gen in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4569(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_4569,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4579,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=C_eqp(C_SCHEME_TRUE,t4);
if(C_truep(t5)){
/* c-backend.scm:64: scheme#newline */
t6=*((C_word*)lf[5]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t3;
av2[2]=lf[3];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
/* c-backend.scm:65: scheme#display */
t6=*((C_word*)lf[6]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[3];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k4577 in for-each-loop642 in chicken.compiler.c-backend#gen in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_4579,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_4569(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.compiler.c-backend#gen-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4592(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_4592,2,t1,t2);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4601,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:71: chicken.base#intersperse */
t4=C_fast_retrieve(lf[8]);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=C_make_character(32);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k4599 in chicken.compiler.c-backend#gen-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4601(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_4601,c,av);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4606,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_4606(t5,((C_word*)t0)[2],t1);}

/* for-each-loop662 in k4599 in chicken.compiler.c-backend#gen-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4606(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_4606,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4616,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:70: scheme#display */
t4=*((C_word*)lf[6]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
av2[3]=lf[3];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k4614 in for-each-loop662 in k4599 in chicken.compiler.c-backend#gen-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4616(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_4616,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_4606(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k4655 in chicken.compiler.c-backend#toplevel in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_4657,c,av);}
/* c-backend.scm:76: chicken.internal#string->c-identifier */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[512]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[512]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k4661 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4663(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(2,c,4)))){
C_save_and_reclaim((void *)f_4663,c,av);}
a=C_alloc(2);
t2=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4668,tmp=(C_word)a,a+=2,tmp);
/* c-backend.scm:87: chicken.sort#sort! */
t3=C_fast_retrieve(lf[668]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)((C_word*)t0)[3])[1];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a4667 in k4661 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_4668,c,av);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4676,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:87: scheme#symbol->string */
t5=*((C_word*)lf[633]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k4674 in a4667 in k4661 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4676(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_4676,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4680,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:88: scheme#symbol->string */
t3=*((C_word*)lf[633]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k4678 in k4674 in a4667 in k4661 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_4680,c,av);}
/* c-backend.scm:87: scheme#string<? */
t2=*((C_word*)lf[667]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a4689 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4690(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_4690,c,av);}
a=C_alloc(6);
t4=C_a_i_cons(&a,2,t2,t3);
t5=C_a_i_cons(&a,2,t4,((C_word*)((C_word*)t0)[2])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10=av[10];
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(c!=11) C_bad_argc_2(c,11,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,4)))){
C_save_and_reclaim((void *)f_4701,c,av);}
a=C_alloc(20);
t11=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_4705,a[2]=t4,a[3]=t7,a[4]=t6,a[5]=t2,a[6]=t3,a[7]=t9,a[8]=t5,a[9]=t1,a[10]=t10,tmp=(C_word)a,a+=11,tmp);
t12=C_SCHEME_END_OF_LIST;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4663,a[2]=t11,a[3]=t13,tmp=(C_word)a,a+=4,tmp);
t15=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4690,a[2]=t13,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:81: chicken.internal#hash-table-for-each */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[669]);
C_word *av2=av;
av2[0]=*((C_word*)lf[669]+1);
av2[1]=t14;
av2[2]=t15;
av2[3]=t4;
tp(4,av2);}}

/* k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_4705,c,av);}
a=C_alloc(20);
t2=C_SCHEME_FALSE;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_4708,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=t1,a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],tmp=(C_word)a,a+=13,tmp);
t5=C_fast_retrieve(lf[665]);
t6=C_a_i_fixnum_plus(&a,2,C_fast_retrieve(lf[665]),C_fix(1));
/* c-backend.scm:98: chicken.flonum#flonum-print-precision */
t7=C_fast_retrieve(lf[666]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t4;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4708(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(82,c,5)))){
C_save_and_reclaim((void *)f_4708,c,av);}
a=C_alloc(82);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_SCHEME_UNDEFINED;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_SCHEME_UNDEFINED;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=C_SCHEME_UNDEFINED;
t23=(*a=C_VECTOR_TYPE|1,a[1]=t22,tmp=(C_word)a,a+=2,tmp);
t24=C_SCHEME_UNDEFINED;
t25=(*a=C_VECTOR_TYPE|1,a[1]=t24,tmp=(C_word)a,a+=2,tmp);
t26=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4710,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp));
t27=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4722,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t28=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7145,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp));
t29=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7304,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp));
t30=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7508,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp));
t31=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7686,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp));
t32=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7807,a[2]=t19,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp));
t33=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7861,a[2]=t17,tmp=(C_word)a,a+=3,tmp));
t34=C_set_block_item(t19,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8144,a[2]=t21,tmp=(C_word)a,a+=3,tmp));
t35=C_set_block_item(t21,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8298,a[2]=t23,tmp=(C_word)a,a+=3,tmp));
t36=C_set_block_item(t23,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8372,tmp=(C_word)a,a+=2,tmp));
t37=C_set_block_item(t25,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8384,a[2]=((C_word*)t0)[3],a[3]=t5,a[4]=((C_word*)t0)[6],a[5]=t15,a[6]=t17,a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp));
t38=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9088,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[8],a[6]=t25,a[7]=((C_word*)t0)[12],a[8]=t13,a[9]=((C_word*)t0)[9],a[10]=t11,a[11]=t9,a[12]=t7,tmp=(C_word)a,a+=13,tmp);
/* c-backend.scm:975: chicken.compiler.support#debugging */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[492]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[492]+1);
av2[1]=t38;
av2[2]=lf[663];
av2[3]=lf[664];
tp(4,av2);}}

/* find-lambda in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4710(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_4710,3,t0,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4714,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:103: chicken.internal#hash-table-ref */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[12]);
C_word av2[4];
av2[0]=*((C_word*)lf[12]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
tp(4,av2);}}

/* k4712 in find-lambda in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4714(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_4714,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* c-backend.scm:104: chicken.compiler.support#bomb */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[10]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[10]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[11];
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}}

/* expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4722(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(27,0,5)))){
C_save_and_reclaim_args((void *)trf_4722,5,t0,t1,t2,t3,t4);}
a=C_alloc(27);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_4725,a[2]=t6,a[3]=t4,a[4]=t12,a[5]=t8,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp));
t14=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6937,a[2]=t6,tmp=(C_word)a,a+=3,tmp));
t15=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6973,a[2]=t10,tmp=(C_word)a,a+=3,tmp));
t16=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7016,a[2]=t6,a[3]=t10,a[4]=t4,tmp=(C_word)a,a+=5,tmp));
/* c-backend.scm:601: expr */
t17=((C_word*)t6)[1];
f_4725(t17,t1,t2,t3);}

/* expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4725(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_4725,4,t0,t1,t2,t3);}
a=C_alloc(11);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_4729,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=t2,tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:110: chicken.compiler.support#node-subexpressions */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[268]);
C_word av2[3];
av2[0]=*((C_word*)lf[268]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}

/* k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_4729,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_4732,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* c-backend.scm:111: chicken.compiler.support#node-parameters */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[136]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[136]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
tp(3,av2);}}

/* k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_4732,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_4735,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* c-backend.scm:112: chicken.compiler.support#node-class */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[186]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[186]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[11];
tp(3,av2);}}

/* k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,6)))){
C_save_and_reclaim((void *)f_4735,c,av);}
a=C_alloc(24);
t2=C_eqp(t1,lf[13]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=C_eqp(t3,lf[14]);
if(C_truep(t4)){
if(C_truep(C_i_cadr(((C_word*)t0)[2]))){
/* c-backend.scm:116: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[15];
f_4549(3,av2);}}
else{
/* c-backend.scm:116: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[16];
f_4549(3,av2);}}}
else{
t5=C_eqp(t3,lf[17]);
if(C_truep(t5)){
t6=C_i_cadr(((C_word*)t0)[2]);
/* c-backend.scm:117: gen */
t7=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[18];
av2[3]=C_fix(C_character_code(t6));
av2[4]=C_make_character(41);
f_4549(5,av2);}}
else{
t6=C_eqp(t3,lf[19]);
if(C_truep(t6)){
/* c-backend.scm:118: gen */
t7=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[20];
f_4549(3,av2);}}
else{
t7=C_eqp(t3,lf[21]);
if(C_truep(t7)){
/* c-backend.scm:119: gen */
t8=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[22];
av2[3]=C_i_cadr(((C_word*)t0)[2]);
av2[4]=C_make_character(41);
f_4549(5,av2);}}
else{
t8=C_eqp(t3,lf[23]);
if(C_truep(t8)){
/* c-backend.scm:120: gen */
t9=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[24];
f_4549(3,av2);}}
else{
t9=C_eqp(t3,lf[25]);
if(C_truep(t9)){
/* c-backend.scm:121: gen */
t10=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t10;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
f_4549(3,av2);}}
else{
/* c-backend.scm:122: chicken.compiler.support#bomb */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[10]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[10]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=lf[27];
tp(3,av2);}}}}}}}}
else{
t3=C_eqp(t1,lf[28]);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[2]);
if(C_truep(C_i_vectorp(t4))){
/* c-backend.scm:127: gen */
t5=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[29];
av2[3]=C_i_vector_ref(t4,C_fix(0));
av2[4]=lf[30];
f_4549(5,av2);}}
else{
/* c-backend.scm:128: gen */
t5=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[31];
av2[3]=C_i_car(((C_word*)t0)[2]);
av2[4]=C_make_character(93);
f_4549(5,av2);}}}
else{
t4=C_eqp(t1,lf[32]);
if(C_truep(t4)){
t5=C_i_car(((C_word*)t0)[2]);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4873,a[2]=t5,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:132: gen */
t7=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[35];
f_4549(3,av2);}}
else{
t5=C_eqp(t1,lf[36]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_4906,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:140: gen */
t7=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[39];
f_4549(4,av2);}}
else{
t6=C_eqp(t1,lf[40]);
if(C_truep(t6)){
/* c-backend.scm:149: gen */
t7=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[41];
av2[3]=C_i_car(((C_word*)t0)[2]);
f_4549(4,av2);}}
else{
t7=C_eqp(t1,lf[42]);
if(C_truep(t7)){
t8=C_i_car(((C_word*)t0)[2]);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4964,a[2]=t10,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp));
t12=((C_word*)t10)[1];
f_4964(t12,((C_word*)t0)[3],((C_word*)t0)[5],((C_word*)t0)[6],t8);}
else{
t8=C_eqp(t1,lf[43]);
if(C_truep(t8)){
t9=C_i_car(((C_word*)t0)[2]);
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5012,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:162: gen */
t11=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(102);
av2[4]=t9;
av2[5]=C_make_character(61);
f_4549(6,av2);}}
else{
t9=C_eqp(t1,lf[44]);
if(C_truep(t9)){
/* c-backend.scm:168: gen */
t10=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t10;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(102);
av2[3]=C_i_car(((C_word*)t0)[2]);
f_4549(4,av2);}}
else{
t10=C_eqp(t1,lf[45]);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5051,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:171: gen */
t12=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t12;
av2[1]=t11;
av2[2]=lf[47];
f_4549(3,av2);}}
else{
t11=C_eqp(t1,lf[48]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5070,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:176: gen */
t13=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t13;
av2[1]=t12;
av2[2]=lf[50];
f_4549(3,av2);}}
else{
t12=C_eqp(t1,lf[51]);
if(C_truep(t12)){
t13=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5089,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:181: gen */
t14=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t14;
av2[1]=t13;
av2[2]=lf[53];
f_4549(3,av2);}}
else{
t13=C_eqp(t1,lf[54]);
if(C_truep(t13)){
t14=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5116,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:186: chicken.compiler.core#lambda-literal-argument-count */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[63]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[63]+1);
av2[1]=t14;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}
else{
t14=C_eqp(t1,lf[64]);
if(C_truep(t14)){
t15=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5156,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:195: chicken.compiler.core#lambda-literal-argument-count */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[63]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[63]+1);
av2[1]=t15;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}
else{
t15=C_eqp(t1,lf[70]);
if(C_truep(t15)){
t16=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5196,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:204: chicken.compiler.core#lambda-literal-argument-count */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[63]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[63]+1);
av2[1]=t16;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}
else{
t16=C_eqp(t1,lf[75]);
if(C_truep(t16)){
t17=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5236,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:213: gen */
t18=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t18;
av2[1]=t17;
av2[2]=lf[77];
f_4549(3,av2);}}
else{
t17=C_eqp(t1,lf[78]);
if(C_truep(t17)){
t18=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5255,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:218: gen */
t19=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t19;
av2[1]=t18;
av2[2]=lf[79];
f_4549(3,av2);}}
else{
t18=C_eqp(t1,lf[80]);
if(C_truep(t18)){
t19=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5288,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:225: gen */
t20=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t20;
av2[1]=t19;
av2[2]=lf[83];
f_4549(3,av2);}}
else{
t19=C_eqp(t1,lf[84]);
if(C_truep(t19)){
t20=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5325,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:232: gen */
t21=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t21;
av2[1]=t20;
av2[2]=lf[86];
f_4549(3,av2);}}
else{
t20=C_eqp(t1,lf[87]);
if(C_truep(t20)){
t21=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5354,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:239: gen */
t22=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t22;
av2[1]=t21;
av2[2]=lf[89];
f_4549(3,av2);}}
else{
t21=C_eqp(t1,lf[90]);
if(C_truep(t21)){
t22=C_i_car(((C_word*)t0)[2]);
t23=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5386,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[5],a[5]=t22,a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:247: gen */
t24=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t24;
av2[1]=t23;
av2[2]=lf[97];
av2[3]=t22;
av2[4]=C_make_character(44);
f_4549(5,av2);}}
else{
t22=C_eqp(t1,lf[98]);
if(C_truep(t22)){
t23=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5460,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:257: gen */
t24=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t24;
av2[1]=t23;
av2[2]=lf[100];
f_4549(3,av2);}}
else{
t23=C_eqp(t1,lf[101]);
if(C_truep(t23)){
/* c-backend.scm:261: gen */
t24=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t24;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(116);
av2[3]=C_i_car(((C_word*)t0)[2]);
f_4549(4,av2);}}
else{
t24=C_eqp(t1,lf[102]);
if(C_truep(t24)){
t25=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5492,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:264: gen */
t26=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t26;
av2[1]=t25;
av2[2]=C_make_character(116);
av2[3]=C_i_car(((C_word*)t0)[2]);
av2[4]=C_make_character(61);
f_4549(5,av2);}}
else{
t25=C_eqp(t1,lf[103]);
if(C_truep(t25)){
t26=C_i_car(((C_word*)t0)[2]);
t27=C_i_cadr(((C_word*)t0)[2]);
if(C_truep(C_i_caddr(((C_word*)t0)[2]))){
if(C_truep(t27)){
/* c-backend.scm:273: gen */
t28=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t28;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[104];
av2[3]=t26;
av2[4]=lf[105];
f_4549(5,av2);}}
else{
t28=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5534,a[2]=((C_word*)t0)[3],a[3]=t26,tmp=(C_word)a,a+=4,tmp);
t29=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5538,a[2]=t28,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:275: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[110]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[110]+1);
av2[1]=t29;
av2[2]=C_i_cadddr(((C_word*)t0)[2]);
tp(3,av2);}}}
else{
if(C_truep(t27)){
/* c-backend.scm:277: gen */
t28=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t28;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[111];
av2[3]=t26;
av2[4]=lf[112];
f_4549(5,av2);}}
else{
/* c-backend.scm:278: gen */
t28=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t28;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[113];
av2[3]=t26;
av2[4]=lf[114];
f_4549(5,av2);}}}}
else{
t26=C_eqp(t1,lf[115]);
if(C_truep(t26)){
t27=C_i_car(((C_word*)t0)[2]);
t28=C_i_cadr(((C_word*)t0)[2]);
t29=C_i_caddr(((C_word*)t0)[2]);
t30=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5569,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t29,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t28)){
/* c-backend.scm:285: gen */
t31=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t31;
av2[1]=t30;
av2[2]=lf[121];
av2[3]=t27;
av2[4]=lf[122];
f_4549(5,av2);}}
else{
/* c-backend.scm:286: gen */
t31=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t31;
av2[1]=t30;
av2[2]=lf[123];
av2[3]=t27;
av2[4]=lf[124];
f_4549(5,av2);}}}
else{
t27=C_eqp(t1,lf[125]);
if(C_truep(t27)){
t28=C_i_car(((C_word*)t0)[2]);
t29=C_i_cadr(((C_word*)t0)[2]);
t30=C_i_caddr(((C_word*)t0)[2]);
if(C_truep(t29)){
t31=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5617,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t32=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5631,a[2]=t31,a[3]=t28,tmp=(C_word)a,a+=4,tmp);
t33=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5635,a[2]=t32,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:297: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[110]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[110]+1);
av2[1]=t33;
av2[2]=t30;
tp(3,av2);}}
else{
t31=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5638,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t32=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5652,a[2]=t31,a[3]=t28,tmp=(C_word)a,a+=4,tmp);
t33=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5656,a[2]=t32,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:302: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[110]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[110]+1);
av2[1]=t33;
av2[2]=t30;
tp(3,av2);}}}
else{
t28=C_eqp(t1,lf[132]);
if(C_truep(t28)){
/* c-backend.scm:306: gen */
t29=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t29;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[133];
f_4549(3,av2);}}
else{
t29=C_eqp(t1,lf[134]);
if(C_truep(t29)){
t30=C_i_cdr(((C_word*)t0)[5]);
t31=C_i_length(t30);
t32=C_a_i_fixnum_plus(&a,2,t31,C_fix(1));
t33=C_i_car(((C_word*)t0)[2]);
t34=C_i_cadr(((C_word*)t0)[2]);
t35=C_i_cddr(((C_word*)t0)[2]);
t36=C_i_pairp(t35);
t37=(C_truep(t36)?C_i_caddr(((C_word*)t0)[2]):C_SCHEME_FALSE);
t38=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_5693,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=t32,a[6]=((C_word*)t0)[8],a[7]=t30,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[4],a[10]=t31,a[11]=((C_word*)t0)[7],a[12]=((C_word*)t0)[9],a[13]=t34,a[14]=t37,a[15]=t33,a[16]=((C_word*)t0)[10],a[17]=((C_word*)t0)[11],a[18]=t36,tmp=(C_word)a,a+=19,tmp);
/* c-backend.scm:317: chicken.compiler.support#source-info->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[200]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[200]+1);
av2[1]=t38;
av2[2]=t37;
tp(3,av2);}}
else{
t30=C_eqp(t1,lf[201]);
if(C_truep(t30)){
t31=C_i_length(((C_word*)t0)[5]);
t32=C_a_i_fixnum_plus(&a,2,t31,C_fix(1));
t33=C_i_car(((C_word*)t0)[2]);
t34=C_i_cadr(((C_word*)t0)[2]);
t35=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_6203,a[2]=t33,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[3],a[6]=t31,a[7]=((C_word*)t0)[5],a[8]=t32,a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[9],a[11]=t34,tmp=(C_word)a,a+=12,tmp);
/* c-backend.scm:415: chicken.compiler.core#lambda-literal-closure-size */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[199]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[199]+1);
av2[1]=t35;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}
else{
t31=C_eqp(t1,lf[205]);
if(C_truep(t31)){
t32=C_i_cdr(((C_word*)t0)[5]);
t33=C_i_length(t32);
t34=C_a_i_fixnum_plus(&a,2,t33,C_fix(1));
t35=C_i_car(((C_word*)t0)[2]);
t36=C_i_caddr(((C_word*)t0)[2]);
t37=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_6363,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=t32,a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[4],a[9]=t36,a[10]=t35,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* c-backend.scm:442: chicken.compiler.support#source-info->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[200]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[200]+1);
av2[1]=t37;
av2[2]=t36;
tp(3,av2);}}
else{
t32=C_eqp(t1,lf[217]);
if(C_truep(t32)){
/* c-backend.scm:468: gen */
t33=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t33;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[218];
av2[3]=C_i_car(((C_word*)t0)[2]);
av2[4]=lf[219];
f_4549(5,av2);}}
else{
t33=C_eqp(t1,lf[220]);
if(C_truep(t33)){
t34=C_i_length(((C_word*)t0)[5]);
t35=C_a_i_fixnum_plus(&a,2,t34,C_fix(1));
t36=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6500,a[2]=((C_word*)t0)[3],a[3]=t35,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:475: gen */
t37=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t37;
av2[1]=t36;
av2[2]=C_make_character(123);
f_4549(3,av2);}}
else{
t34=C_eqp(t1,lf[226]);
if(C_truep(t34)){
t35=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6523,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:480: gen */
t36=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t36;
av2[1]=t35;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[228];
f_4549(4,av2);}}
else{
t35=C_eqp(t1,lf[229]);
if(C_truep(t35)){
t36=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6542,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:485: gen */
t37=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t37;
av2[1]=t36;
av2[2]=C_i_car(((C_word*)t0)[2]);
av2[3]=C_make_character(40);
f_4549(4,av2);}}
else{
t36=C_eqp(t1,lf[230]);
if(C_truep(t36)){
t37=C_i_car(((C_word*)t0)[2]);
if(C_truep(((C_word*)((C_word*)t0)[10])[1])){
/* c-backend.scm:490: gen */
t38=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t38;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[231];
av2[3]=t37;
av2[4]=lf[232];
av2[5]=lf[233];
av2[6]=lf[234];
f_4549(7,av2);}}
else{
/* c-backend.scm:490: gen */
t38=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t38;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[231];
av2[3]=t37;
av2[4]=lf[232];
av2[5]=lf[235];
av2[6]=lf[234];
f_4549(7,av2);}}}
else{
t37=C_eqp(t1,lf[236]);
if(C_truep(t37)){
t38=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6578,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:494: gen */
t39=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t39;
av2[1]=t38;
av2[2]=C_i_car(((C_word*)t0)[2]);
av2[3]=lf[237];
av2[4]=C_i_length(((C_word*)t0)[5]);
f_4549(5,av2);}}
else{
t38=C_eqp(t1,lf[238]);
if(C_truep(t38)){
t39=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6614,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:502: foreign-result-conversion */
f_12382(t39,C_i_cadr(((C_word*)t0)[2]),lf[240]);}
else{
t39=C_eqp(t1,lf[241]);
if(C_truep(t39)){
t40=C_i_cadr(((C_word*)t0)[2]);
t41=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6634,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t42=C_i_car(((C_word*)t0)[2]);
t43=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6652,a[2]=t41,a[3]=t42,a[4]=t40,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:506: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t43;
av2[2]=t40;
av2[3]=lf[246];
tp(4,av2);}}
else{
t40=C_eqp(t1,lf[247]);
if(C_truep(t40)){
t41=C_i_car(((C_word*)t0)[2]);
t42=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6668,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t43=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6682,a[2]=t42,a[3]=t41,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:512: foreign-result-conversion */
f_12382(t43,t41,lf[252]);}
else{
t41=C_eqp(t1,lf[253]);
if(C_truep(t41)){
t42=C_i_car(((C_word*)t0)[2]);
t43=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6698,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t42,tmp=(C_word)a,a+=7,tmp);
t44=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6726,a[2]=t43,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:518: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t44;
av2[2]=t42;
av2[3]=lf[258];
tp(4,av2);}}
else{
t42=C_eqp(t1,lf[259]);
if(C_truep(t42)){
t43=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6735,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:525: gen */
t44=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t44;
av2[1]=t43;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[263];
f_4549(4,av2);}}
else{
t43=C_eqp(t1,lf[264]);
if(C_truep(t43)){
t44=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6814,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:540: gen */
t45=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t45;
av2[1]=t44;
av2[2]=lf[266];
f_4549(3,av2);}}
else{
t44=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6851,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:548: chicken.compiler.support#node-class */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[186]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[186]+1);
av2[1]=t44;
av2[2]=((C_word*)t0)[12];
tp(3,av2);}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}

/* k4871 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4873(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_4873,c,av);}
a=C_alloc(3);
if(C_truep(C_i_nanp(((C_word*)t0)[2]))){
/* c-backend.scm:133: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[33];
f_4549(3,av2);}}
else{
if(C_truep(C_i_infinitep(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4887,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_negativep(((C_word*)t0)[2]))){
/* c-backend.scm:135: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(45);
f_4549(3,av2);}}
else{
/* c-backend.scm:136: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[34];
f_4549(3,av2);}}}
else{
/* c-backend.scm:137: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[2];
f_4549(3,av2);}}}}

/* k4885 in k4871 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_4887,c,av);}
/* c-backend.scm:136: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[34];
f_4549(3,av2);}}

/* k4904 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4906(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_4906,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_4909,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:141: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k4907 in k4904 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4909(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_4909,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_4912,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:142: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[38];
f_4549(3,av2);}}

/* k4910 in k4907 in k4904 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4912(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_4912,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_4915,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:143: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k4913 in k4910 in k4907 in k4904 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4915(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_4915,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_4918,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:144: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(125);
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[37];
f_4549(5,av2);}}

/* k4916 in k4913 in k4910 in k4907 in k4904 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_4918,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4921,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:145: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_caddr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k4919 in k4916 in k4913 in k4910 in k4907 in k4904 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_4921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_4921,c,av);}
/* c-backend.scm:146: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(125);
f_4549(3,av2);}}

/* loop in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_4964(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,5)))){
C_save_and_reclaim_args((void *)trf_4964,5,t0,t1,t2,t3,t4);}
a=C_alloc(8);
if(C_truep(C_i_greaterp(t4,C_fix(0)))){
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_4974,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=((C_word*)t0)[2],a[6]=t1,a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:154: gen */
t6=lf[4];{
C_word av2[6];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(116);
av2[4]=t3;
av2[5]=C_make_character(61);
f_4549(6,av2);}}
else{
/* c-backend.scm:158: expr */
t5=((C_word*)((C_word*)t0)[3])[1];
f_4725(t5,t1,C_i_car(t2),t3);}}

/* k4972 in loop in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4974(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_4974,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_4977,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:155: expr */
t3=((C_word*)((C_word*)t0)[7])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[2]),((C_word*)t0)[3]);}

/* k4975 in k4972 in loop in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_4977,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_4980,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:156: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k4978 in k4975 in k4972 in loop in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_4980(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,4)))){
C_save_and_reclaim((void *)f_4980,c,av);}
a=C_alloc(58);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_s_a_i_plus(&a,2,((C_word*)t0)[3],C_fix(1));
t4=C_s_a_i_minus(&a,2,((C_word*)t0)[4],C_fix(1));
/* c-backend.scm:157: loop */
t5=((C_word*)((C_word*)t0)[5])[1];
f_4964(t5,((C_word*)t0)[6],t2,t3,t4);}

/* k5010 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_5012,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5015,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:163: expr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5013 in k5010 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5015(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_5015,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5018,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:164: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k5016 in k5013 in k5010 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5018(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5018,c,av);}
/* c-backend.scm:165: expr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_4725(t2,((C_word*)t0)[3],C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5049 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5051(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5051,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5054,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:172: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5052 in k5049 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5054(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5054,c,av);}
/* c-backend.scm:173: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[46];
f_4549(3,av2);}}

/* k5068 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5070(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5070,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5073,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:177: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5071 in k5068 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5073,c,av);}
/* c-backend.scm:178: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[49];
f_4549(3,av2);}}

/* k5087 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5089(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_5089,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5092,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:182: expr */
t3=((C_word*)((C_word*)t0)[4])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[5]),((C_word*)t0)[6]);}

/* k5090 in k5087 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_5092,c,av);}
a=C_alloc(29);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_s_a_i_plus(&a,2,t2,C_fix(1));
/* c-backend.scm:183: gen */
t4=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[52];
av2[3]=t3;
av2[4]=C_make_character(93);
f_4549(5,av2);}}

/* k5114 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5116(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_5116,c,av);}
a=C_alloc(9);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5122,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5141,a[2]=t3,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:188: chicken.compiler.core#lambda-literal-customizable */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[62]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[62]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k5120 in k5114 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_5122(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,6)))){
C_save_and_reclaim_args((void *)trf_5122,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* c-backend.scm:191: gen */
t3=lf[4];{
C_word av2[7];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[55];
av2[3]=t2;
av2[4]=lf[56];
av2[5]=((C_word*)t0)[3];
av2[6]=lf[57];
f_4549(7,av2);}}
else{
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:192: gen */
t3=lf[4];{
C_word av2[7];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[58];
av2[3]=t2;
av2[4]=lf[59];
av2[5]=((C_word*)t0)[2];
av2[6]=lf[60];
f_4549(7,av2);}}}

/* k5139 in k5114 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_5141,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5144,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
t3=((C_word*)t0)[2];
f_5122(t3,C_i_not(t1));}
else{
/* c-backend.scm:189: chicken.compiler.core#lambda-literal-direct */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[61]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[61]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k5142 in k5139 in k5114 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5144,c,av);}
t2=((C_word*)t0)[2];
f_5122(t2,C_i_not(t1));}

/* k5154 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5156(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_5156,c,av);}
a=C_alloc(9);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5162,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5181,a[2]=t3,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:197: chicken.compiler.core#lambda-literal-customizable */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[62]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[62]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k5160 in k5154 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_5162(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,6)))){
C_save_and_reclaim_args((void *)trf_5162,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* c-backend.scm:200: gen */
t3=lf[4];{
C_word av2[5];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[65];
av2[3]=t2;
av2[4]=lf[66];
f_4549(5,av2);}}
else{
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:201: gen */
t3=lf[4];{
C_word av2[7];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[67];
av2[3]=t2;
av2[4]=lf[68];
av2[5]=((C_word*)t0)[2];
av2[6]=lf[69];
f_4549(7,av2);}}}

/* k5179 in k5154 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5181(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_5181,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5184,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
t3=((C_word*)t0)[2];
f_5162(t3,C_i_not(t1));}
else{
/* c-backend.scm:198: chicken.compiler.core#lambda-literal-direct */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[61]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[61]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k5182 in k5179 in k5154 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5184(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5184,c,av);}
t2=((C_word*)t0)[2];
f_5162(t2,C_i_not(t1));}

/* k5194 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5196(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_5196,c,av);}
a=C_alloc(9);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5202,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5221,a[2]=t3,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:206: chicken.compiler.core#lambda-literal-customizable */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[62]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[62]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k5200 in k5194 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_5202(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,4)))){
C_save_and_reclaim_args((void *)trf_5202,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* c-backend.scm:209: gen */
t3=lf[4];{
C_word av2[5];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[71];
av2[3]=t2;
av2[4]=lf[72];
f_4549(5,av2);}}
else{
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:210: gen */
t3=lf[4];{
C_word av2[5];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[73];
av2[3]=t2;
av2[4]=lf[74];
f_4549(5,av2);}}}

/* k5219 in k5194 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5221(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_5221,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5224,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
t3=((C_word*)t0)[2];
f_5202(t3,C_i_not(t1));}
else{
/* c-backend.scm:207: chicken.compiler.core#lambda-literal-direct */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[61]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[61]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k5222 in k5219 in k5194 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5224(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5224,c,av);}
t2=((C_word*)t0)[2];
f_5202(t2,C_i_not(t1));}

/* k5234 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5236(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5236,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5239,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:214: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5237 in k5234 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5239(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5239,c,av);}
/* c-backend.scm:215: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[76];
f_4549(3,av2);}}

/* k5253 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_5255,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5258,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:219: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5256 in k5253 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_5258,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5261,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:220: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(44);
av2[3]=C_i_car(((C_word*)t0)[6]);
av2[4]=C_make_character(44);
f_4549(5,av2);}}

/* k5259 in k5256 in k5253 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5261(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5261,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5264,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:221: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5262 in k5259 in k5256 in k5253 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5264(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5264,c,av);}
/* c-backend.scm:222: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k5286 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5288(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_5288,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5291,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:226: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5289 in k5286 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5291(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(35,c,4)))){
C_save_and_reclaim((void *)f_5291,c,av);}
a=C_alloc(35);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5294,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_i_car(((C_word*)t0)[6]);
t4=C_s_a_i_plus(&a,2,t3,C_fix(1));
/* c-backend.scm:227: gen */
t5=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[81];
av2[3]=t4;
av2[4]=lf[82];
f_4549(5,av2);}}

/* k5292 in k5289 in k5286 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5294,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5297,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:228: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5295 in k5292 in k5289 in k5286 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5297,c,av);}
/* c-backend.scm:229: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k5323 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5325(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_5325,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5328,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:233: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5326 in k5323 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_5328,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5331,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:234: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[85];
f_4549(3,av2);}}

/* k5329 in k5326 in k5323 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5331(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5331,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5334,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:235: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5332 in k5329 in k5326 in k5323 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5334,c,av);}
/* c-backend.scm:236: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k5352 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_5354,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5357,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:240: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5355 in k5352 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_5357,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5360,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:241: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[88];
f_4549(3,av2);}}

/* k5358 in k5355 in k5352 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5360(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5360,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5363,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:242: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5361 in k5358 in k5355 in k5352 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5363(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5363,c,av);}
/* c-backend.scm:243: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5386,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5387,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5400,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:253: list-tabulate */
f_4281(t3,((C_word*)t0)[5],*((C_word*)lf[96]+1));}

/* g821 in k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_5387(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_5387,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5391,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:250: gen */
t5=lf[4];{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[91];
av2[3]=t3;
av2[4]=lf[92];
f_4549(5,av2);}}

/* k5389 in g821 in k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5391(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5391,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5394,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:251: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k5392 in k5389 in g821 in k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5394(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5394,c,av);}
/* c-backend.scm:252: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(44);
f_4549(3,av2);}}

/* k5398 in k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5400,c,av);}
a=C_alloc(10);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[93]);
t3=C_i_check_list_2(t1,lf[93]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5409,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5416,a[2]=t6,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_5416(t8,t4,((C_word*)t0)[2],t1);}

/* k5407 in k5398 in k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_5409,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* c-backend.scm:254: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[94];
av2[3]=t2;
av2[4]=lf[95];
f_4549(5,av2);}}

/* for-each-loop820 in k5398 in k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_5416(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_5416,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5426,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:248: g821 */
t7=((C_word*)t0)[3];
f_5387(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k5424 in for-each-loop820 in k5398 in k5384 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5426,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_5416(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k5458 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5460,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5463,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:258: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5461 in k5458 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5463,c,av);}
/* c-backend.scm:259: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[99];
f_4549(3,av2);}}

/* k5490 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5492(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5492,c,av);}
/* c-backend.scm:265: expr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_4725(t2,((C_word*)t0)[3],C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5532 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5534(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_5534,c,av);}
/* c-backend.scm:274: gen */
t2=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[106];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[107];
av2[5]=t1;
av2[6]=lf[108];
f_4549(7,av2);}}

/* k5536 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5538(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5538,c,av);}
/* c-backend.scm:275: chicken.compiler.support#c-ify-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[109]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[109]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k5567 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_5569,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5572,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5586,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5590,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:287: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[110]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[110]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k5570 in k5567 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5572,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5575,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:288: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5573 in k5570 in k5567 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5575(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5575,c,av);}
/* c-backend.scm:289: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k5584 in k5567 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5586,c,av);}
/* c-backend.scm:287: gen */
t2=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[116];
av2[3]=t1;
av2[4]=lf[117];
f_4549(5,av2);}}

/* k5588 in k5567 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_5590,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14759,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:75: chicken.string#->string */
t3=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k5615 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5617,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5620,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:298: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5618 in k5615 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5620(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5620,c,av);}
/* c-backend.scm:299: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k5629 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5631(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_5631,c,av);}
/* c-backend.scm:296: gen */
t2=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[126];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[127];
av2[5]=t1;
av2[6]=lf[128];
f_4549(7,av2);}}

/* k5633 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_5635,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14764,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:75: chicken.string#->string */
t3=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k5636 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5638(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5638,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5641,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:303: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k5639 in k5636 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5641(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5641,c,av);}
/* c-backend.scm:304: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k5650 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_5652,c,av);}
/* c-backend.scm:301: gen */
t2=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[129];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[130];
av2[5]=t1;
av2[6]=lf[131];
f_4549(7,av2);}}

/* k5654 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_5656,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14769,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:75: chicken.string#->string */
t3=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_5693,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_5696,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=t1,a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
if(C_truep(((C_word*)t0)[18])){
t3=C_i_cdddr(((C_word*)t0)[2]);
t4=C_i_pairp(t3);
t5=t2;
f_5696(t5,(C_truep(t4)?C_i_cadddr(((C_word*)t0)[2]):C_SCHEME_FALSE));}
else{
t3=t2;
f_5696(t3,C_SCHEME_FALSE);}}

/* k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_5696(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,0,2)))){
C_save_and_reclaim_args((void *)trf_5696,2,t0,t1);}
a=C_alloc(25);
t2=(C_truep(t1)?C_i_car(C_i_cddddr(((C_word*)t0)[2])):C_SCHEME_FALSE);
t3=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_5702,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t1,a[9]=((C_word*)t0)[9],a[10]=t2,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
if(C_truep(t2)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6156,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6160,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:320: find-lambda */
t6=((C_word*)((C_word*)t0)[18])[1];
f_4710(t6,t5,t1);}
else{
t4=t3;
f_5702(t4,C_SCHEME_FALSE);}}

/* k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_5702(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(27,0,2)))){
C_save_and_reclaim_args((void *)trf_5702,2,t0,t1);}
a=C_alloc(27);
t2=C_u_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_5706,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=t1,a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
if(C_truep(((C_word*)t0)[15])){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6125,a[2]=((C_word*)t0)[16],a[3]=((C_word*)t0)[17],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fast_retrieve(lf[193]))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6145,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14782,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:74: chicken.string#->string */
t7=C_fast_retrieve(lf[120]);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[18];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6152,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14787,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:75: chicken.string#->string */
t7=C_fast_retrieve(lf[120]);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[18];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}
else{
t4=t3;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_5706(2,av2);}}}

/* k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_5706(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_5706,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_6122,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],tmp=(C_word)a,a+=16,tmp);
/* c-backend.scm:329: chicken.compiler.support#node-class */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[186]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[186]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k5713 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_5715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_5715,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5718,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:331: push-args */
t3=((C_word*)((C_word*)t0)[5])[1];
f_7016(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7],lf[137]);}

/* k5716 in k5713 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_5718(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_5718,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5721,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:332: chicken.compiler.support#node-parameters */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[136]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[136]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k5719 in k5716 in k5713 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_5721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_5721,c,av);}
/* c-backend.scm:333: gen */
t2=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=C_i_car(t1);
av2[4]=C_make_character(40);
av2[5]=((C_word*)t0)[3];
av2[6]=lf[135];
f_4549(7,av2);}}

/* k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_5737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,5)))){
C_save_and_reclaim((void *)f_5737,c,av);}
a=C_alloc(17);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5740,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* c-backend.scm:337: chicken.compiler.core#lambda-literal-temporaries */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[141]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[141]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
tp(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_5866,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[12],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[13],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)t0)[11])){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_5866(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5921,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[14],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:352: gen */
t4=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(116);
av2[4]=((C_word*)t0)[3];
av2[5]=C_make_character(61);
f_4549(6,av2);}}}}

/* k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_5740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_5740,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5743,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5859,a[2]=t1,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:338: list-tabulate */
f_4281(t2,((C_word*)t0)[7],t3);}

/* k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_5743(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_5743,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5744,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_i_check_list_2(t1,lf[93]);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5760,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=t1,a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5822,a[2]=t6,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_5822(t8,t4,((C_word*)t0)[8],t1);}

/* g909 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_fcall f_5744(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_5744,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5748,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:341: gen */
t5=lf[4];{
C_word av2[6];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(116);
av2[4]=t3;
av2[5]=C_make_character(61);
f_4549(6,av2);}}

/* k5746 in g909 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_5748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5748,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5751,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:342: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k5749 in k5746 in g909 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_5751(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5751,c,av);}
/* c-backend.scm:343: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k5758 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_5760,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5768,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:347: list-tabulate */
f_4281(t2,((C_word*)t0)[6],*((C_word*)lf[96]+1));}

/* k5766 in k5758 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_5768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5768,c,av);}
a=C_alloc(10);
t2=C_i_check_list_2(t1,lf[93]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5774,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5785,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_5785(t7,t3,((C_word*)t0)[5],t1);}

/* k5772 in k5766 in k5758 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_5774(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_5774,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5777,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[3])){
/* c-backend.scm:349: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[138];
f_4549(4,av2);}}
else{
/* c-backend.scm:348: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[139];
av2[4]=((C_word*)t0)[4];
av2[5]=C_make_character(59);
f_4549(6,av2);}}}

/* k5775 in k5772 in k5766 in k5758 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_ccall f_5777(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5777,c,av);}
/* c-backend.scm:349: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[138];
f_4549(4,av2);}}

/* for-each-loop919 in k5766 in k5758 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_fcall f_5785(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,7)))){
C_save_and_reclaim_args((void *)trf_5785,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5795,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:346: gen */
t7=lf[4];{
C_word av2[8];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(116);
av2[4]=C_slot(t3,C_fix(0));
av2[5]=lf[140];
av2[6]=C_slot(t2,C_fix(0));
av2[7]=C_make_character(59);
f_4549(8,av2);}}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k5793 in for-each-loop919 in k5766 in k5758 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_ccall f_5795(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5795,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_5785(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* for-each-loop908 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_fcall f_5822(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_5822,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5832,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:339: g909 */
t7=((C_word*)t0)[3];
f_5744(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k5830 in for-each-loop908 in k5741 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_5832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5832,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_5822(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a5858 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_5859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_5859,c,av);}
a=C_alloc(33);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)va15400,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=t3;
va15400(t4,C_s_a_i_plus(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]));}

/* k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_5866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5866,c,av);}
a=C_alloc(10);
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5872,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:356: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[8];
av2[4]=C_make_character(40);
f_4549(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5887,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* c-backend.scm:361: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(123);
f_4549(3,av2);}}}

/* k5870 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_5872(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_5872,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5875,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14777,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:358: expr-args */
t4=((C_word*)((C_word*)t0)[3])[1];
f_6937(t4,t3,((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
/* c-backend.scm:357: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(116);
av2[3]=((C_word*)t0)[5];
av2[4]=C_make_character(44);
f_4549(5,av2);}}}

/* k5873 in k5870 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5875(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5875,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5878,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:358: expr-args */
t3=((C_word*)((C_word*)t0)[3])[1];
f_6937(t3,t2,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k5876 in k5873 in k5870 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_5878(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5878,c,av);}
/* c-backend.scm:359: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[142];
f_4549(3,av2);}}

/* k5885 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_5887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_5887,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5890,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5906,a[2]=((C_word*)t0)[6],a[3]=t2,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_not(((C_word*)t0)[9]))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5917,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[8];
av2[3]=C_fix(10);
tp(4,av2);}}
else{
/* c-backend.scm:362: push-args */
t4=((C_word*)((C_word*)t0)[6])[1];
f_7016(t4,t2,((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}}

/* k5888 in k5885 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5890(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_5890,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5893,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:363: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[5];
av2[4]=C_make_character(40);
f_4549(5,av2);}}

/* k5891 in k5888 in k5885 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_5893(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5893,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5896,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[3])){
/* c-backend.scm:365: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[143];
f_4549(3,av2);}}
else{
/* c-backend.scm:364: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_make_character(44);
f_4549(4,av2);}}}

/* k5894 in k5891 in k5888 in k5885 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_5896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5896,c,av);}
/* c-backend.scm:365: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[143];
f_4549(3,av2);}}

/* k5904 in k5885 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5906(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5906,c,av);}
/* c-backend.scm:362: push-args */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7016(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* k5915 in k5885 in k5864 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5917,c,av);}
/* ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[144]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[144]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[145];
av2[3]=t1;
tp(4,av2);}}

/* k5919 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_5921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5921,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5924,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:353: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k5922 in k5919 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_5924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5924,c,av);}
/* c-backend.scm:354: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k5935 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_5937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5937,c,av);}
t2=C_eqp(((C_word*)t0)[2],t1);
if(C_truep(t2)){
/* c-backend.scm:336: chicken.compiler.core#lambda-literal-looping */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[147]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[147]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_5737(2,av2);}}}

/* k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_fcall f_5943(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,5)))){
C_save_and_reclaim_args((void *)trf_5943,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5946,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:370: chicken.compiler.support#node-parameters */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[136]);
C_word av2[3];
av2[0]=*((C_word*)lf[136]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_6056,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* c-backend.scm:400: gen */
t3=lf[4];{
C_word av2[6];
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(116);
av2[4]=((C_word*)t0)[6];
av2[5]=C_make_character(61);
f_4549(6,av2);}}}

/* k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_5946(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_5946,c,av);}
a=C_alloc(14);
t2=C_i_car(t1);
t3=C_i_cadr(t1);
t4=C_i_caddr(t1);
t5=C_SCHEME_FALSE;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_5958,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t6,a[8]=t4,a[9]=t2,a[10]=t3,a[11]=t1,tmp=(C_word)a,a+=12,tmp);
/* c-backend.scm:375: gen */
t8=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[174];
f_4549(4,av2);}}

/* k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_5958(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_5958,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5961,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_fast_retrieve(lf[151]))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5974,a[2]=((C_word*)t0)[7],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[8])){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5984,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=C_fix(10);
tp(4,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5992,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=C_fix(10);
tp(4,av2);}}}
else{
if(C_truep(((C_word*)t0)[8])){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6000,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[10],a[4]=t2,a[5]=((C_word*)t0)[11],tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6025,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=C_fix(10);
tp(4,av2);}}
else{
if(C_truep(((C_word*)t0)[10])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6033,a[2]=((C_word*)t0)[7],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6040,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=C_fix(10);
tp(4,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6045,a[2]=((C_word*)t0)[7],a[3]=t2,a[4]=((C_word*)t0)[9],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6052,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=C_fix(10);
tp(4,av2);}}}}}

/* k5959 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5961(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_5961,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5964,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:396: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k5962 in k5959 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_5964(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_5964,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5967,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:397: push-args */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7016(t3,t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)((C_word*)t0)[7])[1]);}

/* k5965 in k5962 in k5959 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_5967(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_5967,c,av);}
/* c-backend.scm:398: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[149];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[150];
f_4549(6,av2);}}

/* k5972 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5974(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5974,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
/* c-backend.scm:381: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[152];
av2[3]=((C_word*)((C_word*)t0)[2])[1];
av2[4]=lf[153];
f_4549(5,av2);}}

/* k5982 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5984(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5984,c,av);}
/* c-backend.scm:379: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[155];
av2[3]=t1;
av2[4]=lf[156];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k5990 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_5992(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5992,c,av);}
/* c-backend.scm:380: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[157];
av2[3]=t1;
av2[4]=lf[158];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k5998 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6000(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_6000,c,av);}
a=C_alloc(7);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
if(C_truep(((C_word*)t0)[3])){
/* c-backend.scm:385: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[159];
av2[3]=((C_word*)((C_word*)t0)[2])[1];
av2[4]=lf[160];
f_4549(5,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6013,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6017,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:387: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[110]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[110]+1);
av2[1]=t4;
av2[2]=C_i_cadddr(((C_word*)t0)[5]);
tp(3,av2);}}}

/* k6011 in k5998 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_6013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_6013,c,av);}
/* c-backend.scm:386: gen */
t2=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[161];
av2[3]=((C_word*)((C_word*)t0)[3])[1];
av2[4]=lf[162];
av2[5]=t1;
av2[6]=lf[163];
f_4549(7,av2);}}

/* k6015 in k5998 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_6017(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6017,c,av);}
/* c-backend.scm:387: chicken.compiler.support#c-ify-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[109]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[109]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k6023 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6025,c,av);}
/* c-backend.scm:383: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[164];
av2[3]=t1;
av2[4]=lf[165];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k6031 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6033,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
/* c-backend.scm:391: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[166];
av2[3]=((C_word*)((C_word*)t0)[2])[1];
av2[4]=lf[167];
f_4549(5,av2);}}

/* k6038 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6040,c,av);}
/* c-backend.scm:390: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[168];
av2[3]=t1;
av2[4]=lf[169];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k6043 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6045(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6045,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
/* c-backend.scm:395: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[170];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[171];
f_4549(5,av2);}}

/* k6050 in k5956 in k5944 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6052(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6052,c,av);}
/* c-backend.scm:394: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[172];
av2[3]=t1;
av2[4]=lf[173];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_6056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_6056,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6059,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:401: expr */
t3=((C_word*)((C_word*)t0)[8])[1];
f_4725(t3,t2,((C_word*)t0)[9],((C_word*)t0)[4]);}

/* k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_6059(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_6059,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6062,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:402: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[185];
f_4549(3,av2);}}

/* k6060 in k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6062(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_6062,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6065,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6090,a[2]=((C_word*)t0)[6],a[3]=t2,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6095,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
av2[3]=C_fix(10);
tp(4,av2);}}

/* k6063 in k6060 in k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_6065(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_6065,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6068,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:404: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[183];
f_4549(4,av2);}}

/* k6066 in k6063 in k6060 in k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_6068(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_6068,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6071,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_fast_retrieve(lf[177]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6077,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_fast_retrieve(lf[177]))){
t5=t4;
f_6077(t5,C_fast_retrieve(lf[177]));}
else{
t5=C_fast_retrieve(lf[182]);
if(C_truep(C_fast_retrieve(lf[182]))){
t6=C_fast_retrieve(lf[182]);
t7=t4;
f_6077(t7,C_fast_retrieve(lf[182]));}
else{
t6=t4;
f_6077(t6,((C_word*)t0)[5]);}}}

/* k6069 in k6066 in k6063 in k6060 in k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_ccall f_6071(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6071,c,av);}
/* c-backend.scm:408: gen */
t2=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[175];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[176];
f_4549(5,av2);}}

/* k6075 in k6066 in k6063 in k6060 in k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_fcall f_6077(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_6077,2,t0,t1);}
if(C_truep(t1)){
/* c-backend.scm:406: gen */
t2=lf[4];{
C_word av2[5];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[178];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[179];
f_4549(5,av2);}}
else{
/* c-backend.scm:407: gen */
t2=lf[4];{
C_word av2[5];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[180];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[181];
f_4549(5,av2);}}}

/* k6088 in k6060 in k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_6090(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6090,c,av);}
/* c-backend.scm:403: push-args */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7016(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* k6093 in k6060 in k6057 in k6054 in k5941 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_6095(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6095,c,av);}
/* ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[144]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[144]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[184];
av2[3]=t1;
tp(4,av2);}}

/* k6116 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6118(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6118,c,av);}
t2=C_eqp(lf[103],t1);
if(C_truep(t2)){
if(C_truep(C_i_not(C_fast_retrieve(lf[177])))){
t3=C_i_not(C_fast_retrieve(lf[182]));
t4=((C_word*)t0)[2];
f_5943(t4,(C_truep(t3)?C_i_not(((C_word*)t0)[3]):C_SCHEME_FALSE));}
else{
t3=((C_word*)t0)[2];
f_5943(t3,C_SCHEME_FALSE);}}
else{
t3=((C_word*)t0)[2];
f_5943(t3,C_SCHEME_FALSE);}}

/* k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6122(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_6122,c,av);}
a=C_alloc(20);
t2=C_eqp(lf[40],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5715,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:330: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(123);
f_4549(3,av2);}}
else{
if(C_truep(((C_word*)t0)[8])){
t3=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_5737,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[13],a[11]=((C_word*)t0)[14],a[12]=((C_word*)t0)[8],a[13]=((C_word*)t0)[5],a[14]=((C_word*)t0)[4],tmp=(C_word)a,a+=15,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5937,a[2]=((C_word*)t0)[8],a[3]=t3,a[4]=((C_word*)t0)[12],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:335: chicken.compiler.core#lambda-literal-id */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[148]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[148]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[12];
tp(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5943,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[15],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6118,a[2]=t3,a[3]=((C_word*)t0)[15],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:366: chicken.compiler.support#node-class */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[186]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[186]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}}}

/* k6123 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_6125,c,av);}
t2=(C_truep(C_fast_retrieve(lf[187]))?((C_word*)t0)[2]:C_SCHEME_FALSE);
if(C_truep(t2)){
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* c-backend.scm:327: gen */
t3=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[188];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[189];
av2[6]=lf[190];
av2[7]=lf[191];
f_4549(8,av2);}}
else{
/* c-backend.scm:327: gen */
t3=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[188];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[189];
av2[6]=lf[192];
av2[7]=lf[191];
f_4549(8,av2);}}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
f_5706(2,av2);}}}

/* k6143 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6145(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_6145,c,av);}
/* c-backend.scm:324: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[194];
av2[4]=t1;
av2[5]=lf[195];
f_4549(6,av2);}}

/* k6150 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_6152,c,av);}
/* c-backend.scm:325: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[197];
av2[4]=t1;
av2[5]=lf[198];
f_4549(6,av2);}}

/* k6154 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6156(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6156,c,av);}
t2=((C_word*)t0)[2];
f_5702(t2,C_i_zerop(t1));}

/* k6158 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6160(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6160,c,av);}
/* c-backend.scm:320: chicken.compiler.core#lambda-literal-closure-size */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[199]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[199]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_6203,c,av);}
a=C_alloc(8);
t2=C_i_zerop(t1);
if(C_truep(((C_word*)t0)[2])){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6209,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:417: chicken.compiler.core#lambda-literal-temporaries */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[141]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[141]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
tp(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6329,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[4],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:430: gen */
t4=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[11];
av2[3]=C_make_character(40);
f_4549(4,av2);}}}

/* k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6209(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_6209,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6212,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6322,a[2]=t1,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:418: list-tabulate */
f_4281(t2,((C_word*)t0)[5],t3);}

/* k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6212(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_6212,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6213,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_i_check_list_2(t1,lf[93]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6229,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6285,a[2]=t6,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_6285(t8,t4,((C_word*)t0)[6],t1);}

/* g1026 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_6213(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_6213,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6217,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:421: gen */
t5=lf[4];{
C_word av2[6];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(116);
av2[4]=t3;
av2[5]=C_make_character(61);
f_4549(6,av2);}}

/* k6215 in g1026 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6217(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6217,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6220,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:422: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k6218 in k6215 in g1026 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6220,c,av);}
/* c-backend.scm:423: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k6227 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6229(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_6229,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6237,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:427: list-tabulate */
f_4281(t2,((C_word*)t0)[4],*((C_word*)lf[96]+1));}

/* k6235 in k6227 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_6237,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[93]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6243,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6248,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_6248(t7,t3,((C_word*)t0)[3],t1);}

/* k6241 in k6235 in k6227 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6243(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6243,c,av);}
/* c-backend.scm:428: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[202];
f_4549(4,av2);}}

/* for-each-loop1036 in k6235 in k6227 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_fcall f_6248(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,7)))){
C_save_and_reclaim_args((void *)trf_6248,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6258,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:426: gen */
t7=lf[4];{
C_word av2[8];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(116);
av2[4]=C_slot(t3,C_fix(0));
av2[5]=lf[203];
av2[6]=C_slot(t2,C_fix(0));
av2[7]=C_make_character(59);
f_4549(8,av2);}}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k6256 in for-each-loop1036 in k6235 in k6227 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_6258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6258,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_6248(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* for-each-loop1025 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_6285(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_6285,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6295,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:419: g1026 */
t7=((C_word*)t0)[3];
f_6213(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k6293 in for-each-loop1025 in k6210 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6295,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_6285(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a6321 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_6322,c,av);}
a=C_alloc(33);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)va15406,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=t3;
va15406(t4,C_s_a_i_plus(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]));}

/* k6327 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6329(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_6329,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6332,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14800,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:432: expr-args */
t4=((C_word*)((C_word*)t0)[3])[1];
f_6937(t4,t3,((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
/* c-backend.scm:431: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[204];
f_4549(3,av2);}}}

/* k6330 in k6327 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6332(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6332,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6335,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:432: expr-args */
t3=((C_word*)((C_word*)t0)[3])[1];
f_6937(t3,t2,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k6333 in k6330 in k6327 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6335,c,av);}
/* c-backend.scm:433: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6363(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_6363,c,av);}
a=C_alloc(18);
t2=C_i_cadddr(((C_word*)t0)[2]);
t3=C_i_cddddr(((C_word*)t0)[2]);
t4=C_i_car(t3);
t5=C_i_not(C_i_zerop(t4));
t6=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_6376,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t5,a[9]=t4,a[10]=t2,a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],a[14]=t1,tmp=(C_word)a,a+=15,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6471,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:446: find-lambda */
t8=((C_word*)((C_word*)t0)[12])[1];
f_4710(t8,t7,t2);}

/* k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6376(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_6376,c,av);}
a=C_alloc(16);
t2=C_i_zerop(t1);
t3=C_u_i_car(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_6380,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t2,a[7]=((C_word*)t0)[7],a[8]=t3,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* c-backend.scm:448: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_make_character(40);
f_4549(3,av2);}}

/* k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,2)))){
C_save_and_reclaim((void *)f_6380,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_6383,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[12])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6440,a[2]=((C_word*)t0)[13],a[3]=((C_word*)t0)[14],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fast_retrieve(lf[193]))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6460,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14811,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:74: chicken.string#->string */
t6=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[15];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6467,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14816,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:75: chicken.string#->string */
t6=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[15];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_6383(2,av2);}}}

/* k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6383(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_6383,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_6386,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:456: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[207];
av2[4]=((C_word*)t0)[11];
av2[5]=C_make_character(40);
f_4549(6,av2);}}

/* k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_6386,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_6389,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)t0)[9])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6422,a[2]=((C_word*)t0)[6],a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:458: gen */
t4=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[206];
av2[3]=((C_word*)t0)[10];
av2[4]=C_make_character(41);
f_4549(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_6389(2,av2);}}}

/* k6387 in k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_6389,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6392,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_6392(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6410,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:461: expr */
t4=((C_word*)((C_word*)t0)[7])[1];
f_4725(t4,t3,((C_word*)t0)[8],((C_word*)t0)[5]);}}

/* k6390 in k6387 in k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_6392(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_6392,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6395,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
/* c-backend.scm:463: expr-args */
t3=((C_word*)((C_word*)t0)[4])[1];
f_6937(t3,t2,((C_word*)t0)[3],((C_word*)t0)[5]);}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14804,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:464: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(41);
f_4549(3,av2);}}}

/* k6393 in k6390 in k6387 in k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_6395(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6395,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6398,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:464: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k6396 in k6393 in k6390 in k6387 in k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_6398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6398,c,av);}
/* c-backend.scm:465: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=C_make_character(41);
f_4549(4,av2);}}

/* k6408 in k6387 in k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_6410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6410,c,av);}
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
/* c-backend.scm:462: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(44);
f_4549(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_6392(2,av2);}}}

/* k6420 in k6384 in k6381 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6422(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6422,c,av);}
t2=C_i_not(((C_word*)t0)[2]);
if(C_truep(t2)){
if(C_truep(t2)){
/* c-backend.scm:459: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(44);
f_4549(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
f_6389(2,av2);}}}
else{
if(C_truep(C_i_pairp(((C_word*)t0)[4]))){
/* c-backend.scm:459: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(44);
f_4549(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
f_6389(2,av2);}}}}

/* k6438 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6440(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_6440,c,av);}
t2=(C_truep(C_fast_retrieve(lf[187]))?((C_word*)t0)[2]:C_SCHEME_FALSE);
if(C_truep(t2)){
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* c-backend.scm:454: gen */
t3=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[208];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[209];
av2[6]=lf[210];
av2[7]=lf[211];
f_4549(8,av2);}}
else{
/* c-backend.scm:454: gen */
t3=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[208];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[209];
av2[6]=lf[212];
av2[7]=lf[211];
f_4549(8,av2);}}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
f_6383(2,av2);}}}

/* k6458 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_6460,c,av);}
/* c-backend.scm:451: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[213];
av2[4]=t1;
av2[5]=lf[214];
f_4549(6,av2);}}

/* k6465 in k6378 in k6374 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6467(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_6467,c,av);}
/* c-backend.scm:452: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[215];
av2[4]=t1;
av2[5]=lf[216];
f_4549(6,av2);}}

/* k6469 in k6361 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6471(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6471,c,av);}
/* c-backend.scm:446: chicken.compiler.core#lambda-literal-closure-size */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[199]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[199]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k6498 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_6500,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6503,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:476: push-args */
t3=((C_word*)((C_word*)t0)[5])[1];
f_7016(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7],lf[225]);}

/* k6501 in k6498 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6503(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_6503,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6510,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:477: toplevel */
t3=lf[224];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[4]);
f_9329(3,av2);}}

/* k6508 in k6501 in k6498 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6510(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_6510,c,av);}
/* c-backend.scm:477: gen */
t2=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[221];
av2[4]=t1;
av2[5]=lf[222];
av2[6]=((C_word*)t0)[3];
av2[7]=lf[223];
f_4549(8,av2);}}

/* k6521 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6523(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6523,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6526,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:481: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6524 in k6521 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6526,c,av);}
/* c-backend.scm:482: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[227];
f_4549(3,av2);}}

/* k6540 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6542,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6545,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:486: expr-args */
t3=((C_word*)((C_word*)t0)[3])[1];
f_6937(t3,t2,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k6543 in k6540 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6545,c,av);}
/* c-backend.scm:487: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k6576 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6578(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_6578,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6581,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6590,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:497: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(44);
f_4549(3,av2);}}
else{
/* c-backend.scm:499: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}}

/* k6579 in k6576 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6581,c,av);}
/* c-backend.scm:499: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k6588 in k6576 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6590,c,av);}
/* c-backend.scm:498: expr-args */
t2=((C_word*)((C_word*)t0)[2])[1];
f_6937(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k6612 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6614,c,av);}
/* c-backend.scm:502: gen */
t2=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_i_car(((C_word*)t0)[3]);
av2[4]=C_make_character(41);
f_4549(5,av2);}}

/* k6632 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6634(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6634,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6637,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:507: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6635 in k6632 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6637(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6637,c,av);}
/* c-backend.scm:508: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[242];
f_4549(3,av2);}}

/* k6650 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_6652,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6656,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:506: foreign-argument-conversion */
f_11717(t2,((C_word*)t0)[4]);}

/* k6654 in k6650 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_6656,c,av);}
/* c-backend.scm:506: gen */
t2=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(40);
av2[3]=((C_word*)t0)[3];
av2[4]=lf[243];
av2[5]=((C_word*)t0)[4];
av2[6]=C_make_character(41);
av2[7]=t1;
f_4549(8,av2);}}

/* k6666 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6668,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6671,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:513: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6669 in k6666 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6671,c,av);}
/* c-backend.scm:514: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[248];
f_4549(3,av2);}}

/* k6680 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_6682,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6686,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:512: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[251];
tp(4,av2);}}

/* k6684 in k6680 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_6686,c,av);}
/* c-backend.scm:512: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[249];
av2[4]=t1;
av2[5]=lf[250];
f_4549(6,av2);}}

/* k6696 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_6698,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6701,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:519: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6699 in k6696 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_6701,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6704,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6718,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:520: foreign-argument-conversion */
f_11717(t3,((C_word*)t0)[6]);}

/* k6702 in k6699 in k6696 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6704(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6704,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6707,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:521: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6705 in k6702 in k6699 in k6696 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6707,c,av);}
/* c-backend.scm:522: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[254];
f_4549(3,av2);}}

/* k6716 in k6699 in k6696 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6718(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6718,c,av);}
/* c-backend.scm:520: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[255];
av2[3]=t1;
f_4549(4,av2);}}

/* k6724 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6726,c,av);}
/* c-backend.scm:518: gen */
t2=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[256];
av2[3]=t1;
av2[4]=lf[257];
f_4549(5,av2);}}

/* k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_6735,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6738,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:526: expr */
t3=((C_word*)((C_word*)t0)[4])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[3]),((C_word*)t0)[5]);}

/* k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_6738,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6741,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:527: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[262];
f_4549(3,av2);}}

/* k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6741(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_6741,c,av);}
a=C_alloc(7);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_cdr(((C_word*)t0)[3]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6754,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_6754(t7,((C_word*)t0)[6],t2,t3);}

/* doloop1125 in k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_6754(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_6754,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_zerop(t2))){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6762,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:531: gen */
t5=lf[4];{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[260];
f_4549(4,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6775,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t3,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:534: gen */
t5=lf[4];{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[261];
f_4549(4,av2);}}}

/* k6760 in doloop1125 in k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6762,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6765,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:532: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6763 in k6760 in doloop1125 in k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6765(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6765,c,av);}
/* c-backend.scm:533: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(125);
f_4549(3,av2);}}

/* k6773 in doloop1125 in k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6775(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_6775,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6778,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:535: expr */
t3=((C_word*)((C_word*)t0)[6])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[5]),((C_word*)t0)[7]);}

/* k6776 in k6773 in doloop1125 in k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_6778,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6781,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:536: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(58);
f_4549(3,av2);}}

/* k6779 in k6776 in k6773 in doloop1125 in k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_6781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_6781,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6784,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:537: expr */
t3=((C_word*)((C_word*)t0)[6])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[5]),((C_word*)t0)[7]);}

/* k6782 in k6779 in k6776 in k6773 in doloop1125 in k6739 in k6736 in k6733 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_6784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_6784,c,av);}
a=C_alloc(29);
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_6754(t3,((C_word*)t0)[4],t2,C_i_cddr(((C_word*)t0)[5]));}

/* k6812 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_6814,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6817,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:541: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6815 in k6812 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6817(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_6817,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6820,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:542: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[265];
f_4549(3,av2);}}

/* k6818 in k6815 in k6812 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6820(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_6820,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6823,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:543: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6821 in k6818 in k6815 in k6812 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_6823,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6826,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:544: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(58);
f_4549(3,av2);}}

/* k6824 in k6821 in k6818 in k6815 in k6812 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6826(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6826,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6829,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:545: expr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4725(t3,t2,C_i_caddr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k6827 in k6824 in k6821 in k6818 in k6815 in k6812 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_6829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6829,c,av);}
/* c-backend.scm:546: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k6849 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6851,c,av);}
/* c-backend.scm:548: chicken.compiler.support#bomb */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[10]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[10]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[267];
av2[3]=t1;
tp(4,av2);}}

/* expr-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_6937(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_6937,4,t0,t1,t2,t3);}
a=C_alloc(8);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6943,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t2,tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_6943(t7,t1,t2);}

/* loop in expr-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_6943(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_6943,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6953,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
t4=C_eqp(t2,((C_word*)t0)[5]);
if(C_truep(t4)){
t5=t3;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_6953(2,av2);}}
else{
/* c-backend.scm:553: gen */
t5=lf[4];{
C_word av2[3];
av2[0]=t5;
av2[1]=t3;
av2[2]=C_make_character(44);
f_4549(3,av2);}}}}

/* k6951 in loop in expr-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6953(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_6953,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6956,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:554: expr */
t3=((C_word*)((C_word*)t0)[5])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[6]);}

/* k6954 in k6951 in loop in expr-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6956(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6956,c,av);}
/* c-backend.scm:555: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_6943(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* contains-restop? in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_6973(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_6973,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6979,a[2]=t4,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_6979(t6,t1,t2);}

/* loop in contains-restop? in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_6979(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_6979,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7014,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:563: chicken.compiler.support#node-class */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[186]);
C_word av2[3];
av2[0]=*((C_word*)lf[186]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}}

/* k6996 in k7012 in loop in contains-restop? in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_6998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6998,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* c-backend.scm:565: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_6979(t2,((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[4]));}}

/* k7008 in k7012 in loop in contains-restop? in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7010,c,av);}
/* c-backend.scm:564: contains-restop? */
t2=((C_word*)((C_word*)t0)[2])[1];
f_6973(t2,((C_word*)t0)[3],t1);}

/* k7012 in loop in contains-restop? in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7014(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_7014,c,av);}
a=C_alloc(9);
t2=C_eqp(t1,lf[54]);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6998,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7010,a[2]=((C_word*)t0)[5],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:564: chicken.compiler.support#node-subexpressions */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[268]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[268]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}}

/* push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7016(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,2)))){
C_save_and_reclaim_args((void *)trf_7016,5,t0,t1,t2,t3,t4);}
a=C_alloc(19);
t5=C_i_length(t2);
t6=(C_truep(t4)?C_fix(1):C_fix(0));
t7=C_a_i_fixnum_plus(&a,2,t5,t6);
t8=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7028,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t1,a[6]=t2,a[7]=t7,a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[4],tmp=(C_word)a,a+=10,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7134,a[2]=t8,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:570: chicken.compiler.core#lambda-literal-customizable */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[62]);
C_word av2[3];
av2[0]=*((C_word*)lf[62]+1);
av2[1]=t9;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7028(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_7028,2,t0,t1);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_7031,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:572: chicken.compiler.core#lambda-literal-argument-count */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[63]);
C_word av2[3];
av2[0]=*((C_word*)lf[63]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
tp(3,av2);}}

/* k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_7031,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_7034,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:573: chicken.compiler.core#lambda-literal-rest-argument-mode */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[286]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[286]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
tp(3,av2);}}

/* k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7034(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_7034,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7037,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_i_not(((C_word*)t0)[7]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7085,a[2]=t2,a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[9],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t3)){
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t3;
f_7085(2,av2);}}
else{
if(C_truep(C_i_lessp(((C_word*)t0)[9],((C_word*)t0)[8]))){
t5=C_eqp(t1,lf[285]);
if(C_truep(t5)){
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
f_7085(2,av2);}}
else{
/* c-backend.scm:582: contains-restop? */
t6=((C_word*)((C_word*)t0)[10])[1];
f_6973(t6,t4,((C_word*)t0)[6]);}}
else{
/* c-backend.scm:582: contains-restop? */
t5=((C_word*)((C_word*)t0)[10])[1];
f_6973(t5,t4,((C_word*)t0)[6]);}}}

/* k7035 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_7037,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7040,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[2])){
/* c-backend.scm:593: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[272];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[273];
f_4549(6,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7040(2,av2);}}}

/* k7038 in k7035 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_7040,c,av);}
a=C_alloc(7);
t2=(C_truep(((C_word*)t0)[2])?C_fix(1):C_fix(0));
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7049,a[2]=t4,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_7049(t6,((C_word*)t0)[5],t2,((C_word*)t0)[6]);}

/* doloop1178 in k7038 in k7035 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7049(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,5)))){
C_save_and_reclaim_args((void *)trf_7049,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t3))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7059,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:597: gen */
t5=lf[4];{
C_word av2[6];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[270];
av2[4]=t2;
av2[5]=lf[271];
f_4549(6,av2);}}}

/* k7057 in doloop1178 in k7038 in k7035 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7059(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7059,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7062,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:598: expr */
t3=((C_word*)((C_word*)t0)[6])[1];
f_4725(t3,t2,C_i_car(((C_word*)t0)[5]),((C_word*)t0)[7]);}

/* k7060 in k7057 in doloop1178 in k7038 in k7035 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7062(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_7062,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7065,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:599: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[269];
f_4549(3,av2);}}

/* k7063 in k7060 in k7057 in doloop1178 in k7038 in k7035 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7065(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_7065,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_7049(t3,((C_word*)t0)[4],t2,C_u_i_cdr(((C_word*)t0)[5]));}

/* k7083 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_7085,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
/* c-backend.scm:583: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[274];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[275];
f_4549(6,av2);}}
else{
if(C_truep(C_i_greater_or_equalp(((C_word*)t0)[4],((C_word*)t0)[3]))){
/* c-backend.scm:585: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[276];
f_4549(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7100,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:587: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[284];
f_4549(4,av2);}}}}

/* k7098 in k7083 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7100(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_7100,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7103,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:588: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[282];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[283];
f_4549(6,av2);}}

/* k7101 in k7098 in k7083 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7103(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_7103,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7106,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:589: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[281];
f_4549(4,av2);}}

/* k7104 in k7101 in k7098 in k7083 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7106(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_7106,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7109,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:590: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[280];
f_4549(4,av2);}}

/* k7107 in k7104 in k7101 in k7098 in k7083 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7109(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_7109,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7112,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:591: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[278];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[279];
f_4549(6,av2);}}

/* k7110 in k7107 in k7104 in k7101 in k7098 in k7083 in k7032 in k7029 in k7026 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7112(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7112,c,av);}
/* c-backend.scm:592: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[277];
f_4549(4,av2);}}

/* k7132 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7134,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7137,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
t3=((C_word*)t0)[2];
f_7028(t3,C_i_not(t1));}
else{
/* c-backend.scm:571: chicken.compiler.core#lambda-literal-direct */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[61]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[61]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k7135 in k7132 in push-args in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7137(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7137,c,av);}
t2=((C_word*)t0)[2];
f_7028(t2,C_i_not(t1));}

/* header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7145(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,2)))){
C_save_and_reclaim_args((void *)trf_7145,2,t0,t1);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7149,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7235,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7247,a[2]=t3,a[3]=t6,a[4]=t7,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7288,a[2]=t8,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:608: chicken.platform#chicken-version */
t10=C_fast_retrieve(lf[309]);{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}

/* k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7149,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7152,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:611: gen-list */
f_4592(t2,((C_word*)t0)[3]);}

/* k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_7152,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7155,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_not(C_fast_retrieve(lf[297])))){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7155(2,av2);}}
else{
/* c-backend.scm:613: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[298];
av2[4]=C_fast_retrieve(lf[297]);
f_4549(5,av2);}}}

/* k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7155,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7158,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_nullp(C_fast_retrieve(lf[295])))){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7158(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7222,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:615: gen */
t4=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[296];
f_4549(4,av2);}}}

/* k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7158(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_7158,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7161,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:617: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[294];
f_4549(4,av2);}}

/* k7159 in k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_7161,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7164,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:618: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[291];
av2[4]=C_fast_retrieve(lf[292]);
av2[5]=lf[293];
f_4549(6,av2);}}

/* k7162 in k7159 in k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7164(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7164,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7167,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_fast_retrieve(lf[287]))){
/* c-backend.scm:620: generate-foreign-callback-stub-prototypes */
f_9512(t2,C_fast_retrieve(lf[289]));}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7167(2,av2);}}}

/* k7165 in k7162 in k7159 in k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7167(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_7167,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7170,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_pairp(C_fast_retrieve(lf[290])))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7182,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:622: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}
else{
if(C_truep(C_fast_retrieve(lf[287]))){
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* c-backend.scm:625: generate-foreign-callback-stub-prototypes */
f_9512(((C_word*)t0)[2],C_fast_retrieve(lf[289]));}}}

/* k7168 in k7165 in k7162 in k7159 in k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7170(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7170,c,av);}
if(C_truep(C_fast_retrieve(lf[287]))){
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* c-backend.scm:625: generate-foreign-callback-stub-prototypes */
f_9512(((C_word*)t0)[2],C_fast_retrieve(lf[289]));}}

/* k7180 in k7165 in k7162 in k7159 in k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_7182,c,av);}
a=C_alloc(5);
t2=C_fast_retrieve(lf[290]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7192,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_7192(t6,((C_word*)t0)[2],C_fast_retrieve(lf[290]));}

/* for-each-loop1241 in k7180 in k7165 in k7162 in k7159 in k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7192(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_7192,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7202,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:623: gen */
t4=lf[4];{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_slot(t2,C_fix(0));
f_4549(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7200 in for-each-loop1241 in k7180 in k7165 in k7162 in k7159 in k7156 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7202(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7202,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7192(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k7220 in k7153 in k7150 in k7147 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7222(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7222,c,av);}
/* c-backend.scm:616: gen-list */
f_4592(((C_word*)t0)[2],C_fast_retrieve(lf[295]));}

/* k7233 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7235(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_7235,c,av);}
/* c-backend.scm:604: gen */
t2=lf[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[299];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[300];
av2[5]=C_SCHEME_TRUE;
av2[6]=lf[301];
av2[7]=C_SCHEME_TRUE;
av2[8]=t1;
av2[9]=lf[302];
f_4549(10,av2);}}

/* k7245 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_7247,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7250,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7252,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_7252(t6,t2,t1);}

/* k7248 in k7245 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7250,c,av);}
/* c-backend.scm:606: chicken.string#string-intersperse */
t2=C_fast_retrieve(lf[303]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[304];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop1206 in k7245 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7252(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_7252,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7277,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:607: g1229 */
t4=*((C_word*)lf[154]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[305];
av2[3]=C_slot(t2,C_fix(0));
av2[4]=lf[306];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k7275 in map-loop1206 in k7245 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7277,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_7252(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k7286 in header in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7288(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7288,c,av);}
/* c-backend.scm:608: chicken.string#string-split */
t2=C_fast_retrieve(lf[307]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[308];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k7296 in k9117 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7298(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,10)))){
C_save_and_reclaim((void *)f_7298,c,av);}
/* c-backend.scm:628: gen */
t2=lf[4];{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[503];
av2[5]=C_SCHEME_TRUE;
av2[6]=t1;
av2[7]=lf[504];
av2[8]=C_SCHEME_TRUE;
av2[9]=lf[505];
av2[10]=C_SCHEME_TRUE;
f_4549(11,av2);}}

/* k7300 in k9117 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7302(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7302,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14889,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:75: chicken.string#->string */
t3=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7304(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_7304,2,t0,t1);}
a=C_alloc(5);
t2=C_i_length(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7311,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:637: gen */
t4=lf[4];{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[323];
f_4549(5,av2);}}

/* k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7311(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_7311,c,av);}
a=C_alloc(17);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=lf[224];
t7=C_fast_retrieve(lf[295]);
t8=C_i_check_list_2(C_fast_retrieve(lf[295]),lf[310]);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7325,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7474,a[2]=t4,a[3]=t11,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t13=((C_word*)t11)[1];
f_7474(t13,t9,C_fast_retrieve(lf[295]));}

/* k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7325(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_7325,c,av);}
a=C_alloc(10);
t2=C_i_check_list_2(t1,lf[93]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7331,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7451,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_7451(t7,t3,t1);}

/* k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7331(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,6)))){
C_save_and_reclaim((void *)f_7331,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7334,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_eqp(((C_word*)t0)[4],C_fix(0));
if(C_truep(t3)){
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_7334(2,av2);}}
else{
/* c-backend.scm:644: gen */
t4=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[317];
av2[5]=((C_word*)t0)[4];
av2[6]=lf[318];
f_4549(7,av2);}}}

/* k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_7334,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7337,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:645: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[316];
f_4549(4,av2);}}

/* k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7337(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_7337,c,av);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7342,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_7342(t5,((C_word*)t0)[2],C_fix(0),((C_word*)t0)[3]);}

/* doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7342(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_7342,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t3))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7352,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:649: ##sys#lambda-info->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[315]);
C_word av2[3];
av2[0]=*((C_word*)lf[315]+1);
av2[1]=t4;
av2[2]=C_i_car(t3);
tp(3,av2);}}}

/* k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7352(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,11)))){
C_save_and_reclaim((void *)f_7352,c,av);}
a=C_alloc(23);
t2=C_i_string_length(t1);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7358,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t4=C_s_a_i_arithmetic_shift(&a,2,t2,C_fix(-16));
t5=C_s_a_i_arithmetic_shift(&a,2,t2,C_fix(-8));
t6=C_s_a_i_bitwise_and(&a,2,C_fix(255),t5);
/* c-backend.scm:651: gen */
t7=lf[4];{
C_word *av2;
if(c >= 12) {
  av2=av;
} else {
  av2=C_alloc(12);
}
av2[0]=t7;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[313];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[314];
av2[6]=t4;
av2[7]=C_make_character(44);
av2[8]=t6;
av2[9]=C_make_character(44);
av2[10]=C_u_fixnum_and(C_fix(255),t2);
av2[11]=C_make_character(41);
f_4549(12,av2);}}

/* k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7358(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_7358,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7361,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7400,a[2]=((C_word*)t0)[6],a[3]=t4,a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_7400(t6,t2,C_fix(0));}

/* k7359 in k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7361(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_7361,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7364,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[6],C_fix(7));
t4=C_s_a_i_bitwise_and(&a,2,C_fix(16777208),t3);
t5=C_s_a_u_i_integer_minus(&a,2,t4,((C_word*)t0)[6]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7382,a[2]=t7,tmp=(C_word)a,a+=3,tmp));
t9=((C_word*)t7)[1];
f_7382(t9,t2,t5);}

/* k7362 in k7359 in k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7364(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_7364,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7367,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:662: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[311];
f_4549(3,av2);}}

/* k7365 in k7362 in k7359 in k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7367(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_7367,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_7342(t3,((C_word*)t0)[4],t2,C_u_i_cdr(((C_word*)t0)[5]));}

/* doloop1318 in k7359 in k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_fcall f_7382(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7382,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_zerop(t2))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7390,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:661: gen */
t4=lf[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[312];
f_4549(3,av2);}}}

/* k7388 in doloop1318 in k7359 in k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_7390,c,av);}
a=C_alloc(29);
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_7382(t3,((C_word*)t0)[4],t2);}

/* doloop1317 in k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7400(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_7400,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7410,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t4=C_i_string_ref(((C_word*)t0)[4],t2);
/* c-backend.scm:658: gen */
t5=lf[4];{
C_word av2[4];
av2[0]=t5;
av2[1]=t3;
av2[2]=C_make_character(44);
av2[3]=C_fix(C_character_code(t4));
f_4549(4,av2);}}}

/* k7408 in doloop1317 in k7356 in k7350 in doloop1277 in k7335 in k7332 in k7329 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7410,c,av);}
a=C_alloc(5);
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_7400(t3,((C_word*)t0)[4],t2);}

/* for-each-loop1269 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7451(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,9)))){
C_save_and_reclaim_args((void *)trf_7451,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7461,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
/* c-backend.scm:640: gen */
t5=lf[4];{
C_word av2[10];
av2[0]=t5;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[319];
av2[4]=t4;
av2[5]=lf[320];
av2[6]=C_SCHEME_TRUE;
av2[7]=lf[321];
av2[8]=t4;
av2[9]=lf[322];
f_4549(10,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7459 in for-each-loop1269 in k7323 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7461(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7461,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7451(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* map-loop1283 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7474(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_7474,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7499,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:642: g1289 */
t4=lf[224];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_9329(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k7497 in map-loop1283 in k7309 in declarations in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7499(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7499,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_7474(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7508(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_7508,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7512,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:665: gen */
t3=lf[4];{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}

/* k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_7512,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[93]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7663,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_7663(t6,((C_word*)t0)[3],((C_word*)t0)[2]);}

/* k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_7521,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7524,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:671: chicken.compiler.core#lambda-literal-customizable */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[62]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[62]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_7524,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7527,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7655,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:672: chicken.compiler.core#lambda-literal-closure-size */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[199]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[199]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}
else{
t3=t2;
f_7527(t3,C_SCHEME_FALSE);}}

/* k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7527(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(38,0,3)))){
C_save_and_reclaim_args((void *)trf_7527,2,t0,t1);}
a=C_alloc(38);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7530,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7646,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
t4=C_s_a_i_minus(&a,2,((C_word*)t0)[6],C_fix(1));
/* c-backend.scm:673: make-variable-list */
f_9421(t3,t4,lf[342]);}
else{
/* c-backend.scm:673: make-variable-list */
f_9421(t3,((C_word*)t0)[6],lf[342]);}}

/* k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7530(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_7530,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7533,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:674: chicken.compiler.core#lambda-literal-direct */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[61]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[61]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_7533,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7536,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:675: chicken.compiler.core#lambda-literal-allocated */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[340]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[340]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7536(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_7536,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7539,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:676: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}

/* k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7539(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,5)))){
C_save_and_reclaim((void *)f_7539,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7542,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_eqp(lf[328],((C_word*)t0)[7]);
if(C_truep(C_i_not(t3))){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7604,a[2]=t2,a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:678: gen */
t5=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[334];
av2[3]=((C_word*)t0)[7];
av2[4]=lf[335];
av2[5]=C_SCHEME_TRUE;
f_4549(6,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7629,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:686: toplevel */
t5=lf[224];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_fast_retrieve(lf[297]);
f_9329(3,av2);}}}

/* k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_7542,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7545,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:690: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(40);
f_4549(3,av2);}}

/* k7543 in k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_7545,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7548,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7548(2,av2);}}
else{
/* c-backend.scm:691: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[327];
f_4549(3,av2);}}}

/* k7546 in k7543 in k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_7548(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_7548,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7551,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(C_truep(((C_word*)t0)[3])?C_i_not(C_i_zerop(((C_word*)t0)[6])):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7581,a[2]=((C_word*)t0)[5],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:693: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[326];
f_4549(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_7551(2,av2);}}}

/* k7549 in k7546 in k7543 in k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_7551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_7551,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7554,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
if(C_truep(((C_word*)t0)[4])){{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=lf[4];
av2[3]=((C_word*)t0)[5];
C_apply(4,av2);}}
else{
/* c-backend.scm:697: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[325];
f_4549(3,av2);}}}
else{
if(C_truep(((C_word*)t0)[3])){{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=lf[4];
av2[3]=((C_word*)t0)[5];
C_apply(4,av2);}}
else{
/* c-backend.scm:697: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[325];
f_4549(3,av2);}}}}

/* k7552 in k7549 in k7546 in k7543 in k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_7554(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_7554,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7557,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:698: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(41);
f_4549(3,av2);}}

/* k7555 in k7552 in k7549 in k7546 in k7543 in k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_7557(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7557,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7560,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[3])){
/* c-backend.scm:700: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(59);
f_4549(3,av2);}}
else{
/* c-backend.scm:699: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[324];
f_4549(3,av2);}}}

/* k7558 in k7555 in k7552 in k7549 in k7546 in k7543 in k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_ccall f_7560(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7560,c,av);}
/* c-backend.scm:700: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* k7579 in k7546 in k7543 in k7540 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_7581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7581,c,av);}
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
/* c-backend.scm:694: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(44);
f_4549(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_7551(2,av2);}}}

/* k7602 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7604(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_7604,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7607,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:679: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[333];
f_4549(3,av2);}}

/* k7605 in k7602 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7607(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7607,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7610,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[5])){
/* c-backend.scm:680: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[331];
f_4549(3,av2);}}
else{
/* c-backend.scm:680: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[332];
f_4549(3,av2);}}}

/* k7608 in k7605 in k7602 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_7610(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_7610,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7613,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
/* c-backend.scm:682: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[329];
f_4549(3,av2);}}
else{
/* c-backend.scm:683: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[330];
f_4549(3,av2);}}}

/* k7611 in k7608 in k7605 in k7602 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_7613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7613,c,av);}
/* c-backend.scm:684: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
f_4549(3,av2);}}

/* k7627 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_7629,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7632,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:687: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[338];
av2[3]=t1;
av2[4]=lf[339];
av2[5]=C_SCHEME_TRUE;
f_4549(6,av2);}}

/* k7630 in k7627 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_7632,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7635,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:688: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[337];
f_4549(3,av2);}}

/* k7633 in k7630 in k7627 in k7537 in k7534 in k7531 in k7528 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_7635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7635,c,av);}
/* c-backend.scm:689: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[336];
av2[3]=((C_word*)t0)[3];
f_4549(4,av2);}}

/* k7644 in k7525 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7646(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7646,c,av);}
/* c-backend.scm:673: chicken.base#intersperse */
t2=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k7653 in k7522 in k7519 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7655,c,av);}
t2=((C_word*)t0)[2];
f_7527(t2,C_i_zerop(t1));}

/* for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7663(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_7663,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7673,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=C_i_car(t4);
t6=C_u_i_cdr(t4);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7521,a[2]=t3,a[3]=t5,a[4]=t6,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:670: chicken.compiler.core#lambda-literal-argument-count */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[63]);
C_word av2[3];
av2[0]=*((C_word*)lf[63]+1);
av2[1]=t7;
av2[2]=t6;
tp(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7671 in for-each-loop1338 in k7510 in prototypes in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7673(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7673,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7663(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7686(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_7686,2,t0,t1);}
a=C_alloc(5);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[93]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7784,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_7784(t6,t1,((C_word*)t0)[2]);}

/* doloop1403 in k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7697(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,7)))){
C_save_and_reclaim_args((void *)trf_7697,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7707,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:712: gen */
t5=lf[4];{
C_word av2[8];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[346];
av2[4]=t2;
av2[5]=lf[347];
av2[6]=t3;
av2[7]=lf[348];
f_4549(8,av2);}}}

/* k7705 in doloop1403 in k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,3)))){
C_save_and_reclaim((void *)f_7707,c,av);}
a=C_alloc(58);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[3],C_fix(1));
t4=((C_word*)((C_word*)t0)[4])[1];
f_7697(t4,((C_word*)t0)[5],t2,t3);}

/* k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_7723,c,av);}
a=C_alloc(11);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7726,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* c-backend.scm:719: chicken.compiler.core#lambda-literal-customizable */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[62]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[62]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}

/* k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_7726,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7729,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7776,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:720: chicken.compiler.core#lambda-literal-closure-size */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[199]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[199]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}
else{
t3=t2;
f_7729(t3,C_SCHEME_FALSE);}}

/* k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7729(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(39,0,2)))){
C_save_and_reclaim_args((void *)trf_7729,2,t0,t1);}
a=C_alloc(39);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7732,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t1)){
t3=((C_word*)((C_word*)t0)[4])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[4])+1,C_s_a_i_minus(&a,2,t3,C_fix(1)));
t5=t2;
f_7732(t5,t4);}
else{
t3=t2;
f_7732(t3,C_SCHEME_UNDEFINED);}}

/* k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7732(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_7732,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7770,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* c-backend.scm:722: chicken.compiler.core#lambda-literal-direct */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[61]);
C_word av2[3];
av2[0]=*((C_word*)lf[61]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
tp(3,av2);}}

/* k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7741(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_7741,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7744,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:725: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[349];
av2[4]=((C_word*)t0)[4];
av2[5]=lf[350];
f_4549(6,av2);}}

/* k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7744(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(40,c,4)))){
C_save_and_reclaim((void *)f_7744,c,av);}
a=C_alloc(40);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7747,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)((C_word*)t0)[3])[1];
t4=C_s_a_i_minus(&a,2,t3,C_fix(1));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7697,a[2]=t3,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_7697(t8,t2,C_fix(0),t4);}

/* k7745 in k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7747(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_7747,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7750,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:727: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[4];
av2[4]=C_make_character(40);
f_4549(5,av2);}}

/* k7748 in k7745 in k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_7750(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_7750,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7753,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:728: make-argument-list */
f_9438(t2,((C_word*)((C_word*)t0)[3])[1],lf[345]);}

/* k7751 in k7748 in k7745 in k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_7753(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7753,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7756,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7763,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:729: chicken.base#intersperse */
t4=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k7754 in k7751 in k7748 in k7745 in k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_7756(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7756,c,av);}
/* c-backend.scm:730: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[343];
f_4549(3,av2);}}

/* k7761 in k7751 in k7748 in k7745 in k7742 in k7739 in k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_7763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7763,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[4];
av2[3]=t1;
C_apply(4,av2);}}

/* k7768 in k7730 in k7727 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7770(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_7770,c,av);}
a=C_alloc(5);
t2=C_i_not(t1);
t3=(C_truep(t2)?((C_word*)t0)[2]:C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7741,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:723: gen */
t5=lf[4];{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[351];
av2[5]=((C_word*)t0)[5];
av2[6]=lf[352];
av2[7]=C_SCHEME_TRUE;
av2[8]=lf[353];
av2[9]=((C_word*)t0)[5];
av2[10]=lf[354];
f_4549(11,av2);}}
else{
t4=((C_word*)((C_word*)t0)[6])[1];
f_7784(t4,((C_word*)t0)[7],C_slot(((C_word*)t0)[8],C_fix(1)));}}

/* k7774 in k7724 in k7721 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7776,c,av);}
t2=((C_word*)t0)[2];
f_7729(t2,C_i_zerop(t1));}

/* for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7784(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,2)))){
C_save_and_reclaim_args((void *)trf_7784,3,t0,t1,t2);}
a=C_alloc(13);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7794,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=C_i_car(t4);
t6=C_u_i_cdr(t4);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7723,a[2]=t3,a[3]=t5,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=t2,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:718: chicken.compiler.core#lambda-literal-argument-count */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[63]);
C_word av2[3];
av2[0]=*((C_word*)lf[63]+1);
av2[1]=t7;
av2[2]=t6;
tp(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7792 in for-each-loop1393 in trampolines in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7794,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7784(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7807(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_7807,2,t0,t1);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7813,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_7813(t5,t1,C_fix(0),((C_word*)t0)[3]);}

/* doloop1432 in literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7813(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_7813,4,t0,t1,t2,t3);}
a=C_alloc(12);
if(C_truep(C_i_nullp(t3))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7823,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t5=C_i_car(t3);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7838,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=t5,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:737: chicken.base#open-output-string */
t7=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k7821 in doloop1432 in literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_7823,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_7813(t3,((C_word*)t0)[4],t2,C_u_i_cdr(((C_word*)t0)[5]));}

/* k7836 in doloop1432 in literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7838(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_7838,c,av);}
a=C_alloc(7);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7844,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:737: ##sys#print */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[359];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k7842 in k7836 in doloop1432 in literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7844(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_7844,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7847,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:737: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k7845 in k7842 in k7836 in doloop1432 in literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7847,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7850,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:737: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t2;
av2[2]=C_make_character(93);
av2[3]=((C_word*)t0)[5];
tp(4,av2);}}

/* k7848 in k7845 in k7842 in k7836 in doloop1432 in literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7850,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7853,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:737: chicken.base#get-output-string */
t3=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k7851 in k7848 in k7845 in k7842 in k7836 in doloop1432 in literal-frame in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7853,c,av);}
/* c-backend.scm:737: gen-lit */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8144(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7861(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7861,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7868,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:743: chicken.compiler.support#immediate? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[370]);
C_word av2[3];
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7868(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7868,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7874,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:744: chicken.compiler.support#big-fixnum? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[369]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[369]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7874(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7874,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(2);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_stringp(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_bignump(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(2);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(((C_word*)t0)[3]))){
t2=C_fast_retrieve(lf[361]);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fast_retrieve(lf[361]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_symbolp(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(7);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7904,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:749: chicken.keyword#keyword? */
t3=C_fast_retrieve(lf[368]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}}}}

/* k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7904(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_7904,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(7);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7917,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:750: literal-size */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7861(t3,t2,C_u_i_car(((C_word*)t0)[3]));}
else{
if(C_truep(C_i_vectorp(((C_word*)t0)[3]))){
t2=C_block_size(((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7945,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t5,a[5]=((C_word*)t0)[4],a[6]=t6,tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:753: scheme#vector->list */
t8=*((C_word*)lf[363]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8019,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:754: chicken.compiler.support#block-variable-literal? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[367]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[367]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}}}

/* k7915 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_7917,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7921,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:750: literal-size */
t3=((C_word*)((C_word*)t0)[3])[1];
f_7861(t3,t2,C_u_i_cdr(((C_word*)t0)[4]));}

/* k7919 in k7915 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_7921,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)va15438,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=t2;
va15438(t3,C_s_a_i_plus(&a,2,C_fix(3),((C_word*)t0)[3]));}

/* k7943 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_7945,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7948,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7980,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_7980(t6,t2,t1);}

/* k7946 in k7943 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7948(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_7948,c,av);}
a=C_alloc(9);
t2=C_i_check_list_2(t1,lf[362]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7954,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7956,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_7956(t7,t3,t1,C_fix(0));}

/* k7952 in k7946 in k7943 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_7954(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_7954,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)va15440,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=t2;
va15440(t3,C_s_a_i_plus(&a,2,C_fix(1),((C_word*)t0)[3]));}

/* foldl1461 in k7946 in k7943 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7956(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,3)))){
C_save_and_reclaim_args((void *)trf_7956,4,t0,t1,t2,t3);}
a=C_alloc(29);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=C_slot(t2,C_fix(0));
t6=C_s_a_i_plus(&a,2,t3,t5);
t8=t1;
t9=t4;
t10=t6;
t1=t8;
t2=t9;
t3=t10;
goto loop;}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* map-loop1467 in k7943 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_7980(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_7980,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8005,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:753: g1473 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_7861(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k8003 in map-loop1467 in k7943 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8005(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8005,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_7980(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_8019,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_immp(((C_word*)t0)[3]))){
/* c-backend.scm:740: chicken.compiler.support#bomb */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[10]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[10]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[364];
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}
else{
if(C_truep(C_lambdainfop(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8037,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:757: ##sys#bytevector? */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[366]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[366]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}}}

/* k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_8037,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8044,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:757: chicken.compiler.support#bytes->words */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[365]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[365]+1);
av2[1]=t2;
av2[2]=C_block_size(((C_word*)t0)[3]);
tp(3,av2);}}
else{
if(C_truep(C_structurep(((C_word*)t0)[3]))){
t2=C_block_size(((C_word*)t0)[3]);
t3=C_a_i_fixnum_plus(&a,2,C_fix(2),t2);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8065,a[2]=t2,a[3]=t5,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_8065(t7,((C_word*)t0)[2],C_fix(0),t3);}
else{
if(C_truep(C_i_ratnump(((C_word*)t0)[3]))){
t2=C_block_size(((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8106,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:766: literal-size */
t4=((C_word*)((C_word*)t0)[4])[1];
f_7861(t4,t3,C_u_i_ratnum_num(((C_word*)t0)[3]));}
else{
if(C_truep(C_i_cplxnump(((C_word*)t0)[3]))){
t2=C_block_size(((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8131,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:769: literal-size */
t4=((C_word*)((C_word*)t0)[4])[1];
f_7861(t4,t3,C_u_i_cplxnum_real(((C_word*)t0)[3]));}
else{
/* c-backend.scm:740: chicken.compiler.support#bomb */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[10]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[10]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[364];
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}}}}}

/* k8042 in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8044(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_8044,c,av);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,C_fix(2),t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8065(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(35,0,2)))){
C_save_and_reclaim_args((void *)trf_8065,4,t0,t1,t2,t3);}
a=C_alloc(35);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_s_a_i_plus(&a,2,t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8085,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:763: literal-size */
t6=((C_word*)((C_word*)t0)[4])[1];
f_7861(t6,t5,C_slot(((C_word*)t0)[5],t2));}}

/* k8083 in loop in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_8085,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],t1);
/* c-backend.scm:763: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_8065(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k8104 in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8106(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8106,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8110,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:767: literal-size */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7861(t3,t2,C_u_i_ratnum_denom(((C_word*)t0)[5]));}

/* k8108 in k8104 in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8110(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_8110,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)va15448,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=t2;
va15448(t3,C_s_a_i_plus(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]));}

/* k8129 in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8131(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8131,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8135,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:770: literal-size */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7861(t3,t2,C_u_i_cplxnum_imag(((C_word*)t0)[5]));}

/* k8133 in k8129 in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8135(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_8135,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)va15450,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=t2;
va15450(t3,C_s_a_i_plus(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]));}

/* gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8144(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_8144,4,t0,t1,t2,t3);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8151,a[2]=t1,a[3]=t3,a[4]=t2,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fixnump(t2))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8296,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:775: chicken.compiler.support#big-fixnum? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[369]);
C_word av2[3];
av2[0]=*((C_word*)lf[369]+1);
av2[1]=t5;
av2[2]=t2;
tp(3,av2);}}
else{
t5=t4;
f_8151(t5,C_SCHEME_FALSE);}}

/* k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8151(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,6)))){
C_save_and_reclaim_args((void *)trf_8151,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
/* c-backend.scm:776: gen */
t2=lf[4];{
C_word av2[7];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[3];
av2[4]=lf[371];
av2[5]=((C_word*)t0)[4];
av2[6]=lf[372];
f_4549(7,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8157,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:777: chicken.compiler.support#block-variable-literal? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[367]);
C_word av2[3];
av2[0]=*((C_word*)lf[367]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}}

/* k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_8157,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=*((C_word*)lf[373]+1);
t3=C_eqp(((C_word*)t0)[3],*((C_word*)lf[373]+1));
if(C_truep(t3)){
/* c-backend.scm:779: gen */
t4=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[4];
av2[4]=lf[374];
f_4549(5,av2);}}
else{
if(C_truep(C_booleanp(((C_word*)t0)[3]))){
if(C_truep(((C_word*)t0)[3])){
/* c-backend.scm:781: gen */
t4=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[4];
av2[4]=C_make_character(61);
av2[5]=lf[375];
av2[6]=C_make_character(59);
f_4549(7,av2);}}
else{
/* c-backend.scm:781: gen */
t4=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[4];
av2[4]=C_make_character(61);
av2[5]=lf[376];
av2[6]=C_make_character(59);
f_4549(7,av2);}}}
else{
if(C_truep(C_charp(((C_word*)t0)[3]))){
/* c-backend.scm:783: gen */
t4=lf[4];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[4];
av2[4]=lf[377];
av2[5]=C_fix(C_character_code(((C_word*)t0)[3]));
av2[6]=lf[378];
f_4549(7,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8201,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:784: chicken.keyword#keyword? */
t5=C_fast_retrieve(lf[368]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}}}}

/* k8199 in k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8201(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8201,c,av);}
a=C_alloc(6);
t2=(C_truep(t1)?t1:C_i_symbolp(((C_word*)t0)[2]));
if(C_truep(t2)){
t3=C_slot(((C_word*)t0)[2],C_fix(1));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8210,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:786: chicken.compiler.support#c-ify-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[109]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[109]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}
else{
if(C_truep(C_i_nullp(((C_word*)t0)[2]))){
/* c-backend.scm:794: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[4];
av2[4]=lf[385];
f_4549(5,av2);}}
else{
t3=C_immp(((C_word*)t0)[2]);
t4=C_i_not(t3);
t5=(C_truep(t4)?C_lambdainfop(((C_word*)t0)[2]):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_fixnump(((C_word*)t0)[2]);
t7=(C_truep(t6)?t6:C_i_not(C_immp(((C_word*)t0)[2])));
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8252,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:798: gen */
t9=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[4];
av2[4]=lf[388];
f_4549(5,av2);}}
else{
/* c-backend.scm:740: chicken.compiler.support#bomb */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[10]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[10]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=lf[364];
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}}}}}

/* k8208 in k8199 in k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8210(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_8210,c,av);}
a=C_alloc(6);
t2=C_block_size(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8225,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:788: chicken.keyword#keyword? */
t4=C_fast_retrieve(lf[368]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8217 in k8223 in k8208 in k8199 in k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8219(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_8219,c,av);}
/* c-backend.scm:792: gen */
t2=lf[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[381];
av2[4]=((C_word*)t0)[4];
av2[5]=C_make_character(44);
av2[6]=((C_word*)t0)[5];
av2[7]=lf[382];
av2[8]=((C_word*)t0)[6];
av2[9]=lf[383];
f_4549(10,av2);}}

/* k8223 in k8208 in k8199 in k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_8225,c,av);}
a=C_alloc(7);
t2=(C_truep(t1)?lf[379]:lf[380]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8219,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:791: gen */
t4=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[3];
av2[4]=lf[384];
f_4549(5,av2);}}

/* k8250 in k8199 in k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8252(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_8252,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8255,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8262,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:799: encode-literal */
f_13169(t3,((C_word*)t0)[4]);}

/* k8253 in k8250 in k8199 in k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8255,c,av);}
/* c-backend.scm:800: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[386];
f_4549(3,av2);}}

/* k8260 in k8250 in k8199 in k8155 in k8149 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8262(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8262,c,av);}
/* c-backend.scm:799: gen-string-constant */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8298(t2,((C_word*)t0)[3],t1);}

/* k8294 in gen-lit in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8296,c,av);}
t2=((C_word*)t0)[2];
f_8151(t2,C_i_not(t1));}

/* gen-string-constant in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8298(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_8298,3,t0,t1,t2);}
a=C_alloc(9);
t3=C_block_size(t2);
t4=C_fixnum_divide(t3,C_fix(80));
t5=C_fixnum_modulo(t3,C_fix(80));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8312,a[2]=t3,a[3]=t5,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=t7,tmp=(C_word)a,a+=7,tmp));
t9=((C_word*)t7)[1];
f_8312(t9,t1,t4,C_fix(0));}

/* doloop1532 in gen-string-constant in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8312(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(41,0,4)))){
C_save_and_reclaim_args((void *)trf_8312,4,t0,t1,t2,t3);}
a=C_alloc(41);
if(C_truep(C_i_zerop(t2))){
t4=C_eqp(((C_word*)t0)[2],C_fix(0));
t5=(C_truep(t4)?t4:C_i_not(C_eqp(((C_word*)t0)[3],C_fix(0))));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8333,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8337,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:811: string-like-substring */
f_8372(t7,((C_word*)t0)[5],t3,((C_word*)t0)[2]);}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8349,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[6],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8362,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8366,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t7=C_s_a_i_plus(&a,2,t3,C_fix(80));
/* c-backend.scm:812: string-like-substring */
f_8372(t6,((C_word*)t0)[5],t3,t7);}}

/* k8331 in doloop1532 in gen-string-constant in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8333(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8333,c,av);}
/* c-backend.scm:811: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
f_4549(3,av2);}}

/* k8335 in doloop1532 in gen-string-constant in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8337(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8337,c,av);}
/* c-backend.scm:811: chicken.compiler.support#c-ify-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[109]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[109]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k8347 in doloop1532 in gen-string-constant in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,3)))){
C_save_and_reclaim((void *)f_8349,c,av);}
a=C_alloc(58);
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_s_a_i_plus(&a,2,((C_word*)t0)[3],C_fix(80));
t4=((C_word*)((C_word*)t0)[4])[1];
f_8312(t4,((C_word*)t0)[5],t2,t3);}

/* k8360 in doloop1532 in gen-string-constant in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8362(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8362,c,av);}
/* c-backend.scm:812: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_TRUE;
f_4549(4,av2);}}

/* k8364 in doloop1532 in gen-string-constant in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8366,c,av);}
/* c-backend.scm:812: chicken.compiler.support#c-ify-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[109]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[109]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* string-like-substring in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8372(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(35,0,2)))){
C_save_and_reclaim_args((void *)trf_8372,4,t1,t2,t3,t4);}
a=C_alloc(35);
t5=C_s_a_i_minus(&a,2,t4,t3);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8379,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:816: scheme#make-string */
t7=*((C_word*)lf[390]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k8377 in string-like-substring in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,6)))){
C_save_and_reclaim((void *)f_8379,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8382,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:817: ##sys#copy-bytes */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[389]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[389]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
av2[5]=C_fix(0);
av2[6]=((C_word*)t0)[5];
tp(7,av2);}}

/* k8380 in k8377 in string-like-substring in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8382,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8384(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,3)))){
C_save_and_reclaim_args((void *)trf_8384,2,t0,t1);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_8386,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=C_i_check_list_2(((C_word*)t0)[8],lf[93]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9064,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_9064(t7,t1,((C_word*)t0)[8]);}

/* g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8386(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_8386,3,t0,t1,t2);}
a=C_alloc(11);
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8394,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t4,a[6]=t3,a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:825: chicken.compiler.core#lambda-literal-argument-count */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[63]);
C_word av2[3];
av2[0]=*((C_word*)lf[63]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}

/* k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8394(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_8394,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8397,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:826: chicken.compiler.support#real-name */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[502]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[502]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[10];
tp(4,av2);}}

/* k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8397(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_8397,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_8400,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,tmp=(C_word)a,a+=12,tmp);
/* c-backend.scm:827: chicken.compiler.core#lambda-literal-allocated */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[340]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[340]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_8400,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_8403,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9056,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:828: chicken.compiler.core#lambda-literal-callee-signatures */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[501]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[501]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8403(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_8403,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_8406,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* c-backend.scm:829: chicken.compiler.core#lambda-literal-rest-argument */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[499]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[499]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8406(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_8406,c,av);}
a=C_alloc(17);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_8409,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t3,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
/* c-backend.scm:830: chicken.compiler.core#lambda-literal-customizable */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[62]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[62]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_8409,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_8412,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9052,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:831: chicken.compiler.core#lambda-literal-closure-size */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[199]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[199]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}
else{
t3=t2;
f_8412(t3,C_SCHEME_FALSE);}}

/* k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_8412(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(47,0,3)))){
C_save_and_reclaim_args((void *)trf_8412,2,t0,t1);}
a=C_alloc(47);
t2=(C_truep(t1)?C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(1)):C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(0)));
t3=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_8418,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t2,a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=t1,a[17]=((C_word*)t0)[15],tmp=(C_word)a,a+=18,tmp);
/* c-backend.scm:833: make-variable-list */
f_9421(t3,((C_word*)t0)[2],lf[498]);}

/* k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_8418(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_8418,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_8421,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=t1,tmp=(C_word)a,a+=19,tmp);
/* c-backend.scm:834: make-argument-list */
f_9438(t2,((C_word*)t0)[6],lf[497]);}

/* k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_8421(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_8421,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_8424,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=t1,tmp=(C_word)a,a+=19,tmp);
if(C_truep(((C_word*)t0)[16])){
/* c-backend.scm:835: chicken.base#intersperse */
t3=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cdr(((C_word*)t0)[18]);
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* c-backend.scm:835: chicken.base#intersperse */
t3=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[18];
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_8424(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_8424,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_8427,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=t1,a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
if(C_truep(((C_word*)t0)[16])){
/* c-backend.scm:836: chicken.base#intersperse */
t3=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cdr(((C_word*)t0)[18]);
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* c-backend.scm:836: chicken.base#intersperse */
t3=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[18];
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_8427(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_8427,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_8430,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],tmp=(C_word)a,a+=20,tmp);
/* c-backend.scm:837: chicken.compiler.core#lambda-literal-external */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[496]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[496]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_8430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,2)))){
C_save_and_reclaim((void *)f_8430,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_8433,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=t1,a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],tmp=(C_word)a,a+=21,tmp);
/* c-backend.scm:838: chicken.compiler.core#lambda-literal-looping */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[147]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[147]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_8433(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,2)))){
C_save_and_reclaim((void *)f_8433,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8436,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=t1,a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
/* c-backend.scm:839: chicken.compiler.core#lambda-literal-direct */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[61]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[61]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_8436(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,2)))){
C_save_and_reclaim((void *)f_8436,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|22,a[1]=(C_word)f_8439,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],tmp=(C_word)a,a+=23,tmp);
/* c-backend.scm:840: chicken.compiler.core#lambda-literal-rest-argument-mode */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[286]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[286]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_ccall f_8439(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,2)))){
C_save_and_reclaim((void *)f_8439,c,av);}
a=C_alloc(24);
t2=(*a=C_CLOSURE_TYPE|23,a[1]=(C_word)f_8442,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=t1,a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],tmp=(C_word)a,a+=24,tmp);
/* c-backend.scm:841: chicken.compiler.core#lambda-literal-temporaries */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[141]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[141]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in ... */
static void C_ccall f_8442(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,2)))){
C_save_and_reclaim((void *)f_8442,c,av);}
a=C_alloc(25);
t2=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_8445,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],tmp=(C_word)a,a+=25,tmp);
/* c-backend.scm:842: chicken.compiler.core#lambda-literal-float-temporaries */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[495]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[495]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in ... */
static void C_ccall f_8445(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,2)))){
C_save_and_reclaim((void *)f_8445,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|25,a[1]=(C_word)f_8448,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=t1,a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],tmp=(C_word)a,a+=26,tmp);
/* c-backend.scm:843: toplevel */
t3=lf[224];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_fast_retrieve(lf[297]);
f_9329(3,av2);}}

/* k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in ... */
static void C_ccall f_8448(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,4)))){
C_save_and_reclaim((void *)f_8448,c,av);}
a=C_alloc(27);
t2=(*a=C_CLOSURE_TYPE|26,a[1]=(C_word)f_8451,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=t1,a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],a[26]=((C_word*)t0)[25],tmp=(C_word)a,a+=27,tmp);
if(C_truep(((C_word*)t0)[20])){
/* c-backend.scm:844: chicken.compiler.support#debugging */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[492]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[492]+1);
av2[1]=t2;
av2[2]=lf[493];
av2[3]=lf[494];
av2[4]=((C_word*)t0)[9];
tp(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8451(2,av2);}}}

/* k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in ... */
static void C_ccall f_8451(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,3)))){
C_save_and_reclaim((void *)f_8451,c,av);}
a=C_alloc(27);
t2=(*a=C_CLOSURE_TYPE|26,a[1]=(C_word)f_8454,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],a[25]=((C_word*)t0)[25],a[26]=((C_word*)t0)[26],tmp=(C_word)a,a+=27,tmp);
/* c-backend.scm:845: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
f_4549(4,av2);}}

/* k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in ... */
static void C_ccall f_8454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_8454,c,av);}
a=C_alloc(29);
t2=(*a=C_CLOSURE_TYPE|25,a[1]=(C_word)f_8457,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],a[25]=((C_word*)t0)[25],tmp=(C_word)a,a+=26,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9027,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:846: cleanup */
f_9345(t3,((C_word*)t0)[26]);}

/* k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in ... */
static void C_ccall f_8457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,2)))){
C_save_and_reclaim((void *)f_8457,c,av);}
a=C_alloc(32);
t2=(*a=C_CLOSURE_TYPE|25,a[1]=(C_word)f_8460,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],a[25]=((C_word*)t0)[25],tmp=(C_word)a,a+=26,tmp);
t3=C_eqp(lf[328],((C_word*)t0)[9]);
if(C_truep(C_i_not(t3))){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8988,a[2]=t2,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:848: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[485];
f_4549(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9010,a[2]=t2,a[3]=((C_word*)t0)[19],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:855: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[488];
f_4549(3,av2);}}}

/* k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in ... */
static void C_ccall f_8460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,2)))){
C_save_and_reclaim((void *)f_8460,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|25,a[1]=(C_word)f_8463,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],a[25]=((C_word*)t0)[25],tmp=(C_word)a,a+=26,tmp);
/* c-backend.scm:859: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(40);
f_4549(3,av2);}}

/* k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in ... */
static void C_ccall f_8463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,2)))){
C_save_and_reclaim((void *)f_8463,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|25,a[1]=(C_word)f_8466,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],a[25]=((C_word*)t0)[25],tmp=(C_word)a,a+=26,tmp);
if(C_truep(((C_word*)t0)[3])){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8466(2,av2);}}
else{
/* c-backend.scm:860: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[480];
f_4549(3,av2);}}}

/* k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in ... */
static void C_ccall f_8466(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,2)))){
C_save_and_reclaim((void *)f_8466,c,av);}
a=C_alloc(30);
t2=(*a=C_CLOSURE_TYPE|25,a[1]=(C_word)f_8469,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],a[25]=((C_word*)t0)[25],tmp=(C_word)a,a+=26,tmp);
t3=(C_truep(((C_word*)t0)[10])?C_i_not(C_i_zerop(((C_word*)t0)[12])):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8965,a[2]=((C_word*)t0)[25],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:862: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[479];
f_4549(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_8469(2,av2);}}}

/* k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in ... */
static void C_ccall f_8469(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,3)))){
C_save_and_reclaim((void *)f_8469,c,av);}
a=C_alloc(25);
t2=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_8472,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],tmp=(C_word)a,a+=25,tmp);
if(C_truep(((C_word*)t0)[3])){
if(C_truep(((C_word*)t0)[3])){{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=lf[4];
av2[3]=((C_word*)t0)[25];
C_apply(4,av2);}}
else{
/* c-backend.scm:866: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[478];
f_4549(3,av2);}}}
else{
if(C_truep(((C_word*)t0)[10])){{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=lf[4];
av2[3]=((C_word*)t0)[25];
C_apply(4,av2);}}
else{
/* c-backend.scm:866: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[478];
f_4549(3,av2);}}}}

/* k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in ... */
static void C_ccall f_8472(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,2)))){
C_save_and_reclaim((void *)f_8472,c,av);}
a=C_alloc(25);
t2=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_8475,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],tmp=(C_word)a,a+=25,tmp);
/* c-backend.scm:867: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[477];
f_4549(3,av2);}}

/* k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in ... */
static void C_ccall f_8475(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,2)))){
C_save_and_reclaim((void *)f_8475,c,av);}
a=C_alloc(25);
t2=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_8478,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],tmp=(C_word)a,a+=25,tmp);
t3=C_eqp(((C_word*)t0)[22],lf[285]);
if(C_truep(t3)){
t4=C_set_block_item(((C_word*)t0)[5],0,C_SCHEME_FALSE);
t5=t2;
f_8478(t5,t4);}
else{
t4=t2;
f_8478(t4,C_SCHEME_UNDEFINED);}}

/* k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in ... */
static void C_fcall f_8478(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,0,3)))){
C_save_and_reclaim_args((void *)trf_8478,2,t0,t1);}
a=C_alloc(25);
t2=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_8481,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],tmp=(C_word)a,a+=25,tmp);
/* c-backend.scm:869: gen */
t3=lf[4];{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[476];
f_4549(4,av2);}}

/* k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in ... */
static void C_ccall f_8481(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(31,c,3)))){
C_save_and_reclaim((void *)f_8481,c,av);}
a=C_alloc(31);
t2=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_8484,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],tmp=(C_word)a,a+=25,tmp);
t3=(C_truep(((C_word*)t0)[3])?((C_word*)t0)[3]:((C_word*)t0)[10]);
if(C_truep(t3)){
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_8484(2,av2);}}
else{
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8931,a[2]=((C_word*)t0)[6],a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_8931(t7,t2,C_fix(0));}}

/* k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in ... */
static void C_ccall f_8484(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(90,c,5)))){
C_save_and_reclaim((void *)f_8484,c,av);}
a=C_alloc(90);
t2=(*a=C_CLOSURE_TYPE|23,a[1]=(C_word)f_8487,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],tmp=(C_word)a,a+=24,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
/* c-backend.scm:875: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[470];
av2[4]=((C_word*)t0)[6];
av2[5]=C_make_character(59);
f_4549(6,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8863,a[2]=((C_word*)t0)[24],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8901,a[2]=t3,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[15])){
t5=C_s_a_i_minus(&a,2,((C_word*)t0)[6],C_fix(1));
t6=t4;
f_8901(t6,C_s_a_i_plus(&a,2,((C_word*)t0)[11],t5));}
else{
t5=t4;
f_8901(t5,C_s_a_i_plus(&a,2,((C_word*)t0)[11],C_fix(0)));}}}

/* k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in ... */
static void C_ccall f_8487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,4)))){
C_save_and_reclaim((void *)f_8487,c,av);}
a=C_alloc(30);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_8490,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],tmp=(C_word)a,a+=16,tmp);
t3=C_eqp(lf[328],((C_word*)t0)[9]);
if(C_truep(t3)){
t4=C_i_check_list_2(((C_word*)t0)[16],lf[362]);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_8630,a[2]=((C_word*)t0)[16],a[3]=t2,a[4]=((C_word*)t0)[17],a[5]=((C_word*)t0)[12],a[6]=((C_word*)t0)[18],a[7]=((C_word*)t0)[19],tmp=(C_word)a,a+=8,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8693,a[2]=((C_word*)t0)[20],a[3]=t7,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_8693(t9,t5,((C_word*)t0)[16],C_fix(0));}
else{
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8730,a[2]=t2,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[18],a[6]=((C_word*)t0)[21],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:916: gen */
t5=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[455];
f_4549(4,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8769,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[12],a[6]=((C_word*)t0)[18],a[7]=((C_word*)t0)[22],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[23],a[10]=((C_word*)t0)[15],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)t0)[10])){
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_8769(2,av2);}}
else{
/* c-backend.scm:922: gen */
t5=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[469];
f_4549(4,av2);}}}}}

/* k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in ... */
static void C_ccall f_8490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_8490,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8493,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=C_eqp(lf[328],((C_word*)t0)[9]);
t4=C_i_not(t3);
t5=(C_truep(t4)?C_i_not(((C_word*)t0)[10]):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8515,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=t2,a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[13],a[10]=((C_word*)t0)[14],tmp=(C_word)a,a+=11,tmp);
t7=(C_truep(((C_word*)t0)[15])?C_i_not(((C_word*)t0)[3]):C_SCHEME_FALSE);
if(C_truep(t7)){
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8590,a[2]=((C_word*)t0)[6],a[3]=t9,tmp=(C_word)a,a+=4,tmp));
t11=((C_word*)t9)[1];
f_8590(t11,t6,C_fix(0));}
else{
t8=t6;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_8515(2,av2);}}}
else{
/* c-backend.scm:964: gen */
t6=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t2;
av2[2]=C_make_character(125);
f_4549(3,av2);}}}

/* k8491 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8493(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_8493,c,av);}
a=C_alloc(10);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8497,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8504,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=t3,a[6]=((C_word*)t0)[8],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:967: chicken.compiler.core#lambda-literal-body */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[391]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[391]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k8495 in k8491 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8497,c,av);}
/* c-backend.scm:972: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(125);
f_4549(3,av2);}}

/* k8502 in k8491 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_8504,c,av);}
a=C_alloc(29);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:966: expression */
t3=((C_word*)((C_word*)t0)[4])[1];
f_4722(t3,((C_word*)t0)[5],t1,t2,((C_word*)t0)[6]);}
else{
/* c-backend.scm:966: expression */
t2=((C_word*)((C_word*)t0)[4])[1];
f_4722(t2,((C_word*)t0)[5],t1,((C_word*)t0)[3],((C_word*)t0)[6]);}}

/* k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8515(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,11)))){
C_save_and_reclaim((void *)f_8515,c,av);}
a=C_alloc(8);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8521,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:948: gen */
t3=lf[4];{
C_word *av2;
if(c >= 12) {
  av2=av;
} else {
  av2=C_alloc(12);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[396];
av2[4]=((C_word*)t0)[6];
av2[5]=lf[397];
av2[6]=C_SCHEME_TRUE;
av2[7]=lf[398];
av2[8]=((C_word*)t0)[3];
av2[9]=lf[399];
av2[10]=((C_word*)t0)[7];
av2[11]=lf[400];
f_4549(12,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8555,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t3=(C_truep(((C_word*)t0)[8])?C_i_greaterp(((C_word*)t0)[9],C_fix(0)):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8570,a[2]=t2,a[3]=((C_word*)t0)[10],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:957: gen */
t5=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[404];
av2[4]=((C_word*)t0)[6];
av2[5]=C_make_character(44);
av2[6]=((C_word*)t0)[9];
av2[7]=C_make_character(44);
f_4549(8,av2);}}
else{
/* c-backend.scm:961: gen */
t4=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[405];
av2[4]=((C_word*)t0)[6];
av2[5]=lf[406];
f_4549(6,av2);}}}}

/* k8519 in k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,7)))){
C_save_and_reclaim((void *)f_8521,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8524,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:950: gen */
t3=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[393];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[394];
av2[6]=((C_word*)t0)[2];
av2[7]=lf[395];
f_4549(8,av2);}}

/* k8522 in k8519 in k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in ... */
static void C_ccall f_8524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(34,c,4)))){
C_save_and_reclaim((void *)f_8524,c,av);}
a=C_alloc(34);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8533,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_8533(t6,((C_word*)t0)[3],t2,((C_word*)t0)[4]);}

/* doloop1699 in k8522 in k8519 in k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in ... */
static void C_fcall f_8533(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_8533,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_zerop(t3))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8541,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:954: gen */
t5=lf[4];{
C_word av2[6];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[392];
av2[4]=t2;
av2[5]=C_make_character(59);
f_4549(6,av2);}}}

/* k8539 in doloop1699 in k8522 in k8519 in k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in ... */
static void C_ccall f_8541(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,3)))){
C_save_and_reclaim((void *)f_8541,c,av);}
a=C_alloc(58);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[3],C_fix(1));
t4=((C_word*)((C_word*)t0)[4])[1];
f_8533(t4,((C_word*)t0)[5],t2,t3);}

/* k8553 in k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8555(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_8555,c,av);}
if(C_truep(C_i_greaterp(((C_word*)t0)[2],C_fix(0)))){
/* c-backend.scm:963: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[401];
av2[4]=((C_word*)t0)[2];
av2[5]=lf[402];
f_4549(6,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_8493(2,av2);}}}

/* k8568 in k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8570(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_8570,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8573,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=lf[4];
av2[3]=((C_word*)t0)[3];
C_apply(4,av2);}}

/* k8571 in k8568 in k8513 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in ... */
static void C_ccall f_8573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8573,c,av);}
/* c-backend.scm:959: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[403];
f_4549(3,av2);}}

/* doloop1691 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_fcall f_8590(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,7)))){
C_save_and_reclaim_args((void *)trf_8590,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8600,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:946: gen */
t4=lf[4];{
C_word av2[8];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[407];
av2[4]=t2;
av2[5]=lf[408];
av2[6]=t2;
av2[7]=lf[409];
f_4549(8,av2);}}}

/* k8598 in doloop1691 in k8488 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8600(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_8600,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_8590(t3,((C_word*)t0)[4],t2);}

/* k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in ... */
static void C_ccall f_8630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,9)))){
C_save_and_reclaim((void *)f_8630,c,av);}
a=C_alloc(9);
t2=C_u_i_length(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8634,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
t4=C_fast_retrieve(lf[297]);
if(C_truep(C_fast_retrieve(lf[297]))){
t5=C_fast_retrieve(lf[297]);
t6=C_fast_retrieve(lf[297]);
/* c-backend.scm:888: gen */
t7=lf[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t7;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[441];
av2[4]=C_SCHEME_TRUE;
av2[5]=lf[442];
av2[6]=C_SCHEME_TRUE;
av2[7]=lf[443];
av2[8]=C_fast_retrieve(lf[297]);
av2[9]=lf[444];
f_4549(10,av2);}}
else{
/* c-backend.scm:888: gen */
t5=lf[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[441];
av2[4]=C_SCHEME_TRUE;
av2[5]=lf[442];
av2[6]=C_SCHEME_TRUE;
av2[7]=lf[443];
av2[8]=((C_word*)t0)[7];
av2[9]=lf[444];
f_4549(10,av2);}}}

/* k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8634(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_8634,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8637,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_fast_retrieve(lf[187]))){
/* c-backend.scm:892: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[440];
f_4549(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8637(2,av2);}}}

/* k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8637(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_8637,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8640,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_fast_retrieve(lf[438]))){
/* c-backend.scm:894: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[439];
f_4549(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8640(2,av2);}}}

/* k8638 in k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in ... */
static void C_ccall f_8640(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,7)))){
C_save_and_reclaim((void *)f_8640,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8643,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_fast_retrieve(lf[297]))){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8643(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8672,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_fast_retrieve(lf[434]))){
/* c-backend.scm:897: gen */
t4=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[435];
av2[4]=C_fast_retrieve(lf[434]);
av2[5]=lf[436];
av2[6]=C_SCHEME_TRUE;
av2[7]=lf[437];
f_4549(8,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_8672(2,av2);}}}}

/* k8641 in k8638 in k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in ... */
static void C_ccall f_8643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,35)))){
C_save_and_reclaim((void *)f_8643,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8646,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:901: gen */
t3=lf[4];{
C_word *av2;
if(c >= 36) {
  av2=av;
} else {
  av2=C_alloc(36);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[414];
av2[4]=((C_word*)t0)[5];
av2[5]=lf[415];
av2[6]=((C_word*)t0)[6];
av2[7]=lf[416];
av2[8]=C_SCHEME_TRUE;
av2[9]=lf[417];
av2[10]=((C_word*)t0)[5];
av2[11]=lf[418];
av2[12]=((C_word*)t0)[6];
av2[13]=lf[419];
av2[14]=C_SCHEME_TRUE;
av2[15]=lf[420];
av2[16]=((C_word*)t0)[7];
av2[17]=lf[421];
av2[18]=C_SCHEME_TRUE;
av2[19]=lf[422];
av2[20]=C_SCHEME_TRUE;
av2[21]=lf[423];
av2[22]=((C_word*)t0)[8];
av2[23]=lf[424];
av2[24]=C_SCHEME_TRUE;
av2[25]=lf[425];
av2[26]=C_SCHEME_TRUE;
av2[27]=lf[426];
av2[28]=((C_word*)t0)[8];
av2[29]=lf[427];
av2[30]=C_SCHEME_TRUE;
av2[31]=lf[428];
av2[32]=C_SCHEME_TRUE;
av2[33]=lf[429];
av2[34]=((C_word*)t0)[5];
av2[35]=lf[430];
f_4549(36,av2);}}

/* k8644 in k8641 in k8638 in k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in ... */
static void C_ccall f_8646(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_8646,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8649,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_eqp(((C_word*)t0)[3],C_fix(0));
if(C_truep(C_i_not(t3))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8658,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:911: gen */
t5=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[412];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[413];
f_4549(6,av2);}}
else{
/* c-backend.scm:914: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(123);
f_4549(3,av2);}}}

/* k8647 in k8644 in k8641 in k8638 in k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in ... */
static void C_ccall f_8649(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8649,c,av);}
/* c-backend.scm:914: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(123);
f_4549(3,av2);}}

/* k8656 in k8644 in k8641 in k8638 in k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in ... */
static void C_ccall f_8658(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8658,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8661,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:912: literal-frame */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7807(t3,t2);}

/* k8659 in k8656 in k8644 in k8641 in k8638 in k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in ... */
static void C_ccall f_8661(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_8661,c,av);}
/* c-backend.scm:913: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[410];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[411];
f_4549(6,av2);}}

/* k8670 in k8638 in k8635 in k8632 in k8628 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in ... */
static void C_ccall f_8672(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_8672,c,av);}
if(C_truep(C_fast_retrieve(lf[431]))){
/* c-backend.scm:900: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[432];
av2[4]=C_fast_retrieve(lf[431]);
av2[5]=lf[433];
f_4549(6,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_8643(2,av2);}}}

/* foldl1644 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in ... */
static void C_fcall f_8693(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_8693,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8709,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8720,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:886: g1651 */
t7=t5;
f_8709(t7,t6,t3,C_slot(t2,C_fix(0)));}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* g1651 in foldl1644 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_fcall f_8709(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_8709,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8717,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:886: literal-size */
t5=((C_word*)((C_word*)t0)[2])[1];
f_7861(t5,t4,t3);}

/* k8715 in g1651 in foldl1644 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_8717,c,av);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8718 in foldl1644 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8720,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_8693(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k8728 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in ... */
static void C_ccall f_8730(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_8730,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8733,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8745,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_not(C_fast_retrieve(lf[177])))){
if(C_truep(C_i_not(C_fast_retrieve(lf[454])))){
t4=C_i_greaterp(((C_word*)t0)[3],C_fix(2));
t5=t3;
f_8745(t5,(C_truep(t4)?C_i_not(((C_word*)t0)[6]):C_SCHEME_FALSE));}
else{
t4=t3;
f_8745(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_8745(t4,C_SCHEME_FALSE);}}

/* k8731 in k8728 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8733(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,9)))){
C_save_and_reclaim((void *)f_8733,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8736,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fast_retrieve(lf[449]))){
/* c-backend.scm:919: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[450];
f_4549(4,av2);}}
else{
/* c-backend.scm:920: gen */
t3=lf[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[445];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[446];
av2[6]=((C_word*)t0)[4];
av2[7]=lf[447];
av2[8]=((C_word*)t0)[5];
av2[9]=lf[448];
f_4549(10,av2);}}}

/* k8734 in k8731 in k8728 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_8736,c,av);}
/* c-backend.scm:920: gen */
t2=lf[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[445];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[446];
av2[6]=((C_word*)t0)[4];
av2[7]=lf[447];
av2[8]=((C_word*)t0)[5];
av2[9]=lf[448];
f_4549(10,av2);}}

/* k8743 in k8728 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_fcall f_8745(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,7)))){
C_save_and_reclaim_args((void *)trf_8745,2,t0,t1);}
if(C_truep(t1)){
/* c-backend.scm:918: gen */
t2=lf[4];{
C_word av2[8];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[451];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[452];
av2[6]=((C_word*)t0)[3];
av2[7]=lf[453];
f_4549(8,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_8733(2,av2);}}}

/* k8767 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in ... */
static void C_ccall f_8769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_8769,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8772,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)t0)[2])){
if(C_truep(C_i_not(C_fast_retrieve(lf[177])))){
if(C_truep(C_i_not(C_fast_retrieve(lf[438])))){
/* c-backend.scm:924: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[468];
f_4549(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8772(2,av2);}}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8772(2,av2);}}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8772(2,av2);}}}

/* k8770 in k8767 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_8772,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8775,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[10])){
/* c-backend.scm:925: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[467];
f_4549(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8775(2,av2);}}}

/* k8773 in k8770 in k8767 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in ... */
static void C_ccall f_8775(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_8775,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8778,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8803,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[9])){
if(C_truep(C_i_not(C_fast_retrieve(lf[177])))){
t4=C_i_not(C_fast_retrieve(lf[454]));
t5=t3;
f_8803(t5,(C_truep(t4)?C_i_not(((C_word*)t0)[3]):C_SCHEME_FALSE));}
else{
t4=t3;
f_8803(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_8803(t4,C_SCHEME_FALSE);}}

/* k8776 in k8773 in k8770 in k8767 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in ... */
static void C_ccall f_8778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_8778,c,av);}
a=C_alloc(6);
if(C_truep(C_i_not(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8787,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fast_retrieve(lf[449]))){
/* c-backend.scm:934: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[460];
f_4549(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8787(2,av2);}}}
else{
/* c-backend.scm:940: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
av2[2]=C_make_character(123);
f_4549(3,av2);}}}

/* k8785 in k8776 in k8773 in k8770 in k8767 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in ... */
static void C_ccall f_8787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_8787,c,av);}
if(C_truep(((C_word*)t0)[2])){
/* c-backend.scm:935: gen */
t2=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[456];
av2[4]=((C_word*)t0)[4];
av2[5]=lf[457];
av2[6]=((C_word*)t0)[5];
av2[7]=lf[458];
f_4549(8,av2);}}
else{
/* c-backend.scm:935: gen */
t2=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[456];
av2[4]=((C_word*)t0)[4];
av2[5]=lf[459];
av2[6]=((C_word*)t0)[5];
av2[7]=lf[458];
f_4549(8,av2);}}}

/* k8801 in k8773 in k8770 in k8767 in k8485 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in ... */
static void C_fcall f_8803(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,7)))){
C_save_and_reclaim_args((void *)trf_8803,2,t0,t1);}
if(C_truep(t1)){
t2=C_eqp(((C_word*)t0)[2],lf[285]);
if(C_truep(t2)){
if(C_truep(C_i_greaterp(((C_word*)t0)[3],C_fix(2)))){
/* c-backend.scm:929: gen */
t3=lf[4];{
C_word av2[8];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[461];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[462];
av2[6]=((C_word*)t0)[3];
av2[7]=lf[463];
f_4549(8,av2);}}
else{
t3=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8778(2,av2);}}}
else{
/* c-backend.scm:930: gen */
t3=lf[4];{
C_word av2[8];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[464];
av2[4]=((C_word*)t0)[3];
av2[5]=lf[465];
av2[6]=((C_word*)t0)[3];
av2[7]=lf[466];
f_4549(8,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_8778(2,av2);}}}

/* k8861 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in ... */
static void C_ccall f_8863(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_8863,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[93]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8876,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_8876(t6,((C_word*)t0)[3],((C_word*)t0)[2]);}

/* for-each-loop1620 in k8861 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in ... */
static void C_fcall f_8876(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,5)))){
C_save_and_reclaim_args((void *)trf_8876,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8886,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:883: gen */
t4=lf[4];{
C_word av2[6];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[471];
av2[4]=C_slot(t2,C_fix(0));
av2[5]=C_make_character(59);
f_4549(6,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k8884 in for-each-loop1620 in k8861 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8886(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8886,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_8876(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k8899 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in ... */
static void C_fcall f_8901(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_8901,2,t0,t1);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8903,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_8903(t5,((C_word*)t0)[2],((C_word*)t0)[3],t1);}

/* doloop1612 in k8899 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in ... */
static void C_fcall f_8903(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_8903,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_zerop(t3))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8911,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:880: gen */
t5=lf[4];{
C_word av2[6];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[472];
av2[4]=t2;
av2[5]=C_make_character(59);
f_4549(6,av2);}}}

/* k8909 in doloop1612 in k8899 in k8482 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in ... */
static void C_ccall f_8911(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,3)))){
C_save_and_reclaim((void *)f_8911,c,av);}
a=C_alloc(58);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[3],C_fix(1));
t4=((C_word*)((C_word*)t0)[4])[1];
f_8903(t4,((C_word*)t0)[5],t2,t3);}

/* doloop1607 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in ... */
static void C_fcall f_8931(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,7)))){
C_save_and_reclaim_args((void *)trf_8931,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8941,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:873: gen */
t4=lf[4];{
C_word av2[8];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[473];
av2[4]=t2;
av2[5]=lf[474];
av2[6]=t2;
av2[7]=lf[475];
f_4549(8,av2);}}}

/* k8939 in doloop1607 in k8479 in k8476 in k8473 in k8470 in k8467 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in ... */
static void C_ccall f_8941(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_8941,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_8931(t3,((C_word*)t0)[4],t2);}

/* k8963 in k8464 in k8461 in k8458 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in ... */
static void C_ccall f_8965(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8965,c,av);}
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
/* c-backend.scm:863: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(44);
f_4549(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_8469(2,av2);}}}

/* k8986 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in ... */
static void C_ccall f_8988(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8988,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8991,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[5])){
/* c-backend.scm:849: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[483];
f_4549(3,av2);}}
else{
/* c-backend.scm:849: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[484];
f_4549(3,av2);}}}

/* k8989 in k8986 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in ... */
static void C_ccall f_8991(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8991,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8994,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
/* c-backend.scm:851: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[481];
f_4549(3,av2);}}
else{
/* c-backend.scm:852: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[482];
f_4549(3,av2);}}}

/* k8992 in k8989 in k8986 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in ... */
static void C_ccall f_8994(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8994,c,av);}
/* c-backend.scm:853: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
f_4549(3,av2);}}

/* k9008 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in ... */
static void C_ccall f_9010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_9010,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9013,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_fast_retrieve(lf[297]))){
/* c-backend.scm:858: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[486];
av2[5]=((C_word*)t0)[3];
f_4549(6,av2);}}
else{
/* c-backend.scm:857: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[487];
f_4549(4,av2);}}}

/* k9011 in k9008 in k8455 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in ... */
static void C_ccall f_9013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9013,c,av);}
/* c-backend.scm:858: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[486];
av2[5]=((C_word*)t0)[3];
f_4549(6,av2);}}

/* k9025 in k8452 in k8449 in k8446 in k8443 in k8440 in k8437 in k8434 in k8431 in k8428 in k8425 in k8422 in k8419 in k8416 in k8410 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in ... */
static void C_ccall f_9027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9027,c,av);}
/* c-backend.scm:846: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[489];
av2[3]=t1;
av2[4]=lf[490];
av2[5]=C_SCHEME_TRUE;
f_4549(6,av2);}}

/* k9050 in k8407 in k8404 in k8401 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9052(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9052,c,av);}
t2=((C_word*)t0)[2];
f_8412(t2,C_i_zerop(t1));}

/* k9054 in k8398 in k8395 in k8392 in g1550 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9056,c,av);}{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[500]+1);
av2[3]=C_fix(0);
av2[4]=t1;
C_apply(5,av2);}}

/* for-each-loop1549 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9064(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9064,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9074,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:821: g1550 */
t4=((C_word*)t0)[3];
f_8386(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9072 in for-each-loop1549 in procedures in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9074(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9074,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9064(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9088(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_9088,c,av);}
a=C_alloc(11);
t2=C_mutate(&lf[3] /* (set! chicken.compiler.c-backend#output ...) */,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9092,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:977: header */
t4=((C_word*)((C_word*)t0)[12])[1];
f_7145(t4,t3);}

/* k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_9092,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9095,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* c-backend.scm:978: declarations */
t3=((C_word*)((C_word*)t0)[10])[1];
f_7304(t3,t2);}

/* k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9095(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_9095,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9098,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t3=C_fast_retrieve(lf[660]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9459,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1077: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}

/* k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9098(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_9098,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9101,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t3=C_fast_retrieve(lf[614]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9557,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp);
t5=C_fast_retrieve(lf[614]);
t6=C_i_check_list_2(C_fast_retrieve(lf[614]),lf[93]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9870,a[2]=t8,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_9870(t10,t2,C_fast_retrieve(lf[614]));}

/* k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9101(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_9101,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9104,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* c-backend.scm:981: prototypes */
t3=((C_word*)((C_word*)t0)[9])[1];
f_7508(t3,t2);}

/* k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9104(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_9104,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9107,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=C_fast_retrieve(lf[289]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9895,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp);
t5=C_fast_retrieve(lf[289]);
t6=C_i_check_list_2(C_fast_retrieve(lf[289]),lf[93]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10524,a[2]=t8,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_10524(t10,t2,C_fast_retrieve(lf[289]));}

/* k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9107(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_9107,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9110,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:983: trampolines */
t3=((C_word*)((C_word*)t0)[7])[1];
f_7686(t3,t2);}

/* k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9110(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_9110,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9113,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fast_retrieve(lf[187]))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9134,a[2]=t2,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:994: gen */
t4=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[534];
f_4549(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_9113(2,av2);}}}

/* k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9113(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9113,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9116,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:986: procedures */
t3=((C_word*)((C_word*)t0)[5])[1];
f_8384(t3,t2);}

/* k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9116(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,8)))){
C_save_and_reclaim((void *)f_9116,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9119,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9255,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_i_length(((C_word*)t0)[4]);
t5=C_a_i_fixnum_plus(&a,2,t4,C_fix(1));
/* c-backend.scm:1012: gen */
t6=lf[4];{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t6;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[523];
av2[5]=C_SCHEME_TRUE;
av2[6]=lf[524];
av2[7]=t5;
av2[8]=lf[525];
f_4549(9,av2);}}

/* k9117 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_9119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_9119,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7298,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7302,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:630: chicken.base#get-output-string */
t4=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_fast_retrieve(lf[506]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_9134,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9203,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9237,tmp=(C_word)a,a+=2,tmp);
/* c-backend.scm:1005: chicken.sort#sort */
t4=C_fast_retrieve(lf[533]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k9137 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_9139(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_9139,c,av);}
a=C_alloc(8);
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[93]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9170,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9175,a[2]=t6,tmp=(C_word)a,a+=3,tmp));
t8=((C_word*)t6)[1];
f_9175(t8,t4,t2);}

/* k9155 in for-each-loop1782 in k9137 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_9157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9157,c,av);}
/* c-backend.scm:1002: gen */
t2=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[529];
av2[3]=t1;
av2[4]=lf[530];
f_4549(5,av2);}}

/* k9159 in for-each-loop1782 in k9137 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_9161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9161,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f14896,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:74: chicken.string#->string */
t3=C_fast_retrieve(lf[120]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k9168 in k9137 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_9170(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9170,c,av);}
/* c-backend.scm:1004: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[527];
f_4549(3,av2);}}

/* for-each-loop1782 in k9137 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_fcall f_9175(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_9175,3,t0,t1,t2);}
a=C_alloc(11);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9185,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
if(C_truep(C_i_not(t4))){
/* c-backend.scm:1001: gen */
t5=lf[4];{
C_word av2[3];
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[528];
f_4549(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9157,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9161,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1002: chicken.string#->string */
t7=C_fast_retrieve(lf[120]);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9183 in for-each-loop1782 in k9137 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_9185(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9185,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9175(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_9203,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[93]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9209,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9214,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_9214(t7,t3,t1);}

/* k9207 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_9209(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9209,c,av);}
/* c-backend.scm:1006: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[526];
f_4549(4,av2);}}

/* for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_fcall f_9214(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_9214,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9224,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9139,a[2]=t4,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:997: gen */
t6=lf[4];{
C_word av2[6];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[531];
av2[4]=C_i_cadr(t4);
av2[5]=lf[532];
f_4549(6,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9222 in for-each-loop1769 in k9201 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_9224(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9224,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9214(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* a9236 in k9132 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9237,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_lessp(C_i_car(t2),C_i_car(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_9255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_9255,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9256,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9287,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9301,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_9301(t7,t3,((C_word*)t0)[4]);}

/* g1815 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_fcall f_9256(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_9256,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9264,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9284,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1018: chicken.internal#string->c-identifier */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[512]);
C_word av2[3];
av2[0]=*((C_word*)lf[512]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k9262 in g1815 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_9264(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9264,c,av);}
a=C_alloc(3);
t2=C_eqp(lf[328],((C_word*)t0)[2]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9277,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1020: toplevel */
t4=lf[224];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_fast_retrieve(lf[297]);
f_9329(3,av2);}}
else{
/* c-backend.scm:1021: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[2];
av2[3]=lf[509];
f_4549(4,av2);}}}

/* k9275 in k9262 in g1815 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_9277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9277,c,av);}
/* c-backend.scm:1020: gen */
t2=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[507];
av2[3]=t1;
av2[4]=lf[508];
f_4549(5,av2);}}

/* k9282 in g1815 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_9284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_9284,c,av);}
/* c-backend.scm:1018: gen */
t2=lf[4];{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[510];
av2[4]=((C_word*)t0)[3];
av2[5]=C_make_character(58);
av2[6]=t1;
av2[7]=lf[511];
f_4549(8,av2);}}

/* k9285 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_9287(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9287,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9290,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1023: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[522];
f_4549(4,av2);}}

/* k9288 in k9285 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_9290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9290,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9293,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1024: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[521];
f_4549(4,av2);}}

/* k9291 in k9288 in k9285 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_9293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_9293,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9296,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1025: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[520];
f_4549(5,av2);}}

/* k9294 in k9291 in k9288 in k9285 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_9296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,14)))){
C_save_and_reclaim((void *)f_9296,c,av);}
/* c-backend.scm:1026: gen */
t2=lf[4];{
C_word *av2;
if(c >= 15) {
  av2=av;
} else {
  av2=C_alloc(15);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[513];
av2[3]=C_SCHEME_TRUE;
av2[4]=lf[514];
av2[5]=C_SCHEME_TRUE;
av2[6]=lf[515];
av2[7]=C_SCHEME_TRUE;
av2[8]=lf[516];
av2[9]=C_SCHEME_TRUE;
av2[10]=lf[517];
av2[11]=C_SCHEME_TRUE;
av2[12]=lf[518];
av2[13]=C_SCHEME_TRUE;
av2[14]=lf[519];
f_4549(15,av2);}}

/* for-each-loop1814 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_fcall f_9301(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9301,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9311,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1014: g1815 */
t4=((C_word*)t0)[3];
f_9256(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9309 in for-each-loop1814 in k9253 in k9114 in k9111 in k9108 in k9105 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_9311(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9311,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9301(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.compiler.c-backend#toplevel in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9329(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_9329,c,av);}
a=C_alloc(6);
if(C_truep(C_i_not(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[670];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9343,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4657,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:76: chicken.string#->string */
t5=C_fast_retrieve(lf[120]);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k9341 in chicken.compiler.c-backend#toplevel in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9343(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9343,c,av);}
/* c-backend.scm:1039: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[671];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.compiler.c-backend#cleanup in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9345(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_9345,2,t1,t2);}
a=C_alloc(10);
t3=C_SCHEME_FALSE;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_i_string_length(t2);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9354,a[2]=t5,a[3]=t4,a[4]=t2,a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t9=((C_word*)t7)[1];
f_9354(t9,t1,C_fix(0));}

/* loop in chicken.compiler.c-backend#cleanup in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9354(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,2)))){
C_save_and_reclaim_args((void *)trf_9354,3,t0,t1,t2);}
a=C_alloc(18);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t3=((C_word*)((C_word*)t0)[3])[1];
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=(C_truep(t3)?t3:((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_string_ref(((C_word*)t0)[4],t2);
t4=C_u_i_char_lessp(t3,C_make_character(32));
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9380,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[5],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=t3,tmp=(C_word)a,a+=8,tmp);
if(C_truep(t4)){
t6=t5;
f_9380(t6,t4);}
else{
t6=C_u_i_char_greaterp(t3,C_make_character(126));
if(C_truep(t6)){
t7=t5;
f_9380(t7,t6);}
else{
if(C_truep(C_u_i_char_equalp(t3,C_make_character(42)))){
t7=C_a_i_fixnum_difference(&a,2,((C_word*)t0)[2],C_fix(1));
if(C_truep(C_i_integer_lessp(t2,t7))){
t8=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t9=t5;
f_9380(t9,C_u_i_char_equalp(C_make_character(47),C_i_string_ref(((C_word*)t0)[4],t8)));}
else{
t8=t5;
f_9380(t8,C_SCHEME_FALSE);}}
else{
t7=t5;
f_9380(t7,C_SCHEME_FALSE);}}}}}

/* k9378 in loop in chicken.compiler.c-backend#cleanup in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9380(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9380,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=C_i_string_set(((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3],C_make_character(126));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:1058: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_9354(t4,((C_word*)t0)[5],t3);}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9390,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1055: scheme#string-copy */
t3=C_fast_retrieve(lf[672]);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}
else{
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=C_i_string_set(((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3],((C_word*)t0)[7]);
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:1058: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_9354(t4,((C_word*)t0)[5],t3);}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:1058: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_9354(t3,((C_word*)t0)[5],t2);}}}

/* k9388 in k9378 in loop in chicken.compiler.c-backend#cleanup in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9390,c,av);}
a=C_alloc(5);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_i_string_set(((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3],C_make_character(126));
t4=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* c-backend.scm:1058: loop */
t5=((C_word*)((C_word*)t0)[4])[1];
f_9354(t5,((C_word*)t0)[5],t4);}

/* chicken.compiler.c-backend#make-variable-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9421(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_9421,3,t1,t2,t3);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9427,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1064: list-tabulate */
f_4281(t1,t2,t4);}

/* a9426 in chicken.compiler.c-backend#make-variable-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9427(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9427,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9435,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=C_fix(10);
tp(4,av2);}}

/* k9433 in a9426 in chicken.compiler.c-backend#make-variable-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9435(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9435,c,av);}
/* c-backend.scm:1066: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[673];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.compiler.c-backend#make-argument-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9438(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_9438,3,t1,t2,t3);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9444,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1069: list-tabulate */
f_4281(t1,t2,t4);}

/* a9443 in chicken.compiler.c-backend#make-argument-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9444(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9444,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9452,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[146]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[146]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=C_fix(10);
tp(4,av2);}}

/* k9450 in a9443 in chicken.compiler.c-backend#make-argument-list in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9452,c,av);}
/* c-backend.scm:1071: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k9457 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_9459,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[93]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9489,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_9489(t6,((C_word*)t0)[3],((C_word*)t0)[2]);}

/* k9479 in for-each-loop1873 in k9457 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9481(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9481,c,av);}
/* c-backend.scm:1083: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
av2[5]=C_make_character(59);
f_4549(6,av2);}}

/* for-each-loop1873 in k9457 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9489(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_9489,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9499,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=C_i_vector_ref(t4,C_fix(0));
t6=C_i_vector_ref(t4,C_fix(1));
t7=C_i_vector_ref(t4,C_fix(2));
t8=(C_truep(t7)?lf[661]:lf[662]);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9481,a[2]=t3,a[3]=t8,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1083: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t9;
av2[2]=t6;
av2[3]=t5;
tp(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9497 in for-each-loop1873 in k9457 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9499(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9499,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9489(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9512(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_9512,2,t1,t2);}
a=C_alloc(5);
t3=C_i_check_list_2(t2,lf[93]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9532,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_9532(t7,t1,t2);}

/* k9516 in for-each-loop1897 in chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9518(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9518,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9521,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1093: generate-foreign-callback-header */
f_10547(t2,lf[674],((C_word*)t0)[3]);}

/* k9519 in k9516 in for-each-loop1897 in chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9521,c,av);}
/* c-backend.scm:1094: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(59);
f_4549(3,av2);}}

/* for-each-loop1897 in chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9532(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_9532,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9542,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9518,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1092: gen */
t6=lf[4];{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9540 in for-each-loop1897 in chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9542,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9532(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9557(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9557,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9561,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1100: chicken.compiler.core#foreign-stub-id */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[659]);
C_word av2[3];
av2[0]=*((C_word*)lf[659]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_9561,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9564,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1101: chicken.compiler.support#real-name2 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[612]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[612]+1);
av2[1]=t2;
av2[2]=t1;
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}

/* k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_9564,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9567,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1102: chicken.compiler.core#foreign-stub-argument-types */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[658]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[658]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_9567,c,av);}
a=C_alloc(8);
t2=C_i_length(t1);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9573,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t1,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* c-backend.scm:1104: chicken.compiler.core#foreign-stub-return-type */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[657]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[657]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_9573,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9576,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* c-backend.scm:1105: chicken.compiler.core#foreign-stub-name */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[656]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[656]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}

/* k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9576(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_9576,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9579,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* c-backend.scm:1106: chicken.compiler.core#foreign-stub-body */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[655]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[655]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
tp(3,av2);}}

/* k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_9579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_9579,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9582,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* c-backend.scm:1107: chicken.compiler.core#foreign-stub-argument-names */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[654]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[654]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
tp(3,av2);}}

/* k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_9582(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_9582,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9585,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(t1)){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
f_9585(2,av2);}}
else{
t3=C_a_i_list(&a,1,C_SCHEME_FALSE);
if(C_truep(C_i_nullp(t3))){
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f14917,tmp=(C_word)a,a+=2,tmp);
/* mini-srfi-1.scm:228: list-tabulate */
f_4281(t2,((C_word*)t0)[5],t4);}
else{
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4473,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:228: list-tabulate */
f_4281(t2,((C_word*)t0)[5],t5);}}}

/* k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_ccall f_9585(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_9585,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9588,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* c-backend.scm:1108: foreign-result-conversion */
f_12382(t2,((C_word*)t0)[4],lf[653]);}

/* k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_ccall f_9588(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_9588,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9591,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* c-backend.scm:1109: chicken.compiler.core#foreign-stub-cps */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[652]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[11];
tp(3,av2);}}

/* k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_ccall f_9591(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_9591,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9594,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* c-backend.scm:1110: chicken.compiler.core#foreign-stub-callback */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[651]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[651]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
tp(3,av2);}}

/* k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_ccall f_9594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_9594,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_9597,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* c-backend.scm:1111: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}

/* k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_ccall f_9597(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_9597,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9600,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
if(C_truep(((C_word*)t0)[13])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9859,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1113: cleanup */
f_9345(t3,((C_word*)t0)[13]);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_9600(2,av2);}}}

/* k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in ... */
static void C_ccall f_9600(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,5)))){
C_save_and_reclaim((void *)f_9600,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9603,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
if(C_truep(((C_word*)t0)[4])){
/* c-backend.scm:1115: gen */
t3=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[647];
av2[4]=((C_word*)t0)[10];
av2[5]=lf[648];
f_4549(6,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_9603(2,av2);}}}

/* k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in ... */
static void C_ccall f_9603(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,11)))){
C_save_and_reclaim((void *)f_9603,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9606,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[6])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9804,a[2]=((C_word*)t0)[8],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1118: gen */
t4=lf[4];{
C_word *av2;
if(c >= 12) {
  av2=av;
} else {
  av2=C_alloc(12);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[638];
av2[4]=((C_word*)t0)[12];
av2[5]=lf[639];
av2[6]=C_SCHEME_TRUE;
av2[7]=lf[640];
av2[8]=((C_word*)t0)[12];
av2[9]=lf[641];
av2[10]=C_SCHEME_TRUE;
av2[11]=lf[642];
f_4549(12,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9831,a[2]=t2,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1125: gen */
t4=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[646];
av2[4]=((C_word*)t0)[12];
av2[5]=C_make_character(40);
f_4549(6,av2);}}}

/* k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in ... */
static void C_ccall f_9606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_9606,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9609,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* c-backend.scm:1128: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[634];
f_4549(4,av2);}}

/* k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_ccall f_9609(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_9609,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9651,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4461,tmp=(C_word)a,a+=2,tmp);
/* mini-srfi-1.scm:225: list-tabulate */
f_4281(t2,((C_word*)t0)[8],t3);}

/* k9616 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in ... */
static void C_ccall f_9618(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9618,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9622,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1135: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[632];
tp(4,av2);}}

/* k9620 in k9616 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in ... */
static void C_ccall f_9622(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_9622,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9626,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1136: foreign-argument-conversion */
f_11717(t2,((C_word*)t0)[5]);}

/* k9624 in k9620 in k9616 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in ... */
static void C_ccall f_9626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,10)))){
C_save_and_reclaim((void *)f_9626,c,av);}
/* c-backend.scm:1131: gen */
t2=lf[4];{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[3];
av2[4]=lf[629];
av2[5]=((C_word*)t0)[4];
av2[6]=C_make_character(41);
av2[7]=t1;
av2[8]=lf[630];
av2[9]=((C_word*)t0)[5];
av2[10]=lf[631];
f_4549(11,av2);}}

/* k9628 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in ... */
static void C_ccall f_9630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9630,c,av);}
/* c-backend.scm:1132: foreign-type-declaration */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[245]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[245]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k9634 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in ... */
static void C_ccall f_9636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_9636,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[355]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9642,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1134: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[357]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[357]+1);
av2[1]=t3;
av2[2]=C_make_character(116);
av2[3]=t1;
tp(4,av2);}}

/* k9640 in k9634 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in ... */
static void C_ccall f_9642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_9642,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9645,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1134: ##sys#print */
t3=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9643 in k9640 in k9634 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in ... */
static void C_ccall f_9645(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9645,c,av);}
/* c-backend.scm:1134: chicken.base#get-output-string */
t2=C_fast_retrieve(lf[356]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in ... */
static void C_ccall f_9651(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,5)))){
C_save_and_reclaim((void *)f_9651,c,av);}
a=C_alloc(15);
t2=C_i_check_list_2(t1,lf[93]);
t3=C_i_check_list_2(((C_word*)t0)[2],lf[93]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9660,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9752,a[2]=t6,tmp=(C_word)a,a+=3,tmp));
t8=((C_word*)t6)[1];
f_9752(t8,t4,((C_word*)t0)[11],t1,((C_word*)t0)[2]);}

/* k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in ... */
static void C_ccall f_9660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_9660,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9663,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[4])){
/* c-backend.scm:1138: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[628];
f_4549(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_9663(2,av2);}}}

/* k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in ... */
static void C_ccall f_9663(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_9663,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9666,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[3])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9672,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1140: gen */
t4=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=((C_word*)t0)[3];
av2[4]=C_SCHEME_TRUE;
av2[5]=lf[620];
f_4549(6,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9693,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t4=C_eqp(((C_word*)t0)[6],lf[582]);
if(C_truep(C_i_not(t4))){
/* c-backend.scm:1150: gen */
t5=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[627];
av2[4]=((C_word*)t0)[9];
f_4549(5,av2);}}
else{
/* c-backend.scm:1151: gen */
t5=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
f_4549(3,av2);}}}}

/* k9664 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in ... */
static void C_ccall f_9666(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9666,c,av);}
/* c-backend.scm:1161: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(125);
f_4549(3,av2);}}

/* k9670 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in ... */
static void C_ccall f_9672(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_9672,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9675,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1142: gen */
t3=lf[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[619];
av2[4]=C_SCHEME_TRUE;
f_4549(5,av2);}}

/* k9673 in k9670 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in ... */
static void C_ccall f_9675(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9675,c,av);}
if(C_truep(((C_word*)t0)[2])){
/* c-backend.scm:1144: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[615];
av2[4]=C_SCHEME_TRUE;
av2[5]=lf[616];
f_4549(6,av2);}}
else{
if(C_truep(((C_word*)t0)[4])){
/* c-backend.scm:1146: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[617];
f_4549(4,av2);}}
else{
/* c-backend.scm:1147: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[618];
f_4549(4,av2);}}}}

/* k9691 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in ... */
static void C_ccall f_9693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_9693,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9696,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:1152: gen */
t3=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=C_make_character(40);
f_4549(4,av2);}}

/* k9694 in k9691 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in ... */
static void C_ccall f_9696(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_9696,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9699,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9730,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9734,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1153: make-argument-list */
f_9438(t4,((C_word*)t0)[6],lf[626]);}

/* k9697 in k9694 in k9691 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in ... */
static void C_ccall f_9699(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9699,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9702,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_eqp(((C_word*)t0)[5],lf[582]);
if(C_truep(t3)){
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_9702(2,av2);}}
else{
/* c-backend.scm:1154: gen */
t4=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=C_make_character(41);
f_4549(3,av2);}}}

/* k9700 in k9697 in k9694 in k9691 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in ... */
static void C_ccall f_9702(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9702,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9705,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1155: gen */
t3=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[625];
f_4549(3,av2);}}

/* k9703 in k9700 in k9697 in k9694 in k9691 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in ... */
static void C_ccall f_9705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9705,c,av);}
if(C_truep(((C_word*)t0)[2])){
/* c-backend.scm:1157: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[621];
av2[4]=C_SCHEME_TRUE;
av2[5]=lf[622];
f_4549(6,av2);}}
else{
if(C_truep(((C_word*)t0)[4])){
/* c-backend.scm:1159: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[623];
f_4549(3,av2);}}
else{
/* c-backend.scm:1160: gen */
t2=lf[4];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[624];
f_4549(4,av2);}}}}

/* k9728 in k9694 in k9691 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in ... */
static void C_ccall f_9730(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9730,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[4];
av2[3]=t1;
C_apply(4,av2);}}

/* k9732 in k9694 in k9691 in k9661 in k9658 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in ... */
static void C_ccall f_9734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9734,c,av);}
/* c-backend.scm:1153: chicken.base#intersperse */
t2=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in ... */
static void C_fcall f_9752(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_9752,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9759,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_pairp(t2))){
t6=C_i_pairp(t3);
t7=t5;
f_9759(t7,(C_truep(t6)?C_i_pairp(t4):C_SCHEME_FALSE));}
else{
t6=t5;
f_9759(t6,C_SCHEME_FALSE);}}

/* k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in ... */
static void C_fcall f_9759(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,2)))){
C_save_and_reclaim_args((void *)trf_9759,2,t0,t1);}
a=C_alloc(20);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9762,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_slot(((C_word*)t0)[4],C_fix(0));
t4=C_slot(((C_word*)t0)[5],C_fix(0));
t5=C_slot(((C_word*)t0)[6],C_fix(0));
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9618,a[2]=t2,a[3]=t4,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9630,a[2]=t6,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t5)){
/* c-backend.scm:1134: scheme#symbol->string */
t8=*((C_word*)lf[633]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9636,a[2]=t7,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* c-backend.scm:1134: chicken.base#open-output-string */
t9=C_fast_retrieve(lf[360]);{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9760 in k9757 in for-each-loop1950 in k9649 in k9607 in k9604 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in ... */
static void C_ccall f_9762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9762,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9752(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)),C_slot(((C_word*)t0)[6],C_fix(1)));}

/* k9802 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in ... */
static void C_ccall f_9804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9804,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9809,a[2]=((C_word*)t0)[2],a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_9809(t5,((C_word*)t0)[3],C_fix(0));}

/* doloop1963 in k9802 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_fcall f_9809(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(34,0,7)))){
C_save_and_reclaim_args((void *)trf_9809,3,t0,t1,t2);}
a=C_alloc(34);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9819,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t4=C_s_a_i_plus(&a,2,t2,C_fix(3));
/* c-backend.scm:1123: gen */
t5=lf[4];{
C_word av2[8];
av2[0]=t5;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[635];
av2[4]=t2;
av2[5]=lf[636];
av2[6]=t4;
av2[7]=lf[637];
f_4549(8,av2);}}}

/* k9817 in doloop1963 in k9802 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in ... */
static void C_ccall f_9819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_9819,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=((C_word*)((C_word*)t0)[3])[1];
f_9809(t3,((C_word*)t0)[4],t2);}

/* k9829 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in ... */
static void C_ccall f_9831(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_9831,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9834,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9841,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9849,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* c-backend.scm:1126: make-variable-list */
f_9421(t4,((C_word*)t0)[3],lf[645]);}

/* k9832 in k9829 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_ccall f_9834(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9834,c,av);}
/* c-backend.scm:1127: gen */
t2=lf[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[643];
f_4549(3,av2);}}

/* k9839 in k9829 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_ccall f_9841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9841,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[4];
av2[3]=t1;
C_apply(4,av2);}}

/* k9847 in k9829 in k9601 in k9598 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_ccall f_9849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9849,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[644],t1);
/* c-backend.scm:1126: chicken.base#intersperse */
t3=C_fast_retrieve(lf[8]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
av2[3]=C_make_character(44);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k9857 in k9595 in k9592 in k9589 in k9586 in k9583 in k9580 in k9577 in k9574 in k9571 in k9565 in k9562 in k9559 in g1921 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in ... */
static void C_ccall f_9859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9859,c,av);}
/* c-backend.scm:1113: gen */
t2=lf[4];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_TRUE;
av2[3]=lf[649];
av2[4]=t1;
av2[5]=lf[650];
f_4549(6,av2);}}

/* for-each-loop1920 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9870(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9870,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9880,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1098: g1921 */
t4=((C_word*)t0)[3];
f_9557(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9878 in for-each-loop1920 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9880(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9880,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9870(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall f_9895(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9895,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9899,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1167: chicken.compiler.support#foreign-callback-stub-id */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[613]);
C_word av2[3];
av2[0]=*((C_word*)lf[613]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9899(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_9899,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9902,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1168: chicken.compiler.support#real-name2 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[612]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[612]+1);
av2[1]=t2;
av2[2]=t1;
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}

/* k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9902(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_9902,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9905,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* c-backend.scm:1169: chicken.compiler.support#foreign-callback-stub-return-type */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[611]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[611]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_ccall f_9905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_9905,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9908,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* c-backend.scm:1170: chicken.compiler.support#foreign-callback-stub-argument-types */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[610]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[610]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 in ... */
static void C_ccall f_9908(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_9908,c,av);}
a=C_alloc(9);
t2=C_i_length(t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9914,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=t1,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
/* c-backend.scm:1172: make-argument-list */
f_9438(t3,t2,lf[609]);}

/* k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in ... */
static void C_ccall f_9914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,5)))){
C_save_and_reclaim((void *)f_9914,c,av);}
a=C_alloc(21);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9916,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10376,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10490,a[2]=t7,a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_10490(t9,t5,((C_word*)t0)[6],t1,lf[608]);}

/* compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in ... */
static void C_fcall f_9916(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_9916,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
t5=C_eqp(t2,lf[17]);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9926,a[2]=t1,a[3]=t4,a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t5)){
t7=t6;
f_9926(t7,t5);}
else{
t7=C_eqp(t2,lf[579]);
if(C_truep(t7)){
t8=t6;
f_9926(t8,t7);}
else{
t8=C_eqp(t2,lf[580]);
if(C_truep(t8)){
t9=t6;
f_9926(t9,t8);}
else{
t9=C_eqp(t2,lf[581]);
if(C_truep(t9)){
t10=t6;
f_9926(t10,t9);}
else{
t10=C_eqp(t2,lf[14]);
if(C_truep(t10)){
t11=t6;
f_9926(t11,t10);}
else{
t11=C_eqp(t2,lf[582]);
if(C_truep(t11)){
t12=t6;
f_9926(t12,t11);}
else{
t12=C_eqp(t2,lf[583]);
if(C_truep(t12)){
t13=t6;
f_9926(t13,t12);}
else{
t13=C_eqp(t2,lf[584]);
if(C_truep(t13)){
t14=t6;
f_9926(t14,t13);}
else{
t14=C_eqp(t2,lf[585]);
if(C_truep(t14)){
t15=t6;
f_9926(t15,t14);}
else{
t15=C_eqp(t2,lf[586]);
if(C_truep(t15)){
t16=t6;
f_9926(t16,t15);}
else{
t16=C_eqp(t2,lf[587]);
if(C_truep(t16)){
t17=t6;
f_9926(t17,t16);}
else{
t17=C_eqp(t2,lf[588]);
t18=t6;
f_9926(t18,(C_truep(t17)?t17:C_eqp(t2,lf[589])));}}}}}}}}}}}}

/* k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_fcall f_9926(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_9926,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[535]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9935,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_9935(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[4],lf[576]);
if(C_truep(t4)){
t5=t3;
f_9935(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[552]);
if(C_truep(t5)){
t6=t3;
f_9935(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[554]);
if(C_truep(t6)){
t7=t3;
f_9935(t7,t6);}
else{
t7=C_eqp(((C_word*)t0)[4],lf[577]);
t8=t3;
f_9935(t8,(C_truep(t7)?t7:C_eqp(((C_word*)t0)[4],lf[578])));}}}}}}

/* k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in ... */
static void C_fcall f_9935(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_9935,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1181: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[536];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[537]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9947,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_9947(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[4],lf[570]);
if(C_truep(t4)){
t5=t3;
f_9947(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[571]);
if(C_truep(t5)){
t6=t3;
f_9947(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[572]);
if(C_truep(t6)){
t7=t3;
f_9947(t7,t6);}
else{
t7=C_eqp(((C_word*)t0)[4],lf[573]);
if(C_truep(t7)){
t8=t3;
f_9947(t8,t7);}
else{
t8=C_eqp(((C_word*)t0)[4],lf[574]);
t9=t3;
f_9947(t9,(C_truep(t8)?t8:C_eqp(((C_word*)t0)[4],lf[575])));}}}}}}}

/* k9945 in k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in ... */
static void C_fcall f_9947(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_9947,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1184: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[538];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[539]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9959,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_9959(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[4],lf[567]);
if(C_truep(t4)){
t5=t3;
f_9959(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[568]);
t6=t3;
f_9959(t6,(C_truep(t5)?t5:C_eqp(((C_word*)t0)[4],lf[569])));}}}}

/* k9957 in k9945 in k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in ... */
static void C_fcall f_9959(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_9959,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1187: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[540];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[541]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9971,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_9971(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[4],lf[564]);
if(C_truep(t4)){
t5=t3;
f_9971(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[565]);
if(C_truep(t5)){
t6=t3;
f_9971(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[565]);
t7=t3;
f_9971(t7,(C_truep(t6)?t6:C_eqp(((C_word*)t0)[4],lf[566])));}}}}}

/* k9969 in k9957 in k9945 in k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in ... */
static void C_fcall f_9971(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,7)))){
C_save_and_reclaim_args((void *)trf_9971,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1189: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word av2[8];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[542];
av2[4]=((C_word*)t0)[4];
av2[5]=lf[543];
av2[6]=((C_word*)t0)[4];
av2[7]=lf[544];
((C_proc)(void*)(*((C_word*)t2+1)))(8,av2);}}
else{
t2=C_eqp(((C_word*)t0)[5],lf[545]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9983,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_9983(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[5],lf[560]);
if(C_truep(t4)){
t5=t3;
f_9983(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[5],lf[561]);
if(C_truep(t5)){
t6=t3;
f_9983(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[5],lf[562]);
t7=t3;
f_9983(t7,(C_truep(t6)?t6:C_eqp(((C_word*)t0)[5],lf[563])));}}}}}

/* k9981 in k9969 in k9957 in k9945 in k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in chicken.compiler.c-backend#generate-code in ... */
static void C_fcall f_9983(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,5)))){
C_save_and_reclaim_args((void *)trf_9983,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* c-backend.scm:1191: scheme#string-append */
t2=*((C_word*)lf[154]+1);{
C_word av2[6];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[546];
av2[4]=((C_word*)t0)[4];
av2[5]=lf[547];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9989,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_symbolp(((C_word*)t0)[6]))){
/* c-backend.scm:1193: chicken.compiler.support#lookup-foreign-type */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[559]);
C_word av2[3];
av2[0]=*((C_word*)lf[559]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_9989(2,av2);}}}}

/* k9987 in k9981 in k9969 in k9957 in k9945 in k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in k4703 in ... */
static void C_ccall f_9989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_9989,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9993,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* c-backend.scm:1193: g2167 */
t3=t2;
f_9993(t3,((C_word*)t0)[5],t1);}
else{
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
t2=C_u_i_car(((C_word*)t0)[6]);
t3=C_eqp(t2,lf[548]);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10020,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t3)){
t5=t4;
f_10020(t5,t3);}
else{
t5=C_eqp(t2,lf[551]);
if(C_truep(t5)){
t6=t4;
f_10020(t6,t5);}
else{
t6=C_eqp(t2,lf[552]);
if(C_truep(t6)){
t7=t4;
f_10020(t7,t6);}
else{
t7=C_eqp(t2,lf[553]);
if(C_truep(t7)){
t8=t4;
f_10020(t8,t7);}
else{
t8=C_eqp(t2,lf[554]);
if(C_truep(t8)){
t9=t4;
f_10020(t9,t8);}
else{
t9=C_eqp(t2,lf[555]);
if(C_truep(t9)){
t10=t4;
f_10020(t10,t9);}
else{
t10=C_eqp(t2,lf[556]);
if(C_truep(t10)){
t11=t4;
f_10020(t11,t10);}
else{
t11=C_eqp(t2,lf[557]);
t12=t4;
f_10020(t12,(C_truep(t11)?t11:C_eqp(t2,lf[558])));}}}}}}}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* g2167 in k9987 in k9981 in k9969 in k9957 in k9945 in k9933 in k9924 in compute-size in k9912 in k9906 in k9903 in k9900 in k9897 in g2032 in k9102 in k9099 in k9096 in k9093 in k9090 in k9086 in k4706 in ... */
static void C_fcall f_9993(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_9993,3,t0,t1,t2);}
/* c-backend.scm:1194: compute-size */
t3=((C_word*)((C_word*)t0)[2])[1];
f_9916(t3,t1,C_i_vector_ref(t2,C_fix(0)),((C_word*)t0)[3],((C_word*)t0)[4]);}

/* toplevel */
static C_TLS int toplevel_initialized=0;

void C_ccall C_c_2dbackend_toplevel(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(toplevel_initialized) {C_kontinue(t1,C_SCHEME_UNDEFINED);}
else C_toplevel_entry(C_text("c-backend"));
C_check_nursery_minimum(C_calculate_demand(3,c,2));
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void*)C_c_2dbackend_toplevel,c,av);}
toplevel_initialized=1;
if(C_unlikely(!C_demand_2(1737))){
C_save(t1);
C_rereclaim2(1737*sizeof(C_word),1);
t1=C_restore;}
a=C_alloc(3);
C_initialize_lf(lf,885);
lf[0]=C_h_intern(&lf[0],9, C_text("c-backend"));
lf[1]=C_h_intern(&lf[1],27, C_text("chicken.compiler.c-backend#"));
lf[5]=C_h_intern(&lf[5],14, C_text("scheme#newline"));
lf[6]=C_h_intern(&lf[6],14, C_text("scheme#display"));
lf[8]=C_h_intern(&lf[8],24, C_text("chicken.base#intersperse"));
lf[9]=C_h_intern(&lf[9],40, C_text("chicken.compiler.c-backend#generate-code"));
lf[10]=C_h_intern(&lf[10],29, C_text("chicken.compiler.support#bomb"));
lf[11]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021can\047t find lambda"));
lf[12]=C_h_intern(&lf[12],31, C_text("chicken.internal#hash-table-ref"));
lf[13]=C_h_intern(&lf[13],16, C_text("##core#immediate"));
lf[14]=C_h_intern(&lf[14],4, C_text("bool"));
lf[15]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_SCHEME_TRUE"));
lf[16]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_SCHEME_FALSE"));
lf[17]=C_h_intern(&lf[17],4, C_text("char"));
lf[18]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021C_make_character("));
lf[19]=C_h_intern(&lf[19],3, C_text("nil"));
lf[20]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_SCHEME_END_OF_LIST"));
lf[21]=C_h_intern(&lf[21],3, C_text("fix"));
lf[22]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006C_fix("));
lf[23]=C_h_intern(&lf[23],3, C_text("eof"));
lf[24]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_SCHEME_END_OF_FILE"));
lf[25]=C_h_intern(&lf[25],3, C_text("bwp"));
lf[26]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030C_SCHEME_BROKEN_WEAK_PTR"));
lf[27]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015bad immediate"));
lf[28]=C_h_intern(&lf[28],14, C_text("##core#literal"));
lf[29]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013((C_word)li"));
lf[30]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[31]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003lf["));
lf[32]=C_h_intern(&lf[32],12, C_text("##core#float"));
lf[33]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003NAN"));
lf[34]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010INFINITY"));
lf[35]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010(double)"));
lf[36]=C_h_intern(&lf[36],2, C_text("if"));
lf[37]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005else{"));
lf[38]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003)){"));
lf[39]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013if(C_truep("));
lf[40]=C_h_intern(&lf[40],11, C_text("##core#proc"));
lf[41]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010(C_word)"));
lf[42]=C_h_intern(&lf[42],11, C_text("##core#bind"));
lf[43]=C_h_intern(&lf[43],16, C_text("##core#let_float"));
lf[44]=C_h_intern(&lf[44],21, C_text("##core#float-variable"));
lf[45]=C_h_intern(&lf[45],18, C_text("##core#unbox_float"));
lf[46]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[47]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023C_flonum_magnitude("));
lf[48]=C_h_intern(&lf[48],16, C_text("##core#box_float"));
lf[49]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[50]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_flonum(&a,"));
lf[51]=C_h_intern(&lf[51],10, C_text("##core#ref"));
lf[52]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002)["));
lf[53]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012((C_word\052)"));
lf[54]=C_h_intern(&lf[54],15, C_text("##core#rest-car"));
lf[55]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021C_get_rest_arg(c,"));
lf[56]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004,av,"));
lf[57]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004,t0)"));
lf[58]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020C_u_i_list_ref(t"));
lf[59]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001,"));
lf[60]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[61]=C_h_intern(&lf[61],43, C_text("chicken.compiler.core#lambda-literal-direct"));
lf[62]=C_h_intern(&lf[62],49, C_text("chicken.compiler.core#lambda-literal-customizable"));
lf[63]=C_h_intern(&lf[63],51, C_text("chicken.compiler.core#lambda-literal-argument-count"));
lf[64]=C_h_intern(&lf[64],17, C_text("##core#rest-null\077"));
lf[65]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_rest_nullp(c,"));
lf[66]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[67]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036C_mk_bool(C_unfix(C_i_length(t"));
lf[68]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006)) >= "));
lf[69]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[70]=C_h_intern(&lf[70],18, C_text("##core#rest-length"));
lf[71]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_fix(c - "));
lf[72]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[73]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_u_i_length(t"));
lf[74]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[75]=C_h_intern(&lf[75],12, C_text("##core#unbox"));
lf[76]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004)[1]"));
lf[77]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012((C_word\052)"));
lf[78]=C_h_intern(&lf[78],15, C_text("##core#update_i"));
lf[79]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021C_set_block_item("));
lf[80]=C_h_intern(&lf[80],13, C_text("##core#update"));
lf[81]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002)+"));
lf[82]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001,"));
lf[83]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_mutate(((C_word \052)"));
lf[84]=C_h_intern(&lf[84],18, C_text("##core#updatebox_i"));
lf[85]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003,0,"));
lf[86]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021C_set_block_item("));
lf[87]=C_h_intern(&lf[87],16, C_text("##core#updatebox"));
lf[88]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004)+1,"));
lf[89]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_mutate(((C_word \052)"));
lf[90]=C_h_intern(&lf[90],14, C_text("##core#closure"));
lf[91]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002a["));
lf[92]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002]="));
lf[93]=C_h_intern(&lf[93],8, C_text("for-each"));
lf[94]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021tmp=(C_word)a,a+="));
lf[95]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005,tmp)"));
lf[96]=C_h_intern(&lf[96],17, C_text("chicken.base#add1"));
lf[97]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023(\052a=C_CLOSURE_TYPE|"));
lf[98]=C_h_intern(&lf[98],10, C_text("##core#box"));
lf[99]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030,tmp=(C_word)a,a+=2,tmp)"));
lf[100]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031(\052a=C_VECTOR_TYPE|1,a[1]="));
lf[101]=C_h_intern(&lf[101],12, C_text("##core#local"));
lf[102]=C_h_intern(&lf[102],15, C_text("##core#setlocal"));
lf[103]=C_h_intern(&lf[103],13, C_text("##core#global"));
lf[104]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003lf["));
lf[105]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001]"));
lf[106]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_retrieve2(lf["));
lf[107]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011],C_text("));
lf[108]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002))"));
lf[109]=C_h_intern(&lf[109],37, C_text("chicken.compiler.support#c-ify-string"));
lf[110]=C_h_intern(&lf[110],20, C_text("##sys#symbol->string"));
lf[111]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016\052((C_word\052)lf["));
lf[112]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004]+1)"));
lf[113]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023C_fast_retrieve(lf["));
lf[114]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002])"));
lf[115]=C_h_intern(&lf[115],16, C_text("##core#setglobal"));
lf[116]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012 /\052 (set! "));
lf[117]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011 ...) \052/,"));
lf[118]=C_h_intern(&lf[118],32, C_text("chicken.string#string-translate\052"));
lf[119]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\003\000\000\002\376B\000\000\002\052/\376B\000\000\003\052_/\376\377\016"));
lf[120]=C_h_intern(&lf[120],23, C_text("chicken.string#->string"));
lf[121]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_mutate(&lf["));
lf[122]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001]"));
lf[123]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_mutate((C_word\052)lf["));
lf[124]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003]+1"));
lf[125]=C_h_intern(&lf[125],18, C_text("##core#setglobal_i"));
lf[126]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003lf["));
lf[127]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005] /\052 "));
lf[128]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005 \052/ ="));
lf[129]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_set_block_item(lf["));
lf[130]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005] /\052 "));
lf[131]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006 \052/,0,"));
lf[132]=C_h_intern(&lf[132],16, C_text("##core#undefined"));
lf[133]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022C_SCHEME_UNDEFINED"));
lf[134]=C_h_intern(&lf[134],11, C_text("##core#call"));
lf[135]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007,av2);}"));
lf[136]=C_h_intern(&lf[136],40, C_text("chicken.compiler.support#node-parameters"));
lf[137]=C_decode_literal(C_heaptop,C_text("\376B\000\000\0010"));
lf[138]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012goto loop;"));
lf[139]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002c="));
lf[140]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002=t"));
lf[141]=C_h_intern(&lf[141],48, C_text("chicken.compiler.core#lambda-literal-temporaries"));
lf[142]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[143]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006av2);}"));
lf[144]=C_h_intern(&lf[144],19, C_text("##sys#string-append"));
lf[145]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[146]=C_h_intern(&lf[146],20, C_text("##sys#number->string"));
lf[147]=C_h_intern(&lf[147],44, C_text("chicken.compiler.core#lambda-literal-looping"));
lf[148]=C_h_intern(&lf[148],39, C_text("chicken.compiler.core#lambda-literal-id"));
lf[149]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003tp("));
lf[150]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007,av2);}"));
lf[151]=C_h_intern(&lf[151],48, C_text("chicken.compiler.core#no-global-procedure-checks"));
lf[152]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024(void\052)(\052((C_word\052)("));
lf[153]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005)+1))"));
lf[154]=C_h_intern(&lf[154],20, C_text("scheme#string-append"));
lf[155]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003lf["));
lf[156]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001]"));
lf[157]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016\052((C_word\052)lf["));
lf[158]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004]+1)"));
lf[159]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_fast_retrieve_proc("));
lf[160]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[161]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030C_retrieve2_symbol_proc("));
lf[162]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,C_text("));
lf[163]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002))"));
lf[164]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003lf["));
lf[165]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001]"));
lf[166]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_fast_retrieve_proc("));
lf[167]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[168]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016\052((C_word\052)lf["));
lf[169]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004]+1)"));
lf[170]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037C_fast_retrieve_symbol_proc(lf["));
lf[171]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002])"));
lf[172]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016\052((C_word\052)lf["));
lf[173]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004]+1)"));
lf[174]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023{C_proc tp=(C_proc)"));
lf[175]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002)("));
lf[176]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007,av2);}"));
lf[177]=C_h_intern(&lf[177],31, C_text("chicken.compiler.support#unsafe"));
lf[178]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024(void\052)(\052((C_word\052)t"));
lf[179]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004+1))"));
lf[180]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_fast_retrieve_proc(t"));
lf[181]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[182]=C_h_intern(&lf[182],41, C_text("chicken.compiler.core#no-procedure-checks"));
lf[183]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011((C_proc)"));
lf[184]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[185]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002;{"));
lf[186]=C_h_intern(&lf[186],35, C_text("chicken.compiler.support#node-class"));
lf[187]=C_h_intern(&lf[187],37, C_text("chicken.compiler.core#emit-debug-info"));
lf[188]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032C_debugger(&(C_debug_info["));
lf[189]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003]),"));
lf[190]=C_decode_literal(C_heaptop,C_text("\376B\000\000\0060,NULL"));
lf[191]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[192]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004c,av"));
lf[193]=C_h_intern(&lf[193],37, C_text("chicken.compiler.core#emit-trace-info"));
lf[194]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020C_trace(C_text(\042"));
lf[195]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004\042));"));
lf[196]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\003\000\000\002\376B\000\000\001\134\376B\000\000\002\134\134\376\377\016"));
lf[197]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003/\052 "));
lf[198]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003 \052/"));
lf[199]=C_h_intern(&lf[199],49, C_text("chicken.compiler.core#lambda-literal-closure-size"));
lf[200]=C_h_intern(&lf[200],44, C_text("chicken.compiler.support#source-info->string"));
lf[201]=C_h_intern(&lf[201],14, C_text("##core#recurse"));
lf[202]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012goto loop;"));
lf[203]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002=t"));
lf[204]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003t0,"));
lf[205]=C_h_intern(&lf[205],18, C_text("##core#direct_call"));
lf[206]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_a_i(&a,"));
lf[207]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002  "));
lf[208]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032C_debugger(&(C_debug_info["));
lf[209]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003]),"));
lf[210]=C_decode_literal(C_heaptop,C_text("\376B\000\000\0060,NULL"));
lf[211]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002),"));
lf[212]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004c,av"));
lf[213]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_trace(\042"));
lf[214]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\042),"));
lf[215]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003/\052 "));
lf[216]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003 \052/"));
lf[217]=C_h_intern(&lf[217],14, C_text("##core#provide"));
lf[218]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_a_i_provide(&a,1,lf["));
lf[219]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002])"));
lf[220]=C_h_intern(&lf[220],15, C_text("##core#callunit"));
lf[221]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002C_"));
lf[222]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001("));
lf[223]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007,av2);}"));
lf[225]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022C_SCHEME_UNDEFINED"));
lf[226]=C_h_intern(&lf[226],13, C_text("##core#return"));
lf[227]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[228]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007return("));
lf[229]=C_h_intern(&lf[229],13, C_text("##core#inline"));
lf[230]=C_h_intern(&lf[230],18, C_text("##core#debug-event"));
lf[231]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032C_debugger(&(C_debug_info["));
lf[232]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003]),"));
lf[233]=C_decode_literal(C_heaptop,C_text("\376B\000\000\0060,NULL"));
lf[234]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[235]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004c,av"));
lf[236]=C_h_intern(&lf[236],22, C_text("##core#inline_allocate"));
lf[237]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004(&a,"));
lf[238]=C_h_intern(&lf[238],17, C_text("##core#inline_ref"));
lf[240]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001a"));
lf[241]=C_h_intern(&lf[241],20, C_text("##core#inline_update"));
lf[242]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025),C_SCHEME_UNDEFINED)"));
lf[243]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002=("));
lf[245]=C_h_intern(&lf[245],51, C_text("chicken.compiler.c-backend#foreign-type-declaration"));
lf[246]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[247]=C_h_intern(&lf[247],21, C_text("##core#inline_loc_ref"));
lf[248]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003)))"));
lf[249]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\052(("));
lf[250]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021\052)C_data_pointer("));
lf[251]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[252]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001a"));
lf[253]=C_h_intern(&lf[253],24, C_text("##core#inline_loc_update"));
lf[254]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025),C_SCHEME_UNDEFINED)"));
lf[255]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003))="));
lf[256]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004((\052("));
lf[257]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021\052)C_data_pointer("));
lf[258]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[259]=C_h_intern(&lf[259],13, C_text("##core#switch"));
lf[260]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010default:"));
lf[261]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005case "));
lf[262]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002){"));
lf[263]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007switch("));
lf[264]=C_h_intern(&lf[264],11, C_text("##core#cond"));
lf[265]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002)\077"));
lf[266]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011(C_truep("));
lf[267]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010bad form"));
lf[268]=C_h_intern(&lf[268],44, C_text("chicken.compiler.support#node-subexpressions"));
lf[269]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001;"));
lf[270]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004av2["));
lf[271]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002]="));
lf[272]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007av2[0]="));
lf[273]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001;"));
lf[274]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013C_word av2["));
lf[275]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002];"));
lf[276]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_word \052av2=av;"));
lf[277]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001}"));
lf[278]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016  av2=C_alloc("));
lf[279]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[280]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010} else {"));
lf[281]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011  av2=av;"));
lf[282]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010if(c >= "));
lf[283]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003) {"));
lf[284]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_word \052av2;"));
lf[285]=C_h_intern(&lf[285],4, C_text("none"));
lf[286]=C_h_intern(&lf[286],55, C_text("chicken.compiler.core#lambda-literal-rest-argument-mode"));
lf[287]=C_h_intern(&lf[287],43, C_text("chicken.compiler.core#external-protos-first"));
lf[289]=C_h_intern(&lf[289],47, C_text("chicken.compiler.support#foreign-callback-stubs"));
lf[290]=C_h_intern(&lf[290],42, C_text("chicken.compiler.core#foreign-declarations"));
lf[291]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012#include \042"));
lf[292]=C_h_intern(&lf[292],47, C_text("chicken.compiler.c-platform#target-include-file"));
lf[293]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\042"));
lf[294]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\052/"));
lf[295]=C_h_intern(&lf[295],32, C_text("chicken.compiler.core#used-units"));
lf[296]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011   uses: "));
lf[297]=C_h_intern(&lf[297],31, C_text("chicken.compiler.core#unit-name"));
lf[298]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011   unit: "));
lf[299]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022/\052 Generated from "));
lf[300]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030 by the CHICKEN compiler"));
lf[301]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031   http://www.call-cc.org"));
lf[302]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021   command line: "));
lf[303]=C_h_intern(&lf[303],33, C_text("chicken.string#string-intersperse"));
lf[304]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[305]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003   "));
lf[306]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[307]=C_h_intern(&lf[307],27, C_text("chicken.string#string-split"));
lf[308]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[309]=C_h_intern(&lf[309],32, C_text("chicken.platform#chicken-version"));
lf[310]=C_h_intern(&lf[310],3, C_text("map"));
lf[311]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002};"));
lf[312]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002,0"));
lf[313]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026static C_char C_TLS li"));
lf[314]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026[] C_aligned={C_lihdr("));
lf[315]=C_h_intern(&lf[315],25, C_text("##sys#lambda-info->string"));
lf[316]=C_decode_literal(C_heaptop,C_text("\376B\000\000)static double C_possibly_force_alignment;"));
lf[317]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027static C_TLS C_word lf["));
lf[318]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002];"));
lf[319]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_noret_decl(C_"));
lf[320]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[321]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036C_externimport void C_ccall C_"));
lf[322]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036(C_word c,C_word \052av) C_noret;"));
lf[323]=C_decode_literal(C_heaptop,C_text("\376B\000\000+static C_PTABLE_ENTRY \052create_ptable(void);"));
lf[324]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010 C_noret"));
lf[325]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_word \052av"));
lf[326]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_word \052a"));
lf[327]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_word c,"));
lf[328]=C_h_intern(&lf[328],8, C_text("toplevel"));
lf[329]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_fcall "));
lf[330]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_ccall "));
lf[331]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007C_word "));
lf[332]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005void "));
lf[333]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007static "));
lf[334]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_noret_decl("));
lf[335]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[336]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002C_"));
lf[337]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034C_externexport void C_ccall "));
lf[338]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_noret_decl(C_"));
lf[339]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[340]=C_h_intern(&lf[340],46, C_text("chicken.compiler.core#lambda-literal-allocated"));
lf[342]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[343]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003);}"));
lf[345]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[346]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_word t"));
lf[347]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004=av["));
lf[348]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002];"));
lf[349]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026static void C_ccall tr"));
lf[350]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026(C_word c,C_word \052av){"));
lf[351]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_noret_decl(tr"));
lf[352]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[353]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026static void C_ccall tr"));
lf[354]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036(C_word c,C_word \052av) C_noret;"));
lf[355]=C_h_intern(&lf[355],6, C_text("format"));
lf[356]=C_h_intern(&lf[356],30, C_text("chicken.base#get-output-string"));
lf[357]=C_h_intern(&lf[357],18, C_text("##sys#write-char-0"));
lf[358]=C_h_intern(&lf[358],11, C_text("##sys#print"));
lf[359]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003lf["));
lf[360]=C_h_intern(&lf[360],31, C_text("chicken.base#open-output-string"));
lf[361]=C_h_intern(&lf[361],44, C_text("chicken.compiler.c-platform#words-per-flonum"));
lf[362]=C_h_intern(&lf[362],5, C_text("foldl"));
lf[363]=C_h_intern(&lf[363],19, C_text("scheme#vector->list"));
lf[364]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035type of literal not supported"));
lf[365]=C_h_intern(&lf[365],37, C_text("chicken.compiler.support#bytes->words"));
lf[366]=C_h_intern(&lf[366],17, C_text("##sys#bytevector\077"));
lf[367]=C_h_intern(&lf[367],48, C_text("chicken.compiler.support#block-variable-literal\077"));
lf[368]=C_h_intern(&lf[368],24, C_text("chicken.keyword#keyword\077"));
lf[369]=C_h_intern(&lf[369],36, C_text("chicken.compiler.support#big-fixnum\077"));
lf[370]=C_h_intern(&lf[370],35, C_text("chicken.compiler.support#immediate\077"));
lf[371]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007=C_fix("));
lf[372]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[373]=C_h_intern(&lf[373],21, C_text("##sys#undefined-value"));
lf[374]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024=C_SCHEME_UNDEFINED;"));
lf[375]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_SCHEME_TRUE"));
lf[376]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_SCHEME_FALSE"));
lf[377]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022=C_make_character("));
lf[378]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[379]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_h_intern_kw"));
lf[380]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_h_intern"));
lf[381]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002(&"));
lf[382]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011, C_text("));
lf[383]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003));"));
lf[384]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001="));
lf[385]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026=C_SCHEME_END_OF_LIST;"));
lf[386]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003));"));
lf[388]=C_decode_literal(C_heaptop,C_text("\376B\000\000#=C_decode_literal(C_heaptop,C_text("));
lf[389]=C_h_intern(&lf[389],16, C_text("##sys#copy-bytes"));
lf[390]=C_h_intern(&lf[390],18, C_text("scheme#make-string"));
lf[391]=C_h_intern(&lf[391],41, C_text("chicken.compiler.core#lambda-literal-body"));
lf[392]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_word t"));
lf[393]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[394]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023=C_build_rest(&a,c,"));
lf[395]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005,av);"));
lf[396]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032C_save_and_reclaim((void\052)"));
lf[397]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,c,av);}"));
lf[398]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015a=C_alloc((c-"));
lf[399]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020)\052C_SIZEOF_PAIR+"));
lf[400]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[401]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012a=C_alloc("));
lf[402]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[403]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003);}"));
lf[404]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042C_save_and_reclaim_args((void \052)tr"));
lf[405]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033C_save_and_reclaim((void \052)"));
lf[406]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,c,av);}"));
lf[407]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003av["));
lf[408]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003]=t"));
lf[409]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001;"));
lf[410]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022C_register_lf2(lf,"));
lf[411]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022,create_ptable());"));
lf[412]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023C_initialize_lf(lf,"));
lf[413]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[414]=C_decode_literal(C_heaptop,C_text("\376B\000\000+C_check_nursery_minimum(C_calculate_demand("));
lf[415]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003,c,"));
lf[416]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003));"));
lf[417]=C_decode_literal(C_heaptop,C_text("\376B\000\000+if(C_unlikely(!C_demand(C_calculate_demand("));
lf[418]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003,c,"));
lf[419]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005)))){"));
lf[420]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034C_save_and_reclaim((void\052)C_"));
lf[421]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,c,av);}"));
lf[422]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027toplevel_initialized=1;"));
lf[423]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032if(C_unlikely(!C_demand_2("));
lf[424]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004))){"));
lf[425]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013C_save(t1);"));
lf[426]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_rereclaim2("));
lf[427]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023\052sizeof(C_word),1);"));
lf[428]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016t1=C_restore;}"));
lf[429]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012a=C_alloc("));
lf[430]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[431]=C_h_intern(&lf[431],39, C_text("chicken.compiler.core#target-stack-size"));
lf[432]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_resize_stack("));
lf[433]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[434]=C_h_intern(&lf[434],38, C_text("chicken.compiler.core#target-heap-size"));
lf[435]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032C_set_or_change_heap_size("));
lf[436]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004,1);"));
lf[437]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027C_heap_size_is_fixed=1;"));
lf[438]=C_h_intern(&lf[438],53, C_text("chicken.compiler.core#disable-stack-overflow-checking"));
lf[439]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033C_disable_overflow_check=1;"));
lf[440]=C_decode_literal(C_heaptop,C_text("\376B\000\000$C_register_debug_info(C_debug_info);"));
lf[441]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_word \052a;"));
lf[442]=C_decode_literal(C_heaptop,C_text("\376B\000\000=if(toplevel_initialized) {C_kontinue(t1,C_SCHEME_UNDEFINED);}"));
lf[443]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036else C_toplevel_entry(C_text(\042"));
lf[444]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004\042));"));
lf[445]=C_decode_literal(C_heaptop,C_text("\376B\000\000.if(C_unlikely(!C_demand(C_calculate_demand((c-"));
lf[446]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021)\052C_SIZEOF_PAIR +"));
lf[447]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003,c,"));
lf[448]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005)))){"));
lf[449]=C_h_intern(&lf[449],41, C_text("chicken.compiler.core#insert-timer-checks"));
lf[450]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_check_for_interrupt;"));
lf[451]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005if(c<"));
lf[452]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025) C_bad_min_argc_2(c,"));
lf[453]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005,t0);"));
lf[454]=C_h_intern(&lf[454],36, C_text("chicken.compiler.core#no-argc-checks"));
lf[455]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_word \052a;"));
lf[456]=C_decode_literal(C_heaptop,C_text("\376B\000\000+if(C_unlikely(!C_demand(C_calculate_demand("));
lf[457]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003,0,"));
lf[458]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005)))){"));
lf[459]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003,c,"));
lf[460]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_check_for_interrupt;"));
lf[461]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005if(c<"));
lf[462]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025) C_bad_min_argc_2(c,"));
lf[463]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005,t0);"));
lf[464]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006if(c!="));
lf[465]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021) C_bad_argc_2(c,"));
lf[466]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005,t0);"));
lf[467]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005loop:"));
lf[468]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027C_stack_overflow_check;"));
lf[469]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_word \052a;"));
lf[470]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_word t"));
lf[471]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010double f"));
lf[472]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_word t"));
lf[473]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_word t"));
lf[474]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004=av["));
lf[475]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002];"));
lf[476]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013C_word tmp;"));
lf[477]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002){"));
lf[478]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_word \052av"));
lf[479]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_word \052a"));
lf[480]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_word c,"));
lf[481]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_fcall "));
lf[482]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_ccall "));
lf[483]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007C_word "));
lf[484]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005void "));
lf[485]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007static "));
lf[486]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017void C_ccall C_"));
lf[487]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022C_main_entry_point"));
lf[488]=C_decode_literal(C_heaptop,C_text("\376B\000\000(static C_TLS int toplevel_initialized=0;"));
lf[489]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003/\052 "));
lf[490]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003 \052/"));
lf[492]=C_h_intern(&lf[492],34, C_text("chicken.compiler.support#debugging"));
lf[493]=C_h_intern(&lf[493],1, C_text("o"));
lf[494]=C_decode_literal(C_heaptop,C_text("\376B\000\000 dropping unused closure argument"));
lf[495]=C_h_intern(&lf[495],54, C_text("chicken.compiler.core#lambda-literal-float-temporaries"));
lf[496]=C_h_intern(&lf[496],45, C_text("chicken.compiler.core#lambda-literal-external"));
lf[497]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[498]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[499]=C_h_intern(&lf[499],50, C_text("chicken.compiler.core#lambda-literal-rest-argument"));
lf[500]=C_h_intern(&lf[500],10, C_text("scheme#max"));
lf[501]=C_h_intern(&lf[501],54, C_text("chicken.compiler.core#lambda-literal-callee-signatures"));
lf[502]=C_h_intern(&lf[502],34, C_text("chicken.compiler.support#real-name"));
lf[503]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002/\052"));
lf[504]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\052/"));
lf[505]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021/\052 end of file \052/"));
lf[506]=C_h_intern(&lf[506],51, C_text("chicken.compiler.support#collected-debugging-output"));
lf[507]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002C_"));
lf[508]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002},"));
lf[509]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002},"));
lf[510]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011{C_text(\042"));
lf[511]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012\042),(void\052)"));
lf[512]=C_h_intern(&lf[512],37, C_text("chicken.internal#string->c-identifier"));
lf[513]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001{"));
lf[514]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027#ifdef C_ENABLE_PTABLES"));
lf[515]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016return ptable;"));
lf[516]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005#else"));
lf[517]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014return NULL;"));
lf[518]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006#endif"));
lf[519]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001}"));
lf[520]=C_decode_literal(C_heaptop,C_text("\376B\000\000\052static C_PTABLE_ENTRY \052create_ptable(void)"));
lf[521]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006#endif"));
lf[522]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015{NULL,NULL}};"));
lf[523]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027#ifdef C_ENABLE_PTABLES"));
lf[524]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035static C_PTABLE_ENTRY ptable["));
lf[525]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005] = {"));
lf[526]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022{0,0,NULL,NULL}};\012"));
lf[527]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002},"));
lf[528]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005NULL,"));
lf[529]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_text(\042"));
lf[530]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\042),"));
lf[531]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001{"));
lf[532]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003,0,"));
lf[533]=C_h_intern(&lf[533],17, C_text("chicken.sort#sort"));
lf[534]=C_decode_literal(C_heaptop,C_text("\376B\000\000$static C_DEBUG_INFO C_debug_info[]={"));
lf[535]=C_h_intern(&lf[535],5, C_text("float"));
lf[536]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002+3"));
lf[537]=C_h_intern(&lf[537],16, C_text("unsigned-integer"));
lf[538]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024+C_SIZEOF_FIX_BIGNUM"));
lf[539]=C_h_intern(&lf[539],18, C_text("unsigned-integer64"));
lf[540]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023+C_SIZEOF_BIGNUM(2)"));
lf[541]=C_h_intern(&lf[541],8, C_text("c-string"));
lf[542]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004+2+("));
lf[543]=C_decode_literal(C_heaptop,C_text("\376B\000\000!==NULL\0771:C_bytestowords(C_strlen("));
lf[544]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003)))"));
lf[545]=C_h_intern(&lf[545],16, C_text("nonnull-c-string"));
lf[546]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033+2+C_bytestowords(C_strlen("));
lf[547]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002))"));
lf[548]=C_h_intern(&lf[548],3, C_text("ref"));
lf[549]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002+3"));
lf[550]=C_h_intern(&lf[550],5, C_text("const"));
lf[551]=C_h_intern(&lf[551],7, C_text("pointer"));
lf[552]=C_h_intern(&lf[552],9, C_text("c-pointer"));
lf[553]=C_h_intern(&lf[553],15, C_text("nonnull-pointer"));
lf[554]=C_h_intern(&lf[554],17, C_text("nonnull-c-pointer"));
lf[555]=C_h_intern(&lf[555],8, C_text("function"));
lf[556]=C_h_intern(&lf[556],8, C_text("instance"));
lf[557]=C_h_intern(&lf[557],16, C_text("nonnull-instance"));
lf[558]=C_h_intern(&lf[558],12, C_text("instance-ref"));
lf[559]=C_h_intern(&lf[559],44, C_text("chicken.compiler.support#lookup-foreign-type"));
lf[560]=C_h_intern(&lf[560],17, C_text("nonnull-c-string\052"));
lf[561]=C_h_intern(&lf[561],25, C_text("nonnull-unsigned-c-string"));
lf[562]=C_h_intern(&lf[562],26, C_text("nonnull-unsigned-c-string\052"));
lf[563]=C_h_intern(&lf[563],6, C_text("symbol"));
lf[564]=C_h_intern(&lf[564],9, C_text("c-string\052"));
lf[565]=C_h_intern(&lf[565],17, C_text("unsigned-c-string"));
lf[566]=C_h_intern(&lf[566],18, C_text("unsigned-c-string\052"));
lf[567]=C_h_intern(&lf[567],9, C_text("integer64"));
lf[568]=C_h_intern(&lf[568],6, C_text("size_t"));
lf[569]=C_h_intern(&lf[569],7, C_text("ssize_t"));
lf[570]=C_h_intern(&lf[570],18, C_text("unsigned-integer32"));
lf[571]=C_h_intern(&lf[571],4, C_text("long"));
lf[572]=C_h_intern(&lf[572],7, C_text("integer"));
lf[573]=C_h_intern(&lf[573],9, C_text("integer32"));
lf[574]=C_h_intern(&lf[574],13, C_text("unsigned-long"));
lf[575]=C_h_intern(&lf[575],6, C_text("number"));
lf[576]=C_h_intern(&lf[576],6, C_text("double"));
lf[577]=C_h_intern(&lf[577],13, C_text("c-string-list"));
lf[578]=C_h_intern(&lf[578],14, C_text("c-string-list\052"));
lf[579]=C_h_intern(&lf[579],3, C_text("int"));
lf[580]=C_h_intern(&lf[580],5, C_text("int32"));
lf[581]=C_h_intern(&lf[581],5, C_text("short"));
lf[582]=C_h_intern(&lf[582],4, C_text("void"));
lf[583]=C_h_intern(&lf[583],14, C_text("unsigned-short"));
lf[584]=C_h_intern(&lf[584],13, C_text("scheme-object"));
lf[585]=C_h_intern(&lf[585],13, C_text("unsigned-char"));
lf[586]=C_h_intern(&lf[586],12, C_text("unsigned-int"));
lf[587]=C_h_intern(&lf[587],14, C_text("unsigned-int32"));
lf[588]=C_h_intern(&lf[588],4, C_text("byte"));
lf[589]=C_h_intern(&lf[589],13, C_text("unsigned-byte"));
lf[590]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002;}"));
lf[591]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033C_callback_wrapper((void \052)"));
lf[592]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007return "));
lf[593]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002x="));
lf[594]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[595]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_save(x);"));
lf[596]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001a"));
lf[597]=C_h_intern(&lf[597],14, C_text("scheme#reverse"));
lf[598]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035C_callback_adjust_stack(a,s);"));
lf[599]=C_decode_literal(C_heaptop,C_text("\376B\000\000\0010"));
lf[600]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013C_word x,s="));
lf[601]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004,\052a="));
lf[602]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020C_stack_pointer;"));
lf[603]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013C_alloc(s);"));
lf[605]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[606]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010/\052 from "));
lf[607]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003 \052/"));
lf[608]=C_decode_literal(C_heaptop,C_text("\376B\000\000\0010"));
lf[609]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[610]=C_h_intern(&lf[610],61, C_text("chicken.compiler.support#foreign-callback-stub-argument-types"));
lf[611]=C_h_intern(&lf[611],58, C_text("chicken.compiler.support#foreign-callback-stub-return-type"));
lf[612]=C_h_intern(&lf[612],35, C_text("chicken.compiler.support#real-name2"));
lf[613]=C_h_intern(&lf[613],49, C_text("chicken.compiler.support#foreign-callback-stub-id"));
lf[614]=C_h_intern(&lf[614],42, C_text("chicken.compiler.core#foreign-lambda-stubs"));
lf[615]=C_decode_literal(C_heaptop,C_text("\376B\000\000.C_k=C_restore_callback_continuation2(C_level);"));
lf[616]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_kontinue(C_k,C_r);"));
lf[617]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_kontinue(C_k,C_r);"));
lf[618]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013return C_r;"));
lf[619]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015#undef return"));
lf[620]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006C_ret:"));
lf[621]=C_decode_literal(C_heaptop,C_text("\376B\000\000.C_k=C_restore_callback_continuation2(C_level);"));
lf[622]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_kontinue(C_k,C_r);"));
lf[623]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_kontinue(C_k,C_r);"));
lf[624]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013return C_r;"));
lf[625]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[626]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[627]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004C_r="));
lf[628]=C_decode_literal(C_heaptop,C_text("\376B\000\0003int C_level=C_save_callback_continuation(&C_a,C_k);"));
lf[629]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002=("));
lf[630]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003C_a"));
lf[631]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002);"));
lf[632]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[633]=C_h_intern(&lf[633],21, C_text("scheme#symbol->string"));
lf[634]=C_decode_literal(C_heaptop,C_text("\376B\000\0002C_word C_r=C_SCHEME_UNDEFINED,\052C_a=(C_word\052)C_buf;"));
lf[635]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_word C_a"));
lf[636]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006=C_av["));
lf[637]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002];"));
lf[638]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_noret_decl("));
lf[639]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[640]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024static void C_ccall "));
lf[641]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032(C_word C_c,C_word \052C_av){"));
lf[642]=C_decode_literal(C_heaptop,C_text("\376B\000\000!C_word C_k=C_av[1],C_buf=C_av[2];"));
lf[643]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002){"));
lf[644]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_word C_buf"));
lf[645]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003C_a"));
lf[646]=C_decode_literal(C_heaptop,C_text("\376B\000\000 C_regparm static C_word C_fcall "));
lf[647]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042#define return(x) C_cblock C_r = ("));
lf[648]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036(x))); goto C_ret; C_cblockend"));
lf[649]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010/\052 from "));
lf[650]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003 \052/"));
lf[651]=C_h_intern(&lf[651],43, C_text("chicken.compiler.core#foreign-stub-callback"));
lf[652]=C_h_intern(&lf[652],38, C_text("chicken.compiler.core#foreign-stub-cps"));
lf[653]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003C_a"));
lf[654]=C_h_intern(&lf[654],49, C_text("chicken.compiler.core#foreign-stub-argument-names"));
lf[655]=C_h_intern(&lf[655],39, C_text("chicken.compiler.core#foreign-stub-body"));
lf[656]=C_h_intern(&lf[656],39, C_text("chicken.compiler.core#foreign-stub-name"));
lf[657]=C_h_intern(&lf[657],46, C_text("chicken.compiler.core#foreign-stub-return-type"));
lf[658]=C_h_intern(&lf[658],49, C_text("chicken.compiler.core#foreign-stub-argument-types"));
lf[659]=C_h_intern(&lf[659],37, C_text("chicken.compiler.core#foreign-stub-id"));
lf[660]=C_h_intern(&lf[660],40, C_text("chicken.compiler.core#external-variables"));
lf[661]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[662]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007static "));
lf[663]=C_h_intern(&lf[663],1, C_text("p"));
lf[664]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030code generation phase..."));
lf[665]=C_h_intern(&lf[665],46, C_text("chicken.flonum#flonum-maximum-decimal-exponent"));
lf[666]=C_h_intern(&lf[666],37, C_text("chicken.flonum#flonum-print-precision"));
lf[667]=C_h_intern(&lf[667],15, C_text("scheme#string<\077"));
lf[668]=C_h_intern(&lf[668],18, C_text("chicken.sort#sort!"));
lf[669]=C_h_intern(&lf[669],36, C_text("chicken.internal#hash-table-for-each"));
lf[670]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010toplevel"));
lf[671]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011_toplevel"));
lf[672]=C_h_intern(&lf[672],18, C_text("scheme#string-copy"));
lf[673]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007C_word "));
lf[674]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_externexport "));
lf[675]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[676]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001t"));
lf[677]=C_h_intern(&lf[677],57, C_text("chicken.compiler.support#foreign-callback-stub-qualifiers"));
lf[678]=C_h_intern(&lf[678],51, C_text("chicken.compiler.support#foreign-callback-stub-name"));
lf[679]=C_h_intern(&lf[679],39, C_text("chicken.compiler.support#quit-compiling"));
lf[680]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031illegal foreign type `~A\047"));
lf[681]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001 "));
lf[682]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006C_word"));
lf[683]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006C_char"));
lf[684]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017unsigned C_char"));
lf[685]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014unsigned int"));
lf[686]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005C_u32"));
lf[687]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003int"));
lf[688]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006size_t"));
lf[689]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007ssize_t"));
lf[690]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005C_s32"));
lf[691]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005C_s64"));
lf[692]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005C_u64"));
lf[693]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005short"));
lf[694]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004long"));
lf[695]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016unsigned short"));
lf[696]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015unsigned long"));
lf[697]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005float"));
lf[698]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006double"));
lf[699]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006void \052"));
lf[700]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_char \052\052"));
lf[701]=C_h_intern(&lf[701],4, C_text("blob"));
lf[702]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017unsigned char \052"));
lf[703]=C_h_intern(&lf[703],9, C_text("u16vector"));
lf[704]=C_h_intern(&lf[704],17, C_text("nonnull-u16vector"));
lf[705]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020unsigned short \052"));
lf[706]=C_h_intern(&lf[706],8, C_text("s8vector"));
lf[707]=C_h_intern(&lf[707],16, C_text("nonnull-s8vector"));
lf[708]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015signed char \052"));
lf[709]=C_h_intern(&lf[709],9, C_text("u32vector"));
lf[710]=C_h_intern(&lf[710],17, C_text("nonnull-u32vector"));
lf[711]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016unsigned int \052"));
lf[712]=C_h_intern(&lf[712],9, C_text("u64vector"));
lf[713]=C_h_intern(&lf[713],17, C_text("nonnull-u64vector"));
lf[714]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007C_u64 \052"));
lf[715]=C_h_intern(&lf[715],9, C_text("s16vector"));
lf[716]=C_h_intern(&lf[716],17, C_text("nonnull-s16vector"));
lf[717]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007short \052"));
lf[718]=C_h_intern(&lf[718],9, C_text("s32vector"));
lf[719]=C_h_intern(&lf[719],17, C_text("nonnull-s32vector"));
lf[720]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005int \052"));
lf[721]=C_h_intern(&lf[721],9, C_text("s64vector"));
lf[722]=C_h_intern(&lf[722],17, C_text("nonnull-s64vector"));
lf[723]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007C_s64 \052"));
lf[724]=C_h_intern(&lf[724],9, C_text("f32vector"));
lf[725]=C_h_intern(&lf[725],17, C_text("nonnull-f32vector"));
lf[726]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007float \052"));
lf[727]=C_h_intern(&lf[727],9, C_text("f64vector"));
lf[728]=C_h_intern(&lf[728],17, C_text("nonnull-f64vector"));
lf[729]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010double \052"));
lf[730]=C_h_intern(&lf[730],14, C_text("pointer-vector"));
lf[731]=C_h_intern(&lf[731],22, C_text("nonnull-pointer-vector"));
lf[732]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007void \052\052"));
lf[733]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006char \052"));
lf[734]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017unsigned char \052"));
lf[735]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004void"));
lf[736]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\007\001pointer\376\003\000\000\002\376\001\000\000\017\001nonnull-pointer\376\003\000\000\002\376\001\000\000\011\001c-pointer\376\003\000\000\002\376\001\000\000\016\001schem"
"e-pointer\376\003\000\000\002\376\001\000\000\026\001nonnull-scheme-pointer\376\003\000\000\002\376\001\000\000\021\001nonnull-c-pointer\376\377\016"));
lf[737]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\052"));
lf[738]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001&"));
lf[739]=C_h_intern(&lf[739],8, C_text("template"));
lf[740]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001<"));
lf[741]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002> "));
lf[742]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001,"));
lf[743]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[744]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[745]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006const "));
lf[746]=C_h_intern(&lf[746],6, C_text("struct"));
lf[747]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007struct "));
lf[748]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001 "));
lf[749]=C_h_intern(&lf[749],5, C_text("union"));
lf[750]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006union "));
lf[751]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001 "));
lf[752]=C_h_intern(&lf[752],4, C_text("enum"));
lf[753]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005enum "));
lf[754]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001 "));
lf[755]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\010\001instance\376\003\000\000\002\376\001\000\000\020\001nonnull-instance\376\377\016"));
lf[756]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\052"));
lf[757]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001&"));
lf[758]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[759]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003 (\052"));
lf[760]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002)("));
lf[761]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[762]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001,"));
lf[763]=C_h_intern(&lf[763],3, C_text("..."));
lf[764]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003..."));
lf[765]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[766]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[767]=C_h_intern(&lf[767],12, C_text("nonnull-blob"));
lf[768]=C_h_intern(&lf[768],8, C_text("u8vector"));
lf[769]=C_h_intern(&lf[769],16, C_text("nonnull-u8vector"));
lf[770]=C_h_intern(&lf[770],14, C_text("scheme-pointer"));
lf[771]=C_h_intern(&lf[771],22, C_text("nonnull-scheme-pointer"));
lf[772]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042illegal foreign argument type `~A\047"));
lf[773]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001("));
lf[774]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031C_character_code((C_word)"));
lf[775]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_unfix("));
lf[776]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_unfix("));
lf[777]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030(unsigned short)C_unfix("));
lf[778]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027C_num_to_unsigned_long("));
lf[779]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013C_c_double("));
lf[780]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_num_to_int("));
lf[781]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_num_to_int64("));
lf[782]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030(size_t)C_num_to_uint64("));
lf[783]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030(ssize_t)C_num_to_int64("));
lf[784]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020C_num_to_uint64("));
lf[785]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_num_to_long("));
lf[786]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_num_to_unsigned_int("));
lf[787]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027C_data_pointer_or_null("));
lf[788]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_data_pointer("));
lf[789]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_c_pointer_or_null("));
lf[790]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_c_pointer_nn("));
lf[791]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027C_c_bytevector_or_null("));
lf[792]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_c_bytevector("));
lf[793]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_c_u8vector_or_null("));
lf[794]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_c_u8vector("));
lf[795]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_u16vector_or_null("));
lf[796]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_u16vector("));
lf[797]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_u32vector_or_null("));
lf[798]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_u32vector("));
lf[799]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_u64vector_or_null("));
lf[800]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_u64vector("));
lf[801]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_c_s8vector_or_null("));
lf[802]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_c_s8vector("));
lf[803]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_s16vector_or_null("));
lf[804]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_s16vector("));
lf[805]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_s32vector_or_null("));
lf[806]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_s32vector("));
lf[807]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_s64vector_or_null("));
lf[808]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_s64vector("));
lf[809]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_f32vector_or_null("));
lf[810]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_f32vector("));
lf[811]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026C_c_f64vector_or_null("));
lf[812]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_c_f64vector("));
lf[813]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033C_c_pointer_vector_or_null("));
lf[814]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023C_c_pointer_vector("));
lf[815]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021C_string_or_null("));
lf[816]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013C_c_string("));
lf[817]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010C_truep("));
lf[818]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_c_pointer_or_null("));
lf[819]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_c_pointer_nn("));
lf[820]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_c_pointer_or_null("));
lf[821]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_c_pointer_nn("));
lf[822]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027C_data_pointer_or_null("));
lf[823]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_data_pointer("));
lf[824]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024C_c_pointer_or_null("));
lf[825]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_num_to_int("));
lf[826]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\052("));
lf[827]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020)C_c_pointer_nn("));
lf[828]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\052"));
lf[829]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\052("));
lf[830]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021\052)C_c_pointer_nn("));
lf[831]=C_decode_literal(C_heaptop,C_text("\376B\000\000 illegal foreign return type `~A\047"));
lf[832]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031C_make_character((C_word)"));
lf[833]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_fix((C_word)"));
lf[834]=C_decode_literal(C_heaptop,C_text("\376B\000\000%C_fix(C_MOST_POSITIVE_FIXNUM&(C_word)"));
lf[835]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015C_fix((short)"));
lf[836]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_fix(0xffff&(C_word)"));
lf[837]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_fix((char)"));
lf[838]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023C_fix(0xff&(C_word)"));
lf[839]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_flonum(&"));
lf[840]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_number(&"));
lf[841]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,(void\052)"));
lf[842]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_mpointer(&"));
lf[843]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,(void\052)"));
lf[844]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_mpointer_or_false(&"));
lf[845]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_int_to_num(&"));
lf[846]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020C_int64_to_num(&"));
lf[847]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021C_uint64_to_num(&"));
lf[848]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027C_unsigned_int_to_num(&"));
lf[849]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017C_long_to_num(&"));
lf[850]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030C_unsigned_long_to_num(&"));
lf[851]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_mk_bool("));
lf[852]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011((C_word)"));
lf[853]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,(void\052)"));
lf[854]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_mpointer(&"));
lf[855]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011,(void\052)&"));
lf[856]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_mpointer(&"));
lf[857]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,(void\052)"));
lf[858]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_mpointer_or_false(&"));
lf[859]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,(void\052)"));
lf[860]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_mpointer(&"));
lf[861]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011,(void\052)&"));
lf[862]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_mpointer(&"));
lf[863]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,(void\052)"));
lf[864]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025C_mpointer_or_false(&"));
lf[865]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010,(void\052)"));
lf[866]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014C_mpointer(&"));
lf[867]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016C_int_to_num(&"));
lf[868]=C_decode_literal(C_heaptop,C_text("\376B\000\000=Encoded literal size of ~S is too large (must fit in 24 bits)"));
lf[869]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\377\006\001"));
lf[870]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\377\006\000"));
lf[871]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\377\012"));
lf[872]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\377\016"));
lf[873]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\377>"));
lf[874]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\377\036"));
lf[875]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\377\001"));
lf[876]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\302"));
lf[877]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001U"));
lf[878]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\000"));
lf[879]=C_h_intern(&lf[879],20, C_text("##sys#flonum->string"));
lf[880]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\001"));
lf[881]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\002"));
lf[882]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\001"));
lf[883]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037invalid literal - cannot encode"));
lf[884]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
C_register_lf2(lf,885,create_ptable());{}
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3247,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_library_toplevel(2,av2);}}

/* va15400 in a5858 in k5738 in k5735 in k6120 in k5704 in k5700 in k5694 in k5691 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in ... */
static void C_fcall va15400(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,1)))){
C_save_and_reclaim_args((void *)trva15400,2,t0,t1);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* va15406 in a6321 in k6207 in k6201 in k4733 in k4730 in k4727 in expr in expression in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall va15406(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,1)))){
C_save_and_reclaim_args((void *)trva15406,2,t0,t1);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* va15438 in k7919 in k7915 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall va15438(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,1)))){
C_save_and_reclaim_args((void *)trva15438,2,t0,t1);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* va15440 in k7952 in k7946 in k7943 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall va15440(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,1)))){
C_save_and_reclaim_args((void *)trva15440,2,t0,t1);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* va15448 in k8108 in k8104 in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall va15448(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,1)))){
C_save_and_reclaim_args((void *)trva15448,2,t0,t1);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* va15450 in k8133 in k8129 in k8035 in k8017 in k7902 in k7872 in k7866 in literal-size in k4706 in k4703 in chicken.compiler.c-backend#generate-code in k3266 in k3263 in k3260 in k3257 in k3254 in k3251 in k3248 in k3245 */
static void C_fcall va15450(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,1)))){
C_save_and_reclaim_args((void *)trva15450,2,t0,t1);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_s_a_i_plus(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

#ifdef C_ENABLE_PTABLES
static C_PTABLE_ENTRY ptable[821] = {
{C_text("f14759:c_2dbackend_2escm"),(void*)f14759},
{C_text("f14764:c_2dbackend_2escm"),(void*)f14764},
{C_text("f14769:c_2dbackend_2escm"),(void*)f14769},
{C_text("f14777:c_2dbackend_2escm"),(void*)f14777},
{C_text("f14782:c_2dbackend_2escm"),(void*)f14782},
{C_text("f14787:c_2dbackend_2escm"),(void*)f14787},
{C_text("f14800:c_2dbackend_2escm"),(void*)f14800},
{C_text("f14804:c_2dbackend_2escm"),(void*)f14804},
{C_text("f14811:c_2dbackend_2escm"),(void*)f14811},
{C_text("f14816:c_2dbackend_2escm"),(void*)f14816},
{C_text("f14889:c_2dbackend_2escm"),(void*)f14889},
{C_text("f14896:c_2dbackend_2escm"),(void*)f14896},
{C_text("f14917:c_2dbackend_2escm"),(void*)f14917},
{C_text("f_10020:c_2dbackend_2escm"),(void*)f_10020},
{C_text("f_10376:c_2dbackend_2escm"),(void*)f_10376},
{C_text("f_10379:c_2dbackend_2escm"),(void*)f_10379},
{C_text("f_10382:c_2dbackend_2escm"),(void*)f_10382},
{C_text("f_10385:c_2dbackend_2escm"),(void*)f_10385},
{C_text("f_10388:c_2dbackend_2escm"),(void*)f_10388},
{C_text("f_10391:c_2dbackend_2escm"),(void*)f_10391},
{C_text("f_10400:c_2dbackend_2escm"),(void*)f_10400},
{C_text("f_10403:c_2dbackend_2escm"),(void*)f_10403},
{C_text("f_10406:c_2dbackend_2escm"),(void*)f_10406},
{C_text("f_10409:c_2dbackend_2escm"),(void*)f_10409},
{C_text("f_10412:c_2dbackend_2escm"),(void*)f_10412},
{C_text("f_10415:c_2dbackend_2escm"),(void*)f_10415},
{C_text("f_10418:c_2dbackend_2escm"),(void*)f_10418},
{C_text("f_10437:c_2dbackend_2escm"),(void*)f_10437},
{C_text("f_10439:c_2dbackend_2escm"),(void*)f_10439},
{C_text("f_10449:c_2dbackend_2escm"),(void*)f_10449},
{C_text("f_10488:c_2dbackend_2escm"),(void*)f_10488},
{C_text("f_10490:c_2dbackend_2escm"),(void*)f_10490},
{C_text("f_10512:c_2dbackend_2escm"),(void*)f_10512},
{C_text("f_10524:c_2dbackend_2escm"),(void*)f_10524},
{C_text("f_10534:c_2dbackend_2escm"),(void*)f_10534},
{C_text("f_10547:c_2dbackend_2escm"),(void*)f_10547},
{C_text("f_10551:c_2dbackend_2escm"),(void*)f_10551},
{C_text("f_10554:c_2dbackend_2escm"),(void*)f_10554},
{C_text("f_10557:c_2dbackend_2escm"),(void*)f_10557},
{C_text("f_10560:c_2dbackend_2escm"),(void*)f_10560},
{C_text("f_10566:c_2dbackend_2escm"),(void*)f_10566},
{C_text("f_10569:c_2dbackend_2escm"),(void*)f_10569},
{C_text("f_10572:c_2dbackend_2escm"),(void*)f_10572},
{C_text("f_10577:c_2dbackend_2escm"),(void*)f_10577},
{C_text("f_10587:c_2dbackend_2escm"),(void*)f_10587},
{C_text("f_10590:c_2dbackend_2escm"),(void*)f_10590},
{C_text("f_10609:c_2dbackend_2escm"),(void*)f_10609},
{C_text("f_10621:c_2dbackend_2escm"),(void*)f_10621},
{C_text("f_10623:c_2dbackend_2escm"),(void*)f_10623},
{C_text("f_10625:c_2dbackend_2escm"),(void*)f_10625},
{C_text("f_10630:c_2dbackend_2escm"),(void*)f_10630},
{C_text("f_10700:c_2dbackend_2escm"),(void*)f_10700},
{C_text("f_10817:c_2dbackend_2escm"),(void*)f_10817},
{C_text("f_10838:c_2dbackend_2escm"),(void*)f_10838},
{C_text("f_10970:c_2dbackend_2escm"),(void*)f_10970},
{C_text("f_10982:c_2dbackend_2escm"),(void*)f_10982},
{C_text("f_10997:c_2dbackend_2escm"),(void*)f_10997},
{C_text("f_11001:c_2dbackend_2escm"),(void*)f_11001},
{C_text("f_11045:c_2dbackend_2escm"),(void*)f_11045},
{C_text("f_11062:c_2dbackend_2escm"),(void*)f_11062},
{C_text("f_11075:c_2dbackend_2escm"),(void*)f_11075},
{C_text("f_11079:c_2dbackend_2escm"),(void*)f_11079},
{C_text("f_11083:c_2dbackend_2escm"),(void*)f_11083},
{C_text("f_11101:c_2dbackend_2escm"),(void*)f_11101},
{C_text("f_11103:c_2dbackend_2escm"),(void*)f_11103},
{C_text("f_11128:c_2dbackend_2escm"),(void*)f_11128},
{C_text("f_11152:c_2dbackend_2escm"),(void*)f_11152},
{C_text("f_11169:c_2dbackend_2escm"),(void*)f_11169},
{C_text("f_11186:c_2dbackend_2escm"),(void*)f_11186},
{C_text("f_11203:c_2dbackend_2escm"),(void*)f_11203},
{C_text("f_11220:c_2dbackend_2escm"),(void*)f_11220},
{C_text("f_11237:c_2dbackend_2escm"),(void*)f_11237},
{C_text("f_11266:c_2dbackend_2escm"),(void*)f_11266},
{C_text("f_11270:c_2dbackend_2escm"),(void*)f_11270},
{C_text("f_11291:c_2dbackend_2escm"),(void*)f_11291},
{C_text("f_11293:c_2dbackend_2escm"),(void*)f_11293},
{C_text("f_11303:c_2dbackend_2escm"),(void*)f_11303},
{C_text("f_11318:c_2dbackend_2escm"),(void*)f_11318},
{C_text("f_11717:c_2dbackend_2escm"),(void*)f_11717},
{C_text("f_11719:c_2dbackend_2escm"),(void*)f_11719},
{C_text("f_11747:c_2dbackend_2escm"),(void*)f_11747},
{C_text("f_11774:c_2dbackend_2escm"),(void*)f_11774},
{C_text("f_11999:c_2dbackend_2escm"),(void*)f_11999},
{C_text("f_12008:c_2dbackend_2escm"),(void*)f_12008},
{C_text("f_12017:c_2dbackend_2escm"),(void*)f_12017},
{C_text("f_12115:c_2dbackend_2escm"),(void*)f_12115},
{C_text("f_12382:c_2dbackend_2escm"),(void*)f_12382},
{C_text("f_12384:c_2dbackend_2escm"),(void*)f_12384},
{C_text("f_12451:c_2dbackend_2escm"),(void*)f_12451},
{C_text("f_12457:c_2dbackend_2escm"),(void*)f_12457},
{C_text("f_12460:c_2dbackend_2escm"),(void*)f_12460},
{C_text("f_12463:c_2dbackend_2escm"),(void*)f_12463},
{C_text("f_12475:c_2dbackend_2escm"),(void*)f_12475},
{C_text("f_12481:c_2dbackend_2escm"),(void*)f_12481},
{C_text("f_12484:c_2dbackend_2escm"),(void*)f_12484},
{C_text("f_12487:c_2dbackend_2escm"),(void*)f_12487},
{C_text("f_12499:c_2dbackend_2escm"),(void*)f_12499},
{C_text("f_12502:c_2dbackend_2escm"),(void*)f_12502},
{C_text("f_12508:c_2dbackend_2escm"),(void*)f_12508},
{C_text("f_12511:c_2dbackend_2escm"),(void*)f_12511},
{C_text("f_12514:c_2dbackend_2escm"),(void*)f_12514},
{C_text("f_12526:c_2dbackend_2escm"),(void*)f_12526},
{C_text("f_12532:c_2dbackend_2escm"),(void*)f_12532},
{C_text("f_12535:c_2dbackend_2escm"),(void*)f_12535},
{C_text("f_12538:c_2dbackend_2escm"),(void*)f_12538},
{C_text("f_12553:c_2dbackend_2escm"),(void*)f_12553},
{C_text("f_12559:c_2dbackend_2escm"),(void*)f_12559},
{C_text("f_12562:c_2dbackend_2escm"),(void*)f_12562},
{C_text("f_12565:c_2dbackend_2escm"),(void*)f_12565},
{C_text("f_12580:c_2dbackend_2escm"),(void*)f_12580},
{C_text("f_12586:c_2dbackend_2escm"),(void*)f_12586},
{C_text("f_12589:c_2dbackend_2escm"),(void*)f_12589},
{C_text("f_12592:c_2dbackend_2escm"),(void*)f_12592},
{C_text("f_12607:c_2dbackend_2escm"),(void*)f_12607},
{C_text("f_12613:c_2dbackend_2escm"),(void*)f_12613},
{C_text("f_12616:c_2dbackend_2escm"),(void*)f_12616},
{C_text("f_12619:c_2dbackend_2escm"),(void*)f_12619},
{C_text("f_12634:c_2dbackend_2escm"),(void*)f_12634},
{C_text("f_12640:c_2dbackend_2escm"),(void*)f_12640},
{C_text("f_12643:c_2dbackend_2escm"),(void*)f_12643},
{C_text("f_12646:c_2dbackend_2escm"),(void*)f_12646},
{C_text("f_12658:c_2dbackend_2escm"),(void*)f_12658},
{C_text("f_12664:c_2dbackend_2escm"),(void*)f_12664},
{C_text("f_12667:c_2dbackend_2escm"),(void*)f_12667},
{C_text("f_12670:c_2dbackend_2escm"),(void*)f_12670},
{C_text("f_12682:c_2dbackend_2escm"),(void*)f_12682},
{C_text("f_12688:c_2dbackend_2escm"),(void*)f_12688},
{C_text("f_12691:c_2dbackend_2escm"),(void*)f_12691},
{C_text("f_12694:c_2dbackend_2escm"),(void*)f_12694},
{C_text("f_12715:c_2dbackend_2escm"),(void*)f_12715},
{C_text("f_12719:c_2dbackend_2escm"),(void*)f_12719},
{C_text("f_12751:c_2dbackend_2escm"),(void*)f_12751},
{C_text("f_12757:c_2dbackend_2escm"),(void*)f_12757},
{C_text("f_12760:c_2dbackend_2escm"),(void*)f_12760},
{C_text("f_12763:c_2dbackend_2escm"),(void*)f_12763},
{C_text("f_12775:c_2dbackend_2escm"),(void*)f_12775},
{C_text("f_12781:c_2dbackend_2escm"),(void*)f_12781},
{C_text("f_12784:c_2dbackend_2escm"),(void*)f_12784},
{C_text("f_12787:c_2dbackend_2escm"),(void*)f_12787},
{C_text("f_12799:c_2dbackend_2escm"),(void*)f_12799},
{C_text("f_12805:c_2dbackend_2escm"),(void*)f_12805},
{C_text("f_12808:c_2dbackend_2escm"),(void*)f_12808},
{C_text("f_12811:c_2dbackend_2escm"),(void*)f_12811},
{C_text("f_12823:c_2dbackend_2escm"),(void*)f_12823},
{C_text("f_12829:c_2dbackend_2escm"),(void*)f_12829},
{C_text("f_12832:c_2dbackend_2escm"),(void*)f_12832},
{C_text("f_12835:c_2dbackend_2escm"),(void*)f_12835},
{C_text("f_12847:c_2dbackend_2escm"),(void*)f_12847},
{C_text("f_12853:c_2dbackend_2escm"),(void*)f_12853},
{C_text("f_12856:c_2dbackend_2escm"),(void*)f_12856},
{C_text("f_12859:c_2dbackend_2escm"),(void*)f_12859},
{C_text("f_12887:c_2dbackend_2escm"),(void*)f_12887},
{C_text("f_12893:c_2dbackend_2escm"),(void*)f_12893},
{C_text("f_12896:c_2dbackend_2escm"),(void*)f_12896},
{C_text("f_12899:c_2dbackend_2escm"),(void*)f_12899},
{C_text("f_12911:c_2dbackend_2escm"),(void*)f_12911},
{C_text("f_12917:c_2dbackend_2escm"),(void*)f_12917},
{C_text("f_12920:c_2dbackend_2escm"),(void*)f_12920},
{C_text("f_12923:c_2dbackend_2escm"),(void*)f_12923},
{C_text("f_12935:c_2dbackend_2escm"),(void*)f_12935},
{C_text("f_12941:c_2dbackend_2escm"),(void*)f_12941},
{C_text("f_12944:c_2dbackend_2escm"),(void*)f_12944},
{C_text("f_12947:c_2dbackend_2escm"),(void*)f_12947},
{C_text("f_13169:c_2dbackend_2escm"),(void*)f_13169},
{C_text("f_13178:c_2dbackend_2escm"),(void*)f_13178},
{C_text("f_13244:c_2dbackend_2escm"),(void*)f_13244},
{C_text("f_13266:c_2dbackend_2escm"),(void*)f_13266},
{C_text("f_13294:c_2dbackend_2escm"),(void*)f_13294},
{C_text("f_13353:c_2dbackend_2escm"),(void*)f_13353},
{C_text("f_13360:c_2dbackend_2escm"),(void*)f_13360},
{C_text("f_13380:c_2dbackend_2escm"),(void*)f_13380},
{C_text("f_13387:c_2dbackend_2escm"),(void*)f_13387},
{C_text("f_13400:c_2dbackend_2escm"),(void*)f_13400},
{C_text("f_13407:c_2dbackend_2escm"),(void*)f_13407},
{C_text("f_13430:c_2dbackend_2escm"),(void*)f_13430},
{C_text("f_13438:c_2dbackend_2escm"),(void*)f_13438},
{C_text("f_13460:c_2dbackend_2escm"),(void*)f_13460},
{C_text("f_13468:c_2dbackend_2escm"),(void*)f_13468},
{C_text("f_13472:c_2dbackend_2escm"),(void*)f_13472},
{C_text("f_13474:c_2dbackend_2escm"),(void*)f_13474},
{C_text("f_13503:c_2dbackend_2escm"),(void*)f_13503},
{C_text("f_3247:c_2dbackend_2escm"),(void*)f_3247},
{C_text("f_3250:c_2dbackend_2escm"),(void*)f_3250},
{C_text("f_3253:c_2dbackend_2escm"),(void*)f_3253},
{C_text("f_3256:c_2dbackend_2escm"),(void*)f_3256},
{C_text("f_3259:c_2dbackend_2escm"),(void*)f_3259},
{C_text("f_3262:c_2dbackend_2escm"),(void*)f_3262},
{C_text("f_3265:c_2dbackend_2escm"),(void*)f_3265},
{C_text("f_3268:c_2dbackend_2escm"),(void*)f_3268},
{C_text("f_3709:c_2dbackend_2escm"),(void*)f_3709},
{C_text("f_3723:c_2dbackend_2escm"),(void*)f_3723},
{C_text("f_4281:c_2dbackend_2escm"),(void*)f_4281},
{C_text("f_4287:c_2dbackend_2escm"),(void*)f_4287},
{C_text("f_4301:c_2dbackend_2escm"),(void*)f_4301},
{C_text("f_4305:c_2dbackend_2escm"),(void*)f_4305},
{C_text("f_4461:c_2dbackend_2escm"),(void*)f_4461},
{C_text("f_4473:c_2dbackend_2escm"),(void*)f_4473},
{C_text("f_4549:c_2dbackend_2escm"),(void*)f_4549},
{C_text("f_4569:c_2dbackend_2escm"),(void*)f_4569},
{C_text("f_4579:c_2dbackend_2escm"),(void*)f_4579},
{C_text("f_4592:c_2dbackend_2escm"),(void*)f_4592},
{C_text("f_4601:c_2dbackend_2escm"),(void*)f_4601},
{C_text("f_4606:c_2dbackend_2escm"),(void*)f_4606},
{C_text("f_4616:c_2dbackend_2escm"),(void*)f_4616},
{C_text("f_4657:c_2dbackend_2escm"),(void*)f_4657},
{C_text("f_4663:c_2dbackend_2escm"),(void*)f_4663},
{C_text("f_4668:c_2dbackend_2escm"),(void*)f_4668},
{C_text("f_4676:c_2dbackend_2escm"),(void*)f_4676},
{C_text("f_4680:c_2dbackend_2escm"),(void*)f_4680},
{C_text("f_4690:c_2dbackend_2escm"),(void*)f_4690},
{C_text("f_4701:c_2dbackend_2escm"),(void*)f_4701},
{C_text("f_4705:c_2dbackend_2escm"),(void*)f_4705},
{C_text("f_4708:c_2dbackend_2escm"),(void*)f_4708},
{C_text("f_4710:c_2dbackend_2escm"),(void*)f_4710},
{C_text("f_4714:c_2dbackend_2escm"),(void*)f_4714},
{C_text("f_4722:c_2dbackend_2escm"),(void*)f_4722},
{C_text("f_4725:c_2dbackend_2escm"),(void*)f_4725},
{C_text("f_4729:c_2dbackend_2escm"),(void*)f_4729},
{C_text("f_4732:c_2dbackend_2escm"),(void*)f_4732},
{C_text("f_4735:c_2dbackend_2escm"),(void*)f_4735},
{C_text("f_4873:c_2dbackend_2escm"),(void*)f_4873},
{C_text("f_4887:c_2dbackend_2escm"),(void*)f_4887},
{C_text("f_4906:c_2dbackend_2escm"),(void*)f_4906},
{C_text("f_4909:c_2dbackend_2escm"),(void*)f_4909},
{C_text("f_4912:c_2dbackend_2escm"),(void*)f_4912},
{C_text("f_4915:c_2dbackend_2escm"),(void*)f_4915},
{C_text("f_4918:c_2dbackend_2escm"),(void*)f_4918},
{C_text("f_4921:c_2dbackend_2escm"),(void*)f_4921},
{C_text("f_4964:c_2dbackend_2escm"),(void*)f_4964},
{C_text("f_4974:c_2dbackend_2escm"),(void*)f_4974},
{C_text("f_4977:c_2dbackend_2escm"),(void*)f_4977},
{C_text("f_4980:c_2dbackend_2escm"),(void*)f_4980},
{C_text("f_5012:c_2dbackend_2escm"),(void*)f_5012},
{C_text("f_5015:c_2dbackend_2escm"),(void*)f_5015},
{C_text("f_5018:c_2dbackend_2escm"),(void*)f_5018},
{C_text("f_5051:c_2dbackend_2escm"),(void*)f_5051},
{C_text("f_5054:c_2dbackend_2escm"),(void*)f_5054},
{C_text("f_5070:c_2dbackend_2escm"),(void*)f_5070},
{C_text("f_5073:c_2dbackend_2escm"),(void*)f_5073},
{C_text("f_5089:c_2dbackend_2escm"),(void*)f_5089},
{C_text("f_5092:c_2dbackend_2escm"),(void*)f_5092},
{C_text("f_5116:c_2dbackend_2escm"),(void*)f_5116},
{C_text("f_5122:c_2dbackend_2escm"),(void*)f_5122},
{C_text("f_5141:c_2dbackend_2escm"),(void*)f_5141},
{C_text("f_5144:c_2dbackend_2escm"),(void*)f_5144},
{C_text("f_5156:c_2dbackend_2escm"),(void*)f_5156},
{C_text("f_5162:c_2dbackend_2escm"),(void*)f_5162},
{C_text("f_5181:c_2dbackend_2escm"),(void*)f_5181},
{C_text("f_5184:c_2dbackend_2escm"),(void*)f_5184},
{C_text("f_5196:c_2dbackend_2escm"),(void*)f_5196},
{C_text("f_5202:c_2dbackend_2escm"),(void*)f_5202},
{C_text("f_5221:c_2dbackend_2escm"),(void*)f_5221},
{C_text("f_5224:c_2dbackend_2escm"),(void*)f_5224},
{C_text("f_5236:c_2dbackend_2escm"),(void*)f_5236},
{C_text("f_5239:c_2dbackend_2escm"),(void*)f_5239},
{C_text("f_5255:c_2dbackend_2escm"),(void*)f_5255},
{C_text("f_5258:c_2dbackend_2escm"),(void*)f_5258},
{C_text("f_5261:c_2dbackend_2escm"),(void*)f_5261},
{C_text("f_5264:c_2dbackend_2escm"),(void*)f_5264},
{C_text("f_5288:c_2dbackend_2escm"),(void*)f_5288},
{C_text("f_5291:c_2dbackend_2escm"),(void*)f_5291},
{C_text("f_5294:c_2dbackend_2escm"),(void*)f_5294},
{C_text("f_5297:c_2dbackend_2escm"),(void*)f_5297},
{C_text("f_5325:c_2dbackend_2escm"),(void*)f_5325},
{C_text("f_5328:c_2dbackend_2escm"),(void*)f_5328},
{C_text("f_5331:c_2dbackend_2escm"),(void*)f_5331},
{C_text("f_5334:c_2dbackend_2escm"),(void*)f_5334},
{C_text("f_5354:c_2dbackend_2escm"),(void*)f_5354},
{C_text("f_5357:c_2dbackend_2escm"),(void*)f_5357},
{C_text("f_5360:c_2dbackend_2escm"),(void*)f_5360},
{C_text("f_5363:c_2dbackend_2escm"),(void*)f_5363},
{C_text("f_5386:c_2dbackend_2escm"),(void*)f_5386},
{C_text("f_5387:c_2dbackend_2escm"),(void*)f_5387},
{C_text("f_5391:c_2dbackend_2escm"),(void*)f_5391},
{C_text("f_5394:c_2dbackend_2escm"),(void*)f_5394},
{C_text("f_5400:c_2dbackend_2escm"),(void*)f_5400},
{C_text("f_5409:c_2dbackend_2escm"),(void*)f_5409},
{C_text("f_5416:c_2dbackend_2escm"),(void*)f_5416},
{C_text("f_5426:c_2dbackend_2escm"),(void*)f_5426},
{C_text("f_5460:c_2dbackend_2escm"),(void*)f_5460},
{C_text("f_5463:c_2dbackend_2escm"),(void*)f_5463},
{C_text("f_5492:c_2dbackend_2escm"),(void*)f_5492},
{C_text("f_5534:c_2dbackend_2escm"),(void*)f_5534},
{C_text("f_5538:c_2dbackend_2escm"),(void*)f_5538},
{C_text("f_5569:c_2dbackend_2escm"),(void*)f_5569},
{C_text("f_5572:c_2dbackend_2escm"),(void*)f_5572},
{C_text("f_5575:c_2dbackend_2escm"),(void*)f_5575},
{C_text("f_5586:c_2dbackend_2escm"),(void*)f_5586},
{C_text("f_5590:c_2dbackend_2escm"),(void*)f_5590},
{C_text("f_5617:c_2dbackend_2escm"),(void*)f_5617},
{C_text("f_5620:c_2dbackend_2escm"),(void*)f_5620},
{C_text("f_5631:c_2dbackend_2escm"),(void*)f_5631},
{C_text("f_5635:c_2dbackend_2escm"),(void*)f_5635},
{C_text("f_5638:c_2dbackend_2escm"),(void*)f_5638},
{C_text("f_5641:c_2dbackend_2escm"),(void*)f_5641},
{C_text("f_5652:c_2dbackend_2escm"),(void*)f_5652},
{C_text("f_5656:c_2dbackend_2escm"),(void*)f_5656},
{C_text("f_5693:c_2dbackend_2escm"),(void*)f_5693},
{C_text("f_5696:c_2dbackend_2escm"),(void*)f_5696},
{C_text("f_5702:c_2dbackend_2escm"),(void*)f_5702},
{C_text("f_5706:c_2dbackend_2escm"),(void*)f_5706},
{C_text("f_5715:c_2dbackend_2escm"),(void*)f_5715},
{C_text("f_5718:c_2dbackend_2escm"),(void*)f_5718},
{C_text("f_5721:c_2dbackend_2escm"),(void*)f_5721},
{C_text("f_5737:c_2dbackend_2escm"),(void*)f_5737},
{C_text("f_5740:c_2dbackend_2escm"),(void*)f_5740},
{C_text("f_5743:c_2dbackend_2escm"),(void*)f_5743},
{C_text("f_5744:c_2dbackend_2escm"),(void*)f_5744},
{C_text("f_5748:c_2dbackend_2escm"),(void*)f_5748},
{C_text("f_5751:c_2dbackend_2escm"),(void*)f_5751},
{C_text("f_5760:c_2dbackend_2escm"),(void*)f_5760},
{C_text("f_5768:c_2dbackend_2escm"),(void*)f_5768},
{C_text("f_5774:c_2dbackend_2escm"),(void*)f_5774},
{C_text("f_5777:c_2dbackend_2escm"),(void*)f_5777},
{C_text("f_5785:c_2dbackend_2escm"),(void*)f_5785},
{C_text("f_5795:c_2dbackend_2escm"),(void*)f_5795},
{C_text("f_5822:c_2dbackend_2escm"),(void*)f_5822},
{C_text("f_5832:c_2dbackend_2escm"),(void*)f_5832},
{C_text("f_5859:c_2dbackend_2escm"),(void*)f_5859},
{C_text("f_5866:c_2dbackend_2escm"),(void*)f_5866},
{C_text("f_5872:c_2dbackend_2escm"),(void*)f_5872},
{C_text("f_5875:c_2dbackend_2escm"),(void*)f_5875},
{C_text("f_5878:c_2dbackend_2escm"),(void*)f_5878},
{C_text("f_5887:c_2dbackend_2escm"),(void*)f_5887},
{C_text("f_5890:c_2dbackend_2escm"),(void*)f_5890},
{C_text("f_5893:c_2dbackend_2escm"),(void*)f_5893},
{C_text("f_5896:c_2dbackend_2escm"),(void*)f_5896},
{C_text("f_5906:c_2dbackend_2escm"),(void*)f_5906},
{C_text("f_5917:c_2dbackend_2escm"),(void*)f_5917},
{C_text("f_5921:c_2dbackend_2escm"),(void*)f_5921},
{C_text("f_5924:c_2dbackend_2escm"),(void*)f_5924},
{C_text("f_5937:c_2dbackend_2escm"),(void*)f_5937},
{C_text("f_5943:c_2dbackend_2escm"),(void*)f_5943},
{C_text("f_5946:c_2dbackend_2escm"),(void*)f_5946},
{C_text("f_5958:c_2dbackend_2escm"),(void*)f_5958},
{C_text("f_5961:c_2dbackend_2escm"),(void*)f_5961},
{C_text("f_5964:c_2dbackend_2escm"),(void*)f_5964},
{C_text("f_5967:c_2dbackend_2escm"),(void*)f_5967},
{C_text("f_5974:c_2dbackend_2escm"),(void*)f_5974},
{C_text("f_5984:c_2dbackend_2escm"),(void*)f_5984},
{C_text("f_5992:c_2dbackend_2escm"),(void*)f_5992},
{C_text("f_6000:c_2dbackend_2escm"),(void*)f_6000},
{C_text("f_6013:c_2dbackend_2escm"),(void*)f_6013},
{C_text("f_6017:c_2dbackend_2escm"),(void*)f_6017},
{C_text("f_6025:c_2dbackend_2escm"),(void*)f_6025},
{C_text("f_6033:c_2dbackend_2escm"),(void*)f_6033},
{C_text("f_6040:c_2dbackend_2escm"),(void*)f_6040},
{C_text("f_6045:c_2dbackend_2escm"),(void*)f_6045},
{C_text("f_6052:c_2dbackend_2escm"),(void*)f_6052},
{C_text("f_6056:c_2dbackend_2escm"),(void*)f_6056},
{C_text("f_6059:c_2dbackend_2escm"),(void*)f_6059},
{C_text("f_6062:c_2dbackend_2escm"),(void*)f_6062},
{C_text("f_6065:c_2dbackend_2escm"),(void*)f_6065},
{C_text("f_6068:c_2dbackend_2escm"),(void*)f_6068},
{C_text("f_6071:c_2dbackend_2escm"),(void*)f_6071},
{C_text("f_6077:c_2dbackend_2escm"),(void*)f_6077},
{C_text("f_6090:c_2dbackend_2escm"),(void*)f_6090},
{C_text("f_6095:c_2dbackend_2escm"),(void*)f_6095},
{C_text("f_6118:c_2dbackend_2escm"),(void*)f_6118},
{C_text("f_6122:c_2dbackend_2escm"),(void*)f_6122},
{C_text("f_6125:c_2dbackend_2escm"),(void*)f_6125},
{C_text("f_6145:c_2dbackend_2escm"),(void*)f_6145},
{C_text("f_6152:c_2dbackend_2escm"),(void*)f_6152},
{C_text("f_6156:c_2dbackend_2escm"),(void*)f_6156},
{C_text("f_6160:c_2dbackend_2escm"),(void*)f_6160},
{C_text("f_6203:c_2dbackend_2escm"),(void*)f_6203},
{C_text("f_6209:c_2dbackend_2escm"),(void*)f_6209},
{C_text("f_6212:c_2dbackend_2escm"),(void*)f_6212},
{C_text("f_6213:c_2dbackend_2escm"),(void*)f_6213},
{C_text("f_6217:c_2dbackend_2escm"),(void*)f_6217},
{C_text("f_6220:c_2dbackend_2escm"),(void*)f_6220},
{C_text("f_6229:c_2dbackend_2escm"),(void*)f_6229},
{C_text("f_6237:c_2dbackend_2escm"),(void*)f_6237},
{C_text("f_6243:c_2dbackend_2escm"),(void*)f_6243},
{C_text("f_6248:c_2dbackend_2escm"),(void*)f_6248},
{C_text("f_6258:c_2dbackend_2escm"),(void*)f_6258},
{C_text("f_6285:c_2dbackend_2escm"),(void*)f_6285},
{C_text("f_6295:c_2dbackend_2escm"),(void*)f_6295},
{C_text("f_6322:c_2dbackend_2escm"),(void*)f_6322},
{C_text("f_6329:c_2dbackend_2escm"),(void*)f_6329},
{C_text("f_6332:c_2dbackend_2escm"),(void*)f_6332},
{C_text("f_6335:c_2dbackend_2escm"),(void*)f_6335},
{C_text("f_6363:c_2dbackend_2escm"),(void*)f_6363},
{C_text("f_6376:c_2dbackend_2escm"),(void*)f_6376},
{C_text("f_6380:c_2dbackend_2escm"),(void*)f_6380},
{C_text("f_6383:c_2dbackend_2escm"),(void*)f_6383},
{C_text("f_6386:c_2dbackend_2escm"),(void*)f_6386},
{C_text("f_6389:c_2dbackend_2escm"),(void*)f_6389},
{C_text("f_6392:c_2dbackend_2escm"),(void*)f_6392},
{C_text("f_6395:c_2dbackend_2escm"),(void*)f_6395},
{C_text("f_6398:c_2dbackend_2escm"),(void*)f_6398},
{C_text("f_6410:c_2dbackend_2escm"),(void*)f_6410},
{C_text("f_6422:c_2dbackend_2escm"),(void*)f_6422},
{C_text("f_6440:c_2dbackend_2escm"),(void*)f_6440},
{C_text("f_6460:c_2dbackend_2escm"),(void*)f_6460},
{C_text("f_6467:c_2dbackend_2escm"),(void*)f_6467},
{C_text("f_6471:c_2dbackend_2escm"),(void*)f_6471},
{C_text("f_6500:c_2dbackend_2escm"),(void*)f_6500},
{C_text("f_6503:c_2dbackend_2escm"),(void*)f_6503},
{C_text("f_6510:c_2dbackend_2escm"),(void*)f_6510},
{C_text("f_6523:c_2dbackend_2escm"),(void*)f_6523},
{C_text("f_6526:c_2dbackend_2escm"),(void*)f_6526},
{C_text("f_6542:c_2dbackend_2escm"),(void*)f_6542},
{C_text("f_6545:c_2dbackend_2escm"),(void*)f_6545},
{C_text("f_6578:c_2dbackend_2escm"),(void*)f_6578},
{C_text("f_6581:c_2dbackend_2escm"),(void*)f_6581},
{C_text("f_6590:c_2dbackend_2escm"),(void*)f_6590},
{C_text("f_6614:c_2dbackend_2escm"),(void*)f_6614},
{C_text("f_6634:c_2dbackend_2escm"),(void*)f_6634},
{C_text("f_6637:c_2dbackend_2escm"),(void*)f_6637},
{C_text("f_6652:c_2dbackend_2escm"),(void*)f_6652},
{C_text("f_6656:c_2dbackend_2escm"),(void*)f_6656},
{C_text("f_6668:c_2dbackend_2escm"),(void*)f_6668},
{C_text("f_6671:c_2dbackend_2escm"),(void*)f_6671},
{C_text("f_6682:c_2dbackend_2escm"),(void*)f_6682},
{C_text("f_6686:c_2dbackend_2escm"),(void*)f_6686},
{C_text("f_6698:c_2dbackend_2escm"),(void*)f_6698},
{C_text("f_6701:c_2dbackend_2escm"),(void*)f_6701},
{C_text("f_6704:c_2dbackend_2escm"),(void*)f_6704},
{C_text("f_6707:c_2dbackend_2escm"),(void*)f_6707},
{C_text("f_6718:c_2dbackend_2escm"),(void*)f_6718},
{C_text("f_6726:c_2dbackend_2escm"),(void*)f_6726},
{C_text("f_6735:c_2dbackend_2escm"),(void*)f_6735},
{C_text("f_6738:c_2dbackend_2escm"),(void*)f_6738},
{C_text("f_6741:c_2dbackend_2escm"),(void*)f_6741},
{C_text("f_6754:c_2dbackend_2escm"),(void*)f_6754},
{C_text("f_6762:c_2dbackend_2escm"),(void*)f_6762},
{C_text("f_6765:c_2dbackend_2escm"),(void*)f_6765},
{C_text("f_6775:c_2dbackend_2escm"),(void*)f_6775},
{C_text("f_6778:c_2dbackend_2escm"),(void*)f_6778},
{C_text("f_6781:c_2dbackend_2escm"),(void*)f_6781},
{C_text("f_6784:c_2dbackend_2escm"),(void*)f_6784},
{C_text("f_6814:c_2dbackend_2escm"),(void*)f_6814},
{C_text("f_6817:c_2dbackend_2escm"),(void*)f_6817},
{C_text("f_6820:c_2dbackend_2escm"),(void*)f_6820},
{C_text("f_6823:c_2dbackend_2escm"),(void*)f_6823},
{C_text("f_6826:c_2dbackend_2escm"),(void*)f_6826},
{C_text("f_6829:c_2dbackend_2escm"),(void*)f_6829},
{C_text("f_6851:c_2dbackend_2escm"),(void*)f_6851},
{C_text("f_6937:c_2dbackend_2escm"),(void*)f_6937},
{C_text("f_6943:c_2dbackend_2escm"),(void*)f_6943},
{C_text("f_6953:c_2dbackend_2escm"),(void*)f_6953},
{C_text("f_6956:c_2dbackend_2escm"),(void*)f_6956},
{C_text("f_6973:c_2dbackend_2escm"),(void*)f_6973},
{C_text("f_6979:c_2dbackend_2escm"),(void*)f_6979},
{C_text("f_6998:c_2dbackend_2escm"),(void*)f_6998},
{C_text("f_7010:c_2dbackend_2escm"),(void*)f_7010},
{C_text("f_7014:c_2dbackend_2escm"),(void*)f_7014},
{C_text("f_7016:c_2dbackend_2escm"),(void*)f_7016},
{C_text("f_7028:c_2dbackend_2escm"),(void*)f_7028},
{C_text("f_7031:c_2dbackend_2escm"),(void*)f_7031},
{C_text("f_7034:c_2dbackend_2escm"),(void*)f_7034},
{C_text("f_7037:c_2dbackend_2escm"),(void*)f_7037},
{C_text("f_7040:c_2dbackend_2escm"),(void*)f_7040},
{C_text("f_7049:c_2dbackend_2escm"),(void*)f_7049},
{C_text("f_7059:c_2dbackend_2escm"),(void*)f_7059},
{C_text("f_7062:c_2dbackend_2escm"),(void*)f_7062},
{C_text("f_7065:c_2dbackend_2escm"),(void*)f_7065},
{C_text("f_7085:c_2dbackend_2escm"),(void*)f_7085},
{C_text("f_7100:c_2dbackend_2escm"),(void*)f_7100},
{C_text("f_7103:c_2dbackend_2escm"),(void*)f_7103},
{C_text("f_7106:c_2dbackend_2escm"),(void*)f_7106},
{C_text("f_7109:c_2dbackend_2escm"),(void*)f_7109},
{C_text("f_7112:c_2dbackend_2escm"),(void*)f_7112},
{C_text("f_7134:c_2dbackend_2escm"),(void*)f_7134},
{C_text("f_7137:c_2dbackend_2escm"),(void*)f_7137},
{C_text("f_7145:c_2dbackend_2escm"),(void*)f_7145},
{C_text("f_7149:c_2dbackend_2escm"),(void*)f_7149},
{C_text("f_7152:c_2dbackend_2escm"),(void*)f_7152},
{C_text("f_7155:c_2dbackend_2escm"),(void*)f_7155},
{C_text("f_7158:c_2dbackend_2escm"),(void*)f_7158},
{C_text("f_7161:c_2dbackend_2escm"),(void*)f_7161},
{C_text("f_7164:c_2dbackend_2escm"),(void*)f_7164},
{C_text("f_7167:c_2dbackend_2escm"),(void*)f_7167},
{C_text("f_7170:c_2dbackend_2escm"),(void*)f_7170},
{C_text("f_7182:c_2dbackend_2escm"),(void*)f_7182},
{C_text("f_7192:c_2dbackend_2escm"),(void*)f_7192},
{C_text("f_7202:c_2dbackend_2escm"),(void*)f_7202},
{C_text("f_7222:c_2dbackend_2escm"),(void*)f_7222},
{C_text("f_7235:c_2dbackend_2escm"),(void*)f_7235},
{C_text("f_7247:c_2dbackend_2escm"),(void*)f_7247},
{C_text("f_7250:c_2dbackend_2escm"),(void*)f_7250},
{C_text("f_7252:c_2dbackend_2escm"),(void*)f_7252},
{C_text("f_7277:c_2dbackend_2escm"),(void*)f_7277},
{C_text("f_7288:c_2dbackend_2escm"),(void*)f_7288},
{C_text("f_7298:c_2dbackend_2escm"),(void*)f_7298},
{C_text("f_7302:c_2dbackend_2escm"),(void*)f_7302},
{C_text("f_7304:c_2dbackend_2escm"),(void*)f_7304},
{C_text("f_7311:c_2dbackend_2escm"),(void*)f_7311},
{C_text("f_7325:c_2dbackend_2escm"),(void*)f_7325},
{C_text("f_7331:c_2dbackend_2escm"),(void*)f_7331},
{C_text("f_7334:c_2dbackend_2escm"),(void*)f_7334},
{C_text("f_7337:c_2dbackend_2escm"),(void*)f_7337},
{C_text("f_7342:c_2dbackend_2escm"),(void*)f_7342},
{C_text("f_7352:c_2dbackend_2escm"),(void*)f_7352},
{C_text("f_7358:c_2dbackend_2escm"),(void*)f_7358},
{C_text("f_7361:c_2dbackend_2escm"),(void*)f_7361},
{C_text("f_7364:c_2dbackend_2escm"),(void*)f_7364},
{C_text("f_7367:c_2dbackend_2escm"),(void*)f_7367},
{C_text("f_7382:c_2dbackend_2escm"),(void*)f_7382},
{C_text("f_7390:c_2dbackend_2escm"),(void*)f_7390},
{C_text("f_7400:c_2dbackend_2escm"),(void*)f_7400},
{C_text("f_7410:c_2dbackend_2escm"),(void*)f_7410},
{C_text("f_7451:c_2dbackend_2escm"),(void*)f_7451},
{C_text("f_7461:c_2dbackend_2escm"),(void*)f_7461},
{C_text("f_7474:c_2dbackend_2escm"),(void*)f_7474},
{C_text("f_7499:c_2dbackend_2escm"),(void*)f_7499},
{C_text("f_7508:c_2dbackend_2escm"),(void*)f_7508},
{C_text("f_7512:c_2dbackend_2escm"),(void*)f_7512},
{C_text("f_7521:c_2dbackend_2escm"),(void*)f_7521},
{C_text("f_7524:c_2dbackend_2escm"),(void*)f_7524},
{C_text("f_7527:c_2dbackend_2escm"),(void*)f_7527},
{C_text("f_7530:c_2dbackend_2escm"),(void*)f_7530},
{C_text("f_7533:c_2dbackend_2escm"),(void*)f_7533},
{C_text("f_7536:c_2dbackend_2escm"),(void*)f_7536},
{C_text("f_7539:c_2dbackend_2escm"),(void*)f_7539},
{C_text("f_7542:c_2dbackend_2escm"),(void*)f_7542},
{C_text("f_7545:c_2dbackend_2escm"),(void*)f_7545},
{C_text("f_7548:c_2dbackend_2escm"),(void*)f_7548},
{C_text("f_7551:c_2dbackend_2escm"),(void*)f_7551},
{C_text("f_7554:c_2dbackend_2escm"),(void*)f_7554},
{C_text("f_7557:c_2dbackend_2escm"),(void*)f_7557},
{C_text("f_7560:c_2dbackend_2escm"),(void*)f_7560},
{C_text("f_7581:c_2dbackend_2escm"),(void*)f_7581},
{C_text("f_7604:c_2dbackend_2escm"),(void*)f_7604},
{C_text("f_7607:c_2dbackend_2escm"),(void*)f_7607},
{C_text("f_7610:c_2dbackend_2escm"),(void*)f_7610},
{C_text("f_7613:c_2dbackend_2escm"),(void*)f_7613},
{C_text("f_7629:c_2dbackend_2escm"),(void*)f_7629},
{C_text("f_7632:c_2dbackend_2escm"),(void*)f_7632},
{C_text("f_7635:c_2dbackend_2escm"),(void*)f_7635},
{C_text("f_7646:c_2dbackend_2escm"),(void*)f_7646},
{C_text("f_7655:c_2dbackend_2escm"),(void*)f_7655},
{C_text("f_7663:c_2dbackend_2escm"),(void*)f_7663},
{C_text("f_7673:c_2dbackend_2escm"),(void*)f_7673},
{C_text("f_7686:c_2dbackend_2escm"),(void*)f_7686},
{C_text("f_7697:c_2dbackend_2escm"),(void*)f_7697},
{C_text("f_7707:c_2dbackend_2escm"),(void*)f_7707},
{C_text("f_7723:c_2dbackend_2escm"),(void*)f_7723},
{C_text("f_7726:c_2dbackend_2escm"),(void*)f_7726},
{C_text("f_7729:c_2dbackend_2escm"),(void*)f_7729},
{C_text("f_7732:c_2dbackend_2escm"),(void*)f_7732},
{C_text("f_7741:c_2dbackend_2escm"),(void*)f_7741},
{C_text("f_7744:c_2dbackend_2escm"),(void*)f_7744},
{C_text("f_7747:c_2dbackend_2escm"),(void*)f_7747},
{C_text("f_7750:c_2dbackend_2escm"),(void*)f_7750},
{C_text("f_7753:c_2dbackend_2escm"),(void*)f_7753},
{C_text("f_7756:c_2dbackend_2escm"),(void*)f_7756},
{C_text("f_7763:c_2dbackend_2escm"),(void*)f_7763},
{C_text("f_7770:c_2dbackend_2escm"),(void*)f_7770},
{C_text("f_7776:c_2dbackend_2escm"),(void*)f_7776},
{C_text("f_7784:c_2dbackend_2escm"),(void*)f_7784},
{C_text("f_7794:c_2dbackend_2escm"),(void*)f_7794},
{C_text("f_7807:c_2dbackend_2escm"),(void*)f_7807},
{C_text("f_7813:c_2dbackend_2escm"),(void*)f_7813},
{C_text("f_7823:c_2dbackend_2escm"),(void*)f_7823},
{C_text("f_7838:c_2dbackend_2escm"),(void*)f_7838},
{C_text("f_7844:c_2dbackend_2escm"),(void*)f_7844},
{C_text("f_7847:c_2dbackend_2escm"),(void*)f_7847},
{C_text("f_7850:c_2dbackend_2escm"),(void*)f_7850},
{C_text("f_7853:c_2dbackend_2escm"),(void*)f_7853},
{C_text("f_7861:c_2dbackend_2escm"),(void*)f_7861},
{C_text("f_7868:c_2dbackend_2escm"),(void*)f_7868},
{C_text("f_7874:c_2dbackend_2escm"),(void*)f_7874},
{C_text("f_7904:c_2dbackend_2escm"),(void*)f_7904},
{C_text("f_7917:c_2dbackend_2escm"),(void*)f_7917},
{C_text("f_7921:c_2dbackend_2escm"),(void*)f_7921},
{C_text("f_7945:c_2dbackend_2escm"),(void*)f_7945},
{C_text("f_7948:c_2dbackend_2escm"),(void*)f_7948},
{C_text("f_7954:c_2dbackend_2escm"),(void*)f_7954},
{C_text("f_7956:c_2dbackend_2escm"),(void*)f_7956},
{C_text("f_7980:c_2dbackend_2escm"),(void*)f_7980},
{C_text("f_8005:c_2dbackend_2escm"),(void*)f_8005},
{C_text("f_8019:c_2dbackend_2escm"),(void*)f_8019},
{C_text("f_8037:c_2dbackend_2escm"),(void*)f_8037},
{C_text("f_8044:c_2dbackend_2escm"),(void*)f_8044},
{C_text("f_8065:c_2dbackend_2escm"),(void*)f_8065},
{C_text("f_8085:c_2dbackend_2escm"),(void*)f_8085},
{C_text("f_8106:c_2dbackend_2escm"),(void*)f_8106},
{C_text("f_8110:c_2dbackend_2escm"),(void*)f_8110},
{C_text("f_8131:c_2dbackend_2escm"),(void*)f_8131},
{C_text("f_8135:c_2dbackend_2escm"),(void*)f_8135},
{C_text("f_8144:c_2dbackend_2escm"),(void*)f_8144},
{C_text("f_8151:c_2dbackend_2escm"),(void*)f_8151},
{C_text("f_8157:c_2dbackend_2escm"),(void*)f_8157},
{C_text("f_8201:c_2dbackend_2escm"),(void*)f_8201},
{C_text("f_8210:c_2dbackend_2escm"),(void*)f_8210},
{C_text("f_8219:c_2dbackend_2escm"),(void*)f_8219},
{C_text("f_8225:c_2dbackend_2escm"),(void*)f_8225},
{C_text("f_8252:c_2dbackend_2escm"),(void*)f_8252},
{C_text("f_8255:c_2dbackend_2escm"),(void*)f_8255},
{C_text("f_8262:c_2dbackend_2escm"),(void*)f_8262},
{C_text("f_8296:c_2dbackend_2escm"),(void*)f_8296},
{C_text("f_8298:c_2dbackend_2escm"),(void*)f_8298},
{C_text("f_8312:c_2dbackend_2escm"),(void*)f_8312},
{C_text("f_8333:c_2dbackend_2escm"),(void*)f_8333},
{C_text("f_8337:c_2dbackend_2escm"),(void*)f_8337},
{C_text("f_8349:c_2dbackend_2escm"),(void*)f_8349},
{C_text("f_8362:c_2dbackend_2escm"),(void*)f_8362},
{C_text("f_8366:c_2dbackend_2escm"),(void*)f_8366},
{C_text("f_8372:c_2dbackend_2escm"),(void*)f_8372},
{C_text("f_8379:c_2dbackend_2escm"),(void*)f_8379},
{C_text("f_8382:c_2dbackend_2escm"),(void*)f_8382},
{C_text("f_8384:c_2dbackend_2escm"),(void*)f_8384},
{C_text("f_8386:c_2dbackend_2escm"),(void*)f_8386},
{C_text("f_8394:c_2dbackend_2escm"),(void*)f_8394},
{C_text("f_8397:c_2dbackend_2escm"),(void*)f_8397},
{C_text("f_8400:c_2dbackend_2escm"),(void*)f_8400},
{C_text("f_8403:c_2dbackend_2escm"),(void*)f_8403},
{C_text("f_8406:c_2dbackend_2escm"),(void*)f_8406},
{C_text("f_8409:c_2dbackend_2escm"),(void*)f_8409},
{C_text("f_8412:c_2dbackend_2escm"),(void*)f_8412},
{C_text("f_8418:c_2dbackend_2escm"),(void*)f_8418},
{C_text("f_8421:c_2dbackend_2escm"),(void*)f_8421},
{C_text("f_8424:c_2dbackend_2escm"),(void*)f_8424},
{C_text("f_8427:c_2dbackend_2escm"),(void*)f_8427},
{C_text("f_8430:c_2dbackend_2escm"),(void*)f_8430},
{C_text("f_8433:c_2dbackend_2escm"),(void*)f_8433},
{C_text("f_8436:c_2dbackend_2escm"),(void*)f_8436},
{C_text("f_8439:c_2dbackend_2escm"),(void*)f_8439},
{C_text("f_8442:c_2dbackend_2escm"),(void*)f_8442},
{C_text("f_8445:c_2dbackend_2escm"),(void*)f_8445},
{C_text("f_8448:c_2dbackend_2escm"),(void*)f_8448},
{C_text("f_8451:c_2dbackend_2escm"),(void*)f_8451},
{C_text("f_8454:c_2dbackend_2escm"),(void*)f_8454},
{C_text("f_8457:c_2dbackend_2escm"),(void*)f_8457},
{C_text("f_8460:c_2dbackend_2escm"),(void*)f_8460},
{C_text("f_8463:c_2dbackend_2escm"),(void*)f_8463},
{C_text("f_8466:c_2dbackend_2escm"),(void*)f_8466},
{C_text("f_8469:c_2dbackend_2escm"),(void*)f_8469},
{C_text("f_8472:c_2dbackend_2escm"),(void*)f_8472},
{C_text("f_8475:c_2dbackend_2escm"),(void*)f_8475},
{C_text("f_8478:c_2dbackend_2escm"),(void*)f_8478},
{C_text("f_8481:c_2dbackend_2escm"),(void*)f_8481},
{C_text("f_8484:c_2dbackend_2escm"),(void*)f_8484},
{C_text("f_8487:c_2dbackend_2escm"),(void*)f_8487},
{C_text("f_8490:c_2dbackend_2escm"),(void*)f_8490},
{C_text("f_8493:c_2dbackend_2escm"),(void*)f_8493},
{C_text("f_8497:c_2dbackend_2escm"),(void*)f_8497},
{C_text("f_8504:c_2dbackend_2escm"),(void*)f_8504},
{C_text("f_8515:c_2dbackend_2escm"),(void*)f_8515},
{C_text("f_8521:c_2dbackend_2escm"),(void*)f_8521},
{C_text("f_8524:c_2dbackend_2escm"),(void*)f_8524},
{C_text("f_8533:c_2dbackend_2escm"),(void*)f_8533},
{C_text("f_8541:c_2dbackend_2escm"),(void*)f_8541},
{C_text("f_8555:c_2dbackend_2escm"),(void*)f_8555},
{C_text("f_8570:c_2dbackend_2escm"),(void*)f_8570},
{C_text("f_8573:c_2dbackend_2escm"),(void*)f_8573},
{C_text("f_8590:c_2dbackend_2escm"),(void*)f_8590},
{C_text("f_8600:c_2dbackend_2escm"),(void*)f_8600},
{C_text("f_8630:c_2dbackend_2escm"),(void*)f_8630},
{C_text("f_8634:c_2dbackend_2escm"),(void*)f_8634},
{C_text("f_8637:c_2dbackend_2escm"),(void*)f_8637},
{C_text("f_8640:c_2dbackend_2escm"),(void*)f_8640},
{C_text("f_8643:c_2dbackend_2escm"),(void*)f_8643},
{C_text("f_8646:c_2dbackend_2escm"),(void*)f_8646},
{C_text("f_8649:c_2dbackend_2escm"),(void*)f_8649},
{C_text("f_8658:c_2dbackend_2escm"),(void*)f_8658},
{C_text("f_8661:c_2dbackend_2escm"),(void*)f_8661},
{C_text("f_8672:c_2dbackend_2escm"),(void*)f_8672},
{C_text("f_8693:c_2dbackend_2escm"),(void*)f_8693},
{C_text("f_8709:c_2dbackend_2escm"),(void*)f_8709},
{C_text("f_8717:c_2dbackend_2escm"),(void*)f_8717},
{C_text("f_8720:c_2dbackend_2escm"),(void*)f_8720},
{C_text("f_8730:c_2dbackend_2escm"),(void*)f_8730},
{C_text("f_8733:c_2dbackend_2escm"),(void*)f_8733},
{C_text("f_8736:c_2dbackend_2escm"),(void*)f_8736},
{C_text("f_8745:c_2dbackend_2escm"),(void*)f_8745},
{C_text("f_8769:c_2dbackend_2escm"),(void*)f_8769},
{C_text("f_8772:c_2dbackend_2escm"),(void*)f_8772},
{C_text("f_8775:c_2dbackend_2escm"),(void*)f_8775},
{C_text("f_8778:c_2dbackend_2escm"),(void*)f_8778},
{C_text("f_8787:c_2dbackend_2escm"),(void*)f_8787},
{C_text("f_8803:c_2dbackend_2escm"),(void*)f_8803},
{C_text("f_8863:c_2dbackend_2escm"),(void*)f_8863},
{C_text("f_8876:c_2dbackend_2escm"),(void*)f_8876},
{C_text("f_8886:c_2dbackend_2escm"),(void*)f_8886},
{C_text("f_8901:c_2dbackend_2escm"),(void*)f_8901},
{C_text("f_8903:c_2dbackend_2escm"),(void*)f_8903},
{C_text("f_8911:c_2dbackend_2escm"),(void*)f_8911},
{C_text("f_8931:c_2dbackend_2escm"),(void*)f_8931},
{C_text("f_8941:c_2dbackend_2escm"),(void*)f_8941},
{C_text("f_8965:c_2dbackend_2escm"),(void*)f_8965},
{C_text("f_8988:c_2dbackend_2escm"),(void*)f_8988},
{C_text("f_8991:c_2dbackend_2escm"),(void*)f_8991},
{C_text("f_8994:c_2dbackend_2escm"),(void*)f_8994},
{C_text("f_9010:c_2dbackend_2escm"),(void*)f_9010},
{C_text("f_9013:c_2dbackend_2escm"),(void*)f_9013},
{C_text("f_9027:c_2dbackend_2escm"),(void*)f_9027},
{C_text("f_9052:c_2dbackend_2escm"),(void*)f_9052},
{C_text("f_9056:c_2dbackend_2escm"),(void*)f_9056},
{C_text("f_9064:c_2dbackend_2escm"),(void*)f_9064},
{C_text("f_9074:c_2dbackend_2escm"),(void*)f_9074},
{C_text("f_9088:c_2dbackend_2escm"),(void*)f_9088},
{C_text("f_9092:c_2dbackend_2escm"),(void*)f_9092},
{C_text("f_9095:c_2dbackend_2escm"),(void*)f_9095},
{C_text("f_9098:c_2dbackend_2escm"),(void*)f_9098},
{C_text("f_9101:c_2dbackend_2escm"),(void*)f_9101},
{C_text("f_9104:c_2dbackend_2escm"),(void*)f_9104},
{C_text("f_9107:c_2dbackend_2escm"),(void*)f_9107},
{C_text("f_9110:c_2dbackend_2escm"),(void*)f_9110},
{C_text("f_9113:c_2dbackend_2escm"),(void*)f_9113},
{C_text("f_9116:c_2dbackend_2escm"),(void*)f_9116},
{C_text("f_9119:c_2dbackend_2escm"),(void*)f_9119},
{C_text("f_9134:c_2dbackend_2escm"),(void*)f_9134},
{C_text("f_9139:c_2dbackend_2escm"),(void*)f_9139},
{C_text("f_9157:c_2dbackend_2escm"),(void*)f_9157},
{C_text("f_9161:c_2dbackend_2escm"),(void*)f_9161},
{C_text("f_9170:c_2dbackend_2escm"),(void*)f_9170},
{C_text("f_9175:c_2dbackend_2escm"),(void*)f_9175},
{C_text("f_9185:c_2dbackend_2escm"),(void*)f_9185},
{C_text("f_9203:c_2dbackend_2escm"),(void*)f_9203},
{C_text("f_9209:c_2dbackend_2escm"),(void*)f_9209},
{C_text("f_9214:c_2dbackend_2escm"),(void*)f_9214},
{C_text("f_9224:c_2dbackend_2escm"),(void*)f_9224},
{C_text("f_9237:c_2dbackend_2escm"),(void*)f_9237},
{C_text("f_9255:c_2dbackend_2escm"),(void*)f_9255},
{C_text("f_9256:c_2dbackend_2escm"),(void*)f_9256},
{C_text("f_9264:c_2dbackend_2escm"),(void*)f_9264},
{C_text("f_9277:c_2dbackend_2escm"),(void*)f_9277},
{C_text("f_9284:c_2dbackend_2escm"),(void*)f_9284},
{C_text("f_9287:c_2dbackend_2escm"),(void*)f_9287},
{C_text("f_9290:c_2dbackend_2escm"),(void*)f_9290},
{C_text("f_9293:c_2dbackend_2escm"),(void*)f_9293},
{C_text("f_9296:c_2dbackend_2escm"),(void*)f_9296},
{C_text("f_9301:c_2dbackend_2escm"),(void*)f_9301},
{C_text("f_9311:c_2dbackend_2escm"),(void*)f_9311},
{C_text("f_9329:c_2dbackend_2escm"),(void*)f_9329},
{C_text("f_9343:c_2dbackend_2escm"),(void*)f_9343},
{C_text("f_9345:c_2dbackend_2escm"),(void*)f_9345},
{C_text("f_9354:c_2dbackend_2escm"),(void*)f_9354},
{C_text("f_9380:c_2dbackend_2escm"),(void*)f_9380},
{C_text("f_9390:c_2dbackend_2escm"),(void*)f_9390},
{C_text("f_9421:c_2dbackend_2escm"),(void*)f_9421},
{C_text("f_9427:c_2dbackend_2escm"),(void*)f_9427},
{C_text("f_9435:c_2dbackend_2escm"),(void*)f_9435},
{C_text("f_9438:c_2dbackend_2escm"),(void*)f_9438},
{C_text("f_9444:c_2dbackend_2escm"),(void*)f_9444},
{C_text("f_9452:c_2dbackend_2escm"),(void*)f_9452},
{C_text("f_9459:c_2dbackend_2escm"),(void*)f_9459},
{C_text("f_9481:c_2dbackend_2escm"),(void*)f_9481},
{C_text("f_9489:c_2dbackend_2escm"),(void*)f_9489},
{C_text("f_9499:c_2dbackend_2escm"),(void*)f_9499},
{C_text("f_9512:c_2dbackend_2escm"),(void*)f_9512},
{C_text("f_9518:c_2dbackend_2escm"),(void*)f_9518},
{C_text("f_9521:c_2dbackend_2escm"),(void*)f_9521},
{C_text("f_9532:c_2dbackend_2escm"),(void*)f_9532},
{C_text("f_9542:c_2dbackend_2escm"),(void*)f_9542},
{C_text("f_9557:c_2dbackend_2escm"),(void*)f_9557},
{C_text("f_9561:c_2dbackend_2escm"),(void*)f_9561},
{C_text("f_9564:c_2dbackend_2escm"),(void*)f_9564},
{C_text("f_9567:c_2dbackend_2escm"),(void*)f_9567},
{C_text("f_9573:c_2dbackend_2escm"),(void*)f_9573},
{C_text("f_9576:c_2dbackend_2escm"),(void*)f_9576},
{C_text("f_9579:c_2dbackend_2escm"),(void*)f_9579},
{C_text("f_9582:c_2dbackend_2escm"),(void*)f_9582},
{C_text("f_9585:c_2dbackend_2escm"),(void*)f_9585},
{C_text("f_9588:c_2dbackend_2escm"),(void*)f_9588},
{C_text("f_9591:c_2dbackend_2escm"),(void*)f_9591},
{C_text("f_9594:c_2dbackend_2escm"),(void*)f_9594},
{C_text("f_9597:c_2dbackend_2escm"),(void*)f_9597},
{C_text("f_9600:c_2dbackend_2escm"),(void*)f_9600},
{C_text("f_9603:c_2dbackend_2escm"),(void*)f_9603},
{C_text("f_9606:c_2dbackend_2escm"),(void*)f_9606},
{C_text("f_9609:c_2dbackend_2escm"),(void*)f_9609},
{C_text("f_9618:c_2dbackend_2escm"),(void*)f_9618},
{C_text("f_9622:c_2dbackend_2escm"),(void*)f_9622},
{C_text("f_9626:c_2dbackend_2escm"),(void*)f_9626},
{C_text("f_9630:c_2dbackend_2escm"),(void*)f_9630},
{C_text("f_9636:c_2dbackend_2escm"),(void*)f_9636},
{C_text("f_9642:c_2dbackend_2escm"),(void*)f_9642},
{C_text("f_9645:c_2dbackend_2escm"),(void*)f_9645},
{C_text("f_9651:c_2dbackend_2escm"),(void*)f_9651},
{C_text("f_9660:c_2dbackend_2escm"),(void*)f_9660},
{C_text("f_9663:c_2dbackend_2escm"),(void*)f_9663},
{C_text("f_9666:c_2dbackend_2escm"),(void*)f_9666},
{C_text("f_9672:c_2dbackend_2escm"),(void*)f_9672},
{C_text("f_9675:c_2dbackend_2escm"),(void*)f_9675},
{C_text("f_9693:c_2dbackend_2escm"),(void*)f_9693},
{C_text("f_9696:c_2dbackend_2escm"),(void*)f_9696},
{C_text("f_9699:c_2dbackend_2escm"),(void*)f_9699},
{C_text("f_9702:c_2dbackend_2escm"),(void*)f_9702},
{C_text("f_9705:c_2dbackend_2escm"),(void*)f_9705},
{C_text("f_9730:c_2dbackend_2escm"),(void*)f_9730},
{C_text("f_9734:c_2dbackend_2escm"),(void*)f_9734},
{C_text("f_9752:c_2dbackend_2escm"),(void*)f_9752},
{C_text("f_9759:c_2dbackend_2escm"),(void*)f_9759},
{C_text("f_9762:c_2dbackend_2escm"),(void*)f_9762},
{C_text("f_9804:c_2dbackend_2escm"),(void*)f_9804},
{C_text("f_9809:c_2dbackend_2escm"),(void*)f_9809},
{C_text("f_9819:c_2dbackend_2escm"),(void*)f_9819},
{C_text("f_9831:c_2dbackend_2escm"),(void*)f_9831},
{C_text("f_9834:c_2dbackend_2escm"),(void*)f_9834},
{C_text("f_9841:c_2dbackend_2escm"),(void*)f_9841},
{C_text("f_9849:c_2dbackend_2escm"),(void*)f_9849},
{C_text("f_9859:c_2dbackend_2escm"),(void*)f_9859},
{C_text("f_9870:c_2dbackend_2escm"),(void*)f_9870},
{C_text("f_9880:c_2dbackend_2escm"),(void*)f_9880},
{C_text("f_9895:c_2dbackend_2escm"),(void*)f_9895},
{C_text("f_9899:c_2dbackend_2escm"),(void*)f_9899},
{C_text("f_9902:c_2dbackend_2escm"),(void*)f_9902},
{C_text("f_9905:c_2dbackend_2escm"),(void*)f_9905},
{C_text("f_9908:c_2dbackend_2escm"),(void*)f_9908},
{C_text("f_9914:c_2dbackend_2escm"),(void*)f_9914},
{C_text("f_9916:c_2dbackend_2escm"),(void*)f_9916},
{C_text("f_9926:c_2dbackend_2escm"),(void*)f_9926},
{C_text("f_9935:c_2dbackend_2escm"),(void*)f_9935},
{C_text("f_9947:c_2dbackend_2escm"),(void*)f_9947},
{C_text("f_9959:c_2dbackend_2escm"),(void*)f_9959},
{C_text("f_9971:c_2dbackend_2escm"),(void*)f_9971},
{C_text("f_9983:c_2dbackend_2escm"),(void*)f_9983},
{C_text("f_9989:c_2dbackend_2escm"),(void*)f_9989},
{C_text("f_9993:c_2dbackend_2escm"),(void*)f_9993},
{C_text("toplevel:c_2dbackend_2escm"),(void*)C_c_2dbackend_toplevel},
{C_text("va15400:c_2dbackend_2escm"),(void*)va15400},
{C_text("va15406:c_2dbackend_2escm"),(void*)va15406},
{C_text("va15438:c_2dbackend_2escm"),(void*)va15438},
{C_text("va15440:c_2dbackend_2escm"),(void*)va15440},
{C_text("va15448:c_2dbackend_2escm"),(void*)va15448},
{C_text("va15450:c_2dbackend_2escm"),(void*)va15450},
{NULL,NULL}};
#endif

static C_PTABLE_ENTRY *create_ptable(void){
#ifdef C_ENABLE_PTABLES
return ptable;
#else
return NULL;
#endif
}

/*
o|hiding unexported module binding: chicken.compiler.c-backend#partition 
o|hiding unexported module binding: chicken.compiler.c-backend#span 
o|hiding unexported module binding: chicken.compiler.c-backend#take 
o|hiding unexported module binding: chicken.compiler.c-backend#drop 
o|hiding unexported module binding: chicken.compiler.c-backend#split-at 
o|hiding unexported module binding: chicken.compiler.c-backend#append-map 
o|hiding unexported module binding: chicken.compiler.c-backend#every 
o|hiding unexported module binding: chicken.compiler.c-backend#any 
o|hiding unexported module binding: chicken.compiler.c-backend#cons* 
o|hiding unexported module binding: chicken.compiler.c-backend#concatenate 
o|hiding unexported module binding: chicken.compiler.c-backend#delete 
o|hiding unexported module binding: chicken.compiler.c-backend#first 
o|hiding unexported module binding: chicken.compiler.c-backend#second 
o|hiding unexported module binding: chicken.compiler.c-backend#third 
o|hiding unexported module binding: chicken.compiler.c-backend#fourth 
o|hiding unexported module binding: chicken.compiler.c-backend#fifth 
o|hiding unexported module binding: chicken.compiler.c-backend#delete-duplicates 
o|hiding unexported module binding: chicken.compiler.c-backend#alist-cons 
o|hiding unexported module binding: chicken.compiler.c-backend#filter 
o|hiding unexported module binding: chicken.compiler.c-backend#filter-map 
o|hiding unexported module binding: chicken.compiler.c-backend#remove 
o|hiding unexported module binding: chicken.compiler.c-backend#unzip1 
o|hiding unexported module binding: chicken.compiler.c-backend#last 
o|hiding unexported module binding: chicken.compiler.c-backend#list-index 
o|hiding unexported module binding: chicken.compiler.c-backend#lset-adjoin/eq? 
o|hiding unexported module binding: chicken.compiler.c-backend#lset-difference/eq? 
o|hiding unexported module binding: chicken.compiler.c-backend#lset-union/eq? 
o|hiding unexported module binding: chicken.compiler.c-backend#lset-intersection/eq? 
o|hiding unexported module binding: chicken.compiler.c-backend#list-tabulate 
o|hiding unexported module binding: chicken.compiler.c-backend#lset<=/eq? 
o|hiding unexported module binding: chicken.compiler.c-backend#lset=/eq? 
o|hiding unexported module binding: chicken.compiler.c-backend#length+ 
o|hiding unexported module binding: chicken.compiler.c-backend#find 
o|hiding unexported module binding: chicken.compiler.c-backend#find-tail 
o|hiding unexported module binding: chicken.compiler.c-backend#iota 
o|hiding unexported module binding: chicken.compiler.c-backend#make-list 
o|hiding unexported module binding: chicken.compiler.c-backend#posq 
o|hiding unexported module binding: chicken.compiler.c-backend#posv 
o|hiding unexported module binding: chicken.compiler.c-backend#output 
o|hiding unexported module binding: chicken.compiler.c-backend#gen 
o|hiding unexported module binding: chicken.compiler.c-backend#gen-list 
o|hiding unexported module binding: chicken.compiler.c-backend#backslashify 
o|hiding unexported module binding: chicken.compiler.c-backend#uncommentify 
o|hiding unexported module binding: chicken.compiler.c-backend#c-identifier 
o|hiding unexported module binding: chicken.compiler.c-backend#table->sorted-alist 
o|hiding unexported module binding: chicken.compiler.c-backend#emit-debug-table 
o|hiding unexported module binding: chicken.compiler.c-backend#emit-procedure-table 
o|hiding unexported module binding: chicken.compiler.c-backend#toplevel 
o|hiding unexported module binding: chicken.compiler.c-backend#cleanup 
o|hiding unexported module binding: chicken.compiler.c-backend#make-variable-list 
o|hiding unexported module binding: chicken.compiler.c-backend#make-argument-list 
o|hiding unexported module binding: chicken.compiler.c-backend#generate-external-variables 
o|hiding unexported module binding: chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes 
o|hiding unexported module binding: chicken.compiler.c-backend#generate-foreign-stubs 
o|hiding unexported module binding: chicken.compiler.c-backend#generate-foreign-callback-stubs 
o|hiding unexported module binding: chicken.compiler.c-backend#generate-foreign-callback-header 
o|hiding unexported module binding: chicken.compiler.c-backend#foreign-argument-conversion 
o|hiding unexported module binding: chicken.compiler.c-backend#foreign-result-conversion 
o|hiding unexported module binding: chicken.compiler.c-backend#encode-literal 
S|applied compiler syntax:
S|  chicken.format#sprintf		20
S|  scheme#for-each		22
S|  chicken.base#foldl		5
S|  scheme#map		8
S|  chicken.base#foldr		3
o|eliminated procedure checks: 160 
o|specializations:
o|  1 (scheme#number->string float)
o|  1 (scheme#string-length string)
o|  1 (scheme#number->string * *)
o|  1 (chicken.base#exact-integer? *)
o|  1 (scheme#cdddr (pair * (pair * pair)))
o|  3 (scheme#>= fixnum fixnum)
o|  1 (scheme#> fixnum fixnum)
o|  2 (scheme#memq * list)
o|  8 (scheme#= fixnum fixnum)
o|  1 (scheme#< integer integer)
o|  1 (chicken.base#sub1 fixnum)
o|  2 (scheme#char=? char char)
o|  1 (scheme#char>? char char)
o|  1 (scheme#char<? char char)
o|  4 (scheme#length list)
o|  1 (scheme#modulo fixnum fixnum)
o|  1 (scheme#imag-part cplxnum)
o|  1 (scheme#real-part cplxnum)
o|  1 (scheme#denominator ratnum)
o|  1 (scheme#numerator ratnum)
o|  1 (scheme#vector-length vector)
o|  20 (##sys#check-output-port * * *)
o|  1 (scheme#- integer integer)
o|  1 (chicken.bitwise#bitwise-and fixnum fixnum)
o|  4 (scheme#zero? integer)
o|  3 (scheme#string-append string string)
o|  9 (scheme#number->string *)
o|  14 (scheme#zero? *)
o|  7 (chicken.base#add1 fixnum)
o|  13 (chicken.base#sub1 *)
o|  12 (chicken.base#add1 *)
o|  1 (scheme#negative? *)
o|  1 (chicken.base#infinite? *)
o|  1 (chicken.base#nan? *)
o|  286 (scheme#eqv? * (or eof null fixnum char boolean symbol keyword))
o|  5 (scheme#+ fixnum fixnum)
o|  1 (scheme#eqv? * *)
o|  16 (##sys#check-list (or pair list) *)
o|  36 (scheme#cdr pair)
o|  13 (scheme#car pair)
(o e)|safe calls: 1580 
o|safe globals: (chicken.compiler.c-backend#encode-literal chicken.compiler.c-backend#foreign-result-conversion chicken.compiler.c-backend#foreign-argument-conversion chicken.compiler.c-backend#foreign-type-declaration chicken.compiler.c-backend#generate-foreign-callback-header chicken.compiler.c-backend#generate-foreign-callback-stubs chicken.compiler.c-backend#generate-foreign-stubs chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes chicken.compiler.c-backend#generate-external-variables chicken.compiler.c-backend#make-argument-list chicken.compiler.c-backend#make-variable-list chicken.compiler.c-backend#cleanup chicken.compiler.c-backend#toplevel chicken.compiler.c-backend#emit-procedure-table chicken.compiler.c-backend#emit-debug-table chicken.compiler.c-backend#generate-code chicken.compiler.c-backend#table->sorted-alist chicken.compiler.c-backend#c-identifier chicken.compiler.c-backend#uncommentify chicken.compiler.c-backend#backslashify chicken.compiler.c-backend#gen-list chicken.compiler.c-backend#gen chicken.compiler.c-backend#output chicken.compiler.c-backend#posv chicken.compiler.c-backend#posq chicken.compiler.c-backend#make-list chicken.compiler.c-backend#iota chicken.compiler.c-backend#find-tail chicken.compiler.c-backend#find chicken.compiler.c-backend#length+ chicken.compiler.c-backend#lset=/eq? chicken.compiler.c-backend#lset<=/eq? chicken.compiler.c-backend#list-tabulate chicken.compiler.c-backend#lset-intersection/eq? chicken.compiler.c-backend#lset-union/eq? chicken.compiler.c-backend#lset-difference/eq? chicken.compiler.c-backend#lset-adjoin/eq? chicken.compiler.c-backend#list-index chicken.compiler.c-backend#last chicken.compiler.c-backend#unzip1 chicken.compiler.c-backend#remove chicken.compiler.c-backend#filter-map chicken.compiler.c-backend#filter chicken.compiler.c-backend#alist-cons chicken.compiler.c-backend#delete-duplicates chicken.compiler.c-backend#fifth chicken.compiler.c-backend#fourth chicken.compiler.c-backend#third chicken.compiler.c-backend#second chicken.compiler.c-backend#first chicken.compiler.c-backend#delete chicken.compiler.c-backend#concatenate chicken.compiler.c-backend#cons* chicken.compiler.c-backend#any chicken.compiler.c-backend#every chicken.compiler.c-backend#append-map chicken.compiler.c-backend#split-at chicken.compiler.c-backend#drop chicken.compiler.c-backend#take chicken.compiler.c-backend#span chicken.compiler.c-backend#partition) 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#partition 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#span 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#drop 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#split-at 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#append-map 
o|inlining procedure: k3650 
o|inlining procedure: k3650 
o|inlining procedure: k3681 
o|inlining procedure: k3681 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#concatenate 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#delete-duplicates 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#alist-cons 
o|inlining procedure: k3898 
o|inlining procedure: k3898 
o|inlining procedure: k3890 
o|inlining procedure: k3890 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#filter-map 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#remove 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#unzip1 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#last 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#list-index 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#lset-adjoin/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#lset-difference/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#lset-union/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#lset-intersection/eq? 
o|inlining procedure: k4289 
o|inlining procedure: k4289 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#lset<=/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#lset=/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#length+ 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#find 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#find-tail 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#posq 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#posv 
o|inlining procedure: k4571 
o|contracted procedure: "(c-backend.scm:61) g643650" 
o|inlining procedure: k4553 
o|inlining procedure: k4553 
o|inlining procedure: k4571 
o|inlining procedure: k4608 
o|contracted procedure: "(c-backend.scm:69) g663670" 
o|inlining procedure: k4608 
o|inlining procedure: k4715 
o|inlining procedure: k4715 
o|inlining procedure: k4736 
o|inlining procedure: k4755 
o|inlining procedure: k4755 
o|inlining procedure: "(c-backend.scm:116) chicken.compiler.c-backend#second" 
o|inlining procedure: k4761 
o|inlining procedure: "(c-backend.scm:117) chicken.compiler.c-backend#second" 
o|inlining procedure: k4761 
o|inlining procedure: k4787 
o|inlining procedure: "(c-backend.scm:119) chicken.compiler.c-backend#second" 
o|inlining procedure: k4787 
o|inlining procedure: k4809 
o|inlining procedure: k4809 
o|substituted constant variable: a4822 
o|substituted constant variable: a4824 
o|substituted constant variable: a4826 
o|substituted constant variable: a4828 
o|substituted constant variable: a4830 
o|substituted constant variable: a4832 
o|inlining procedure: "(c-backend.scm:115) chicken.compiler.c-backend#first" 
o|inlining procedure: k4736 
o|inlining procedure: k4842 
o|inlining procedure: k4842 
o|inlining procedure: "(c-backend.scm:128) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:125) chicken.compiler.c-backend#first" 
o|inlining procedure: k4862 
o|inlining procedure: k4881 
o|inlining procedure: k4881 
o|inlining procedure: "(c-backend.scm:131) chicken.compiler.c-backend#first" 
o|inlining procedure: k4862 
o|inlining procedure: k4937 
o|inlining procedure: "(c-backend.scm:149) chicken.compiler.c-backend#first" 
o|inlining procedure: k4937 
o|inlining procedure: k4966 
o|inlining procedure: k4966 
o|inlining procedure: "(c-backend.scm:152) chicken.compiler.c-backend#first" 
o|inlining procedure: k5001 
o|inlining procedure: "(c-backend.scm:165) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:163) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:161) chicken.compiler.c-backend#first" 
o|inlining procedure: k5001 
o|inlining procedure: "(c-backend.scm:168) chicken.compiler.c-backend#first" 
o|inlining procedure: k5043 
o|inlining procedure: "(c-backend.scm:172) chicken.compiler.c-backend#first" 
o|inlining procedure: k5043 
o|inlining procedure: "(c-backend.scm:177) chicken.compiler.c-backend#first" 
o|inlining procedure: k5081 
o|inlining procedure: "(c-backend.scm:183) chicken.compiler.c-backend#first" 
o|inlining procedure: k5081 
o|inlining procedure: k5123 
o|inlining procedure: k5123 
o|inlining procedure: k5142 
o|inlining procedure: k5142 
o|inlining procedure: "(c-backend.scm:187) chicken.compiler.c-backend#second" 
o|inlining procedure: k5148 
o|inlining procedure: k5182 
o|inlining procedure: k5182 
o|inlining procedure: "(c-backend.scm:196) chicken.compiler.c-backend#second" 
o|inlining procedure: k5148 
o|inlining procedure: k5203 
o|inlining procedure: k5203 
o|inlining procedure: k5222 
o|inlining procedure: k5222 
o|inlining procedure: "(c-backend.scm:205) chicken.compiler.c-backend#second" 
o|inlining procedure: k5228 
o|inlining procedure: k5228 
o|inlining procedure: "(c-backend.scm:220) chicken.compiler.c-backend#first" 
o|inlining procedure: k5280 
o|inlining procedure: "(c-backend.scm:227) chicken.compiler.c-backend#first" 
o|inlining procedure: k5280 
o|inlining procedure: k5346 
o|inlining procedure: k5346 
o|inlining procedure: k5418 
o|inlining procedure: k5418 
o|inlining procedure: "(c-backend.scm:246) chicken.compiler.c-backend#first" 
o|inlining procedure: k5452 
o|inlining procedure: k5452 
o|inlining procedure: "(c-backend.scm:261) chicken.compiler.c-backend#first" 
o|inlining procedure: k5484 
o|inlining procedure: "(c-backend.scm:264) chicken.compiler.c-backend#first" 
o|inlining procedure: k5484 
o|inlining procedure: k5519 
o|inlining procedure: "(c-backend.scm:276) chicken.compiler.c-backend#fourth" 
o|inlining procedure: k5519 
o|inlining procedure: "(c-backend.scm:270) chicken.compiler.c-backend#third" 
o|inlining procedure: "(c-backend.scm:269) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:268) chicken.compiler.c-backend#first" 
o|inlining procedure: k5552 
o|inlining procedure: "(c-backend.scm:283) chicken.compiler.c-backend#third" 
o|inlining procedure: "(c-backend.scm:282) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:281) chicken.compiler.c-backend#first" 
o|inlining procedure: k5552 
o|inlining procedure: k5612 
o|inlining procedure: k5612 
o|inlining procedure: "(c-backend.scm:294) chicken.compiler.c-backend#third" 
o|inlining procedure: "(c-backend.scm:293) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:292) chicken.compiler.c-backend#first" 
o|inlining procedure: k5657 
o|inlining procedure: k5657 
o|inlining procedure: k5707 
o|inlining procedure: "(c-backend.scm:333) chicken.compiler.c-backend#first" 
o|inlining procedure: k5707 
o|inlining procedure: k5732 
o|inlining procedure: k5787 
o|contracted procedure: "(c-backend.scm:345) g920943" 
o|inlining procedure: k5787 
o|inlining procedure: k5824 
o|inlining procedure: k5824 
o|inlining procedure: k5732 
o|inlining procedure: k5894 
o|inlining procedure: k5894 
o|inlining procedure: k5904 
o|substituted constant variable: a5913 
o|inlining procedure: k5904 
o|inlining procedure: k5938 
o|inlining procedure: k5994 
o|inlining procedure: "(c-backend.scm:387) chicken.compiler.c-backend#fourth" 
o|inlining procedure: k5994 
o|inlining procedure: "(c-backend.scm:373) chicken.compiler.c-backend#third" 
o|inlining procedure: "(c-backend.scm:372) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:371) chicken.compiler.c-backend#first" 
o|inlining procedure: k5938 
o|propagated global variable: tmp992994 chicken.compiler.support#unsafe 
o|propagated global variable: tmp992994 chicken.compiler.support#unsafe 
o|propagated global variable: tmp995997 chicken.compiler.core#no-procedure-checks 
o|inlining procedure: k6084 
o|propagated global variable: tmp995997 chicken.compiler.core#no-procedure-checks 
o|inlining procedure: k6084 
o|substituted constant variable: a6091 
o|inlining procedure: k6100 
o|inlining procedure: k6100 
o|inlining procedure: k6126 
o|inlining procedure: k6136 
o|inlining procedure: k6136 
o|inlining procedure: k6126 
o|inlining procedure: k6164 
o|inlining procedure: "(c-backend.scm:318) chicken.compiler.c-backend#fourth" 
o|inlining procedure: k6164 
o|inlining procedure: "(c-backend.scm:316) chicken.compiler.c-backend#third" 
o|inlining procedure: "(c-backend.scm:314) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:313) chicken.compiler.c-backend#first" 
o|inlining procedure: k6184 
o|inlining procedure: k6250 
o|contracted procedure: "(c-backend.scm:425) g10371060" 
o|inlining procedure: k6250 
o|inlining procedure: k6287 
o|inlining procedure: k6287 
o|inlining procedure: "(c-backend.scm:414) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:413) chicken.compiler.c-backend#first" 
o|inlining procedure: k6184 
o|inlining procedure: k6411 
o|inlining procedure: k6411 
o|inlining procedure: k6423 
o|inlining procedure: k6423 
o|inlining procedure: k6441 
o|inlining procedure: k6451 
o|inlining procedure: k6451 
o|inlining procedure: k6441 
o|inlining procedure: "(c-backend.scm:443) chicken.compiler.c-backend#fourth" 
o|inlining procedure: "(c-backend.scm:441) chicken.compiler.c-backend#third" 
o|inlining procedure: "(c-backend.scm:439) chicken.compiler.c-backend#first" 
o|inlining procedure: k6474 
o|inlining procedure: "(c-backend.scm:468) chicken.compiler.c-backend#first" 
o|inlining procedure: k6474 
o|substituted constant variable: a6497 
o|inlining procedure: "(c-backend.scm:477) chicken.compiler.c-backend#first" 
o|inlining procedure: k6515 
o|inlining procedure: "(c-backend.scm:481) chicken.compiler.c-backend#first" 
o|inlining procedure: k6515 
o|inlining procedure: "(c-backend.scm:485) chicken.compiler.c-backend#first" 
o|inlining procedure: k6553 
o|inlining procedure: k6567 
o|inlining procedure: k6567 
o|inlining procedure: "(c-backend.scm:490) chicken.compiler.c-backend#first" 
o|inlining procedure: k6553 
o|inlining procedure: k6579 
o|inlining procedure: k6579 
o|inlining procedure: "(c-backend.scm:494) chicken.compiler.c-backend#first" 
o|inlining procedure: k6602 
o|inlining procedure: "(c-backend.scm:502) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:502) chicken.compiler.c-backend#second" 
o|inlining procedure: k6602 
o|inlining procedure: "(c-backend.scm:507) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:506) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:505) chicken.compiler.c-backend#second" 
o|inlining procedure: k6657 
o|inlining procedure: "(c-backend.scm:513) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:511) chicken.compiler.c-backend#first" 
o|inlining procedure: k6657 
o|inlining procedure: "(c-backend.scm:521) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:519) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:517) chicken.compiler.c-backend#first" 
o|inlining procedure: k6727 
o|inlining procedure: k6756 
o|inlining procedure: k6756 
o|inlining procedure: "(c-backend.scm:528) chicken.compiler.c-backend#first" 
o|inlining procedure: "(c-backend.scm:526) chicken.compiler.c-backend#first" 
o|inlining procedure: k6727 
o|inlining procedure: "(c-backend.scm:545) chicken.compiler.c-backend#third" 
o|inlining procedure: "(c-backend.scm:543) chicken.compiler.c-backend#second" 
o|inlining procedure: "(c-backend.scm:541) chicken.compiler.c-backend#first" 
o|substituted constant variable: a6853 
o|substituted constant variable: a6855 
o|substituted constant variable: a6857 
o|substituted constant variable: a6859 
o|substituted constant variable: a6861 
o|substituted constant variable: a6863 
o|substituted constant variable: a6865 
o|substituted constant variable: a6867 
o|substituted constant variable: a6869 
o|substituted constant variable: a6871 
o|substituted constant variable: a6873 
o|substituted constant variable: a6875 
o|substituted constant variable: a6877 
o|substituted constant variable: a6879 
o|substituted constant variable: a6881 
o|substituted constant variable: a6883 
o|substituted constant variable: a6885 
o|substituted constant variable: a6887 
o|substituted constant variable: a6889 
o|substituted constant variable: a6891 
o|substituted constant variable: a6893 
o|substituted constant variable: a6895 
o|substituted constant variable: a6897 
o|substituted constant variable: a6899 
o|substituted constant variable: a6901 
o|substituted constant variable: a6903 
o|substituted constant variable: a6905 
o|substituted constant variable: a6907 
o|substituted constant variable: a6909 
o|substituted constant variable: a6911 
o|substituted constant variable: a6913 
o|substituted constant variable: a6915 
o|substituted constant variable: a6917 
o|substituted constant variable: a6919 
o|substituted constant variable: a6921 
o|substituted constant variable: a6923 
o|substituted constant variable: a6925 
o|substituted constant variable: a6927 
o|substituted constant variable: a6929 
o|substituted constant variable: a6931 
o|substituted constant variable: a6933 
o|substituted constant variable: a6935 
o|inlining procedure: k6945 
o|inlining procedure: k6945 
o|inlining procedure: k6981 
o|inlining procedure: k6981 
o|inlining procedure: k6999 
o|inlining procedure: k6999 
o|inlining procedure: k7051 
o|inlining procedure: k7051 
o|inlining procedure: k7089 
o|inlining procedure: k7089 
o|inlining procedure: k7119 
o|inlining procedure: k7119 
o|inlining procedure: k7135 
o|inlining procedure: k7135 
o|inlining procedure: k7171 
o|inlining procedure: k7171 
o|inlining procedure: k7194 
o|contracted procedure: "(c-backend.scm:623) g12421249" 
o|inlining procedure: k7194 
o|propagated global variable: g12481250 chicken.compiler.core#foreign-declarations 
o|inlining procedure: k7254 
o|contracted procedure: "(c-backend.scm:607) g12121221" 
o|inlining procedure: k7254 
o|inlining procedure: k7344 
o|inlining procedure: k7344 
o|inlining procedure: k7384 
o|inlining procedure: k7384 
o|substituted constant variable: a7398 
o|inlining procedure: k7402 
o|inlining procedure: k7402 
o|substituted constant variable: a7433 
o|inlining procedure: k7453 
o|contracted procedure: "(c-backend.scm:638) g12701278" 
o|inlining procedure: k7453 
o|inlining procedure: k7476 
o|inlining procedure: k7476 
o|propagated global variable: g12951299 chicken.compiler.core#used-units 
o|inlining procedure: k7665 
o|contracted procedure: "(c-backend.scm:666) g13391346" 
o|inlining procedure: k7558 
o|inlining procedure: k7558 
o|inlining procedure: k7582 
o|inlining procedure: k7582 
o|inlining procedure: k7611 
o|inlining procedure: k7611 
o|inlining procedure: k7624 
o|inlining procedure: k7624 
o|inlining procedure: k7648 
o|inlining procedure: k7648 
o|inlining procedure: k7665 
o|inlining procedure: k7733 
o|contracted procedure: "(c-backend.scm:726) restore1401" 
o|inlining procedure: k7699 
o|inlining procedure: k7699 
o|inlining procedure: k7733 
o|inlining procedure: k7786 
o|inlining procedure: k7786 
o|inlining procedure: k7815 
o|inlining procedure: k7815 
o|substituted constant variable: a7840 
o|substituted constant variable: a7841 
o|inlining procedure: k7863 
o|inlining procedure: k7863 
o|inlining procedure: k7875 
o|inlining procedure: k7875 
o|inlining procedure: k7887 
o|propagated global variable: r788814095 chicken.compiler.c-platform#words-per-flonum 
o|inlining procedure: k7887 
o|inlining procedure: k7899 
o|inlining procedure: k7899 
o|inlining procedure: k7926 
o|inlining procedure: k7958 
o|inlining procedure: k7958 
o|substituted constant variable: g14601463 
o|inlining procedure: k7982 
o|inlining procedure: k7982 
o|inlining procedure: k7926 
o|inlining procedure: k8020 
o|inlining procedure: "(c-backend.scm:755) bad-literal712" 
o|inlining procedure: k8020 
o|inlining procedure: k8032 
o|inlining procedure: k8032 
o|substituted constant variable: a8062 
o|inlining procedure: k8067 
o|inlining procedure: k8067 
o|inlining procedure: k8090 
o|inlining procedure: k8090 
o|inlining procedure: "(c-backend.scm:771) bad-literal712" 
o|inlining procedure: k8146 
o|inlining procedure: k8146 
o|inlining procedure: k8161 
o|inlining procedure: k8161 
o|inlining procedure: k8180 
o|inlining procedure: k8180 
o|inlining procedure: k8183 
o|inlining procedure: k8183 
o|inlining procedure: k8226 
o|inlining procedure: k8226 
o|inlining procedure: k8241 
o|inlining procedure: k8241 
o|inlining procedure: "(c-backend.scm:801) bad-literal712" 
o|substituted constant variable: a8307 
o|inlining procedure: k8314 
o|inlining procedure: k8314 
o|inlining procedure: k8506 
o|inlining procedure: k8506 
o|inlining procedure: k8516 
o|inlining procedure: k8535 
o|inlining procedure: k8535 
o|inlining procedure: k8516 
o|inlining procedure: k8592 
o|inlining procedure: k8592 
o|inlining procedure: k8647 
o|inlining procedure: k8647 
o|inlining procedure: k8673 
o|inlining procedure: k8673 
o|propagated global variable: tmp16571659 chicken.compiler.core#unit-name 
o|inlining procedure: k8689 
o|propagated global variable: tmp16571659 chicken.compiler.core#unit-name 
o|inlining procedure: k8689 
o|inlining procedure: k8695 
o|inlining procedure: k8695 
o|substituted constant variable: g16431646 
o|inlining procedure: k8725 
o|inlining procedure: k8752 
o|inlining procedure: k8752 
o|inlining procedure: k8725 
o|inlining procedure: k8792 
o|inlining procedure: k8792 
o|inlining procedure: k8804 
o|inlining procedure: k8804 
o|inlining procedure: k8822 
o|inlining procedure: k8822 
o|inlining procedure: k8846 
o|inlining procedure: k8846 
o|inlining procedure: k8878 
o|contracted procedure: "(c-backend.scm:881) g16211628" 
o|inlining procedure: k8878 
o|inlining procedure: k8905 
o|inlining procedure: k8905 
o|inlining procedure: k8920 
o|inlining procedure: k8920 
o|inlining procedure: k8933 
o|inlining procedure: k8933 
o|inlining procedure: k8966 
o|inlining procedure: k8966 
o|inlining procedure: k8992 
o|inlining procedure: k8992 
o|inlining procedure: k9005 
o|inlining procedure: k9005 
o|inlining procedure: k9032 
o|inlining procedure: k9032 
o|inlining procedure: k9039 
o|inlining procedure: k9039 
o|inlining procedure: k9046 
o|inlining procedure: k9046 
o|inlining procedure: k9066 
o|inlining procedure: k9066 
o|contracted procedure: "(c-backend.scm:988) trailer707" 
o|contracted procedure: "(c-backend.scm:987) chicken.compiler.c-backend#emit-procedure-table" 
o|inlining procedure: k9265 
o|inlining procedure: k9265 
o|inlining procedure: k9303 
o|inlining procedure: k9303 
o|contracted procedure: "(c-backend.scm:985) chicken.compiler.c-backend#emit-debug-table" 
o|inlining procedure: k9216 
o|contracted procedure: "(c-backend.scm:995) g17701777" 
o|inlining procedure: k9177 
o|contracted procedure: "(c-backend.scm:998) g17831790" 
o|inlining procedure: k9142 
o|inlining procedure: k9142 
o|inlining procedure: k9177 
o|inlining procedure: "(c-backend.scm:997) chicken.compiler.c-backend#second" 
o|inlining procedure: k9216 
o|contracted procedure: "(c-backend.scm:982) chicken.compiler.c-backend#generate-foreign-callback-stubs" 
o|inlining procedure: k9918 
o|inlining procedure: k9918 
o|inlining procedure: k9939 
o|inlining procedure: k9939 
o|inlining procedure: k9963 
o|inlining procedure: k9963 
o|inlining procedure: k9990 
o|inlining procedure: k9990 
o|inlining procedure: k10012 
o|inlining procedure: k10012 
o|substituted constant variable: a10038 
o|inlining procedure: k10042 
o|inlining procedure: k10042 
o|inlining procedure: k10054 
o|inlining procedure: k10054 
o|inlining procedure: k10066 
o|inlining procedure: k10066 
o|inlining procedure: k10078 
o|inlining procedure: k10078 
o|substituted constant variable: a10085 
o|substituted constant variable: a10087 
o|substituted constant variable: a10089 
o|substituted constant variable: a10091 
o|substituted constant variable: a10093 
o|substituted constant variable: a10095 
o|substituted constant variable: a10097 
o|substituted constant variable: a10099 
o|substituted constant variable: a10101 
o|inlining procedure: k10111 
o|inlining procedure: k10111 
o|inlining procedure: k10123 
o|inlining procedure: k10123 
o|substituted constant variable: a10130 
o|substituted constant variable: a10132 
o|substituted constant variable: a10134 
o|substituted constant variable: a10136 
o|substituted constant variable: a10138 
o|inlining procedure: k10142 
o|inlining procedure: k10142 
o|inlining procedure: k10154 
o|inlining procedure: k10154 
o|substituted constant variable: a10161 
o|substituted constant variable: a10163 
o|substituted constant variable: a10165 
o|substituted constant variable: a10167 
o|substituted constant variable: a10169 
o|inlining procedure: k10173 
o|inlining procedure: k10173 
o|substituted constant variable: a10186 
o|substituted constant variable: a10188 
o|substituted constant variable: a10190 
o|substituted constant variable: a10192 
o|inlining procedure: k10196 
o|inlining procedure: k10196 
o|inlining procedure: k10208 
o|inlining procedure: k10208 
o|inlining procedure: k10220 
o|inlining procedure: k10220 
o|substituted constant variable: a10227 
o|substituted constant variable: a10229 
o|substituted constant variable: a10231 
o|substituted constant variable: a10233 
o|substituted constant variable: a10235 
o|substituted constant variable: a10237 
o|substituted constant variable: a10239 
o|inlining procedure: k10243 
o|inlining procedure: k10243 
o|inlining procedure: k10255 
o|inlining procedure: k10255 
o|substituted constant variable: a10268 
o|substituted constant variable: a10270 
o|substituted constant variable: a10272 
o|substituted constant variable: a10274 
o|substituted constant variable: a10276 
o|substituted constant variable: a10278 
o|inlining procedure: k10282 
o|inlining procedure: k10282 
o|inlining procedure: k10294 
o|inlining procedure: k10294 
o|inlining procedure: k10306 
o|inlining procedure: k10306 
o|inlining procedure: k10318 
o|inlining procedure: k10318 
o|inlining procedure: k10330 
o|inlining procedure: k10330 
o|inlining procedure: k10342 
o|inlining procedure: k10342 
o|substituted constant variable: a10349 
o|substituted constant variable: a10351 
o|substituted constant variable: a10353 
o|substituted constant variable: a10355 
o|substituted constant variable: a10357 
o|substituted constant variable: a10359 
o|substituted constant variable: a10361 
o|substituted constant variable: a10363 
o|substituted constant variable: a10365 
o|substituted constant variable: a10367 
o|substituted constant variable: a10369 
o|substituted constant variable: a10371 
o|substituted constant variable: a10373 
o|inlining procedure: k10416 
o|inlining procedure: k10416 
o|inlining procedure: k10441 
o|contracted procedure: "(c-backend.scm:1216) g22092217" 
o|inlining procedure: k10441 
o|inlining procedure: k10476 
o|inlining procedure: k10476 
o|inlining procedure: k10492 
o|inlining procedure: k10492 
o|propagated global variable: stubs2027 chicken.compiler.support#foreign-callback-stubs 
o|inlining procedure: k10526 
o|inlining procedure: k10526 
o|contracted procedure: "(c-backend.scm:980) chicken.compiler.c-backend#generate-foreign-stubs" 
o|inlining procedure: k9664 
o|inlining procedure: k9682 
o|inlining procedure: k9682 
o|inlining procedure: k9664 
o|inlining procedure: k9712 
o|inlining procedure: k9712 
o|inlining procedure: k9754 
o|contracted procedure: "(c-backend.scm:1129) g19511971" 
o|inlining procedure: k9628 
o|substituted constant variable: a9638 
o|substituted constant variable: a9639 
o|inlining procedure: k9628 
o|inlining procedure: k9754 
o|inlining procedure: k9793 
o|inlining procedure: k9793 
o|contracted procedure: "(c-backend.scm:1137) chicken.compiler.c-backend#iota" 
o|inlining procedure: k9811 
o|inlining procedure: k9811 
o|contracted procedure: "(c-backend.scm:1107) chicken.compiler.c-backend#make-list" 
o|propagated global variable: stubs1916 chicken.compiler.core#foreign-lambda-stubs 
o|inlining procedure: k9872 
o|inlining procedure: k9872 
o|contracted procedure: "(c-backend.scm:979) chicken.compiler.c-backend#generate-external-variables" 
o|inlining procedure: k9491 
o|contracted procedure: "(c-backend.scm:1078) g18741881" 
o|inlining procedure: k9491 
o|propagated global variable: a9127 chicken.flonum#flonum-maximum-decimal-exponent 
o|substituted constant variable: a9128 
o|contracted procedure: "(c-backend.scm:94) chicken.compiler.c-backend#table->sorted-alist" 
o|inlining procedure: k9331 
o|inlining procedure: k9331 
o|contracted procedure: "(c-backend.scm:1039) chicken.compiler.c-backend#c-identifier" 
o|inlining procedure: k9356 
o|inlining procedure: k9356 
o|substituted constant variable: a9377 
o|inlining procedure: k9391 
o|inlining procedure: k9391 
o|substituted constant variable: a9398 
o|inlining procedure: k9399 
o|inlining procedure: k9399 
o|substituted constant variable: a9406 
o|inlining procedure: k9407 
o|substituted constant variable: a9413 
o|inlining procedure: k9407 
o|inlining procedure: k9534 
o|contracted procedure: "(c-backend.scm:1090) g18981905" 
o|inlining procedure: k9534 
o|inlining procedure: k10579 
o|inlining procedure: k10579 
o|inlining procedure: k10635 
o|inlining procedure: k10635 
o|inlining procedure: k10656 
o|inlining procedure: k10656 
o|inlining procedure: k10680 
o|inlining procedure: k10680 
o|inlining procedure: k10704 
o|inlining procedure: k10704 
o|inlining procedure: k10722 
o|inlining procedure: k10722 
o|inlining procedure: k10743 
o|inlining procedure: k10743 
o|inlining procedure: k10761 
o|inlining procedure: k10761 
o|inlining procedure: k10779 
o|inlining procedure: k10779 
o|inlining procedure: k10797 
o|inlining procedure: k10797 
o|inlining procedure: k10821 
o|inlining procedure: k10821 
o|inlining procedure: k10842 
o|inlining procedure: k10842 
o|inlining procedure: k10866 
o|inlining procedure: k10866 
o|inlining procedure: k10890 
o|inlining procedure: k10890 
o|inlining procedure: k10914 
o|inlining procedure: k10914 
o|inlining procedure: k10938 
o|inlining procedure: k10938 
o|inlining procedure: k10962 
o|inlining procedure: k10962 
o|inlining procedure: k10986 
o|inlining procedure: k10986 
o|inlining procedure: k11013 
o|inlining procedure: k11013 
o|inlining procedure: k11029 
o|inlining procedure: k11029 
o|inlining procedure: k11063 
o|inlining procedure: k11105 
o|contracted procedure: "(c-backend.scm:1309) g23962405" 
o|propagated global variable: g24132414 chicken.compiler.c-backend#foreign-type-declaration 
o|inlining procedure: k11105 
o|inlining procedure: k11063 
o|inlining procedure: k11157 
o|inlining procedure: k11157 
o|inlining procedure: k11191 
o|inlining procedure: k11191 
o|inlining procedure: k11225 
o|inlining procedure: k11225 
o|inlining procedure: k11295 
o|contracted procedure: "(c-backend.scm:1333) g24442453" 
o|inlining procedure: k11277 
o|inlining procedure: k11277 
o|inlining procedure: k11295 
o|substituted constant variable: a11346 
o|substituted constant variable: a11358 
o|substituted constant variable: a11366 
o|substituted constant variable: a11368 
o|substituted constant variable: a11380 
o|substituted constant variable: a11392 
o|substituted constant variable: a11404 
o|substituted constant variable: a11416 
o|substituted constant variable: a11428 
o|substituted constant variable: a11439 
o|substituted constant variable: a11448 
o|substituted constant variable: a11449 
o|substituted constant variable: a11461 
o|inlining procedure: k11465 
o|inlining procedure: k11465 
o|substituted constant variable: a11478 
o|substituted constant variable: a11480 
o|substituted constant variable: a11482 
o|substituted constant variable: a11484 
o|inlining procedure: k11488 
o|inlining procedure: k11488 
o|inlining procedure: k11500 
o|inlining procedure: k11500 
o|substituted constant variable: a11507 
o|substituted constant variable: a11509 
o|substituted constant variable: a11511 
o|substituted constant variable: a11513 
o|substituted constant variable: a11515 
o|substituted constant variable: a11520 
o|substituted constant variable: a11522 
o|substituted constant variable: a11527 
o|substituted constant variable: a11529 
o|substituted constant variable: a11534 
o|substituted constant variable: a11536 
o|substituted constant variable: a11541 
o|substituted constant variable: a11543 
o|substituted constant variable: a11548 
o|substituted constant variable: a11550 
o|substituted constant variable: a11555 
o|substituted constant variable: a11557 
o|substituted constant variable: a11562 
o|substituted constant variable: a11564 
o|substituted constant variable: a11569 
o|substituted constant variable: a11571 
o|substituted constant variable: a11576 
o|substituted constant variable: a11578 
o|substituted constant variable: a11583 
o|substituted constant variable: a11585 
o|inlining procedure: k11589 
o|inlining procedure: k11589 
o|substituted constant variable: a11602 
o|substituted constant variable: a11604 
o|substituted constant variable: a11606 
o|substituted constant variable: a11608 
o|substituted constant variable: a11613 
o|substituted constant variable: a11615 
o|inlining procedure: k11619 
o|inlining procedure: k11619 
o|substituted constant variable: a11632 
o|substituted constant variable: a11634 
o|substituted constant variable: a11636 
o|substituted constant variable: a11638 
o|substituted constant variable: a11643 
o|substituted constant variable: a11645 
o|substituted constant variable: a11647 
o|substituted constant variable: a11649 
o|substituted constant variable: a11651 
o|substituted constant variable: a11653 
o|substituted constant variable: a11655 
o|substituted constant variable: a11657 
o|substituted constant variable: a11659 
o|substituted constant variable: a11664 
o|substituted constant variable: a11666 
o|substituted constant variable: a11668 
o|substituted constant variable: a11670 
o|inlining procedure: k11674 
o|inlining procedure: k11674 
o|substituted constant variable: a11681 
o|substituted constant variable: a11683 
o|substituted constant variable: a11685 
o|substituted constant variable: a11690 
o|substituted constant variable: a11692 
o|substituted constant variable: a11697 
o|substituted constant variable: a11699 
o|substituted constant variable: a11704 
o|substituted constant variable: a11706 
o|substituted constant variable: a11711 
o|substituted constant variable: a11713 
o|substituted constant variable: a11715 
o|inlining procedure: k11724 
o|inlining procedure: k11724 
o|inlining procedure: k11739 
o|inlining procedure: k11739 
o|inlining procedure: k11754 
o|inlining procedure: k11754 
o|inlining procedure: k11766 
o|inlining procedure: k11766 
o|inlining procedure: k11784 
o|inlining procedure: k11784 
o|inlining procedure: k11796 
o|inlining procedure: k11796 
o|inlining procedure: k11808 
o|inlining procedure: k11808 
o|inlining procedure: k11823 
o|inlining procedure: k11823 
o|inlining procedure: k11835 
o|inlining procedure: k11835 
o|inlining procedure: k11847 
o|inlining procedure: k11847 
o|inlining procedure: k11859 
o|inlining procedure: k11859 
o|inlining procedure: k11871 
o|inlining procedure: k11871 
o|inlining procedure: k11883 
o|inlining procedure: k11883 
o|inlining procedure: k11895 
o|inlining procedure: k11895 
o|inlining procedure: k11907 
o|inlining procedure: k11907 
o|inlining procedure: k11919 
o|inlining procedure: k11919 
o|inlining procedure: k11931 
o|inlining procedure: k11931 
o|inlining procedure: k11943 
o|inlining procedure: k11943 
o|inlining procedure: k11955 
o|inlining procedure: k11955 
o|inlining procedure: k11967 
o|inlining procedure: k11967 
o|inlining procedure: k11979 
o|inlining procedure: k11979 
o|inlining procedure: k11991 
o|inlining procedure: k11991 
o|inlining procedure: k12009 
o|inlining procedure: k12009 
o|contracted procedure: "(c-backend.scm:1397) g25302531" 
o|inlining procedure: k12033 
o|inlining procedure: k12048 
o|inlining procedure: k12048 
o|inlining procedure: k12060 
o|inlining procedure: k12060 
o|inlining procedure: k12072 
o|inlining procedure: k12072 
o|inlining procedure: k12084 
o|inlining procedure: k12084 
o|inlining procedure: k12103 
o|inlining procedure: k12103 
o|substituted constant variable: a12137 
o|substituted constant variable: a12139 
o|substituted constant variable: a12141 
o|substituted constant variable: a12143 
o|substituted constant variable: a12145 
o|substituted constant variable: a12147 
o|substituted constant variable: a12149 
o|substituted constant variable: a12151 
o|substituted constant variable: a12153 
o|substituted constant variable: a12155 
o|substituted constant variable: a12157 
o|inlining procedure: k12033 
o|substituted constant variable: a12169 
o|substituted constant variable: a12177 
o|inlining procedure: k12181 
o|inlining procedure: k12181 
o|inlining procedure: k12193 
o|inlining procedure: k12193 
o|substituted constant variable: a12200 
o|substituted constant variable: a12202 
o|substituted constant variable: a12204 
o|substituted constant variable: a12206 
o|substituted constant variable: a12208 
o|inlining procedure: k12212 
o|inlining procedure: k12212 
o|substituted constant variable: a12225 
o|substituted constant variable: a12227 
o|substituted constant variable: a12229 
o|substituted constant variable: a12231 
o|substituted constant variable: a12233 
o|substituted constant variable: a12235 
o|substituted constant variable: a12237 
o|substituted constant variable: a12239 
o|substituted constant variable: a12241 
o|substituted constant variable: a12243 
o|substituted constant variable: a12245 
o|substituted constant variable: a12247 
o|substituted constant variable: a12249 
o|substituted constant variable: a12251 
o|substituted constant variable: a12253 
o|substituted constant variable: a12255 
o|substituted constant variable: a12257 
o|substituted constant variable: a12259 
o|substituted constant variable: a12261 
o|substituted constant variable: a12263 
o|substituted constant variable: a12265 
o|substituted constant variable: a12267 
o|substituted constant variable: a12269 
o|substituted constant variable: a12271 
o|substituted constant variable: a12273 
o|substituted constant variable: a12275 
o|substituted constant variable: a12277 
o|substituted constant variable: a12279 
o|substituted constant variable: a12281 
o|substituted constant variable: a12283 
o|substituted constant variable: a12285 
o|substituted constant variable: a12287 
o|substituted constant variable: a12292 
o|substituted constant variable: a12294 
o|substituted constant variable: a12296 
o|substituted constant variable: a12298 
o|substituted constant variable: a12300 
o|substituted constant variable: a12302 
o|substituted constant variable: a12304 
o|substituted constant variable: a12309 
o|substituted constant variable: a12311 
o|inlining procedure: k12315 
o|inlining procedure: k12315 
o|substituted constant variable: a12322 
o|substituted constant variable: a12324 
o|substituted constant variable: a12326 
o|substituted constant variable: a12328 
o|substituted constant variable: a12330 
o|substituted constant variable: a12332 
o|inlining procedure: k12336 
o|inlining procedure: k12336 
o|inlining procedure: k12348 
o|inlining procedure: k12348 
o|substituted constant variable: a12361 
o|substituted constant variable: a12363 
o|substituted constant variable: a12365 
o|substituted constant variable: a12367 
o|substituted constant variable: a12369 
o|substituted constant variable: a12371 
o|substituted constant variable: a12376 
o|substituted constant variable: a12378 
o|substituted constant variable: a12380 
o|inlining procedure: k12389 
o|inlining procedure: k12389 
o|inlining procedure: k12407 
o|inlining procedure: k12407 
o|inlining procedure: k12422 
o|inlining procedure: k12422 
o|inlining procedure: k12434 
o|inlining procedure: k12434 
o|substituted constant variable: a12453 
o|substituted constant variable: a12454 
o|substituted constant variable: a12477 
o|substituted constant variable: a12478 
o|inlining procedure: k12467 
o|inlining procedure: k12467 
o|substituted constant variable: a12504 
o|substituted constant variable: a12505 
o|substituted constant variable: a12528 
o|substituted constant variable: a12529 
o|inlining procedure: k12518 
o|inlining procedure: k12518 
o|substituted constant variable: a12555 
o|substituted constant variable: a12556 
o|substituted constant variable: a12582 
o|substituted constant variable: a12583 
o|inlining procedure: k12569 
o|inlining procedure: k12569 
o|substituted constant variable: a12609 
o|substituted constant variable: a12610 
o|substituted constant variable: a12636 
o|substituted constant variable: a12637 
o|inlining procedure: k12623 
o|inlining procedure: k12623 
o|substituted constant variable: a12660 
o|substituted constant variable: a12661 
o|substituted constant variable: a12684 
o|substituted constant variable: a12685 
o|inlining procedure: k12674 
o|inlining procedure: k12674 
o|inlining procedure: k12704 
o|inlining procedure: k12704 
o|inlining procedure: k12731 
o|substituted constant variable: a12753 
o|substituted constant variable: a12754 
o|substituted constant variable: a12777 
o|substituted constant variable: a12778 
o|inlining procedure: k12767 
o|inlining procedure: k12767 
o|substituted constant variable: a12801 
o|substituted constant variable: a12802 
o|substituted constant variable: a12825 
o|substituted constant variable: a12826 
o|inlining procedure: k12815 
o|inlining procedure: k12815 
o|substituted constant variable: a12849 
o|substituted constant variable: a12850 
o|inlining procedure: k12863 
o|inlining procedure: k12863 
o|substituted constant variable: a12889 
o|substituted constant variable: a12890 
o|substituted constant variable: a12913 
o|substituted constant variable: a12914 
o|inlining procedure: k12903 
o|inlining procedure: k12903 
o|substituted constant variable: a12937 
o|substituted constant variable: a12938 
o|substituted constant variable: a12955 
o|substituted constant variable: a12957 
o|substituted constant variable: a12962 
o|substituted constant variable: a12964 
o|substituted constant variable: a12966 
o|substituted constant variable: a12968 
o|substituted constant variable: a12970 
o|substituted constant variable: a12972 
o|substituted constant variable: a12974 
o|substituted constant variable: a12979 
o|substituted constant variable: a12981 
o|inlining procedure: k12731 
o|substituted constant variable: a12993 
o|substituted constant variable: a13004 
o|substituted constant variable: a13006 
o|substituted constant variable: a13008 
o|substituted constant variable: a13010 
o|substituted constant variable: a13012 
o|substituted constant variable: a13017 
o|substituted constant variable: a13019 
o|substituted constant variable: a13024 
o|substituted constant variable: a13026 
o|substituted constant variable: a13031 
o|substituted constant variable: a13033 
o|substituted constant variable: a13038 
o|substituted constant variable: a13040 
o|substituted constant variable: a13042 
o|inlining procedure: k13046 
o|inlining procedure: k13046 
o|inlining procedure: k13058 
o|inlining procedure: k13058 
o|inlining procedure: k13070 
o|inlining procedure: k13070 
o|inlining procedure: k13082 
o|inlining procedure: k13082 
o|inlining procedure: k13094 
o|inlining procedure: k13094 
o|substituted constant variable: a13107 
o|substituted constant variable: a13109 
o|substituted constant variable: a13111 
o|substituted constant variable: a13113 
o|substituted constant variable: a13115 
o|substituted constant variable: a13117 
o|substituted constant variable: a13119 
o|substituted constant variable: a13121 
o|substituted constant variable: a13123 
o|substituted constant variable: a13125 
o|substituted constant variable: a13127 
o|substituted constant variable: a13129 
o|substituted constant variable: a13131 
o|substituted constant variable: a13136 
o|substituted constant variable: a13138 
o|substituted constant variable: a13140 
o|substituted constant variable: a13142 
o|substituted constant variable: a13144 
o|substituted constant variable: a13146 
o|substituted constant variable: a13151 
o|substituted constant variable: a13153 
o|substituted constant variable: a13158 
o|substituted constant variable: a13160 
o|substituted constant variable: a13165 
o|substituted constant variable: a13167 
o|inlining procedure: k13180 
o|inlining procedure: k13180 
o|contracted procedure: "(c-backend.scm:1503) finish2854" 
o|inlining procedure: k13248 
o|inlining procedure: k13248 
o|inlining procedure: k13271 
o|inlining procedure: k13271 
o|inlining procedure: k13283 
o|inlining procedure: k13283 
o|substituted constant variable: a13298 
o|inlining procedure: k13347 
o|substituted constant variable: a13367 
o|inlining procedure: k13347 
o|inlining procedure: k13382 
o|inlining procedure: k13402 
o|inlining procedure: k13402 
o|inlining procedure: k13382 
o|inlining procedure: k13421 
o|inlining procedure: "(c-backend.scm:1542) getsize2852" 
o|inlining procedure: "(c-backend.scm:1541) getbits2851" 
o|inlining procedure: k13421 
o|contracted procedure: "(c-backend.scm:1547) chicken.compiler.c-backend#cons*" 
o|inlining procedure: k3711 
o|inlining procedure: k3711 
o|inlining procedure: "(c-backend.scm:1548) getbits2851" 
o|inlining procedure: "(c-backend.scm:1545) getsize2852" 
o|replaced variables: 3242 
o|removed binding forms: 635 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#every 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#any 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#first 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#second 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#third 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#fourth 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#filter 
o|substituted constant variable: r429013516 
o|substituted constant variable: r475613527 
o|substituted constant variable: r475613527 
o|substituted constant variable: r475613529 
o|substituted constant variable: r475613529 
o|inlining procedure: k4885 
o|inlining procedure: k5775 
o|substituted constant variable: r590513787 
o|substituted constant variable: r590513787 
o|propagated global variable: r608513813 chicken.compiler.core#no-procedure-checks 
o|substituted constant variable: r610113816 
o|substituted constant variable: r613713818 
o|substituted constant variable: r613713818 
o|substituted constant variable: r613713820 
o|substituted constant variable: r613713820 
o|substituted constant variable: r616513829 
o|substituted constant variable: r645213866 
o|substituted constant variable: r645213866 
o|substituted constant variable: r645213868 
o|substituted constant variable: r645213868 
o|substituted constant variable: r656813911 
o|substituted constant variable: r656813911 
o|substituted constant variable: r656813913 
o|substituted constant variable: r656813913 
o|substituted constant variable: r698214021 
o|substituted constant variable: r762514074 
o|substituted constant variable: r762514074 
o|substituted constant variable: r762514076 
o|substituted constant variable: r762514076 
o|contracted procedure: "(c-backend.scm:714) g13941409" 
o|removed side-effect free assignment to unused variable: bad-literal712 
o|substituted constant variable: r786414091 
o|substituted constant variable: r787614093 
o|substituted constant variable: r790014097 
o|substituted constant variable: r818114127 
o|substituted constant variable: r818114127 
o|substituted constant variable: r818114129 
o|substituted constant variable: r818114129 
o|propagated global variable: r869014166 chicken.compiler.core#unit-name 
o|substituted constant variable: r875314174 
o|substituted constant variable: r879314176 
o|substituted constant variable: r879314176 
o|substituted constant variable: r879314178 
o|substituted constant variable: r879314178 
o|substituted constant variable: r882314183 
o|substituted constant variable: r884714185 
o|substituted constant variable: r892114192 
o|substituted constant variable: r892114192 
o|substituted constant variable: r900614208 
o|substituted constant variable: r900614208 
o|substituted constant variable: r900614210 
o|substituted constant variable: r900614210 
o|inlining procedure: k9011 
o|substituted constant variable: r904714220 
o|substituted constant variable: r904714220 
o|substituted constant variable: r904714222 
o|substituted constant variable: r904714222 
o|substituted constant variable: r1047714303 
o|substituted constant variable: r1047714303 
o|substituted constant variable: r1047714305 
o|substituted constant variable: r1047714305 
o|propagated global variable: stubs2027 chicken.compiler.support#foreign-callback-stubs 
o|substituted constant variable: r979414332 
o|propagated global variable: stubs1916 chicken.compiler.core#foreign-lambda-stubs 
o|substituted constant variable: r933214340 
o|inlining procedure: k9381 
o|inlining procedure: k9381 
o|substituted constant variable: r940814349 
o|substituted constant variable: r1082214372 
o|substituted constant variable: r1127814403 
o|substituted constant variable: r1172514418 
o|substituted constant variable: r1174014420 
o|substituted constant variable: r1175514422 
o|substituted constant variable: r1176714424 
o|substituted constant variable: r1178514426 
o|substituted constant variable: r1179714428 
o|substituted constant variable: r1180914430 
o|substituted constant variable: r1182414432 
o|substituted constant variable: r1183614434 
o|substituted constant variable: r1184814436 
o|substituted constant variable: r1186014438 
o|substituted constant variable: r1187214440 
o|substituted constant variable: r1188414442 
o|substituted constant variable: r1189614444 
o|substituted constant variable: r1190814446 
o|substituted constant variable: r1192014448 
o|substituted constant variable: r1193214450 
o|substituted constant variable: r1194414452 
o|substituted constant variable: r1195614454 
o|substituted constant variable: r1196814456 
o|substituted constant variable: r1198014458 
o|substituted constant variable: r1199214460 
o|substituted constant variable: r1201014462 
o|substituted constant variable: r1204914465 
o|substituted constant variable: r1206114467 
o|substituted constant variable: r1207314469 
o|substituted constant variable: r1239014488 
o|substituted constant variable: r1240814490 
o|substituted constant variable: r1242314492 
o|substituted constant variable: r1243514494 
o|substituted constant variable: r1270514506 
o|removed side-effect free assignment to unused variable: getbits2851 
o|removed side-effect free assignment to unused variable: getsize2852 
o|substituted constant variable: r1324914530 
o|substituted constant variable: r1327214532 
o|substituted constant variable: r1328414534 
o|substituted constant variable: r1340314539 
o|substituted constant variable: r1340314539 
o|substituted constant variable: r1340314541 
o|substituted constant variable: r1340314541 
o|replaced variables: 384 
o|removed binding forms: 2542 
o|inlining procedure: "(c-backend.scm:287) chicken.compiler.c-backend#uncommentify" 
o|inlining procedure: "(c-backend.scm:297) chicken.compiler.c-backend#uncommentify" 
o|inlining procedure: "(c-backend.scm:302) chicken.compiler.c-backend#uncommentify" 
o|inlining procedure: k5873 
o|inlining procedure: "(c-backend.scm:324) chicken.compiler.c-backend#backslashify" 
o|inlining procedure: "(c-backend.scm:325) chicken.compiler.c-backend#uncommentify" 
o|inlining procedure: "(c-backend.scm:319) chicken.compiler.c-backend#fifth" 
o|inlining procedure: k6330 
o|inlining procedure: k6393 
o|inlining procedure: k6429 
o|inlining procedure: "(c-backend.scm:451) chicken.compiler.c-backend#backslashify" 
o|inlining procedure: "(c-backend.scm:452) chicken.compiler.c-backend#uncommentify" 
o|inlining procedure: "(c-backend.scm:444) chicken.compiler.c-backend#fifth" 
o|inlining procedure: k7116 
o|inlining procedure: k7168 
o|inlining procedure: k7567 
o|inlining procedure: k7567 
o|propagated global variable: r869014166 chicken.compiler.core#unit-name 
o|inlining procedure: k8734 
o|inlining procedure: k8840 
o|inlining procedure: k8840 
o|inlining procedure: k8951 
o|inlining procedure: k8951 
o|inlining procedure: "(c-backend.scm:629) chicken.compiler.c-backend#uncommentify" 
o|inlining procedure: "(c-backend.scm:1002) chicken.compiler.c-backend#backslashify" 
o|inlining procedure: k4466 
o|inlining procedure: k9368 
o|inlining procedure: k10588 
o|inlining procedure: k11316 
o|inlining procedure: k13440 
o|inlining procedure: k13448 
o|inlining procedure: k13488 
o|converted assignments to bindings: (encode-size2853) 
o|simplifications: ((let . 1)) 
o|replaced variables: 4 
o|removed binding forms: 492 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#fifth 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#backslashify 
o|removed side-effect free assignment to unused variable: chicken.compiler.c-backend#uncommentify 
o|substituted constant variable: r711714831 
o|substituted constant variable: r711714831 
o|inlining procedure: k7792 
o|substituted constant variable: r884114874 
o|substituted constant variable: r884114875 
o|substituted constant variable: r446714914 
o|substituted constant variable: r1131714936 
o|inlining procedure: k13242 
o|inlining procedure: k13242 
o|inlining procedure: k13242 
o|inlining procedure: k13242 
o|inlining procedure: k13242 
o|contracted procedure: k13451 
o|replaced variables: 27 
o|removed binding forms: 16 
o|removed conditional forms: 3 
o|substituted constant variable: r1324315051 
o|substituted constant variable: r1324315055 
o|substituted constant variable: r1324315059 
o|substituted constant variable: r1324315063 
o|substituted constant variable: r1324315067 
o|removed binding forms: 37 
o|removed binding forms: 6 
o|simplifications: ((let . 27) (if . 81) (##core#call . 885)) 
o|  call simplifications:
o|    scheme#eof-object?
o|    chicken.fixnum#fxlen
o|    scheme#integer->char	9
o|    scheme#string	10
o|    scheme#list?	3
o|    chicken.fixnum#fx>	2
o|    scheme#string-set!	3
o|    scheme#string=?
o|    scheme#-	4
o|    chicken.fixnum#fx/
o|    chicken.base#void	2
o|    scheme#boolean?
o|    scheme#char?	2
o|    chicken.base#fixnum?	3
o|    scheme#string?	2
o|    chicken.base#bignum?
o|    chicken.base#flonum?	2
o|    scheme#symbol?	7
o|    ##sys#immediate?	4
o|    ##sys#generic-structure?
o|    chicken.base#ratnum?
o|    chicken.base#cplxnum?
o|    ##sys#size	8
o|    scheme#apply	9
o|    scheme#string-length	3
o|    chicken.bitwise#arithmetic-shift	7
o|    scheme#string-ref	3
o|    chicken.bitwise#bitwise-and	9
o|    ##sys#setslot	5
o|    scheme#<	2
o|    scheme#>=	8
o|    scheme#null?	13
o|    scheme#cdr	7
o|    scheme#length	11
o|    scheme#cddr	4
o|    scheme#cdddr
o|    scheme#cddddr	2
o|    scheme#cadddr	4
o|    ##sys#check-list	24
o|    scheme#not	42
o|    scheme#+	22
o|    scheme#>	5
o|    scheme#caddr	9
o|    scheme#vector?	2
o|    scheme#vector-ref	8
o|    scheme#car	89
o|    scheme#char->integer	4
o|    scheme#cadr	39
o|    scheme#pair?	49
o|    scheme#eq?	329
o|    ##sys#slot	84
o|    chicken.fixnum#fx>=	4
o|    chicken.fixnum#fx+
o|    scheme#cons	16
o|contracted procedure: k4292 
o|contracted procedure: k4307 
o|contracted procedure: k4574 
o|contracted procedure: k4584 
o|contracted procedure: k4588 
o|contracted procedure: k4556 
o|contracted procedure: k4611 
o|contracted procedure: k4621 
o|contracted procedure: k4625 
o|contracted procedure: k4739 
o|contracted procedure: k4742 
o|contracted procedure: k4748 
o|contracted procedure: k4758 
o|contracted procedure: k4764 
o|contracted procedure: k4775 
o|contracted procedure: k4771 
o|contracted procedure: k4781 
o|contracted procedure: k4790 
o|contracted procedure: k4797 
o|contracted procedure: k4803 
o|contracted procedure: k4812 
o|contracted procedure: k4836 
o|contracted procedure: k4839 
o|contracted procedure: k4845 
o|contracted procedure: k4852 
o|contracted procedure: k4859 
o|contracted procedure: k4865 
o|contracted procedure: k4868 
o|contracted procedure: k4901 
o|contracted procedure: k4926 
o|contracted procedure: k4930 
o|contracted procedure: k4934 
o|contracted procedure: k4940 
o|contracted procedure: k4947 
o|contracted procedure: k4953 
o|contracted procedure: k4960 
o|contracted procedure: k4969 
o|contracted procedure: k4991 
o|contracted procedure: k4998 
o|contracted procedure: k5004 
o|contracted procedure: k5007 
o|contracted procedure: k5023 
o|contracted procedure: k5027 
o|contracted procedure: k5033 
o|contracted procedure: k5040 
o|contracted procedure: k5046 
o|contracted procedure: k5059 
o|contracted procedure: k5065 
o|contracted procedure: k5078 
o|contracted procedure: k5084 
o|contracted procedure: k5101 
o|contracted procedure: k5097 
o|contracted procedure: k5105 
o|contracted procedure: k5111 
o|contracted procedure: k5117 
o|contracted procedure: k5130 
o|contracted procedure: k5151 
o|contracted procedure: k5157 
o|contracted procedure: k5170 
o|contracted procedure: k5191 
o|contracted procedure: k5197 
o|contracted procedure: k5210 
o|contracted procedure: k5231 
o|contracted procedure: k5244 
o|contracted procedure: k5250 
o|contracted procedure: k5269 
o|contracted procedure: k5273 
o|contracted procedure: k5277 
o|contracted procedure: k5283 
o|contracted procedure: k5302 
o|contracted procedure: k5310 
o|contracted procedure: k5306 
o|contracted procedure: k5314 
o|contracted procedure: k5320 
o|contracted procedure: k5339 
o|contracted procedure: k5343 
o|contracted procedure: k5349 
o|contracted procedure: k5368 
o|contracted procedure: k5372 
o|contracted procedure: k5378 
o|contracted procedure: k5381 
o|contracted procedure: k5401 
o|contracted procedure: k5404 
o|contracted procedure: k5446 
o|contracted procedure: k5421 
o|contracted procedure: k5431 
o|contracted procedure: k5435 
o|contracted procedure: k5439 
o|contracted procedure: k5443 
o|contracted procedure: k5455 
o|contracted procedure: k5468 
o|contracted procedure: k5474 
o|contracted procedure: k5481 
o|contracted procedure: k5487 
o|contracted procedure: k5497 
o|contracted procedure: k5501 
o|contracted procedure: k5507 
o|contracted procedure: k5510 
o|contracted procedure: k5513 
o|contracted procedure: k5516 
o|contracted procedure: k5540 
o|contracted procedure: k5555 
o|contracted procedure: k5558 
o|contracted procedure: k5561 
o|contracted procedure: k5564 
o|contracted procedure: k5580 
o|contracted procedure: k5600 
o|contracted procedure: k5603 
o|contracted procedure: k5606 
o|contracted procedure: k5609 
o|contracted procedure: k5625 
o|contracted procedure: k5646 
o|contracted procedure: k5660 
o|contracted procedure: k5669 
o|contracted procedure: k5672 
o|contracted procedure: k5675 
o|contracted procedure: k5679 
o|contracted procedure: k5682 
o|contracted procedure: k6181 
o|contracted procedure: k5685 
o|contracted procedure: k5688 
o|contracted procedure: k5710 
o|contracted procedure: k5726 
o|contracted procedure: k5755 
o|contracted procedure: k5769 
o|contracted procedure: k5815 
o|contracted procedure: k5790 
o|contracted procedure: k5800 
o|contracted procedure: k5804 
o|contracted procedure: k5808 
o|contracted procedure: k5812 
o|contracted procedure: k5852 
o|contracted procedure: k5827 
o|contracted procedure: k5837 
o|contracted procedure: k5841 
o|contracted procedure: k5845 
o|contracted procedure: k5849 
o|contracted procedure: k5907 
o|contracted procedure: k5928 
o|contracted procedure: k5947 
o|contracted procedure: k5950 
o|contracted procedure: k5953 
o|contracted procedure: k6019 
o|contracted procedure: k6097 
o|contracted procedure: k6103 
o|contracted procedure: k6109 
o|contracted procedure: k6129 
o|contracted procedure: k383014793 
o|contracted procedure: k6174 
o|contracted procedure: k6167 
o|contracted procedure: k6187 
o|contracted procedure: k6190 
o|contracted procedure: k6194 
o|contracted procedure: k6197 
o|contracted procedure: k6224 
o|contracted procedure: k6238 
o|contracted procedure: k6278 
o|contracted procedure: k6253 
o|contracted procedure: k6263 
o|contracted procedure: k6267 
o|contracted procedure: k6271 
o|contracted procedure: k6275 
o|contracted procedure: k6315 
o|contracted procedure: k6290 
o|contracted procedure: k6300 
o|contracted procedure: k6304 
o|contracted procedure: k6308 
o|contracted procedure: k6312 
o|contracted procedure: k6345 
o|contracted procedure: k6348 
o|contracted procedure: k6351 
o|contracted procedure: k6355 
o|contracted procedure: k6358 
o|contracted procedure: k6364 
o|contracted procedure: k383014822 
o|contracted procedure: k6367 
o|contracted procedure: k6370 
o|contracted procedure: k6402 
o|contracted procedure: k6414 
o|contracted procedure: k6426 
o|contracted procedure: k6429 
o|contracted procedure: k6444 
o|contracted procedure: k6477 
o|contracted procedure: k6484 
o|contracted procedure: k6490 
o|contracted procedure: k6493 
o|contracted procedure: k6512 
o|contracted procedure: k6518 
o|contracted procedure: k6531 
o|contracted procedure: k6537 
o|contracted procedure: k6550 
o|contracted procedure: k6556 
o|contracted procedure: k6563 
o|contracted procedure: k6573 
o|contracted procedure: k6585 
o|contracted procedure: k6595 
o|contracted procedure: k6599 
o|contracted procedure: k6605 
o|contracted procedure: k6616 
o|contracted procedure: k6620 
o|contracted procedure: k6626 
o|contracted procedure: k6629 
o|contracted procedure: k6642 
o|contracted procedure: k6646 
o|contracted procedure: k6660 
o|contracted procedure: k6663 
o|contracted procedure: k6676 
o|contracted procedure: k6690 
o|contracted procedure: k6693 
o|contracted procedure: k6712 
o|contracted procedure: k6720 
o|contracted procedure: k6730 
o|contracted procedure: k6746 
o|contracted procedure: k6750 
o|contracted procedure: k6770 
o|contracted procedure: k6791 
o|contracted procedure: k6795 
o|contracted procedure: k6799 
o|contracted procedure: k6803 
o|contracted procedure: k6809 
o|contracted procedure: k6834 
o|contracted procedure: k6838 
o|contracted procedure: k6842 
o|contracted procedure: k6948 
o|contracted procedure: k6963 
o|contracted procedure: k6966 
o|contracted procedure: k6984 
o|contracted procedure: k6987 
o|contracted procedure: k6990 
o|contracted procedure: k7018 
o|contracted procedure: k7023 
o|contracted procedure: k7045 
o|contracted procedure: k7054 
o|contracted procedure: k7074 
o|contracted procedure: k7080 
o|contracted procedure: k7092 
o|contracted procedure: k7125 
o|contracted procedure: k7116 
o|contracted procedure: k7177 
o|contracted procedure: k7197 
o|contracted procedure: k7207 
o|contracted procedure: k7211 
o|contracted procedure: k7217 
o|contracted procedure: k7226 
o|contracted procedure: k7237 
o|contracted procedure: k7257 
o|contracted procedure: k7260 
o|contracted procedure: k7263 
o|contracted procedure: k7271 
o|contracted procedure: k7279 
o|contracted procedure: k7306 
o|contracted procedure: k7317 
o|contracted procedure: k7320 
o|contracted procedure: k7326 
o|contracted procedure: k7347 
o|contracted procedure: k7353 
o|contracted procedure: k7377 
o|contracted procedure: k7405 
o|contracted procedure: k7421 
o|contracted procedure: k7417 
o|contracted procedure: k7425 
o|contracted procedure: k7436 
o|contracted procedure: k7429 
o|contracted procedure: k7440 
o|contracted procedure: k7443 
o|contracted procedure: k7456 
o|contracted procedure: k7466 
o|contracted procedure: k7470 
o|contracted procedure: k7479 
o|contracted procedure: k7482 
o|contracted procedure: k7485 
o|contracted procedure: k7493 
o|contracted procedure: k7501 
o|propagated global variable: g12951299 chicken.compiler.core#used-units 
o|contracted procedure: k7656 
o|contracted procedure: k7668 
o|contracted procedure: k7678 
o|contracted procedure: k7682 
o|contracted procedure: k7515 
o|contracted procedure: k7576 
o|contracted procedure: k7585 
o|contracted procedure: k7640 
o|contracted procedure: k7599 
o|contracted procedure: k7777 
o|contracted procedure: k7789 
o|contracted procedure: k7799 
o|contracted procedure: k7803 
o|contracted procedure: k7717 
o|contracted procedure: k7764 
o|contracted procedure: k7736 
o|contracted procedure: k7702 
o|contracted procedure: k779914992 
o|contracted procedure: k7818 
o|contracted procedure: k7832 
o|contracted procedure: k7878 
o|contracted procedure: k7884 
o|contracted procedure: k7890 
o|contracted procedure: k7896 
o|contracted procedure: k7908 
o|contracted procedure: k7929 
o|contracted procedure: k7936 
o|contracted procedure: k7940 
o|contracted procedure: k7949 
o|contracted procedure: k7961 
o|contracted procedure: k7968 
o|contracted procedure: k7976 
o|contracted procedure: k7972 
o|contracted procedure: k7985 
o|contracted procedure: k7988 
o|contracted procedure: k7991 
o|contracted procedure: k7999 
o|contracted procedure: k8007 
o|contracted procedure: k8023 
o|contracted procedure: k8046 
o|contracted procedure: k8052 
o|contracted procedure: k8055 
o|contracted procedure: k8070 
o|contracted procedure: k8079 
o|contracted procedure: k8087 
o|contracted procedure: k8093 
o|contracted procedure: k8100 
o|contracted procedure: k8118 
o|contracted procedure: k8125 
o|contracted procedure: k8284 
o|contracted procedure: k8164 
o|propagated global variable: r8285 ##sys#undefined-value 
o|contracted procedure: k8173 
o|contracted procedure: k8186 
o|contracted procedure: k8193 
o|contracted procedure: k8202 
o|contracted procedure: k8205 
o|contracted procedure: k8211 
o|contracted procedure: k8214 
o|contracted procedure: k8229 
o|contracted procedure: k8277 
o|contracted procedure: k8273 
o|contracted procedure: k8235 
o|contracted procedure: k8244 
o|contracted procedure: k8270 
o|contracted procedure: k8287 
o|contracted procedure: k8300 
o|contracted procedure: k8303 
o|contracted procedure: k8321 
o|contracted procedure: k8342 
o|contracted procedure: k8356 
o|contracted procedure: k8368 
o|contracted procedure: k8374 
o|contracted procedure: k8388 
o|contracted procedure: k8413 
o|contracted procedure: k8619 
o|contracted procedure: k8612 
o|contracted procedure: k8510 
o|contracted procedure: k8529 
o|contracted procedure: k8546 
o|contracted procedure: k8550 
o|contracted procedure: k8559 
o|contracted procedure: k8565 
o|contracted procedure: k8583 
o|contracted procedure: k8595 
o|contracted procedure: k8622 
o|contracted procedure: k8625 
o|contracted procedure: k8666 
o|contracted procedure: k8653 
o|contracted procedure: k8698 
o|contracted procedure: k8705 
o|contracted procedure: k8722 
o|contracted procedure: k8749 
o|contracted procedure: k8755 
o|contracted procedure: k8761 
o|contracted procedure: k8782 
o|contracted procedure: k8807 
o|contracted procedure: k8813 
o|contracted procedure: k8825 
o|contracted procedure: k8831 
o|contracted procedure: k8849 
o|contracted procedure: k8840 
o|contracted procedure: k8869 
o|contracted procedure: k8881 
o|contracted procedure: k8891 
o|contracted procedure: k8895 
o|contracted procedure: k8924 
o|contracted procedure: k8936 
o|contracted procedure: k8947 
o|contracted procedure: k8960 
o|contracted procedure: k8969 
o|contracted procedure: k9021 
o|contracted procedure: k8983 
o|contracted procedure: k9032 
o|contracted procedure: k9039 
o|contracted procedure: k9057 
o|contracted procedure: k9069 
o|contracted procedure: k9079 
o|contracted procedure: k9083 
o|contracted procedure: k9258 
o|contracted procedure: k9268 
o|contracted procedure: k9306 
o|contracted procedure: k9316 
o|contracted procedure: k9320 
o|contracted procedure: k9325 
o|contracted procedure: k9204 
o|contracted procedure: k9219 
o|contracted procedure: k9229 
o|contracted procedure: k9233 
o|contracted procedure: k9162 
o|contracted procedure: k9165 
o|contracted procedure: k9180 
o|contracted procedure: k9190 
o|contracted procedure: k9194 
o|contracted procedure: k9145 
o|contracted procedure: k9198 
o|contracted procedure: k9243 
o|contracted procedure: k9247 
o|contracted procedure: k9909 
o|contracted procedure: k9921 
o|contracted procedure: k9930 
o|contracted procedure: k9942 
o|contracted procedure: k9954 
o|contracted procedure: k9966 
o|contracted procedure: k9978 
o|contracted procedure: k9999 
o|contracted procedure: k10008 
o|contracted procedure: k10015 
o|contracted procedure: k10027 
o|contracted procedure: k10034 
o|contracted procedure: k10039 
o|contracted procedure: k10045 
o|contracted procedure: k10051 
o|contracted procedure: k10057 
o|contracted procedure: k10063 
o|contracted procedure: k10069 
o|contracted procedure: k10075 
o|contracted procedure: k10102 
o|contracted procedure: k10108 
o|contracted procedure: k10114 
o|contracted procedure: k10120 
o|contracted procedure: k10139 
o|contracted procedure: k10145 
o|contracted procedure: k10151 
o|contracted procedure: k10170 
o|contracted procedure: k10176 
o|contracted procedure: k10193 
o|contracted procedure: k10199 
o|contracted procedure: k10205 
o|contracted procedure: k10211 
o|contracted procedure: k10217 
o|contracted procedure: k10240 
o|contracted procedure: k10246 
o|contracted procedure: k10252 
o|contracted procedure: k10258 
o|contracted procedure: k10279 
o|contracted procedure: k10285 
o|contracted procedure: k10291 
o|contracted procedure: k10297 
o|contracted procedure: k10303 
o|contracted procedure: k10309 
o|contracted procedure: k10315 
o|contracted procedure: k10321 
o|contracted procedure: k10327 
o|contracted procedure: k10333 
o|contracted procedure: k10339 
o|contracted procedure: k10422 
o|contracted procedure: k10428 
o|contracted procedure: k10469 
o|contracted procedure: k10444 
o|contracted procedure: k10454 
o|contracted procedure: k10458 
o|contracted procedure: k10462 
o|contracted procedure: k10466 
o|contracted procedure: k10479 
o|contracted procedure: k10495 
o|contracted procedure: k10502 
o|contracted procedure: k10506 
o|contracted procedure: k10517 
o|contracted procedure: k10529 
o|contracted procedure: k10539 
o|contracted procedure: k10543 
o|propagated global variable: stubs2027 chicken.compiler.support#foreign-callback-stubs 
o|contracted procedure: k9568 
o|contracted procedure: k9652 
o|contracted procedure: k9655 
o|contracted procedure: k9721 
o|contracted procedure: k9745 
o|contracted procedure: k9735 
o|contracted procedure: k9767 
o|contracted procedure: k9771 
o|contracted procedure: k9775 
o|contracted procedure: k9779 
o|contracted procedure: k9783 
o|contracted procedure: k9787 
o|contracted procedure: k9790 
o|contracted procedure: k9796 
o|contracted procedure: k9814 
o|contracted procedure: k9826 
o|contracted procedure: k9843 
o|contracted procedure: k4475 
o|contracted procedure: k4466 
o|contracted procedure: k9863 
o|contracted procedure: k9875 
o|contracted procedure: k9885 
o|contracted procedure: k9889 
o|propagated global variable: stubs1916 chicken.compiler.core#foreign-lambda-stubs 
o|contracted procedure: k9482 
o|contracted procedure: k9494 
o|contracted procedure: k9504 
o|contracted procedure: k9508 
o|contracted procedure: k9462 
o|contracted procedure: k9465 
o|contracted procedure: k9468 
o|contracted procedure: k9475 
o|contracted procedure: k4682 
o|contracted procedure: k4686 
o|contracted procedure: k4697 
o|contracted procedure: k4693 
o|contracted procedure: k9334 
o|contracted procedure: k9347 
o|contracted procedure: k9359 
o|contracted procedure: k9365 
o|inlining procedure: k9368 
o|inlining procedure: k9368 
o|contracted procedure: k9415 
o|contracted procedure: k9525 
o|contracted procedure: k9537 
o|contracted procedure: k9547 
o|contracted procedure: k9551 
o|contracted procedure: k10561 
o|contracted procedure: k10582 
o|contracted procedure: k10598 
o|contracted procedure: k10611 
o|contracted procedure: k10615 
o|contracted procedure: k10638 
o|contracted procedure: k10647 
o|contracted procedure: k10650 
o|contracted procedure: k10659 
o|contracted procedure: k10662 
o|contracted procedure: k10671 
o|contracted procedure: k10674 
o|contracted procedure: k10683 
o|contracted procedure: k10686 
o|contracted procedure: k10695 
o|contracted procedure: k10707 
o|contracted procedure: k10716 
o|contracted procedure: k10725 
o|contracted procedure: k10728 
o|contracted procedure: k10737 
o|contracted procedure: k10746 
o|contracted procedure: k10755 
o|contracted procedure: k10764 
o|contracted procedure: k10773 
o|contracted procedure: k10782 
o|contracted procedure: k10791 
o|contracted procedure: k10800 
o|contracted procedure: k10803 
o|contracted procedure: k10812 
o|contracted procedure: k10824 
o|contracted procedure: k10827 
o|contracted procedure: k10833 
o|contracted procedure: k10845 
o|contracted procedure: k10848 
o|contracted procedure: k10857 
o|contracted procedure: k10860 
o|contracted procedure: k10869 
o|contracted procedure: k10872 
o|contracted procedure: k10881 
o|contracted procedure: k10884 
o|contracted procedure: k10893 
o|contracted procedure: k10896 
o|contracted procedure: k10905 
o|contracted procedure: k10908 
o|contracted procedure: k10917 
o|contracted procedure: k10920 
o|contracted procedure: k10929 
o|contracted procedure: k10932 
o|contracted procedure: k10941 
o|contracted procedure: k10944 
o|contracted procedure: k10953 
o|contracted procedure: k10956 
o|contracted procedure: k10965 
o|contracted procedure: k10977 
o|contracted procedure: k10989 
o|contracted procedure: k11007 
o|contracted procedure: k11016 
o|contracted procedure: k11025 
o|contracted procedure: k11039 
o|contracted procedure: k11056 
o|contracted procedure: k11085 
o|contracted procedure: k11093 
o|contracted procedure: k11096 
o|contracted procedure: k11108 
o|contracted procedure: k11111 
o|contracted procedure: k11114 
o|contracted procedure: k11122 
o|contracted procedure: k11130 
o|contracted procedure: k11137 
o|contracted procedure: k11154 
o|contracted procedure: k11171 
o|contracted procedure: k11188 
o|contracted procedure: k11205 
o|contracted procedure: k11222 
o|contracted procedure: k11239 
o|contracted procedure: k11248 
o|contracted procedure: k11251 
o|contracted procedure: k11326 
o|contracted procedure: k11257 
o|contracted procedure: k11272 
o|contracted procedure: k11286 
o|contracted procedure: k11298 
o|contracted procedure: k11304 
o|contracted procedure: k11312 
o|contracted procedure: k11320 
o|contracted procedure: k11280 
o|contracted procedure: k11335 
o|contracted procedure: k11342 
o|contracted procedure: k11347 
o|contracted procedure: k11354 
o|contracted procedure: k11359 
o|contracted procedure: k11363 
o|contracted procedure: k11369 
o|contracted procedure: k11376 
o|contracted procedure: k11381 
o|contracted procedure: k11388 
o|contracted procedure: k11393 
o|contracted procedure: k11400 
o|contracted procedure: k11405 
o|contracted procedure: k11412 
o|contracted procedure: k11417 
o|contracted procedure: k11424 
o|contracted procedure: k11429 
o|contracted procedure: k11436 
o|contracted procedure: k11441 
o|contracted procedure: k11445 
o|contracted procedure: k11454 
o|contracted procedure: k11462 
o|contracted procedure: k11468 
o|contracted procedure: k11485 
o|contracted procedure: k11491 
o|contracted procedure: k11497 
o|contracted procedure: k11586 
o|contracted procedure: k11592 
o|contracted procedure: k11616 
o|contracted procedure: k11622 
o|contracted procedure: k11671 
o|contracted procedure: k11727 
o|contracted procedure: k11733 
o|contracted procedure: k11736 
o|contracted procedure: k11742 
o|contracted procedure: k11751 
o|contracted procedure: k11757 
o|contracted procedure: k11763 
o|contracted procedure: k11769 
o|contracted procedure: k11778 
o|contracted procedure: k11781 
o|contracted procedure: k11787 
o|contracted procedure: k11793 
o|contracted procedure: k11799 
o|contracted procedure: k11805 
o|contracted procedure: k11811 
o|contracted procedure: k11817 
o|contracted procedure: k11820 
o|contracted procedure: k11826 
o|contracted procedure: k11832 
o|contracted procedure: k11838 
o|contracted procedure: k11844 
o|contracted procedure: k11850 
o|contracted procedure: k11856 
o|contracted procedure: k11862 
o|contracted procedure: k11868 
o|contracted procedure: k11874 
o|contracted procedure: k11880 
o|contracted procedure: k11886 
o|contracted procedure: k11892 
o|contracted procedure: k11898 
o|contracted procedure: k11904 
o|contracted procedure: k11910 
o|contracted procedure: k11916 
o|contracted procedure: k11922 
o|contracted procedure: k11928 
o|contracted procedure: k11934 
o|contracted procedure: k11940 
o|contracted procedure: k11946 
o|contracted procedure: k11952 
o|contracted procedure: k11958 
o|contracted procedure: k11964 
o|contracted procedure: k11970 
o|contracted procedure: k11976 
o|contracted procedure: k11982 
o|contracted procedure: k11988 
o|contracted procedure: k11994 
o|contracted procedure: k12003 
o|contracted procedure: k12012 
o|contracted procedure: k12027 
o|contracted procedure: k12161 
o|contracted procedure: k12036 
o|contracted procedure: k12039 
o|contracted procedure: k12045 
o|contracted procedure: k12051 
o|contracted procedure: k12057 
o|contracted procedure: k12063 
o|contracted procedure: k12069 
o|contracted procedure: k12075 
o|contracted procedure: k12081 
o|contracted procedure: k12087 
o|contracted procedure: k12094 
o|contracted procedure: k12100 
o|contracted procedure: k12106 
o|contracted procedure: k12117 
o|contracted procedure: k12123 
o|contracted procedure: k12130 
o|contracted procedure: k12170 
o|contracted procedure: k12178 
o|contracted procedure: k12184 
o|contracted procedure: k12190 
o|contracted procedure: k12209 
o|contracted procedure: k12215 
o|contracted procedure: k12312 
o|contracted procedure: k12333 
o|contracted procedure: k12339 
o|contracted procedure: k12345 
o|contracted procedure: k12351 
o|contracted procedure: k12392 
o|contracted procedure: k12395 
o|contracted procedure: k12401 
o|contracted procedure: k12404 
o|contracted procedure: k12410 
o|contracted procedure: k12413 
o|contracted procedure: k12419 
o|contracted procedure: k12425 
o|contracted procedure: k12431 
o|contracted procedure: k12437 
o|contracted procedure: k12443 
o|contracted procedure: k12446 
o|contracted procedure: k12470 
o|contracted procedure: k12494 
o|contracted procedure: k12521 
o|contracted procedure: k12545 
o|contracted procedure: k12548 
o|contracted procedure: k12572 
o|contracted procedure: k12575 
o|contracted procedure: k12599 
o|contracted procedure: k12602 
o|contracted procedure: k12626 
o|contracted procedure: k12629 
o|contracted procedure: k12653 
o|contracted procedure: k12677 
o|contracted procedure: k12701 
o|contracted procedure: k12707 
o|contracted procedure: k12710 
o|contracted procedure: k12725 
o|contracted procedure: k12985 
o|contracted procedure: k12734 
o|contracted procedure: k12737 
o|contracted procedure: k12743 
o|contracted procedure: k12746 
o|contracted procedure: k12770 
o|contracted procedure: k12794 
o|contracted procedure: k12818 
o|contracted procedure: k12842 
o|contracted procedure: k12866 
o|contracted procedure: k12873 
o|contracted procedure: k12879 
o|contracted procedure: k12882 
o|contracted procedure: k12906 
o|contracted procedure: k12930 
o|contracted procedure: k12994 
o|contracted procedure: k13043 
o|contracted procedure: k13049 
o|contracted procedure: k13055 
o|contracted procedure: k13061 
o|contracted procedure: k13067 
o|contracted procedure: k13073 
o|contracted procedure: k13079 
o|contracted procedure: k13085 
o|contracted procedure: k13091 
o|contracted procedure: k13097 
o|contracted procedure: k13225 
o|contracted procedure: k13183 
o|contracted procedure: k13221 
o|contracted procedure: k13217 
o|contracted procedure: k13193 
o|contracted procedure: k13213 
o|contracted procedure: k13209 
o|contracted procedure: k13197 
o|contracted procedure: k13205 
o|contracted procedure: k13201 
o|contracted procedure: k13235 
o|contracted procedure: k13245 
o|contracted procedure: k1323515054 
o|contracted procedure: k13251 
o|contracted procedure: k1323515058 
o|contracted procedure: k13257 
o|contracted procedure: k13268 
o|contracted procedure: k13274 
o|contracted procedure: k1323515062 
o|contracted procedure: k13280 
o|contracted procedure: k1323515066 
o|contracted procedure: k13505 
o|contracted procedure: k13286 
o|propagated global variable: r13506 ##sys#undefined-value 
o|contracted procedure: k1323515070 
o|contracted procedure: k13344 
o|contracted procedure: k13340 
o|contracted procedure: k13304 
o|contracted procedure: k13336 
o|contracted procedure: k13332 
o|contracted procedure: k13308 
o|contracted procedure: k13328 
o|contracted procedure: k13324 
o|contracted procedure: k13312 
o|contracted procedure: k13320 
o|contracted procedure: k13316 
o|contracted procedure: k13300 
o|contracted procedure: k13362 
o|contracted procedure: k13371 
o|contracted procedure: k13388 
o|contracted procedure: k13391 
o|contracted procedure: k13409 
o|contracted procedure: k13415 
o|contracted procedure: k13444 
o|contracted procedure: k13432 
o|contracted procedure: k13484 
o|contracted procedure: k13462 
o|contracted procedure: k3714 
o|contracted procedure: k3725 
o|contracted procedure: k13480 
o|contracted procedure: k13494 
o|simplifications: ((if . 13) (##core#call . 12) (let . 266)) 
o|  call simplifications:
o|    scheme#+	12
o|removed binding forms: 817 
o|contracted procedure: k5697 
o|contracted procedure: k8247 
o|contracted procedure: k8324 
o|contracted procedure: k9368 
o|contracted procedure: k11032 
o|contracted procedure: k11049 
o|contracted procedure: k11066 
o|contracted procedure: k11143 
o|contracted procedure: k11160 
o|contracted procedure: k11177 
o|contracted procedure: k11194 
o|contracted procedure: k11211 
o|contracted procedure: k11228 
o|contracted procedure: k11245 
o|removed binding forms: 14 
o|customizable procedures: (k13292 loop299 encode-size2853 k12497 err2543 g27372738 k11745 k11772 k11997 k12006 err2465 k10698 k10815 k10836 k10968 k10980 err2265 k11301 map-loop24382456 map-loop23902415 g23772378 str2266 loop2254 for-each-loop18971910 k9378 loop1844 header706 declarations708 for-each-loop18731887 g19211928 for-each-loop19202021 doloop19631964 k9757 for-each-loop19501989 prototypes709 g20322039 for-each-loop20312240 loop2201 chicken.compiler.c-backend#generate-foreign-callback-header for-each-loop22082222 k9924 k9933 k9945 k9957 k9969 k9981 k10018 g21672168 compute-size2048 trampolines710 for-each-loop17821793 for-each-loop17691802 procedures717 g18151822 for-each-loop18141828 g15501557 for-each-loop15491733 k8410 chicken.compiler.c-backend#cleanup k8476 doloop16071608 k8899 doloop16121613 for-each-loop16201631 k8801 k8743 g16511652 foldl16441648 literal-frame711 doloop16911692 doloop16991700 expression705 doloop15321533 string-like-substring716 k8149 chicken.compiler.c-backend#encode-literal gen-string-constant715 va15450 va15448 loop1497 map-loop14671484 foldl14611491 va15440 literal-size713 va15438 gen-lit714 doloop14321433 k7727 k7730 doloop14031404 chicken.compiler.c-backend#make-argument-list for-each-loop13931426 k7525 chicken.compiler.c-backend#make-variable-list for-each-loop13381382 map-loop12831300 for-each-loop12691307 doloop13171319 doloop13181323 doloop12771312 map-loop12061231 chicken.compiler.c-backend#gen-list for-each-loop12411252 chicken.compiler.c-backend#generate-foreign-callback-stub-prototypes k7026 doloop11781191 contains-restop?727 loop1153 loop1147 doloop11251126 chicken.compiler.c-backend#foreign-argument-conversion chicken.compiler.c-backend#foreign-result-conversion va15406 g10261045 for-each-loop10251052 for-each-loop10361065 k5694 find-lambda704 k5700 k5941 k6075 expr-args726 va15400 g909928 for-each-loop908935 for-each-loop919948 push-args728 chicken.compiler.c-backend#list-tabulate g821829 for-each-loop820836 k5200 k5160 k5120 loop759 expr725 for-each-loop662673 for-each-loop642653 loop517) 
o|calls to known targets: 836 
o|identified direct recursive calls: f_7956 1 
o|unused rest argument: _57714916 f14917 
o|unused rest argument: _577 f_4473 
o|identified direct recursive calls: f_3709 1 
o|fast box initializations: 68 
o|fast global references: 406 
o|fast global assignments: 14 
o|dropping unused closure argument: f_10547 
o|dropping unused closure argument: f_11717 
o|dropping unused closure argument: f_12382 
o|dropping unused closure argument: f_13169 
o|dropping unused closure argument: f_13178 
o|dropping unused closure argument: f_4281 
o|dropping unused closure argument: f_4592 
o|dropping unused closure argument: f_8372 
o|dropping unused closure argument: f_9345 
o|dropping unused closure argument: f_9421 
o|dropping unused closure argument: f_9438 
o|dropping unused closure argument: f_9512 
*/
/* end of file */
