/* Generated from optimizer.scm by the CHICKEN compiler
   http://www.call-cc.org
   Version 5.4.0rc1 (prerelease) (rev bc191a47)
   linux-unix-gnu-x86-64 [ 64bit dload ptables ]
   command line: optimizer.scm -optimize-level 2 -include-path . -include-path ./ -inline -ignore-repository -feature chicken-bootstrap -no-warnings -specialize -consult-types-file ./types.db -no-lambda-info -no-trace -emit-import-library chicken.compiler.optimizer -output-file optimizer.c
   unit: optimizer
   uses: eval data-structures internal support library
*/
#include "chicken.h"

static C_PTABLE_ENTRY *create_ptable(void);
C_noret_decl(C_eval_toplevel)
C_externimport void C_ccall C_eval_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_data_2dstructures_toplevel)
C_externimport void C_ccall C_data_2dstructures_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_internal_toplevel)
C_externimport void C_ccall C_internal_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_support_toplevel)
C_externimport void C_ccall C_support_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_library_toplevel)
C_externimport void C_ccall C_library_toplevel(C_word c,C_word *av) C_noret;

static C_TLS C_word lf[245];
static double C_possibly_force_alignment;


C_noret_decl(f_10002)
static void C_ccall f_10002(C_word c,C_word *av) C_noret;
C_noret_decl(f_10017)
static void C_ccall f_10017(C_word c,C_word *av) C_noret;
C_noret_decl(f_10021)
static void C_ccall f_10021(C_word c,C_word *av) C_noret;
C_noret_decl(f_10031)
static void C_ccall f_10031(C_word c,C_word *av) C_noret;
C_noret_decl(f_10043)
static void C_ccall f_10043(C_word c,C_word *av) C_noret;
C_noret_decl(f_10055)
static void C_ccall f_10055(C_word c,C_word *av) C_noret;
C_noret_decl(f_10059)
static void C_ccall f_10059(C_word c,C_word *av) C_noret;
C_noret_decl(f_10101)
static void C_ccall f_10101(C_word c,C_word *av) C_noret;
C_noret_decl(f_10116)
static void C_ccall f_10116(C_word c,C_word *av) C_noret;
C_noret_decl(f_10124)
static void C_ccall f_10124(C_word c,C_word *av) C_noret;
C_noret_decl(f_10126)
static void C_ccall f_10126(C_word c,C_word *av) C_noret;
C_noret_decl(f_10134)
static void C_ccall f_10134(C_word c,C_word *av) C_noret;
C_noret_decl(f_10146)
static void C_ccall f_10146(C_word c,C_word *av) C_noret;
C_noret_decl(f_10173)
static void C_ccall f_10173(C_word c,C_word *av) C_noret;
C_noret_decl(f_10188)
static void C_ccall f_10188(C_word c,C_word *av) C_noret;
C_noret_decl(f_10209)
static void C_ccall f_10209(C_word c,C_word *av) C_noret;
C_noret_decl(f_10245)
static void C_ccall f_10245(C_word c,C_word *av) C_noret;
C_noret_decl(f_10247)
static void C_ccall f_10247(C_word c,C_word *av) C_noret;
C_noret_decl(f_10282)
static void C_ccall f_10282(C_word c,C_word *av) C_noret;
C_noret_decl(f_10304)
static void C_ccall f_10304(C_word c,C_word *av) C_noret;
C_noret_decl(f_10308)
static void C_ccall f_10308(C_word c,C_word *av) C_noret;
C_noret_decl(f_10344)
static void C_ccall f_10344(C_word c,C_word *av) C_noret;
C_noret_decl(f_10368)
static void C_ccall f_10368(C_word c,C_word *av) C_noret;
C_noret_decl(f_10408)
static void C_ccall f_10408(C_word c,C_word *av) C_noret;
C_noret_decl(f_10428)
static void C_ccall f_10428(C_word c,C_word *av) C_noret;
C_noret_decl(f_10432)
static void C_ccall f_10432(C_word c,C_word *av) C_noret;
C_noret_decl(f_10436)
static void C_ccall f_10436(C_word c,C_word *av) C_noret;
C_noret_decl(f_10438)
static void C_ccall f_10438(C_word c,C_word *av) C_noret;
C_noret_decl(f_10444)
static void C_ccall f_10444(C_word c,C_word *av) C_noret;
C_noret_decl(f_10452)
static void C_ccall f_10452(C_word c,C_word *av) C_noret;
C_noret_decl(f_10458)
static void C_fcall f_10458(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10478)
static void C_ccall f_10478(C_word c,C_word *av) C_noret;
C_noret_decl(f_10482)
static void C_ccall f_10482(C_word c,C_word *av) C_noret;
C_noret_decl(f_10505)
static void C_ccall f_10505(C_word c,C_word *av) C_noret;
C_noret_decl(f_10578)
static void C_ccall f_10578(C_word c,C_word *av) C_noret;
C_noret_decl(f_10581)
static void C_fcall f_10581(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_10585)
static void C_ccall f_10585(C_word c,C_word *av) C_noret;
C_noret_decl(f_10588)
static void C_ccall f_10588(C_word c,C_word *av) C_noret;
C_noret_decl(f_10591)
static void C_ccall f_10591(C_word c,C_word *av) C_noret;
C_noret_decl(f_10606)
static void C_ccall f_10606(C_word c,C_word *av) C_noret;
C_noret_decl(f_10637)
static void C_ccall f_10637(C_word c,C_word *av) C_noret;
C_noret_decl(f_10643)
static void C_ccall f_10643(C_word c,C_word *av) C_noret;
C_noret_decl(f_10649)
static void C_ccall f_10649(C_word c,C_word *av) C_noret;
C_noret_decl(f_10697)
static void C_ccall f_10697(C_word c,C_word *av) C_noret;
C_noret_decl(f_10705)
static void C_ccall f_10705(C_word c,C_word *av) C_noret;
C_noret_decl(f_10709)
static void C_ccall f_10709(C_word c,C_word *av) C_noret;
C_noret_decl(f_10735)
static void C_ccall f_10735(C_word c,C_word *av) C_noret;
C_noret_decl(f_10751)
static void C_fcall f_10751(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10763)
static void C_fcall f_10763(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10773)
static void C_ccall f_10773(C_word c,C_word *av) C_noret;
C_noret_decl(f_10792)
static void C_fcall f_10792(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_10795)
static void C_fcall f_10795(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_10799)
static void C_ccall f_10799(C_word c,C_word *av) C_noret;
C_noret_decl(f_10802)
static void C_ccall f_10802(C_word c,C_word *av) C_noret;
C_noret_decl(f_10805)
static void C_ccall f_10805(C_word c,C_word *av) C_noret;
C_noret_decl(f_10844)
static void C_ccall f_10844(C_word c,C_word *av) C_noret;
C_noret_decl(f_10862)
static void C_ccall f_10862(C_word c,C_word *av) C_noret;
C_noret_decl(f_10878)
static void C_ccall f_10878(C_word c,C_word *av) C_noret;
C_noret_decl(f_10899)
static void C_ccall f_10899(C_word c,C_word *av) C_noret;
C_noret_decl(f_10933)
static void C_ccall f_10933(C_word c,C_word *av) C_noret;
C_noret_decl(f_10949)
static void C_ccall f_10949(C_word c,C_word *av) C_noret;
C_noret_decl(f_10953)
static void C_fcall f_10953(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10958)
static void C_ccall f_10958(C_word c,C_word *av) C_noret;
C_noret_decl(f_10988)
static void C_ccall f_10988(C_word c,C_word *av) C_noret;
C_noret_decl(f_10992)
static void C_fcall f_10992(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10997)
static void C_ccall f_10997(C_word c,C_word *av) C_noret;
C_noret_decl(f_11039)
static void C_fcall f_11039(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11044)
static void C_ccall f_11044(C_word c,C_word *av) C_noret;
C_noret_decl(f_11081)
static void C_ccall f_11081(C_word c,C_word *av) C_noret;
C_noret_decl(f_11085)
static void C_ccall f_11085(C_word c,C_word *av) C_noret;
C_noret_decl(f_11092)
static void C_ccall f_11092(C_word c,C_word *av) C_noret;
C_noret_decl(f_11096)
static void C_ccall f_11096(C_word c,C_word *av) C_noret;
C_noret_decl(f_11124)
static void C_ccall f_11124(C_word c,C_word *av) C_noret;
C_noret_decl(f_11157)
static void C_ccall f_11157(C_word c,C_word *av) C_noret;
C_noret_decl(f_11168)
static void C_ccall f_11168(C_word c,C_word *av) C_noret;
C_noret_decl(f_11181)
static void C_ccall f_11181(C_word c,C_word *av) C_noret;
C_noret_decl(f_11214)
static void C_ccall f_11214(C_word c,C_word *av) C_noret;
C_noret_decl(f_11221)
static void C_ccall f_11221(C_word c,C_word *av) C_noret;
C_noret_decl(f_11223)
static void C_fcall f_11223(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7) C_noret;
C_noret_decl(f_11227)
static void C_ccall f_11227(C_word c,C_word *av) C_noret;
C_noret_decl(f_11231)
static void C_ccall f_11231(C_word c,C_word *av) C_noret;
C_noret_decl(f_11237)
static void C_ccall f_11237(C_word c,C_word *av) C_noret;
C_noret_decl(f_11243)
static void C_fcall f_11243(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11249)
static void C_ccall f_11249(C_word c,C_word *av) C_noret;
C_noret_decl(f_11252)
static void C_ccall f_11252(C_word c,C_word *av) C_noret;
C_noret_decl(f_11258)
static void C_ccall f_11258(C_word c,C_word *av) C_noret;
C_noret_decl(f_11261)
static void C_ccall f_11261(C_word c,C_word *av) C_noret;
C_noret_decl(f_11262)
static void C_fcall f_11262(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11269)
static void C_ccall f_11269(C_word c,C_word *av) C_noret;
C_noret_decl(f_11272)
static void C_ccall f_11272(C_word c,C_word *av) C_noret;
C_noret_decl(f_11278)
static void C_ccall f_11278(C_word c,C_word *av) C_noret;
C_noret_decl(f_11293)
static void C_ccall f_11293(C_word c,C_word *av) C_noret;
C_noret_decl(f_11335)
static void C_ccall f_11335(C_word c,C_word *av) C_noret;
C_noret_decl(f_11341)
static void C_ccall f_11341(C_word c,C_word *av) C_noret;
C_noret_decl(f_11350)
static void C_ccall f_11350(C_word c,C_word *av) C_noret;
C_noret_decl(f_11353)
static void C_ccall f_11353(C_word c,C_word *av) C_noret;
C_noret_decl(f_11359)
static void C_ccall f_11359(C_word c,C_word *av) C_noret;
C_noret_decl(f_11362)
static void C_ccall f_11362(C_word c,C_word *av) C_noret;
C_noret_decl(f_11370)
static void C_ccall f_11370(C_word c,C_word *av) C_noret;
C_noret_decl(f_11377)
static void C_ccall f_11377(C_word c,C_word *av) C_noret;
C_noret_decl(f_11381)
static void C_ccall f_11381(C_word c,C_word *av) C_noret;
C_noret_decl(f_11389)
static void C_ccall f_11389(C_word c,C_word *av) C_noret;
C_noret_decl(f_11394)
static void C_fcall f_11394(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11417)
static void C_fcall f_11417(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11444)
static void C_ccall f_11444(C_word c,C_word *av) C_noret;
C_noret_decl(f_11448)
static void C_ccall f_11448(C_word c,C_word *av) C_noret;
C_noret_decl(f_11452)
static void C_ccall f_11452(C_word c,C_word *av) C_noret;
C_noret_decl(f_11456)
static void C_ccall f_11456(C_word c,C_word *av) C_noret;
C_noret_decl(f_11460)
static void C_ccall f_11460(C_word c,C_word *av) C_noret;
C_noret_decl(f_11477)
static void C_ccall f_11477(C_word c,C_word *av) C_noret;
C_noret_decl(f_11486)
static void C_fcall f_11486(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11496)
static void C_ccall f_11496(C_word c,C_word *av) C_noret;
C_noret_decl(f_11509)
static void C_ccall f_11509(C_word c,C_word *av) C_noret;
C_noret_decl(f_11520)
static void C_ccall f_11520(C_word c,C_word *av) C_noret;
C_noret_decl(f_11522)
static void C_ccall f_11522(C_word c,C_word *av) C_noret;
C_noret_decl(f_11536)
static void C_fcall f_11536(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11540)
static void C_ccall f_11540(C_word c,C_word *av) C_noret;
C_noret_decl(f_11543)
static void C_ccall f_11543(C_word c,C_word *av) C_noret;
C_noret_decl(f_11546)
static void C_ccall f_11546(C_word c,C_word *av) C_noret;
C_noret_decl(f_11561)
static void C_ccall f_11561(C_word c,C_word *av) C_noret;
C_noret_decl(f_11564)
static void C_ccall f_11564(C_word c,C_word *av) C_noret;
C_noret_decl(f_11589)
static void C_ccall f_11589(C_word c,C_word *av) C_noret;
C_noret_decl(f_11592)
static void C_ccall f_11592(C_word c,C_word *av) C_noret;
C_noret_decl(f_11610)
static void C_fcall f_11610(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11620)
static void C_ccall f_11620(C_word c,C_word *av) C_noret;
C_noret_decl(f_11623)
static void C_ccall f_11623(C_word c,C_word *av) C_noret;
C_noret_decl(f_11626)
static void C_ccall f_11626(C_word c,C_word *av) C_noret;
C_noret_decl(f_11637)
static void C_ccall f_11637(C_word c,C_word *av) C_noret;
C_noret_decl(f_11649)
static void C_ccall f_11649(C_word c,C_word *av) C_noret;
C_noret_decl(f_11657)
static void C_ccall f_11657(C_word c,C_word *av) C_noret;
C_noret_decl(f_11661)
static void C_ccall f_11661(C_word c,C_word *av) C_noret;
C_noret_decl(f_11684)
static void C_ccall f_11684(C_word c,C_word *av) C_noret;
C_noret_decl(f_11687)
static void C_ccall f_11687(C_word c,C_word *av) C_noret;
C_noret_decl(f_11709)
static void C_ccall f_11709(C_word c,C_word *av) C_noret;
C_noret_decl(f_11734)
static void C_ccall f_11734(C_word c,C_word *av) C_noret;
C_noret_decl(f_11749)
static void C_fcall f_11749(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11759)
static void C_ccall f_11759(C_word c,C_word *av) C_noret;
C_noret_decl(f_11778)
static void C_fcall f_11778(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11788)
static void C_ccall f_11788(C_word c,C_word *av) C_noret;
C_noret_decl(f_11807)
static void C_ccall f_11807(C_word c,C_word *av) C_noret;
C_noret_decl(f_11847)
static void C_ccall f_11847(C_word c,C_word *av) C_noret;
C_noret_decl(f_11849)
static void C_ccall f_11849(C_word c,C_word *av) C_noret;
C_noret_decl(f_11857)
static void C_ccall f_11857(C_word c,C_word *av) C_noret;
C_noret_decl(f_11859)
static void C_ccall f_11859(C_word c,C_word *av) C_noret;
C_noret_decl(f_11869)
static void C_ccall f_11869(C_word c,C_word *av) C_noret;
C_noret_decl(f_11872)
static void C_ccall f_11872(C_word c,C_word *av) C_noret;
C_noret_decl(f_11874)
static void C_ccall f_11874(C_word c,C_word *av) C_noret;
C_noret_decl(f_11877)
static C_word C_fcall f_11877(C_word *a,C_word t0);
C_noret_decl(f_11921)
static void C_ccall f_11921(C_word c,C_word *av) C_noret;
C_noret_decl(f_11925)
static void C_ccall f_11925(C_word c,C_word *av) C_noret;
C_noret_decl(f_11927)
static void C_fcall f_11927(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11931)
static void C_ccall f_11931(C_word c,C_word *av) C_noret;
C_noret_decl(f_11934)
static void C_ccall f_11934(C_word c,C_word *av) C_noret;
C_noret_decl(f_11937)
static void C_ccall f_11937(C_word c,C_word *av) C_noret;
C_noret_decl(f_11958)
static void C_fcall f_11958(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11972)
static void C_fcall f_11972(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11989)
static void C_ccall f_11989(C_word c,C_word *av) C_noret;
C_noret_decl(f_12041)
static void C_ccall f_12041(C_word c,C_word *av) C_noret;
C_noret_decl(f_12045)
static void C_ccall f_12045(C_word c,C_word *av) C_noret;
C_noret_decl(f_12049)
static void C_ccall f_12049(C_word c,C_word *av) C_noret;
C_noret_decl(f_12053)
static void C_ccall f_12053(C_word c,C_word *av) C_noret;
C_noret_decl(f_12057)
static void C_ccall f_12057(C_word c,C_word *av) C_noret;
C_noret_decl(f_12061)
static void C_ccall f_12061(C_word c,C_word *av) C_noret;
C_noret_decl(f_12071)
static void C_ccall f_12071(C_word c,C_word *av) C_noret;
C_noret_decl(f_12089)
static void C_ccall f_12089(C_word c,C_word *av) C_noret;
C_noret_decl(f_12095)
static void C_ccall f_12095(C_word c,C_word *av) C_noret;
C_noret_decl(f_12102)
static void C_ccall f_12102(C_word c,C_word *av) C_noret;
C_noret_decl(f_12112)
static void C_ccall f_12112(C_word c,C_word *av) C_noret;
C_noret_decl(f_12121)
static void C_fcall f_12121(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12133)
static void C_fcall f_12133(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12143)
static void C_ccall f_12143(C_word c,C_word *av) C_noret;
C_noret_decl(f_12166)
static void C_ccall f_12166(C_word c,C_word *av) C_noret;
C_noret_decl(f_12169)
static void C_ccall f_12169(C_word c,C_word *av) C_noret;
C_noret_decl(f_12170)
static void C_fcall f_12170(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12178)
static void C_ccall f_12178(C_word c,C_word *av) C_noret;
C_noret_decl(f_12181)
static void C_ccall f_12181(C_word c,C_word *av) C_noret;
C_noret_decl(f_12185)
static void C_fcall f_12185(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12195)
static void C_ccall f_12195(C_word c,C_word *av) C_noret;
C_noret_decl(f_12207)
static void C_ccall f_12207(C_word c,C_word *av) C_noret;
C_noret_decl(f_12212)
static void C_ccall f_12212(C_word c,C_word *av) C_noret;
C_noret_decl(f_12221)
static void C_ccall f_12221(C_word c,C_word *av) C_noret;
C_noret_decl(f_12228)
static void C_ccall f_12228(C_word c,C_word *av) C_noret;
C_noret_decl(f_12232)
static void C_ccall f_12232(C_word c,C_word *av) C_noret;
C_noret_decl(f_12234)
static void C_fcall f_12234(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12259)
static void C_ccall f_12259(C_word c,C_word *av) C_noret;
C_noret_decl(f_12270)
static void C_ccall f_12270(C_word c,C_word *av) C_noret;
C_noret_decl(f_12274)
static void C_ccall f_12274(C_word c,C_word *av) C_noret;
C_noret_decl(f_12280)
static void C_ccall f_12280(C_word c,C_word *av) C_noret;
C_noret_decl(f_12283)
static void C_ccall f_12283(C_word c,C_word *av) C_noret;
C_noret_decl(f_12286)
static void C_ccall f_12286(C_word c,C_word *av) C_noret;
C_noret_decl(f_12289)
static void C_ccall f_12289(C_word c,C_word *av) C_noret;
C_noret_decl(f_12292)
static void C_ccall f_12292(C_word c,C_word *av) C_noret;
C_noret_decl(f_12295)
static void C_ccall f_12295(C_word c,C_word *av) C_noret;
C_noret_decl(f_12296)
static void C_fcall f_12296(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12300)
static void C_ccall f_12300(C_word c,C_word *av) C_noret;
C_noret_decl(f_12301)
static void C_fcall f_12301(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12315)
static void C_ccall f_12315(C_word c,C_word *av) C_noret;
C_noret_decl(f_12319)
static void C_ccall f_12319(C_word c,C_word *av) C_noret;
C_noret_decl(f_12323)
static void C_ccall f_12323(C_word c,C_word *av) C_noret;
C_noret_decl(f_12327)
static void C_ccall f_12327(C_word c,C_word *av) C_noret;
C_noret_decl(f_12331)
static void C_ccall f_12331(C_word c,C_word *av) C_noret;
C_noret_decl(f_12335)
static void C_ccall f_12335(C_word c,C_word *av) C_noret;
C_noret_decl(f_12343)
static void C_ccall f_12343(C_word c,C_word *av) C_noret;
C_noret_decl(f_12353)
static void C_ccall f_12353(C_word c,C_word *av) C_noret;
C_noret_decl(f_12365)
static void C_ccall f_12365(C_word c,C_word *av) C_noret;
C_noret_decl(f_12373)
static void C_fcall f_12373(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12383)
static void C_ccall f_12383(C_word c,C_word *av) C_noret;
C_noret_decl(f_12403)
static void C_fcall f_12403(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12413)
static void C_ccall f_12413(C_word c,C_word *av) C_noret;
C_noret_decl(f_12426)
static void C_fcall f_12426(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12436)
static void C_fcall f_12436(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12446)
static void C_ccall f_12446(C_word c,C_word *av) C_noret;
C_noret_decl(f_12458)
static void C_ccall f_12458(C_word c,C_word *av) C_noret;
C_noret_decl(f_12462)
static void C_ccall f_12462(C_word c,C_word *av) C_noret;
C_noret_decl(f_12474)
static void C_ccall f_12474(C_word c,C_word *av) C_noret;
C_noret_decl(f_12478)
static void C_ccall f_12478(C_word c,C_word *av) C_noret;
C_noret_decl(f_12482)
static void C_ccall f_12482(C_word c,C_word *av) C_noret;
C_noret_decl(f_12486)
static void C_ccall f_12486(C_word c,C_word *av) C_noret;
C_noret_decl(f_12490)
static void C_ccall f_12490(C_word c,C_word *av) C_noret;
C_noret_decl(f_12494)
static void C_ccall f_12494(C_word c,C_word *av) C_noret;
C_noret_decl(f_12502)
static void C_ccall f_12502(C_word c,C_word *av) C_noret;
C_noret_decl(f_12504)
static void C_ccall f_12504(C_word c,C_word *av) C_noret;
C_noret_decl(f_12520)
static void C_ccall f_12520(C_word c,C_word *av) C_noret;
C_noret_decl(f_12532)
static void C_ccall f_12532(C_word c,C_word *av) C_noret;
C_noret_decl(f_12540)
static void C_ccall f_12540(C_word c,C_word *av) C_noret;
C_noret_decl(f_12548)
static void C_ccall f_12548(C_word c,C_word *av) C_noret;
C_noret_decl(f_12556)
static void C_ccall f_12556(C_word c,C_word *av) C_noret;
C_noret_decl(f_12558)
static void C_ccall f_12558(C_word c,C_word *av) C_noret;
C_noret_decl(f_12566)
static void C_ccall f_12566(C_word c,C_word *av) C_noret;
C_noret_decl(f_12570)
static void C_ccall f_12570(C_word c,C_word *av) C_noret;
C_noret_decl(f_12576)
static void C_fcall f_12576(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12601)
static void C_ccall f_12601(C_word c,C_word *av) C_noret;
C_noret_decl(f_12605)
static void C_ccall f_12605(C_word c,C_word *av) C_noret;
C_noret_decl(f_12625)
static void C_ccall f_12625(C_word c,C_word *av) C_noret;
C_noret_decl(f_12631)
static void C_ccall f_12631(C_word c,C_word *av) C_noret;
C_noret_decl(f_12635)
static void C_ccall f_12635(C_word c,C_word *av) C_noret;
C_noret_decl(f_12648)
static void C_ccall f_12648(C_word c,C_word *av) C_noret;
C_noret_decl(f_12652)
static void C_ccall f_12652(C_word c,C_word *av) C_noret;
C_noret_decl(f_12656)
static void C_ccall f_12656(C_word c,C_word *av) C_noret;
C_noret_decl(f_12660)
static void C_ccall f_12660(C_word c,C_word *av) C_noret;
C_noret_decl(f_12667)
static void C_ccall f_12667(C_word c,C_word *av) C_noret;
C_noret_decl(f_12669)
static void C_fcall f_12669(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12705)
static void C_ccall f_12705(C_word c,C_word *av) C_noret;
C_noret_decl(f_12711)
static void C_ccall f_12711(C_word c,C_word *av) C_noret;
C_noret_decl(f_12734)
static void C_ccall f_12734(C_word c,C_word *av) C_noret;
C_noret_decl(f_12736)
static void C_fcall f_12736(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12770)
static void C_fcall f_12770(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12795)
static void C_ccall f_12795(C_word c,C_word *av) C_noret;
C_noret_decl(f_12808)
static void C_ccall f_12808(C_word c,C_word *av) C_noret;
C_noret_decl(f_12817)
static void C_fcall f_12817(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12827)
static void C_ccall f_12827(C_word c,C_word *av) C_noret;
C_noret_decl(f_12856)
static void C_ccall f_12856(C_word c,C_word *av) C_noret;
C_noret_decl(f_12878)
static void C_ccall f_12878(C_word c,C_word *av) C_noret;
C_noret_decl(f_12896)
static void C_ccall f_12896(C_word c,C_word *av) C_noret;
C_noret_decl(f_12904)
static void C_ccall f_12904(C_word c,C_word *av) C_noret;
C_noret_decl(f_12906)
static void C_fcall f_12906(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12914)
static void C_fcall f_12914(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12926)
static void C_ccall f_12926(C_word c,C_word *av) C_noret;
C_noret_decl(f_12930)
static void C_ccall f_12930(C_word c,C_word *av) C_noret;
C_noret_decl(f_12938)
static void C_ccall f_12938(C_word c,C_word *av) C_noret;
C_noret_decl(f_12942)
static void C_ccall f_12942(C_word c,C_word *av) C_noret;
C_noret_decl(f_12953)
static void C_ccall f_12953(C_word c,C_word *av) C_noret;
C_noret_decl(f_12972)
static void C_ccall f_12972(C_word c,C_word *av) C_noret;
C_noret_decl(f_12976)
static void C_ccall f_12976(C_word c,C_word *av) C_noret;
C_noret_decl(f_13002)
static void C_ccall f_13002(C_word c,C_word *av) C_noret;
C_noret_decl(f_13017)
static void C_ccall f_13017(C_word c,C_word *av) C_noret;
C_noret_decl(f_13021)
static void C_ccall f_13021(C_word c,C_word *av) C_noret;
C_noret_decl(f_13083)
static void C_ccall f_13083(C_word c,C_word *av) C_noret;
C_noret_decl(f_13098)
static void C_fcall f_13098(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_13115)
static void C_ccall f_13115(C_word c,C_word *av) C_noret;
C_noret_decl(f_13121)
static void C_fcall f_13121(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13134)
static void C_ccall f_13134(C_word c,C_word *av) C_noret;
C_noret_decl(f_13163)
static void C_ccall f_13163(C_word c,C_word *av) C_noret;
C_noret_decl(f_13169)
static void C_ccall f_13169(C_word c,C_word *av) C_noret;
C_noret_decl(f_13182)
static void C_ccall f_13182(C_word c,C_word *av) C_noret;
C_noret_decl(f_13216)
static void C_ccall f_13216(C_word c,C_word *av) C_noret;
C_noret_decl(f_13243)
static void C_fcall f_13243(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_13264)
static void C_ccall f_13264(C_word c,C_word *av) C_noret;
C_noret_decl(f_13268)
static void C_ccall f_13268(C_word c,C_word *av) C_noret;
C_noret_decl(f_13276)
static void C_ccall f_13276(C_word c,C_word *av) C_noret;
C_noret_decl(f_13282)
static void C_fcall f_13282(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13295)
static void C_ccall f_13295(C_word c,C_word *av) C_noret;
C_noret_decl(f_13324)
static void C_ccall f_13324(C_word c,C_word *av) C_noret;
C_noret_decl(f_13330)
static void C_ccall f_13330(C_word c,C_word *av) C_noret;
C_noret_decl(f_13343)
static void C_ccall f_13343(C_word c,C_word *av) C_noret;
C_noret_decl(f_13347)
static void C_ccall f_13347(C_word c,C_word *av) C_noret;
C_noret_decl(f_13401)
static void C_ccall f_13401(C_word c,C_word *av) C_noret;
C_noret_decl(f_13425)
static void C_ccall f_13425(C_word c,C_word *av) C_noret;
C_noret_decl(f_13438)
static void C_ccall f_13438(C_word c,C_word *av) C_noret;
C_noret_decl(f_13446)
static void C_ccall f_13446(C_word c,C_word *av) C_noret;
C_noret_decl(f_13484)
static void C_ccall f_13484(C_word c,C_word *av) C_noret;
C_noret_decl(f_13494)
static void C_fcall f_13494(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13498)
static void C_ccall f_13498(C_word c,C_word *av) C_noret;
C_noret_decl(f_13501)
static void C_ccall f_13501(C_word c,C_word *av) C_noret;
C_noret_decl(f_13504)
static void C_ccall f_13504(C_word c,C_word *av) C_noret;
C_noret_decl(f_13534)
static void C_ccall f_13534(C_word c,C_word *av) C_noret;
C_noret_decl(f_13537)
static void C_ccall f_13537(C_word c,C_word *av) C_noret;
C_noret_decl(f_13540)
static void C_ccall f_13540(C_word c,C_word *av) C_noret;
C_noret_decl(f_13570)
static void C_ccall f_13570(C_word c,C_word *av) C_noret;
C_noret_decl(f_13597)
static void C_fcall f_13597(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_13601)
static void C_ccall f_13601(C_word c,C_word *av) C_noret;
C_noret_decl(f_13604)
static void C_ccall f_13604(C_word c,C_word *av) C_noret;
C_noret_decl(f_13607)
static void C_ccall f_13607(C_word c,C_word *av) C_noret;
C_noret_decl(f_13613)
static void C_fcall f_13613(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13636)
static void C_ccall f_13636(C_word c,C_word *av) C_noret;
C_noret_decl(f_13651)
static void C_ccall f_13651(C_word c,C_word *av) C_noret;
C_noret_decl(f_13659)
static void C_ccall f_13659(C_word c,C_word *av) C_noret;
C_noret_decl(f_13661)
static void C_ccall f_13661(C_word c,C_word *av) C_noret;
C_noret_decl(f_13711)
static void C_ccall f_13711(C_word c,C_word *av) C_noret;
C_noret_decl(f_13719)
static void C_ccall f_13719(C_word c,C_word *av) C_noret;
C_noret_decl(f_13727)
static void C_ccall f_13727(C_word c,C_word *av) C_noret;
C_noret_decl(f_13735)
static void C_ccall f_13735(C_word c,C_word *av) C_noret;
C_noret_decl(f_13763)
static void C_ccall f_13763(C_word c,C_word *av) C_noret;
C_noret_decl(f_13771)
static void C_ccall f_13771(C_word c,C_word *av) C_noret;
C_noret_decl(f_13797)
static void C_ccall f_13797(C_word c,C_word *av) C_noret;
C_noret_decl(f_13810)
static void C_ccall f_13810(C_word c,C_word *av) C_noret;
C_noret_decl(f_13827)
static void C_ccall f_13827(C_word c,C_word *av) C_noret;
C_noret_decl(f_13831)
static void C_ccall f_13831(C_word c,C_word *av) C_noret;
C_noret_decl(f_13835)
static void C_ccall f_13835(C_word c,C_word *av) C_noret;
C_noret_decl(f_13846)
static void C_ccall f_13846(C_word c,C_word *av) C_noret;
C_noret_decl(f_13850)
static void C_ccall f_13850(C_word c,C_word *av) C_noret;
C_noret_decl(f_13924)
static void C_ccall f_13924(C_word c,C_word *av) C_noret;
C_noret_decl(f_13937)
static void C_ccall f_13937(C_word c,C_word *av) C_noret;
C_noret_decl(f_13943)
static void C_ccall f_13943(C_word c,C_word *av) C_noret;
C_noret_decl(f_13966)
static void C_ccall f_13966(C_word c,C_word *av) C_noret;
C_noret_decl(f_13970)
static void C_ccall f_13970(C_word c,C_word *av) C_noret;
C_noret_decl(f_13974)
static void C_ccall f_13974(C_word c,C_word *av) C_noret;
C_noret_decl(f_13983)
static void C_ccall f_13983(C_word c,C_word *av) C_noret;
C_noret_decl(f_13992)
static void C_ccall f_13992(C_word c,C_word *av) C_noret;
C_noret_decl(f_13996)
static void C_ccall f_13996(C_word c,C_word *av) C_noret;
C_noret_decl(f_14094)
static void C_ccall f_14094(C_word c,C_word *av) C_noret;
C_noret_decl(f_14102)
static void C_ccall f_14102(C_word c,C_word *av) C_noret;
C_noret_decl(f_14107)
static void C_fcall f_14107(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14117)
static void C_ccall f_14117(C_word c,C_word *av) C_noret;
C_noret_decl(f_14121)
static C_word C_fcall f_14121(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_3389)
static void C_ccall f_3389(C_word c,C_word *av) C_noret;
C_noret_decl(f_3392)
static void C_ccall f_3392(C_word c,C_word *av) C_noret;
C_noret_decl(f_3395)
static void C_ccall f_3395(C_word c,C_word *av) C_noret;
C_noret_decl(f_3398)
static void C_ccall f_3398(C_word c,C_word *av) C_noret;
C_noret_decl(f_3401)
static void C_ccall f_3401(C_word c,C_word *av) C_noret;
C_noret_decl(f_3409)
static void C_fcall f_3409(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_3423)
static void C_ccall f_3423(C_word c,C_word *av) C_noret;
C_noret_decl(f_3427)
static void C_ccall f_3427(C_word c,C_word *av) C_noret;
C_noret_decl(f_3433)
static void C_ccall f_3433(C_word c,C_word *av) C_noret;
C_noret_decl(f_3511)
static void C_fcall f_3511(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3529)
static void C_ccall f_3529(C_word c,C_word *av) C_noret;
C_noret_decl(f_3563)
static void C_fcall f_3563(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3569)
static void C_fcall f_3569(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_3583)
static void C_ccall f_3583(C_word c,C_word *av) C_noret;
C_noret_decl(f_3602)
static void C_fcall f_3602(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_3617)
static void C_fcall f_3617(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3625)
static void C_fcall f_3625(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_3633)
static void C_ccall f_3633(C_word c,C_word *av) C_noret;
C_noret_decl(f_3644)
static void C_ccall f_3644(C_word c,C_word *av) C_noret;
C_noret_decl(f_3657)
static void C_fcall f_3657(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3664)
static void C_ccall f_3664(C_word c,C_word *av) C_noret;
C_noret_decl(f_3671)
static void C_ccall f_3671(C_word c,C_word *av) C_noret;
C_noret_decl(f_3675)
static void C_ccall f_3675(C_word c,C_word *av) C_noret;
C_noret_decl(f_3687)
static void C_ccall f_3687(C_word c,C_word *av) C_noret;
C_noret_decl(f_3689)
static void C_fcall f_3689(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3736)
static void C_ccall f_3736(C_word c,C_word *av) C_noret;
C_noret_decl(f_3738)
static void C_fcall f_3738(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3772)
static void C_fcall f_3772(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3778)
static void C_fcall f_3778(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3800)
static void C_ccall f_3800(C_word c,C_word *av) C_noret;
C_noret_decl(f_3806)
static void C_fcall f_3806(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3812)
static void C_fcall f_3812(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3822)
static void C_ccall f_3822(C_word c,C_word *av) C_noret;
C_noret_decl(f_3836)
static void C_fcall f_3836(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3842)
static void C_fcall f_3842(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_3856)
static void C_ccall f_3856(C_word c,C_word *av) C_noret;
C_noret_decl(f_3892)
static void C_fcall f_3892(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_3898)
static void C_fcall f_3898(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3911)
static void C_ccall f_3911(C_word c,C_word *av) C_noret;
C_noret_decl(f_3925)
static void C_ccall f_3925(C_word c,C_word *av) C_noret;
C_noret_decl(f_3933)
static void C_ccall f_3933(C_word c,C_word *av) C_noret;
C_noret_decl(f_3973)
static void C_fcall f_3973(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_3987)
static void C_ccall f_3987(C_word c,C_word *av) C_noret;
C_noret_decl(f_4000)
static void C_ccall f_4000(C_word c,C_word *av) C_noret;
C_noret_decl(f_4012)
static void C_fcall f_4012(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4021)
static void C_fcall f_4021(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4029)
static void C_fcall f_4029(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_4036)
static void C_ccall f_4036(C_word c,C_word *av) C_noret;
C_noret_decl(f_4050)
static void C_ccall f_4050(C_word c,C_word *av) C_noret;
C_noret_decl(f_4065)
static void C_fcall f_4065(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4073)
static void C_fcall f_4073(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_4077)
static void C_ccall f_4077(C_word c,C_word *av) C_noret;
C_noret_decl(f_4081)
static C_word C_fcall f_4081(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_4099)
static void C_ccall f_4099(C_word c,C_word *av) C_noret;
C_noret_decl(f_4138)
static void C_fcall f_4138(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4178)
static C_word C_fcall f_4178(C_word t0);
C_noret_decl(f_4237)
static void C_fcall f_4237(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_4414)
static void C_fcall f_4414(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4420)
static void C_fcall f_4420(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4434)
static void C_ccall f_4434(C_word c,C_word *av) C_noret;
C_noret_decl(f_4438)
static void C_ccall f_4438(C_word c,C_word *av) C_noret;
C_noret_decl(f_4450)
static void C_ccall f_4450(C_word c,C_word *av) C_noret;
C_noret_decl(f_4468)
static void C_ccall f_4468(C_word c,C_word *av) C_noret;
C_noret_decl(f_4683)
static void C_ccall f_4683(C_word c,C_word *av) C_noret;
C_noret_decl(f_4687)
static void C_ccall f_4687(C_word c,C_word *av) C_noret;
C_noret_decl(f_4691)
static void C_ccall f_4691(C_word c,C_word *av) C_noret;
C_noret_decl(f_4695)
static void C_ccall f_4695(C_word c,C_word *av) C_noret;
C_noret_decl(f_4697)
static void C_ccall f_4697(C_word c,C_word *av) C_noret;
C_noret_decl(f_4700)
static C_word C_fcall f_4700(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_4723)
static void C_fcall f_4723(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_4728)
static void C_ccall f_4728(C_word c,C_word *av) C_noret;
C_noret_decl(f_4730)
static C_word C_fcall f_4730(C_word t0);
C_noret_decl(f_4735)
static void C_fcall f_4735(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_4737)
static void C_fcall f_4737(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4753)
static void C_fcall f_4753(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_4763)
static void C_ccall f_4763(C_word c,C_word *av) C_noret;
C_noret_decl(f_4776)
static void C_fcall f_4776(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_4780)
static void C_ccall f_4780(C_word c,C_word *av) C_noret;
C_noret_decl(f_4783)
static void C_ccall f_4783(C_word c,C_word *av) C_noret;
C_noret_decl(f_4786)
static void C_ccall f_4786(C_word c,C_word *av) C_noret;
C_noret_decl(f_4798)
static void C_fcall f_4798(C_word t0,C_word t1) C_noret;
C_noret_decl(f_4802)
static void C_ccall f_4802(C_word c,C_word *av) C_noret;
C_noret_decl(f_4804)
static void C_ccall f_4804(C_word c,C_word *av) C_noret;
C_noret_decl(f_4846)
static void C_fcall f_4846(C_word t0,C_word t1) C_noret;
C_noret_decl(f_4849)
static void C_ccall f_4849(C_word c,C_word *av) C_noret;
C_noret_decl(f_4872)
static void C_ccall f_4872(C_word c,C_word *av) C_noret;
C_noret_decl(f_4883)
static void C_ccall f_4883(C_word c,C_word *av) C_noret;
C_noret_decl(f_4887)
static void C_ccall f_4887(C_word c,C_word *av) C_noret;
C_noret_decl(f_4920)
static void C_ccall f_4920(C_word c,C_word *av) C_noret;
C_noret_decl(f_4923)
static void C_ccall f_4923(C_word c,C_word *av) C_noret;
C_noret_decl(f_4926)
static void C_ccall f_4926(C_word c,C_word *av) C_noret;
C_noret_decl(f_4944)
static void C_ccall f_4944(C_word c,C_word *av) C_noret;
C_noret_decl(f_4951)
static void C_ccall f_4951(C_word c,C_word *av) C_noret;
C_noret_decl(f_4994)
static void C_ccall f_4994(C_word c,C_word *av) C_noret;
C_noret_decl(f_4997)
static void C_ccall f_4997(C_word c,C_word *av) C_noret;
C_noret_decl(f_5000)
static void C_ccall f_5000(C_word c,C_word *av) C_noret;
C_noret_decl(f_5013)
static void C_fcall f_5013(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5023)
static void C_ccall f_5023(C_word c,C_word *av) C_noret;
C_noret_decl(f_5044)
static void C_ccall f_5044(C_word c,C_word *av) C_noret;
C_noret_decl(f_5048)
static void C_ccall f_5048(C_word c,C_word *av) C_noret;
C_noret_decl(f_5053)
static void C_ccall f_5053(C_word c,C_word *av) C_noret;
C_noret_decl(f_5056)
static void C_fcall f_5056(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_5070)
static void C_ccall f_5070(C_word c,C_word *av) C_noret;
C_noret_decl(f_5080)
static void C_ccall f_5080(C_word c,C_word *av) C_noret;
C_noret_decl(f_5082)
static C_word C_fcall f_5082(C_word t0);
C_noret_decl(f_5086)
static void C_fcall f_5086(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5100)
static C_word C_fcall f_5100(C_word t0);
C_noret_decl(f_5123)
static void C_fcall f_5123(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5127)
static void C_ccall f_5127(C_word c,C_word *av) C_noret;
C_noret_decl(f_5130)
static void C_ccall f_5130(C_word c,C_word *av) C_noret;
C_noret_decl(f_5138)
static void C_ccall f_5138(C_word c,C_word *av) C_noret;
C_noret_decl(f_5148)
static void C_ccall f_5148(C_word c,C_word *av) C_noret;
C_noret_decl(f_5154)
static void C_ccall f_5154(C_word c,C_word *av) C_noret;
C_noret_decl(f_5193)
static C_word C_fcall f_5193(C_word t0,C_word t1);
C_noret_decl(f_5207)
static void C_ccall f_5207(C_word c,C_word *av) C_noret;
C_noret_decl(f_5209)
static void C_fcall f_5209(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5249)
static void C_ccall f_5249(C_word c,C_word *av) C_noret;
C_noret_decl(f_5251)
static void C_fcall f_5251(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5258)
static void C_ccall f_5258(C_word c,C_word *av) C_noret;
C_noret_decl(f_5270)
static void C_fcall f_5270(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5306)
static void C_ccall f_5306(C_word c,C_word *av) C_noret;
C_noret_decl(f_5328)
static void C_ccall f_5328(C_word c,C_word *av) C_noret;
C_noret_decl(f_5338)
static void C_ccall f_5338(C_word c,C_word *av) C_noret;
C_noret_decl(f_5350)
static void C_ccall f_5350(C_word c,C_word *av) C_noret;
C_noret_decl(f_5354)
static void C_ccall f_5354(C_word c,C_word *av) C_noret;
C_noret_decl(f_5358)
static void C_ccall f_5358(C_word c,C_word *av) C_noret;
C_noret_decl(f_5362)
static void C_ccall f_5362(C_word c,C_word *av) C_noret;
C_noret_decl(f_5366)
static void C_ccall f_5366(C_word c,C_word *av) C_noret;
C_noret_decl(f_5370)
static void C_ccall f_5370(C_word c,C_word *av) C_noret;
C_noret_decl(f_5374)
static void C_ccall f_5374(C_word c,C_word *av) C_noret;
C_noret_decl(f_5378)
static void C_ccall f_5378(C_word c,C_word *av) C_noret;
C_noret_decl(f_5382)
static void C_ccall f_5382(C_word c,C_word *av) C_noret;
C_noret_decl(f_5407)
static void C_ccall f_5407(C_word c,C_word *av) C_noret;
C_noret_decl(f_5411)
static void C_ccall f_5411(C_word c,C_word *av) C_noret;
C_noret_decl(f_5413)
static void C_fcall f_5413(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_5427)
static void C_ccall f_5427(C_word c,C_word *av) C_noret;
C_noret_decl(f_5430)
static void C_ccall f_5430(C_word c,C_word *av) C_noret;
C_noret_decl(f_5433)
static void C_ccall f_5433(C_word c,C_word *av) C_noret;
C_noret_decl(f_5436)
static void C_ccall f_5436(C_word c,C_word *av) C_noret;
C_noret_decl(f_5496)
static void C_ccall f_5496(C_word c,C_word *av) C_noret;
C_noret_decl(f_5509)
static void C_fcall f_5509(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5513)
static void C_ccall f_5513(C_word c,C_word *av) C_noret;
C_noret_decl(f_5520)
static void C_ccall f_5520(C_word c,C_word *av) C_noret;
C_noret_decl(f_5551)
static void C_fcall f_5551(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5555)
static void C_ccall f_5555(C_word c,C_word *av) C_noret;
C_noret_decl(f_5559)
static void C_fcall f_5559(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5563)
static void C_ccall f_5563(C_word c,C_word *av) C_noret;
C_noret_decl(f_5566)
static void C_ccall f_5566(C_word c,C_word *av) C_noret;
C_noret_decl(f_5571)
static void C_fcall f_5571(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_5575)
static void C_ccall f_5575(C_word c,C_word *av) C_noret;
C_noret_decl(f_5578)
static void C_ccall f_5578(C_word c,C_word *av) C_noret;
C_noret_decl(f_5581)
static void C_ccall f_5581(C_word c,C_word *av) C_noret;
C_noret_decl(f_5590)
static void C_ccall f_5590(C_word c,C_word *av) C_noret;
C_noret_decl(f_5596)
static void C_ccall f_5596(C_word c,C_word *av) C_noret;
C_noret_decl(f_5602)
static void C_ccall f_5602(C_word c,C_word *av) C_noret;
C_noret_decl(f_5613)
static void C_ccall f_5613(C_word c,C_word *av) C_noret;
C_noret_decl(f_5617)
static void C_ccall f_5617(C_word c,C_word *av) C_noret;
C_noret_decl(f_5640)
static void C_fcall f_5640(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5650)
static void C_fcall f_5650(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5653)
static void C_ccall f_5653(C_word c,C_word *av) C_noret;
C_noret_decl(f_5670)
static void C_ccall f_5670(C_word c,C_word *av) C_noret;
C_noret_decl(f_5703)
static void C_ccall f_5703(C_word c,C_word *av) C_noret;
C_noret_decl(f_5706)
static void C_fcall f_5706(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5721)
static void C_fcall f_5721(C_word t0,C_word t1) C_noret;
C_noret_decl(f_5729)
static void C_fcall f_5729(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5739)
static void C_ccall f_5739(C_word c,C_word *av) C_noret;
C_noret_decl(f_5741)
static void C_fcall f_5741(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5766)
static void C_ccall f_5766(C_word c,C_word *av) C_noret;
C_noret_decl(f_5776)
static void C_ccall f_5776(C_word c,C_word *av) C_noret;
C_noret_decl(f_5787)
static void C_ccall f_5787(C_word c,C_word *av) C_noret;
C_noret_decl(f_5805)
static void C_ccall f_5805(C_word c,C_word *av) C_noret;
C_noret_decl(f_5813)
static void C_ccall f_5813(C_word c,C_word *av) C_noret;
C_noret_decl(f_5823)
static void C_ccall f_5823(C_word c,C_word *av) C_noret;
C_noret_decl(f_5830)
static void C_ccall f_5830(C_word c,C_word *av) C_noret;
C_noret_decl(f_5848)
static void C_ccall f_5848(C_word c,C_word *av) C_noret;
C_noret_decl(f_5853)
static void C_ccall f_5853(C_word c,C_word *av) C_noret;
C_noret_decl(f_5859)
static void C_ccall f_5859(C_word c,C_word *av) C_noret;
C_noret_decl(f_5865)
static void C_fcall f_5865(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_5871)
static void C_ccall f_5871(C_word c,C_word *av) C_noret;
C_noret_decl(f_5878)
static void C_ccall f_5878(C_word c,C_word *av) C_noret;
C_noret_decl(f_5893)
static void C_ccall f_5893(C_word c,C_word *av) C_noret;
C_noret_decl(f_5913)
static void C_ccall f_5913(C_word c,C_word *av) C_noret;
C_noret_decl(f_5920)
static void C_ccall f_5920(C_word c,C_word *av) C_noret;
C_noret_decl(f_5923)
static void C_ccall f_5923(C_word c,C_word *av) C_noret;
C_noret_decl(f_5940)
static void C_ccall f_5940(C_word c,C_word *av) C_noret;
C_noret_decl(f_5945)
static void C_ccall f_5945(C_word c,C_word *av) C_noret;
C_noret_decl(f_5952)
static void C_ccall f_5952(C_word c,C_word *av) C_noret;
C_noret_decl(f_5967)
static void C_ccall f_5967(C_word c,C_word *av) C_noret;
C_noret_decl(f_5987)
static void C_ccall f_5987(C_word c,C_word *av) C_noret;
C_noret_decl(f_6021)
static void C_ccall f_6021(C_word c,C_word *av) C_noret;
C_noret_decl(f_6033)
static void C_ccall f_6033(C_word c,C_word *av) C_noret;
C_noret_decl(f_6036)
static void C_ccall f_6036(C_word c,C_word *av) C_noret;
C_noret_decl(f_6043)
static void C_fcall f_6043(C_word t0,C_word t1) C_noret;
C_noret_decl(f_6046)
static void C_ccall f_6046(C_word c,C_word *av) C_noret;
C_noret_decl(f_6055)
static void C_ccall f_6055(C_word c,C_word *av) C_noret;
C_noret_decl(f_6058)
static void C_ccall f_6058(C_word c,C_word *av) C_noret;
C_noret_decl(f_6062)
static void C_fcall f_6062(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6072)
static void C_ccall f_6072(C_word c,C_word *av) C_noret;
C_noret_decl(f_6079)
static void C_ccall f_6079(C_word c,C_word *av) C_noret;
C_noret_decl(f_6087)
static void C_ccall f_6087(C_word c,C_word *av) C_noret;
C_noret_decl(f_6089)
static void C_fcall f_6089(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6099)
static void C_ccall f_6099(C_word c,C_word *av) C_noret;
C_noret_decl(f_6113)
static void C_ccall f_6113(C_word c,C_word *av) C_noret;
C_noret_decl(f_6122)
static void C_ccall f_6122(C_word c,C_word *av) C_noret;
C_noret_decl(f_6125)
static void C_fcall f_6125(C_word t0,C_word t1) C_noret;
C_noret_decl(f_6128)
static void C_ccall f_6128(C_word c,C_word *av) C_noret;
C_noret_decl(f_6147)
static void C_ccall f_6147(C_word c,C_word *av) C_noret;
C_noret_decl(f_6153)
static void C_fcall f_6153(C_word t0,C_word t1) C_noret;
C_noret_decl(f_6156)
static void C_ccall f_6156(C_word c,C_word *av) C_noret;
C_noret_decl(f_6164)
static void C_ccall f_6164(C_word c,C_word *av) C_noret;
C_noret_decl(f_6171)
static void C_ccall f_6171(C_word c,C_word *av) C_noret;
C_noret_decl(f_6177)
static void C_fcall f_6177(C_word t0,C_word t1) C_noret;
C_noret_decl(f_6183)
static void C_ccall f_6183(C_word c,C_word *av) C_noret;
C_noret_decl(f_6186)
static void C_ccall f_6186(C_word c,C_word *av) C_noret;
C_noret_decl(f_6187)
static void C_fcall f_6187(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6197)
static void C_ccall f_6197(C_word c,C_word *av) C_noret;
C_noret_decl(f_6200)
static void C_ccall f_6200(C_word c,C_word *av) C_noret;
C_noret_decl(f_6205)
static void C_ccall f_6205(C_word c,C_word *av) C_noret;
C_noret_decl(f_6208)
static void C_ccall f_6208(C_word c,C_word *av) C_noret;
C_noret_decl(f_6212)
static void C_ccall f_6212(C_word c,C_word *av) C_noret;
C_noret_decl(f_6219)
static void C_ccall f_6219(C_word c,C_word *av) C_noret;
C_noret_decl(f_6222)
static void C_ccall f_6222(C_word c,C_word *av) C_noret;
C_noret_decl(f_6244)
static void C_ccall f_6244(C_word c,C_word *av) C_noret;
C_noret_decl(f_6246)
static void C_fcall f_6246(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6256)
static void C_ccall f_6256(C_word c,C_word *av) C_noret;
C_noret_decl(f_6278)
static void C_ccall f_6278(C_word c,C_word *av) C_noret;
C_noret_decl(f_6287)
static void C_ccall f_6287(C_word c,C_word *av) C_noret;
C_noret_decl(f_6301)
static void C_fcall f_6301(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_6318)
static void C_fcall f_6318(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6328)
static void C_ccall f_6328(C_word c,C_word *av) C_noret;
C_noret_decl(f_6331)
static void C_ccall f_6331(C_word c,C_word *av) C_noret;
C_noret_decl(f_6336)
static void C_fcall f_6336(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6361)
static void C_ccall f_6361(C_word c,C_word *av) C_noret;
C_noret_decl(f_6372)
static void C_ccall f_6372(C_word c,C_word *av) C_noret;
C_noret_decl(f_6376)
static void C_ccall f_6376(C_word c,C_word *av) C_noret;
C_noret_decl(f_6382)
static void C_ccall f_6382(C_word c,C_word *av) C_noret;
C_noret_decl(f_6388)
static void C_ccall f_6388(C_word c,C_word *av) C_noret;
C_noret_decl(f_6394)
static void C_ccall f_6394(C_word c,C_word *av) C_noret;
C_noret_decl(f_6409)
static void C_ccall f_6409(C_word c,C_word *av) C_noret;
C_noret_decl(f_6413)
static void C_ccall f_6413(C_word c,C_word *av) C_noret;
C_noret_decl(f_6425)
static void C_ccall f_6425(C_word c,C_word *av) C_noret;
C_noret_decl(f_6475)
static void C_ccall f_6475(C_word c,C_word *av) C_noret;
C_noret_decl(f_6487)
static void C_ccall f_6487(C_word c,C_word *av) C_noret;
C_noret_decl(f_6492)
static void C_ccall f_6492(C_word c,C_word *av) C_noret;
C_noret_decl(f_6498)
static void C_ccall f_6498(C_word c,C_word *av) C_noret;
C_noret_decl(f_6502)
static void C_ccall f_6502(C_word c,C_word *av) C_noret;
C_noret_decl(f_6509)
static void C_ccall f_6509(C_word c,C_word *av) C_noret;
C_noret_decl(f_6514)
static void C_fcall f_6514(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6524)
static void C_ccall f_6524(C_word c,C_word *av) C_noret;
C_noret_decl(f_6526)
static void C_fcall f_6526(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6551)
static void C_ccall f_6551(C_word c,C_word *av) C_noret;
C_noret_decl(f_6562)
static void C_ccall f_6562(C_word c,C_word *av) C_noret;
C_noret_decl(f_6570)
static void C_ccall f_6570(C_word c,C_word *av) C_noret;
C_noret_decl(f_6599)
static void C_ccall f_6599(C_word c,C_word *av) C_noret;
C_noret_decl(f_6612)
static void C_ccall f_6612(C_word c,C_word *av) C_noret;
C_noret_decl(f_6630)
static void C_ccall f_6630(C_word c,C_word *av) C_noret;
C_noret_decl(f_6636)
static void C_ccall f_6636(C_word c,C_word *av) C_noret;
C_noret_decl(f_6642)
static void C_ccall f_6642(C_word c,C_word *av) C_noret;
C_noret_decl(f_6667)
static void C_ccall f_6667(C_word c,C_word *av) C_noret;
C_noret_decl(f_6671)
static void C_ccall f_6671(C_word c,C_word *av) C_noret;
C_noret_decl(f_6675)
static void C_ccall f_6675(C_word c,C_word *av) C_noret;
C_noret_decl(f_6681)
static void C_ccall f_6681(C_word c,C_word *av) C_noret;
C_noret_decl(f_6684)
static void C_ccall f_6684(C_word c,C_word *av) C_noret;
C_noret_decl(f_6691)
static void C_ccall f_6691(C_word c,C_word *av) C_noret;
C_noret_decl(f_6705)
static void C_ccall f_6705(C_word c,C_word *av) C_noret;
C_noret_decl(f_6725)
static void C_ccall f_6725(C_word c,C_word *av) C_noret;
C_noret_decl(f_6729)
static void C_ccall f_6729(C_word c,C_word *av) C_noret;
C_noret_decl(f_6736)
static void C_ccall f_6736(C_word c,C_word *av) C_noret;
C_noret_decl(f_6751)
static void C_ccall f_6751(C_word c,C_word *av) C_noret;
C_noret_decl(f_6769)
static void C_ccall f_6769(C_word c,C_word *av) C_noret;
C_noret_decl(f_6772)
static void C_fcall f_6772(C_word t0,C_word t1) C_noret;
C_noret_decl(f_6782)
static void C_ccall f_6782(C_word c,C_word *av) C_noret;
C_noret_decl(f_6784)
static void C_ccall f_6784(C_word c,C_word *av) C_noret;
C_noret_decl(f_6803)
static void C_ccall f_6803(C_word c,C_word *av) C_noret;
C_noret_decl(f_6809)
static void C_ccall f_6809(C_word c,C_word *av) C_noret;
C_noret_decl(f_6819)
static void C_ccall f_6819(C_word c,C_word *av) C_noret;
C_noret_decl(f_6823)
static void C_ccall f_6823(C_word c,C_word *av) C_noret;
C_noret_decl(f_6833)
static void C_ccall f_6833(C_word c,C_word *av) C_noret;
C_noret_decl(f_6837)
static void C_ccall f_6837(C_word c,C_word *av) C_noret;
C_noret_decl(f_6843)
static void C_ccall f_6843(C_word c,C_word *av) C_noret;
C_noret_decl(f_6850)
static void C_ccall f_6850(C_word c,C_word *av) C_noret;
C_noret_decl(f_6863)
static void C_ccall f_6863(C_word c,C_word *av) C_noret;
C_noret_decl(f_6871)
static void C_ccall f_6871(C_word c,C_word *av) C_noret;
C_noret_decl(f_6875)
static void C_ccall f_6875(C_word c,C_word *av) C_noret;
C_noret_decl(f_6881)
static void C_ccall f_6881(C_word c,C_word *av) C_noret;
C_noret_decl(f_6891)
static void C_ccall f_6891(C_word c,C_word *av) C_noret;
C_noret_decl(f_6895)
static void C_ccall f_6895(C_word c,C_word *av) C_noret;
C_noret_decl(f_6913)
static void C_ccall f_6913(C_word c,C_word *av) C_noret;
C_noret_decl(f_6916)
static void C_ccall f_6916(C_word c,C_word *av) C_noret;
C_noret_decl(f_6925)
static void C_fcall f_6925(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6932)
static void C_ccall f_6932(C_word c,C_word *av) C_noret;
C_noret_decl(f_6934)
static void C_fcall f_6934(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6959)
static void C_ccall f_6959(C_word c,C_word *av) C_noret;
C_noret_decl(f_6992)
static void C_ccall f_6992(C_word c,C_word *av) C_noret;
C_noret_decl(f_6998)
static void C_ccall f_6998(C_word c,C_word *av) C_noret;
C_noret_decl(f_7004)
static void C_ccall f_7004(C_word c,C_word *av) C_noret;
C_noret_decl(f_7013)
static void C_ccall f_7013(C_word c,C_word *av) C_noret;
C_noret_decl(f_7025)
static void C_fcall f_7025(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7031)
static void C_ccall f_7031(C_word c,C_word *av) C_noret;
C_noret_decl(f_7037)
static void C_ccall f_7037(C_word c,C_word *av) C_noret;
C_noret_decl(f_7046)
static void C_ccall f_7046(C_word c,C_word *av) C_noret;
C_noret_decl(f_7048)
static void C_fcall f_7048(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7058)
static void C_ccall f_7058(C_word c,C_word *av) C_noret;
C_noret_decl(f_7072)
static void C_ccall f_7072(C_word c,C_word *av) C_noret;
C_noret_decl(f_7073)
static void C_ccall f_7073(C_word c,C_word *av) C_noret;
C_noret_decl(f_7090)
static void C_ccall f_7090(C_word c,C_word *av) C_noret;
C_noret_decl(f_7114)
static void C_ccall f_7114(C_word c,C_word *av) C_noret;
C_noret_decl(f_7124)
static void C_fcall f_7124(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7143)
static void C_ccall f_7143(C_word c,C_word *av) C_noret;
C_noret_decl(f_7151)
static void C_ccall f_7151(C_word c,C_word *av) C_noret;
C_noret_decl(f_7155)
static void C_ccall f_7155(C_word c,C_word *av) C_noret;
C_noret_decl(f_7162)
static void C_ccall f_7162(C_word c,C_word *av) C_noret;
C_noret_decl(f_7166)
static void C_ccall f_7166(C_word c,C_word *av) C_noret;
C_noret_decl(f_7175)
static void C_fcall f_7175(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7184)
static void C_ccall f_7184(C_word c,C_word *av) C_noret;
C_noret_decl(f_7190)
static void C_ccall f_7190(C_word c,C_word *av) C_noret;
C_noret_decl(f_7197)
static void C_ccall f_7197(C_word c,C_word *av) C_noret;
C_noret_decl(f_7240)
static void C_fcall f_7240(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8) C_noret;
C_noret_decl(f_7246)
static void C_fcall f_7246(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_7256)
static void C_ccall f_7256(C_word c,C_word *av) C_noret;
C_noret_decl(f_7266)
static void C_ccall f_7266(C_word c,C_word *av) C_noret;
C_noret_decl(f_7272)
static void C_ccall f_7272(C_word c,C_word *av) C_noret;
C_noret_decl(f_7300)
static void C_fcall f_7300(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7306)
static void C_ccall f_7306(C_word c,C_word *av) C_noret;
C_noret_decl(f_7310)
static void C_ccall f_7310(C_word c,C_word *av) C_noret;
C_noret_decl(f_7313)
static void C_ccall f_7313(C_word c,C_word *av) C_noret;
C_noret_decl(f_7316)
static void C_ccall f_7316(C_word c,C_word *av) C_noret;
C_noret_decl(f_7319)
static void C_ccall f_7319(C_word c,C_word *av) C_noret;
C_noret_decl(f_7322)
static void C_ccall f_7322(C_word c,C_word *av) C_noret;
C_noret_decl(f_7325)
static void C_ccall f_7325(C_word c,C_word *av) C_noret;
C_noret_decl(f_7354)
static void C_ccall f_7354(C_word c,C_word *av) C_noret;
C_noret_decl(f_7358)
static void C_ccall f_7358(C_word c,C_word *av) C_noret;
C_noret_decl(f_7363)
static void C_ccall f_7363(C_word c,C_word *av) C_noret;
C_noret_decl(f_7391)
static void C_fcall f_7391(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7401)
static void C_ccall f_7401(C_word c,C_word *av) C_noret;
C_noret_decl(f_7429)
static void C_fcall f_7429(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7469)
static C_word C_fcall f_7469(C_word t0);
C_noret_decl(f_7473)
static void C_fcall f_7473(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7480)
static void C_ccall f_7480(C_word c,C_word *av) C_noret;
C_noret_decl(f_7483)
static void C_ccall f_7483(C_word c,C_word *av) C_noret;
C_noret_decl(f_7486)
static void C_ccall f_7486(C_word c,C_word *av) C_noret;
C_noret_decl(f_7495)
static void C_ccall f_7495(C_word c,C_word *av) C_noret;
C_noret_decl(f_7496)
static void C_fcall f_7496(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7503)
static void C_ccall f_7503(C_word c,C_word *av) C_noret;
C_noret_decl(f_7509)
static void C_ccall f_7509(C_word c,C_word *av) C_noret;
C_noret_decl(f_7512)
static void C_ccall f_7512(C_word c,C_word *av) C_noret;
C_noret_decl(f_7518)
static void C_fcall f_7518(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7527)
static void C_ccall f_7527(C_word c,C_word *av) C_noret;
C_noret_decl(f_7539)
static void C_ccall f_7539(C_word c,C_word *av) C_noret;
C_noret_decl(f_7545)
static void C_fcall f_7545(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7554)
static void C_fcall f_7554(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7561)
static void C_ccall f_7561(C_word c,C_word *av) C_noret;
C_noret_decl(f_7564)
static void C_ccall f_7564(C_word c,C_word *av) C_noret;
C_noret_decl(f_7567)
static void C_ccall f_7567(C_word c,C_word *av) C_noret;
C_noret_decl(f_7582)
static void C_ccall f_7582(C_word c,C_word *av) C_noret;
C_noret_decl(f_7602)
static void C_ccall f_7602(C_word c,C_word *av) C_noret;
C_noret_decl(f_7606)
static void C_ccall f_7606(C_word c,C_word *av) C_noret;
C_noret_decl(f_7610)
static void C_ccall f_7610(C_word c,C_word *av) C_noret;
C_noret_decl(f_7620)
static void C_ccall f_7620(C_word c,C_word *av) C_noret;
C_noret_decl(f_7639)
static void C_ccall f_7639(C_word c,C_word *av) C_noret;
C_noret_decl(f_7643)
static void C_ccall f_7643(C_word c,C_word *av) C_noret;
C_noret_decl(f_7662)
static void C_ccall f_7662(C_word c,C_word *av) C_noret;
C_noret_decl(f_7682)
static void C_ccall f_7682(C_word c,C_word *av) C_noret;
C_noret_decl(f_7686)
static void C_ccall f_7686(C_word c,C_word *av) C_noret;
C_noret_decl(f_7693)
static void C_ccall f_7693(C_word c,C_word *av) C_noret;
C_noret_decl(f_7704)
static void C_fcall f_7704(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7714)
static void C_ccall f_7714(C_word c,C_word *av) C_noret;
C_noret_decl(f_7734)
static void C_ccall f_7734(C_word c,C_word *av) C_noret;
C_noret_decl(f_7737)
static void C_ccall f_7737(C_word c,C_word *av) C_noret;
C_noret_decl(f_7740)
static void C_ccall f_7740(C_word c,C_word *av) C_noret;
C_noret_decl(f_7755)
static void C_ccall f_7755(C_word c,C_word *av) C_noret;
C_noret_decl(f_7757)
static void C_fcall f_7757(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7763)
static void C_fcall f_7763(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7787)
static void C_ccall f_7787(C_word c,C_word *av) C_noret;
C_noret_decl(f_7800)
static void C_fcall f_7800(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7809)
static void C_ccall f_7809(C_word c,C_word *av) C_noret;
C_noret_decl(f_7812)
static void C_ccall f_7812(C_word c,C_word *av) C_noret;
C_noret_decl(f_7813)
static void C_fcall f_7813(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7823)
static void C_ccall f_7823(C_word c,C_word *av) C_noret;
C_noret_decl(f_7831)
static void C_ccall f_7831(C_word c,C_word *av) C_noret;
C_noret_decl(f_7839)
static void C_ccall f_7839(C_word c,C_word *av) C_noret;
C_noret_decl(f_7845)
static void C_ccall f_7845(C_word c,C_word *av) C_noret;
C_noret_decl(f_7858)
static void C_ccall f_7858(C_word c,C_word *av) C_noret;
C_noret_decl(f_7872)
static void C_ccall f_7872(C_word c,C_word *av) C_noret;
C_noret_decl(f_7873)
static void C_fcall f_7873(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7880)
static void C_ccall f_7880(C_word c,C_word *av) C_noret;
C_noret_decl(f_7888)
static void C_ccall f_7888(C_word c,C_word *av) C_noret;
C_noret_decl(f_7890)
static void C_fcall f_7890(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7903)
static void C_ccall f_7903(C_word c,C_word *av) C_noret;
C_noret_decl(f_7914)
static void C_ccall f_7914(C_word c,C_word *av) C_noret;
C_noret_decl(f_7920)
static void C_ccall f_7920(C_word c,C_word *av) C_noret;
C_noret_decl(f_7932)
static void C_ccall f_7932(C_word c,C_word *av) C_noret;
C_noret_decl(f_7935)
static void C_ccall f_7935(C_word c,C_word *av) C_noret;
C_noret_decl(f_7938)
static void C_ccall f_7938(C_word c,C_word *av) C_noret;
C_noret_decl(f_7947)
static void C_ccall f_7947(C_word c,C_word *av) C_noret;
C_noret_decl(f_7955)
static void C_fcall f_7955(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7971)
static void C_fcall f_7971(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7984)
static void C_fcall f_7984(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8008)
static void C_fcall f_8008(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8032)
static void C_ccall f_8032(C_word c,C_word *av) C_noret;
C_noret_decl(f_8043)
static void C_ccall f_8043(C_word c,C_word *av) C_noret;
C_noret_decl(f_8055)
static void C_fcall f_8055(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8063)
static void C_fcall f_8063(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8079)
static void C_ccall f_8079(C_word c,C_word *av) C_noret;
C_noret_decl(f_8099)
static void C_ccall f_8099(C_word c,C_word *av) C_noret;
C_noret_decl(f_8110)
static void C_ccall f_8110(C_word c,C_word *av) C_noret;
C_noret_decl(f_8141)
static void C_ccall f_8141(C_word c,C_word *av) C_noret;
C_noret_decl(f_8147)
static void C_fcall f_8147(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8157)
static void C_ccall f_8157(C_word c,C_word *av) C_noret;
C_noret_decl(f_8170)
static void C_fcall f_8170(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8180)
static void C_ccall f_8180(C_word c,C_word *av) C_noret;
C_noret_decl(f_8193)
static void C_fcall f_8193(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8203)
static void C_ccall f_8203(C_word c,C_word *av) C_noret;
C_noret_decl(f_8230)
static void C_fcall f_8230(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8280)
static void C_ccall f_8280(C_word c,C_word *av) C_noret;
C_noret_decl(f_8282)
static void C_ccall f_8282(C_word c,C_word *av) C_noret;
C_noret_decl(f_8286)
static void C_ccall f_8286(C_word c,C_word *av) C_noret;
C_noret_decl(f_8296)
static void C_ccall f_8296(C_word c,C_word *av) C_noret;
C_noret_decl(f_8305)
static C_word C_fcall f_8305(C_word t0,C_word t1);
C_noret_decl(f_8395)
static void C_ccall f_8395(C_word c,C_word *av) C_noret;
C_noret_decl(f_8398)
static void C_ccall f_8398(C_word c,C_word *av) C_noret;
C_noret_decl(f_8419)
static void C_ccall f_8419(C_word c,C_word *av) C_noret;
C_noret_decl(f_8469)
static void C_ccall f_8469(C_word c,C_word *av) C_noret;
C_noret_decl(f_8473)
static void C_ccall f_8473(C_word c,C_word *av) C_noret;
C_noret_decl(f_8477)
static void C_ccall f_8477(C_word c,C_word *av) C_noret;
C_noret_decl(f_8481)
static void C_ccall f_8481(C_word c,C_word *av) C_noret;
C_noret_decl(f_8485)
static void C_ccall f_8485(C_word c,C_word *av) C_noret;
C_noret_decl(f_8514)
static void C_ccall f_8514(C_word c,C_word *av) C_noret;
C_noret_decl(f_8541)
static void C_ccall f_8541(C_word c,C_word *av) C_noret;
C_noret_decl(f_8572)
static void C_ccall f_8572(C_word c,C_word *av) C_noret;
C_noret_decl(f_8589)
static void C_fcall f_8589(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8613)
static void C_ccall f_8613(C_word c,C_word *av) C_noret;
C_noret_decl(f_8624)
static void C_ccall f_8624(C_word c,C_word *av) C_noret;
C_noret_decl(f_8643)
static void C_ccall f_8643(C_word c,C_word *av) C_noret;
C_noret_decl(f_8686)
static void C_ccall f_8686(C_word c,C_word *av) C_noret;
C_noret_decl(f_8701)
static void C_ccall f_8701(C_word c,C_word *av) C_noret;
C_noret_decl(f_8709)
static void C_ccall f_8709(C_word c,C_word *av) C_noret;
C_noret_decl(f_8745)
static void C_ccall f_8745(C_word c,C_word *av) C_noret;
C_noret_decl(f_8778)
static void C_ccall f_8778(C_word c,C_word *av) C_noret;
C_noret_decl(f_8794)
static void C_ccall f_8794(C_word c,C_word *av) C_noret;
C_noret_decl(f_8840)
static void C_ccall f_8840(C_word c,C_word *av) C_noret;
C_noret_decl(f_8855)
static void C_ccall f_8855(C_word c,C_word *av) C_noret;
C_noret_decl(f_8867)
static void C_ccall f_8867(C_word c,C_word *av) C_noret;
C_noret_decl(f_8914)
static void C_ccall f_8914(C_word c,C_word *av) C_noret;
C_noret_decl(f_8929)
static void C_ccall f_8929(C_word c,C_word *av) C_noret;
C_noret_decl(f_8937)
static void C_ccall f_8937(C_word c,C_word *av) C_noret;
C_noret_decl(f_8945)
static void C_ccall f_8945(C_word c,C_word *av) C_noret;
C_noret_decl(f_8976)
static void C_ccall f_8976(C_word c,C_word *av) C_noret;
C_noret_decl(f_8997)
static void C_ccall f_8997(C_word c,C_word *av) C_noret;
C_noret_decl(f_9018)
static void C_ccall f_9018(C_word c,C_word *av) C_noret;
C_noret_decl(f_9027)
static void C_fcall f_9027(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9038)
static void C_ccall f_9038(C_word c,C_word *av) C_noret;
C_noret_decl(f_9047)
static void C_ccall f_9047(C_word c,C_word *av) C_noret;
C_noret_decl(f_9052)
static void C_fcall f_9052(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9077)
static void C_ccall f_9077(C_word c,C_word *av) C_noret;
C_noret_decl(f_9079)
static void C_ccall f_9079(C_word c,C_word *av) C_noret;
C_noret_decl(f_9119)
static void C_ccall f_9119(C_word c,C_word *av) C_noret;
C_noret_decl(f_9129)
static void C_fcall f_9129(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9154)
static void C_ccall f_9154(C_word c,C_word *av) C_noret;
C_noret_decl(f_9163)
static void C_fcall f_9163(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9188)
static void C_ccall f_9188(C_word c,C_word *av) C_noret;
C_noret_decl(f_9252)
static void C_ccall f_9252(C_word c,C_word *av) C_noret;
C_noret_decl(f_9261)
static void C_ccall f_9261(C_word c,C_word *av) C_noret;
C_noret_decl(f_9276)
static void C_ccall f_9276(C_word c,C_word *av) C_noret;
C_noret_decl(f_9284)
static void C_ccall f_9284(C_word c,C_word *av) C_noret;
C_noret_decl(f_9288)
static void C_ccall f_9288(C_word c,C_word *av) C_noret;
C_noret_decl(f_9341)
static void C_ccall f_9341(C_word c,C_word *av) C_noret;
C_noret_decl(f_9364)
static void C_ccall f_9364(C_word c,C_word *av) C_noret;
C_noret_decl(f_9368)
static void C_ccall f_9368(C_word c,C_word *av) C_noret;
C_noret_decl(f_9402)
static void C_ccall f_9402(C_word c,C_word *av) C_noret;
C_noret_decl(f_9448)
static void C_ccall f_9448(C_word c,C_word *av) C_noret;
C_noret_decl(f_9452)
static void C_ccall f_9452(C_word c,C_word *av) C_noret;
C_noret_decl(f_9481)
static void C_ccall f_9481(C_word c,C_word *av) C_noret;
C_noret_decl(f_9506)
static void C_fcall f_9506(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9510)
static void C_ccall f_9510(C_word c,C_word *av) C_noret;
C_noret_decl(f_9514)
static void C_ccall f_9514(C_word c,C_word *av) C_noret;
C_noret_decl(f_9551)
static void C_ccall f_9551(C_word c,C_word *av) C_noret;
C_noret_decl(f_9581)
static void C_ccall f_9581(C_word c,C_word *av) C_noret;
C_noret_decl(f_9634)
static void C_ccall f_9634(C_word c,C_word *av) C_noret;
C_noret_decl(f_9651)
static void C_ccall f_9651(C_word c,C_word *av) C_noret;
C_noret_decl(f_9655)
static void C_ccall f_9655(C_word c,C_word *av) C_noret;
C_noret_decl(f_9735)
static void C_ccall f_9735(C_word c,C_word *av) C_noret;
C_noret_decl(f_9756)
static void C_ccall f_9756(C_word c,C_word *av) C_noret;
C_noret_decl(f_9764)
static void C_ccall f_9764(C_word c,C_word *av) C_noret;
C_noret_decl(f_9847)
static void C_ccall f_9847(C_word c,C_word *av) C_noret;
C_noret_decl(f_9862)
static void C_ccall f_9862(C_word c,C_word *av) C_noret;
C_noret_decl(f_9915)
static void C_ccall f_9915(C_word c,C_word *av) C_noret;
C_noret_decl(f_9930)
static void C_ccall f_9930(C_word c,C_word *av) C_noret;
C_noret_decl(f_9949)
static void C_ccall f_9949(C_word c,C_word *av) C_noret;
C_noret_decl(f_9958)
static void C_ccall f_9958(C_word c,C_word *av) C_noret;
C_noret_decl(f_9974)
static void C_fcall f_9974(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_9996)
static void C_ccall f_9996(C_word c,C_word *av) C_noret;
C_noret_decl(f_9999)
static void C_ccall f_9999(C_word c,C_word *av) C_noret;
C_noret_decl(C_optimizer_toplevel)
C_externexport void C_ccall C_optimizer_toplevel(C_word c,C_word *av) C_noret;

C_noret_decl(trf_10458)
static void C_ccall trf_10458(C_word c,C_word *av) C_noret;
static void C_ccall trf_10458(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10458(t0,t1,t2,t3);}

C_noret_decl(trf_10581)
static void C_ccall trf_10581(C_word c,C_word *av) C_noret;
static void C_ccall trf_10581(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_10581(t0,t1,t2,t3,t4);}

C_noret_decl(trf_10751)
static void C_ccall trf_10751(C_word c,C_word *av) C_noret;
static void C_ccall trf_10751(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10751(t0,t1,t2);}

C_noret_decl(trf_10763)
static void C_ccall trf_10763(C_word c,C_word *av) C_noret;
static void C_ccall trf_10763(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10763(t0,t1,t2);}

C_noret_decl(trf_10792)
static void C_ccall trf_10792(C_word c,C_word *av) C_noret;
static void C_ccall trf_10792(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_10792(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_10795)
static void C_ccall trf_10795(C_word c,C_word *av) C_noret;
static void C_ccall trf_10795(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_10795(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_10953)
static void C_ccall trf_10953(C_word c,C_word *av) C_noret;
static void C_ccall trf_10953(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10953(t0,t1);}

C_noret_decl(trf_10992)
static void C_ccall trf_10992(C_word c,C_word *av) C_noret;
static void C_ccall trf_10992(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10992(t0,t1);}

C_noret_decl(trf_11039)
static void C_ccall trf_11039(C_word c,C_word *av) C_noret;
static void C_ccall trf_11039(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11039(t0,t1);}

C_noret_decl(trf_11223)
static void C_ccall trf_11223(C_word c,C_word *av) C_noret;
static void C_ccall trf_11223(C_word c,C_word *av){
C_word t0=av[7];
C_word t1=av[6];
C_word t2=av[5];
C_word t3=av[4];
C_word t4=av[3];
C_word t5=av[2];
C_word t6=av[1];
C_word t7=av[0];
f_11223(t0,t1,t2,t3,t4,t5,t6,t7);}

C_noret_decl(trf_11243)
static void C_ccall trf_11243(C_word c,C_word *av) C_noret;
static void C_ccall trf_11243(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11243(t0,t1);}

C_noret_decl(trf_11262)
static void C_ccall trf_11262(C_word c,C_word *av) C_noret;
static void C_ccall trf_11262(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11262(t0,t1,t2);}

C_noret_decl(trf_11394)
static void C_ccall trf_11394(C_word c,C_word *av) C_noret;
static void C_ccall trf_11394(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11394(t0,t1,t2);}

C_noret_decl(trf_11417)
static void C_ccall trf_11417(C_word c,C_word *av) C_noret;
static void C_ccall trf_11417(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11417(t0,t1,t2);}

C_noret_decl(trf_11486)
static void C_ccall trf_11486(C_word c,C_word *av) C_noret;
static void C_ccall trf_11486(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11486(t0,t1,t2);}

C_noret_decl(trf_11536)
static void C_ccall trf_11536(C_word c,C_word *av) C_noret;
static void C_ccall trf_11536(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11536(t0,t1,t2);}

C_noret_decl(trf_11610)
static void C_ccall trf_11610(C_word c,C_word *av) C_noret;
static void C_ccall trf_11610(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11610(t0,t1,t2);}

C_noret_decl(trf_11749)
static void C_ccall trf_11749(C_word c,C_word *av) C_noret;
static void C_ccall trf_11749(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11749(t0,t1,t2);}

C_noret_decl(trf_11778)
static void C_ccall trf_11778(C_word c,C_word *av) C_noret;
static void C_ccall trf_11778(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11778(t0,t1,t2);}

C_noret_decl(trf_11927)
static void C_ccall trf_11927(C_word c,C_word *av) C_noret;
static void C_ccall trf_11927(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11927(t0,t1,t2,t3);}

C_noret_decl(trf_11958)
static void C_ccall trf_11958(C_word c,C_word *av) C_noret;
static void C_ccall trf_11958(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11958(t0,t1);}

C_noret_decl(trf_11972)
static void C_ccall trf_11972(C_word c,C_word *av) C_noret;
static void C_ccall trf_11972(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11972(t0,t1);}

C_noret_decl(trf_12121)
static void C_ccall trf_12121(C_word c,C_word *av) C_noret;
static void C_ccall trf_12121(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12121(t0,t1,t2);}

C_noret_decl(trf_12133)
static void C_ccall trf_12133(C_word c,C_word *av) C_noret;
static void C_ccall trf_12133(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12133(t0,t1,t2);}

C_noret_decl(trf_12170)
static void C_ccall trf_12170(C_word c,C_word *av) C_noret;
static void C_ccall trf_12170(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12170(t0,t1,t2);}

C_noret_decl(trf_12185)
static void C_ccall trf_12185(C_word c,C_word *av) C_noret;
static void C_ccall trf_12185(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12185(t0,t1,t2);}

C_noret_decl(trf_12234)
static void C_ccall trf_12234(C_word c,C_word *av) C_noret;
static void C_ccall trf_12234(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12234(t0,t1,t2);}

C_noret_decl(trf_12296)
static void C_ccall trf_12296(C_word c,C_word *av) C_noret;
static void C_ccall trf_12296(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12296(t0,t1,t2);}

C_noret_decl(trf_12301)
static void C_ccall trf_12301(C_word c,C_word *av) C_noret;
static void C_ccall trf_12301(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12301(t0,t1,t2);}

C_noret_decl(trf_12373)
static void C_ccall trf_12373(C_word c,C_word *av) C_noret;
static void C_ccall trf_12373(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12373(t0,t1,t2);}

C_noret_decl(trf_12403)
static void C_ccall trf_12403(C_word c,C_word *av) C_noret;
static void C_ccall trf_12403(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12403(t0,t1,t2);}

C_noret_decl(trf_12426)
static void C_ccall trf_12426(C_word c,C_word *av) C_noret;
static void C_ccall trf_12426(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12426(t0,t1,t2);}

C_noret_decl(trf_12436)
static void C_ccall trf_12436(C_word c,C_word *av) C_noret;
static void C_ccall trf_12436(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12436(t0,t1);}

C_noret_decl(trf_12576)
static void C_ccall trf_12576(C_word c,C_word *av) C_noret;
static void C_ccall trf_12576(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12576(t0,t1,t2,t3);}

C_noret_decl(trf_12669)
static void C_ccall trf_12669(C_word c,C_word *av) C_noret;
static void C_ccall trf_12669(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12669(t0,t1,t2);}

C_noret_decl(trf_12736)
static void C_ccall trf_12736(C_word c,C_word *av) C_noret;
static void C_ccall trf_12736(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12736(t0,t1,t2);}

C_noret_decl(trf_12770)
static void C_ccall trf_12770(C_word c,C_word *av) C_noret;
static void C_ccall trf_12770(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12770(t0,t1,t2);}

C_noret_decl(trf_12817)
static void C_ccall trf_12817(C_word c,C_word *av) C_noret;
static void C_ccall trf_12817(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12817(t0,t1,t2);}

C_noret_decl(trf_12906)
static void C_ccall trf_12906(C_word c,C_word *av) C_noret;
static void C_ccall trf_12906(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12906(t0,t1,t2);}

C_noret_decl(trf_12914)
static void C_ccall trf_12914(C_word c,C_word *av) C_noret;
static void C_ccall trf_12914(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12914(t0,t1,t2,t3);}

C_noret_decl(trf_13098)
static void C_ccall trf_13098(C_word c,C_word *av) C_noret;
static void C_ccall trf_13098(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_13098(t0,t1,t2,t3,t4);}

C_noret_decl(trf_13121)
static void C_ccall trf_13121(C_word c,C_word *av) C_noret;
static void C_ccall trf_13121(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13121(t0,t1);}

C_noret_decl(trf_13243)
static void C_ccall trf_13243(C_word c,C_word *av) C_noret;
static void C_ccall trf_13243(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_13243(t0,t1,t2,t3,t4);}

C_noret_decl(trf_13282)
static void C_ccall trf_13282(C_word c,C_word *av) C_noret;
static void C_ccall trf_13282(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13282(t0,t1);}

C_noret_decl(trf_13494)
static void C_ccall trf_13494(C_word c,C_word *av) C_noret;
static void C_ccall trf_13494(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13494(t0,t1,t2,t3);}

C_noret_decl(trf_13597)
static void C_ccall trf_13597(C_word c,C_word *av) C_noret;
static void C_ccall trf_13597(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_13597(t0,t1,t2,t3,t4);}

C_noret_decl(trf_13613)
static void C_ccall trf_13613(C_word c,C_word *av) C_noret;
static void C_ccall trf_13613(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13613(t0,t1);}

C_noret_decl(trf_14107)
static void C_ccall trf_14107(C_word c,C_word *av) C_noret;
static void C_ccall trf_14107(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14107(t0,t1,t2);}

C_noret_decl(trf_3409)
static void C_ccall trf_3409(C_word c,C_word *av) C_noret;
static void C_ccall trf_3409(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_3409(t0,t1,t2,t3,t4);}

C_noret_decl(trf_3511)
static void C_ccall trf_3511(C_word c,C_word *av) C_noret;
static void C_ccall trf_3511(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3511(t0,t1,t2);}

C_noret_decl(trf_3563)
static void C_ccall trf_3563(C_word c,C_word *av) C_noret;
static void C_ccall trf_3563(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3563(t0,t1,t2);}

C_noret_decl(trf_3569)
static void C_ccall trf_3569(C_word c,C_word *av) C_noret;
static void C_ccall trf_3569(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_3569(t0,t1,t2,t3,t4);}

C_noret_decl(trf_3602)
static void C_ccall trf_3602(C_word c,C_word *av) C_noret;
static void C_ccall trf_3602(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_3602(t0,t1,t2,t3);}

C_noret_decl(trf_3617)
static void C_ccall trf_3617(C_word c,C_word *av) C_noret;
static void C_ccall trf_3617(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3617(t0,t1,t2);}

C_noret_decl(trf_3625)
static void C_ccall trf_3625(C_word c,C_word *av) C_noret;
static void C_ccall trf_3625(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_3625(t0,t1,t2,t3);}

C_noret_decl(trf_3657)
static void C_ccall trf_3657(C_word c,C_word *av) C_noret;
static void C_ccall trf_3657(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3657(t0,t1,t2);}

C_noret_decl(trf_3689)
static void C_ccall trf_3689(C_word c,C_word *av) C_noret;
static void C_ccall trf_3689(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3689(t0,t1,t2);}

C_noret_decl(trf_3738)
static void C_ccall trf_3738(C_word c,C_word *av) C_noret;
static void C_ccall trf_3738(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3738(t0,t1,t2);}

C_noret_decl(trf_3772)
static void C_ccall trf_3772(C_word c,C_word *av) C_noret;
static void C_ccall trf_3772(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3772(t0,t1,t2);}

C_noret_decl(trf_3778)
static void C_ccall trf_3778(C_word c,C_word *av) C_noret;
static void C_ccall trf_3778(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3778(t0,t1,t2);}

C_noret_decl(trf_3806)
static void C_ccall trf_3806(C_word c,C_word *av) C_noret;
static void C_ccall trf_3806(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3806(t0,t1,t2);}

C_noret_decl(trf_3812)
static void C_ccall trf_3812(C_word c,C_word *av) C_noret;
static void C_ccall trf_3812(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3812(t0,t1,t2);}

C_noret_decl(trf_3836)
static void C_ccall trf_3836(C_word c,C_word *av) C_noret;
static void C_ccall trf_3836(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3836(t0,t1,t2);}

C_noret_decl(trf_3842)
static void C_ccall trf_3842(C_word c,C_word *av) C_noret;
static void C_ccall trf_3842(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_3842(t0,t1,t2,t3);}

C_noret_decl(trf_3892)
static void C_ccall trf_3892(C_word c,C_word *av) C_noret;
static void C_ccall trf_3892(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_3892(t0,t1,t2,t3);}

C_noret_decl(trf_3898)
static void C_ccall trf_3898(C_word c,C_word *av) C_noret;
static void C_ccall trf_3898(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3898(t0,t1,t2);}

C_noret_decl(trf_3973)
static void C_ccall trf_3973(C_word c,C_word *av) C_noret;
static void C_ccall trf_3973(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_3973(t0,t1,t2);}

C_noret_decl(trf_4012)
static void C_ccall trf_4012(C_word c,C_word *av) C_noret;
static void C_ccall trf_4012(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4012(t0,t1,t2);}

C_noret_decl(trf_4021)
static void C_ccall trf_4021(C_word c,C_word *av) C_noret;
static void C_ccall trf_4021(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4021(t0,t1,t2);}

C_noret_decl(trf_4029)
static void C_ccall trf_4029(C_word c,C_word *av) C_noret;
static void C_ccall trf_4029(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_4029(t0,t1,t2,t3);}

C_noret_decl(trf_4065)
static void C_ccall trf_4065(C_word c,C_word *av) C_noret;
static void C_ccall trf_4065(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4065(t0,t1,t2);}

C_noret_decl(trf_4073)
static void C_ccall trf_4073(C_word c,C_word *av) C_noret;
static void C_ccall trf_4073(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_4073(t0,t1,t2,t3);}

C_noret_decl(trf_4138)
static void C_ccall trf_4138(C_word c,C_word *av) C_noret;
static void C_ccall trf_4138(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4138(t0,t1,t2);}

C_noret_decl(trf_4237)
static void C_ccall trf_4237(C_word c,C_word *av) C_noret;
static void C_ccall trf_4237(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_4237(t0,t1,t2,t3);}

C_noret_decl(trf_4414)
static void C_ccall trf_4414(C_word c,C_word *av) C_noret;
static void C_ccall trf_4414(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4414(t0,t1,t2);}

C_noret_decl(trf_4420)
static void C_ccall trf_4420(C_word c,C_word *av) C_noret;
static void C_ccall trf_4420(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4420(t0,t1,t2);}

C_noret_decl(trf_4723)
static void C_ccall trf_4723(C_word c,C_word *av) C_noret;
static void C_ccall trf_4723(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_4723(t0,t1,t2,t3);}

C_noret_decl(trf_4735)
static void C_ccall trf_4735(C_word c,C_word *av) C_noret;
static void C_ccall trf_4735(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_4735(t0,t1,t2,t3,t4);}

C_noret_decl(trf_4737)
static void C_ccall trf_4737(C_word c,C_word *av) C_noret;
static void C_ccall trf_4737(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4737(t0,t1,t2);}

C_noret_decl(trf_4753)
static void C_ccall trf_4753(C_word c,C_word *av) C_noret;
static void C_ccall trf_4753(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_4753(t0,t1,t2);}

C_noret_decl(trf_4776)
static void C_ccall trf_4776(C_word c,C_word *av) C_noret;
static void C_ccall trf_4776(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_4776(t0,t1,t2,t3);}

C_noret_decl(trf_4798)
static void C_ccall trf_4798(C_word c,C_word *av) C_noret;
static void C_ccall trf_4798(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_4798(t0,t1);}

C_noret_decl(trf_4846)
static void C_ccall trf_4846(C_word c,C_word *av) C_noret;
static void C_ccall trf_4846(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_4846(t0,t1);}

C_noret_decl(trf_5013)
static void C_ccall trf_5013(C_word c,C_word *av) C_noret;
static void C_ccall trf_5013(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5013(t0,t1,t2);}

C_noret_decl(trf_5056)
static void C_ccall trf_5056(C_word c,C_word *av) C_noret;
static void C_ccall trf_5056(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_5056(t0,t1,t2,t3);}

C_noret_decl(trf_5086)
static void C_ccall trf_5086(C_word c,C_word *av) C_noret;
static void C_ccall trf_5086(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5086(t0,t1);}

C_noret_decl(trf_5123)
static void C_ccall trf_5123(C_word c,C_word *av) C_noret;
static void C_ccall trf_5123(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5123(t0,t1,t2);}

C_noret_decl(trf_5209)
static void C_ccall trf_5209(C_word c,C_word *av) C_noret;
static void C_ccall trf_5209(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5209(t0,t1,t2);}

C_noret_decl(trf_5251)
static void C_ccall trf_5251(C_word c,C_word *av) C_noret;
static void C_ccall trf_5251(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5251(t0,t1,t2);}

C_noret_decl(trf_5270)
static void C_ccall trf_5270(C_word c,C_word *av) C_noret;
static void C_ccall trf_5270(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5270(t0,t1);}

C_noret_decl(trf_5413)
static void C_ccall trf_5413(C_word c,C_word *av) C_noret;
static void C_ccall trf_5413(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_5413(t0,t1,t2,t3,t4);}

C_noret_decl(trf_5509)
static void C_ccall trf_5509(C_word c,C_word *av) C_noret;
static void C_ccall trf_5509(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5509(t0,t1);}

C_noret_decl(trf_5551)
static void C_ccall trf_5551(C_word c,C_word *av) C_noret;
static void C_ccall trf_5551(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5551(t0,t1,t2);}

C_noret_decl(trf_5559)
static void C_ccall trf_5559(C_word c,C_word *av) C_noret;
static void C_ccall trf_5559(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5559(t0,t1,t2);}

C_noret_decl(trf_5571)
static void C_ccall trf_5571(C_word c,C_word *av) C_noret;
static void C_ccall trf_5571(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_5571(t0,t1,t2,t3,t4);}

C_noret_decl(trf_5640)
static void C_ccall trf_5640(C_word c,C_word *av) C_noret;
static void C_ccall trf_5640(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5640(t0,t1,t2);}

C_noret_decl(trf_5650)
static void C_ccall trf_5650(C_word c,C_word *av) C_noret;
static void C_ccall trf_5650(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5650(t0,t1);}

C_noret_decl(trf_5706)
static void C_ccall trf_5706(C_word c,C_word *av) C_noret;
static void C_ccall trf_5706(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5706(t0,t1);}

C_noret_decl(trf_5721)
static void C_ccall trf_5721(C_word c,C_word *av) C_noret;
static void C_ccall trf_5721(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_5721(t0,t1);}

C_noret_decl(trf_5729)
static void C_ccall trf_5729(C_word c,C_word *av) C_noret;
static void C_ccall trf_5729(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5729(t0,t1,t2);}

C_noret_decl(trf_5741)
static void C_ccall trf_5741(C_word c,C_word *av) C_noret;
static void C_ccall trf_5741(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5741(t0,t1,t2);}

C_noret_decl(trf_5865)
static void C_ccall trf_5865(C_word c,C_word *av) C_noret;
static void C_ccall trf_5865(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_5865(t0,t1,t2);}

C_noret_decl(trf_6043)
static void C_ccall trf_6043(C_word c,C_word *av) C_noret;
static void C_ccall trf_6043(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6043(t0,t1);}

C_noret_decl(trf_6062)
static void C_ccall trf_6062(C_word c,C_word *av) C_noret;
static void C_ccall trf_6062(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6062(t0,t1,t2);}

C_noret_decl(trf_6089)
static void C_ccall trf_6089(C_word c,C_word *av) C_noret;
static void C_ccall trf_6089(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6089(t0,t1,t2);}

C_noret_decl(trf_6125)
static void C_ccall trf_6125(C_word c,C_word *av) C_noret;
static void C_ccall trf_6125(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6125(t0,t1);}

C_noret_decl(trf_6153)
static void C_ccall trf_6153(C_word c,C_word *av) C_noret;
static void C_ccall trf_6153(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6153(t0,t1);}

C_noret_decl(trf_6177)
static void C_ccall trf_6177(C_word c,C_word *av) C_noret;
static void C_ccall trf_6177(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6177(t0,t1);}

C_noret_decl(trf_6187)
static void C_ccall trf_6187(C_word c,C_word *av) C_noret;
static void C_ccall trf_6187(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6187(t0,t1,t2);}

C_noret_decl(trf_6246)
static void C_ccall trf_6246(C_word c,C_word *av) C_noret;
static void C_ccall trf_6246(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6246(t0,t1,t2);}

C_noret_decl(trf_6301)
static void C_ccall trf_6301(C_word c,C_word *av) C_noret;
static void C_ccall trf_6301(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_6301(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_6318)
static void C_ccall trf_6318(C_word c,C_word *av) C_noret;
static void C_ccall trf_6318(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6318(t0,t1,t2);}

C_noret_decl(trf_6336)
static void C_ccall trf_6336(C_word c,C_word *av) C_noret;
static void C_ccall trf_6336(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6336(t0,t1,t2);}

C_noret_decl(trf_6514)
static void C_ccall trf_6514(C_word c,C_word *av) C_noret;
static void C_ccall trf_6514(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6514(t0,t1,t2);}

C_noret_decl(trf_6526)
static void C_ccall trf_6526(C_word c,C_word *av) C_noret;
static void C_ccall trf_6526(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6526(t0,t1,t2);}

C_noret_decl(trf_6772)
static void C_ccall trf_6772(C_word c,C_word *av) C_noret;
static void C_ccall trf_6772(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6772(t0,t1);}

C_noret_decl(trf_6925)
static void C_ccall trf_6925(C_word c,C_word *av) C_noret;
static void C_ccall trf_6925(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6925(t0,t1,t2);}

C_noret_decl(trf_6934)
static void C_ccall trf_6934(C_word c,C_word *av) C_noret;
static void C_ccall trf_6934(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6934(t0,t1,t2);}

C_noret_decl(trf_7025)
static void C_ccall trf_7025(C_word c,C_word *av) C_noret;
static void C_ccall trf_7025(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7025(t0,t1);}

C_noret_decl(trf_7048)
static void C_ccall trf_7048(C_word c,C_word *av) C_noret;
static void C_ccall trf_7048(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7048(t0,t1,t2);}

C_noret_decl(trf_7124)
static void C_ccall trf_7124(C_word c,C_word *av) C_noret;
static void C_ccall trf_7124(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7124(t0,t1);}

C_noret_decl(trf_7175)
static void C_ccall trf_7175(C_word c,C_word *av) C_noret;
static void C_ccall trf_7175(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7175(t0,t1);}

C_noret_decl(trf_7240)
static void C_ccall trf_7240(C_word c,C_word *av) C_noret;
static void C_ccall trf_7240(C_word c,C_word *av){
C_word t0=av[8];
C_word t1=av[7];
C_word t2=av[6];
C_word t3=av[5];
C_word t4=av[4];
C_word t5=av[3];
C_word t6=av[2];
C_word t7=av[1];
C_word t8=av[0];
f_7240(t0,t1,t2,t3,t4,t5,t6,t7,t8);}

C_noret_decl(trf_7246)
static void C_ccall trf_7246(C_word c,C_word *av) C_noret;
static void C_ccall trf_7246(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_7246(t0,t1,t2,t3,t4);}

C_noret_decl(trf_7300)
static void C_ccall trf_7300(C_word c,C_word *av) C_noret;
static void C_ccall trf_7300(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7300(t0,t1);}

C_noret_decl(trf_7391)
static void C_ccall trf_7391(C_word c,C_word *av) C_noret;
static void C_ccall trf_7391(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7391(t0,t1,t2);}

C_noret_decl(trf_7429)
static void C_ccall trf_7429(C_word c,C_word *av) C_noret;
static void C_ccall trf_7429(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7429(t0,t1,t2,t3);}

C_noret_decl(trf_7473)
static void C_ccall trf_7473(C_word c,C_word *av) C_noret;
static void C_ccall trf_7473(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7473(t0,t1,t2,t3);}

C_noret_decl(trf_7496)
static void C_ccall trf_7496(C_word c,C_word *av) C_noret;
static void C_ccall trf_7496(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7496(t0,t1,t2);}

C_noret_decl(trf_7518)
static void C_ccall trf_7518(C_word c,C_word *av) C_noret;
static void C_ccall trf_7518(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7518(t0,t1);}

C_noret_decl(trf_7545)
static void C_ccall trf_7545(C_word c,C_word *av) C_noret;
static void C_ccall trf_7545(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7545(t0,t1);}

C_noret_decl(trf_7554)
static void C_ccall trf_7554(C_word c,C_word *av) C_noret;
static void C_ccall trf_7554(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7554(t0,t1);}

C_noret_decl(trf_7704)
static void C_ccall trf_7704(C_word c,C_word *av) C_noret;
static void C_ccall trf_7704(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7704(t0,t1,t2);}

C_noret_decl(trf_7757)
static void C_ccall trf_7757(C_word c,C_word *av) C_noret;
static void C_ccall trf_7757(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7757(t0,t1,t2,t3);}

C_noret_decl(trf_7763)
static void C_ccall trf_7763(C_word c,C_word *av) C_noret;
static void C_ccall trf_7763(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7763(t0,t1,t2,t3);}

C_noret_decl(trf_7800)
static void C_ccall trf_7800(C_word c,C_word *av) C_noret;
static void C_ccall trf_7800(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7800(t0,t1,t2,t3);}

C_noret_decl(trf_7813)
static void C_ccall trf_7813(C_word c,C_word *av) C_noret;
static void C_ccall trf_7813(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7813(t0,t1,t2);}

C_noret_decl(trf_7873)
static void C_ccall trf_7873(C_word c,C_word *av) C_noret;
static void C_ccall trf_7873(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7873(t0,t1,t2);}

C_noret_decl(trf_7890)
static void C_ccall trf_7890(C_word c,C_word *av) C_noret;
static void C_ccall trf_7890(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7890(t0,t1,t2);}

C_noret_decl(trf_7955)
static void C_ccall trf_7955(C_word c,C_word *av) C_noret;
static void C_ccall trf_7955(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7955(t0,t1,t2,t3);}

C_noret_decl(trf_7971)
static void C_ccall trf_7971(C_word c,C_word *av) C_noret;
static void C_ccall trf_7971(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7971(t0,t1,t2,t3);}

C_noret_decl(trf_7984)
static void C_ccall trf_7984(C_word c,C_word *av) C_noret;
static void C_ccall trf_7984(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7984(t0,t1);}

C_noret_decl(trf_8008)
static void C_ccall trf_8008(C_word c,C_word *av) C_noret;
static void C_ccall trf_8008(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8008(t0,t1,t2);}

C_noret_decl(trf_8055)
static void C_ccall trf_8055(C_word c,C_word *av) C_noret;
static void C_ccall trf_8055(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8055(t0,t1,t2);}

C_noret_decl(trf_8063)
static void C_ccall trf_8063(C_word c,C_word *av) C_noret;
static void C_ccall trf_8063(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8063(t0,t1,t2,t3);}

C_noret_decl(trf_8147)
static void C_ccall trf_8147(C_word c,C_word *av) C_noret;
static void C_ccall trf_8147(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8147(t0,t1,t2);}

C_noret_decl(trf_8170)
static void C_ccall trf_8170(C_word c,C_word *av) C_noret;
static void C_ccall trf_8170(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8170(t0,t1,t2);}

C_noret_decl(trf_8193)
static void C_ccall trf_8193(C_word c,C_word *av) C_noret;
static void C_ccall trf_8193(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8193(t0,t1,t2,t3);}

C_noret_decl(trf_8230)
static void C_ccall trf_8230(C_word c,C_word *av) C_noret;
static void C_ccall trf_8230(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8230(t0,t1,t2,t3);}

C_noret_decl(trf_8589)
static void C_ccall trf_8589(C_word c,C_word *av) C_noret;
static void C_ccall trf_8589(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8589(t0,t1,t2);}

C_noret_decl(trf_9027)
static void C_ccall trf_9027(C_word c,C_word *av) C_noret;
static void C_ccall trf_9027(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9027(t0,t1);}

C_noret_decl(trf_9052)
static void C_ccall trf_9052(C_word c,C_word *av) C_noret;
static void C_ccall trf_9052(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9052(t0,t1,t2,t3);}

C_noret_decl(trf_9129)
static void C_ccall trf_9129(C_word c,C_word *av) C_noret;
static void C_ccall trf_9129(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9129(t0,t1,t2);}

C_noret_decl(trf_9163)
static void C_ccall trf_9163(C_word c,C_word *av) C_noret;
static void C_ccall trf_9163(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9163(t0,t1,t2);}

C_noret_decl(trf_9506)
static void C_ccall trf_9506(C_word c,C_word *av) C_noret;
static void C_ccall trf_9506(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9506(t0,t1);}

C_noret_decl(trf_9974)
static void C_ccall trf_9974(C_word c,C_word *av) C_noret;
static void C_ccall trf_9974(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_9974(t0,t1,t2,t3,t4,t5);}

/* k10000 in k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10002(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(40,c,2)))){
C_save_and_reclaim((void *)f_10002,c,av);}
a=C_alloc(40);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10017,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t4=C_a_i_list1(&a,1,((C_word*)t0)[6]);
t5=C_a_i_list4(&a,4,t1,C_SCHEME_TRUE,t4,C_fix(0));
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10043,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10055,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=t6,a[5]=t7,a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1405: chicken.compiler.support#varnode */
t9=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}

/* k10015 in k10000 in k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10017(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_10017,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10021,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_i_car(((C_word*)t0)[4]);
t4=C_u_i_cdr(((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10031,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[6],a[5]=t3,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1409: chicken.compiler.support#varnode */
t6=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k10019 in k10015 in k10000 in k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10021,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1398: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10029 in k10015 in k10000 in k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_10031,c,av);}
/* optimizer.scm:1406: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9974(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1);}

/* k10041 in k10000 in k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10043(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_10043,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1401: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[29];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10053 in k10000 in k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10055,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10059,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1405: chicken.compiler.support#varnode */
t3=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10057 in k10053 in k10000 in k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10059(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_10059,c,av);}
a=C_alloc(12);
t2=C_a_i_list4(&a,4,((C_word*)t0)[2],((C_word*)t0)[3],t1,((C_word*)t0)[4]);
/* optimizer.scm:1403: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[6];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10099 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10101(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_10101,c,av);}
a=C_alloc(22);
if(C_truep(t1)){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10116,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_i_cadr(((C_word*)t0)[4]);
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10124,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10126,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10134,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1423: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t6;
av2[2]=t7;
av2[3]=t8;
C_call_with_values(4,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k10114 in k10099 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10116(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10116,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1418: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10122 in k10099 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10124,c,av);}
/* optimizer.scm:1421: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[58];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a10125 in k10099 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_10126,c,av);}
a=C_alloc(5);
t2=C_a_i_fixnum_difference(&a,2,((C_word*)t0)[2],C_fix(1));
/* optimizer.scm:1423: split-at */
f_3563(t1,((C_word*)t0)[3],t2);}

/* a10133 in k10099 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10134,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10146,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1425: chicken.compiler.support#qnode */
t5=*((C_word*)lf[77]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_caddr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k10144 in a10133 in k10099 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10146(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_10146,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1424: scheme#append */
t3=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10173(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_10173,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_cddddr(((C_word*)t0)[2]);
t4=C_i_car(t3);
t5=C_i_cadddr(((C_word*)t0)[2]);
t6=(C_truep(*((C_word*)lf[232]+1))?C_i_caddr(((C_word*)t0)[2]):C_i_cadr(((C_word*)t0)[2]));
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10188,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=t6,a[6]=t5,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10282,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1441: filter */
f_4012(t7,t8,((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k10186 in k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_10188,c,av);}
a=C_alloc(13);
if(C_truep(C_i_nullp(t1))){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10209,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1446: chicken.compiler.support#qnode */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=C_i_cdr(t1);
if(C_truep(C_i_nullp(t2))){
t3=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t4=C_i_car(t1);
t5=C_a_i_list2(&a,2,((C_word*)t0)[2],t4);
/* optimizer.scm:1448: chicken.compiler.support#make-node */
t6=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=t3;
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t3=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10245,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10247,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1454: chicken.compiler.support#fold-inner */
t6=*((C_word*)lf[242]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}}

/* k10207 in k10186 in k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10209(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10209,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1446: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10243 in k10186 in k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10245,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1450: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a10246 in k10186 in k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_10247,c,av);}
a=C_alloc(12);
t4=C_eqp(*((C_word*)lf[233]+1),lf[235]);
if(C_truep(t4)){
t5=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t6=C_a_i_list2(&a,2,t2,t3);
/* optimizer.scm:1457: chicken.compiler.support#make-node */
t7=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[58];
av2[3]=t5;
av2[4]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t5=C_a_i_list2(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t6=C_a_i_list2(&a,2,t2,t3);
/* optimizer.scm:1458: chicken.compiler.support#make-node */
t7=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[121];
av2[3]=t5;
av2[4]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}}

/* a10281 in k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10282(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10282,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10308,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1443: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k10302 in k10306 in a10281 in k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10304(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10304,c,av);}
t2=C_i_car(t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_not(C_eqp(((C_word*)t0)[3],t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10306 in a10281 in k10171 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10308(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_10308,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[76],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10304,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1444: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10342 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10344(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_10344,c,av);}
a=C_alloc(14);
if(C_truep(t1)){
t2=C_i_caddr(((C_word*)t0)[2]);
t3=(C_truep(t2)?t2:*((C_word*)lf[232]+1));
if(C_truep(t3)){
t4=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10368,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=C_eqp(*((C_word*)lf[233]+1),lf[235]);
if(C_truep(t6)){
t7=C_i_cddddr(((C_word*)t0)[2]);
t8=C_i_car(t7);
t9=C_a_i_list1(&a,1,t8);
/* optimizer.scm:1475: chicken.compiler.support#make-node */
t10=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t10;
av2[1]=t5;
av2[2]=lf[58];
av2[3]=t9;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
t7=C_i_cadr(((C_word*)t0)[2]);
t8=C_a_i_list2(&a,2,t7,((C_word*)t0)[6]);
/* optimizer.scm:1479: chicken.compiler.support#make-node */
t9=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t5;
av2[2]=lf[121];
av2[3]=t8;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k10366 in k10342 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10368,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1471: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10408(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_10408,c,av);}
a=C_alloc(17);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_length(((C_word*)t0)[3]);
t4=C_i_car(((C_word*)t0)[2]);
if(C_truep(C_i_greater_or_equalp(t3,t4))){
t5=C_i_cadr(((C_word*)t0)[2]);
t6=C_a_i_list2(&a,2,C_SCHEME_TRUE,t5);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10428,a[2]=((C_word*)t0)[4],a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10432,a[2]=t7,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1496: chicken.compiler.support#varnode */
t9=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k10426 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10428(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10428,c,av);}
/* optimizer.scm:1493: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10432(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_10432,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10436,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10438,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10444,a[2]=((C_word*)t0)[6],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1498: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=t3;
av2[3]=t4;
C_call_with_values(4,av2);}}

/* k10434 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10436(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_10436,c,av);}
a=C_alloc(6);
/* optimizer.scm:1495: cons* */
f_3836(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,2,((C_word*)t0)[4],t1));}

/* a10437 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10438(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10438,c,av);}
/* optimizer.scm:1498: split-at */
f_3563(t1,((C_word*)t0)[2],((C_word*)t0)[3]);}

/* a10443 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10444(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_10444,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10452,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t5=C_i_cddr(((C_word*)t0)[2]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10458,a[2]=t7,tmp=(C_word)a,a+=3,tmp));
t9=((C_word*)t7)[1];
f_10458(t9,t4,t3,t5);}

/* k10450 in a10443 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10452,c,av);}
/* optimizer.scm:1499: scheme#append */
t2=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* loop in a10443 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_10458(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_10458,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10478,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_car(t3);
if(C_truep(C_i_symbolp(t5))){
/* optimizer.scm:1107: chicken.compiler.support#varnode */
t6=*((C_word*)lf[83]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t6=C_i_pairp(t5);
t7=(C_truep(t6)?C_eqp(lf[76],C_u_i_car(t5)):C_SCHEME_FALSE);
if(C_truep(t7)){
/* optimizer.scm:1108: chicken.compiler.support#qnode */
t8=*((C_word*)lf[77]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t4;
av2[2]=C_i_cadr(t5);
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
/* optimizer.scm:1109: chicken.compiler.support#qnode */
t8=*((C_word*)lf[77]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}}}
else{
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10505,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1508: loop */
t9=t5;
t10=C_u_i_cdr(t2);
t11=C_i_cdr(t3);
t1=t9;
t2=t10;
t3=t11;
goto loop;}}}

/* k10476 in loop in a10443 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_10478,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10482,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1506: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10458(t3,t2,C_SCHEME_END_OF_LIST,C_u_i_cdr(((C_word*)t0)[4]));}

/* k10480 in k10476 in loop in a10443 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10482(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10482,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10503 in loop in a10443 in k10430 in k10406 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10505(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10505,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10578(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,8)))){
C_save_and_reclaim((void *)f_10578,c,av);}
a=C_alloc(39);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_END_OF_LIST;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_END_OF_LIST;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_fix(0);
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10581,a[2]=t17,a[3]=t7,a[4]=t9,a[5]=t11,a[6]=t13,a[7]=t15,a[8]=t3,tmp=(C_word)a,a+=9,tmp));
t19=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10792,a[2]=t11,a[3]=t3,a[4]=t9,a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t20=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11223,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t21=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11869,a[2]=t1,a[3]=t5,a[4]=t13,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1746: chicken.compiler.support#debugging */
t22=*((C_word*)lf[35]+1);{
C_word *av2=av;
av2[0]=t22;
av2[1]=t21;
av2[2]=lf[48];
av2[3]=lf[185];
((C_proc)(void*)(*((C_word*)t22+1)))(4,av2);}}

/* walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_10581(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,2)))){
C_save_and_reclaim_args((void *)trf_10581,5,t0,t1,t2,t3,t4);}
a=C_alloc(13);
t5=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10585,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,a[5]=t2,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=t4,a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[6],a[11]=((C_word*)t0)[7],a[12]=((C_word*)t0)[8],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:1529: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10585(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_10585,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_10588,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* optimizer.scm:1530: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10588(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_10588,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_10591,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
/* optimizer.scm:1531: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10591(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_10591,c,av);}
a=C_alloc(22);
t2=C_eqp(t1,lf[29]);
if(C_truep(t2)){
t3=C_i_caddr(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10606,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[6])){
if(C_truep(C_i_cadr(((C_word*)t0)[2]))){
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10709,a[2]=t3,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[13],a[7]=t4,a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[14],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:1536: chicken.compiler.support#db-get */
t6=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[14];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[131];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}
else{
t3=C_eqp(t1,lf[31]);
if(C_truep(t3)){
/* optimizer.scm:1550: walk */
t4=((C_word*)((C_word*)t0)[11])[1];
f_10581(t4,((C_word*)t0)[4],C_i_car(((C_word*)t0)[2]),C_i_car(((C_word*)t0)[12]),C_SCHEME_FALSE);}
else{
t4=C_eqp(t1,lf[26]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10735,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[12],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1552: walk */
t6=((C_word*)((C_word*)t0)[11])[1];
f_10581(t6,t5,C_i_car(((C_word*)t0)[2]),C_i_car(((C_word*)t0)[12]),((C_word*)t0)[5]);}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10751,a[2]=((C_word*)t0)[11],tmp=(C_word)a,a+=3,tmp);
t6=C_i_check_list_2(((C_word*)t0)[12],lf[23]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10763,a[2]=t8,a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_10763(t10,((C_word*)t0)[4],((C_word*)t0)[12]);}}}}

/* k10604 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_10606,c,av);}
if(C_truep(t1)){
/* optimizer.scm:1548: transform */
t2=((C_word*)((C_word*)t0)[2])[1];
f_11223(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)((C_word*)t0)[6])[1],((C_word*)((C_word*)t0)[7])[1],((C_word*)t0)[8],((C_word*)((C_word*)t0)[9])[1]);}
else{
/* optimizer.scm:1549: walk */
t2=((C_word*)((C_word*)t0)[10])[1];
f_10581(t2,((C_word*)t0)[3],C_SCHEME_FALSE,C_i_car(((C_word*)t0)[11]),C_SCHEME_FALSE);}}

/* k10635 in k10707 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10637(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_10637,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10643,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:1539: chicken.compiler.support#db-get-list */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}

/* k10641 in k10635 in k10707 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_10643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_10643,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10649,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:1540: chicken.compiler.support#db-get-list */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[157];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}

/* k10647 in k10641 in k10635 in k10707 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_10649(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_10649,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=C_eqp(((C_word*)t0)[2],((C_word*)t0)[3]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10697,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10705,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1544: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}
else{
t2=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}

/* k10695 in k10647 in k10641 in k10635 in k10707 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_10697(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_10697,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
t2=C_i_length(((C_word*)t0)[2]);
t3=C_i_length(((C_word*)t0)[3]);
t4=C_eqp(t2,t3);
if(C_truep(t4)){
t5=C_i_car(((C_word*)t0)[4]);
t6=C_i_car(((C_word*)t0)[5]);
t7=C_a_i_cons(&a,2,((C_word*)t0)[6],((C_word*)t0)[5]);
/* optimizer.scm:1547: scan */
t8=((C_word*)((C_word*)t0)[7])[1];
f_10792(t8,((C_word*)t0)[8],t5,t6,((C_word*)t0)[6],((C_word*)t0)[9],t7);}
else{
t5=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}
else{
t2=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}

/* k10703 in k10647 in k10641 in k10635 in k10707 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_10705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10705,c,av);}
/* optimizer.scm:1543: chicken.compiler.support#variable-mark */
t2=*((C_word*)lf[86]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_car(t1);
av2[3]=lf[163];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k10707 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10709(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_10709,c,av);}
a=C_alloc(10);
if(C_truep(C_i_not(t1))){
if(C_truep(C_i_listp(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10637,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:1538: chicken.compiler.support#db-get */
t3=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[81];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}
else{
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_10606(2,av2);}}}

/* k10733 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10735,c,av);}
/* optimizer.scm:1553: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10581(t2,((C_word*)t0)[3],C_SCHEME_FALSE,C_i_cadr(((C_word*)t0)[4]),C_SCHEME_FALSE);}

/* g2229 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_10751(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_10751,3,t0,t1,t2);}
/* optimizer.scm:1554: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10581(t3,t1,C_SCHEME_FALSE,t2,C_SCHEME_FALSE);}

/* for-each-loop2228 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_10763(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_10763,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10773,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1554: g2229 */
t4=((C_word*)t0)[3];
f_10751(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k10771 in for-each-loop2228 in k10589 in k10586 in k10583 in walk in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10773(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10773,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_10763(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_10792(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,0,6)))){
C_save_and_reclaim_args((void *)trf_10792,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(25);
t7=C_SCHEME_END_OF_LIST;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_FALSE;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10795,a[2]=t6,a[3]=t10,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=t8,a[7]=t12,a[8]=t5,a[9]=((C_word*)t0)[4],a[10]=t4,a[11]=((C_word*)t0)[5],a[12]=t3,tmp=(C_word)a,a+=13,tmp));
t14=C_set_block_item(((C_word*)t0)[5],0,C_SCHEME_END_OF_LIST);
t15=C_set_block_item(((C_word*)t0)[4],0,C_SCHEME_END_OF_LIST);
t16=C_set_block_item(((C_word*)t0)[2],0,C_fix(0));
t17=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11214,a[2]=t8,a[3]=t1,a[4]=t3,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1633: rec */
t18=((C_word*)t12)[1];
f_10795(t18,t17,t2,C_SCHEME_FALSE,C_SCHEME_FALSE,t6);}

/* rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_10795(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,2)))){
C_save_and_reclaim_args((void *)trf_10795,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(18);
t6=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10799,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t3,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=t5,a[11]=t4,a[12]=((C_word*)t0)[8],a[13]=((C_word*)t0)[9],a[14]=((C_word*)t0)[10],a[15]=((C_word*)t0)[11],a[16]=((C_word*)t0)[12],a[17]=t2,tmp=(C_word)a,a+=18,tmp);
/* optimizer.scm:1560: chicken.compiler.support#node-parameters */
t7=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_10799,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_10802,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
/* optimizer.scm:1561: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[17];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10802(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_10802,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_10805,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],tmp=(C_word)a,a+=20,tmp);
/* optimizer.scm:1562: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[18];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,5)))){
C_save_and_reclaim((void *)f_10805,c,av);}
a=C_alloc(33);
t2=C_eqp(t1,lf[24]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10844,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1565: chicken.compiler.support#db-get */
t5=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
av2[3]=t3;
av2[4]=lf[164];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t3=C_eqp(t1,lf[29]);
if(C_truep(t3)){
if(C_truep(((C_word*)t0)[8])){
t4=C_i_caddr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10862,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[12],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1573: ##sys#decompose-lambda-list */
t6=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[3];
av2[2]=t4;
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=C_eqp(t1,lf[121]);
if(C_truep(t4)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[5])[1]))){
t5=C_i_cadr(((C_word*)t0)[2]);
t6=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[6])[1],t5);
t7=C_mutate(((C_word *)((C_word*)t0)[6])+1,t6);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10899,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1582: every */
f_3772(((C_word*)t0)[3],t8,((C_word*)t0)[10]);}
else{
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t5=C_eqp(t1,lf[101]);
if(C_truep(t5)){
if(C_truep(((C_word*)t0)[13])){
if(C_truep(((C_word*)t0)[14])){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10933,a[2]=((C_word*)t0)[15],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1585: chicken.compiler.support#scan-used-variables */
t7=*((C_word*)lf[165]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_car(((C_word*)t0)[10]);
av2[3]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t6=C_eqp(t1,lf[166]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10949,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1590: chicken.compiler.support#estimate-foreign-result-size */
t8=*((C_word*)lf[167]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=C_eqp(t1,lf[168]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10988,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1598: chicken.compiler.support#estimate-foreign-result-size */
t9=*((C_word*)lf[167]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=C_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=C_eqp(t1,lf[30]);
if(C_truep(t8)){
t9=C_i_car(((C_word*)t0)[10]);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11096,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[16],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[17],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[18],a[11]=t9,tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:1607: chicken.compiler.support#node-class */
t11=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=t9;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t9=C_eqp(t1,lf[169]);
if(C_truep(t9)){
t10=C_i_cadddr(((C_word*)t0)[2]);
t11=C_i_zerop(t10);
if(C_truep(t11)){
t12=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[5])[1]))){
t12=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[6])[1],t10);
t13=C_mutate(((C_word *)((C_word*)t0)[6])+1,t12);
t14=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11124,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1624: every */
f_3772(((C_word*)t0)[3],t14,((C_word*)t0)[10]);}
else{
t12=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}}
else{
t10=C_eqp(t1,lf[31]);
if(C_truep(t10)){
/* optimizer.scm:1625: rec */
t11=((C_word*)((C_word*)t0)[11])[1];
f_10795(t11,((C_word*)t0)[3],C_i_car(((C_word*)t0)[10]),C_i_car(((C_word*)t0)[2]),C_SCHEME_FALSE,((C_word*)t0)[12]);}
else{
t11=C_eqp(t1,lf[26]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11157,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[12],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1627: rec */
t13=((C_word*)((C_word*)t0)[11])[1];
f_10795(t13,t12,C_i_car(((C_word*)t0)[10]),C_i_car(((C_word*)t0)[2]),((C_word*)t0)[19],((C_word*)t0)[12]);}
else{
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11181,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1629: every */
f_3772(((C_word*)t0)[3],t12,((C_word*)t0)[10]);}}}}}}}}}}}

/* k10842 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10844(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_10844,c,av);}
a=C_alloc(29);
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_memq(((C_word*)t0)[3],((C_word*)t0)[4]);
t4=C_i_not(t3);
if(C_truep(t4)){
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[5])[1]))){
t5=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[6])[1],C_fix(2));
t6=C_mutate(((C_word *)((C_word*)t0)[6])+1,t5);
t7=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}}}

/* a10861 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10862,c,av);}
a=C_alloc(8);
t5=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[3])+1,t5);
t7=C_i_car(((C_word*)t0)[4]);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10878,a[2]=((C_word*)t0)[5],a[3]=t1,a[4]=t7,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1577: scheme#append */
t9=*((C_word*)lf[7]+1);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
av2[2]=t2;
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}

/* k10876 in a10861 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_10878(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_10878,c,av);}
/* optimizer.scm:1577: rec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10795(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_FALSE,C_SCHEME_FALSE,t1);}

/* a10898 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10899(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_10899,c,av);}
/* optimizer.scm:1582: rec */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10795(t3,t1,t2,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[3]);}

/* k10931 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10933(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10933,c,av);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t1))){
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k10947 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(35,c,2)))){
C_save_and_reclaim((void *)f_10949,c,av);}
a=C_alloc(35);
t2=C_i_zerop(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10953,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t2)){
t4=t3;
f_10953(t4,t2);}
else{
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[6])[1]))){
t4=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[7])[1],t1);
t5=C_mutate(((C_word *)((C_word*)t0)[7])+1,t4);
t6=t3;
f_10953(t6,C_SCHEME_TRUE);}
else{
t4=t3;
f_10953(t4,C_SCHEME_FALSE);}}}

/* k10951 in k10947 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_fcall f_10953(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_10953,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10958,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1596: every */
f_3772(((C_word*)t0)[4],t2,((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a10957 in k10951 in k10947 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_10958(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_10958,c,av);}
/* optimizer.scm:1596: rec */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10795(t3,t1,t2,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[3]);}

/* k10986 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_10988(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(35,c,2)))){
C_save_and_reclaim((void *)f_10988,c,av);}
a=C_alloc(35);
t2=C_i_zerop(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10992,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t2)){
t4=t3;
f_10992(t4,t2);}
else{
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[6])[1]))){
t4=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[7])[1],t1);
t5=C_mutate(((C_word *)((C_word*)t0)[7])+1,t4);
t6=t3;
f_10992(t6,C_SCHEME_TRUE);}
else{
t4=t3;
f_10992(t4,C_SCHEME_FALSE);}}}

/* k10990 in k10986 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_fcall f_10992(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_10992,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10997,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1604: every */
f_3772(((C_word*)t0)[4],t2,((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a10996 in k10990 in k10986 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_10997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_10997,c,av);}
/* optimizer.scm:1604: rec */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10795(t3,t1,t2,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[3]);}

/* k11037 in k11090 in k11094 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_fcall f_11039(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_11039,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11044,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1617: every */
f_3772(((C_word*)t0)[4],t2,C_i_cdr(((C_word*)t0)[5]));}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a11043 in k11037 in k11090 in k11094 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_11044(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11044,c,av);}
/* optimizer.scm:1617: rec */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10795(t3,t1,t2,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[3]);}

/* k11079 in k11083 in k11090 in k11094 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_11081(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_11081,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,((C_word*)((C_word*)t0)[2])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t5=C_set_block_item(((C_word*)t0)[3],0,C_SCHEME_TRUE);
t6=((C_word*)t0)[4];
f_11039(t6,C_SCHEME_TRUE);}

/* k11083 in k11090 in k11094 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_11085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11085,c,av);}
a=C_alloc(5);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11081,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1613: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_set_block_item(((C_word*)t0)[3],0,C_SCHEME_TRUE);
t4=((C_word*)t0)[4];
f_11039(t4,C_SCHEME_TRUE);}}

/* k11090 in k11094 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_11092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_11092,c,av);}
a=C_alloc(12);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11039,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=C_eqp(t2,((C_word*)t0)[6]);
if(C_truep(t4)){
t5=((C_word*)((C_word*)t0)[7])[1];
if(C_truep(C_i_zerop(t5))){
t6=C_i_cadr(((C_word*)t0)[5]);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11085,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[9],a[4]=t3,a[5]=t6,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1612: chicken.compiler.support#node-class */
t8=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t6=t3;
f_11039(t6,C_SCHEME_FALSE);}}
else{
t5=t3;
f_11039(t5,C_eqp(t2,((C_word*)t0)[10]));}}

/* k11094 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_11096,c,av);}
a=C_alloc(11);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11092,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:1608: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a11123 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11124,c,av);}
/* optimizer.scm:1624: rec */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10795(t3,t1,t2,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[3]);}

/* k11155 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11157,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11168,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1628: scheme#append */
t4=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k11166 in k11155 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_11168(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11168,c,av);}
/* optimizer.scm:1628: rec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10795(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_FALSE,C_SCHEME_FALSE,t1);}

/* a11180 in k10803 in k10800 in k10797 in rec in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11181(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11181,c,av);}
/* optimizer.scm:1629: rec */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10795(t3,t1,t2,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[3]);}

/* k11212 in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11214(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11214,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11221,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1634: delete */
f_3892(t2,((C_word*)t0)[4],((C_word*)((C_word*)t0)[5])[1],*((C_word*)lf[47]+1));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k11219 in k11212 in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11221(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_11221,c,av);}
a=C_alloc(3);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_i_length(t2);
t4=C_i_length(t1);
t5=C_eqp(t3,t4);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4468,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:197: every */
f_3772(((C_word*)t0)[3],t6,t2);}
else{
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_11223(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7){
C_word tmp;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,5)))){
C_save_and_reclaim_args((void *)trf_11223,8,t0,t1,t2,t3,t4,t5,t6,t7);}
a=C_alloc(19);
t8=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11227,a[2]=((C_word*)t0)[2],a[3]=t7,a[4]=t3,a[5]=t6,a[6]=t5,a[7]=t1,a[8]=t4,a[9]=t2,a[10]=((C_word*)t0)[3],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_pairp(t5))){
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11847,a[2]=t8,a[3]=t3,a[4]=t7,tmp=(C_word)a,a+=5,tmp);
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11849,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1638: ##sys#make-promise */
t11=*((C_word*)lf[182]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t9;
av2[2]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
/* optimizer.scm:1639: chicken.compiler.support#debugging */
t9=*((C_word*)lf[35]+1);{
C_word av2[6];
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[36];
av2[3]=lf[184];
av2[4]=t3;
av2[5]=t7;
((C_proc)(void*)(*((C_word*)t9+1)))(6,av2);}}}

/* k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_11227,c,av);}
a=C_alloc(10);
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11231,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:1641: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11231(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_11231,c,av);}
a=C_alloc(14);
t2=C_i_caddr(t1);
t3=C_i_length(t2);
t4=C_SCHEME_END_OF_LIST;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11237,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=t5,a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[8],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:1644: chicken.compiler.support#db-get-list */
t7=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[157];
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}

/* k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_11237,c,av);}
a=C_alloc(16);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_11243,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t3,a[10]=t1,a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],tmp=(C_word)a,a+=14,tmp);
if(C_truep(C_i_listp(((C_word*)t0)[2]))){
t5=C_eqp(C_u_i_length(((C_word*)t0)[2]),C_fix(4));
t6=t4;
f_11243(t6,(C_truep(t5)?C_i_listp(C_i_caddr(((C_word*)t0)[2])):C_SCHEME_FALSE));}
else{
t5=t4;
f_11243(t5,C_SCHEME_FALSE);}}

/* k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_11243(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,3)))){
C_save_and_reclaim_args((void *)trf_11243,2,t0,t1);}
a=C_alloc(15);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_11249,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
/* optimizer.scm:1648: scheme#caaddr */
t4=*((C_word*)lf[179]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* optimizer.scm:1744: chicken.compiler.support#bomb */
t2=*((C_word*)lf[174]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[8];
av2[2]=lf[180];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_11249,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_11252,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* optimizer.scm:1649: scheme#cdaddr */
t3=*((C_word*)lf[178]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_11252(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_11252,c,av);}
a=C_alloc(15);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_setslot(C_u_i_cdr(t2),C_fix(0),t1);
t4=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_11258,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[15],tmp=(C_word)a,a+=15,tmp);
/* optimizer.scm:1653: chicken.compiler.support#node-class-set! */
t5=*((C_word*)lf[172]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[15];
av2[3]=lf[101];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_11258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_11258,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11261,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11807,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[12],a[7]=((C_word*)t0)[13],a[8]=t2,tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:1656: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[14];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_11261(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_11261,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11262,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11335,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11509,a[2]=((C_word*)t0)[9],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1718: filter */
f_4012(t3,t4,((C_word*)t0)[10]);}

/* g2348 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_fcall f_11262(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_11262,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_cdr(t2);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11269,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1703: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k11267 in g2348 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_11269(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_11269,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11272,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:1704: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11270 in k11267 in g2348 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_11272(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_11272,c,av);}
a=C_alloc(8);
t2=C_i_cdr(t1);
t3=C_i_pairp(t2);
t4=(C_truep(t3)?C_i_cadr(t1):C_SCHEME_FALSE);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11278,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t4,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t6=C_i_cdr(((C_word*)t0)[2]);
t7=C_i_length(t6);
t8=C_eqp(((C_word*)t0)[7],t7);
if(C_truep(t8)){
t9=t5;{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_SCHEME_UNDEFINED;
f_11278(2,av2);}}
else{
/* optimizer.scm:1708: chicken.compiler.support#quit-compiling */
t9=*((C_word*)lf[170]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t9;
av2[1]=t5;
av2[2]=lf[171];
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}}

/* k11276 in k11270 in k11267 in g2348 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_11278(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,4)))){
C_save_and_reclaim((void *)f_11278,c,av);}
a=C_alloc(20);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11293,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_a_i_list4(&a,4,C_SCHEME_TRUE,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);
t5=C_u_i_car(((C_word*)t0)[2]);
t6=C_i_cddr(((C_word*)t0)[2]);
t7=C_a_i_cons(&a,2,t5,t6);
/* optimizer.scm:1714: chicken.compiler.support#make-node */
t8=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t3;
av2[2]=lf[169];
av2[3]=t4;
av2[4]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}

/* k11291 in k11276 in k11270 in k11267 in g2348 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_11293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_11293,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1711: chicken.compiler.support#node-subexpressions-set! */
t3=*((C_word*)lf[152]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_11335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_11335,c,av);}
a=C_alloc(11);
t2=C_i_check_list_2(t1,lf[23]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11341,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11486,a[2]=t5,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_11486(t7,t3,t1);}

/* k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_11341(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_11341,c,av);}
a=C_alloc(5);
t2=(C_truep(((C_word*)t0)[2])?C_i_pairp(((C_word*)t0)[3]):C_SCHEME_FALSE);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11350,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1725: chicken.compiler.support#make-node */
t4=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_FALSE;
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_11350(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_11350,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11353,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1726: chicken.compiler.support#copy-node! */
t3=*((C_word*)lf[32]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_11353(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_11353,c,av);}
a=C_alloc(11);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[6]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11359,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11417,a[2]=t5,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_11417(t7,t3,((C_word*)t0)[2]);}

/* k11357 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_11359(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_11359,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11362,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1737: chicken.compiler.support#copy-node! */
t3=*((C_word*)lf[32]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11360 in k11357 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_11362(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11362,c,av);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11394,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_11394(t5,((C_word*)t0)[2],((C_word*)t0)[3]);}

/* k11368 in for-each-loop2473 in k11360 in k11357 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_11370(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11370,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11377,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1742: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11375 in k11368 in for-each-loop2473 in k11360 in k11357 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in ... */
static void C_ccall f_11377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_11377,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11381,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1742: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11379 in k11375 in k11368 in for-each-loop2473 in k11360 in k11357 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in ... */
static void C_ccall f_11381(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11381,c,av);}
t2=C_i_set_car(((C_word*)t0)[2],t1);
t3=((C_word*)((C_word*)t0)[3])[1];
f_11394(t3,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11387 in for-each-loop2473 in k11360 in k11357 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_11389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_11389,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1741: chicken.compiler.support#node-parameters-set! */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* for-each-loop2473 in k11360 in k11357 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_fcall f_11394(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_11394,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_cdr(t3);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11370,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11389,a[2]=t5,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1741: chicken.base#gensym */
t7=*((C_word*)lf[116]+1);{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* foldr2459 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_fcall f_11417(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_11417,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11477,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=t4;
t7=C_slot(t2,C_fix(1));
t1=t6;
t2=t7;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11442 in k11458 in k11475 in foldr2459 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_11444(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_11444,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,t1,((C_word*)t0)[2]);
/* optimizer.scm:1730: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11446 in k11458 in k11475 in foldr2459 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_11448(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11448,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11452,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1733: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11450 in k11446 in k11458 in k11475 in foldr2459 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in ... */
static void C_ccall f_11452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11452,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11456,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1733: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11454 in k11450 in k11446 in k11458 in k11475 in foldr2459 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in ... */
static void C_ccall f_11456(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11456,c,av);}
/* optimizer.scm:1733: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k11458 in k11475 in foldr2459 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_ccall f_11460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_11460,c,av);}
a=C_alloc(9);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11444,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11448,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1733: chicken.compiler.support#node-class */
t5=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k11475 in foldr2459 in k11351 in k11348 in k11339 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_11477(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_11477,c,av);}
a=C_alloc(8);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_a_i_list1(&a,1,t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11460,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1732: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_u_i_cdr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* for-each-loop2347 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_fcall f_11486(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_11486,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11496,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1700: g2348 */
t4=((C_word*)t0)[3];
f_11262(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k11494 in for-each-loop2347 in k11333 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_11496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11496,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_11486(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* a11508 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_11509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_11509,c,av);}
a=C_alloc(6);
t3=C_i_cdr(t2);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11520,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11522,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1720: any */
f_3806(t4,t5,((C_word*)((C_word*)t0)[2])[1]);}

/* k11518 in a11508 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_11520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11520,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_not(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a11521 in a11508 in k11259 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_11522(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11522,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_eqp(C_i_cdr(t2),((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_fcall f_11536(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_11536,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11540,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=t1,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:1657: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_11540(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_11540,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11543,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:1658: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_11543(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_11543,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11546,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:1659: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_11546(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_11546,c,av);}
a=C_alloc(13);
t2=C_eqp(t1,lf[30]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=C_i_cadr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11561,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t3,a[12]=t4,tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:1663: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t3=C_eqp(t1,lf[26]);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[11]);
t5=C_i_car(((C_word*)t0)[2]);
if(C_truep(C_i_memq(t4,((C_word*)t0)[12]))){
t6=((C_word*)((C_word*)t0)[9])[1];
t7=C_a_i_cons(&a,2,t4,t5);
t8=C_a_i_cons(&a,2,t7,t6);
t9=C_mutate(((C_word *)((C_word*)t0)[9])+1,t8);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11734,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1693: chicken.compiler.support#copy-node! */
t11=*((C_word*)lf[32]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t11+1)))(4,av2);}}
else{
t6=C_i_check_list_2(((C_word*)t0)[2],lf[23]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11749,a[2]=t8,a[3]=((C_word*)t0)[10],tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_11749(t10,((C_word*)t0)[7],((C_word*)t0)[2]);}}
else{
t4=C_i_check_list_2(((C_word*)t0)[2],lf[23]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11778,a[2]=t6,a[3]=((C_word*)t0)[10],tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_11778(t8,((C_word*)t0)[7],((C_word*)t0)[2]);}}}

/* k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_11561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_11561,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11564,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:1664: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_11564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_11564,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11709,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:1665: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11587 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_11589(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_11589,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11592,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_a_i_list2(&a,2,C_SCHEME_TRUE,((C_word*)t0)[5]);
/* optimizer.scm:1670: chicken.compiler.support#node-parameters-set! */
t4=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k11590 in k11587 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in ... */
static void C_ccall f_11592(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11592,c,av);}
/* optimizer.scm:1671: chicken.compiler.support#node-subexpressions-set! */
t2=*((C_word*)lf[152]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_cddr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in ... */
static void C_fcall f_11610(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_11610,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_cdr(t2);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11661,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t3,tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1675: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k11618 in k11659 in g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in ... */
static void C_ccall f_11620(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_11620,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11623,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11649,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11657,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1677: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k11621 in k11618 in k11659 in g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in ... */
static void C_ccall f_11623(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_11623,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11626,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11637,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
t4=C_a_i_list2(&a,2,C_SCHEME_FALSE,((C_word*)t0)[6]);
/* optimizer.scm:1680: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[173];
av2[3]=t4;
av2[4]=C_i_cddr(((C_word*)t0)[7]);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k11624 in k11621 in k11618 in k11659 in g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in ... */
static void C_ccall f_11626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11626,c,av);}
/* optimizer.scm:1681: rec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_11536(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k11635 in k11621 in k11618 in k11659 in g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in ... */
static void C_ccall f_11637(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_11637,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,t1,((C_word*)t0)[2]);
/* optimizer.scm:1678: chicken.compiler.support#node-subexpressions-set! */
t3=*((C_word*)lf[152]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11647 in k11618 in k11659 in g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in ... */
static void C_ccall f_11649(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11649,c,av);}
/* optimizer.scm:1677: chicken.compiler.support#node-parameters-set! */
t2=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k11655 in k11618 in k11659 in g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in ... */
static void C_ccall f_11657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11657,c,av);}
/* optimizer.scm:1677: take */
f_3511(((C_word*)t0)[2],C_i_caddr(t1),C_fix(1));}

/* k11659 in g2381 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in ... */
static void C_ccall f_11661(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_11661,c,av);}
a=C_alloc(9);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11620,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:1676: chicken.compiler.support#node-class-set! */
t4=*((C_word*)lf[172]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[26];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k11682 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_11684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11684,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11687,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1685: chicken.compiler.support#node-parameters-set! */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11685 in k11682 in k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in ... */
static void C_ccall f_11687(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11687,c,av);}
/* optimizer.scm:1686: chicken.compiler.support#node-subexpressions-set! */
t2=*((C_word*)lf[152]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_cdr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k11707 in k11562 in k11559 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_ccall f_11709(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_11709,c,av);}
a=C_alloc(12);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=C_eqp(((C_word*)t0)[3],t3);
if(C_truep(t4)){
t5=((C_word*)((C_word*)t0)[4])[1];
t6=C_a_i_cons(&a,2,C_SCHEME_FALSE,((C_word*)t0)[5]);
t7=C_a_i_cons(&a,2,t6,t5);
t8=C_mutate(((C_word *)((C_word*)t0)[4])+1,t7);
t9=C_i_car(((C_word*)t0)[6]);
t10=C_eqp(((C_word*)t0)[7],t9);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11589,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1669: chicken.compiler.support#node-class-set! */
t12=*((C_word*)lf[172]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t12;
av2[1]=t11;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[173];
((C_proc)(void*)(*((C_word*)t12+1)))(4,av2);}}
else{
t11=C_i_car(((C_word*)t0)[6]);
t12=C_i_assq(t11,((C_word*)((C_word*)t0)[11])[1]);
if(C_truep(t12)){
t13=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11610,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[9],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1668: g2381 */
t14=t13;
f_11610(t14,((C_word*)t0)[8],t12);}
else{
/* optimizer.scm:1682: chicken.compiler.support#bomb */
t13=*((C_word*)lf[174]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t13;
av2[1]=((C_word*)t0)[8];
av2[2]=lf[175];
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t13+1)))(4,av2);}}}}
else{
t5=C_i_car(((C_word*)t0)[2]);
t6=C_eqp(((C_word*)t0)[7],t5);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11684,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[9],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1684: chicken.compiler.support#node-class-set! */
t8=*((C_word*)lf[172]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[176];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
/* optimizer.scm:1687: chicken.compiler.support#bomb */
t7=*((C_word*)lf[174]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[8];
av2[2]=lf[177];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}}
else{
t3=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11732 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_11734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11734,c,av);}
/* optimizer.scm:1694: rec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_11536(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* for-each-loop2402 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_fcall f_11749(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_11749,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11759,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1695: g2403 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_11536(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k11757 in for-each-loop2402 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_11759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11759,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_11749(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop2419 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_fcall f_11778(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_11778,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11788,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1697: g2420 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_11536(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k11786 in for-each-loop2419 in k11544 in k11541 in k11538 in rec in k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_11788(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11788,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_11778(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k11805 in k11256 in k11250 in k11247 in k11241 in k11235 in k11229 in k11225 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_11807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_11807,c,av);}
a=C_alloc(11);
t2=C_i_car(t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11536,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t4,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp));
t6=((C_word*)t4)[1];
f_11536(t6,((C_word*)t0)[8],t2);}

/* k11845 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11847,c,av);}
/* optimizer.scm:1638: chicken.compiler.support#debugging */
t2=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[36];
av2[3]=lf[181];
av2[4]=((C_word*)t0)[3];
av2[5]=t1;
av2[6]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(7,av2);}}

/* a11848 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_11849,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11857,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11859,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1638: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=t3;
av2[3]=*((C_word*)lf[183]+1);
C_call_with_values(4,av2);}}

/* k11855 in a11848 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11857(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11857,c,av);}
/* optimizer.scm:1638: ##sys#make-promise */
t2=*((C_word*)lf[182]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a11858 in a11848 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_11859,c,av);}
a=C_alloc(12);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(((C_word*)t0)[2],lf[8]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4138,a[2]=t4,a[3]=t8,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_4138(t10,t1,((C_word*)t0)[2]);}

/* k11867 in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11869,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11872,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1747: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_10581(t3,t2,C_SCHEME_FALSE,((C_word*)t0)[5],C_SCHEME_FALSE);}

/* k11870 in k11867 in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11872(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11872,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11874(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_11874,c,av);}
a=C_alloc(29);
t4=C_SCHEME_END_OF_LIST;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_FALSE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_END_OF_LIST;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11877,a[2]=t9,a[3]=t7,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t15=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11927,a[2]=t7,a[3]=t13,a[4]=t9,a[5]=t11,a[6]=t3,tmp=(C_word)a,a+=7,tmp));
t16=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12166,a[2]=t3,a[3]=t5,a[4]=t1,a[5]=t2,a[6]=t13,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1831: chicken.compiler.support#debugging */
t17=*((C_word*)lf[35]+1);{
C_word *av2=av;
av2[0]=t17;
av2[1]=t16;
av2[2]=lf[48];
av2[3]=lf[196];
((C_proc)(void*)(*((C_word*)t17+1)))(4,av2);}}

/* close in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_11877(C_word *a,C_word t0){
C_word tmp;
C_word t1;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_stack_overflow_check;{}
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[2])[1]))){
t1=C_i_length(((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(C_fixnum_greaterp(t1,C_fix(1)))){
t2=((C_word*)((C_word*)t0)[3])[1];
t3=((C_word*)((C_word*)t0)[2])[1];
t4=((C_word*)((C_word*)t0)[4])[1];
t5=C_a_i_cons(&a,2,t2,t3);
t6=C_a_i_cons(&a,2,t5,t4);
t7=C_mutate(((C_word *)((C_word*)t0)[4])+1,t6);
t8=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_END_OF_LIST);
t9=C_set_block_item(((C_word*)t0)[3],0,C_SCHEME_FALSE);
return(t9);}
else{
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_END_OF_LIST);
t3=C_set_block_item(((C_word*)t0)[3],0,C_SCHEME_FALSE);
return(t3);}}
else{
t1=C_SCHEME_UNDEFINED;
return(t1);}}

/* k11919 in k11923 in k12039 in k12043 in k12047 in k12051 in k12055 in k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_11921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11921,c,av);}
t2=((C_word*)t0)[2];
f_11972(t2,C_i_listp(C_i_caddr(t1)));}

/* k11923 in k12039 in k12043 in k12047 in k12051 in k12055 in k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_11925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11925,c,av);}
a=C_alloc(3);
t2=C_eqp(lf[29],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11921,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1784: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_11972(t3,C_SCHEME_FALSE);}}

/* walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_11927(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_11927,4,t0,t1,t2,t3);}
a=C_alloc(10);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11931,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=t1,a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:1787: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11931(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_11931,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11934,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:1788: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11934(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_11934,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11937,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:1789: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_11937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,5)))){
C_save_and_reclaim((void *)f_11937,c,av);}
a=C_alloc(16);
t2=C_eqp(t1,lf[26]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=C_i_car(((C_word*)t0)[3]);
t5=C_i_cadr(((C_word*)t0)[3]);
t6=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11958,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t3,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t5,a[9]=t4,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[4])[1]))){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12071,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1796: chicken.compiler.support#node-class */
t8=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=t6;
f_11958(t7,C_SCHEME_FALSE);}}
else{
t3=C_eqp(t1,lf[29]);
t4=(C_truep(t3)?t3:C_eqp(t1,lf[101]));
if(C_truep(t4)){
t5=C_i_caddr(((C_word*)t0)[2]);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12089,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1819: ##sys#decompose-lambda-list */
t7=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[8];
av2[2]=t5;
av2[3]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t5=(
/* optimizer.scm:1828: close */
  f_11877(C_a_i(&a,6),((C_word*)((C_word*)t0)[10])[1])
);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12121,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t7=C_i_check_list_2(((C_word*)t0)[3],lf[23]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12133,a[2]=t9,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t11=((C_word*)t9)[1];
f_12133(t11,((C_word*)t0)[8],((C_word*)t0)[3]);}}}

/* k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_11958(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,3)))){
C_save_and_reclaim_args((void *)trf_11958,2,t0,t1);}
a=C_alloc(16);
if(C_truep(t1)){
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]);
/* optimizer.scm:1799: walk */
t4=((C_word*)((C_word*)t0)[6])[1];
f_11927(t4,((C_word*)t0)[7],((C_word*)t0)[8],t3);}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11972,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[11],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12061,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[9],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1801: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;
f_11972(t3,C_SCHEME_FALSE);}}}

/* k11970 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_11972(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_11972,2,t0,t1);}
a=C_alloc(13);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,t2);
t4=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]);
/* optimizer.scm:1812: walk */
t5=((C_word*)((C_word*)t0)[6])[1];
f_11927(t5,((C_word*)t0)[7],((C_word*)t0)[8],t4);}
else{
t2=(
/* optimizer.scm:1815: close */
  f_11877(C_a_i(&a,6),((C_word*)((C_word*)t0)[9])[1])
);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11989,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1816: walk */
t4=((C_word*)((C_word*)t0)[6])[1];
f_11927(t4,t3,((C_word*)t0)[2],((C_word*)t0)[5]);}}

/* k11987 in k11970 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_11989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_11989,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* optimizer.scm:1817: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_11927(t3,((C_word*)t0)[5],((C_word*)t0)[6],t2);}

/* k12039 in k12043 in k12047 in k12051 in k12055 in k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_12041(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_12041,c,av);}
a=C_alloc(4);
t2=C_i_length(t1);
t3=C_eqp(((C_word*)t0)[2],t2);
if(C_truep(t3)){
if(C_truep(C_i_memq(((C_word*)t0)[3],((C_word*)t0)[4]))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11925,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1783: chicken.compiler.support#node-class */
t5=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[5];
f_11972(t4,C_SCHEME_FALSE);}}
else{
t4=((C_word*)t0)[5];
f_11972(t4,C_SCHEME_FALSE);}}

/* k12043 in k12047 in k12051 in k12055 in k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_12045(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_12045,c,av);}
a=C_alloc(7);
t2=C_i_length(t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12041,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1807: chicken.compiler.support#db-get-list */
t4=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[2];
av2[4]=lf[157];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12047 in k12051 in k12055 in k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_12049(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_12049,c,av);}
a=C_alloc(7);
t2=C_eqp(lf[29],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12045,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1806: chicken.compiler.support#db-get-list */
t4=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[2];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=((C_word*)t0)[4];
f_11972(t3,C_SCHEME_FALSE);}}

/* k12051 in k12055 in k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_12053(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_12053,c,av);}
a=C_alloc(7);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12049,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1805: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12055 in k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_12057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_12057,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12053,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1803: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12059 in k11956 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12061(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_12061,c,av);}
a=C_alloc(6);
t2=C_eqp(lf[31],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12057,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1802: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];
f_11972(t3,C_SCHEME_FALSE);}}

/* k12069 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12071(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12071,c,av);}
t2=((C_word*)t0)[2];
f_11958(t2,C_eqp(lf[34],t1));}

/* a12088 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12089(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_12089,c,av);}
a=C_alloc(29);
t5=C_SCHEME_END_OF_LIST;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_FALSE;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_FALSE;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_FALSE;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12095,a[2]=t10,a[3]=((C_word*)t0)[2],a[4]=t12,a[5]=((C_word*)t0)[3],a[6]=t6,a[7]=t8,tmp=(C_word)a,a+=8,tmp);
t14=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12102,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t15=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12112,a[2]=t6,a[3]=((C_word*)t0)[2],a[4]=t8,a[5]=((C_word*)t0)[3],a[6]=t10,a[7]=t12,tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1823: ##sys#dynamic-wind */
t16=*((C_word*)lf[187]+1);{
C_word *av2=av;
av2[0]=t16;
av2[1]=t1;
av2[2]=t13;
av2[3]=t14;
av2[4]=t15;
((C_proc)(void*)(*((C_word*)t16+1)))(5,av2);}}

/* a12094 in a12088 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12095(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12095,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)((C_word*)t0)[5])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[6])[1]);
t5=C_mutate(((C_word *)((C_word*)t0)[5])+1,((C_word*)((C_word*)t0)[7])[1]);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* a12101 in a12088 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12102,c,av);}
/* optimizer.scm:1825: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_11927(t2,t1,C_i_car(((C_word*)t0)[3]),((C_word*)t0)[4]);}

/* a12111 in a12088 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12112(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12112,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)((C_word*)t0)[5])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[6])[1]);
t5=C_mutate(((C_word *)((C_word*)t0)[5])+1,((C_word*)((C_word*)t0)[7])[1]);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* g2586 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12121(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_12121,3,t0,t1,t2);}
/* optimizer.scm:1829: g2601 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_11927(t3,t1,t2,((C_word*)t0)[3]);}

/* for-each-loop2585 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12133(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_12133,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12143,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1829: g2586 */
t4=((C_word*)t0)[3];
f_12121(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k12141 in for-each-loop2585 in k11935 in k11932 in k11929 in walk in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12143(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12143,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_12133(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12166(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_12166,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12169,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1834: walk */
t3=((C_word*)((C_word*)t0)[6])[1];
f_11927(t3,t2,((C_word*)t0)[5],C_SCHEME_END_OF_LIST);}

/* k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_12169,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12170,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=((C_word*)((C_word*)t0)[3])[1];
t4=C_i_check_list_2(t3,lf[23]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12808,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12817,a[2]=t7,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_12817(t9,t5,t3);}

/* g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12170(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_12170,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12178,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1841: chicken.base#gensym */
t6=*((C_word*)lf[116]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[195];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_12178,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12181,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1842: chicken.base#gensym */
t3=*((C_word*)lf[116]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[106];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12181(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_12181,c,av);}
a=C_alloc(26);
t2=C_fix(1);
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12185,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t9=C_i_check_list_2(((C_word*)t0)[2],lf[8]);
t10=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12280,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t3,a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12770,a[2]=t6,a[3]=t12,a[4]=t8,a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_12770(t14,t10,((C_word*)t0)[2]);}

/* g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12185(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_12185,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12274,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1848: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_12195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_12195,c,av);}
a=C_alloc(20);
t2=C_i_caddr(t1);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(t2,lf[8]);
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12207,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12234,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_12234(t12,t8,t2);}

/* k12205 in k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_12207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_12207,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12212,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1853: ##sys#decompose-lambda-list */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[7];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a12211 in k12205 in k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_12212(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_12212,c,av);}
a=C_alloc(7);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12232,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1856: chicken.compiler.support#node-subexpressions */
t6=*((C_word*)lf[42]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k12219 in k12230 in a12211 in k12205 in k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_12221(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_12221,c,av);}
a=C_alloc(12);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list4(&a,4,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12226 in k12230 in a12211 in k12205 in k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_12228(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12228,c,av);}
/* optimizer.scm:1859: chicken.compiler.support#copy-node! */
t2=*((C_word*)lf[32]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k12230 in a12211 in k12205 in k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_12232(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(40,c,4)))){
C_save_and_reclaim((void *)f_12232,c,av);}
a=C_alloc(40);
t2=C_i_car(t1);
t3=((C_word*)((C_word*)t0)[2])[1];
t4=((C_word*)((C_word*)t0)[2])[1];
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t4,C_fix(1)));
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12221,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t3,a[5]=((C_word*)t0)[5],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12228,a[2]=t6,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1860: chicken.compiler.support#make-node */
t8=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}

/* map-loop2645 in k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_fcall f_12234(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_12234,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12259,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1852: g2651 */
t4=*((C_word*)lf[116]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k12257 in map-loop2645 in k12193 in k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_12259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_12259,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_12234(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k12268 in k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_12270(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_12270,c,av);}
a=C_alloc(7);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12195,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1850: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12272 in g2626 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_12274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_12274,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12270,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1849: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12280,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12283,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:1864: chicken.base#gensym */
t3=*((C_word*)lf[116]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[194];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_12283(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_12283,c,av);}
a=C_alloc(24);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12286,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(((C_word*)t0)[5],lf[8]);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12734,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12736,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_12736(t12,t8,((C_word*)t0)[5]);}

/* k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_12286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_12286,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12289,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12705,a[2]=((C_word*)t0)[7],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_12711,tmp=(C_word)a,a+=2,tmp);
/* optimizer.scm:1867: list-tabulate */
f_4414(t3,t1,t4);}

/* k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_12289(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_12289,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12292,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=lf[14];
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12667,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12669,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_12669(t12,t8,((C_word*)t0)[6]);}

/* k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_12292(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_12292,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12295,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12426,a[2]=t4,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp));
t6=((C_word*)t4)[1];
f_12426(t6,t2,((C_word*)t0)[10]);}

/* k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_12295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_12295,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12296,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12403,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_12403(t6,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_fcall f_12296(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_12296,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12300,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1932: chicken.compiler.support#db-get */
t4=*((C_word*)lf[55]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=C_i_car(t2);
av2[4]=lf[157];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_12300(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_12300,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12301,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_i_check_list_2(t1,lf[23]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12373,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_12373(t7,((C_word*)t0)[5],t1);}

/* g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_fcall f_12301(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_12301,3,t0,t1,t2);}
a=C_alloc(7);
t3=C_i_cdr(t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12365,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1936: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k12313 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_ccall f_12315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12315,c,av);}
/* optimizer.scm:1937: chicken.compiler.support#copy-node! */
t2=*((C_word*)lf[32]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k12317 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_ccall f_12319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_12319,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12323,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12327,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1940: chicken.compiler.support#varnode */
t4=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12321 in k12317 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12323,c,av);}
/* optimizer.scm:1938: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12325 in k12317 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(40,c,3)))){
C_save_and_reclaim((void *)f_12327,c,av);}
a=C_alloc(40);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12331,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12335,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_i_length(((C_word*)t0)[3]);
t5=C_s_a_i_minus(&a,2,((C_word*)t0)[5],t4);
t6=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_12353,tmp=(C_word)a,a+=2,tmp);
/* optimizer.scm:1943: list-tabulate */
f_4414(t3,t5,t6);}

/* k12329 in k12325 in k12317 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12331(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_12331,c,av);}
a=C_alloc(3);
/* optimizer.scm:1940: cons* */
f_3836(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,1,t1));}

/* k12333 in k12325 in k12317 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12335,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12343,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1946: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12341 in k12333 in k12325 in k12317 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in ... */
static void C_ccall f_12343(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_12343,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1941: scheme#append */
t3=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a12352 in k12325 in k12317 in k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12353(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12353,c,av);}
/* optimizer.scm:1945: chicken.compiler.support#qnode */
t2=*((C_word*)lf[77]+1);{
C_word av2[3];
av2[0]=t2;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12363 in g2771 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_12365(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_12365,c,av);}
a=C_alloc(11);
t2=C_i_cdr(t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12315,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12319,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1939: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* for-each-loop2770 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_fcall f_12373(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_12373,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12383,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1933: g2771 */
t4=((C_word*)t0)[3];
f_12301(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k12381 in for-each-loop2770 in k12298 in g2719 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_12383(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12383,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_12373(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop2718 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_fcall f_12403(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_12403,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12413,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1930: g2719 */
t4=((C_word*)t0)[3];
f_12296(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k12411 in for-each-loop2718 in k12293 in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_12413(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12413,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_12403(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_fcall f_12426(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_12426,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12660,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:1877: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_fcall f_12436(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,4)))){
C_save_and_reclaim_args((void *)trf_12436,2,t0,t1);}
a=C_alloc(18);
if(C_truep(t1)){
/* optimizer.scm:1881: descend */
t2=((C_word*)((C_word*)t0)[2])[1];
f_12426(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12446,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_list1(&a,1,((C_word*)t0)[6]);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12458,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:1888: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k12444 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_12446(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12446,c,av);}
/* optimizer.scm:1883: chicken.compiler.support#copy-node! */
t2=*((C_word*)lf[32]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_12458(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_12458,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12462,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12635,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:1890: chicken.base#gensym */
t4=*((C_word*)lf[116]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k12460 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_12462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_12462,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1884: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_ccall f_12474(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_12474,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12478,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12482,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12486,a[2]=t3,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1923: chicken.compiler.support#varnode */
t5=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k12476 in k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_12478,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1889: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12480 in k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12482(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12482,c,av);}
/* optimizer.scm:1921: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=lf[188];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12484 in k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12486(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_12486,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12490,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12494,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_12504,tmp=(C_word)a,a+=2,tmp);
/* optimizer.scm:1925: list-tabulate */
f_4414(t3,((C_word*)t0)[3],t4);}

/* k12488 in k12484 in k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_12490,c,av);}
a=C_alloc(3);
/* optimizer.scm:1923: cons* */
f_3836(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,1,t1));}

/* k12492 in k12484 in k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12494(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_12494,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12502,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1926: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_fix(0);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12500 in k12492 in k12484 in k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in ... */
static void C_ccall f_12502(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_12502,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1924: scheme#append */
t3=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a12503 in k12484 in k12472 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12504,c,av);}
/* optimizer.scm:1925: chicken.compiler.support#qnode */
t2=*((C_word*)lf[77]+1);{
C_word av2[3];
av2[0]=t2;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12518 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_ccall f_12520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_12520,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1892: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[31];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12530 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12532(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_12532,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1895: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[29];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12538 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12540(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12540,c,av);}
/* optimizer.scm:1900: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[40];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12546 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12548(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12548,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12556,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1917: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12554 in k12546 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in ... */
static void C_ccall f_12556(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12556,c,av);}
/* optimizer.scm:1903: scheme#append */
t2=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=C_i_cdr(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a12557 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in ... */
static void C_ccall f_12558(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12558,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12566,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1907: chicken.compiler.support#qnode */
t4=*((C_word*)lf[77]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_cadr(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12564 in a12557 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in ... */
static void C_ccall f_12566(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_12566,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12570,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_i_caddr(((C_word*)t0)[3]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12576,a[2]=((C_word*)t0)[3],a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_12576(t7,t2,((C_word*)t0)[4],t3);}

/* k12568 in k12564 in a12557 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in ... */
static void C_ccall f_12570(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_12570,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list2(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in k12564 in a12557 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in ... */
static void C_fcall f_12576(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_12576,4,t0,t1,t2,t3);}
a=C_alloc(10);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_i_cadddr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t3);
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12601,a[2]=t1,a[3]=t5,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1914: chicken.compiler.support#varnode */
t7=*((C_word*)lf[83]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k12599 in loop in k12564 in a12557 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in ... */
static void C_ccall f_12601(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12601,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12605,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1915: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_12576(t3,t2,C_u_i_cdr(((C_word*)t0)[5]),C_u_i_cdr(((C_word*)t0)[6]));}

/* k12603 in k12599 in loop in k12564 in a12557 in k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in ... */
static void C_ccall f_12605(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_12605,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1912: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12623 in k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in ... */
static void C_ccall f_12625(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_12625,c,av);}
a=C_alloc(11);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12548,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12558,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1905: append-map */
f_3602(t3,t4,((C_word*)t0)[5],C_SCHEME_END_OF_LIST);}

/* k12629 in k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in ... */
static void C_ccall f_12631(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,2)))){
C_save_and_reclaim((void *)f_12631,c,av);}
a=C_alloc(58);
t2=C_a_i_list4(&a,4,t1,C_SCHEME_TRUE,((C_word*)t0)[2],C_fix(0));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12532,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=((C_word*)((C_word*)t0)[4])[1];
t5=C_s_a_i_minus(&a,2,t4,C_fix(1));
t6=C_a_i_list1(&a,1,t5);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12540,a[2]=t3,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12625,a[2]=t7,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1904: chicken.compiler.support#varnode */
t9=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}

/* k12633 in k12456 in k12434 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_12635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,2)))){
C_save_and_reclaim((void *)f_12635,c,av);}
a=C_alloc(24);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12474,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t4=C_a_i_list1(&a,1,((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12520,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12631,a[2]=((C_word*)t0)[5],a[3]=t5,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1897: chicken.base#gensym */
t7=*((C_word*)lf[116]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[189];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k12646 in k12650 in k12654 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_12648(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12648,c,av);}
t2=((C_word*)t0)[2];
f_12436(t2,C_eqp(lf[34],t1));}

/* k12650 in k12654 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_12652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_12652,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12648,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1880: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12654 in k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_12656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_12656,c,av);}
a=C_alloc(3);
t2=C_eqp(lf[26],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12652,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1879: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_12436(t3,C_SCHEME_FALSE);}}

/* k12658 in descend in k12290 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_12660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_12660,c,av);}
a=C_alloc(16);
t2=C_i_cadr(t1);
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_12436,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12656,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1878: chicken.compiler.support#node-class */
t5=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k12665 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_12667(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12667,c,av);}
/* optimizer.scm:1870: chicken.compiler.support#debugging */
t2=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[190];
av2[3]=lf[191];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop2728 in k12287 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_fcall f_12669(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_12669,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k12703 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_12705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_12705,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
/* optimizer.scm:1866: scheme#append */
t3=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a12710 in k12284 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_12711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12711,c,av);}
/* optimizer.scm:1867: chicken.base#gensym */
t2=*((C_word*)lf[116]+1);{
C_word av2[3];
av2[0]=t2;
av2[1]=t1;
av2[2]=lf[192];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12732 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_12734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12734,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[193]+1);
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop2687 in k12281 in k12278 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_fcall f_12736(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_12736,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_caddr(t3);
t5=C_i_length(t4);
t6=C_a_i_cons(&a,2,t5,C_SCHEME_END_OF_LIST);
t7=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t6);
t8=C_mutate(((C_word *)((C_word*)t0)[2])+1,t6);
t10=t1;
t11=C_slot(t2,C_fix(1));
t1=t10;
t2=t11;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* map-loop2620 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12770(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_12770,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12795,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1845: g2626 */
t4=((C_word*)t0)[4];
f_12185(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k12793 in map-loop2620 in k12179 in k12176 in g2516 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_12795(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_12795,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_12770(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k12806 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12808,c,av);}
/* optimizer.scm:1952: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_pairp(((C_word*)((C_word*)t0)[4])[1]);
C_values(4,av2);}}

/* for-each-loop2515 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12817(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_12817,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12827,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1837: g2516 */
t4=((C_word*)t0)[3];
f_12170(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k12825 in for-each-loop2515 in k12167 in k12164 in chicken.compiler.optimizer#determine-loop-and-dispatch in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12827,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_12817(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12856,c,av);}
a=C_alloc(9);
t10=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12976,a[2]=t5,a[3]=t7,a[4]=t6,a[5]=t1,a[6]=t8,a[7]=t9,a[8]=t4,tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:975: membership-test-operators */
t11=*((C_word*)lf[18]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}

/* k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12878(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_12878,c,av);}
a=C_alloc(24);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_list1(&a,1,t2);
t4=C_a_i_list1(&a,1,t1);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12896,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12904,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=t5,a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12906,a[2]=t3,a[3]=t1,a[4]=t8,tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_12906(t10,t6,((C_word*)t0)[8]);}

/* k12894 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_12896,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:980: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12902 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12904(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_12904,c,av);}
a=C_alloc(9);
t2=C_a_i_list3(&a,3,t1,((C_word*)t0)[2],((C_word*)t0)[3]);
/* optimizer.scm:984: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[25];
av2[3]=((C_word*)t0)[5];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* foldr1637 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12906(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_12906,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12914,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12953,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
/* optimizer.scm:995: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* g1642 in foldr1637 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_12914(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_12914,4,t0,t1,t2,t3);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12926,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12938,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:992: chicken.compiler.support#varnode */
t6=*((C_word*)lf[83]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k12924 in g1642 in foldr1637 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12926(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12926,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12930,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:993: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12928 in k12924 in g1642 in foldr1637 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12930(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_12930,c,av);}
a=C_alloc(9);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],t1,((C_word*)t0)[3]);
/* optimizer.scm:989: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[39];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12936 in g1642 in foldr1637 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12938,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12942,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:992: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12940 in k12936 in g1642 in foldr1637 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_12942,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:992: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[58];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12951 in foldr1637 in k12876 in k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12953(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12953,c,av);}
/* optimizer.scm:987: g1642 */
t2=((C_word*)t0)[2];
f_12914(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k12970 in k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12972,c,av);}
a=C_alloc(9);
if(C_truep(C_i_lessp(((C_word*)t0)[2],t1))){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12878,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:978: chicken.base#gensym */
t3=*((C_word*)lf[116]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k12974 in a12855 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_12976(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_12976,c,av);}
a=C_alloc(10);
t2=C_i_assoc(((C_word*)t0)[2],t1);
if(C_truep(t2)){
if(C_truep(C_i_listp(((C_word*)t0)[3]))){
t3=C_i_length(((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12972,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[3],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:977: membership-unfold-limit */
t5=*((C_word*)lf[19]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a13001 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13002(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10=av[10];
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_13002,c,av);}
a=C_alloc(7);
if(C_truep(t3)){
t11=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13017,a[2]=t1,a[3]=t5,a[4]=t7,a[5]=t8,a[6]=t9,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:963: chicken.compiler.support#varnode */
t12=*((C_word*)lf[83]+1);{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=t10;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}
else{
t11=t1;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}

/* k13015 in a13001 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13017(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_13017,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13021,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_a_i_list3(&a,3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);
/* optimizer.scm:964: chicken.compiler.support#make-node */
t4=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[39];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k13019 in k13015 in a13001 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_13021,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:961: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13083(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13083,c,av);}
a=C_alloc(8);
if(C_truep(t3)){
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13182,a[2]=t7,a[3]=t5,a[4]=t6,a[5]=t4,a[6]=t1,a[7]=t8,tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:924: chicken.compiler.support#db-get-list */
t10=*((C_word*)lf[155]+1);{
C_word *av2=av;
av2[0]=t10;
av2[1]=t9;
av2[2]=t2;
av2[3]=t4;
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
t9=t1;{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}

/* loop in k13180 in a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_13098(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_13098,5,t0,t1,t2,t3,t4);}
a=C_alloc(14);
if(C_truep(C_i_nullp(t2))){
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13115,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:930: scheme#reverse */
t6=*((C_word*)lf[4]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13121,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=t4,tmp=(C_word)a,a+=9,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13169,a[2]=t5,a[3]=((C_word*)t0)[6],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:932: chicken.compiler.support#node-class */
t7=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k13113 in loop in k13180 in a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13115(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13115,c,av);}
/* optimizer.scm:928: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k13119 in loop in k13180 in a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_13121(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_13121,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13134,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_a_i_list1(&a,1,((C_word*)t0)[6]);
/* optimizer.scm:936: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[58];
av2[3]=t4;
av2[4]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_u_i_car(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[3]);
/* optimizer.scm:942: loop */
t5=((C_word*)((C_word*)t0)[4])[1];
f_13098(t5,((C_word*)t0)[5],t2,t4,((C_word*)t0)[8]);}}

/* k13132 in k13119 in loop in k13180 in a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_13134,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* optimizer.scm:935: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_13098(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2,C_SCHEME_TRUE);}

/* k13161 in k13167 in loop in k13180 in a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13163(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13163,c,av);}
t2=((C_word*)t0)[2];
f_13121(t2,C_eqp(((C_word*)t0)[3],C_i_car(t1)));}

/* k13167 in loop in k13180 in a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13169,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13163,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:934: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_u_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_13121(t3,C_SCHEME_FALSE);}}

/* k13180 in a13082 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_13182,c,av);}
a=C_alloc(9);
t2=C_i_length(t1);
t3=C_eqp(C_fix(1),t2);
if(C_truep(t3)){
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13098,a[2]=((C_word*)t0)[2],a[3]=t5,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp));
t7=((C_word*)t5)[1];
f_13098(t7,((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);}
else{
t4=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13216(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10=av[10];
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_13216,c,av);}
a=C_alloc(11);
if(C_truep(t3)){
t11=C_eqp(t4,t8);
if(C_truep(C_i_not(t11))){
t12=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_13347,a[2]=t7,a[3]=t9,a[4]=t8,a[5]=t5,a[6]=t6,a[7]=t4,a[8]=t1,a[9]=t10,a[10]=t2,tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:887: chicken.compiler.support#db-get */
t13=*((C_word*)lf[55]+1);{
C_word *av2=av;
av2[0]=t13;
av2[1]=t12;
av2[2]=t2;
av2[3]=t8;
av2[4]=lf[91];
((C_proc)(void*)(*((C_word*)t13+1)))(5,av2);}}
else{
t12=t1;{
C_word *av2=av;
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}
else{
t11=t1;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}

/* loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_13243(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_13243,5,t0,t1,t2,t3,t4);}
a=C_alloc(14);
if(C_truep(C_i_nullp(t2))){
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13264,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:894: chicken.compiler.support#varnode */
t6=*((C_word*)lf[83]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13282,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=t1,a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t4,tmp=(C_word)a,a+=9,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13330,a[2]=t5,a[3]=((C_word*)t0)[8],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:900: chicken.compiler.support#node-class */
t7=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k13262 in loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13264(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_13264,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13268,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_a_i_list1(&a,1,((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13276,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:898: scheme#reverse */
t5=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k13266 in k13262 in loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13268(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_13268,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:892: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13274 in k13262 in loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13276(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13276,c,av);}
/* optimizer.scm:895: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[58];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k13280 in loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_13282(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_13282,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13295,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_a_i_list1(&a,1,((C_word*)t0)[6]);
/* optimizer.scm:904: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[58];
av2[3]=t4;
av2[4]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_u_i_car(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[3]);
/* optimizer.scm:910: loop */
t5=((C_word*)((C_word*)t0)[4])[1];
f_13243(t5,((C_word*)t0)[5],t2,t4,((C_word*)t0)[8]);}}

/* k13293 in k13280 in loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_13295,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* optimizer.scm:903: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_13243(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2,C_SCHEME_TRUE);}

/* k13322 in k13328 in loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13324(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13324,c,av);}
t2=((C_word*)t0)[2];
f_13282(t2,C_eqp(((C_word*)t0)[3],C_i_car(t1)));}

/* k13328 in loop in k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13330,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13324,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:902: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_u_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_13282(t3,C_SCHEME_FALSE);}}

/* k13341 in k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13343(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_13343,c,av);}
a=C_alloc(11);
t2=C_i_length(t1);
t3=C_eqp(C_fix(1),t2);
if(C_truep(t3)){
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13243,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t5,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp));
t7=((C_word*)t5)[1];
f_13243(t7,((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);}
else{
t4=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k13345 in a13215 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13347(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_13347,c,av);}
a=C_alloc(10);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13343,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:888: chicken.compiler.support#db-get-list */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
av2[3]=((C_word*)t0)[7];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a13400 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_13401,c,av);}
a=C_alloc(10);
t10=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13446,a[2]=t5,a[3]=t8,a[4]=t9,a[5]=t1,a[6]=t7,a[7]=t6,a[8]=t2,a[9]=t4,tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:867: eq-inline-operator */
t11=*((C_word*)lf[17]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}

/* k13423 in k13436 in k13444 in a13400 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13425(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_13425,c,av);}
a=C_alloc(9);
t2=C_a_i_list3(&a,3,t1,((C_word*)t0)[2],((C_word*)t0)[3]);
/* optimizer.scm:869: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[25];
av2[3]=((C_word*)t0)[5];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13436 in k13444 in a13400 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13438(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_13438,c,av);}
a=C_alloc(9);
t2=C_i_length(t1);
t3=C_eqp(C_fix(1),t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13425,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t5=C_a_i_list1(&a,1,((C_word*)t0)[6]);
/* optimizer.scm:871: chicken.compiler.support#make-node */
t6=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=lf[58];
av2[3]=t5;
av2[4]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k13444 in a13400 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13446(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13446,c,av);}
a=C_alloc(8);
t2=C_i_equalp(((C_word*)t0)[2],t1);
if(C_truep(C_i_not(t2))){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13438,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:868: chicken.compiler.support#db-get-list */
t4=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
av2[3]=((C_word*)t0)[9];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13484(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_13484,c,av);}
a=C_alloc(9);
t6=C_a_i_list1(&a,1,t4);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13494,a[2]=t8,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_13494(t10,t1,t6,t5);}

/* loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_13494(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_13494,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13498,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=((C_word*)t0)[3],a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:802: chicken.compiler.support#node-class */
t5=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13498(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13498,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13501,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:803: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13501(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13501,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13504,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:804: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13504,c,av);}
a=C_alloc(8);
t2=C_eqp(((C_word*)t0)[2],lf[26]);
if(C_truep(t2)){
t3=C_i_cdr(((C_word*)t0)[3]);
if(C_truep(C_i_nullp(t3))){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13771,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:807: chicken.compiler.support#db-get */
t5=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
av2[3]=C_i_car(((C_word*)t0)[3]);
av2[4]=lf[136];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13534(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_13534,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13537,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:811: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13537(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_13537,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13540,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:812: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13540(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13540,c,av);}
a=C_alloc(7);
t2=C_eqp(t1,lf[34]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[3]);
/* optimizer.scm:813: loop1 */
t5=((C_word*)((C_word*)t0)[4])[1];
f_13494(t5,((C_word*)t0)[5],t4,C_i_cadr(((C_word*)t0)[6]));}
else{
t3=C_eqp(t1,lf[31]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13570,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:815: scheme#reverse */
t5=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_13570(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,5)))){
C_save_and_reclaim((void *)f_13570,c,av);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t1))){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_car(t1);
t4=C_eqp(t2,t3);
if(C_truep(t4)){
t5=C_i_car(((C_word*)t0)[3]);
t6=C_a_i_list1(&a,1,t5);
t7=C_u_i_cdr(t1);
t8=C_i_cadr(((C_word*)t0)[4]);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13597,a[2]=t10,a[3]=t1,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_13597(t12,((C_word*)t0)[6],t6,t7,t8);}
else{
t5=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_fcall f_13597(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_13597,5,t0,t1,t2,t3,t4);}
a=C_alloc(9);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13601,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,a[6]=((C_word*)t0)[3],a[7]=t4,a[8]=((C_word*)t0)[4],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:821: chicken.compiler.support#node-class */
t6=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_13601(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_13601,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13604,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:822: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_13604(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_13604,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_13607,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:823: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_13607(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_13607,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13613,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t3=C_eqp(((C_word*)t0)[8],lf[26]);
if(C_truep(t3)){
t4=C_i_cdr(((C_word*)t0)[9]);
if(C_truep(C_i_nullp(t4))){
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13735,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=t1,a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[9],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:826: chicken.compiler.support#db-get */
t6=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[10];
av2[3]=C_i_car(((C_word*)t0)[9]);
av2[4]=lf[136];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=t2;
f_13613(t5,C_SCHEME_FALSE);}}
else{
t4=t2;
f_13613(t4,C_SCHEME_FALSE);}}

/* k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_fcall f_13613(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_13613,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13636,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:831: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
if(C_truep(C_i_nullp(((C_word*)t0)[5]))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13651,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13661,tmp=(C_word)a,a+=2,tmp);
/* optimizer.scm:835: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* k13634 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_13636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_13636,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[2]);
/* optimizer.scm:831: loop2 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_13597(t4,((C_word*)t0)[4],t3,C_i_cdr(((C_word*)t0)[5]),C_i_cadr(((C_word*)t0)[6]));}

/* a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_13651(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_13651,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13659,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:836: scheme#reverse */
t3=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_13659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,4)))){
C_save_and_reclaim((void *)f_13659,c,av);}
a=C_alloc(21);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=C_i_check_list_2(((C_word*)t0)[2],lf[8]);
t9=C_i_check_list_2(t1,lf[8]);
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7755,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8230,a[2]=t6,a[3]=t12,a[4]=t7,tmp=(C_word)a,a+=5,tmp));
t14=((C_word*)t12)[1];
f_8230(t14,t10,((C_word*)t0)[2],t1);}

/* a13660 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_13661(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13661,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?t2:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k13709 in k13717 in k13725 in k13733 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_13711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13711,c,av);}
t2=((C_word*)t0)[2];
f_13613(t2,C_eqp(((C_word*)t0)[3],C_i_car(t1)));}

/* k13717 in k13725 in k13733 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in ... */
static void C_ccall f_13719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13719,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[31],t1);
if(C_truep(t2)){
t3=C_u_i_car(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13711,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:830: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];
f_13613(t3,C_SCHEME_FALSE);}}

/* k13725 in k13733 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_13727(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_13727,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13719,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:829: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];
f_13613(t2,C_SCHEME_FALSE);}}
else{
t2=((C_word*)t0)[3];
f_13613(t2,C_SCHEME_FALSE);}}

/* k13733 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_13735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_13735,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13727,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:827: chicken.compiler.support#db-get */
t3=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_i_car(((C_word*)t0)[6]);
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[3];
f_13613(t2,C_SCHEME_FALSE);}}

/* k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_13763,c,av);}
a=C_alloc(9);
if(C_truep(C_i_not(t1))){
t2=C_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13534,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],a[8]=t2,tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:810: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13771,c,av);}
a=C_alloc(8);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13763,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:808: chicken.compiler.support#db-get */
t3=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=C_i_car(((C_word*)t0)[3]);
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a13796 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13797(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10=av[10];
C_word t11=av[11];
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_13797,c,av);}
a=C_alloc(11);
t12=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_13850,a[2]=t5,a[3]=t10,a[4]=t1,a[5]=t9,a[6]=t11,a[7]=t7,a[8]=t6,a[9]=t2,a[10]=t4,tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:776: eq-inline-operator */
t13=*((C_word*)lf[17]+1);{
C_word *av2=av;
av2[0]=t13;
av2[1]=t12;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}

/* k13808 in k13848 in a13796 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13810(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13810,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13846,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:778: chicken.compiler.support#db-get-list */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
av2[3]=((C_word*)t0)[9];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k13825 in k13844 in k13808 in k13848 in a13796 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13827,c,av);}
/* optimizer.scm:779: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[40];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k13829 in k13844 in k13808 in k13848 in a13796 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13831(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_13831,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13835,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:783: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13833 in k13829 in k13844 in k13808 in k13848 in a13796 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_13835,c,av);}
a=C_alloc(9);
/* optimizer.scm:782: cons* */
f_3836(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,3,t1,((C_word*)t0)[4],((C_word*)t0)[5]));}

/* k13844 in k13808 in k13848 in a13796 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13846(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(42,c,2)))){
C_save_and_reclaim((void *)f_13846,c,av);}
a=C_alloc(42);
t2=C_i_length(t1);
t3=C_eqp(C_fix(1),t2);
if(C_truep(t3)){
t4=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13827,a[2]=((C_word*)t0)[3],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13831,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:782: chicken.compiler.support#varnode */
t8=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k13848 in a13796 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_13850,c,av);}
a=C_alloc(10);
if(C_truep(C_i_equalp(((C_word*)t0)[2],t1))){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13810,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:777: chicken.compiler.support#immediate? */
t3=*((C_word*)lf[215]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10=av[10];
C_word t11=av[11];
C_word t12=av[12];
C_word t13=av[13];
C_word t14=av[14];
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_13924,c,av);}
a=C_alloc(13);
t15=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_13996,a[2]=t7,a[3]=t10,a[4]=t11,a[5]=t14,a[6]=t1,a[7]=t9,a[8]=t8,a[9]=t4,a[10]=t2,a[11]=t6,a[12]=t5,tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:749: eq-inline-operator */
t16=*((C_word*)lf[17]+1);{
C_word *av2=av;
av2[0]=t16;
av2[1]=t15;
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}

/* k13935 in k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_13937,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_13943,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:751: chicken.compiler.support#immediate? */
t3=*((C_word*)lf[215]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k13941 in k13935 in k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_13943,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_13992,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:752: chicken.compiler.support#db-get-list */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[11];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k13964 in k13981 in k13990 in k13941 in k13935 in k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13966(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13966,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13970,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:758: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13968 in k13964 in k13981 in k13990 in k13941 in k13935 in k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13970(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13970,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13974,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:760: chicken.compiler.support#qnode */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13972 in k13968 in k13964 in k13981 in k13990 in k13941 in k13935 in k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13974(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,4)))){
C_save_and_reclaim((void *)f_13974,c,av);}
a=C_alloc(18);
t2=C_a_i_list6(&a,6,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);
/* optimizer.scm:754: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[7];
av2[2]=lf[40];
av2[3]=lf[214];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13981 in k13990 in k13941 in k13935 in k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13983(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13983,c,av);}
a=C_alloc(8);
t2=C_i_length(t1);
t3=C_eqp(C_fix(1),t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13966,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:757: chicken.compiler.support#varnode */
t5=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k13990 in k13941 in k13935 in k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13992(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_13992,c,av);}
a=C_alloc(9);
t2=C_i_length(t1);
t3=C_eqp(C_fix(1),t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13983,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:753: chicken.compiler.support#db-get-list */
t5=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k13994 in a13923 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_13996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_13996,c,av);}
a=C_alloc(12);
if(C_truep(C_i_equalp(((C_word*)t0)[2],t1))){
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_13937,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:750: chicken.compiler.support#immediate? */
t3=*((C_word*)lf[215]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_14094(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_14094,c,av);}
a=C_alloc(9);
t8=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_14102,a[2]=t4,a[3]=t6,a[4]=t3,a[5]=t5,a[6]=t2,a[7]=t7,a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:717: chicken.internal#hash-table-ref */
t9=*((C_word*)lf[57]+1);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[159];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}

/* k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_14102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_14102,c,av);}
a=C_alloc(11);
t2=(C_truep(t1)?t1:C_SCHEME_END_OF_LIST);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_14107,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp));
t6=((C_word*)t4)[1];
f_14107(t6,((C_word*)t0)[8],t2);}

/* loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_14107(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word t69;
C_word t70;
C_word t71;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,2)))){
C_save_and_reclaim_args((void *)trf_14107,3,t0,t1,t2);}
a=C_alloc(19);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14117,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_i_caar(t2);
t5=C_u_i_car(t2);
t6=C_u_i_cdr(t5);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8305,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
switch(t4){
case C_fix(1):
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8395,a[2]=t3,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=t6,a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1116: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}
case C_fix(2):
if(C_truep(((C_word*)t0)[5])){
t8=C_i_length(((C_word*)t0)[4]);
t9=C_i_car(t6);
if(C_truep(C_i_nequalp(t8,t9))){
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8514,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1134: chicken.compiler.support#intrinsic? */
t11=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(3):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8572,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1147: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(4):
if(C_truep(((C_word*)t0)[5])){
if(C_truep(*((C_word*)lf[232]+1))){
t8=C_i_length(((C_word*)t0)[4]);
t9=C_eqp(C_fix(2),t8);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8686,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1160: chicken.compiler.support#intrinsic? */
t11=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(5):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8745,a[2]=((C_word*)t0)[4],a[3]=t6,a[4]=((C_word*)t0)[6],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1172: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(6):
t8=C_i_caddr(t6);
t9=(C_truep(t8)?t8:*((C_word*)lf[232]+1));
if(C_truep(t9)){
if(C_truep(((C_word*)t0)[5])){
t10=C_i_length(((C_word*)t0)[4]);
t11=C_eqp(C_fix(1),t10);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8840,a[2]=((C_word*)t0)[6],a[3]=t3,a[4]=t6,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1187: chicken.compiler.support#intrinsic? */
t13=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t13;
av2[1]=t12;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t12=t3;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(7):
t8=C_i_cadddr(t6);
t9=(C_truep(t8)?t8:*((C_word*)lf[232]+1));
if(C_truep(t9)){
if(C_truep(((C_word*)t0)[5])){
t10=C_i_length(((C_word*)t0)[4]);
t11=C_i_car(t6);
if(C_truep(C_i_nequalp(t10,t11))){
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8914,a[2]=((C_word*)t0)[6],a[3]=t3,a[4]=t6,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1199: chicken.compiler.support#intrinsic? */
t13=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t13;
av2[1]=t12;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t12=t3;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(8):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8976,a[2]=t6,a[3]=t3,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1209: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(9):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8997,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[6],a[4]=t3,a[5]=t6,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1216: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(10):
if(C_truep(((C_word*)t0)[5])){
t8=C_i_cadddr(t6);
t9=(C_truep(t8)?t8:*((C_word*)lf[232]+1));
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9252,a[2]=((C_word*)t0)[4],a[3]=t6,a[4]=((C_word*)t0)[6],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1247: chicken.compiler.support#intrinsic? */
t11=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(11):
if(C_truep(((C_word*)t0)[5])){
t8=C_i_caddr(t6);
t9=(C_truep(t8)?t8:*((C_word*)lf[232]+1));
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9341,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=t3,a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1264: chicken.compiler.support#intrinsic? */
t11=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(12):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9402,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1277: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(13):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9481,a[2]=t6,a[3]=t7,a[4]=t3,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1291: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(14):
if(C_truep(((C_word*)t0)[5])){
t8=C_i_cadr(t6);
t9=C_i_length(((C_word*)t0)[4]);
if(C_truep(C_i_nequalp(t8,t9))){
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9551,a[2]=t6,a[3]=((C_word*)t0)[6],a[4]=t3,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1303: chicken.compiler.support#intrinsic? */
t11=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(15):
if(C_truep(((C_word*)t0)[5])){
t8=C_i_length(((C_word*)t0)[4]);
t9=C_eqp(C_fix(1),t8);
if(C_truep(t9)){
t10=*((C_word*)lf[232]+1);
t11=(C_truep(*((C_word*)lf[232]+1))?*((C_word*)lf[232]+1):C_i_cadddr(t6));
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9634,a[2]=t6,a[3]=t3,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1320: chicken.compiler.support#intrinsic? */
t13=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t13;
av2[1]=t12;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t12=t3;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(16):
t8=C_i_car(t6);
t9=C_i_length(((C_word*)t0)[4]);
t10=C_i_caddr(t6);
t11=C_i_cadddr(t6);
t12=C_i_cddddr(t6);
t13=C_i_pairp(t12);
t14=(C_truep(t13)?C_i_car(C_i_cddddr(t6)):C_SCHEME_FALSE);
if(C_truep(((C_word*)t0)[5])){
t15=C_i_not(t8);
t16=(C_truep(t15)?t15:C_i_nequalp(t9,t8));
if(C_truep(t16)){
t17=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9735,a[2]=t10,a[3]=((C_word*)t0)[6],a[4]=t3,a[5]=t11,a[6]=t9,a[7]=((C_word*)t0)[4],a[8]=t14,a[9]=t6,tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:1345: chicken.compiler.support#intrinsic? */
t18=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t18;
av2[1]=t17;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t18+1)))(3,av2);}}
else{
t17=t3;{
C_word av2[2];
av2[0]=t17;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t15=t3;{
C_word av2[2];
av2[0]=t15;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(17):
if(C_truep(((C_word*)t0)[5])){
t8=C_i_length(((C_word*)t0)[4]);
t9=C_i_car(t6);
if(C_truep(C_i_nequalp(t8,t9))){
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9847,a[2]=((C_word*)t0)[6],a[3]=t3,a[4]=t6,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1365: chicken.compiler.support#intrinsic? */
t11=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=t3;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(18):
if(C_truep(((C_word*)t0)[5])){
if(C_truep(C_i_nullp(((C_word*)t0)[4]))){
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9915,a[2]=((C_word*)t0)[6],a[3]=t3,a[4]=t6,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1379: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(19):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9949,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1385: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(20):
t8=C_i_length(((C_word*)t0)[4]);
t9=C_i_cadddr(t6);
t10=(C_truep(t9)?t9:*((C_word*)lf[232]+1));
if(C_truep(t10)){
if(C_truep(((C_word*)t0)[5])){
t11=C_i_car(t6);
if(C_truep(C_i_nequalp(t8,t11))){
t12=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10101,a[2]=((C_word*)t0)[6],a[3]=t3,a[4]=t6,a[5]=t8,a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1417: chicken.compiler.support#intrinsic? */
t13=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t13;
av2[1]=t12;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t12=t3;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t11=t3;{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t11=t3;{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(21):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10173,a[2]=t6,a[3]=((C_word*)t0)[6],a[4]=t3,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1435: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(22):
t8=C_i_car(t6);
t9=C_i_length(((C_word*)t0)[4]);
t10=C_i_cadddr(t6);
if(C_truep(((C_word*)t0)[5])){
if(C_truep(C_i_nequalp(t9,t8))){
t11=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10344,a[2]=t6,a[3]=((C_word*)t0)[6],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=t10,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1469: chicken.compiler.support#intrinsic? */
t12=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t12;
av2[1]=t11;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}
else{
t11=t3;{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t11=t3;{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
case C_fix(23):
if(C_truep(((C_word*)t0)[5])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10408,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=t3,a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1490: chicken.compiler.support#intrinsic? */
t9=*((C_word*)lf[129]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=t3;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}
default:
/* optimizer.scm:1510: chicken.compiler.support#bomb */
t8=*((C_word*)lf[174]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t3;
av2[2]=lf[243];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}}

/* k14115 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_14117(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(38,c,2)))){
C_save_and_reclaim((void *)f_14117,c,av);}
a=C_alloc(38);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14121,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:718: g1440 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* optimizer.scm:718: g1440 */
  f_14121(C_a_i(&a,35),t2,t1)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* optimizer.scm:727: loop */
t2=((C_word*)((C_word*)t0)[4])[1];
f_14107(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[5]));}}

/* g1440 in k14115 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_14121(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_stack_overflow_check;{}
t2=C_i_assq(((C_word*)t0)[2],lf[51]);
if(C_truep(t2)){
t3=C_i_cdr(t2);
t4=C_s_a_i_plus(&a,2,t3,C_fix(1));
t5=C_i_set_cdr(t2,t4);
return(t1);}
else{
t3=lf[51];
t4=C_a_i_cons(&a,2,((C_word*)t0)[2],C_fix(1));
t5=C_a_i_cons(&a,2,t4,lf[51]);
t6=C_mutate(&lf[51] /* (set! chicken.compiler.optimizer#simplified-ops ...) */,t5);
return(t1);}}

/* k3387 */
static void C_ccall f_3389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3389,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3392,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_eval_toplevel(2,av2);}}

/* k3390 in k3387 */
static void C_ccall f_3392(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3392,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3395,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_data_2dstructures_toplevel(2,av2);}}

/* k3393 in k3390 in k3387 */
static void C_ccall f_3395(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3395,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3398,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_internal_toplevel(2,av2);}}

/* k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_3398,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3401,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_support_toplevel(2,av2);}}

/* k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,5)))){
C_save_and_reclaim((void *)f_3401,c,av);}
a=C_alloc(39);
t2=C_a_i_provide(&a,1,lf[0]);
t3=C_a_i_provide(&a,1,lf[1]);
t4=C_mutate(&lf[2] /* (set! chicken.compiler.optimizer#take ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3511,tmp=(C_word)a,a+=2,tmp));
t5=C_mutate(&lf[3] /* (set! chicken.compiler.optimizer#split-at ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3563,tmp=(C_word)a,a+=2,tmp));
t6=C_mutate(&lf[5] /* (set! chicken.compiler.optimizer#append-map ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3602,tmp=(C_word)a,a+=2,tmp));
t7=C_mutate(&lf[11] /* (set! chicken.compiler.optimizer#every ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3772,tmp=(C_word)a,a+=2,tmp));
t8=C_mutate(&lf[9] /* (set! chicken.compiler.optimizer#any ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3806,tmp=(C_word)a,a+=2,tmp));
t9=C_mutate(&lf[12] /* (set! chicken.compiler.optimizer#cons* ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3836,tmp=(C_word)a,a+=2,tmp));
t10=C_mutate(&lf[13] /* (set! chicken.compiler.optimizer#delete ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3892,tmp=(C_word)a,a+=2,tmp));
t11=C_mutate(&lf[14] /* (set! chicken.compiler.optimizer#first ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_3933,tmp=(C_word)a,a+=2,tmp));
t12=C_mutate(&lf[15] /* (set! chicken.compiler.optimizer#filter ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4012,tmp=(C_word)a,a+=2,tmp));
t13=C_mutate(&lf[16] /* (set! chicken.compiler.optimizer#list-tabulate ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4414,tmp=(C_word)a,a+=2,tmp));
t14=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4683,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:52: chicken.base#make-parameter */
t15=*((C_word*)lf[244]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t15;
av2[1]=t14;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t15+1)))(3,av2);}}

/* loop in a5858 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3409(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_3409,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t4))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3423,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:43: scheme#reverse */
t6=*((C_word*)lf[4]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_3433,a[2]=t4,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* mini-srfi-1.scm:44: pred */
t6=((C_word*)t0)[3];
f_5865(t6,t5,C_i_car(t4));}}

/* k3421 in loop in a5858 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3423(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_3423,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3427,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:43: scheme#reverse */
t3=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k3425 in k3421 in loop in a5858 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3427(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_3427,c,av);}
/* mini-srfi-1.scm:43: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_values(4,av2);}}

/* k3431 in loop in a5858 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3433(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_3433,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[3]);
/* mini-srfi-1.scm:44: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_3409(t4,((C_word*)t0)[5],t3,((C_word*)t0)[6],C_u_i_cdr(((C_word*)t0)[2]));}
else{
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[6]);
/* mini-srfi-1.scm:45: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_3409(t4,((C_word*)t0)[5],((C_word*)t0)[3],t3,C_u_i_cdr(((C_word*)t0)[2]));}}

/* chicken.compiler.optimizer#take in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3511(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_3511,3,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(0)))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3529,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:56: take */
t7=t5;
t8=C_u_i_cdr(t2);
t9=C_fixnum_difference(t3,C_fix(1));
t1=t7;
t2=t8;
t3=t9;
goto loop;}}

/* k3527 in chicken.compiler.optimizer#take in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3529(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_3529,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.optimizer#split-at in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3563(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,5)))){
C_save_and_reclaim_args((void *)trf_3563,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3569,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_3569(t7,t1,t3,C_SCHEME_END_OF_LIST,t2);}

/* loop in chicken.compiler.optimizer#split-at in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3569(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_3569,5,t0,t1,t2,t3,t4);}
a=C_alloc(4);
if(C_truep(C_fixnum_less_or_equal_p(t2,C_fix(0)))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3583,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:67: scheme#reverse */
t6=*((C_word*)lf[4]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_fixnum_difference(t2,C_fix(1));
t6=C_i_car(t4);
t7=C_a_i_cons(&a,2,t6,t3);
/* mini-srfi-1.scm:68: loop */
t9=t1;
t10=t5;
t11=t7;
t12=C_u_i_cdr(t4);
t1=t9;
t2=t10;
t3=t11;
t4=t12;
goto loop;}}

/* k3581 in loop in chicken.compiler.optimizer#split-at in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3583(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_3583,c,av);}
/* mini-srfi-1.scm:67: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
C_values(4,av2);}}

/* chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3602(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_3602,4,t1,t2,t3,t4);}
a=C_alloc(9);
if(C_truep(C_i_nullp(t4))){
t5=C_i_check_list_2(t3,lf[6]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3617,a[2]=t2,a[3]=t7,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_3617(t9,t1,t3);}
else{
t5=C_a_i_cons(&a,2,t3,t4);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3657,a[2]=t7,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_3657(t9,t1,t5);}}

/* foldr113 in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3617(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_3617,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3625,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3644,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g118 in foldr113 in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3625(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_3625,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3633,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:72: proc */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k3631 in g118 in foldr113 in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3633(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_3633,c,av);}
/* mini-srfi-1.scm:72: scheme#append */
t2=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k3642 in foldr113 in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_3644,c,av);}
/* mini-srfi-1.scm:72: g118 */
t2=((C_word*)t0)[2];
f_3625(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3657(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_3657,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_3664,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* mini-srfi-1.scm:74: any */
f_3806(t3,*((C_word*)lf[10]+1),t2);}

/* k3662 in loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3664(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_3664,c,av);}
a=C_alloc(21);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3671,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(((C_word*)t0)[4],lf[8]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3736,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3738,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_3738(t12,t8,((C_word*)t0)[4]);}}

/* k3669 in k3662 in loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_3671,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3675,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3687,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3689,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_3689(t11,t7,((C_word*)t0)[4]);}

/* k3673 in k3669 in k3662 in loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3675(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_3675,c,av);}
/* mini-srfi-1.scm:76: scheme#append */
t2=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k3685 in k3669 in k3662 in loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3687(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_3687,c,av);}
/* mini-srfi-1.scm:77: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_3657(t2,((C_word*)t0)[3],t1);}

/* map-loop155 in k3669 in k3662 in loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3689(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_3689,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_cdr(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k3734 in k3662 in loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_3736,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop128 in k3662 in loop in chicken.compiler.optimizer#append-map in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3738(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_3738,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.compiler.optimizer#every in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3772(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_3772,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3778,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_3778(t7,t1,t3);}

/* loop in chicken.compiler.optimizer#every in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3778(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_3778,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_nullp(t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3800,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:82: pred */
t5=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k3798 in loop in chicken.compiler.optimizer#every in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_3800,c,av);}
if(C_truep(C_i_not(t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* mini-srfi-1.scm:83: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_3778(t2,((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[4]));}}

/* chicken.compiler.optimizer#any in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3806(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_3806,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3812,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_3812(t7,t1,t3);}

/* loop in chicken.compiler.optimizer#any in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3812(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_3812,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3822,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:88: pred */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k3820 in loop in chicken.compiler.optimizer#any in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_3822,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* mini-srfi-1.scm:89: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_3812(t2,((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[4]));}}

/* chicken.compiler.optimizer#cons* in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3836(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_3836,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3842,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_3842(t7,t1,t2,t3);}

/* loop in chicken.compiler.optimizer#cons* in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3842(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_3842,4,t0,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3856,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:95: loop */
t6=t4;
t7=C_i_car(t3);
t8=C_u_i_cdr(t3);
t1=t6;
t2=t7;
t3=t8;
goto loop;}}

/* k3854 in loop in chicken.compiler.optimizer#cons* in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_3856,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.optimizer#delete in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3892(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_3892,4,t1,t2,t3,t4);}
a=C_alloc(7);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3898,a[2]=t6,a[3]=t4,a[4]=t2,tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_3898(t8,t1,t3);}

/* loop in chicken.compiler.optimizer#delete in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3898(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_3898,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_3911,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:106: test */
t4=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k3909 in loop in chicken.compiler.optimizer#delete in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3911(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_3911,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
/* mini-srfi-1.scm:107: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_3898(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}
else{
t2=C_u_i_car(((C_word*)t0)[4]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3925,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:109: loop */
t4=((C_word*)((C_word*)t0)[2])[1];
f_3898(t4,t3,C_u_i_cdr(((C_word*)t0)[4]));}}

/* k3923 in k3909 in loop in chicken.compiler.optimizer#delete in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_3925,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.optimizer#first in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3933(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_3933,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* loop in k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_3973(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_3973,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_3987,a[2]=t4,a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4000,a[2]=((C_word*)t0)[2],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:123: delete */
f_3892(t6,t3,t4,((C_word*)t0)[3]);}}

/* k3985 in loop in k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_3987(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_3987,c,av);}
a=C_alloc(3);
t2=C_i_equalp(((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?((C_word*)t0)[4]:C_a_i_cons(&a,2,((C_word*)t0)[5],t1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k3998 in loop in k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4000(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_4000,c,av);}
/* mini-srfi-1.scm:123: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_3973(t2,((C_word*)t0)[3],t1);}

/* chicken.compiler.optimizer#filter in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4012(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_4012,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_check_list_2(t3,lf[6]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4021,a[2]=t2,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_4021(t8,t1,t3);}

/* foldr260 in chicken.compiler.optimizer#filter in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4021(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_4021,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4029,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4050,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g265 in foldr260 in chicken.compiler.optimizer#filter in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4029(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_4029,4,t0,t1,t2,t3);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4036,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:131: pred */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k4034 in g265 in foldr260 in chicken.compiler.optimizer#filter in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4036(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_4036,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]):((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k4048 in foldr260 in chicken.compiler.optimizer#filter in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4050(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_4050,c,av);}
/* mini-srfi-1.scm:131: g265 */
t2=((C_word*)t0)[2];
f_4029(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* foldr278 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in ... */
static void C_fcall f_4065(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_4065,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4073,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4099,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g283 in foldr278 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in ... */
static void C_fcall f_4073(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_4073,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4077,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:135: pred */
t5=((C_word*)t0)[2];
f_7890(t5,t4,t2);}

/* k4075 in g283 in foldr278 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in ... */
static void C_ccall f_4077(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_4077,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4081,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:135: g293 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* mini-srfi-1.scm:135: g293 */
  f_4081(C_a_i(&a,3),t2,t1)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g293 in k4075 in g283 in foldr278 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in ... */
static C_word C_fcall f_4081(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_a_i_cons(&a,2,t1,((C_word*)t0)[2]));}

/* k4097 in foldr278 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in ... */
static void C_ccall f_4099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_4099,c,av);}
/* mini-srfi-1.scm:134: g283 */
t2=((C_word*)t0)[2];
f_4073(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* map-loop306 in a11858 in a11848 in transform in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4138(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_4138,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* loop in k4870 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_4178(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
t2=C_i_cdr(t1);
if(C_truep(C_i_nullp(t2))){
return(C_u_i_car(t1));}
else{
t4=C_u_i_cdr(t1);
t1=t4;
goto loop;}}

/* loop in k5507 in a5495 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4237(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_4237,4,t0,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
if(C_truep(C_i_memq(t4,t3))){
/* mini-srfi-1.scm:160: loop */
t9=t1;
t10=C_u_i_cdr(t2);
t11=t3;
t1=t9;
t2=t10;
t3=t11;
goto loop;}
else{
t5=C_u_i_cdr(t2);
t6=C_u_i_car(t2);
t7=C_a_i_cons(&a,2,t6,t3);
/* mini-srfi-1.scm:161: loop */
t9=t1;
t10=t5;
t11=t7;
t1=t9;
t2=t10;
t3=t11;
goto loop;}}}

/* chicken.compiler.optimizer#list-tabulate in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4414(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_4414,3,t1,t2,t3);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4420,a[2]=t2,a[3]=t5,a[4]=t3,tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_4420(t7,t1,C_fix(0));}

/* loop in chicken.compiler.optimizer#list-tabulate in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4420(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_4420,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4434,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:190: proc */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k4432 in loop in chicken.compiler.optimizer#list-tabulate in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4434(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_4434,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4438,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:190: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4420(t3,t2,C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* k4436 in k4432 in loop in chicken.compiler.optimizer#list-tabulate in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4438(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_4438,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a4449 in a7889 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in ... */
static void C_ccall f_4450(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_4450,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_memq(t2,((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a4467 in k11219 in k11212 in scan in chicken.compiler.optimizer#transform-direct-lambdas! in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_4468,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_memq(t2,((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_4683,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[17]+1 /* (set! chicken.compiler.optimizer#eq-inline-operator ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4687,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:53: chicken.base#make-parameter */
t4=*((C_word*)lf[244]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4687(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_4687,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[18]+1 /* (set! chicken.compiler.optimizer#membership-test-operators ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4691,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:54: chicken.base#make-parameter */
t4=*((C_word*)lf[244]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4691(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_4691,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.optimizer#membership-unfold-limit ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4695,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:55: chicken.base#make-parameter */
t4=*((C_word*)lf[244]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4695(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_4695,c,av);}
a=C_alloc(5);
t2=C_mutate((C_word*)lf[20]+1 /* (set! chicken.compiler.optimizer#default-optimization-passes ...) */,t1);
t3=C_mutate((C_word*)lf[21]+1 /* (set! chicken.compiler.optimizer#scan-toplevel-assignments ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4697,tmp=(C_word)a,a+=2,tmp));
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5048,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:150: scheme#make-vector */
t5=*((C_word*)lf[197]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_fix(301);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4697(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(49,c,5)))){
C_save_and_reclaim((void *)f_4697,c,av);}
a=C_alloc(49);
t3=C_SCHEME_END_OF_LIST;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_END_OF_LIST;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_FALSE;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_END_OF_LIST;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_SCHEME_UNDEFINED;
t18=(*a=C_VECTOR_TYPE|1,a[1]=t17,tmp=(C_word)a,a+=2,tmp);
t19=C_SCHEME_UNDEFINED;
t20=(*a=C_VECTOR_TYPE|1,a[1]=t19,tmp=(C_word)a,a+=2,tmp);
t21=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4700,a[2]=t8,a[3]=t6,a[4]=t4,tmp=(C_word)a,a+=5,tmp));
t22=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4723,a[2]=t10,tmp=(C_word)a,a+=3,tmp));
t23=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4730,a[2]=t8,a[3]=t10,tmp=(C_word)a,a+=4,tmp));
t24=C_set_block_item(t18,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4735,a[2]=t10,a[3]=t20,tmp=(C_word)a,a+=4,tmp));
t25=C_set_block_item(t20,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_4776,a[2]=t10,a[3]=t6,a[4]=t16,a[5]=t18,a[6]=t20,a[7]=t14,a[8]=t12,tmp=(C_word)a,a+=9,tmp));
t26=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_4994,a[2]=t4,a[3]=t1,a[4]=t20,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:127: chicken.compiler.support#debugging */
t27=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t27;
av2[1]=t26;
av2[2]=lf[48];
av2[3]=lf[49];
((C_proc)(void*)(*((C_word*)t27+1)))(4,av2);}}

/* mark in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_4700(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;{}
t2=C_i_not(((C_word*)((C_word*)t0)[2])[1]);
t3=(C_truep(t2)?C_i_not(C_i_memq(t1,((C_word*)((C_word*)t0)[3])[1])):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_a_i_cons(&a,2,t1,((C_word*)((C_word*)t0)[4])[1]);
t5=C_mutate(((C_word *)((C_word*)t0)[4])+1,t4);
return(t5);}
else{
t4=C_SCHEME_UNDEFINED;
return(t4);}}

/* remember in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4723(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_4723,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4728,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:71: chicken.base#alist-update! */
t5=*((C_word*)lf[22]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
av2[3]=t3;
av2[4]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k4726 in remember in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4728(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_4728,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* touch in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_4730(C_word t0){
C_word tmp;
C_word t1;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
t1=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_TRUE);
t2=C_set_block_item(((C_word*)t0)[3],0,C_SCHEME_END_OF_LIST);
return(t2);}

/* scan-each in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4735(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_4735,5,t0,t1,t2,t3,t4);}
a=C_alloc(12);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_4737,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t6=C_i_check_list_2(t2,lf[23]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4753,a[2]=t8,a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_4753(t10,t1,t2);}

/* g584 in scan-each in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4737(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_4737,3,t0,t1,t2);}
if(C_truep(((C_word*)t0)[2])){
t3=C_set_block_item(((C_word*)t0)[3],0,C_SCHEME_END_OF_LIST);
/* optimizer.scm:80: scan */
t4=((C_word*)((C_word*)t0)[4])[1];
f_4776(t4,t1,t2,((C_word*)t0)[5]);}
else{
/* optimizer.scm:80: scan */
t3=((C_word*)((C_word*)t0)[4])[1];
f_4776(t3,t1,t2,((C_word*)t0)[5]);}}

/* for-each-loop583 in scan-each in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4753(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_4753,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4763,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:78: g584 */
t4=((C_word*)t0)[3];
f_4737(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k4761 in for-each-loop583 in scan-each in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_4763,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_4753(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4776(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_4776,4,t0,t1,t2,t3);}
a=C_alloc(12);
t4=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_4780,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=t2,a[11]=((C_word*)t0)[8],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:84: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_4780,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_4783,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:85: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4783(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_4783,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_4786,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* optimizer.scm:86: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4786(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_4786,c,av);}
a=C_alloc(15);
t2=C_eqp(t1,lf[24]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4798,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_memq(t3,((C_word*)t0)[5]);
t6=C_i_not(t5);
t7=(C_truep(t6)?C_i_not(C_i_memq(t3,((C_word*)((C_word*)t0)[6])[1])):C_SCHEME_FALSE);
if(C_truep(t7)){
t8=C_a_i_cons(&a,2,t3,((C_word*)((C_word*)t0)[6])[1]);
t9=C_mutate(((C_word *)((C_word*)t0)[6])+1,t8);
t10=t4;
f_4798(t10,t9);}
else{
t8=t4;
f_4798(t8,C_SCHEME_UNDEFINED);}}
else{
t3=C_eqp(t1,lf[25]);
t4=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_4846,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[10],a[8]=t1,a[9]=((C_word*)t0)[2],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[6],a[14]=((C_word*)t0)[3],tmp=(C_word)a,a+=15,tmp);
if(C_truep(t3)){
t5=t4;
f_4846(t5,t3);}
else{
t5=C_eqp(t1,lf[39]);
t6=t4;
f_4846(t6,(C_truep(t5)?t5:C_eqp(t1,lf[40])));}}}

/* k4796 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4798(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_4798,2,t0,t1);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4802,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4804,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:93: filter */
f_4012(t2,t3,((C_word*)((C_word*)t0)[2])[1]);}

/* k4800 in k4796 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4802(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_4802,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a4803 in k4796 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_4804,c,av);}
t3=C_i_car(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_not(C_eqp(t3,((C_word*)t0)[2]));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_4846(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_4846,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_4849,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:96: scan */
t3=((C_word*)((C_word*)t0)[7])[1];
f_4776(t3,t2,C_i_car(((C_word*)t0)[5]),((C_word*)t0)[6]);}
else{
t2=C_eqp(((C_word*)t0)[8],lf[26]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_4872,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4887,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:101: chicken.base#butlast */
t5=*((C_word*)lf[27]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=C_eqp(((C_word*)t0)[8],lf[28]);
t4=(C_truep(t3)?t3:C_eqp(((C_word*)t0)[8],lf[29]));
if(C_truep(t4)){
t5=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(((C_word*)t0)[8],lf[30]);
if(C_truep(t5)){
/* optimizer.scm:106: touch */
t6=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t6;
av2[1]=(
/* optimizer.scm:106: touch */
  f_4730(((C_word*)((C_word*)t0)[2])[1])
);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_eqp(((C_word*)t0)[8],lf[31]);
if(C_truep(t6)){
t7=C_i_car(((C_word*)t0)[9]);
t8=C_i_car(((C_word*)t0)[5]);
t9=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_4920,a[2]=t7,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[11],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[13],a[9]=((C_word*)t0)[14],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:111: scan */
t10=((C_word*)((C_word*)t0)[7])[1];
f_4776(t10,t9,t8,((C_word*)t0)[6]);}
else{
/* optimizer.scm:125: scan-each */
t7=((C_word*)((C_word*)t0)[3])[1];
f_4735(t7,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_FALSE);}}}}}}

/* k4847 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_4849,c,av);}
t2=(
/* optimizer.scm:97: touch */
  f_4730(((C_word*)((C_word*)t0)[2])[1])
);
/* optimizer.scm:98: scan-each */
t3=((C_word*)((C_word*)t0)[3])[1];
f_4735(t3,((C_word*)t0)[4],C_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],C_SCHEME_TRUE);}

/* k4870 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4872(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_4872,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_4178,tmp=(C_word)a,a+=2,tmp);
t3=(
  f_4178(((C_word*)t0)[2])
);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_4883,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:102: scheme#append */
t5=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k4881 in k4870 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4883(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_4883,c,av);}
/* optimizer.scm:102: scan */
t2=((C_word*)((C_word*)t0)[2])[1];
f_4776(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k4885 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_4887,c,av);}
/* optimizer.scm:101: scan-each */
t2=((C_word*)((C_word*)t0)[2])[1];
f_4735(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],C_SCHEME_FALSE);}

/* k4918 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4920(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_4920,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_4923,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:112: chicken.base#alist-ref */
t3=*((C_word*)lf[38]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)((C_word*)t0)[9])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k4921 in k4918 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_4923,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_4926,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=(C_truep(t1)?C_i_not(C_i_memq(((C_word*)t0)[2],((C_word*)((C_word*)t0)[8])[1])):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4944,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:118: chicken.compiler.support#debugging */
t5=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[36];
av2[3]=lf[37];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_4926(2,av2);}}}

/* k4924 in k4921 in k4918 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4926(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_4926,c,av);}
a=C_alloc(3);
if(C_truep(C_i_memq(((C_word*)t0)[2],((C_word*)t0)[3]))){
/* optimizer.scm:123: remember */
t2=((C_word*)((C_word*)t0)[4])[1];
f_4723(t2,((C_word*)t0)[5],((C_word*)t0)[2],((C_word*)t0)[6]);}
else{
t2=(
/* optimizer.scm:122: mark */
  f_4700(C_a_i(&a,3),((C_word*)((C_word*)t0)[7])[1],((C_word*)t0)[2])
);
/* optimizer.scm:123: remember */
t3=((C_word*)((C_word*)t0)[4])[1];
f_4723(t3,((C_word*)t0)[5],((C_word*)t0)[2],((C_word*)t0)[6]);}}

/* k4942 in k4921 in k4918 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_4944,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4951,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:120: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k4949 in k4942 in k4921 in k4918 in k4844 in k4784 in k4781 in k4778 in scan in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_4951,c,av);}
/* optimizer.scm:119: chicken.compiler.support#copy-node! */
t2=*((C_word*)lf[32]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4994(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_4994,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4997,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:128: scan */
t3=((C_word*)((C_word*)t0)[4])[1];
f_4776(t3,t2,((C_word*)t0)[5],C_SCHEME_END_OF_LIST);}

/* k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_4997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_4997,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5000,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[2])[1]))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5044,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=((C_word*)((C_word*)t0)[2])[1];
t5=*((C_word*)lf[47]+1);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3973,a[2]=t7,a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_3973(t9,t3,t4);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_5000(2,av2);}}}

/* k4998 in k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5000(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_5000,c,av);}
a=C_alloc(5);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_i_check_list_2(t2,lf[23]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5013,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_5013(t7,((C_word*)t0)[3],t2);}

/* for-each-loop565 in k4998 in k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5013(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_5013,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5023,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[44]+1);
/* optimizer.scm:131: g642 */
t6=*((C_word*)lf[44]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[45];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k5021 in for-each-loop565 in k4998 in k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5023(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5023,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_5013(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k5042 in k4995 in k4992 in chicken.compiler.optimizer#scan-toplevel-assignments in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5044(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5044,c,av);}
/* optimizer.scm:130: chicken.compiler.support#debugging */
t2=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[36];
av2[3]=lf[46];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5048(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(52,c,9)))){
C_save_and_reclaim((void *)f_5048,c,av);}
a=C_alloc(52);
t2=C_mutate(&lf[50] /* (set! chicken.compiler.optimizer#simplifications ...) */,t1);
t3=lf[51] /* chicken.compiler.optimizer#simplified-ops */ =C_SCHEME_END_OF_LIST;;
t4=lf[52] /* chicken.compiler.optimizer#broken-constant-nodes */ =C_SCHEME_END_OF_LIST;;
t5=lf[53] /* chicken.compiler.optimizer#inline-history */ =C_SCHEME_END_OF_LIST;;
t6=C_mutate((C_word*)lf[54]+1 /* (set! chicken.compiler.optimizer#perform-high-level-optimizations ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_5053,tmp=(C_word)a,a+=2,tmp));
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7734,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t8=C_a_i_list(&a,1,lf[192]);
t9=C_a_i_list(&a,2,lf[24],t8);
t10=C_a_i_cons(&a,2,lf[230],lf[231]);
t11=C_a_i_cons(&a,2,t9,t10);
t12=C_a_i_cons(&a,2,lf[219],t11);
t13=C_a_i_cons(&a,2,lf[30],t12);
t14=C_a_i_list(&a,4,lf[192],lf[230],lf[231],lf[219]);
t15=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_14094,tmp=(C_word)a,a+=2,tmp);
t16=C_a_i_list(&a,3,t13,t14,t15);
t17=C_a_i_list(&a,1,t16);
/* optimizer.scm:708: chicken.internal#hash-table-set! */
t18=*((C_word*)lf[161]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t18;
av2[1]=t7;
av2[2]=lf[50];
av2[3]=lf[30];
av2[4]=t17;
((C_proc)(void*)(*((C_word*)t18+1)))(5,av2);}}

/* chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5053(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(116,c,9)))){
C_save_and_reclaim((void *)f_5053,c,av);}
a=C_alloc(116);
t9=C_fix(0);
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_fix(0);
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_fix(0);
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_SCHEME_END_OF_LIST;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_SCHEME_END_OF_LIST;
t18=(*a=C_VECTOR_TYPE|1,a[1]=t17,tmp=(C_word)a,a+=2,tmp);
t19=C_SCHEME_FALSE;
t20=(*a=C_VECTOR_TYPE|1,a[1]=t19,tmp=(C_word)a,a+=2,tmp);
t21=C_SCHEME_UNDEFINED;
t22=(*a=C_VECTOR_TYPE|1,a[1]=t21,tmp=(C_word)a,a+=2,tmp);
t23=C_SCHEME_UNDEFINED;
t24=(*a=C_VECTOR_TYPE|1,a[1]=t23,tmp=(C_word)a,a+=2,tmp);
t25=C_SCHEME_UNDEFINED;
t26=(*a=C_VECTOR_TYPE|1,a[1]=t25,tmp=(C_word)a,a+=2,tmp);
t27=C_SCHEME_UNDEFINED;
t28=(*a=C_VECTOR_TYPE|1,a[1]=t27,tmp=(C_word)a,a+=2,tmp);
t29=C_SCHEME_UNDEFINED;
t30=(*a=C_VECTOR_TYPE|1,a[1]=t29,tmp=(C_word)a,a+=2,tmp);
t31=C_SCHEME_UNDEFINED;
t32=(*a=C_VECTOR_TYPE|1,a[1]=t31,tmp=(C_word)a,a+=2,tmp);
t33=C_SCHEME_UNDEFINED;
t34=(*a=C_VECTOR_TYPE|1,a[1]=t33,tmp=(C_word)a,a+=2,tmp);
t35=C_SCHEME_UNDEFINED;
t36=(*a=C_VECTOR_TYPE|1,a[1]=t35,tmp=(C_word)a,a+=2,tmp);
t37=C_SCHEME_UNDEFINED;
t38=(*a=C_VECTOR_TYPE|1,a[1]=t37,tmp=(C_word)a,a+=2,tmp);
t39=C_set_block_item(t22,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5056,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t40=C_set_block_item(t24,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5082,a[2]=t20,tmp=(C_word)a,a+=3,tmp));
t41=C_set_block_item(t26,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_5086,tmp=(C_word)a,a+=2,tmp));
t42=C_set_block_item(t28,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5123,a[2]=t18,a[3]=t24,a[4]=t28,a[5]=t3,a[6]=t8,tmp=(C_word)a,a+=7,tmp));
t43=C_set_block_item(t30,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5251,a[2]=t24,a[3]=t22,a[4]=t3,tmp=(C_word)a,a+=5,tmp));
t44=C_set_block_item(t32,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5413,a[2]=t20,a[3]=t28,a[4]=t12,a[5]=t24,a[6]=t32,a[7]=t30,a[8]=t36,tmp=(C_word)a,a+=9,tmp));
t45=C_set_block_item(t34,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5551,a[2]=t3,a[3]=t34,a[4]=t22,tmp=(C_word)a,a+=5,tmp));
t46=C_set_block_item(t36,0,(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_5571,a[2]=t24,a[3]=t22,a[4]=t14,a[5]=t34,a[6]=t10,a[7]=t32,a[8]=t38,a[9]=t3,a[10]=t26,a[11]=t16,a[12]=t5,a[13]=t6,a[14]=t7,a[15]=t4,tmp=(C_word)a,a+=16,tmp));
t47=C_set_block_item(t38,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7240,a[2]=t26,a[3]=t32,tmp=(C_word)a,a+=4,tmp));
t48=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7300,a[2]=t1,a[3]=t2,a[4]=t20,a[5]=t12,a[6]=t10,a[7]=t14,a[8]=t18,a[9]=t32,tmp=(C_word)a,a+=10,tmp);
t49=C_SCHEME_FALSE;
t50=(*a=C_VECTOR_TYPE|1,a[1]=t49,tmp=(C_word)a,a+=2,tmp);
t51=C_fix(0);
t52=(*a=C_VECTOR_TYPE|1,a[1]=t51,tmp=(C_word)a,a+=2,tmp);
t53=C_SCHEME_UNDEFINED;
t54=(*a=C_VECTOR_TYPE|1,a[1]=t53,tmp=(C_word)a,a+=2,tmp);
t55=C_SCHEME_UNDEFINED;
t56=(*a=C_VECTOR_TYPE|1,a[1]=t55,tmp=(C_word)a,a+=2,tmp);
t57=C_set_block_item(t54,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7469,a[2]=t50,tmp=(C_word)a,a+=3,tmp));
t58=C_set_block_item(t56,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7473,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t59=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7480,a[2]=t48,a[3]=t50,a[4]=t52,a[5]=t54,a[6]=t3,a[7]=t56,tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:660: chicken.compiler.support#debugging */
t60=*((C_word*)lf[35]+1);{
C_word *av2=av;
av2[0]=t60;
av2[1]=t59;
av2[2]=lf[48];
av2[3]=lf[158];
((C_proc)(void*)(*((C_word*)t60+1)))(4,av2);}}

/* test in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5056(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_5056,4,t0,t1,t2,t3);}
/* optimizer.scm:166: chicken.compiler.support#db-get */
t4=*((C_word*)lf[55]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k5068 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5070(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,2)))){
C_save_and_reclaim((void *)f_5070,c,av);}
a=C_alloc(36);
t2=C_eqp(lf[76],t1);
if(C_truep(t2)){
t3=((C_word*)((C_word*)t0)[2])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t3,C_fix(1)));
t5=(
/* optimizer.scm:235: touch */
  f_5082(((C_word*)((C_word*)t0)[3])[1])
);
t6=C_u_i_car(((C_word*)t0)[4]);
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5080,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:168: chicken.compiler.support#node-parameters */
t8=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
/* optimizer.scm:226: simplify */
t3=((C_word*)((C_word*)t0)[9])[1];
f_5123(t3,((C_word*)t0)[10],((C_word*)t0)[11]);}}

/* k5078 in k5068 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5080,c,av);}
t2=C_i_car(t1);
t3=(C_truep(t2)?C_i_cadr(((C_word*)t0)[2]):C_i_caddr(((C_word*)t0)[2]));
/* optimizer.scm:236: walk */
t4=((C_word*)((C_word*)t0)[3])[1];
f_5413(t4,((C_word*)t0)[4],t3,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* touch in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_5082(C_word t0){
C_word tmp;
C_word t1;
C_word t2;
C_stack_overflow_check;{}
t1=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_TRUE);
return(t1);}

/* invalidate-gae! in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5086(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(2,0,2)))){
C_save_and_reclaim_args((void *)trf_5086,2,t1,t2);}
a=C_alloc(2);
t3=C_i_check_list_2(t2,lf[23]);
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_5100,tmp=(C_word)a,a+=2,tmp);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(
  f_5100(t2)
);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* for-each-loop693 in invalidate-gae! in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_5100(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_slot(t1,C_fix(0));
t3=C_i_set_cdr(t2,C_SCHEME_FALSE);
t5=C_slot(t1,C_fix(1));
t1=t5;
goto loop;}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5123(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_5123,3,t0,t1,t2);}
a=C_alloc(12);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5127,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5249,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:176: chicken.compiler.support#node-class */
t5=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5127(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_5127,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5130,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5138,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:177: any */
f_3806(t2,t3,t1);}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k5128 in k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5130,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?t1:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a5137 in k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5138(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5138,c,av);}
a=C_alloc(10);
t3=C_i_cadr(t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5148,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t1,a[7]=t3,a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:179: chicken.compiler.support#match-node */
t5=*((C_word*)lf[56]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
av2[3]=C_i_car(t2);
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k5146 in a5137 in k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_5148,c,av);}
a=C_alloc(29);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5154,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_i_caddr(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5193,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t9=C_i_check_list_2(((C_word*)t0)[7],lf[8]);
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5207,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],tmp=(C_word)a,a+=6,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5209,a[2]=t8,a[3]=t6,a[4]=t12,a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_5209(t14,t10,((C_word*)t0)[7]);}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k5152 in k5146 in a5137 in k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5154(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_5154,c,av);}
a=C_alloc(29);
if(C_truep(t1)){
t2=C_i_caar(((C_word*)t0)[2]);
t3=C_i_assq(t2,((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(t3)){
t4=C_i_cdr(t3);
t5=C_s_a_i_plus(&a,2,t4,C_fix(1));
t6=C_i_set_cdr(t3,t5);
t7=(
/* optimizer.scm:187: touch */
  f_5082(((C_word*)((C_word*)t0)[4])[1])
);
/* optimizer.scm:188: simplify */
t8=((C_word*)((C_word*)t0)[5])[1];
f_5123(t8,((C_word*)t0)[6],t1);}
else{
t4=((C_word*)((C_word*)t0)[3])[1];
t5=C_a_i_cons(&a,2,t2,C_fix(1));
t6=C_a_i_cons(&a,2,t5,t4);
t7=C_mutate(((C_word *)((C_word*)t0)[3])+1,t6);
t8=(
/* optimizer.scm:187: touch */
  f_5082(((C_word*)((C_word*)t0)[4])[1])
);
/* optimizer.scm:188: simplify */
t9=((C_word*)((C_word*)t0)[5])[1];
f_5123(t9,((C_word*)t0)[6],t1);}}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g733 in k5146 in a5137 in k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_5193(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_i_cdr(C_i_assq(t1,((C_word*)t0)[2])));}

/* k5205 in k5146 in a5137 in k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_5207,c,av);}{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=t1;
C_apply(6,av2);}}

/* map-loop727 in k5146 in a5137 in k5125 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5209(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_5209,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=(
/* optimizer.scm:181: g733 */
  f_5193(((C_word*)t0)[2],C_slot(t2,C_fix(0)))
);
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[3])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[3])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k5247 in simplify in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5249,c,av);}
/* optimizer.scm:175: chicken.internal#hash-table-ref */
t2=*((C_word*)lf[57]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[50];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5251(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_5251,3,t0,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5411,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:197: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k5256 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5258,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?t1:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5270(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_5270,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5382,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:205: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k5304 in k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5306(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_5306,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=C_i_car(t1);
if(C_truep(t2)){
t3=C_u_i_cdr(t1);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5362,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=t3,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:213: test */
t5=((C_word*)((C_word*)t0)[8])[1];
f_5056(t5,t4,((C_word*)t0)[6],lf[62]);}
else{
t4=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k5326 in k5360 in k5304 in k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_5328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_5328,c,av);}
a=C_alloc(9);
t2=(
/* optimizer.scm:217: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5338,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5350,a[2]=t3,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:219: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k5336 in k5326 in k5360 in k5304 in k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_5338(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5338,c,av);}
/* optimizer.scm:218: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k5348 in k5326 in k5360 in k5304 in k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_5350(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_5350,c,av);}
a=C_alloc(6);
t2=C_i_cdr(t1);
/* optimizer.scm:219: cons* */
f_3836(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,2,((C_word*)t0)[4],t2));}

/* k5352 in k5360 in k5304 in k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_5354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_5354,c,av);}
/* optimizer.scm:215: chicken.compiler.support#debugging */
t2=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[59];
av2[3]=lf[60];
av2[4]=t1;
av2[5]=((C_word*)t0)[3];
av2[6]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(7,av2);}}

/* k5356 in k5360 in k5304 in k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_5358(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5358,c,av);}
/* optimizer.scm:216: chicken.compiler.support#call-info */
t2=*((C_word*)lf[61]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k5360 in k5304 in k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_5362(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_5362,c,av);}
a=C_alloc(17);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5328,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5354,a[2]=t2,a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5358,a[2]=t3,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:216: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t2=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k5364 in k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_5366,c,av);}
a=C_alloc(9);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5306,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:210: chicken.compiler.support#db-get */
t3=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[63];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k5368 in k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5370(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5370,c,av);}
a=C_alloc(10);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5366,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:209: chicken.compiler.support#db-get */
t3=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[64];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k5372 in k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5374,c,av);}
a=C_alloc(10);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5370,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:208: chicken.compiler.support#db-get */
t4=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
av2[3]=t2;
av2[4]=lf[65];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k5376 in k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5378(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_5378,c,av);}
a=C_alloc(9);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5374,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:207: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k5380 in k5268 in k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_5382,c,av);}
a=C_alloc(10);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5378,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t2,tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:206: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k5405 in k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5407(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_5407,c,av);}
a=C_alloc(8);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5270,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep((C_truep(C_i_equalp(t2,lf[66]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(t2,lf[67]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
t4=t3;
f_5270(t4,lf[68]);}
else{
if(C_truep((C_truep(C_i_equalp(t2,lf[69]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(t2,lf[70]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
t4=t3;
f_5270(t4,lf[71]);}
else{
if(C_truep((C_truep(C_i_equalp(t2,lf[72]))?C_SCHEME_TRUE:C_SCHEME_FALSE))){
t4=t3;
f_5270(t4,lf[73]);}
else{
t4=C_i_member(t2,lf[74]);
t5=t3;
f_5270(t5,(C_truep(t4)?lf[75]:C_SCHEME_FALSE));}}}}
else{
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k5409 in maybe-replace-rest-arg-calls in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5411(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_5411,c,av);}
a=C_alloc(12);
t2=C_eqp(lf[58],t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5258,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t2)){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5407,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:198: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5413(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_5413,5,t0,t1,t2,t3,t4);}
a=C_alloc(12);
if(C_truep(C_i_memq(t2,lf[52]))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=((C_word*)((C_word*)t0)[2])[1];
t6=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_5427,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t3,a[8]=t4,a[9]=((C_word*)t0)[7],a[10]=t5,a[11]=((C_word*)t0)[2],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:228: walk1 */
t7=((C_word*)((C_word*)t0)[8])[1];
f_5571(t7,t6,t2,t3,t4);}}

/* k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5427(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_5427,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_5430,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:229: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_5430,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_5433,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* optimizer.scm:230: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5433(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,5)))){
C_save_and_reclaim((void *)f_5433,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5436,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_eqp(t1,lf[25]);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_5070,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[7],a[6]=t2,a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[2],a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:167: chicken.compiler.support#node-class */
t6=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=C_eqp(t1,lf[58]);
if(C_truep(t4)){
/* optimizer.scm:243: maybe-replace-rest-arg-calls */
t5=((C_word*)((C_word*)t0)[11])[1];
f_5251(t5,t2,((C_word*)t0)[10]);}
else{
t5=C_eqp(t1,lf[30]);
if(C_truep(t5)){
t6=C_i_car(((C_word*)t0)[4]);
t7=C_i_cddr(((C_word*)t0)[4]);
t8=C_a_i_cons(&a,2,t6,t7);
t9=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5496,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:246: chicken.compiler.support#maybe-constant-fold-call */
t10=*((C_word*)lf[78]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t10;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
av2[3]=t8;
av2[4]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
/* optimizer.scm:226: simplify */
t6=((C_word*)((C_word*)t0)[2])[1];
f_5123(t6,((C_word*)t0)[3],((C_word*)t0)[10]);}}}}

/* k5434 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5436(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5436,c,av);}
/* optimizer.scm:226: simplify */
t2=((C_word*)((C_word*)t0)[2])[1];
f_5123(t2,((C_word*)t0)[3],t1);}

/* a5495 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_5496,c,av);}
a=C_alloc(4);
if(C_truep(C_i_not(t2))){
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5509,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[3])){
t6=t5;
f_5509(t6,C_SCHEME_UNDEFINED);}
else{
t6=C_set_block_item(((C_word*)t0)[4],0,C_SCHEME_FALSE);
t7=t5;
f_5509(t7,t6);}}
else{
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t5=(
/* optimizer.scm:257: touch */
  f_5082(((C_word*)((C_word*)t0)[5])[1])
);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5520,a[2]=((C_word*)t0)[6],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:259: chicken.compiler.support#qnode */
t7=*((C_word*)lf[77]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k5507 in a5495 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5509(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_5509,2,t0,t1);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5513,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=lf[52];
t4=C_a_i_list(&a,1,((C_word*)t0)[3]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4237,a[2]=t6,tmp=(C_word)a,a+=3,tmp));
t8=((C_word*)t6)[1];
f_4237(t8,t2,t4,lf[52]);}

/* k5511 in k5507 in a5495 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5513(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5513,c,av);}
t2=C_mutate(&lf[52] /* (set! chicken.compiler.optimizer#broken-constant-nodes ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k5518 in a5495 in k5431 in k5428 in k5425 in walk in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_5520,c,av);}
a=C_alloc(9);
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=C_i_cadr(((C_word*)t0)[2]);
t4=C_a_i_list2(&a,2,t3,t1);
/* optimizer.scm:260: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=t2;
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* replace-var in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5551(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_5551,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5555,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:267: test */
t4=((C_word*)((C_word*)t0)[4])[1];
f_5056(t4,t3,t2,lf[80]);}

/* k5553 in replace-var in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5555(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_5555,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5559,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:267: g827 */
t3=t2;
f_5559(t3,((C_word*)t0)[5],t1);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g827 in k5553 in replace-var in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5559(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_5559,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5563,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:269: replace-var */
t4=((C_word*)((C_word*)t0)[4])[1];
f_5551(t4,t3,t2);}

/* k5561 in g827 in k5553 in replace-var in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5563(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_5563,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5566,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:271: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[79]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[80];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k5564 in k5561 in g827 in k5553 in replace-var in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5566(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5566,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5571(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,2)))){
C_save_and_reclaim_args((void *)trf_5571,5,t0,t1,t2,t3,t4);}
a=C_alloc(20);
t5=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_5575,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t4,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=t3,a[11]=((C_word*)t0)[8],a[12]=t2,a[13]=((C_word*)t0)[9],a[14]=((C_word*)t0)[10],a[15]=((C_word*)t0)[11],a[16]=((C_word*)t0)[12],a[17]=((C_word*)t0)[13],a[18]=((C_word*)t0)[14],a[19]=((C_word*)t0)[15],tmp=(C_word)a,a+=20,tmp);
/* optimizer.scm:276: chicken.compiler.support#node-subexpressions */
t6=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5575(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,2)))){
C_save_and_reclaim((void *)f_5575,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_5578,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],tmp=(C_word)a,a+=21,tmp);
/* optimizer.scm:277: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5578(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,2)))){
C_save_and_reclaim((void *)f_5578,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_5581,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
/* optimizer.scm:278: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[13];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,8)))){
C_save_and_reclaim((void *)f_5581,c,av);}
a=C_alloc(20);
t2=C_eqp(t1,lf[24]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5590,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:282: replace-var */
t4=((C_word*)((C_word*)t0)[8])[1];
f_5551(t4,t3,C_i_car(((C_word*)t0)[5]));}
else{
t3=C_eqp(t1,lf[26]);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[5]);
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_5703,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[11],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[5],a[10]=t4,a[11]=((C_word*)t0)[4],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:303: test */
t6=((C_word*)((C_word*)t0)[4])[1];
f_5056(t6,t5,t4,lf[92]);}
else{
t4=C_eqp(t1,lf[29]);
if(C_truep(t4)){
t5=C_i_caddr(((C_word*)t0)[5]);
t6=C_i_car(((C_word*)t0)[5]);
t7=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_5848,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[11],a[6]=t6,a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[3],a[10]=t5,a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=t1,tmp=(C_word)a,a+=14,tmp);
/* optimizer.scm:321: test */
t8=((C_word*)((C_word*)t0)[4])[1];
f_5056(t8,t7,t6,lf[100]);}
else{
t5=C_eqp(t1,lf[101]);
if(C_truep(t5)){
/* optimizer.scm:354: walk-generic */
t6=((C_word*)((C_word*)t0)[13])[1];
f_7240(t6,((C_word*)t0)[3],((C_word*)t0)[14],t1,((C_word*)t0)[5],((C_word*)t0)[11],((C_word*)t0)[12],C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);}
else{
t6=C_eqp(t1,lf[30]);
if(C_truep(t6)){
t7=C_i_car(((C_word*)t0)[11]);
t8=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_6021,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[15],a[5]=((C_word*)t0)[12],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[13],a[10]=((C_word*)t0)[14],a[11]=t1,a[12]=((C_word*)t0)[5],a[13]=t7,a[14]=((C_word*)t0)[16],a[15]=((C_word*)t0)[4],a[16]=((C_word*)t0)[17],a[17]=((C_word*)t0)[18],a[18]=((C_word*)t0)[19],a[19]=((C_word*)t0)[20],tmp=(C_word)a,a+=20,tmp);
/* optimizer.scm:358: chicken.compiler.support#node-class */
t9=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=t7;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t7=C_eqp(t1,lf[31]);
if(C_truep(t7)){
t8=C_i_car(((C_word*)t0)[5]);
t9=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_6992,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t8,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[15],a[12]=((C_word*)t0)[21],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:545: test */
t10=((C_word*)((C_word*)t0)[4])[1];
f_5056(t10,t9,t8,lf[91]);}
else{
t8=C_eqp(t1,lf[71]);
t9=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_7175,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[13],a[7]=((C_word*)t0)[14],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[4],tmp=(C_word)a,a+=12,tmp);
if(C_truep(t8)){
t10=t9;
f_7175(t10,t8);}
else{
t10=C_eqp(t1,lf[68]);
if(C_truep(t10)){
t11=t9;
f_7175(t11,t10);}
else{
t11=C_eqp(t1,lf[73]);
t12=t9;
f_7175(t12,(C_truep(t11)?t11:C_eqp(t1,lf[75])));}}}}}}}}}

/* k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_5590,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5596,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:283: test */
t3=((C_word*)((C_word*)t0)[4])[1];
f_5056(t3,t2,t1,lf[88]);}

/* k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5596(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_5596,c,av);}
a=C_alloc(29);
if(C_truep(t1)){
t2=(
/* optimizer.scm:284: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5602,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:285: chicken.compiler.support#debugging */
t4=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[36];
av2[3]=lf[82];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t2=C_i_car(((C_word*)t0)[6]);
t3=C_eqp(((C_word*)t0)[5],t2);
if(C_truep(C_i_not(t3))){
t4=(
/* optimizer.scm:288: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t5=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[7])[1],C_fix(1));
t6=C_mutate(((C_word *)((C_word*)t0)[7])+1,t5);
/* optimizer.scm:290: chicken.compiler.support#varnode */
t7=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t4=C_i_assq(((C_word*)t0)[5],((C_word*)t0)[8]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5640,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:283: g855 */
t6=t5;
f_5640(t6,((C_word*)t0)[3],t4);}
else{
/* optimizer.scm:299: chicken.compiler.support#varnode */
t5=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}}}

/* k5600 in k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_5602,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5613,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5617,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:286: test */
t4=((C_word*)((C_word*)t0)[3])[1];
f_5056(t4,t3,((C_word*)t0)[4],lf[81]);}

/* k5611 in k5600 in k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5613,c,av);}
/* optimizer.scm:286: chicken.compiler.support#qnode */
t2=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k5615 in k5600 in k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5617,c,av);}
/* optimizer.scm:286: chicken.compiler.support#node-parameters */
t2=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* g855 in k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5640(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_5640,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_cdr(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5650,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t3)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5670,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:295: chicken.compiler.support#variable-mark */
t6=*((C_word*)lf[86]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
av2[3]=lf[87];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t5=t4;
f_5650(t5,C_SCHEME_FALSE);}}

/* k5648 in g855 in k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5650(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,5)))){
C_save_and_reclaim_args((void *)trf_5650,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5653,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:296: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[84];
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
/* optimizer.scm:298: chicken.compiler.support#varnode */
t2=*((C_word*)lf[83]+1);{
C_word av2[3];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}}

/* k5651 in k5648 in g855 in k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5653(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_5653,c,av);}
/* optimizer.scm:297: chicken.compiler.support#varnode */
t2=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k5668 in g855 in k5594 in k5588 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5670(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5670,c,av);}
t2=((C_word*)t0)[2];
f_5650(t2,C_i_not(C_eqp(lf[85],t1)));}

/* k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5703(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_5703,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_5706,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(t1)){
t3=t2;
f_5706(t3,t1);}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5823,a[2]=t2,a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[10],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:304: test */
t4=((C_word*)((C_word*)t0)[11])[1];
f_5056(t4,t3,((C_word*)t0)[10],lf[91]);}}

/* k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5706(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,4)))){
C_save_and_reclaim_args((void *)trf_5706,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=(
/* optimizer.scm:306: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=((C_word*)((C_word*)t0)[3])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[3])+1,C_s_a_i_plus(&a,2,t3,C_fix(1)));
/* optimizer.scm:308: walk */
t5=((C_word*)((C_word*)t0)[4])[1];
f_5413(t5,((C_word*)t0)[5],C_i_cadr(((C_word*)t0)[6]),((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_5721,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[9],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5776,a[2]=((C_word*)t0)[10],a[3]=t2,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5813,a[2]=((C_word*)t0)[11],a[3]=t3,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:310: chicken.compiler.support#node-class */
t5=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k5719 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5721(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,0,3)))){
C_save_and_reclaim_args((void *)trf_5721,2,t0,t1);}
a=C_alloc(22);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5729,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t7=C_i_check_list_2(((C_word*)t0)[4],lf[8]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5739,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5741,a[2]=t4,a[3]=t10,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_5741(t12,t8,((C_word*)t0)[4]);}

/* g886 in k5719 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5729(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_5729,3,t0,t1,t2);}
/* optimizer.scm:316: g903 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_5413(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k5737 in k5719 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5739(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_5739,c,av);}
/* optimizer.scm:316: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop880 in k5719 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5741(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_5741,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5766,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:316: g886 */
t4=((C_word*)t0)[4];
f_5729(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k5764 in map-loop880 in k5719 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5766(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_5766,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_5741(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k5774 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_5776,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5787,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:313: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];
f_5721(t2,((C_word*)t0)[4]);}}

/* k5785 in k5774 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_5787,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t2);
t4=((C_word*)t0)[3];
f_5721(t4,C_a_i_cons(&a,2,t3,((C_word*)t0)[4]));}

/* k5803 in k5811 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_5805,c,av);}
/* optimizer.scm:311: test */
t2=((C_word*)((C_word*)t0)[2])[1];
f_5056(t2,((C_word*)t0)[3],C_i_car(t1),lf[89]);}

/* k5811 in k5704 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_5813,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5805,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:311: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_5776(2,av2);}}}

/* k5821 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_5823,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5830,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:305: test */
t3=((C_word*)((C_word*)t0)[3])[1];
f_5056(t3,t2,((C_word*)t0)[4],lf[90]);}
else{
t2=((C_word*)t0)[2];
f_5706(t2,C_SCHEME_FALSE);}}

/* k5828 in k5821 in k5701 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5830(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_5830,c,av);}
t2=((C_word*)t0)[2];
f_5706(t2,C_i_not(t1));}

/* k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5848(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,5)))){
C_save_and_reclaim((void *)f_5848,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_5853,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:322: ##sys#decompose-lambda-list */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[9];
av2[2]=((C_word*)t0)[10];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_5940,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:338: test */
t3=((C_word*)((C_word*)t0)[2])[1];
f_5056(t3,t2,((C_word*)t0)[6],lf[96]);}}

/* a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_5853,c,av);}
a=C_alloc(15);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5859,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_5871,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t3,a[9]=t4,a[10]=((C_word*)t0)[2],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:325: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t5;
av2[3]=t6;
C_call_with_values(4,av2);}}

/* a5858 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_5859,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_5865,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_3409,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_3409(t6,t1,C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST,((C_word*)t0)[3]);}

/* a5864 in a5858 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_5865(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_5865,3,t0,t1,t2);}
/* optimizer.scm:325: test */
t3=((C_word*)((C_word*)t0)[2])[1];
f_5056(t3,t1,t2,lf[93]);}

/* a5870 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_5871,c,av);}
a=C_alloc(12);
t4=(
/* optimizer.scm:326: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_5878,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t3,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:327: chicken.compiler.support#debugging */
t6=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[36];
av2[3]=lf[97];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* k5876 in a5870 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5878(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_5878,c,av);}
a=C_alloc(16);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_cadr(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5913,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_5920,a[2]=((C_word*)t0)[8],a[3]=t4,a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[10])){
/* optimizer.scm:331: test */
t6=((C_word*)((C_word*)t0)[11])[1];
f_5056(t6,t5,((C_word*)t0)[5],lf[96]);}
else{
t6=t5;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_5920(2,av2);}}}

/* k5891 in k5911 in k5876 in a5870 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5893(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_5893,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:328: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[29];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k5911 in k5876 in a5870 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,4)))){
C_save_and_reclaim((void *)f_5913,c,av);}
a=C_alloc(19);
t2=C_i_cadddr(((C_word*)t0)[2]);
t3=C_a_i_list4(&a,4,((C_word*)t0)[3],((C_word*)t0)[4],t1,t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5893,a[2]=((C_word*)t0)[5],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=C_i_car(((C_word*)t0)[6]);
t6=C_a_i_cons(&a,2,((C_word*)t0)[7],((C_word*)t0)[8]);
/* optimizer.scm:337: walk */
t7=((C_word*)((C_word*)t0)[9])[1];
f_5413(t7,t4,t5,t6,C_SCHEME_END_OF_LIST);}

/* k5918 in k5876 in a5870 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5920(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_5920,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_5923,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:332: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[95];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* optimizer.scm:335: chicken.compiler.support#build-lambda-list */
t2=*((C_word*)lf[94]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[2];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k5921 in k5918 in k5876 in a5870 in a5852 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_5923,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* optimizer.scm:334: chicken.compiler.support#build-lambda-list */
t3=*((C_word*)lf[94]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k5938 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,8)))){
C_save_and_reclaim((void *)f_5940,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_5945,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:339: ##sys#decompose-lambda-list */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[8];
av2[2]=((C_word*)t0)[9];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=C_a_i_cons(&a,2,((C_word*)t0)[5],((C_word*)t0)[6]);
/* optimizer.scm:351: walk-generic */
t3=((C_word*)((C_word*)t0)[10])[1];
f_7240(t3,((C_word*)t0)[8],((C_word*)t0)[11],((C_word*)t0)[12],((C_word*)t0)[3],((C_word*)t0)[4],t2,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);}}

/* a5944 in k5938 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_5945,c,av);}
a=C_alloc(10);
t5=(
/* optimizer.scm:342: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t6=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5952,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t3,a[9]=t2,tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:343: chicken.compiler.support#debugging */
t7=*((C_word*)lf[35]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[36];
av2[3]=lf[99];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}

/* k5950 in a5944 in k5938 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5952(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,4)))){
C_save_and_reclaim((void *)f_5952,c,av);}
a=C_alloc(39);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_cadr(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_5987,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
t5=C_s_a_i_plus(&a,2,((C_word*)t0)[8],C_fix(1));
/* optimizer.scm:348: chicken.compiler.support#build-lambda-list */
t6=*((C_word*)lf[94]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=t5;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* k5965 in k5985 in k5950 in a5944 in k5938 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5967(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_5967,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:344: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[29];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k5985 in k5950 in a5944 in k5938 in k5846 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_5987(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,4)))){
C_save_and_reclaim((void *)f_5987,c,av);}
a=C_alloc(19);
t2=C_i_cadddr(((C_word*)t0)[2]);
t3=C_a_i_list4(&a,4,((C_word*)t0)[3],((C_word*)t0)[4],t1,t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_5967,a[2]=((C_word*)t0)[5],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=C_i_car(((C_word*)t0)[6]);
t6=C_a_i_cons(&a,2,((C_word*)t0)[7],((C_word*)t0)[8]);
/* optimizer.scm:350: walk */
t7=((C_word*)((C_word*)t0)[9])[1];
f_5413(t7,t4,t5,t6,C_SCHEME_END_OF_LIST);}

/* k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,8)))){
C_save_and_reclaim((void *)f_6021,c,av);}
a=C_alloc(30);
t2=C_eqp(t1,lf[24]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_6895,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],tmp=(C_word)a,a+=20,tmp);
/* optimizer.scm:362: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[13];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_eqp(t1,lf[29]);
if(C_truep(t3)){
if(C_truep(C_i_car(((C_word*)t0)[12]))){
/* optimizer.scm:536: walk-generic */
t4=((C_word*)((C_word*)t0)[9])[1];
f_7240(t4,((C_word*)t0)[7],((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[12],((C_word*)t0)[2],((C_word*)t0)[5],((C_word*)t0)[8],C_SCHEME_FALSE);}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6913,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[14],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
t5=C_i_cdr(((C_word*)t0)[12]);
t6=C_a_i_cons(&a,2,C_SCHEME_TRUE,t5);
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6925,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6932,a[2]=t4,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6934,a[2]=t9,a[3]=t14,a[4]=t11,a[5]=t10,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_6934(t16,t12,((C_word*)t0)[2]);}}
else{
/* optimizer.scm:541: walk-generic */
t4=((C_word*)((C_word*)t0)[9])[1];
f_7240(t4,((C_word*)t0)[7],((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[12],((C_word*)t0)[2],((C_word*)t0)[5],((C_word*)t0)[8],C_SCHEME_TRUE);}}}

/* k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,3)))){
C_save_and_reclaim((void *)f_6033,c,av);}
a=C_alloc(27);
t2=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_6036,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6891,a[2]=t2,a[3]=((C_word*)t0)[16],a[4]=((C_word*)t0)[13],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:364: test */
t4=((C_word*)((C_word*)t0)[16])[1];
f_5056(t4,t3,((C_word*)t0)[13],lf[131]);}

/* k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6036(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,3)))){
C_save_and_reclaim((void *)f_6036,c,av);}
a=C_alloc(30);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|23,a[1]=(C_word)f_6043,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t2,a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[2],a[16]=((C_word*)t0)[14],a[17]=((C_word*)t0)[15],a[18]=((C_word*)t0)[16],a[19]=((C_word*)t0)[17],a[20]=((C_word*)t0)[18],a[21]=((C_word*)t0)[19],a[22]=((C_word*)t0)[20],a[23]=((C_word*)t0)[21],tmp=(C_word)a,a+=24,tmp);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6850,a[2]=t3,a[3]=((C_word*)t0)[17],a[4]=t1,a[5]=((C_word*)t0)[14],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:368: test */
t5=((C_word*)((C_word*)t0)[17])[1];
f_5056(t5,t4,((C_word*)t0)[14],lf[91]);}

/* k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_6043(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,0,3)))){
C_save_and_reclaim_args((void *)trf_6043,2,t0,t1);}
a=C_alloc(24);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_6046,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],tmp=(C_word)a,a+=17,tmp);
/* optimizer.scm:373: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|23,a[1]=(C_word)f_6122,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[12],a[9]=((C_word*)t0)[13],a[10]=((C_word*)t0)[14],a[11]=((C_word*)t0)[15],a[12]=((C_word*)t0)[7],a[13]=((C_word*)t0)[2],a[14]=((C_word*)t0)[5],a[15]=((C_word*)t0)[9],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],tmp=(C_word)a,a+=24,tmp);
/* optimizer.scm:392: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[86]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[16];
av2[3]=lf[132];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6046(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_6046,c,av);}
a=C_alloc(17);
t2=C_i_caddr(t1);
t3=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_6055,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t2,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],tmp=(C_word)a,a+=17,tmp);
/* optimizer.scm:375: chicken.compiler.support#check-signature */
t4=*((C_word*)lf[108]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[16];
av2[3]=((C_word*)t0)[8];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_6055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_6055,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_6058,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:376: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[105];
av2[4]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_6113,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[14],a[6]=((C_word*)t0)[15],a[7]=((C_word*)t0)[16],a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:387: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[106];
av2[3]=lf[107];
av2[4]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k6056 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_6058(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_6058,c,av);}
a=C_alloc(19);
t2=(
/* optimizer.scm:377: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6062,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t4=C_i_check_list_2(((C_word*)t0)[4],lf[23]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_6072,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6089,a[2]=t7,a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_6089(t9,t5,((C_word*)t0)[4]);}

/* g968 in k6056 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_fcall f_6062(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_6062,3,t0,t1,t2);}
t3=*((C_word*)lf[79]+1);
/* optimizer.scm:378: g983 */
t4=*((C_word*)lf[79]+1);{
C_word av2[6];
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[102];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k6070 in k6056 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_6072(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_6072,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6079,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6087,a[2]=t2,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:382: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k6077 in k6070 in k6056 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6079,c,av);}
/* optimizer.scm:380: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_5413(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k6085 in k6070 in k6056 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6087(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_6087,c,av);}
/* optimizer.scm:381: chicken.compiler.support#inline-lambda-bindings */
t2=*((C_word*)lf[103]+1);{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=C_i_car(t1);
av2[5]=C_SCHEME_FALSE;
av2[6]=((C_word*)t0)[5];
av2[7]=*((C_word*)lf[104]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(8,av2);}}

/* for-each-loop967 in k6056 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_fcall f_6089(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_6089,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6099,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:378: g968 */
t4=((C_word*)t0)[3];
f_6062(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k6097 in for-each-loop967 in k6056 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6099,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_6089(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k6111 in k6053 in k6044 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_6113(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_6113,c,av);}
/* optimizer.scm:391: walk-generic */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7240(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_TRUE);}

/* k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6122(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,2)))){
C_save_and_reclaim((void *)f_6122,c,av);}
a=C_alloc(30);
t2=(*a=C_CLOSURE_TYPE|23,a[1]=(C_word)f_6125,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],tmp=(C_word)a,a+=24,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6843,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[19],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:393: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;
f_6125(t3,C_SCHEME_FALSE);}}

/* k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_fcall f_6125(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,0,4)))){
C_save_and_reclaim_args((void *)trf_6125,2,t0,t1);}
a=C_alloc(27);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6128,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:405: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[109];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|23,a[1]=(C_word)f_6153,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[4],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=((C_word*)t0)[2],a[14]=((C_word*)t0)[15],a[15]=((C_word*)t0)[16],a[16]=((C_word*)t0)[17],a[17]=((C_word*)t0)[18],a[18]=((C_word*)t0)[19],a[19]=((C_word*)t0)[20],a[20]=((C_word*)t0)[21],a[21]=((C_word*)t0)[22],a[22]=((C_word*)t0)[23],a[23]=((C_word*)t0)[3],tmp=(C_word)a,a+=24,tmp);
if(C_truep(((C_word*)t0)[15])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6736,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:414: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[15];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;
f_6153(t3,C_SCHEME_FALSE);}}}

/* k6126 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_6128(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_6128,c,av);}
a=C_alloc(8);
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=C_i_car(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6147,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:412: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k6145 in k6126 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_6147(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_6147,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:409: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_fcall f_6153(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,0,2)))){
C_save_and_reclaim_args((void *)trf_6153,2,t0,t1);}
a=C_alloc(24);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|23,a[1]=(C_word)f_6156,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],tmp=(C_word)a,a+=24,tmp);
/* optimizer.scm:416: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[14];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_6681,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[23],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[14],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[4],a[11]=((C_word*)t0)[5],a[12]=((C_word*)t0)[6],tmp=(C_word)a,a+=13,tmp);
if(C_truep(((C_word*)t0)[14])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6729,a[2]=t2,a[3]=((C_word*)t0)[14],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:522: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[14];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_6681(2,av2);}}}}

/* k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_6156(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,5)))){
C_save_and_reclaim((void *)f_6156,c,av);}
a=C_alloc(25);
t2=C_i_caddr(t1);
t3=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_6164,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=t2,a[15]=((C_word*)t0)[13],a[16]=((C_word*)t0)[14],a[17]=((C_word*)t0)[15],a[18]=((C_word*)t0)[16],a[19]=((C_word*)t0)[17],a[20]=((C_word*)t0)[18],a[21]=((C_word*)t0)[19],a[22]=((C_word*)t0)[20],a[23]=((C_word*)t0)[21],a[24]=((C_word*)t0)[22],tmp=(C_word)a,a+=25,tmp);
/* optimizer.scm:418: ##sys#decompose-lambda-list */
t4=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[23];
av2[2]=t2;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6164(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,3)))){
C_save_and_reclaim((void *)f_6164,c,av);}
a=C_alloc(32);
t5=C_i_car(((C_word*)t0)[2]);
t6=(*a=C_CLOSURE_TYPE|28,a[1]=(C_word)f_6171,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=t5,a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=t1,a[18]=((C_word*)t0)[2],a[19]=((C_word*)t0)[17],a[20]=t3,a[21]=((C_word*)t0)[18],a[22]=((C_word*)t0)[19],a[23]=((C_word*)t0)[20],a[24]=t2,a[25]=((C_word*)t0)[21],a[26]=((C_word*)t0)[22],a[27]=((C_word*)t0)[23],a[28]=((C_word*)t0)[24],tmp=(C_word)a,a+=29,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6675,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:422: chicken.compiler.support#variable-mark */
t8=*((C_word*)lf[86]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[17];
av2[3]=lf[127];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}

/* k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_6171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,3)))){
C_save_and_reclaim((void *)f_6171,c,av);}
a=C_alloc(39);
t2=(*a=C_CLOSURE_TYPE|26,a[1]=(C_word)f_6177,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=t1,a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],a[26]=((C_word*)t0)[25],tmp=(C_word)a,a+=27,tmp);
if(C_truep(((C_word*)t0)[26])){
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_6612,a[2]=t1,a[3]=((C_word*)t0)[18],a[4]=((C_word*)t0)[27],a[5]=t2,a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[28],a[10]=((C_word*)t0)[19],a[11]=((C_word*)t0)[23],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:424: test */
t4=((C_word*)((C_word*)t0)[23])[1];
f_5056(t4,t3,((C_word*)t0)[19],lf[125]);}
else{
t3=t2;
f_6177(t3,C_SCHEME_FALSE);}}

/* k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_fcall f_6177(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,0,4)))){
C_save_and_reclaim_args((void *)trf_6177,2,t0,t1);}
a=C_alloc(23);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_6183,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],tmp=(C_word)a,a+=20,tmp);
/* optimizer.scm:436: chicken.compiler.support#check-signature */
t3=*((C_word*)lf[108]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[20];
av2[3]=((C_word*)t0)[15];
av2[4]=((C_word*)t0)[14];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|22,a[1]=(C_word)f_6287,a[2]=((C_word*)t0)[15],a[3]=((C_word*)t0)[21],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[17],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[22],a[15]=((C_word*)t0)[23],a[16]=((C_word*)t0)[2],a[17]=((C_word*)t0)[10],a[18]=((C_word*)t0)[24],a[19]=((C_word*)t0)[25],a[20]=((C_word*)t0)[26],a[21]=((C_word*)t0)[14],a[22]=((C_word*)t0)[11],tmp=(C_word)a,a+=23,tmp);
/* optimizer.scm:466: test */
t3=((C_word*)((C_word*)t0)[24])[1];
f_5056(t3,t2,((C_word*)t0)[11],lf[100]);}}

/* k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_6183(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,6)))){
C_save_and_reclaim((void *)f_6183,c,av);}
a=C_alloc(18);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_6186,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],tmp=(C_word)a,a+=18,tmp);
t3=(C_truep(((C_word*)t0)[18])?lf[113]:lf[114]);
/* optimizer.scm:437: chicken.compiler.support#debugging */
t4=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[106];
av2[3]=t3;
av2[4]=((C_word*)t0)[10];
av2[5]=((C_word*)t0)[11];
av2[6]=C_i_cadddr(((C_word*)t0)[19]);
((C_proc)(void*)(*((C_word*)t4+1)))(7,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_6278,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[17],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:461: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[106];
av2[3]=lf[115];
av2[4]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_6186(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,3)))){
C_save_and_reclaim((void *)f_6186,c,av);}
a=C_alloc(27);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6187,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_i_check_list_2(((C_word*)t0)[3],lf[23]);
t4=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_6197,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[15],a[15]=((C_word*)t0)[2],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],tmp=(C_word)a,a+=18,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6246,a[2]=t6,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_6246(t8,t4,((C_word*)t0)[3]);}

/* g1061 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_fcall f_6187(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_6187,3,t0,t1,t2);}
t3=*((C_word*)lf[79]+1);
/* optimizer.scm:442: g1076 */
t4=*((C_word*)lf[79]+1);{
C_word av2[6];
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[102];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_ccall f_6197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,4)))){
C_save_and_reclaim((void *)f_6197,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_6200,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],tmp=(C_word)a,a+=18,tmp);
/* optimizer.scm:444: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[112];
av2[4]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k6198 in k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_ccall f_6200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_6200,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_6205,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],tmp=(C_word)a,a+=17,tmp);
/* optimizer.scm:445: chicken.base#call/cc */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[17];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* a6204 in k6198 in k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in ... */
static void C_ccall f_6205(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_6205,c,av);}
a=C_alloc(26);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_6208,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6222,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[12],a[6]=t1,a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6244,a[2]=t4,a[3]=((C_word*)t0)[13],a[4]=((C_word*)t0)[14],a[5]=((C_word*)t0)[15],a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:454: chicken.compiler.support#node-subexpressions */
t6=*((C_word*)lf[42]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[16];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* cfk in a6204 in k6198 in k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_ccall f_6208(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_6208,c,av);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_6212,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:448: chicken.compiler.support#debugging */
t4=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[106];
av2[3]=lf[110];
av2[4]=((C_word*)t0)[10];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k6210 in cfk in a6204 in k6198 in k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in ... */
static void C_ccall f_6212(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,8)))){
C_save_and_reclaim((void *)f_6212,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6219,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:452: walk-generic */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7240(t3,t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_TRUE);}

/* k6217 in k6210 in cfk in a6204 in k6198 in k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in ... */
static void C_ccall f_6219(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6219,c,av);}
/* optimizer.scm:452: return */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k6220 in a6204 in k6198 in k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_ccall f_6222(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_6222,c,av);}
a=C_alloc(6);
t2=C_i_car(((C_word*)t0)[2]);
t3=lf[53];
t4=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
t5=C_a_i_cons(&a,2,t4,lf[53]);
t6=C_mutate(&lf[53] /* (set! chicken.compiler.optimizer#inline-history ...) */,t5);
t7=(
/* optimizer.scm:458: touch */
  f_5082(((C_word*)((C_word*)t0)[4])[1])
);
/* optimizer.scm:459: walk */
t8=((C_word*)((C_word*)t0)[5])[1];
f_5413(t8,((C_word*)t0)[6],t1,((C_word*)t0)[2],((C_word*)t0)[7]);}

/* k6242 in a6204 in k6198 in k6195 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_ccall f_6244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_6244,c,av);}
/* optimizer.scm:453: chicken.compiler.support#inline-lambda-bindings */
t2=*((C_word*)lf[103]+1);{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=C_i_car(t1);
av2[5]=C_SCHEME_TRUE;
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t2+1)))(8,av2);}}

/* for-each-loop1060 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_fcall f_6246(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_6246,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6256,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:442: g1061 */
t4=((C_word*)t0)[3];
f_6187(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k6254 in for-each-loop1060 in k6184 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_ccall f_6256(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6256,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_6246(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k6276 in k6181 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_6278(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_6278,c,av);}
/* optimizer.scm:465: walk-generic */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7240(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_TRUE);}

/* k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_6287(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,8)))){
C_save_and_reclaim((void *)f_6287,c,av);}
a=C_alloc(17);
if(C_truep(t1)){
t2=C_i_length(((C_word*)t0)[2]);
if(C_truep(C_i_lessp(t2,((C_word*)t0)[3]))){
/* optimizer.scm:468: walk-generic */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7240(t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],C_SCHEME_TRUE);}
else{
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_6301,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[13],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[14],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[15],a[9]=t4,a[10]=((C_word*)t0)[16],a[11]=((C_word*)t0)[17],a[12]=((C_word*)t0)[18],tmp=(C_word)a,a+=13,tmp));
t6=((C_word*)t4)[1];
f_6301(t6,((C_word*)t0)[5],((C_word*)t0)[19],((C_word*)t0)[3],((C_word*)t0)[2],C_SCHEME_END_OF_LIST);}}
else{
t2=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_6599,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[20],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[15],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[17],a[16]=((C_word*)t0)[21],tmp=(C_word)a,a+=17,tmp);
/* optimizer.scm:495: test */
t3=((C_word*)((C_word*)t0)[18])[1];
f_5056(t3,t2,((C_word*)t0)[22],lf[96]);}}

/* loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_fcall f_6301(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,0,3)))){
C_save_and_reclaim_args((void *)trf_6301,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(24);
t6=C_i_nullp(t2);
t7=(C_truep(t6)?t6:C_i_zerop(t3));
if(C_truep(t7)){
t8=(
/* optimizer.scm:471: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t9=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t10=t9;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=((C_word*)t11)[1];
t13=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6318,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
t14=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_6372,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[5],a[7]=t11,a[8]=t13,a[9]=t12,tmp=(C_word)a,a+=10,tmp);
t15=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6376,a[2]=t14,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:476: scheme#reverse */
t16=*((C_word*)lf[4]+1);{
C_word av2[3];
av2[0]=t16;
av2[1]=t15;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t16+1)))(3,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_6382,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[9],a[7]=t4,a[8]=t5,a[9]=((C_word*)t0)[3],a[10]=((C_word*)t0)[4],a[11]=((C_word*)t0)[5],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],tmp=(C_word)a,a+=14,tmp);
/* optimizer.scm:479: test */
t9=((C_word*)((C_word*)t0)[12])[1];
f_5056(t9,t8,C_i_car(t2),lf[93]);}}

/* g1116 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_fcall f_6318(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_6318,3,t0,t1,t2);}
/* optimizer.scm:473: g1133 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_5413(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k6326 in k6370 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_ccall f_6328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_6328,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6331,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:477: invalidate-gae! */
f_5086(t2,((C_word*)t0)[5]);}

/* k6329 in k6326 in k6370 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in ... */
static void C_ccall f_6331(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6331,c,av);}
/* optimizer.scm:478: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop1110 in k6370 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_fcall f_6336(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_6336,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6361,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:473: g1116 */
t4=((C_word*)t0)[4];
f_6318(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k6359 in map-loop1110 in k6370 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in ... */
static void C_ccall f_6361(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6361,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_6336(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k6370 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_ccall f_6372(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_6372,c,av);}
a=C_alloc(17);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6328,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6336,a[2]=((C_word*)t0)[7],a[3]=t5,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_6336(t7,t3,t2);}

/* k6374 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_ccall f_6376(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6376,c,av);}
/* optimizer.scm:476: scheme#append */
t2=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k6380 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_ccall f_6382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,5)))){
C_save_and_reclaim((void *)f_6382,c,av);}
a=C_alloc(32);
if(C_truep(t1)){
t2=(
/* optimizer.scm:480: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_6388,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:481: chicken.compiler.support#debugging */
t4=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[36];
av2[3]=lf[119];
av2[4]=C_u_i_car(((C_word*)t0)[4]);
av2[5]=((C_word*)t0)[13];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
t2=C_u_i_cdr(((C_word*)t0)[4]);
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[5],C_fix(1));
t4=C_i_cdr(((C_word*)t0)[7]);
t5=C_u_i_car(((C_word*)t0)[7]);
t6=C_a_i_cons(&a,2,t5,((C_word*)t0)[8]);
/* optimizer.scm:491: loop */
t7=((C_word*)((C_word*)t0)[6])[1];
f_6301(t7,((C_word*)t0)[3],t2,t3,t4,t6);}}

/* k6386 in k6380 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_ccall f_6388(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_6388,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_6394,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:484: chicken.compiler.support#expression-has-side-effects? */
t3=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[6]);
av2[3]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k6392 in k6386 in k6380 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in ... */
static void C_ccall f_6394(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,5)))){
C_save_and_reclaim((void *)f_6394,c,av);}
a=C_alloc(29);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_6425,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:487: chicken.base#gensym */
t3=*((C_word*)lf[116]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[117];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_u_i_cdr(((C_word*)t0)[3]);
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[4],C_fix(1));
/* optimizer.scm:490: loop */
t4=((C_word*)((C_word*)t0)[5])[1];
f_6301(t4,((C_word*)t0)[2],t2,t3,C_u_i_cdr(((C_word*)t0)[6]),((C_word*)t0)[7]);}}

/* k6407 in k6423 in k6392 in k6386 in k6380 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in ... */
static void C_ccall f_6409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(34,c,5)))){
C_save_and_reclaim((void *)f_6409,c,av);}
a=C_alloc(34);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6413,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_u_i_cdr(((C_word*)t0)[4]);
t4=C_s_a_i_minus(&a,2,((C_word*)t0)[5],C_fix(1));
/* optimizer.scm:489: loop */
t5=((C_word*)((C_word*)t0)[6])[1];
f_6301(t5,t2,t3,t4,C_u_i_cdr(((C_word*)t0)[7]),((C_word*)t0)[8]);}

/* k6411 in k6407 in k6423 in k6392 in k6386 in k6380 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in ... */
static void C_ccall f_6413(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_6413,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:485: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k6423 in k6392 in k6386 in k6380 in loop in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_ccall f_6425(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_6425,c,av);}
a=C_alloc(12);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_6409,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:488: walk */
t4=((C_word*)((C_word*)t0)[8])[1];
f_5413(t4,t3,C_u_i_car(((C_word*)t0)[6]),((C_word*)t0)[9],((C_word*)t0)[10]);}

/* k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_ccall f_6475(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,8)))){
C_save_and_reclaim((void *)f_6475,c,av);}
a=C_alloc(12);
t2=C_i_length(((C_word*)t0)[2]);
if(C_truep(C_i_lessp(t2,t1))){
/* optimizer.scm:499: walk-generic */
t3=((C_word*)((C_word*)t0)[3])[1];
f_7240(t3,((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_TRUE);}
else{
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_6487,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[13],a[10]=((C_word*)t0)[6],a[11]=((C_word*)t0)[4],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:501: chicken.compiler.support#debugging */
t4=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[36];
av2[3]=lf[122];
av2[4]=((C_word*)t0)[14];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}}

/* k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_ccall f_6487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_6487,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6492,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_6498,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:502: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[11];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a6491 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in ... */
static void C_ccall f_6492(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6492,c,av);}
/* optimizer.scm:502: split-at */
f_3563(t1,((C_word*)t0)[2],((C_word*)t0)[3]);}

/* a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in ... */
static void C_ccall f_6498(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,4)))){
C_save_and_reclaim((void *)f_6498,c,av);}
a=C_alloc(39);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6502,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6514,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t10=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_6562,a[2]=((C_word*)t0)[7],a[3]=t4,a[4]=((C_word*)t0)[8],a[5]=t7,a[6]=t9,a[7]=t8,tmp=(C_word)a,a+=8,tmp);
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6570,a[2]=t10,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_nullp(t3))){
/* optimizer.scm:512: chicken.compiler.support#qnode */
t12=*((C_word*)lf[77]+1);{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}
else{
t12=C_i_length(t3);
t13=C_a_i_fixnum_times(&a,2,C_fix(3),t12);
t14=C_a_i_list2(&a,2,lf[120],t13);
/* optimizer.scm:513: chicken.compiler.support#make-node */
t15=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t15;
av2[1]=t11;
av2[2]=lf[121];
av2[3]=t14;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t15+1)))(5,av2);}}}

/* k6500 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_ccall f_6502(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_6502,c,av);}
a=C_alloc(7);
t2=C_a_i_cons(&a,2,t1,((C_word*)((C_word*)t0)[2])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6509,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:518: invalidate-gae! */
f_5086(t4,((C_word*)t0)[5]);}

/* k6507 in k6500 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in ... */
static void C_ccall f_6509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6509,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* g1166 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_fcall f_6514(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_6514,3,t0,t1,t2);}
/* optimizer.scm:506: g1183 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_5413(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k6522 in k6560 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in ... */
static void C_ccall f_6524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6524,c,av);}
/* optimizer.scm:503: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop1160 in k6560 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in ... */
static void C_fcall f_6526(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_6526,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6551,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:506: g1166 */
t4=((C_word*)t0)[4];
f_6514(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k6549 in map-loop1160 in k6560 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in ... */
static void C_ccall f_6551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6551,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_6526(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k6560 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_ccall f_6562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_6562,c,av);}
a=C_alloc(15);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6524,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6526,a[2]=((C_word*)t0)[5],a[3]=t5,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_6526(t7,t3,t2);}

/* k6568 in a6497 in k6485 in k6473 in k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in ... */
static void C_ccall f_6570(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6570,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:508: scheme#append */
t3=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k6597 in k6285 in k6175 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_6599(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,8)))){
C_save_and_reclaim((void *)f_6599,c,av);}
a=C_alloc(15);
t2=(C_truep(t1)?C_i_not(C_i_memq(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1])):C_SCHEME_FALSE);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_6475,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[15],tmp=(C_word)a,a+=15,tmp);
/* optimizer.scm:497: chicken.compiler.support#llist-length */
t4=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[16];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* optimizer.scm:520: walk-generic */
t3=((C_word*)((C_word*)t0)[5])[1];
f_7240(t3,((C_word*)t0)[6],((C_word*)t0)[2],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],C_SCHEME_TRUE);}}

/* k6610 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_6612(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_6612,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_6671,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:425: test */
t3=((C_word*)((C_word*)t0)[11])[1];
f_5056(t3,t2,((C_word*)t0)[7],lf[102]);}
else{
t2=((C_word*)t0)[5];
f_6177(t2,C_SCHEME_FALSE);}}

/* k6628 in k6665 in k6669 in k6610 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in ... */
static void C_ccall f_6630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_6630,c,av);}
a=C_alloc(16);
t2=C_eqp(t1,lf[85]);
t3=(C_truep(t2)?C_SCHEME_FALSE:(C_truep(((C_word*)t0)[2])?((C_word*)t0)[2]:C_i_lessp(C_i_cadddr(((C_word*)t0)[3]),((C_word*)t0)[4])));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6636,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],tmp=(C_word)a,a+=6,tmp);
t5=C_i_car(((C_word*)t0)[8]);
t6=C_a_i_cons(&a,2,((C_word*)t0)[7],t5);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7429,a[2]=t6,a[3]=((C_word*)t0)[9],a[4]=t8,tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_7429(t10,t4,lf[53],C_fix(0));}
else{
t4=((C_word*)t0)[5];
f_6177(t4,C_SCHEME_FALSE);}}

/* k6634 in k6628 in k6665 in k6669 in k6610 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_ccall f_6636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_6636,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=((C_word*)t0)[2];
f_6177(t2,t1);}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6642,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:433: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[106];
av2[3]=lf[124];
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=C_u_i_car(((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t3+1)))(7,av2);}}}

/* k6640 in k6634 in k6628 in k6665 in k6669 in k6610 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in ... */
static void C_ccall f_6642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6642,c,av);}
t2=((C_word*)t0)[2];
f_6177(t2,C_SCHEME_FALSE);}

/* k6665 in k6669 in k6610 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_6667(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_6667,c,av);}
a=C_alloc(10);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_6630,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:427: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[86]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
av2[3]=lf[87];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[5];
f_6177(t2,C_SCHEME_FALSE);}}

/* k6669 in k6610 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_6671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_6671,c,av);}
a=C_alloc(11);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_6667,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* optimizer.scm:426: test */
t3=((C_word*)((C_word*)t0)[11])[1];
f_5056(t3,t2,((C_word*)t0)[7],lf[96]);}
else{
t2=((C_word*)t0)[5];
f_6177(t2,C_SCHEME_FALSE);}}

/* k6673 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_6675(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6675,c,av);}
/* optimizer.scm:422: chicken.compiler.support#node? */
t2=*((C_word*)lf[126]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k6679 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_6681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,8)))){
C_save_and_reclaim((void *)f_6681,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_6684,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6705,a[2]=t2,a[3]=((C_word*)t0)[9],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:526: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* optimizer.scm:533: walk-generic */
t2=((C_word*)((C_word*)t0)[10])[1];
f_7240(t2,((C_word*)t0)[3],((C_word*)t0)[11],((C_word*)t0)[12],((C_word*)t0)[8],((C_word*)t0)[6],((C_word*)t0)[4],((C_word*)t0)[5],C_SCHEME_TRUE);}}

/* k6682 in k6679 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_6684,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6691,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_u_i_cdr(((C_word*)t0)[6]);
t4=C_a_i_cons(&a,2,((C_word*)t0)[7],t3);
/* optimizer.scm:528: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[30];
av2[3]=((C_word*)t0)[8];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k6689 in k6682 in k6679 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_6691(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6691,c,av);}
/* optimizer.scm:527: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_5413(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k6703 in k6679 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_6705,c,av);}
/* optimizer.scm:525: chicken.compiler.support#debugging */
t2=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[106];
av2[3]=lf[128];
av2[4]=((C_word*)t0)[3];
av2[5]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k6723 in k6727 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6725(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6725,c,av);}
/* optimizer.scm:523: chicken.compiler.support#intrinsic? */
t2=*((C_word*)lf[129]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k6727 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_6729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6729,c,av);}
a=C_alloc(3);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6725,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:523: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_6681(2,av2);}}}

/* k6734 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_6736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6736,c,av);}
t2=((C_word*)t0)[2];
f_6153(t2,C_eqp(lf[29],t1));}

/* k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_6751(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_6751,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6823,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:397: chicken.compiler.support#node-class */
t3=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];
f_6125(t2,C_SCHEME_FALSE);}}

/* k6767 in k6817 in k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_6769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_6769,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6772,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t1)){
t3=t2;
f_6772(t3,t1);}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6809,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:400: test */
t4=((C_word*)((C_word*)t0)[5])[1];
f_5056(t4,t3,C_u_i_car(((C_word*)t0)[6]),lf[130]);}}

/* k6770 in k6767 in k6817 in k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in ... */
static void C_fcall f_6772(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_6772,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6782,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6784,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:403: any */
f_3806(t2,t3,C_u_i_cdr(((C_word*)t0)[4]));}
else{
t2=((C_word*)t0)[2];
f_6125(t2,C_SCHEME_FALSE);}}

/* k6780 in k6770 in k6767 in k6817 in k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_6782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6782,c,av);}
t2=((C_word*)t0)[2];
f_6125(t2,C_i_not(t1));}

/* a6783 in k6770 in k6767 in k6817 in k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_6784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6784,c,av);}
t3=*((C_word*)lf[118]+1);
/* optimizer.scm:403: g1020 */
t4=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k6801 in k6807 in k6767 in k6817 in k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_6803(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6803,c,av);}
t2=((C_word*)t0)[2];
f_6772(t2,C_i_not(t1));}

/* k6807 in k6767 in k6817 in k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_6809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_6809,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6803,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:401: test */
t3=((C_word*)((C_word*)t0)[3])[1];
f_5056(t3,t2,C_u_i_car(((C_word*)t0)[4]),lf[62]);}
else{
t2=((C_word*)t0)[2];
f_6772(t2,C_SCHEME_FALSE);}}

/* k6817 in k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_6819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_6819,c,av);}
a=C_alloc(7);
t2=C_i_caddr(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_6769,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:399: test */
t4=((C_word*)((C_word*)t0)[5])[1];
f_5056(t4,t3,C_i_car(t2),lf[93]);}
else{
t3=((C_word*)t0)[2];
f_6125(t3,C_SCHEME_FALSE);}}

/* k6821 in k6749 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_6823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_6823,c,av);}
a=C_alloc(6);
t2=C_eqp(lf[29],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6819,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:398: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_6125(t3,C_SCHEME_FALSE);}}

/* k6831 in k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_6833(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6833,c,av);}
if(C_truep(C_i_not(t1))){
/* optimizer.scm:396: test */
t2=((C_word*)((C_word*)t0)[2])[1];
f_5056(t2,((C_word*)t0)[3],((C_word*)t0)[4],lf[81]);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_6751(2,av2);}}}

/* k6835 in k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_6837(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_6837,c,av);}
a=C_alloc(11);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6751,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6833,a[2]=((C_word*)t0)[5],a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:395: test */
t5=((C_word*)((C_word*)t0)[5])[1];
f_5056(t5,t4,t2,lf[131]);}
else{
t3=((C_word*)t0)[2];
f_6125(t3,C_SCHEME_FALSE);}}

/* k6841 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_6843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_6843,c,av);}
a=C_alloc(6);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6837,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:394: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_u_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_6125(t3,C_SCHEME_FALSE);}}

/* k6848 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_6850,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6875,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:369: test */
t3=((C_word*)((C_word*)t0)[3])[1];
f_5056(t3,t2,((C_word*)t0)[5],lf[90]);}
else{
t2=((C_word*)t0)[2];
f_6043(t2,C_SCHEME_FALSE);}}

/* k6861 in k6873 in k6848 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_6863(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6863,c,av);}
t2=((C_word*)t0)[2];
f_6043(t2,C_i_not(t1));}

/* k6869 in k6873 in k6848 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_6871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6871,c,av);}
/* optimizer.scm:371: test */
t2=((C_word*)((C_word*)t0)[2])[1];
f_5056(t2,((C_word*)t0)[3],C_i_car(t1),lf[102]);}

/* k6873 in k6848 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6875(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_6875,c,av);}
a=C_alloc(7);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6863,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6871,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:371: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];
f_6043(t2,C_SCHEME_FALSE);}}

/* k6879 in k6889 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6881(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6881,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
f_6036(2,av2);}}
else{
/* optimizer.scm:366: test */
t2=((C_word*)((C_word*)t0)[3])[1];
f_5056(t2,((C_word*)t0)[2],((C_word*)t0)[4],lf[133]);}}

/* k6889 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6891(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_6891,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6881,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:365: test */
t3=((C_word*)((C_word*)t0)[3])[1];
f_5056(t3,t2,((C_word*)t0)[4],lf[81]);}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_6036(2,av2);}}}

/* k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_6895,c,av);}
a=C_alloc(21);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_6033,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=t2,a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],tmp=(C_word)a,a+=21,tmp);
/* optimizer.scm:363: chicken.compiler.support#call-info */
t4=*((C_word*)lf[61]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[12];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k6911 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_6913,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6916,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:539: invalidate-gae! */
f_5086(t2,((C_word*)t0)[4]);}

/* k6914 in k6911 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6916(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_6916,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* g1207 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_6925(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_6925,3,t0,t1,t2);}
/* optimizer.scm:538: g1224 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_5413(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k6930 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6932,c,av);}
/* optimizer.scm:537: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop1201 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_6934(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_6934,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6959,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:538: g1207 */
t4=((C_word*)t0)[4];
f_6925(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k6957 in map-loop1201 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6959(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6959,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_6934(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6992(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_6992,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=(
/* optimizer.scm:546: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6998,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7004,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:547: test */
t5=((C_word*)((C_word*)t0)[5])[1];
f_5056(t5,t4,((C_word*)t0)[4],lf[89]);}
else{
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_7013,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* optimizer.scm:550: test */
t3=((C_word*)((C_word*)t0)[5])[1];
f_5056(t3,t2,((C_word*)t0)[4],lf[80]);}}

/* k6996 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_6998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_6998,c,av);}
/* optimizer.scm:549: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k7002 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7004(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_7004,c,av);}
if(C_truep(t1)){
/* optimizer.scm:548: chicken.compiler.support#debugging */
t2=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[106];
av2[3]=lf[134];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
/* optimizer.scm:549: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,4)))){
C_save_and_reclaim((void *)f_7013,c,av);}
a=C_alloc(19);
if(C_truep(t1)){
t2=(
/* optimizer.scm:551: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
/* optimizer.scm:552: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_7025,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7166,a[2]=t2,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[12],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:553: test */
t4=((C_word*)((C_word*)t0)[6])[1];
f_5056(t4,t3,((C_word*)t0)[4],lf[89]);}}

/* k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7025(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_7025,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(
/* optimizer.scm:558: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7031,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:559: chicken.compiler.support#debugging */
t4=*((C_word*)lf[35]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[36];
av2[3]=lf[135];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7037,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7114,a[2]=t2,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:562: walk */
t4=((C_word*)((C_word*)t0)[8])[1];
f_5413(t4,t3,C_i_car(((C_word*)t0)[9]),((C_word*)t0)[10],((C_word*)t0)[5]);}}

/* k7029 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_7031,c,av);}
/* optimizer.scm:560: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k7035 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7037,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7072,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:564: test */
t3=((C_word*)((C_word*)t0)[5])[1];
f_5056(t3,t2,((C_word*)t0)[2],lf[89]);}

/* k7044 in k7070 in k7035 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7046(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7046,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* for-each-loop1253 in k7070 in k7035 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7048(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7048,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7058,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:563: g1254 */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7056 in for-each-loop1253 in k7070 in k7035 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_7058(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7058,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7048(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k7070 in k7035 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7072(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_7072,c,av);}
a=C_alloc(13);
t2=(C_truep(t1)?(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7073,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp):(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7090,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp));
t3=C_i_check_list_2(((C_word*)t0)[3],lf[23]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7046,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7048,a[2]=t6,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_7048(t8,t4,((C_word*)t0)[3]);}

/* f_7073 in k7070 in k7035 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7073,c,av);}
t3=C_i_cdr(t2);
t4=C_eqp(((C_word*)t0)[2],t3);
if(C_truep(t4)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_set_i_slot(t2,C_fix(1),C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* f_7090 in k7070 in k7035 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7090(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7090,c,av);}
t3=C_i_car(t2);
t4=C_eqp(((C_word*)t0)[2],t3);
if(C_truep(t4)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_set_i_slot(t2,C_fix(1),C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k7112 in k7023 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7114(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_7114,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:562: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[31];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k7122 in k7164 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7124(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_7124,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7155,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:555: test */
t3=((C_word*)((C_word*)t0)[5])[1];
f_5056(t3,t2,((C_word*)t0)[6],lf[136]);}
else{
t2=((C_word*)t0)[2];
f_7025(t2,C_SCHEME_FALSE);}}

/* k7141 in k7149 in k7153 in k7122 in k7164 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_7143(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7143,c,av);}
t2=((C_word*)t0)[2];
f_7025(t2,C_i_not(t1));}

/* k7149 in k7153 in k7122 in k7164 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7151(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_7151,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7143,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:557: chicken.compiler.support#expression-has-side-effects? */
t3=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[3]);
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_7025(t2,C_SCHEME_FALSE);}}

/* k7153 in k7122 in k7164 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_7155,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7151,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:556: test */
t3=((C_word*)((C_word*)t0)[5])[1];
f_5056(t3,t2,((C_word*)t0)[6],lf[130]);}
else{
t2=((C_word*)t0)[2];
f_7025(t2,C_SCHEME_FALSE);}}

/* k7160 in k7164 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7162(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7162,c,av);}
t2=((C_word*)t0)[2];
f_7124(t2,C_i_not(t1));}

/* k7164 in k7011 in k6990 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7166(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_7166,c,av);}
a=C_alloc(10);
t2=C_i_not(t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7124,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_7124(t4,t2);}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7162,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:554: chicken.compiler.support#variable-visible? */
t5=*((C_word*)lf[137]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k7173 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7175(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,8)))){
C_save_and_reclaim_args((void *)trf_7175,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_7184,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=t2,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* optimizer.scm:582: test */
t4=((C_word*)((C_word*)t0)[11])[1];
f_5056(t4,t3,t2,lf[64]);}
else{
/* optimizer.scm:590: walk-generic */
t2=((C_word*)((C_word*)t0)[6])[1];
f_7240(t2,((C_word*)t0)[4],((C_word*)t0)[7],((C_word*)t0)[5],((C_word*)t0)[2],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_FALSE);}}

/* k7182 in k7173 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7184(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,8)))){
C_save_and_reclaim((void *)f_7184,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(
/* optimizer.scm:583: touch */
  f_5082(((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7190,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:584: chicken.compiler.support#debugging */
t4=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[36];
av2[3]=lf[139];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
/* optimizer.scm:588: walk-generic */
t2=((C_word*)((C_word*)t0)[7])[1];
f_7240(t2,((C_word*)t0)[3],((C_word*)t0)[8],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],C_SCHEME_FALSE);}}

/* k7188 in k7182 in k7173 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7190(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7190,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7197,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:586: chicken.compiler.support#varnode */
t3=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k7195 in k7188 in k7182 in k7173 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_7197,c,av);}
/* optimizer.scm:586: chicken.compiler.support#replace-rest-op-with-list-ops */
t2=*((C_word*)lf[138]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* walk-generic in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7240(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8){
C_word tmp;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,5)))){
C_save_and_reclaim_args((void *)trf_7240,9,t0,t1,t2,t3,t4,t5,t6,t7,t8);}
a=C_alloc(13);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_7246,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t8,a[6]=((C_word*)t0)[2],a[7]=t7,a[8]=t10,a[9]=((C_word*)t0)[3],a[10]=t6,tmp=(C_word)a,a+=11,tmp));
t12=((C_word*)t10)[1];
f_7246(t12,t1,C_SCHEME_TRUE,t5,C_SCHEME_END_OF_LIST);}

/* lp in walk-generic in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7246(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_7246,5,t0,t1,t2,t3,t4);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t3))){
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7256,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=t4,tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)t0)[5])){
/* optimizer.scm:597: invalidate-gae! */
f_5086(t5,((C_word*)t0)[7]);}
else{
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_7256(2,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7272,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=((C_word*)t0)[8],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:601: walk */
t6=((C_word*)((C_word*)t0)[9])[1];
f_5413(t6,t5,C_i_car(t3),((C_word*)t0)[10],((C_word*)t0)[7]);}}

/* k7254 in lp in walk-generic in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7256(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7256,c,av);}
a=C_alloc(5);
if(C_truep(((C_word*)t0)[2])){
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7266,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:599: scheme#reverse */
t3=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k7264 in k7254 in lp in walk-generic in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7266(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_7266,c,av);}
/* optimizer.scm:599: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k7270 in lp in walk-generic in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7272(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_7272,c,av);}
a=C_alloc(3);
t2=(C_truep(((C_word*)t0)[2])?C_eqp(t1,C_u_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
t3=C_u_i_cdr(((C_word*)t0)[3]);
t4=C_a_i_cons(&a,2,t1,((C_word*)t0)[4]);
/* optimizer.scm:602: lp */
t5=((C_word*)((C_word*)t0)[5])[1];
f_7246(t5,((C_word*)t0)[6],t2,t3,t4);}

/* k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7300(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_7300,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
/* optimizer.scm:606: scheme#values */{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_SCHEME_TRUE;
C_values(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7306,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[3],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:608: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[48];
av2[3]=lf[150];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7306(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_7306,c,av);}
a=C_alloc(8);
t2=lf[51] /* chicken.compiler.optimizer#simplified-ops */ =C_SCHEME_END_OF_LIST;;
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7310,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:610: walk */
t4=((C_word*)((C_word*)t0)[8])[1];
f_5413(t4,t3,((C_word*)t0)[9],C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST);}

/* k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_7310,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7313,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[7])[1]))){
/* optimizer.scm:611: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[149];
av2[4]=((C_word*)((C_word*)t0)[7])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7313(2,av2);}}}

/* k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7313(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_7313,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7316,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_pairp(lf[51]))){
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7354,tmp=(C_word)a,a+=2,tmp);
/* optimizer.scm:613: chicken.compiler.support#with-debugging-output */
t4=*((C_word*)lf[148]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7316(2,av2);}}}

/* k7314 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7316(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_7316,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7319,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_greaterp(((C_word*)((C_word*)t0)[7])[1],C_fix(0)))){
/* optimizer.scm:624: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[142];
av2[4]=((C_word*)((C_word*)t0)[7])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7319(2,av2);}}}

/* k7317 in k7314 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_7319,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7322,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_greaterp(((C_word*)((C_word*)t0)[6])[1],C_fix(0)))){
/* optimizer.scm:625: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[141];
av2[4]=((C_word*)((C_word*)t0)[6])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_7322(2,av2);}}}

/* k7320 in k7317 in k7314 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_7322,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7325,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_greaterp(((C_word*)((C_word*)t0)[5])[1],C_fix(0)))){
/* optimizer.scm:626: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[140];
av2[4]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* optimizer.scm:627: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
C_values(4,av2);}}}

/* k7323 in k7320 in k7317 in k7314 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7325(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7325,c,av);}
/* optimizer.scm:627: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
C_values(4,av2);}}

/* a7353 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7354,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7358,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:616: chicken.base#print */
t3=*((C_word*)lf[143]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[147];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k7356 in a7353 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7358(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_7358,c,av);}
a=C_alloc(5);
t2=lf[51];
t3=C_i_check_list_2(lf[51],lf[23]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7391,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_7391(t7,((C_word*)t0)[2],lf[51]);}

/* k7361 in for-each-loop1309 in k7356 in a7353 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7363(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7363,c,av);}
if(C_truep(C_i_greaterp(C_u_i_cdr(((C_word*)t0)[2]),C_fix(1)))){
/* optimizer.scm:621: chicken.base#print */
t2=*((C_word*)lf[143]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_make_character(9);
av2[3]=C_u_i_cdr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
/* optimizer.scm:622: scheme#newline */
t2=*((C_word*)lf[144]+1);{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* for-each-loop1309 in k7356 in a7353 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7391(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_7391,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7401,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7363,a[2]=t4,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:619: chicken.base#print* */
t6=*((C_word*)lf[145]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[146];
av2[3]=C_i_car(t4);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7399 in for-each-loop1309 in k7356 in a7353 in k7311 in k7308 in k7304 in k7298 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7401,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7391(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* loop in k6628 in k6665 in k6669 in k6610 in k6169 in a6163 in k6154 in k6151 in k6123 in k6120 in k6041 in k6034 in k6031 in k6893 in k6019 in k5579 in k5576 in k5573 in walk1 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in ... */
static void C_fcall f_7429(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(29,0,3)))){
C_save_and_reclaim_args((void *)trf_7429,4,t0,t1,t2,t3);}
a=C_alloc(29);
t4=C_i_nullp(t2);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_car(t2);
if(C_truep(C_i_equalp(((C_word*)t0)[2],t5))){
if(C_truep(C_i_lessp(t3,((C_word*)t0)[3]))){
t6=C_u_i_cdr(t2);
t7=C_s_a_i_plus(&a,2,t3,C_fix(1));
/* optimizer.scm:643: loop */
t9=t1;
t10=t6;
t11=t7;
t1=t9;
t2=t10;
t3=t11;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
/* optimizer.scm:644: loop */
t9=t1;
t10=C_u_i_cdr(t2);
t11=t3;
t1=t9;
t2=t10;
t3=t11;
goto loop;}}}

/* touch in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_7469(C_word t0){
C_word tmp;
C_word t1;
C_word t2;
C_stack_overflow_check;{}
t1=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_TRUE);
return(C_SCHEME_TRUE);}

/* test in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7473(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_7473,4,t0,t1,t2,t3);}
/* optimizer.scm:658: chicken.compiler.support#db-get */
t4=*((C_word*)lf[55]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7480(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_7480,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7483,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7495,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:663: chicken.compiler.support#intrinsic? */
t4=*((C_word*)lf[129]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[156];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k7481 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_7483,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7486,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_greaterp(((C_word*)((C_word*)t0)[4])[1],C_fix(0)))){
/* optimizer.scm:701: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[151];
av2[4]=((C_word*)((C_word*)t0)[4])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=((C_word*)t0)[2];
f_7300(t3,((C_word*)((C_word*)t0)[3])[1]);}}

/* k7484 in k7481 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7486(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7486,c,av);}
t2=((C_word*)t0)[2];
f_7300(t2,((C_word*)((C_word*)t0)[3])[1]);}

/* k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7495(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_7495,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7496,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7693,a[2]=t2,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:699: test */
t4=((C_word*)((C_word*)t0)[5])[1];
f_7473(t4,t3,lf[156],lf[157]);}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_7483(2,av2);}}}

/* g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7496(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_7496,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_cdr(t2);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7503,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t3,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:667: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7503(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_7503,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7686,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:668: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(t1);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_7509,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7512,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:670: chicken.compiler.support#db-get-list */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[8];
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_7512,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7518,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)t0)[8])){
t3=C_i_length(t1);
t4=C_eqp(C_fix(1),t3);
if(C_truep(t4)){
t5=C_i_length(((C_word*)t0)[6]);
t6=C_eqp(C_fix(3),t5);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7662,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:674: chicken.compiler.support#node-class */
t8=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=t2;
f_7518(t7,C_SCHEME_FALSE);}}
else{
t5=t2;
f_7518(t5,C_SCHEME_FALSE);}}
else{
t3=t2;
f_7518(t3,C_SCHEME_FALSE);}}

/* k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7518(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_7518,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7643,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:675: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 in ... */
static void C_ccall f_7527(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_7527,c,av);}
a=C_alloc(10);
t2=C_i_listp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_i_nullp(C_i_cdr(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7539,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t1,a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t4,tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:681: chicken.compiler.support#db-get-list */
t6=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[9];
av2[3]=t4;
av2[4]=lf[130];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in ... */
static void C_ccall f_7539(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_7539,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7545,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t3=C_i_length(t1);
t4=C_eqp(C_fix(1),t3);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7620,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:683: chicken.compiler.support#node-class */
t6=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=t2;
f_7545(t5,C_SCHEME_FALSE);}}

/* k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_fcall f_7545(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_7545,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7610,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:685: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[42]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k7552 in k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_fcall f_7554(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(37,0,3)))){
C_save_and_reclaim_args((void *)trf_7554,2,t0,t1);}
a=C_alloc(37);
if(C_truep(t1)){
t2=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[2])[1],C_fix(1));
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7561,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:693: chicken.compiler.support#node-parameters-set! */
t5=*((C_word*)lf[153]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
av2[3]=lf[154];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k7559 in k7552 in k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_7561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7561,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7564,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:694: chicken.compiler.support#node-subexpressions-set! */
t3=*((C_word*)lf[152]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=C_i_cdr(((C_word*)t0)[7]);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k7562 in k7559 in k7552 in k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in ... */
static void C_ccall f_7564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_7564,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7567,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_i_car(((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7582,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:697: scheme#reverse */
t5=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_u_i_cdr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k7565 in k7562 in k7559 in k7552 in k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_7567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7567,c,av);}
/* optimizer.scm:698: touch */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(
/* optimizer.scm:698: touch */
  f_7469(((C_word*)((C_word*)t0)[3])[1])
);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k7580 in k7562 in k7559 in k7552 in k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in ... */
static void C_ccall f_7582(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_7582,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:695: chicken.compiler.support#node-subexpressions-set! */
t3=*((C_word*)lf[152]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k7600 in k7604 in k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in ... */
static void C_ccall f_7602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7602,c,av);}
t2=((C_word*)t0)[2];
f_7554(t2,C_eqp(((C_word*)t0)[3],C_i_car(t1)));}

/* k7604 in k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in ... */
static void C_ccall f_7606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_7606,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7602,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:688: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_7554(t3,C_SCHEME_FALSE);}}

/* k7608 in k7543 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in ... */
static void C_ccall f_7610(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_7610,c,av);}
a=C_alloc(14);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7554,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7606,a[2]=t3,a[3]=((C_word*)t0)[9],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:687: chicken.compiler.support#node-class */
t5=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k7618 in k7537 in k7525 in k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in ... */
static void C_ccall f_7620(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7620,c,av);}
t2=((C_word*)t0)[2];
f_7545(t2,C_eqp(lf[25],t1));}

/* k7637 in k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_7639,c,av);}
a=C_alloc(10);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_7527,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:677: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k7641 in k7516 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_7643,c,av);}
a=C_alloc(9);
t2=C_i_caddr(t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7639,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:676: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[42]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k7660 in k7510 in k7507 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7662(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7662,c,av);}
t2=((C_word*)t0)[2];
f_7518(t2,C_eqp(lf[29],t1));}

/* k7680 in k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7682,c,av);}
if(C_truep(C_i_not(t1))){
/* optimizer.scm:669: test */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7473(t2,((C_word*)t0)[3],((C_word*)t0)[4],lf[81]);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_7509(2,av2);}}}

/* k7684 in k7501 in g1375 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_7686,c,av);}
a=C_alloc(14);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7509,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t2,tmp=(C_word)a,a+=9,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7682,a[2]=((C_word*)t0)[8],a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:669: test */
t5=((C_word*)((C_word*)t0)[8])[1];
f_7473(t5,t4,t2,lf[131]);}

/* k7691 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7693,c,av);}
a=C_alloc(6);
t2=(C_truep(t1)?t1:C_SCHEME_END_OF_LIST);
t3=C_i_check_list_2(t2,lf[23]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7704,a[2]=t5,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_7704(t7,((C_word*)t0)[3],t2);}

/* for-each-loop1374 in k7691 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_7704(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7704,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7714,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:664: g1375 */
t4=((C_word*)t0)[3];
f_7496(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7712 in for-each-loop1374 in k7691 in k7493 in k7478 in chicken.compiler.optimizer#perform-high-level-optimizations in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7714(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7714,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7704(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word t69;
C_word t70;
C_word t71;
C_word t72;
C_word t73;
C_word t74;
C_word t75;
C_word t76;
C_word t77;
C_word t78;
C_word t79;
C_word t80;
C_word t81;
C_word t82;
C_word t83;
C_word t84;
C_word t85;
C_word t86;
C_word t87;
C_word t88;
C_word t89;
C_word t90;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(594,c,15)))){
C_save_and_reclaim((void *)f_7734,c,av);}
a=C_alloc(594);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7737,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_a_i_list(&a,1,lf[206]);
t4=C_a_i_list(&a,1,lf[204]);
t5=C_a_i_list(&a,1,lf[207]);
t6=C_a_i_list(&a,2,lf[24],t5);
t7=C_a_i_list(&a,1,lf[208]);
t8=C_a_i_list(&a,2,lf[76],t7);
t9=C_a_i_list(&a,4,lf[58],t4,t6,t8);
t10=C_a_i_list(&a,1,lf[206]);
t11=C_a_i_list(&a,2,lf[24],t10);
t12=C_a_i_list(&a,1,lf[209]);
t13=C_a_i_list(&a,1,lf[204]);
t14=C_a_i_list(&a,1,lf[207]);
t15=C_a_i_list(&a,2,lf[24],t14);
t16=C_a_i_list(&a,1,lf[210]);
t17=C_a_i_list(&a,2,lf[76],t16);
t18=C_a_i_list(&a,4,lf[58],t13,t15,t17);
t19=C_a_i_list(&a,1,lf[209]);
t20=C_a_i_list(&a,2,lf[24],t19);
t21=C_a_i_list(&a,5,lf[25],lf[199],t20,lf[211],lf[212]);
t22=C_a_i_list(&a,4,lf[26],t12,t18,t21);
t23=C_a_i_list(&a,5,lf[25],lf[203],t11,lf[213],t22);
t24=C_a_i_list(&a,4,lf[26],t3,t9,t23);
t25=C_a_i_list(&a,11,lf[207],lf[206],lf[209],lf[204],lf[208],lf[210],lf[213],lf[211],lf[203],lf[199],lf[212]);
t26=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13924,tmp=(C_word)a,a+=2,tmp);
t27=C_a_i_list(&a,3,t24,t25,t26);
t28=C_a_i_list(&a,1,lf[198]);
t29=C_a_i_list(&a,1,lf[204]);
t30=C_a_i_list(&a,1,lf[207]);
t31=C_a_i_list(&a,2,lf[24],t30);
t32=C_a_i_list(&a,1,lf[216]);
t33=C_a_i_list(&a,2,lf[76],t32);
t34=C_a_i_list(&a,4,lf[58],t29,t31,t33);
t35=C_a_i_list(&a,1,lf[198]);
t36=C_a_i_list(&a,2,lf[24],t35);
t37=C_a_i_list(&a,1,lf[217]);
t38=C_a_i_list(&a,1,lf[207]);
t39=C_a_i_list(&a,2,lf[24],t38);
t40=C_a_i_cons(&a,2,t39,lf[218]);
t41=C_a_i_cons(&a,2,t37,t40);
t42=C_a_i_cons(&a,2,lf[40],t41);
t43=C_a_i_list(&a,5,lf[25],lf[219],t36,lf[220],t42);
t44=C_a_i_list(&a,4,lf[26],t28,t34,t43);
t45=C_a_i_list(&a,8,lf[198],lf[204],lf[207],lf[216],lf[219],lf[220],lf[217],lf[218]);
t46=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13797,tmp=(C_word)a,a+=2,tmp);
t47=C_a_i_list(&a,3,t44,t45,t46);
t48=C_a_i_list(&a,1,lf[206]);
t49=C_a_i_list(&a,2,lf[34],C_SCHEME_END_OF_LIST);
t50=C_a_i_list(&a,4,lf[26],t48,t49,lf[221]);
t51=C_a_i_list(&a,2,lf[206],lf[221]);
t52=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13484,tmp=(C_word)a,a+=2,tmp);
t53=C_a_i_list(&a,3,t50,t51,t52);
t54=C_a_i_list(&a,1,lf[198]);
t55=C_a_i_list(&a,1,lf[204]);
t56=C_a_i_cons(&a,2,t55,lf[224]);
t57=C_a_i_cons(&a,2,lf[58],t56);
t58=C_a_i_list(&a,1,lf[198]);
t59=C_a_i_list(&a,2,lf[24],t58);
t60=C_a_i_list(&a,5,lf[25],lf[219],t59,lf[190],lf[200]);
t61=C_a_i_list(&a,4,lf[26],t54,t57,t60);
t62=C_a_i_list(&a,6,lf[198],lf[204],lf[224],lf[219],lf[190],lf[200]);
t63=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13401,tmp=(C_word)a,a+=2,tmp);
t64=C_a_i_list(&a,3,t61,t62,t63);
t65=C_a_i_list(&a,1,lf[198]);
t66=C_a_i_list(&a,1,lf[225]);
t67=C_a_i_cons(&a,2,t66,lf[226]);
t68=C_a_i_cons(&a,2,lf[58],t67);
t69=C_a_i_list(&a,1,lf[227]);
t70=C_a_i_list(&a,2,lf[24],t69);
t71=C_a_i_list(&a,1,lf[228]);
t72=C_a_i_cons(&a,2,t71,lf[229]);
t73=C_a_i_cons(&a,2,lf[58],t72);
t74=C_a_i_list(&a,4,lf[30],lf[48],t70,t73);
t75=C_a_i_list(&a,4,lf[26],t65,t68,t74);
t76=C_a_i_list(&a,7,lf[198],lf[225],lf[226],lf[48],lf[227],lf[228],lf[229]);
t77=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13216,tmp=(C_word)a,a+=2,tmp);
t78=C_a_i_list(&a,3,t75,t76,t77);
t79=C_a_i_list(&a,1,lf[198]);
t80=C_a_i_list(&a,1,lf[204]);
t81=C_a_i_cons(&a,2,t80,lf[226]);
t82=C_a_i_cons(&a,2,lf[58],t81);
t83=C_a_i_cons(&a,2,lf[48],lf[229]);
t84=C_a_i_cons(&a,2,lf[30],t83);
t85=C_a_i_list(&a,4,lf[26],t79,t82,t84);
t86=C_a_i_list(&a,5,lf[198],lf[204],lf[226],lf[48],lf[229]);
t87=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13083,tmp=(C_word)a,a+=2,tmp);
t88=C_a_i_list(&a,3,t85,t86,t87);
t89=C_a_i_list(&a,6,t27,t47,t53,t64,t78,t88);
/* optimizer.scm:708: chicken.internal#hash-table-set! */
t90=*((C_word*)lf[161]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t90;
av2[1]=t2;
av2[2]=lf[50];
av2[3]=lf[26];
av2[4]=t89;
((C_proc)(void*)(*((C_word*)t90+1)))(5,av2);}}

/* k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(166,c,11)))){
C_save_and_reclaim((void *)f_7737,c,av);}
a=C_alloc(166);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7740,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_a_i_list(&a,1,lf[198]);
t4=C_a_i_list(&a,2,lf[24],t3);
t5=C_a_i_list(&a,4,lf[30],lf[199],t4,lf[200]);
t6=C_a_i_list(&a,1,lf[198]);
t7=C_a_i_list(&a,2,lf[24],t6);
t8=C_a_i_list(&a,4,lf[30],lf[201],t7,lf[202]);
t9=C_a_i_list(&a,5,lf[25],lf[203],lf[190],t5,t8);
t10=C_a_i_list(&a,7,lf[203],lf[199],lf[201],lf[190],lf[200],lf[202],lf[198]);
t11=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13002,tmp=(C_word)a,a+=2,tmp);
t12=C_a_i_list(&a,3,t9,t10,t11);
t13=C_a_i_list(&a,1,lf[204]);
t14=C_a_i_list(&a,1,lf[205]);
t15=C_a_i_list(&a,2,lf[76],t14);
t16=C_a_i_list(&a,4,lf[58],t13,lf[190],t15);
t17=C_a_i_list(&a,5,lf[25],lf[203],t16,lf[200],lf[202]);
t18=C_a_i_list(&a,6,lf[203],lf[204],lf[190],lf[205],lf[200],lf[202]);
t19=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_12856,tmp=(C_word)a,a+=2,tmp);
t20=C_a_i_list(&a,3,t17,t18,t19);
t21=C_a_i_list(&a,2,t12,t20);
/* optimizer.scm:708: chicken.internal#hash-table-set! */
t22=*((C_word*)lf[161]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t22;
av2[1]=t2;
av2[2]=lf[50];
av2[3]=lf[25];
av2[4]=t21;
((C_proc)(void*)(*((C_word*)t22+1)))(5,av2);}}

/* k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_7740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_7740,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8280,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1090: scheme#make-vector */
t3=*((C_word*)lf[197]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_fix(301);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in ... */
static void C_ccall f_7755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,4)))){
C_save_and_reclaim((void *)f_7755,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7757,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7800,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7812,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8193,a[2]=t6,a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_8193(t8,t4,((C_word*)t0)[3],((C_word*)t0)[6]);}

/* find-path in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in ... */
static void C_fcall f_7757(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_7757,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7763,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_7763(t7,t1,t2,C_SCHEME_END_OF_LIST);}

/* find in find-path in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in ... */
static void C_fcall f_7763(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_7763,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_i_memq(t2,t3);
if(C_truep(C_i_not(t4))){
t5=C_i_assq(t2,((C_word*)((C_word*)t0)[2])[1]);
t6=C_i_cdr(t5);
t7=C_i_memq(((C_word*)t0)[3],t6);
if(C_truep(t7)){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_a_i_cons(&a,2,t2,t3);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7787,a[2]=((C_word*)t0)[4],a[3]=t8,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1013: any */
f_3806(t1,t9,t6);}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* a7786 in find in find-path in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in ... */
static void C_ccall f_7787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7787,c,av);}
/* optimizer.scm:1013: find */
t3=((C_word*)((C_word*)t0)[2])[1];
f_7763(t3,t1,t2,((C_word*)t0)[3]);}

/* g1689 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in ... */
static void C_fcall f_7800(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_7800,4,t0,t1,t2,t3);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7809,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1017: chicken.compiler.support#scan-used-variables */
t5=*((C_word*)lf[165]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k7807 in g1689 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in ... */
static void C_ccall f_7809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_7809,c,av);}
a=C_alloc(6);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in ... */
static void C_ccall f_7812(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,3)))){
C_save_and_reclaim((void *)f_7812,c,av);}
a=C_alloc(25);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_END_OF_LIST;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7813,a[2]=t5,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t7=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_7872,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8170,a[2]=t9,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t11=((C_word*)t9)[1];
f_8170(t11,t7,((C_word*)t0)[3]);}

/* g1729 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in ... */
static void C_fcall f_7813(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_7813,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_memq(t2,((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(C_i_not(t3))){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7823,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7845,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1026: filter */
f_4012(t4,t5,((C_word*)t0)[5]);}
else{
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k7821 in g1729 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in ... */
static void C_ccall f_7823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_7823,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7839,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1029: chicken.base#gensym */
t3=*((C_word*)lf[116]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7829 in k7837 in k7821 in g1729 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in ... */
static void C_ccall f_7831(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7831,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7837 in k7821 in g1729 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in ... */
static void C_ccall f_7839(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_7839,c,av);}
a=C_alloc(16);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=((C_word*)((C_word*)t0)[4])[1];
t4=C_a_i_cons(&a,2,t1,t2);
t5=C_a_i_cons(&a,2,t4,t3);
t6=C_mutate(((C_word *)((C_word*)t0)[4])+1,t5);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7831,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t8=C_a_i_list1(&a,1,((C_word*)t0)[2]);
/* optimizer.scm:1030: scheme#append */
t9=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t7;
av2[2]=t8;
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a7844 in g1729 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in ... */
static void C_ccall f_7845(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7845,c,av);}
a=C_alloc(6);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(C_i_not(t3))){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7858,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1027: find-path */
t5=((C_word*)t0)[3];
f_7757(t5,t4,((C_word*)t0)[2],t2);}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7856 in a7844 in g1729 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in ... */
static void C_ccall f_7858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7858,c,av);}
if(C_truep(t1)){
/* optimizer.scm:1027: find-path */
t2=((C_word*)t0)[2];
f_7757(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in ... */
static void C_ccall f_7872(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_7872,c,av);}
a=C_alloc(22);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7873,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t5=((C_word*)((C_word*)t0)[2])[1];
t6=C_i_check_list_2(t5,lf[23]);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7932,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=t3,tmp=(C_word)a,a+=8,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8147,a[2]=t9,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t11=((C_word*)t9)[1];
f_8147(t11,t7,t5);}

/* g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in ... */
static void C_fcall f_7873(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_7873,3,t0,t1,t2);}
a=C_alloc(11);
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7880,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t1,a[5]=t2,a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7914,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1039: append-map */
f_3602(t4,t5,C_u_i_cdr(t2),C_SCHEME_END_OF_LIST);}

/* k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in ... */
static void C_ccall f_7880(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_7880,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7888,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7890,a[2]=((C_word*)t0)[5],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=((C_word*)((C_word*)t0)[6])[1];
t5=C_i_check_list_2(t4,lf[6]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_4065,a[2]=t3,a[3]=t7,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_4065(t9,t2,t4);}

/* k7886 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in ... */
static void C_ccall f_7888(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_7888,c,av);}
a=C_alloc(6);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* a7889 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in ... */
static void C_fcall f_7890(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_7890,3,t0,t1,t2);}
a=C_alloc(7);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(C_i_not(t3))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7903,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t5=C_i_cdr(t2);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_4450,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:193: every */
f_3772(t4,t6,t5);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7901 in a7889 in k7878 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in ... */
static void C_ccall f_7903(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7903,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_u_i_car(((C_word*)t0)[3]):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a7913 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in ... */
static void C_ccall f_7914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_7914,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7920,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1040: filter */
f_4012(t1,t3,((C_word*)t0)[3]);}

/* a7919 in a7913 in g1753 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in ... */
static void C_ccall f_7920(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7920,c,av);}
/* optimizer.scm:1040: find-path */
t3=((C_word*)t0)[2];
f_7757(t3,t1,((C_word*)t0)[3],t2);}

/* k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in ... */
static void C_ccall f_7932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_7932,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7935,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1052: chicken.sort#topological-sort */
t3=*((C_word*)lf[223]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[7])[1];
av2[3]=*((C_word*)lf[47]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in ... */
static void C_ccall f_7935(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_7935,c,av);}
a=C_alloc(15);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7938,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7955,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t6,tmp=(C_word)a,a+=7,tmp));
t8=((C_word*)t6)[1];
f_7955(t8,t4,t1,((C_word*)t0)[6]);}

/* k7936 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in ... */
static void C_ccall f_7938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_7938,c,av);}
a=C_alloc(4);
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[2])[1]))){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7947,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1083: chicken.compiler.support#debugging */
t3=*((C_word*)lf[35]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[36];
av2[3]=lf[222];
av2[4]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* optimizer.scm:1085: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
C_values(4,av2);}}}

/* k7945 in k7936 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in ... */
static void C_ccall f_7947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7947,c,av);}
/* optimizer.scm:1084: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_SCHEME_TRUE;
C_values(4,av2);}}

/* foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in ... */
static void C_fcall f_7955(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_7955,4,t0,t1,t2,t3);}
a=C_alloc(11);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7971,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8141,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1057: g1790 */
t7=t5;
f_7971(t7,t6,t3,C_slot(t2,C_fix(0)));}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in ... */
static void C_fcall f_7971(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_7971,4,t0,t1,t2,t3);}
a=C_alloc(8);
t4=C_i_assq(t3,((C_word*)((C_word*)t0)[2])[1]);
t5=C_i_cdr(t4);
t6=C_i_car(t5);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7984,a[2]=t6,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=t1,a[7]=t5,tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_nullp(C_u_i_cdr(t5)))){
t8=C_i_assq(t6,((C_word*)((C_word*)t0)[5])[1]);
t9=C_i_cdr(t8);
t10=t7;
f_7984(t10,C_i_not(C_i_memq(t6,t9)));}
else{
t8=t7;
f_7984(t8,C_SCHEME_FALSE);}}

/* k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in ... */
static void C_fcall f_7984(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_7984,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,t2);
t4=C_i_assq(((C_word*)t0)[2],((C_word*)t0)[4]);
t5=C_i_cdr(t4);
t6=C_a_i_list2(&a,2,t5,((C_word*)t0)[5]);
/* optimizer.scm:1064: chicken.compiler.support#make-node */
t7=*((C_word*)lf[33]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=((C_word*)t0)[6];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[7];
av2[4]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8008,a[2]=t3,a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp));
t5=((C_word*)t3)[1];
f_8008(t5,((C_word*)t0)[6],((C_word*)t0)[7]);}}

/* foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in ... */
static void C_fcall f_8008(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_8008,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8043,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t8=t4;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=C_i_check_list_2(((C_word*)t0)[3],lf[6]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8055,a[2]=((C_word*)t0)[4],a[3]=t5,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_8055(t7,t1,((C_word*)t0)[3]);}}

/* k8030 in k8041 in foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in ... */
static void C_ccall f_8032(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8032,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,t1,((C_word*)t0)[2]);
/* optimizer.scm:1068: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8041 in foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in ... */
static void C_ccall f_8043(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_8043,c,av);}
a=C_alloc(8);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8032,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1070: chicken.compiler.support#make-node */
t4=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[34];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* foldr1819 in foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in ... */
static void C_fcall f_8055(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_8055,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8063,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8110,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g1824 in foldr1819 in foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in ... */
static void C_fcall f_8063(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_8063,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8099,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1074: chicken.base#gensym */
t5=*((C_word*)lf[116]+1);{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k8077 in k8097 in g1824 in foldr1819 in foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in ... */
static void C_ccall f_8079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8079,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,t1,((C_word*)t0)[2]);
/* optimizer.scm:1073: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8097 in g1824 in foldr1819 in foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in ... */
static void C_ccall f_8099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_8099,c,av);}
a=C_alloc(14);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8079,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_a_i_list1(&a,1,((C_word*)t0)[4]);
t5=C_i_assq(((C_word*)t0)[4],((C_word*)t0)[5]);
t6=C_i_cdr(t5);
t7=C_a_i_list1(&a,1,t6);
/* optimizer.scm:1075: chicken.compiler.support#make-node */
t8=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t3;
av2[2]=lf[31];
av2[3]=t4;
av2[4]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}

/* k8108 in foldr1819 in foldr1806 in k7982 in g1790 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in ... */
static void C_ccall f_8110(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8110,c,av);}
/* optimizer.scm:1071: g1824 */
t2=((C_word*)t0)[2];
f_8063(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k8139 in foldl1783 in k7933 in k7930 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in ... */
static void C_ccall f_8141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8141,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7955(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* for-each-loop1752 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in ... */
static void C_fcall f_8147(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_8147,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8157,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1035: g1753 */
t4=((C_word*)t0)[3];
f_7873(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k8155 in for-each-loop1752 in k7870 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in ... */
static void C_ccall f_8157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8157,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_8147(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop1728 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in ... */
static void C_fcall f_8170(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_8170,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8180,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1023: g1729 */
t4=((C_word*)t0)[3];
f_7813(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k8178 in for-each-loop1728 in k7810 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in ... */
static void C_ccall f_8180(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8180,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_8170(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop1688 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in ... */
static void C_fcall f_8193(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_8193,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8203,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1016: g1689 */
t7=((C_word*)t0)[3];
f_7800(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k8201 in for-each-loop1688 in k7753 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in ... */
static void C_ccall f_8203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8203,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_8193(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* map-loop1657 in k13657 in a13650 in k13611 in k13605 in k13602 in k13599 in loop2 in k13568 in k13538 in k13535 in k13532 in k13761 in k13769 in k13502 in k13499 in k13496 in loop1 in a13483 in k7732 in k5046 in k4693 in ... */
static void C_fcall f_8230(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_8230,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=C_slot(t2,C_fix(0));
t7=C_slot(t3,C_fix(0));
t8=C_a_i_cons(&a,2,t6,t7);
t9=C_a_i_cons(&a,2,t8,C_SCHEME_END_OF_LIST);
t10=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t9);
t11=C_mutate(((C_word *)((C_word*)t0)[2])+1,t9);
t13=t1;
t14=C_slot(t2,C_fix(1));
t15=C_slot(t3,C_fix(1));
t1=t13;
t2=t14;
t3=t15;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8280,c,av);}
a=C_alloc(6);
t2=C_mutate(&lf[159] /* (set! chicken.compiler.optimizer#substitution-table ...) */,t1);
t3=C_mutate((C_word*)lf[160]+1 /* (set! chicken.compiler.optimizer#rewrite ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8282,tmp=(C_word)a,a+=2,tmp));
t4=C_mutate((C_word*)lf[162]+1 /* (set! chicken.compiler.optimizer#transform-direct-lambdas! ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_10578,tmp=(C_word)a,a+=2,tmp));
t5=C_mutate((C_word*)lf[186]+1 /* (set! chicken.compiler.optimizer#determine-loop-and-dispatch ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11874,tmp=(C_word)a,a+=2,tmp));
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* chicken.compiler.optimizer#rewrite in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8282(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_8282,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+5);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8286,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1093: chicken.internal#hash-table-ref */
t5=*((C_word*)lf[57]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[159];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k8284 in chicken.compiler.optimizer#rewrite in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_8286,c,av);}
a=C_alloc(7);
t2=(C_truep(t1)?t1:C_SCHEME_END_OF_LIST);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8296,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_a_i_list1(&a,1,((C_word*)t0)[4]);
/* optimizer.scm:1094: scheme#append */
t5=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t2;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k8294 in k8284 in chicken.compiler.optimizer#rewrite in k8278 in k7738 in k7735 in k7732 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8296,c,av);}
/* optimizer.scm:1094: chicken.internal#hash-table-set! */
t2=*((C_word*)lf[161]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[159];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* argc-ok? in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static C_word C_fcall f_8305(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_stack_overflow_check;
loop:{}
t2=C_i_not(t1);
if(C_truep(t2)){
return(t2);}
else{
t3=C_fixnump(t1);
t4=(C_truep(t3)?C_eqp(t1,C_i_length(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t4)){
return(t4);}
else{
if(C_truep(C_i_pairp(t1))){
t5=f_8305(t0,C_u_i_car(t1));
if(C_truep(t5)){
t7=C_u_i_cdr(t1);
t1=t7;
goto loop;}
else{
return(C_SCHEME_FALSE);}}
else{
return(C_SCHEME_FALSE);}}}}

/* k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8395(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_8395,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8398,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_i_length(((C_word*)t0)[6]);
t4=C_i_car(((C_word*)t0)[5]);
if(C_truep(C_i_nequalp(t3,t4))){
t5=C_i_car(((C_word*)t0)[6]);
t6=C_i_cadr(((C_word*)t0)[6]);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8485,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1120: chicken.compiler.support#node-class */
t8=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t5=t2;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_8398(2,av2);}}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k8396 in k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_8398,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
f_14117(2,av2);}}
else{
if(C_truep(((C_word*)t0)[3])){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8419,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_i_cadr(((C_word*)t0)[5]);
t5=C_a_i_list1(&a,1,t4);
/* optimizer.scm:1127: chicken.compiler.support#make-node */
t6=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t3;
av2[2]=lf[58];
av2[3]=t5;
av2[4]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}}

/* k8417 in k8396 in k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8419(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8419,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1125: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8467 in k8475 in k8471 in k8479 in k8483 in k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8469(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8469,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1123: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8471 in k8479 in k8483 in k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8473,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8477,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1122: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8475 in k8471 in k8479 in k8483 in k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8477(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_8477,c,av);}
a=C_alloc(8);
if(C_truep(C_i_equalp(((C_word*)t0)[2],t1))){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8469,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1123: chicken.compiler.support#qnode */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_8398(2,av2);}}}

/* k8479 in k8483 in k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8481(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8481,c,av);}
a=C_alloc(5);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8473,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1122: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[43]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_8398(2,av2);}}}

/* k8483 in k8393 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_8485,c,av);}
a=C_alloc(6);
t2=C_eqp(lf[24],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8481,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1121: chicken.compiler.support#node-class */
t4=*((C_word*)lf[41]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_8398(2,av2);}}}

/* k8512 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8514(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_8514,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_i_caddr(((C_word*)t0)[2]);
t3=(C_truep(t2)?t2:*((C_word*)lf[232]+1));
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[3]);
t5=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8541,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t5,tmp=(C_word)a,a+=5,tmp);
t7=C_i_cadr(((C_word*)t0)[2]);
t8=C_a_i_list1(&a,1,t7);
/* optimizer.scm:1141: chicken.compiler.support#make-node */
t9=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t6;
av2[2]=lf[58];
av2[3]=t8;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k8539 in k8512 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8541(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8541,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1137: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8570 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_8572,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=C_i_cadr(((C_word*)t0)[2]);
t3=C_i_not(t2);
t4=(C_truep(t3)?t3:C_i_nequalp(C_i_length(((C_word*)t0)[3]),C_i_cadr(((C_word*)t0)[2])));
if(C_truep(t4)){
t5=C_i_check_list_2(((C_word*)t0)[3],lf[6]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8589,a[2]=t7,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_8589(t9,((C_word*)t0)[5],((C_word*)t0)[3]);}
else{
t5=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* foldr1913 in k8570 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_8589(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_8589,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8624,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=t4;
t7=C_slot(t2,C_fix(1));
t1=t6;
t2=t7;
goto loop;}
else{
t3=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8643,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1152: chicken.compiler.support#varnode */
t5=*((C_word*)lf[83]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k8611 in k8622 in foldr1913 in k8570 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_8613,c,av);}
a=C_alloc(9);
t2=C_a_i_list1(&a,1,t1);
t3=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* optimizer.scm:1151: chicken.compiler.support#make-node */
t4=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[26];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k8622 in foldr1913 in k8570 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8624,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8613,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1151: chicken.base#gensym */
t3=*((C_word*)lf[116]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k8641 in foldr1913 in k8570 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8643,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1152: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8684 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_8686,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_a_i_list2(&a,2,C_SCHEME_FALSE,t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8701,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t3,a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1162: chicken.compiler.support#varnode */
t5=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k8699 in k8684 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_8701,c,av);}
a=C_alloc(8);
t2=C_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_8709,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* optimizer.scm:1165: chicken.compiler.support#qnode */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_cadr(((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8707 in k8699 in k8684 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8709(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_8709,c,av);}
a=C_alloc(15);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=C_a_i_list5(&a,5,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1,t2);
/* optimizer.scm:1161: chicken.compiler.support#make-node */
t4=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[6];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[7];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k8743 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8745(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_8745,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=C_i_length(((C_word*)t0)[2]);
t3=C_eqp(C_fix(1),t2);
if(C_truep(t3)){
t4=C_i_caddr(((C_word*)t0)[3]);
t5=C_i_not(t4);
t6=(C_truep(t5)?t5:C_eqp(t4,*((C_word*)lf[233]+1)));
if(C_truep(t6)){
t7=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8778,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t7,tmp=(C_word)a,a+=5,tmp);
t9=C_i_car(((C_word*)t0)[3]);
t10=C_a_i_list1(&a,1,t9);
t11=C_i_car(((C_word*)t0)[2]);
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8794,a[2]=t11,a[3]=t8,a[4]=t10,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1180: chicken.compiler.support#qnode */
t13=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t13;
av2[1]=t12;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t7=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k8776 in k8743 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8778,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1176: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8792 in k8743 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8794,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1178: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[58];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8838 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,4)))){
C_save_and_reclaim((void *)f_8840,c,av);}
a=C_alloc(18);
if(C_truep(t1)){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8855,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_i_car(((C_word*)t0)[4]);
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8867,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=C_i_cadr(((C_word*)t0)[4]);
t8=C_a_i_list1(&a,1,t7);
/* optimizer.scm:1191: chicken.compiler.support#make-node */
t9=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t6;
av2[2]=lf[58];
av2[3]=t8;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k8853 in k8838 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8855,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1188: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8865 in k8838 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8867(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_8867,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1190: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[58];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8912 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_8914,c,av);}
a=C_alloc(19);
if(C_truep(t1)){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8929,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_i_cadr(((C_word*)t0)[4]);
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8937,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8945,a[2]=t6,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* optimizer.scm:1204: chicken.compiler.support#qnode */
t8=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=C_i_caddr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k8927 in k8912 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8929,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1200: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8935 in k8912 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8937,c,av);}
/* optimizer.scm:1202: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[58];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k8943 in k8912 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_8945,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* optimizer.scm:1203: scheme#append */
t3=*((C_word*)lf[7]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k8974 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8976(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_8976,c,av);}
if(C_truep(t1)){
/* optimizer.scm:1208: g1952 */
t2=C_i_car(((C_word*)t0)[2]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[2];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_8997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_8997,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_i_length(((C_word*)t0)[2]);
if(C_truep(C_fixnum_lessp(t2,C_fix(2)))){
t3=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9018,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1218: chicken.compiler.support#qnode */
t5=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=(C_truep(*((C_word*)lf[232]+1))?C_i_not(C_eqp(*((C_word*)lf[233]+1),lf[234])):C_SCHEME_FALSE);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9027,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t3)){
t5=t4;
f_9027(t5,t3);}
else{
t5=C_eqp(*((C_word*)lf[233]+1),lf[235]);
t6=(C_truep(t5)?C_i_caddr(((C_word*)t0)[5]):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t4;
f_9027(t7,t6);}
else{
t7=C_eqp(*((C_word*)lf[233]+1),lf[237]);
t8=t4;
f_9027(t8,(C_truep(t7)?C_i_cadddr(((C_word*)t0)[5]):C_SCHEME_FALSE));}}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9016 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9018(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9018,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1218: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_9027(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,3)))){
C_save_and_reclaim_args((void *)trf_9027,2,t0,t1);}
a=C_alloc(18);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9038,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9163,a[2]=t4,a[3]=t8,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_9163(t10,t6,((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9038(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_9038,c,av);}
a=C_alloc(20);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=*((C_word*)lf[83]+1);
t7=C_i_check_list_2(t1,lf[8]);
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9047,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9129,a[2]=t4,a[3]=t10,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_9129(t12,t8,t1);}

/* k9045 in k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_9047,c,av);}
a=C_alloc(8);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9052,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t3,tmp=(C_word)a,a+=6,tmp));
t5=((C_word*)t3)[1];
f_9052(t5,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);}

/* loop in k9045 in k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_9052(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(14,0,4)))){
C_save_and_reclaim_args((void *)trf_9052,4,t0,t1,t2,t3);}
a=C_alloc(14);
if(C_truep(C_i_nullp(t2))){
t4=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t5=C_eqp(*((C_word*)lf[233]+1),lf[235]);
t6=(C_truep(t5)?C_i_car(((C_word*)t0)[2]):C_i_cadr(((C_word*)t0)[2]));
t7=C_a_i_list1(&a,1,t6);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9077,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9079,a[2]=t7,tmp=(C_word)a,a+=3,tmp);
/* optimizer.scm:1235: chicken.compiler.support#fold-boolean */
t10=*((C_word*)lf[236]+1);{
C_word av2[4];
av2[0]=t10;
av2[1]=t8;
av2[2]=t9;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t10+1)))(4,av2);}}
else{
t4=C_i_car(t3);
t5=C_a_i_list1(&a,1,t4);
t6=C_i_car(t2);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9119,a[2]=t6,a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1241: loop */
t11=t7;
t12=C_u_i_cdr(t2);
t13=C_u_i_cdr(t3);
t1=t11;
t2=t12;
t3=t13;
goto loop;}}

/* k9075 in loop in k9045 in k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9077(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9077,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1227: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a9078 in loop in k9045 in k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9079,c,av);}
a=C_alloc(6);
t4=C_a_i_list2(&a,2,t2,t3);
/* optimizer.scm:1236: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[58];
av2[3]=((C_word*)t0)[2];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k9117 in loop in k9045 in k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9119,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1238: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[26];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* map-loop1997 in k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_9129(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9129,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9154,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1223: g2003 */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9152 in map-loop1997 in k9036 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9154(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9154,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9129(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* map-loop1969 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_9163(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9163,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9188,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1222: chicken.base#gensym */
t4=*((C_word*)lf[116]+1);{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9186 in map-loop1969 in k9025 in k8995 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9188,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9163(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k9250 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9252(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9252,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_length(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9261,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* optimizer.scm:1249: scheme#< */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t3;
av2[2]=C_fix(0);
av2[3]=t2;
av2[4]=C_fix(3);
C_lessp(5,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9259 in k9250 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9261(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_9261,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_a_i_list2(&a,2,C_SCHEME_FALSE,t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9276,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t3,a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1251: chicken.compiler.support#varnode */
t5=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9274 in k9259 in k9250 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9276(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_9276,c,av);}
a=C_alloc(9);
t2=C_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9284,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:1254: chicken.compiler.support#qnode */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_cadr(((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k9282 in k9274 in k9259 in k9250 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_9284,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9288,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=C_i_cdr(((C_word*)t0)[7]);
if(C_truep(C_i_nullp(t3))){
/* optimizer.scm:1256: chicken.compiler.support#varnode */
t4=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=C_i_caddr(((C_word*)t0)[8]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cadr(((C_word*)t0)[7]);
f_9288(2,av2);}}}

/* k9286 in k9282 in k9274 in k9259 in k9250 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9288(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_9288,c,av);}
a=C_alloc(15);
t2=C_a_i_list5(&a,5,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);
/* optimizer.scm:1250: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[6];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[7];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9339 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9341(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_9341,c,av);}
a=C_alloc(15);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_not(t2);
t4=(C_truep(t3)?t3:C_i_nequalp(C_i_length(((C_word*)t0)[3]),C_i_car(((C_word*)t0)[2])));
if(C_truep(t4)){
t5=C_i_cadr(((C_word*)t0)[2]);
t6=C_a_i_list2(&a,2,C_SCHEME_TRUE,t5);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9364,a[2]=((C_word*)t0)[4],a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9368,a[2]=t7,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1269: chicken.compiler.support#varnode */
t9=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9362 in k9339 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9364(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9364,c,av);}
/* optimizer.scm:1268: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k9366 in k9339 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9368,c,av);}
a=C_alloc(6);
/* optimizer.scm:1269: cons* */
f_3836(((C_word*)t0)[2],t1,C_a_i_list(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]));}

/* k9400 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9402(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_9402,c,av);}
a=C_alloc(15);
if(C_truep(t1)){
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(C_truep(t2)?t2:*((C_word*)lf[232]+1));
if(C_truep(t3)){
t4=C_i_length(((C_word*)t0)[3]);
t5=C_i_caddr(((C_word*)t0)[2]);
if(C_truep(C_i_less_or_equalp(t4,t5))){
t6=C_eqp(t4,C_fix(1));
if(C_truep(t6)){
t7=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t8=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[3]);
/* optimizer.scm:1282: chicken.compiler.support#make-node */
t9=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[5];
av2[2]=lf[30];
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t7=C_i_car(((C_word*)t0)[2]);
t8=C_a_i_list2(&a,2,C_SCHEME_TRUE,t7);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9448,a[2]=((C_word*)t0)[5],a[3]=t8,tmp=(C_word)a,a+=4,tmp);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9452,a[2]=t9,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1284: chicken.compiler.support#varnode */
t11=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=C_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}}
else{
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9446 in k9400 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9448(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9448,c,av);}
/* optimizer.scm:1283: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k9450 in k9400 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9452,c,av);}
a=C_alloc(6);
/* optimizer.scm:1284: cons* */
f_3836(((C_word*)t0)[2],t1,C_a_i_list(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]));}

/* k9479 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9481(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_9481,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_i_caddr(((C_word*)t0)[2]);
t3=(C_truep(t2)?t2:*((C_word*)lf[232]+1));
if(C_truep(t3)){
t4=(
/* optimizer.scm:1293: argc-ok? */
  f_8305(((C_word*)t0)[3],C_i_car(((C_word*)t0)[2]))
);
if(C_truep(t4)){
t5=C_i_cadr(((C_word*)t0)[2]);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9506,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=t5,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[7]))){
t7=C_u_i_cdr(((C_word*)t0)[7]);
t8=t6;
f_9506(t8,C_a_i_cons(&a,2,C_SCHEME_TRUE,t7));}
else{
t7=t6;
f_9506(t7,((C_word*)t0)[7]);}}
else{
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9504 in k9479 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_9506(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,4)))){
C_save_and_reclaim_args((void *)trf_9506,2,t0,t1);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9510,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9514,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_a_i_list2(&a,2,((C_word*)t0)[5],C_SCHEME_TRUE);
/* optimizer.scm:1296: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[238];
av2[3]=t4;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k9508 in k9504 in k9479 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9510(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9510,c,av);}
/* optimizer.scm:1295: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k9512 in k9504 in k9479 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9514(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9514,c,av);}
a=C_alloc(6);
/* optimizer.scm:1296: cons* */
f_3836(((C_word*)t0)[2],t1,C_a_i_list(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]));}

/* k9549 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_9551,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_eqp(*((C_word*)lf[233]+1),t2);
if(C_truep(t3)){
t4=C_i_cadddr(((C_word*)t0)[2]);
t5=(C_truep(t4)?t4:*((C_word*)lf[232]+1));
if(C_truep(t5)){
t6=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9581,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t6,tmp=(C_word)a,a+=5,tmp);
t8=(C_truep(*((C_word*)lf[232]+1))?C_i_cadddr(((C_word*)t0)[2]):C_i_caddr(((C_word*)t0)[2]));
t9=C_a_i_list1(&a,1,t8);
/* optimizer.scm:1309: chicken.compiler.support#make-node */
t10=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t10;
av2[1]=t7;
av2[2]=lf[58];
av2[3]=t9;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9579 in k9549 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9581,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1306: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9632 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9634(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_9634,c,av);}
a=C_alloc(15);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_eqp(*((C_word*)lf[233]+1),t2);
if(C_truep(t3)){
t4=C_i_caddr(((C_word*)t0)[2]);
t5=C_a_i_list2(&a,2,C_SCHEME_TRUE,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9651,a[2]=((C_word*)t0)[3],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9655,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1323: chicken.compiler.support#varnode */
t8=*((C_word*)lf[83]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=C_i_caddr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t4=C_i_cadr(((C_word*)t0)[2]);
t5=C_eqp(*((C_word*)lf[233]+1),t4);
if(C_truep(t5)){
t6=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t7=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]);
/* optimizer.scm:1325: chicken.compiler.support#make-node */
t8=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=t6;
av2[4]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9649 in k9632 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9651(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9651,c,av);}
/* optimizer.scm:1322: chicken.compiler.support#make-node */
t2=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k9653 in k9632 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9655,c,av);}
a=C_alloc(6);
/* optimizer.scm:1323: cons* */
f_3836(((C_word*)t0)[2],t1,C_a_i_list(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]));}

/* k9733 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_9735,c,av);}
a=C_alloc(14);
if(C_truep(t1)){
t2=*((C_word*)lf[232]+1);
t3=(C_truep(*((C_word*)lf[232]+1))?*((C_word*)lf[232]+1):((C_word*)t0)[2]);
if(C_truep(t3)){
t4=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9756,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9764,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=t5,a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
t7=(C_truep(((C_word*)t0)[8])?(C_truep(C_i_fixnum_positivep(((C_word*)t0)[6]))?C_fixnum_less_or_equal_p(((C_word*)t0)[6],C_fix(8)):C_SCHEME_FALSE):C_SCHEME_FALSE);
if(C_truep(t7)){
/* optimizer.scm:1353: chicken.string#conc */
t8=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t8;
av2[1]=t6;
av2[2]=C_i_cadr(((C_word*)t0)[9]);
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
t8=t6;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_i_cadr(((C_word*)t0)[9]);
f_9764(2,av2);}}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9754 in k9733 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9756(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9756,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1347: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9762 in k9733 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9764(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(68,c,4)))){
C_save_and_reclaim((void *)f_9764,c,av);}
a=C_alloc(68);
t2=C_eqp(C_SCHEME_TRUE,((C_word*)t0)[2]);
if(C_truep(t2)){
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
t4=C_a_i_list2(&a,2,t1,t3);
/* optimizer.scm:1350: chicken.compiler.support#make-node */
t5=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[121];
av2[3]=t4;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t3=C_u_i_car(((C_word*)t0)[2]);
t4=C_i_cadr(((C_word*)t0)[2]);
t5=C_s_a_i_times(&a,2,((C_word*)t0)[3],t4);
t6=C_s_a_i_plus(&a,2,t3,t5);
t7=C_a_i_list2(&a,2,t1,t6);
/* optimizer.scm:1350: chicken.compiler.support#make-node */
t8=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[121];
av2[3]=t7;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
t3=C_a_i_list2(&a,2,t1,((C_word*)t0)[2]);
/* optimizer.scm:1350: chicken.compiler.support#make-node */
t4=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[121];
av2[3]=t3;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}}

/* k9845 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_9847,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9862,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(*((C_word*)lf[232]+1))){
t4=C_i_cddr(((C_word*)t0)[4]);
t5=C_i_pairp(t4);
t6=(C_truep(t5)?C_i_caddr(((C_word*)t0)[4]):C_i_cadr(((C_word*)t0)[4]));
t7=C_a_i_list1(&a,1,t6);
/* optimizer.scm:1369: chicken.compiler.support#make-node */
t8=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t3;
av2[2]=lf[58];
av2[3]=t7;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
t4=C_i_cadr(((C_word*)t0)[4]);
t5=C_a_i_list1(&a,1,t4);
/* optimizer.scm:1369: chicken.compiler.support#make-node */
t6=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t3;
av2[2]=lf[58];
av2[3]=t5;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9860 in k9845 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9862,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1366: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9913 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9915(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_9915,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9930,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1380: chicken.compiler.support#qnode */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9928 in k9913 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9930(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9930,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* optimizer.scm:1380: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9949,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_i_length(((C_word*)t0)[2]);
if(C_truep(C_fixnum_greaterp(t2,C_fix(2)))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9958,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* optimizer.scm:1387: scheme#reverse */
t4=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_14117(2,av2);}}}

/* k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9958(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_9958,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=C_i_cadr(t1);
t4=C_u_i_cdr(t1);
t5=C_u_i_cdr(t4);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9974,a[2]=((C_word*)t0)[2],a[3]=t7,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_9974(t9,((C_word*)t0)[3],t2,t3,t5,((C_word*)t0)[4]);}

/* lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_fcall f_9974(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_9974,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(10);
if(C_truep(C_i_nullp(t4))){
t6=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9996,a[2]=t5,a[3]=t3,a[4]=t2,a[5]=t1,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
/* optimizer.scm:1395: chicken.compiler.support#varnode */
t8=*((C_word*)lf[83]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9999,a[2]=t1,a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=t3,a[6]=t5,a[7]=t2,a[8]=((C_word*)t0)[2],tmp=(C_word)a,a+=9,tmp);
/* optimizer.scm:1396: chicken.base#gensym */
t7=*((C_word*)lf[116]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[241];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k9994 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_9996,c,av);}
a=C_alloc(12);
t2=C_a_i_list4(&a,4,t1,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
/* optimizer.scm:1393: chicken.compiler.support#make-node */
t3=*((C_word*)lf[33]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
av2[2]=lf[30];
av2[3]=((C_word*)t0)[6];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9997 in lp in k9956 in k9947 in loop in k14100 in a14093 in k5046 in k4693 in k4689 in k4685 in k4681 in k3399 in k3396 in k3393 in k3390 in k3387 */
static void C_ccall f_9999(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_9999,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10002,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* optimizer.scm:1397: chicken.base#gensym */
t3=*((C_word*)lf[116]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[240];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* toplevel */
static C_TLS int toplevel_initialized=0;

void C_ccall C_optimizer_toplevel(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(toplevel_initialized) {C_kontinue(t1,C_SCHEME_UNDEFINED);}
else C_toplevel_entry(C_text("optimizer"));
C_check_nursery_minimum(C_calculate_demand(3,c,2));
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void*)C_optimizer_toplevel,c,av);}
toplevel_initialized=1;
if(C_unlikely(!C_demand_2(1260))){
C_save(t1);
C_rereclaim2(1260*sizeof(C_word),1);
t1=C_restore;}
a=C_alloc(3);
C_initialize_lf(lf,245);
lf[0]=C_h_intern(&lf[0],9, C_text("optimizer"));
lf[1]=C_h_intern(&lf[1],27, C_text("chicken.compiler.optimizer#"));
lf[4]=C_h_intern(&lf[4],14, C_text("scheme#reverse"));
lf[6]=C_h_intern(&lf[6],5, C_text("foldr"));
lf[7]=C_h_intern(&lf[7],13, C_text("scheme#append"));
lf[8]=C_h_intern(&lf[8],3, C_text("map"));
lf[10]=C_h_intern(&lf[10],12, C_text("scheme#null\077"));
lf[17]=C_h_intern(&lf[17],45, C_text("chicken.compiler.optimizer#eq-inline-operator"));
lf[18]=C_h_intern(&lf[18],52, C_text("chicken.compiler.optimizer#membership-test-operators"));
lf[19]=C_h_intern(&lf[19],50, C_text("chicken.compiler.optimizer#membership-unfold-limit"));
lf[20]=C_h_intern(&lf[20],54, C_text("chicken.compiler.optimizer#default-optimization-passes"));
lf[21]=C_h_intern(&lf[21],52, C_text("chicken.compiler.optimizer#scan-toplevel-assignments"));
lf[22]=C_h_intern(&lf[22],26, C_text("chicken.base#alist-update!"));
lf[23]=C_h_intern(&lf[23],8, C_text("for-each"));
lf[24]=C_h_intern(&lf[24],15, C_text("##core#variable"));
lf[25]=C_h_intern(&lf[25],2, C_text("if"));
lf[26]=C_h_intern(&lf[26],3, C_text("let"));
lf[27]=C_h_intern(&lf[27],20, C_text("chicken.base#butlast"));
lf[28]=C_h_intern(&lf[28],6, C_text("lambda"));
lf[29]=C_h_intern(&lf[29],13, C_text("##core#lambda"));
lf[30]=C_h_intern(&lf[30],11, C_text("##core#call"));
lf[31]=C_h_intern(&lf[31],4, C_text("set!"));
lf[32]=C_h_intern(&lf[32],35, C_text("chicken.compiler.support#copy-node!"));
lf[33]=C_h_intern(&lf[33],34, C_text("chicken.compiler.support#make-node"));
lf[34]=C_h_intern(&lf[34],16, C_text("##core#undefined"));
lf[35]=C_h_intern(&lf[35],34, C_text("chicken.compiler.support#debugging"));
lf[36]=C_h_intern(&lf[36],1, C_text("o"));
lf[37]=C_decode_literal(C_heaptop,C_text("\376B\000\000&dropping redundant toplevel assignment"));
lf[38]=C_h_intern(&lf[38],22, C_text("chicken.base#alist-ref"));
lf[39]=C_h_intern(&lf[39],11, C_text("##core#cond"));
lf[40]=C_h_intern(&lf[40],13, C_text("##core#switch"));
lf[41]=C_h_intern(&lf[41],35, C_text("chicken.compiler.support#node-class"));
lf[42]=C_h_intern(&lf[42],44, C_text("chicken.compiler.support#node-subexpressions"));
lf[43]=C_h_intern(&lf[43],40, C_text("chicken.compiler.support#node-parameters"));
lf[44]=C_h_intern(&lf[44],38, C_text("chicken.compiler.support#mark-variable"));
lf[45]=C_h_intern(&lf[45],23, C_text("##compiler#always-bound"));
lf[46]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014safe globals"));
lf[47]=C_h_intern(&lf[47],10, C_text("scheme#eq\077"));
lf[48]=C_h_intern(&lf[48],1, C_text("p"));
lf[49]=C_decode_literal(C_heaptop,C_text("\376B\000\000 scanning toplevel assignments..."));
lf[54]=C_h_intern(&lf[54],59, C_text("chicken.compiler.optimizer#perform-high-level-optimizations"));
lf[55]=C_h_intern(&lf[55],31, C_text("chicken.compiler.support#db-get"));
lf[56]=C_h_intern(&lf[56],35, C_text("chicken.compiler.support#match-node"));
lf[57]=C_h_intern(&lf[57],31, C_text("chicken.internal#hash-table-ref"));
lf[58]=C_h_intern(&lf[58],13, C_text("##core#inline"));
lf[59]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001o\376\003\000\000\002\376\001\000\000\001\001x\376\377\016"));
lf[60]=C_decode_literal(C_heaptop,C_text("\376B\000\000!known list op on rest arg sublist"));
lf[61]=C_h_intern(&lf[61],34, C_text("chicken.compiler.support#call-info"));
lf[62]=C_h_intern(&lf[62],8, C_text("assigned"));
lf[63]=C_h_intern(&lf[63],8, C_text("rest-cdr"));
lf[64]=C_h_intern(&lf[64],15, C_text("consed-rest-arg"));
lf[65]=C_h_intern(&lf[65],8, C_text("captured"));
lf[66]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007C_i_car"));
lf[67]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_u_i_car"));
lf[68]=C_h_intern(&lf[68],15, C_text("##core#rest-car"));
lf[69]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007C_i_cdr"));
lf[70]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_u_i_cdr"));
lf[71]=C_h_intern(&lf[71],15, C_text("##core#rest-cdr"));
lf[72]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011C_i_nullp"));
lf[73]=C_h_intern(&lf[73],17, C_text("##core#rest-null\077"));
lf[74]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376B\000\000\012C_i_length\376\003\000\000\002\376B\000\000\014C_u_i_length\376\377\016"));
lf[75]=C_h_intern(&lf[75],18, C_text("##core#rest-length"));
lf[76]=C_h_intern(&lf[76],5, C_text("quote"));
lf[77]=C_h_intern(&lf[77],30, C_text("chicken.compiler.support#qnode"));
lf[78]=C_h_intern(&lf[78],49, C_text("chicken.compiler.support#maybe-constant-fold-call"));
lf[79]=C_h_intern(&lf[79],32, C_text("chicken.compiler.support#db-put!"));
lf[80]=C_h_intern(&lf[80],10, C_text("replacable"));
lf[81]=C_h_intern(&lf[81],5, C_text("value"));
lf[82]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035substituted constant variable"));
lf[83]=C_h_intern(&lf[83],32, C_text("chicken.compiler.support#varnode"));
lf[84]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032propagated global variable"));
lf[85]=C_h_intern(&lf[85],2, C_text("no"));
lf[86]=C_h_intern(&lf[86],38, C_text("chicken.compiler.support#variable-mark"));
lf[87]=C_h_intern(&lf[87],17, C_text("##compiler#inline"));
lf[88]=C_h_intern(&lf[88],11, C_text("collapsable"));
lf[89]=C_h_intern(&lf[89],6, C_text("global"));
lf[90]=C_h_intern(&lf[90],9, C_text("replacing"));
lf[91]=C_h_intern(&lf[91],12, C_text("contractable"));
lf[92]=C_h_intern(&lf[92],9, C_text("removable"));
lf[93]=C_h_intern(&lf[93],6, C_text("unused"));
lf[94]=C_h_intern(&lf[94],42, C_text("chicken.compiler.support#build-lambda-list"));
lf[95]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047merged explicitly consed rest parameter"));
lf[96]=C_h_intern(&lf[96],13, C_text("explicit-rest"));
lf[97]=C_decode_literal(C_heaptop,C_text("\376B\000\000 removed unused formal parameters"));
lf[98]=C_h_intern(&lf[98],27, C_text("##sys#decompose-lambda-list"));
lf[99]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047merged explicitly consed rest parameter"));
lf[100]=C_h_intern(&lf[100],21, C_text("has-unused-parameters"));
lf[101]=C_h_intern(&lf[101],20, C_text("##core#direct_lambda"));
lf[102]=C_h_intern(&lf[102],13, C_text("inline-target"));
lf[103]=C_h_intern(&lf[103],47, C_text("chicken.compiler.support#inline-lambda-bindings"));
lf[104]=C_h_intern(&lf[104],17, C_text("chicken.base#void"));
lf[105]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024contracted procedure"));
lf[106]=C_h_intern(&lf[106],1, C_text("i"));
lf[107]=C_decode_literal(C_heaptop,C_text("\376B\000\000>not contracting procedure because argument list does not match"));
lf[108]=C_h_intern(&lf[108],40, C_text("chicken.compiler.support#check-signature"));
lf[109]=C_decode_literal(C_heaptop,C_text("\376B\000\0001removed call to pure procedure with unused result"));
lf[110]=C_decode_literal(C_heaptop,C_text("\376B\000\0008not inlining procedure because it refers to contractable"));
lf[111]=C_h_intern(&lf[111],20, C_text("chicken.base#call/cc"));
lf[112]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022inlining procedure"));
lf[113]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017global inlining"));
lf[114]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010inlining"));
lf[115]=C_decode_literal(C_heaptop,C_text("\376B\000\000;not inlining procedure because argument list does not match"));
lf[116]=C_h_intern(&lf[116],19, C_text("chicken.base#gensym"));
lf[117]=C_h_intern(&lf[117],1, C_text("t"));
lf[118]=C_h_intern(&lf[118],53, C_text("chicken.compiler.support#expression-has-side-effects\077"));
lf[119]=C_decode_literal(C_heaptop,C_text("\376B\000\000+removed unused parameter to known procedure"));
lf[120]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012C_a_i_list"));
lf[121]=C_h_intern(&lf[121],22, C_text("##core#inline_allocate"));
lf[122]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042consed rest parameter at call site"));
lf[123]=C_h_intern(&lf[123],37, C_text("chicken.compiler.support#llist-length"));
lf[124]=C_decode_literal(C_heaptop,C_text("\376B\000\000(not inlining as unroll-limit is exceeded"));
lf[125]=C_h_intern(&lf[125],9, C_text("inlinable"));
lf[126]=C_h_intern(&lf[126],30, C_text("chicken.compiler.support#node\077"));
lf[127]=C_h_intern(&lf[127],24, C_text("##compiler#inline-global"));
lf[128]=C_decode_literal(C_heaptop,C_text("\376B\000\000 inlining call to intrinsic alias"));
lf[129]=C_h_intern(&lf[129],35, C_text("chicken.compiler.support#intrinsic\077"));
lf[130]=C_h_intern(&lf[130],10, C_text("references"));
lf[131]=C_h_intern(&lf[131],7, C_text("unknown"));
lf[132]=C_h_intern(&lf[132],15, C_text("##compiler#pure"));
lf[133]=C_h_intern(&lf[133],11, C_text("local-value"));
lf[134]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034removing global contractable"));
lf[135]=C_decode_literal(C_heaptop,C_text("\376B\000\0006removed side-effect free assignment to unused variable"));
lf[136]=C_h_intern(&lf[136],16, C_text("inline-transient"));
lf[137]=C_h_intern(&lf[137],42, C_text("chicken.compiler.support#variable-visible\077"));
lf[138]=C_h_intern(&lf[138],54, C_text("chicken.compiler.support#replace-rest-op-with-list-ops"));
lf[139]=C_decode_literal(C_heaptop,C_text("\376B\000\0006resetting rest op for explicitly consed rest parameter"));
lf[140]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031removed conditional forms"));
lf[141]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025removed binding forms"));
lf[142]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022replaced variables"));
lf[143]=C_h_intern(&lf[143],18, C_text("chicken.base#print"));
lf[144]=C_h_intern(&lf[144],14, C_text("scheme#newline"));
lf[145]=C_h_intern(&lf[145],19, C_text("chicken.base#print\052"));
lf[146]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004    "));
lf[147]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027  call simplifications:"));
lf[148]=C_h_intern(&lf[148],46, C_text("chicken.compiler.support#with-debugging-output"));
lf[149]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017simplifications"));
lf[150]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022traversal phase..."));
lf[151]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023Removed `not\047 forms"));
lf[152]=C_h_intern(&lf[152],49, C_text("chicken.compiler.support#node-subexpressions-set!"));
lf[153]=C_h_intern(&lf[153],45, C_text("chicken.compiler.support#node-parameters-set!"));
lf[154]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\006\001\376\377\016"));
lf[155]=C_h_intern(&lf[155],36, C_text("chicken.compiler.support#db-get-list"));
lf[156]=C_h_intern(&lf[156],3, C_text("not"));
lf[157]=C_h_intern(&lf[157],10, C_text("call-sites"));
lf[158]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031pre-optimization phase..."));
lf[160]=C_h_intern(&lf[160],34, C_text("chicken.compiler.optimizer#rewrite"));
lf[161]=C_h_intern(&lf[161],32, C_text("chicken.internal#hash-table-set!"));
lf[162]=C_h_intern(&lf[162],52, C_text("chicken.compiler.optimizer#transform-direct-lambdas!"));
lf[163]=C_h_intern(&lf[163],26, C_text("##compiler#callback-lambda"));
lf[164]=C_h_intern(&lf[164],5, C_text("boxed"));
lf[165]=C_h_intern(&lf[165],44, C_text("chicken.compiler.support#scan-used-variables"));
lf[166]=C_h_intern(&lf[166],17, C_text("##core#inline_ref"));
lf[167]=C_h_intern(&lf[167],53, C_text("chicken.compiler.support#estimate-foreign-result-size"));
lf[168]=C_h_intern(&lf[168],21, C_text("##core#inline_loc_ref"));
lf[169]=C_h_intern(&lf[169],18, C_text("##core#direct_call"));
lf[170]=C_h_intern(&lf[170],39, C_text("chicken.compiler.support#quit-compiling"));
lf[171]=C_decode_literal(C_heaptop,C_text("\376B\000\000;known procedure called with wrong number of arguments: `~A\047"));
lf[172]=C_h_intern(&lf[172],40, C_text("chicken.compiler.support#node-class-set!"));
lf[173]=C_h_intern(&lf[173],14, C_text("##core#recurse"));
lf[174]=C_h_intern(&lf[174],29, C_text("chicken.compiler.support#bomb"));
lf[175]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014missing kvar"));
lf[176]=C_h_intern(&lf[176],13, C_text("##core#return"));
lf[177]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017bad call (leaf)"));
lf[178]=C_h_intern(&lf[178],13, C_text("scheme#cdaddr"));
lf[179]=C_h_intern(&lf[179],13, C_text("scheme#caaddr"));
lf[180]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026invalid parameter list"));
lf[181]=C_decode_literal(C_heaptop,C_text("\376B\000\0006direct leaf routine with hoistable closures/allocation"));
lf[182]=C_h_intern(&lf[182],18, C_text("##sys#make-promise"));
lf[183]=C_h_intern(&lf[183],10, C_text("##sys#list"));
lf[184]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036direct leaf routine/allocation"));
lf[185]=C_decode_literal(C_heaptop,C_text("\376B\000\000(direct leaf routine optimization pass..."));
lf[186]=C_h_intern(&lf[186],54, C_text("chicken.compiler.optimizer#determine-loop-and-dispatch"));
lf[187]=C_h_intern(&lf[187],18, C_text("##sys#dynamic-wind"));
lf[188]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\006\001\376\377\016"));
lf[189]=C_h_intern(&lf[189],2, C_text("f_"));
lf[190]=C_h_intern(&lf[190],1, C_text("x"));
lf[191]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012clustering"));
lf[192]=C_h_intern(&lf[192],1, C_text("a"));
lf[193]=C_h_intern(&lf[193],10, C_text("scheme#max"));
lf[194]=C_h_intern(&lf[194],1, C_text("k"));
lf[195]=C_h_intern(&lf[195],8, C_text("dispatch"));
lf[196]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027collecting clusters ..."));
lf[197]=C_h_intern(&lf[197],18, C_text("scheme#make-vector"));
lf[198]=C_h_intern(&lf[198],3, C_text("var"));
lf[199]=C_h_intern(&lf[199],2, C_text("d2"));
lf[200]=C_h_intern(&lf[200],1, C_text("y"));
lf[201]=C_h_intern(&lf[201],2, C_text("d3"));
lf[202]=C_h_intern(&lf[202],1, C_text("z"));
lf[203]=C_h_intern(&lf[203],2, C_text("d1"));
lf[204]=C_h_intern(&lf[204],2, C_text("op"));
lf[205]=C_h_intern(&lf[205],5, C_text("clist"));
lf[206]=C_h_intern(&lf[206],4, C_text("var1"));
lf[207]=C_h_intern(&lf[207],4, C_text("var0"));
lf[208]=C_h_intern(&lf[208],6, C_text("const1"));
lf[209]=C_h_intern(&lf[209],4, C_text("var2"));
lf[210]=C_h_intern(&lf[210],6, C_text("const2"));
lf[211]=C_h_intern(&lf[211],5, C_text("body2"));
lf[212]=C_h_intern(&lf[212],4, C_text("rest"));
lf[213]=C_h_intern(&lf[213],5, C_text("body1"));
lf[214]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\001\000\000\000\002\376\377\016"));
lf[215]=C_h_intern(&lf[215],35, C_text("chicken.compiler.support#immediate\077"));
lf[216]=C_h_intern(&lf[216],5, C_text("const"));
lf[217]=C_h_intern(&lf[217],1, C_text("n"));
lf[218]=C_h_intern(&lf[218],7, C_text("clauses"));
lf[219]=C_h_intern(&lf[219],1, C_text("d"));
lf[220]=C_h_intern(&lf[220],4, C_text("body"));
lf[221]=C_h_intern(&lf[221],4, C_text("more"));
lf[222]=C_decode_literal(C_heaptop,C_text("\376B\000\000!converted assignments to bindings"));
lf[223]=C_h_intern(&lf[223],29, C_text("chicken.sort#topological-sort"));
lf[224]=C_h_intern(&lf[224],4, C_text("args"));
lf[225]=C_h_intern(&lf[225],3, C_text("op1"));
lf[226]=C_h_intern(&lf[226],5, C_text("args1"));
lf[227]=C_h_intern(&lf[227],4, C_text("kvar"));
lf[228]=C_h_intern(&lf[228],3, C_text("op2"));
lf[229]=C_h_intern(&lf[229],5, C_text("args2"));
lf[230]=C_h_intern(&lf[230],1, C_text("b"));
lf[231]=C_h_intern(&lf[231],1, C_text("c"));
lf[232]=C_h_intern(&lf[232],31, C_text("chicken.compiler.support#unsafe"));
lf[233]=C_h_intern(&lf[233],36, C_text("chicken.compiler.support#number-type"));
lf[234]=C_h_intern(&lf[234],7, C_text("generic"));
lf[235]=C_h_intern(&lf[235],6, C_text("fixnum"));
lf[236]=C_h_intern(&lf[236],37, C_text("chicken.compiler.support#fold-boolean"));
lf[237]=C_h_intern(&lf[237],6, C_text("flonum"));
lf[238]=C_h_intern(&lf[238],11, C_text("##core#proc"));
lf[239]=C_h_intern(&lf[239],19, C_text("chicken.string#conc"));
lf[240]=C_h_intern(&lf[240],2, C_text("va"));
lf[241]=C_h_intern(&lf[241],1, C_text("r"));
lf[242]=C_h_intern(&lf[242],35, C_text("chicken.compiler.support#fold-inner"));
lf[243]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023bad type (optimize)"));
lf[244]=C_h_intern(&lf[244],27, C_text("chicken.base#make-parameter"));
C_register_lf2(lf,245,create_ptable());{}
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_3389,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_library_toplevel(2,av2);}}

#ifdef C_ENABLE_PTABLES
static C_PTABLE_ENTRY ptable[830] = {
{C_text("f_10002:optimizer_2escm"),(void*)f_10002},
{C_text("f_10017:optimizer_2escm"),(void*)f_10017},
{C_text("f_10021:optimizer_2escm"),(void*)f_10021},
{C_text("f_10031:optimizer_2escm"),(void*)f_10031},
{C_text("f_10043:optimizer_2escm"),(void*)f_10043},
{C_text("f_10055:optimizer_2escm"),(void*)f_10055},
{C_text("f_10059:optimizer_2escm"),(void*)f_10059},
{C_text("f_10101:optimizer_2escm"),(void*)f_10101},
{C_text("f_10116:optimizer_2escm"),(void*)f_10116},
{C_text("f_10124:optimizer_2escm"),(void*)f_10124},
{C_text("f_10126:optimizer_2escm"),(void*)f_10126},
{C_text("f_10134:optimizer_2escm"),(void*)f_10134},
{C_text("f_10146:optimizer_2escm"),(void*)f_10146},
{C_text("f_10173:optimizer_2escm"),(void*)f_10173},
{C_text("f_10188:optimizer_2escm"),(void*)f_10188},
{C_text("f_10209:optimizer_2escm"),(void*)f_10209},
{C_text("f_10245:optimizer_2escm"),(void*)f_10245},
{C_text("f_10247:optimizer_2escm"),(void*)f_10247},
{C_text("f_10282:optimizer_2escm"),(void*)f_10282},
{C_text("f_10304:optimizer_2escm"),(void*)f_10304},
{C_text("f_10308:optimizer_2escm"),(void*)f_10308},
{C_text("f_10344:optimizer_2escm"),(void*)f_10344},
{C_text("f_10368:optimizer_2escm"),(void*)f_10368},
{C_text("f_10408:optimizer_2escm"),(void*)f_10408},
{C_text("f_10428:optimizer_2escm"),(void*)f_10428},
{C_text("f_10432:optimizer_2escm"),(void*)f_10432},
{C_text("f_10436:optimizer_2escm"),(void*)f_10436},
{C_text("f_10438:optimizer_2escm"),(void*)f_10438},
{C_text("f_10444:optimizer_2escm"),(void*)f_10444},
{C_text("f_10452:optimizer_2escm"),(void*)f_10452},
{C_text("f_10458:optimizer_2escm"),(void*)f_10458},
{C_text("f_10478:optimizer_2escm"),(void*)f_10478},
{C_text("f_10482:optimizer_2escm"),(void*)f_10482},
{C_text("f_10505:optimizer_2escm"),(void*)f_10505},
{C_text("f_10578:optimizer_2escm"),(void*)f_10578},
{C_text("f_10581:optimizer_2escm"),(void*)f_10581},
{C_text("f_10585:optimizer_2escm"),(void*)f_10585},
{C_text("f_10588:optimizer_2escm"),(void*)f_10588},
{C_text("f_10591:optimizer_2escm"),(void*)f_10591},
{C_text("f_10606:optimizer_2escm"),(void*)f_10606},
{C_text("f_10637:optimizer_2escm"),(void*)f_10637},
{C_text("f_10643:optimizer_2escm"),(void*)f_10643},
{C_text("f_10649:optimizer_2escm"),(void*)f_10649},
{C_text("f_10697:optimizer_2escm"),(void*)f_10697},
{C_text("f_10705:optimizer_2escm"),(void*)f_10705},
{C_text("f_10709:optimizer_2escm"),(void*)f_10709},
{C_text("f_10735:optimizer_2escm"),(void*)f_10735},
{C_text("f_10751:optimizer_2escm"),(void*)f_10751},
{C_text("f_10763:optimizer_2escm"),(void*)f_10763},
{C_text("f_10773:optimizer_2escm"),(void*)f_10773},
{C_text("f_10792:optimizer_2escm"),(void*)f_10792},
{C_text("f_10795:optimizer_2escm"),(void*)f_10795},
{C_text("f_10799:optimizer_2escm"),(void*)f_10799},
{C_text("f_10802:optimizer_2escm"),(void*)f_10802},
{C_text("f_10805:optimizer_2escm"),(void*)f_10805},
{C_text("f_10844:optimizer_2escm"),(void*)f_10844},
{C_text("f_10862:optimizer_2escm"),(void*)f_10862},
{C_text("f_10878:optimizer_2escm"),(void*)f_10878},
{C_text("f_10899:optimizer_2escm"),(void*)f_10899},
{C_text("f_10933:optimizer_2escm"),(void*)f_10933},
{C_text("f_10949:optimizer_2escm"),(void*)f_10949},
{C_text("f_10953:optimizer_2escm"),(void*)f_10953},
{C_text("f_10958:optimizer_2escm"),(void*)f_10958},
{C_text("f_10988:optimizer_2escm"),(void*)f_10988},
{C_text("f_10992:optimizer_2escm"),(void*)f_10992},
{C_text("f_10997:optimizer_2escm"),(void*)f_10997},
{C_text("f_11039:optimizer_2escm"),(void*)f_11039},
{C_text("f_11044:optimizer_2escm"),(void*)f_11044},
{C_text("f_11081:optimizer_2escm"),(void*)f_11081},
{C_text("f_11085:optimizer_2escm"),(void*)f_11085},
{C_text("f_11092:optimizer_2escm"),(void*)f_11092},
{C_text("f_11096:optimizer_2escm"),(void*)f_11096},
{C_text("f_11124:optimizer_2escm"),(void*)f_11124},
{C_text("f_11157:optimizer_2escm"),(void*)f_11157},
{C_text("f_11168:optimizer_2escm"),(void*)f_11168},
{C_text("f_11181:optimizer_2escm"),(void*)f_11181},
{C_text("f_11214:optimizer_2escm"),(void*)f_11214},
{C_text("f_11221:optimizer_2escm"),(void*)f_11221},
{C_text("f_11223:optimizer_2escm"),(void*)f_11223},
{C_text("f_11227:optimizer_2escm"),(void*)f_11227},
{C_text("f_11231:optimizer_2escm"),(void*)f_11231},
{C_text("f_11237:optimizer_2escm"),(void*)f_11237},
{C_text("f_11243:optimizer_2escm"),(void*)f_11243},
{C_text("f_11249:optimizer_2escm"),(void*)f_11249},
{C_text("f_11252:optimizer_2escm"),(void*)f_11252},
{C_text("f_11258:optimizer_2escm"),(void*)f_11258},
{C_text("f_11261:optimizer_2escm"),(void*)f_11261},
{C_text("f_11262:optimizer_2escm"),(void*)f_11262},
{C_text("f_11269:optimizer_2escm"),(void*)f_11269},
{C_text("f_11272:optimizer_2escm"),(void*)f_11272},
{C_text("f_11278:optimizer_2escm"),(void*)f_11278},
{C_text("f_11293:optimizer_2escm"),(void*)f_11293},
{C_text("f_11335:optimizer_2escm"),(void*)f_11335},
{C_text("f_11341:optimizer_2escm"),(void*)f_11341},
{C_text("f_11350:optimizer_2escm"),(void*)f_11350},
{C_text("f_11353:optimizer_2escm"),(void*)f_11353},
{C_text("f_11359:optimizer_2escm"),(void*)f_11359},
{C_text("f_11362:optimizer_2escm"),(void*)f_11362},
{C_text("f_11370:optimizer_2escm"),(void*)f_11370},
{C_text("f_11377:optimizer_2escm"),(void*)f_11377},
{C_text("f_11381:optimizer_2escm"),(void*)f_11381},
{C_text("f_11389:optimizer_2escm"),(void*)f_11389},
{C_text("f_11394:optimizer_2escm"),(void*)f_11394},
{C_text("f_11417:optimizer_2escm"),(void*)f_11417},
{C_text("f_11444:optimizer_2escm"),(void*)f_11444},
{C_text("f_11448:optimizer_2escm"),(void*)f_11448},
{C_text("f_11452:optimizer_2escm"),(void*)f_11452},
{C_text("f_11456:optimizer_2escm"),(void*)f_11456},
{C_text("f_11460:optimizer_2escm"),(void*)f_11460},
{C_text("f_11477:optimizer_2escm"),(void*)f_11477},
{C_text("f_11486:optimizer_2escm"),(void*)f_11486},
{C_text("f_11496:optimizer_2escm"),(void*)f_11496},
{C_text("f_11509:optimizer_2escm"),(void*)f_11509},
{C_text("f_11520:optimizer_2escm"),(void*)f_11520},
{C_text("f_11522:optimizer_2escm"),(void*)f_11522},
{C_text("f_11536:optimizer_2escm"),(void*)f_11536},
{C_text("f_11540:optimizer_2escm"),(void*)f_11540},
{C_text("f_11543:optimizer_2escm"),(void*)f_11543},
{C_text("f_11546:optimizer_2escm"),(void*)f_11546},
{C_text("f_11561:optimizer_2escm"),(void*)f_11561},
{C_text("f_11564:optimizer_2escm"),(void*)f_11564},
{C_text("f_11589:optimizer_2escm"),(void*)f_11589},
{C_text("f_11592:optimizer_2escm"),(void*)f_11592},
{C_text("f_11610:optimizer_2escm"),(void*)f_11610},
{C_text("f_11620:optimizer_2escm"),(void*)f_11620},
{C_text("f_11623:optimizer_2escm"),(void*)f_11623},
{C_text("f_11626:optimizer_2escm"),(void*)f_11626},
{C_text("f_11637:optimizer_2escm"),(void*)f_11637},
{C_text("f_11649:optimizer_2escm"),(void*)f_11649},
{C_text("f_11657:optimizer_2escm"),(void*)f_11657},
{C_text("f_11661:optimizer_2escm"),(void*)f_11661},
{C_text("f_11684:optimizer_2escm"),(void*)f_11684},
{C_text("f_11687:optimizer_2escm"),(void*)f_11687},
{C_text("f_11709:optimizer_2escm"),(void*)f_11709},
{C_text("f_11734:optimizer_2escm"),(void*)f_11734},
{C_text("f_11749:optimizer_2escm"),(void*)f_11749},
{C_text("f_11759:optimizer_2escm"),(void*)f_11759},
{C_text("f_11778:optimizer_2escm"),(void*)f_11778},
{C_text("f_11788:optimizer_2escm"),(void*)f_11788},
{C_text("f_11807:optimizer_2escm"),(void*)f_11807},
{C_text("f_11847:optimizer_2escm"),(void*)f_11847},
{C_text("f_11849:optimizer_2escm"),(void*)f_11849},
{C_text("f_11857:optimizer_2escm"),(void*)f_11857},
{C_text("f_11859:optimizer_2escm"),(void*)f_11859},
{C_text("f_11869:optimizer_2escm"),(void*)f_11869},
{C_text("f_11872:optimizer_2escm"),(void*)f_11872},
{C_text("f_11874:optimizer_2escm"),(void*)f_11874},
{C_text("f_11877:optimizer_2escm"),(void*)f_11877},
{C_text("f_11921:optimizer_2escm"),(void*)f_11921},
{C_text("f_11925:optimizer_2escm"),(void*)f_11925},
{C_text("f_11927:optimizer_2escm"),(void*)f_11927},
{C_text("f_11931:optimizer_2escm"),(void*)f_11931},
{C_text("f_11934:optimizer_2escm"),(void*)f_11934},
{C_text("f_11937:optimizer_2escm"),(void*)f_11937},
{C_text("f_11958:optimizer_2escm"),(void*)f_11958},
{C_text("f_11972:optimizer_2escm"),(void*)f_11972},
{C_text("f_11989:optimizer_2escm"),(void*)f_11989},
{C_text("f_12041:optimizer_2escm"),(void*)f_12041},
{C_text("f_12045:optimizer_2escm"),(void*)f_12045},
{C_text("f_12049:optimizer_2escm"),(void*)f_12049},
{C_text("f_12053:optimizer_2escm"),(void*)f_12053},
{C_text("f_12057:optimizer_2escm"),(void*)f_12057},
{C_text("f_12061:optimizer_2escm"),(void*)f_12061},
{C_text("f_12071:optimizer_2escm"),(void*)f_12071},
{C_text("f_12089:optimizer_2escm"),(void*)f_12089},
{C_text("f_12095:optimizer_2escm"),(void*)f_12095},
{C_text("f_12102:optimizer_2escm"),(void*)f_12102},
{C_text("f_12112:optimizer_2escm"),(void*)f_12112},
{C_text("f_12121:optimizer_2escm"),(void*)f_12121},
{C_text("f_12133:optimizer_2escm"),(void*)f_12133},
{C_text("f_12143:optimizer_2escm"),(void*)f_12143},
{C_text("f_12166:optimizer_2escm"),(void*)f_12166},
{C_text("f_12169:optimizer_2escm"),(void*)f_12169},
{C_text("f_12170:optimizer_2escm"),(void*)f_12170},
{C_text("f_12178:optimizer_2escm"),(void*)f_12178},
{C_text("f_12181:optimizer_2escm"),(void*)f_12181},
{C_text("f_12185:optimizer_2escm"),(void*)f_12185},
{C_text("f_12195:optimizer_2escm"),(void*)f_12195},
{C_text("f_12207:optimizer_2escm"),(void*)f_12207},
{C_text("f_12212:optimizer_2escm"),(void*)f_12212},
{C_text("f_12221:optimizer_2escm"),(void*)f_12221},
{C_text("f_12228:optimizer_2escm"),(void*)f_12228},
{C_text("f_12232:optimizer_2escm"),(void*)f_12232},
{C_text("f_12234:optimizer_2escm"),(void*)f_12234},
{C_text("f_12259:optimizer_2escm"),(void*)f_12259},
{C_text("f_12270:optimizer_2escm"),(void*)f_12270},
{C_text("f_12274:optimizer_2escm"),(void*)f_12274},
{C_text("f_12280:optimizer_2escm"),(void*)f_12280},
{C_text("f_12283:optimizer_2escm"),(void*)f_12283},
{C_text("f_12286:optimizer_2escm"),(void*)f_12286},
{C_text("f_12289:optimizer_2escm"),(void*)f_12289},
{C_text("f_12292:optimizer_2escm"),(void*)f_12292},
{C_text("f_12295:optimizer_2escm"),(void*)f_12295},
{C_text("f_12296:optimizer_2escm"),(void*)f_12296},
{C_text("f_12300:optimizer_2escm"),(void*)f_12300},
{C_text("f_12301:optimizer_2escm"),(void*)f_12301},
{C_text("f_12315:optimizer_2escm"),(void*)f_12315},
{C_text("f_12319:optimizer_2escm"),(void*)f_12319},
{C_text("f_12323:optimizer_2escm"),(void*)f_12323},
{C_text("f_12327:optimizer_2escm"),(void*)f_12327},
{C_text("f_12331:optimizer_2escm"),(void*)f_12331},
{C_text("f_12335:optimizer_2escm"),(void*)f_12335},
{C_text("f_12343:optimizer_2escm"),(void*)f_12343},
{C_text("f_12353:optimizer_2escm"),(void*)f_12353},
{C_text("f_12365:optimizer_2escm"),(void*)f_12365},
{C_text("f_12373:optimizer_2escm"),(void*)f_12373},
{C_text("f_12383:optimizer_2escm"),(void*)f_12383},
{C_text("f_12403:optimizer_2escm"),(void*)f_12403},
{C_text("f_12413:optimizer_2escm"),(void*)f_12413},
{C_text("f_12426:optimizer_2escm"),(void*)f_12426},
{C_text("f_12436:optimizer_2escm"),(void*)f_12436},
{C_text("f_12446:optimizer_2escm"),(void*)f_12446},
{C_text("f_12458:optimizer_2escm"),(void*)f_12458},
{C_text("f_12462:optimizer_2escm"),(void*)f_12462},
{C_text("f_12474:optimizer_2escm"),(void*)f_12474},
{C_text("f_12478:optimizer_2escm"),(void*)f_12478},
{C_text("f_12482:optimizer_2escm"),(void*)f_12482},
{C_text("f_12486:optimizer_2escm"),(void*)f_12486},
{C_text("f_12490:optimizer_2escm"),(void*)f_12490},
{C_text("f_12494:optimizer_2escm"),(void*)f_12494},
{C_text("f_12502:optimizer_2escm"),(void*)f_12502},
{C_text("f_12504:optimizer_2escm"),(void*)f_12504},
{C_text("f_12520:optimizer_2escm"),(void*)f_12520},
{C_text("f_12532:optimizer_2escm"),(void*)f_12532},
{C_text("f_12540:optimizer_2escm"),(void*)f_12540},
{C_text("f_12548:optimizer_2escm"),(void*)f_12548},
{C_text("f_12556:optimizer_2escm"),(void*)f_12556},
{C_text("f_12558:optimizer_2escm"),(void*)f_12558},
{C_text("f_12566:optimizer_2escm"),(void*)f_12566},
{C_text("f_12570:optimizer_2escm"),(void*)f_12570},
{C_text("f_12576:optimizer_2escm"),(void*)f_12576},
{C_text("f_12601:optimizer_2escm"),(void*)f_12601},
{C_text("f_12605:optimizer_2escm"),(void*)f_12605},
{C_text("f_12625:optimizer_2escm"),(void*)f_12625},
{C_text("f_12631:optimizer_2escm"),(void*)f_12631},
{C_text("f_12635:optimizer_2escm"),(void*)f_12635},
{C_text("f_12648:optimizer_2escm"),(void*)f_12648},
{C_text("f_12652:optimizer_2escm"),(void*)f_12652},
{C_text("f_12656:optimizer_2escm"),(void*)f_12656},
{C_text("f_12660:optimizer_2escm"),(void*)f_12660},
{C_text("f_12667:optimizer_2escm"),(void*)f_12667},
{C_text("f_12669:optimizer_2escm"),(void*)f_12669},
{C_text("f_12705:optimizer_2escm"),(void*)f_12705},
{C_text("f_12711:optimizer_2escm"),(void*)f_12711},
{C_text("f_12734:optimizer_2escm"),(void*)f_12734},
{C_text("f_12736:optimizer_2escm"),(void*)f_12736},
{C_text("f_12770:optimizer_2escm"),(void*)f_12770},
{C_text("f_12795:optimizer_2escm"),(void*)f_12795},
{C_text("f_12808:optimizer_2escm"),(void*)f_12808},
{C_text("f_12817:optimizer_2escm"),(void*)f_12817},
{C_text("f_12827:optimizer_2escm"),(void*)f_12827},
{C_text("f_12856:optimizer_2escm"),(void*)f_12856},
{C_text("f_12878:optimizer_2escm"),(void*)f_12878},
{C_text("f_12896:optimizer_2escm"),(void*)f_12896},
{C_text("f_12904:optimizer_2escm"),(void*)f_12904},
{C_text("f_12906:optimizer_2escm"),(void*)f_12906},
{C_text("f_12914:optimizer_2escm"),(void*)f_12914},
{C_text("f_12926:optimizer_2escm"),(void*)f_12926},
{C_text("f_12930:optimizer_2escm"),(void*)f_12930},
{C_text("f_12938:optimizer_2escm"),(void*)f_12938},
{C_text("f_12942:optimizer_2escm"),(void*)f_12942},
{C_text("f_12953:optimizer_2escm"),(void*)f_12953},
{C_text("f_12972:optimizer_2escm"),(void*)f_12972},
{C_text("f_12976:optimizer_2escm"),(void*)f_12976},
{C_text("f_13002:optimizer_2escm"),(void*)f_13002},
{C_text("f_13017:optimizer_2escm"),(void*)f_13017},
{C_text("f_13021:optimizer_2escm"),(void*)f_13021},
{C_text("f_13083:optimizer_2escm"),(void*)f_13083},
{C_text("f_13098:optimizer_2escm"),(void*)f_13098},
{C_text("f_13115:optimizer_2escm"),(void*)f_13115},
{C_text("f_13121:optimizer_2escm"),(void*)f_13121},
{C_text("f_13134:optimizer_2escm"),(void*)f_13134},
{C_text("f_13163:optimizer_2escm"),(void*)f_13163},
{C_text("f_13169:optimizer_2escm"),(void*)f_13169},
{C_text("f_13182:optimizer_2escm"),(void*)f_13182},
{C_text("f_13216:optimizer_2escm"),(void*)f_13216},
{C_text("f_13243:optimizer_2escm"),(void*)f_13243},
{C_text("f_13264:optimizer_2escm"),(void*)f_13264},
{C_text("f_13268:optimizer_2escm"),(void*)f_13268},
{C_text("f_13276:optimizer_2escm"),(void*)f_13276},
{C_text("f_13282:optimizer_2escm"),(void*)f_13282},
{C_text("f_13295:optimizer_2escm"),(void*)f_13295},
{C_text("f_13324:optimizer_2escm"),(void*)f_13324},
{C_text("f_13330:optimizer_2escm"),(void*)f_13330},
{C_text("f_13343:optimizer_2escm"),(void*)f_13343},
{C_text("f_13347:optimizer_2escm"),(void*)f_13347},
{C_text("f_13401:optimizer_2escm"),(void*)f_13401},
{C_text("f_13425:optimizer_2escm"),(void*)f_13425},
{C_text("f_13438:optimizer_2escm"),(void*)f_13438},
{C_text("f_13446:optimizer_2escm"),(void*)f_13446},
{C_text("f_13484:optimizer_2escm"),(void*)f_13484},
{C_text("f_13494:optimizer_2escm"),(void*)f_13494},
{C_text("f_13498:optimizer_2escm"),(void*)f_13498},
{C_text("f_13501:optimizer_2escm"),(void*)f_13501},
{C_text("f_13504:optimizer_2escm"),(void*)f_13504},
{C_text("f_13534:optimizer_2escm"),(void*)f_13534},
{C_text("f_13537:optimizer_2escm"),(void*)f_13537},
{C_text("f_13540:optimizer_2escm"),(void*)f_13540},
{C_text("f_13570:optimizer_2escm"),(void*)f_13570},
{C_text("f_13597:optimizer_2escm"),(void*)f_13597},
{C_text("f_13601:optimizer_2escm"),(void*)f_13601},
{C_text("f_13604:optimizer_2escm"),(void*)f_13604},
{C_text("f_13607:optimizer_2escm"),(void*)f_13607},
{C_text("f_13613:optimizer_2escm"),(void*)f_13613},
{C_text("f_13636:optimizer_2escm"),(void*)f_13636},
{C_text("f_13651:optimizer_2escm"),(void*)f_13651},
{C_text("f_13659:optimizer_2escm"),(void*)f_13659},
{C_text("f_13661:optimizer_2escm"),(void*)f_13661},
{C_text("f_13711:optimizer_2escm"),(void*)f_13711},
{C_text("f_13719:optimizer_2escm"),(void*)f_13719},
{C_text("f_13727:optimizer_2escm"),(void*)f_13727},
{C_text("f_13735:optimizer_2escm"),(void*)f_13735},
{C_text("f_13763:optimizer_2escm"),(void*)f_13763},
{C_text("f_13771:optimizer_2escm"),(void*)f_13771},
{C_text("f_13797:optimizer_2escm"),(void*)f_13797},
{C_text("f_13810:optimizer_2escm"),(void*)f_13810},
{C_text("f_13827:optimizer_2escm"),(void*)f_13827},
{C_text("f_13831:optimizer_2escm"),(void*)f_13831},
{C_text("f_13835:optimizer_2escm"),(void*)f_13835},
{C_text("f_13846:optimizer_2escm"),(void*)f_13846},
{C_text("f_13850:optimizer_2escm"),(void*)f_13850},
{C_text("f_13924:optimizer_2escm"),(void*)f_13924},
{C_text("f_13937:optimizer_2escm"),(void*)f_13937},
{C_text("f_13943:optimizer_2escm"),(void*)f_13943},
{C_text("f_13966:optimizer_2escm"),(void*)f_13966},
{C_text("f_13970:optimizer_2escm"),(void*)f_13970},
{C_text("f_13974:optimizer_2escm"),(void*)f_13974},
{C_text("f_13983:optimizer_2escm"),(void*)f_13983},
{C_text("f_13992:optimizer_2escm"),(void*)f_13992},
{C_text("f_13996:optimizer_2escm"),(void*)f_13996},
{C_text("f_14094:optimizer_2escm"),(void*)f_14094},
{C_text("f_14102:optimizer_2escm"),(void*)f_14102},
{C_text("f_14107:optimizer_2escm"),(void*)f_14107},
{C_text("f_14117:optimizer_2escm"),(void*)f_14117},
{C_text("f_14121:optimizer_2escm"),(void*)f_14121},
{C_text("f_3389:optimizer_2escm"),(void*)f_3389},
{C_text("f_3392:optimizer_2escm"),(void*)f_3392},
{C_text("f_3395:optimizer_2escm"),(void*)f_3395},
{C_text("f_3398:optimizer_2escm"),(void*)f_3398},
{C_text("f_3401:optimizer_2escm"),(void*)f_3401},
{C_text("f_3409:optimizer_2escm"),(void*)f_3409},
{C_text("f_3423:optimizer_2escm"),(void*)f_3423},
{C_text("f_3427:optimizer_2escm"),(void*)f_3427},
{C_text("f_3433:optimizer_2escm"),(void*)f_3433},
{C_text("f_3511:optimizer_2escm"),(void*)f_3511},
{C_text("f_3529:optimizer_2escm"),(void*)f_3529},
{C_text("f_3563:optimizer_2escm"),(void*)f_3563},
{C_text("f_3569:optimizer_2escm"),(void*)f_3569},
{C_text("f_3583:optimizer_2escm"),(void*)f_3583},
{C_text("f_3602:optimizer_2escm"),(void*)f_3602},
{C_text("f_3617:optimizer_2escm"),(void*)f_3617},
{C_text("f_3625:optimizer_2escm"),(void*)f_3625},
{C_text("f_3633:optimizer_2escm"),(void*)f_3633},
{C_text("f_3644:optimizer_2escm"),(void*)f_3644},
{C_text("f_3657:optimizer_2escm"),(void*)f_3657},
{C_text("f_3664:optimizer_2escm"),(void*)f_3664},
{C_text("f_3671:optimizer_2escm"),(void*)f_3671},
{C_text("f_3675:optimizer_2escm"),(void*)f_3675},
{C_text("f_3687:optimizer_2escm"),(void*)f_3687},
{C_text("f_3689:optimizer_2escm"),(void*)f_3689},
{C_text("f_3736:optimizer_2escm"),(void*)f_3736},
{C_text("f_3738:optimizer_2escm"),(void*)f_3738},
{C_text("f_3772:optimizer_2escm"),(void*)f_3772},
{C_text("f_3778:optimizer_2escm"),(void*)f_3778},
{C_text("f_3800:optimizer_2escm"),(void*)f_3800},
{C_text("f_3806:optimizer_2escm"),(void*)f_3806},
{C_text("f_3812:optimizer_2escm"),(void*)f_3812},
{C_text("f_3822:optimizer_2escm"),(void*)f_3822},
{C_text("f_3836:optimizer_2escm"),(void*)f_3836},
{C_text("f_3842:optimizer_2escm"),(void*)f_3842},
{C_text("f_3856:optimizer_2escm"),(void*)f_3856},
{C_text("f_3892:optimizer_2escm"),(void*)f_3892},
{C_text("f_3898:optimizer_2escm"),(void*)f_3898},
{C_text("f_3911:optimizer_2escm"),(void*)f_3911},
{C_text("f_3925:optimizer_2escm"),(void*)f_3925},
{C_text("f_3933:optimizer_2escm"),(void*)f_3933},
{C_text("f_3973:optimizer_2escm"),(void*)f_3973},
{C_text("f_3987:optimizer_2escm"),(void*)f_3987},
{C_text("f_4000:optimizer_2escm"),(void*)f_4000},
{C_text("f_4012:optimizer_2escm"),(void*)f_4012},
{C_text("f_4021:optimizer_2escm"),(void*)f_4021},
{C_text("f_4029:optimizer_2escm"),(void*)f_4029},
{C_text("f_4036:optimizer_2escm"),(void*)f_4036},
{C_text("f_4050:optimizer_2escm"),(void*)f_4050},
{C_text("f_4065:optimizer_2escm"),(void*)f_4065},
{C_text("f_4073:optimizer_2escm"),(void*)f_4073},
{C_text("f_4077:optimizer_2escm"),(void*)f_4077},
{C_text("f_4081:optimizer_2escm"),(void*)f_4081},
{C_text("f_4099:optimizer_2escm"),(void*)f_4099},
{C_text("f_4138:optimizer_2escm"),(void*)f_4138},
{C_text("f_4178:optimizer_2escm"),(void*)f_4178},
{C_text("f_4237:optimizer_2escm"),(void*)f_4237},
{C_text("f_4414:optimizer_2escm"),(void*)f_4414},
{C_text("f_4420:optimizer_2escm"),(void*)f_4420},
{C_text("f_4434:optimizer_2escm"),(void*)f_4434},
{C_text("f_4438:optimizer_2escm"),(void*)f_4438},
{C_text("f_4450:optimizer_2escm"),(void*)f_4450},
{C_text("f_4468:optimizer_2escm"),(void*)f_4468},
{C_text("f_4683:optimizer_2escm"),(void*)f_4683},
{C_text("f_4687:optimizer_2escm"),(void*)f_4687},
{C_text("f_4691:optimizer_2escm"),(void*)f_4691},
{C_text("f_4695:optimizer_2escm"),(void*)f_4695},
{C_text("f_4697:optimizer_2escm"),(void*)f_4697},
{C_text("f_4700:optimizer_2escm"),(void*)f_4700},
{C_text("f_4723:optimizer_2escm"),(void*)f_4723},
{C_text("f_4728:optimizer_2escm"),(void*)f_4728},
{C_text("f_4730:optimizer_2escm"),(void*)f_4730},
{C_text("f_4735:optimizer_2escm"),(void*)f_4735},
{C_text("f_4737:optimizer_2escm"),(void*)f_4737},
{C_text("f_4753:optimizer_2escm"),(void*)f_4753},
{C_text("f_4763:optimizer_2escm"),(void*)f_4763},
{C_text("f_4776:optimizer_2escm"),(void*)f_4776},
{C_text("f_4780:optimizer_2escm"),(void*)f_4780},
{C_text("f_4783:optimizer_2escm"),(void*)f_4783},
{C_text("f_4786:optimizer_2escm"),(void*)f_4786},
{C_text("f_4798:optimizer_2escm"),(void*)f_4798},
{C_text("f_4802:optimizer_2escm"),(void*)f_4802},
{C_text("f_4804:optimizer_2escm"),(void*)f_4804},
{C_text("f_4846:optimizer_2escm"),(void*)f_4846},
{C_text("f_4849:optimizer_2escm"),(void*)f_4849},
{C_text("f_4872:optimizer_2escm"),(void*)f_4872},
{C_text("f_4883:optimizer_2escm"),(void*)f_4883},
{C_text("f_4887:optimizer_2escm"),(void*)f_4887},
{C_text("f_4920:optimizer_2escm"),(void*)f_4920},
{C_text("f_4923:optimizer_2escm"),(void*)f_4923},
{C_text("f_4926:optimizer_2escm"),(void*)f_4926},
{C_text("f_4944:optimizer_2escm"),(void*)f_4944},
{C_text("f_4951:optimizer_2escm"),(void*)f_4951},
{C_text("f_4994:optimizer_2escm"),(void*)f_4994},
{C_text("f_4997:optimizer_2escm"),(void*)f_4997},
{C_text("f_5000:optimizer_2escm"),(void*)f_5000},
{C_text("f_5013:optimizer_2escm"),(void*)f_5013},
{C_text("f_5023:optimizer_2escm"),(void*)f_5023},
{C_text("f_5044:optimizer_2escm"),(void*)f_5044},
{C_text("f_5048:optimizer_2escm"),(void*)f_5048},
{C_text("f_5053:optimizer_2escm"),(void*)f_5053},
{C_text("f_5056:optimizer_2escm"),(void*)f_5056},
{C_text("f_5070:optimizer_2escm"),(void*)f_5070},
{C_text("f_5080:optimizer_2escm"),(void*)f_5080},
{C_text("f_5082:optimizer_2escm"),(void*)f_5082},
{C_text("f_5086:optimizer_2escm"),(void*)f_5086},
{C_text("f_5100:optimizer_2escm"),(void*)f_5100},
{C_text("f_5123:optimizer_2escm"),(void*)f_5123},
{C_text("f_5127:optimizer_2escm"),(void*)f_5127},
{C_text("f_5130:optimizer_2escm"),(void*)f_5130},
{C_text("f_5138:optimizer_2escm"),(void*)f_5138},
{C_text("f_5148:optimizer_2escm"),(void*)f_5148},
{C_text("f_5154:optimizer_2escm"),(void*)f_5154},
{C_text("f_5193:optimizer_2escm"),(void*)f_5193},
{C_text("f_5207:optimizer_2escm"),(void*)f_5207},
{C_text("f_5209:optimizer_2escm"),(void*)f_5209},
{C_text("f_5249:optimizer_2escm"),(void*)f_5249},
{C_text("f_5251:optimizer_2escm"),(void*)f_5251},
{C_text("f_5258:optimizer_2escm"),(void*)f_5258},
{C_text("f_5270:optimizer_2escm"),(void*)f_5270},
{C_text("f_5306:optimizer_2escm"),(void*)f_5306},
{C_text("f_5328:optimizer_2escm"),(void*)f_5328},
{C_text("f_5338:optimizer_2escm"),(void*)f_5338},
{C_text("f_5350:optimizer_2escm"),(void*)f_5350},
{C_text("f_5354:optimizer_2escm"),(void*)f_5354},
{C_text("f_5358:optimizer_2escm"),(void*)f_5358},
{C_text("f_5362:optimizer_2escm"),(void*)f_5362},
{C_text("f_5366:optimizer_2escm"),(void*)f_5366},
{C_text("f_5370:optimizer_2escm"),(void*)f_5370},
{C_text("f_5374:optimizer_2escm"),(void*)f_5374},
{C_text("f_5378:optimizer_2escm"),(void*)f_5378},
{C_text("f_5382:optimizer_2escm"),(void*)f_5382},
{C_text("f_5407:optimizer_2escm"),(void*)f_5407},
{C_text("f_5411:optimizer_2escm"),(void*)f_5411},
{C_text("f_5413:optimizer_2escm"),(void*)f_5413},
{C_text("f_5427:optimizer_2escm"),(void*)f_5427},
{C_text("f_5430:optimizer_2escm"),(void*)f_5430},
{C_text("f_5433:optimizer_2escm"),(void*)f_5433},
{C_text("f_5436:optimizer_2escm"),(void*)f_5436},
{C_text("f_5496:optimizer_2escm"),(void*)f_5496},
{C_text("f_5509:optimizer_2escm"),(void*)f_5509},
{C_text("f_5513:optimizer_2escm"),(void*)f_5513},
{C_text("f_5520:optimizer_2escm"),(void*)f_5520},
{C_text("f_5551:optimizer_2escm"),(void*)f_5551},
{C_text("f_5555:optimizer_2escm"),(void*)f_5555},
{C_text("f_5559:optimizer_2escm"),(void*)f_5559},
{C_text("f_5563:optimizer_2escm"),(void*)f_5563},
{C_text("f_5566:optimizer_2escm"),(void*)f_5566},
{C_text("f_5571:optimizer_2escm"),(void*)f_5571},
{C_text("f_5575:optimizer_2escm"),(void*)f_5575},
{C_text("f_5578:optimizer_2escm"),(void*)f_5578},
{C_text("f_5581:optimizer_2escm"),(void*)f_5581},
{C_text("f_5590:optimizer_2escm"),(void*)f_5590},
{C_text("f_5596:optimizer_2escm"),(void*)f_5596},
{C_text("f_5602:optimizer_2escm"),(void*)f_5602},
{C_text("f_5613:optimizer_2escm"),(void*)f_5613},
{C_text("f_5617:optimizer_2escm"),(void*)f_5617},
{C_text("f_5640:optimizer_2escm"),(void*)f_5640},
{C_text("f_5650:optimizer_2escm"),(void*)f_5650},
{C_text("f_5653:optimizer_2escm"),(void*)f_5653},
{C_text("f_5670:optimizer_2escm"),(void*)f_5670},
{C_text("f_5703:optimizer_2escm"),(void*)f_5703},
{C_text("f_5706:optimizer_2escm"),(void*)f_5706},
{C_text("f_5721:optimizer_2escm"),(void*)f_5721},
{C_text("f_5729:optimizer_2escm"),(void*)f_5729},
{C_text("f_5739:optimizer_2escm"),(void*)f_5739},
{C_text("f_5741:optimizer_2escm"),(void*)f_5741},
{C_text("f_5766:optimizer_2escm"),(void*)f_5766},
{C_text("f_5776:optimizer_2escm"),(void*)f_5776},
{C_text("f_5787:optimizer_2escm"),(void*)f_5787},
{C_text("f_5805:optimizer_2escm"),(void*)f_5805},
{C_text("f_5813:optimizer_2escm"),(void*)f_5813},
{C_text("f_5823:optimizer_2escm"),(void*)f_5823},
{C_text("f_5830:optimizer_2escm"),(void*)f_5830},
{C_text("f_5848:optimizer_2escm"),(void*)f_5848},
{C_text("f_5853:optimizer_2escm"),(void*)f_5853},
{C_text("f_5859:optimizer_2escm"),(void*)f_5859},
{C_text("f_5865:optimizer_2escm"),(void*)f_5865},
{C_text("f_5871:optimizer_2escm"),(void*)f_5871},
{C_text("f_5878:optimizer_2escm"),(void*)f_5878},
{C_text("f_5893:optimizer_2escm"),(void*)f_5893},
{C_text("f_5913:optimizer_2escm"),(void*)f_5913},
{C_text("f_5920:optimizer_2escm"),(void*)f_5920},
{C_text("f_5923:optimizer_2escm"),(void*)f_5923},
{C_text("f_5940:optimizer_2escm"),(void*)f_5940},
{C_text("f_5945:optimizer_2escm"),(void*)f_5945},
{C_text("f_5952:optimizer_2escm"),(void*)f_5952},
{C_text("f_5967:optimizer_2escm"),(void*)f_5967},
{C_text("f_5987:optimizer_2escm"),(void*)f_5987},
{C_text("f_6021:optimizer_2escm"),(void*)f_6021},
{C_text("f_6033:optimizer_2escm"),(void*)f_6033},
{C_text("f_6036:optimizer_2escm"),(void*)f_6036},
{C_text("f_6043:optimizer_2escm"),(void*)f_6043},
{C_text("f_6046:optimizer_2escm"),(void*)f_6046},
{C_text("f_6055:optimizer_2escm"),(void*)f_6055},
{C_text("f_6058:optimizer_2escm"),(void*)f_6058},
{C_text("f_6062:optimizer_2escm"),(void*)f_6062},
{C_text("f_6072:optimizer_2escm"),(void*)f_6072},
{C_text("f_6079:optimizer_2escm"),(void*)f_6079},
{C_text("f_6087:optimizer_2escm"),(void*)f_6087},
{C_text("f_6089:optimizer_2escm"),(void*)f_6089},
{C_text("f_6099:optimizer_2escm"),(void*)f_6099},
{C_text("f_6113:optimizer_2escm"),(void*)f_6113},
{C_text("f_6122:optimizer_2escm"),(void*)f_6122},
{C_text("f_6125:optimizer_2escm"),(void*)f_6125},
{C_text("f_6128:optimizer_2escm"),(void*)f_6128},
{C_text("f_6147:optimizer_2escm"),(void*)f_6147},
{C_text("f_6153:optimizer_2escm"),(void*)f_6153},
{C_text("f_6156:optimizer_2escm"),(void*)f_6156},
{C_text("f_6164:optimizer_2escm"),(void*)f_6164},
{C_text("f_6171:optimizer_2escm"),(void*)f_6171},
{C_text("f_6177:optimizer_2escm"),(void*)f_6177},
{C_text("f_6183:optimizer_2escm"),(void*)f_6183},
{C_text("f_6186:optimizer_2escm"),(void*)f_6186},
{C_text("f_6187:optimizer_2escm"),(void*)f_6187},
{C_text("f_6197:optimizer_2escm"),(void*)f_6197},
{C_text("f_6200:optimizer_2escm"),(void*)f_6200},
{C_text("f_6205:optimizer_2escm"),(void*)f_6205},
{C_text("f_6208:optimizer_2escm"),(void*)f_6208},
{C_text("f_6212:optimizer_2escm"),(void*)f_6212},
{C_text("f_6219:optimizer_2escm"),(void*)f_6219},
{C_text("f_6222:optimizer_2escm"),(void*)f_6222},
{C_text("f_6244:optimizer_2escm"),(void*)f_6244},
{C_text("f_6246:optimizer_2escm"),(void*)f_6246},
{C_text("f_6256:optimizer_2escm"),(void*)f_6256},
{C_text("f_6278:optimizer_2escm"),(void*)f_6278},
{C_text("f_6287:optimizer_2escm"),(void*)f_6287},
{C_text("f_6301:optimizer_2escm"),(void*)f_6301},
{C_text("f_6318:optimizer_2escm"),(void*)f_6318},
{C_text("f_6328:optimizer_2escm"),(void*)f_6328},
{C_text("f_6331:optimizer_2escm"),(void*)f_6331},
{C_text("f_6336:optimizer_2escm"),(void*)f_6336},
{C_text("f_6361:optimizer_2escm"),(void*)f_6361},
{C_text("f_6372:optimizer_2escm"),(void*)f_6372},
{C_text("f_6376:optimizer_2escm"),(void*)f_6376},
{C_text("f_6382:optimizer_2escm"),(void*)f_6382},
{C_text("f_6388:optimizer_2escm"),(void*)f_6388},
{C_text("f_6394:optimizer_2escm"),(void*)f_6394},
{C_text("f_6409:optimizer_2escm"),(void*)f_6409},
{C_text("f_6413:optimizer_2escm"),(void*)f_6413},
{C_text("f_6425:optimizer_2escm"),(void*)f_6425},
{C_text("f_6475:optimizer_2escm"),(void*)f_6475},
{C_text("f_6487:optimizer_2escm"),(void*)f_6487},
{C_text("f_6492:optimizer_2escm"),(void*)f_6492},
{C_text("f_6498:optimizer_2escm"),(void*)f_6498},
{C_text("f_6502:optimizer_2escm"),(void*)f_6502},
{C_text("f_6509:optimizer_2escm"),(void*)f_6509},
{C_text("f_6514:optimizer_2escm"),(void*)f_6514},
{C_text("f_6524:optimizer_2escm"),(void*)f_6524},
{C_text("f_6526:optimizer_2escm"),(void*)f_6526},
{C_text("f_6551:optimizer_2escm"),(void*)f_6551},
{C_text("f_6562:optimizer_2escm"),(void*)f_6562},
{C_text("f_6570:optimizer_2escm"),(void*)f_6570},
{C_text("f_6599:optimizer_2escm"),(void*)f_6599},
{C_text("f_6612:optimizer_2escm"),(void*)f_6612},
{C_text("f_6630:optimizer_2escm"),(void*)f_6630},
{C_text("f_6636:optimizer_2escm"),(void*)f_6636},
{C_text("f_6642:optimizer_2escm"),(void*)f_6642},
{C_text("f_6667:optimizer_2escm"),(void*)f_6667},
{C_text("f_6671:optimizer_2escm"),(void*)f_6671},
{C_text("f_6675:optimizer_2escm"),(void*)f_6675},
{C_text("f_6681:optimizer_2escm"),(void*)f_6681},
{C_text("f_6684:optimizer_2escm"),(void*)f_6684},
{C_text("f_6691:optimizer_2escm"),(void*)f_6691},
{C_text("f_6705:optimizer_2escm"),(void*)f_6705},
{C_text("f_6725:optimizer_2escm"),(void*)f_6725},
{C_text("f_6729:optimizer_2escm"),(void*)f_6729},
{C_text("f_6736:optimizer_2escm"),(void*)f_6736},
{C_text("f_6751:optimizer_2escm"),(void*)f_6751},
{C_text("f_6769:optimizer_2escm"),(void*)f_6769},
{C_text("f_6772:optimizer_2escm"),(void*)f_6772},
{C_text("f_6782:optimizer_2escm"),(void*)f_6782},
{C_text("f_6784:optimizer_2escm"),(void*)f_6784},
{C_text("f_6803:optimizer_2escm"),(void*)f_6803},
{C_text("f_6809:optimizer_2escm"),(void*)f_6809},
{C_text("f_6819:optimizer_2escm"),(void*)f_6819},
{C_text("f_6823:optimizer_2escm"),(void*)f_6823},
{C_text("f_6833:optimizer_2escm"),(void*)f_6833},
{C_text("f_6837:optimizer_2escm"),(void*)f_6837},
{C_text("f_6843:optimizer_2escm"),(void*)f_6843},
{C_text("f_6850:optimizer_2escm"),(void*)f_6850},
{C_text("f_6863:optimizer_2escm"),(void*)f_6863},
{C_text("f_6871:optimizer_2escm"),(void*)f_6871},
{C_text("f_6875:optimizer_2escm"),(void*)f_6875},
{C_text("f_6881:optimizer_2escm"),(void*)f_6881},
{C_text("f_6891:optimizer_2escm"),(void*)f_6891},
{C_text("f_6895:optimizer_2escm"),(void*)f_6895},
{C_text("f_6913:optimizer_2escm"),(void*)f_6913},
{C_text("f_6916:optimizer_2escm"),(void*)f_6916},
{C_text("f_6925:optimizer_2escm"),(void*)f_6925},
{C_text("f_6932:optimizer_2escm"),(void*)f_6932},
{C_text("f_6934:optimizer_2escm"),(void*)f_6934},
{C_text("f_6959:optimizer_2escm"),(void*)f_6959},
{C_text("f_6992:optimizer_2escm"),(void*)f_6992},
{C_text("f_6998:optimizer_2escm"),(void*)f_6998},
{C_text("f_7004:optimizer_2escm"),(void*)f_7004},
{C_text("f_7013:optimizer_2escm"),(void*)f_7013},
{C_text("f_7025:optimizer_2escm"),(void*)f_7025},
{C_text("f_7031:optimizer_2escm"),(void*)f_7031},
{C_text("f_7037:optimizer_2escm"),(void*)f_7037},
{C_text("f_7046:optimizer_2escm"),(void*)f_7046},
{C_text("f_7048:optimizer_2escm"),(void*)f_7048},
{C_text("f_7058:optimizer_2escm"),(void*)f_7058},
{C_text("f_7072:optimizer_2escm"),(void*)f_7072},
{C_text("f_7073:optimizer_2escm"),(void*)f_7073},
{C_text("f_7090:optimizer_2escm"),(void*)f_7090},
{C_text("f_7114:optimizer_2escm"),(void*)f_7114},
{C_text("f_7124:optimizer_2escm"),(void*)f_7124},
{C_text("f_7143:optimizer_2escm"),(void*)f_7143},
{C_text("f_7151:optimizer_2escm"),(void*)f_7151},
{C_text("f_7155:optimizer_2escm"),(void*)f_7155},
{C_text("f_7162:optimizer_2escm"),(void*)f_7162},
{C_text("f_7166:optimizer_2escm"),(void*)f_7166},
{C_text("f_7175:optimizer_2escm"),(void*)f_7175},
{C_text("f_7184:optimizer_2escm"),(void*)f_7184},
{C_text("f_7190:optimizer_2escm"),(void*)f_7190},
{C_text("f_7197:optimizer_2escm"),(void*)f_7197},
{C_text("f_7240:optimizer_2escm"),(void*)f_7240},
{C_text("f_7246:optimizer_2escm"),(void*)f_7246},
{C_text("f_7256:optimizer_2escm"),(void*)f_7256},
{C_text("f_7266:optimizer_2escm"),(void*)f_7266},
{C_text("f_7272:optimizer_2escm"),(void*)f_7272},
{C_text("f_7300:optimizer_2escm"),(void*)f_7300},
{C_text("f_7306:optimizer_2escm"),(void*)f_7306},
{C_text("f_7310:optimizer_2escm"),(void*)f_7310},
{C_text("f_7313:optimizer_2escm"),(void*)f_7313},
{C_text("f_7316:optimizer_2escm"),(void*)f_7316},
{C_text("f_7319:optimizer_2escm"),(void*)f_7319},
{C_text("f_7322:optimizer_2escm"),(void*)f_7322},
{C_text("f_7325:optimizer_2escm"),(void*)f_7325},
{C_text("f_7354:optimizer_2escm"),(void*)f_7354},
{C_text("f_7358:optimizer_2escm"),(void*)f_7358},
{C_text("f_7363:optimizer_2escm"),(void*)f_7363},
{C_text("f_7391:optimizer_2escm"),(void*)f_7391},
{C_text("f_7401:optimizer_2escm"),(void*)f_7401},
{C_text("f_7429:optimizer_2escm"),(void*)f_7429},
{C_text("f_7469:optimizer_2escm"),(void*)f_7469},
{C_text("f_7473:optimizer_2escm"),(void*)f_7473},
{C_text("f_7480:optimizer_2escm"),(void*)f_7480},
{C_text("f_7483:optimizer_2escm"),(void*)f_7483},
{C_text("f_7486:optimizer_2escm"),(void*)f_7486},
{C_text("f_7495:optimizer_2escm"),(void*)f_7495},
{C_text("f_7496:optimizer_2escm"),(void*)f_7496},
{C_text("f_7503:optimizer_2escm"),(void*)f_7503},
{C_text("f_7509:optimizer_2escm"),(void*)f_7509},
{C_text("f_7512:optimizer_2escm"),(void*)f_7512},
{C_text("f_7518:optimizer_2escm"),(void*)f_7518},
{C_text("f_7527:optimizer_2escm"),(void*)f_7527},
{C_text("f_7539:optimizer_2escm"),(void*)f_7539},
{C_text("f_7545:optimizer_2escm"),(void*)f_7545},
{C_text("f_7554:optimizer_2escm"),(void*)f_7554},
{C_text("f_7561:optimizer_2escm"),(void*)f_7561},
{C_text("f_7564:optimizer_2escm"),(void*)f_7564},
{C_text("f_7567:optimizer_2escm"),(void*)f_7567},
{C_text("f_7582:optimizer_2escm"),(void*)f_7582},
{C_text("f_7602:optimizer_2escm"),(void*)f_7602},
{C_text("f_7606:optimizer_2escm"),(void*)f_7606},
{C_text("f_7610:optimizer_2escm"),(void*)f_7610},
{C_text("f_7620:optimizer_2escm"),(void*)f_7620},
{C_text("f_7639:optimizer_2escm"),(void*)f_7639},
{C_text("f_7643:optimizer_2escm"),(void*)f_7643},
{C_text("f_7662:optimizer_2escm"),(void*)f_7662},
{C_text("f_7682:optimizer_2escm"),(void*)f_7682},
{C_text("f_7686:optimizer_2escm"),(void*)f_7686},
{C_text("f_7693:optimizer_2escm"),(void*)f_7693},
{C_text("f_7704:optimizer_2escm"),(void*)f_7704},
{C_text("f_7714:optimizer_2escm"),(void*)f_7714},
{C_text("f_7734:optimizer_2escm"),(void*)f_7734},
{C_text("f_7737:optimizer_2escm"),(void*)f_7737},
{C_text("f_7740:optimizer_2escm"),(void*)f_7740},
{C_text("f_7755:optimizer_2escm"),(void*)f_7755},
{C_text("f_7757:optimizer_2escm"),(void*)f_7757},
{C_text("f_7763:optimizer_2escm"),(void*)f_7763},
{C_text("f_7787:optimizer_2escm"),(void*)f_7787},
{C_text("f_7800:optimizer_2escm"),(void*)f_7800},
{C_text("f_7809:optimizer_2escm"),(void*)f_7809},
{C_text("f_7812:optimizer_2escm"),(void*)f_7812},
{C_text("f_7813:optimizer_2escm"),(void*)f_7813},
{C_text("f_7823:optimizer_2escm"),(void*)f_7823},
{C_text("f_7831:optimizer_2escm"),(void*)f_7831},
{C_text("f_7839:optimizer_2escm"),(void*)f_7839},
{C_text("f_7845:optimizer_2escm"),(void*)f_7845},
{C_text("f_7858:optimizer_2escm"),(void*)f_7858},
{C_text("f_7872:optimizer_2escm"),(void*)f_7872},
{C_text("f_7873:optimizer_2escm"),(void*)f_7873},
{C_text("f_7880:optimizer_2escm"),(void*)f_7880},
{C_text("f_7888:optimizer_2escm"),(void*)f_7888},
{C_text("f_7890:optimizer_2escm"),(void*)f_7890},
{C_text("f_7903:optimizer_2escm"),(void*)f_7903},
{C_text("f_7914:optimizer_2escm"),(void*)f_7914},
{C_text("f_7920:optimizer_2escm"),(void*)f_7920},
{C_text("f_7932:optimizer_2escm"),(void*)f_7932},
{C_text("f_7935:optimizer_2escm"),(void*)f_7935},
{C_text("f_7938:optimizer_2escm"),(void*)f_7938},
{C_text("f_7947:optimizer_2escm"),(void*)f_7947},
{C_text("f_7955:optimizer_2escm"),(void*)f_7955},
{C_text("f_7971:optimizer_2escm"),(void*)f_7971},
{C_text("f_7984:optimizer_2escm"),(void*)f_7984},
{C_text("f_8008:optimizer_2escm"),(void*)f_8008},
{C_text("f_8032:optimizer_2escm"),(void*)f_8032},
{C_text("f_8043:optimizer_2escm"),(void*)f_8043},
{C_text("f_8055:optimizer_2escm"),(void*)f_8055},
{C_text("f_8063:optimizer_2escm"),(void*)f_8063},
{C_text("f_8079:optimizer_2escm"),(void*)f_8079},
{C_text("f_8099:optimizer_2escm"),(void*)f_8099},
{C_text("f_8110:optimizer_2escm"),(void*)f_8110},
{C_text("f_8141:optimizer_2escm"),(void*)f_8141},
{C_text("f_8147:optimizer_2escm"),(void*)f_8147},
{C_text("f_8157:optimizer_2escm"),(void*)f_8157},
{C_text("f_8170:optimizer_2escm"),(void*)f_8170},
{C_text("f_8180:optimizer_2escm"),(void*)f_8180},
{C_text("f_8193:optimizer_2escm"),(void*)f_8193},
{C_text("f_8203:optimizer_2escm"),(void*)f_8203},
{C_text("f_8230:optimizer_2escm"),(void*)f_8230},
{C_text("f_8280:optimizer_2escm"),(void*)f_8280},
{C_text("f_8282:optimizer_2escm"),(void*)f_8282},
{C_text("f_8286:optimizer_2escm"),(void*)f_8286},
{C_text("f_8296:optimizer_2escm"),(void*)f_8296},
{C_text("f_8305:optimizer_2escm"),(void*)f_8305},
{C_text("f_8395:optimizer_2escm"),(void*)f_8395},
{C_text("f_8398:optimizer_2escm"),(void*)f_8398},
{C_text("f_8419:optimizer_2escm"),(void*)f_8419},
{C_text("f_8469:optimizer_2escm"),(void*)f_8469},
{C_text("f_8473:optimizer_2escm"),(void*)f_8473},
{C_text("f_8477:optimizer_2escm"),(void*)f_8477},
{C_text("f_8481:optimizer_2escm"),(void*)f_8481},
{C_text("f_8485:optimizer_2escm"),(void*)f_8485},
{C_text("f_8514:optimizer_2escm"),(void*)f_8514},
{C_text("f_8541:optimizer_2escm"),(void*)f_8541},
{C_text("f_8572:optimizer_2escm"),(void*)f_8572},
{C_text("f_8589:optimizer_2escm"),(void*)f_8589},
{C_text("f_8613:optimizer_2escm"),(void*)f_8613},
{C_text("f_8624:optimizer_2escm"),(void*)f_8624},
{C_text("f_8643:optimizer_2escm"),(void*)f_8643},
{C_text("f_8686:optimizer_2escm"),(void*)f_8686},
{C_text("f_8701:optimizer_2escm"),(void*)f_8701},
{C_text("f_8709:optimizer_2escm"),(void*)f_8709},
{C_text("f_8745:optimizer_2escm"),(void*)f_8745},
{C_text("f_8778:optimizer_2escm"),(void*)f_8778},
{C_text("f_8794:optimizer_2escm"),(void*)f_8794},
{C_text("f_8840:optimizer_2escm"),(void*)f_8840},
{C_text("f_8855:optimizer_2escm"),(void*)f_8855},
{C_text("f_8867:optimizer_2escm"),(void*)f_8867},
{C_text("f_8914:optimizer_2escm"),(void*)f_8914},
{C_text("f_8929:optimizer_2escm"),(void*)f_8929},
{C_text("f_8937:optimizer_2escm"),(void*)f_8937},
{C_text("f_8945:optimizer_2escm"),(void*)f_8945},
{C_text("f_8976:optimizer_2escm"),(void*)f_8976},
{C_text("f_8997:optimizer_2escm"),(void*)f_8997},
{C_text("f_9018:optimizer_2escm"),(void*)f_9018},
{C_text("f_9027:optimizer_2escm"),(void*)f_9027},
{C_text("f_9038:optimizer_2escm"),(void*)f_9038},
{C_text("f_9047:optimizer_2escm"),(void*)f_9047},
{C_text("f_9052:optimizer_2escm"),(void*)f_9052},
{C_text("f_9077:optimizer_2escm"),(void*)f_9077},
{C_text("f_9079:optimizer_2escm"),(void*)f_9079},
{C_text("f_9119:optimizer_2escm"),(void*)f_9119},
{C_text("f_9129:optimizer_2escm"),(void*)f_9129},
{C_text("f_9154:optimizer_2escm"),(void*)f_9154},
{C_text("f_9163:optimizer_2escm"),(void*)f_9163},
{C_text("f_9188:optimizer_2escm"),(void*)f_9188},
{C_text("f_9252:optimizer_2escm"),(void*)f_9252},
{C_text("f_9261:optimizer_2escm"),(void*)f_9261},
{C_text("f_9276:optimizer_2escm"),(void*)f_9276},
{C_text("f_9284:optimizer_2escm"),(void*)f_9284},
{C_text("f_9288:optimizer_2escm"),(void*)f_9288},
{C_text("f_9341:optimizer_2escm"),(void*)f_9341},
{C_text("f_9364:optimizer_2escm"),(void*)f_9364},
{C_text("f_9368:optimizer_2escm"),(void*)f_9368},
{C_text("f_9402:optimizer_2escm"),(void*)f_9402},
{C_text("f_9448:optimizer_2escm"),(void*)f_9448},
{C_text("f_9452:optimizer_2escm"),(void*)f_9452},
{C_text("f_9481:optimizer_2escm"),(void*)f_9481},
{C_text("f_9506:optimizer_2escm"),(void*)f_9506},
{C_text("f_9510:optimizer_2escm"),(void*)f_9510},
{C_text("f_9514:optimizer_2escm"),(void*)f_9514},
{C_text("f_9551:optimizer_2escm"),(void*)f_9551},
{C_text("f_9581:optimizer_2escm"),(void*)f_9581},
{C_text("f_9634:optimizer_2escm"),(void*)f_9634},
{C_text("f_9651:optimizer_2escm"),(void*)f_9651},
{C_text("f_9655:optimizer_2escm"),(void*)f_9655},
{C_text("f_9735:optimizer_2escm"),(void*)f_9735},
{C_text("f_9756:optimizer_2escm"),(void*)f_9756},
{C_text("f_9764:optimizer_2escm"),(void*)f_9764},
{C_text("f_9847:optimizer_2escm"),(void*)f_9847},
{C_text("f_9862:optimizer_2escm"),(void*)f_9862},
{C_text("f_9915:optimizer_2escm"),(void*)f_9915},
{C_text("f_9930:optimizer_2escm"),(void*)f_9930},
{C_text("f_9949:optimizer_2escm"),(void*)f_9949},
{C_text("f_9958:optimizer_2escm"),(void*)f_9958},
{C_text("f_9974:optimizer_2escm"),(void*)f_9974},
{C_text("f_9996:optimizer_2escm"),(void*)f_9996},
{C_text("f_9999:optimizer_2escm"),(void*)f_9999},
{C_text("toplevel:optimizer_2escm"),(void*)C_optimizer_toplevel},
{NULL,NULL}};
#endif

static C_PTABLE_ENTRY *create_ptable(void){
#ifdef C_ENABLE_PTABLES
return ptable;
#else
return NULL;
#endif
}

/*
o|hiding unexported module binding: chicken.compiler.optimizer#partition 
o|hiding unexported module binding: chicken.compiler.optimizer#span 
o|hiding unexported module binding: chicken.compiler.optimizer#take 
o|hiding unexported module binding: chicken.compiler.optimizer#drop 
o|hiding unexported module binding: chicken.compiler.optimizer#split-at 
o|hiding unexported module binding: chicken.compiler.optimizer#append-map 
o|hiding unexported module binding: chicken.compiler.optimizer#every 
o|hiding unexported module binding: chicken.compiler.optimizer#any 
o|hiding unexported module binding: chicken.compiler.optimizer#cons* 
o|hiding unexported module binding: chicken.compiler.optimizer#concatenate 
o|hiding unexported module binding: chicken.compiler.optimizer#delete 
o|hiding unexported module binding: chicken.compiler.optimizer#first 
o|hiding unexported module binding: chicken.compiler.optimizer#second 
o|hiding unexported module binding: chicken.compiler.optimizer#third 
o|hiding unexported module binding: chicken.compiler.optimizer#fourth 
o|hiding unexported module binding: chicken.compiler.optimizer#fifth 
o|hiding unexported module binding: chicken.compiler.optimizer#delete-duplicates 
o|hiding unexported module binding: chicken.compiler.optimizer#alist-cons 
o|hiding unexported module binding: chicken.compiler.optimizer#filter 
o|hiding unexported module binding: chicken.compiler.optimizer#filter-map 
o|hiding unexported module binding: chicken.compiler.optimizer#remove 
o|hiding unexported module binding: chicken.compiler.optimizer#unzip1 
o|hiding unexported module binding: chicken.compiler.optimizer#last 
o|hiding unexported module binding: chicken.compiler.optimizer#list-index 
o|hiding unexported module binding: chicken.compiler.optimizer#lset-adjoin/eq? 
o|hiding unexported module binding: chicken.compiler.optimizer#lset-difference/eq? 
o|hiding unexported module binding: chicken.compiler.optimizer#lset-union/eq? 
o|hiding unexported module binding: chicken.compiler.optimizer#lset-intersection/eq? 
o|hiding unexported module binding: chicken.compiler.optimizer#list-tabulate 
o|hiding unexported module binding: chicken.compiler.optimizer#lset<=/eq? 
o|hiding unexported module binding: chicken.compiler.optimizer#lset=/eq? 
o|hiding unexported module binding: chicken.compiler.optimizer#length+ 
o|hiding unexported module binding: chicken.compiler.optimizer#find 
o|hiding unexported module binding: chicken.compiler.optimizer#find-tail 
o|hiding unexported module binding: chicken.compiler.optimizer#iota 
o|hiding unexported module binding: chicken.compiler.optimizer#make-list 
o|hiding unexported module binding: chicken.compiler.optimizer#posq 
o|hiding unexported module binding: chicken.compiler.optimizer#posv 
o|hiding unexported module binding: chicken.compiler.optimizer#simplifications 
o|hiding unexported module binding: chicken.compiler.optimizer#simplified-ops 
o|hiding unexported module binding: chicken.compiler.optimizer#broken-constant-nodes 
o|hiding unexported module binding: chicken.compiler.optimizer#inline-history 
o|hiding unexported module binding: chicken.compiler.optimizer#within-unrolling-limit 
o|hiding unexported module binding: chicken.compiler.optimizer#perform-pre-optimization! 
o|hiding unexported module binding: chicken.compiler.optimizer#register-simplifications 
o|hiding unexported module binding: chicken.compiler.optimizer#reorganize-recursive-bindings 
o|hiding unexported module binding: chicken.compiler.optimizer#substitution-table 
o|hiding unexported module binding: chicken.compiler.optimizer#simplify-named-call 
S|applied compiler syntax:
S|  chicken.base#o		1
S|  scheme#for-each		20
S|  chicken.base#foldl		4
S|  scheme#map		15
S|  chicken.base#foldr		8
o|eliminated procedure checks: 239 
o|eliminated procedure checks: 1 
o|eliminated procedure checks: 1 
o|eliminated procedure checks: 1 
o|specializations:
o|  1 (scheme#set-car! pair *)
o|  1 (scheme#length list)
o|  1 (chicken.base#sub1 fixnum)
o|  2 (scheme#cddr (pair * pair))
o|  2 (scheme#> fixnum fixnum)
o|  1 (chicken.base#add1 fixnum)
o|  1 (scheme#<= fixnum fixnum)
o|  1 (scheme#positive? fixnum)
o|  1 (scheme#eqv? (or eof null fixnum char boolean symbol keyword) *)
o|  1 (scheme#< fixnum fixnum)
o|  1 (scheme#cdar (pair pair *))
o|  17 (scheme#= fixnum fixnum)
o|  2 (scheme#set-cdr! pair *)
o|  1 (scheme#* fixnum fixnum)
o|  4 (chicken.base#sub1 *)
o|  5 (scheme#zero? *)
o|  9 (chicken.base#add1 *)
o|  68 (scheme#eqv? * (or eof null fixnum char boolean symbol keyword))
o|  1 (scheme#eqv? * *)
o|  16 (##sys#check-list (or pair list) *)
o|  56 (scheme#cdr pair)
o|  26 (scheme#car pair)
(o e)|safe calls: 1509 
(o e)|assignments to immediate values: 10 
o|safe globals: (chicken.compiler.optimizer#posv chicken.compiler.optimizer#posq chicken.compiler.optimizer#make-list chicken.compiler.optimizer#iota chicken.compiler.optimizer#find-tail chicken.compiler.optimizer#find chicken.compiler.optimizer#length+ chicken.compiler.optimizer#lset=/eq? chicken.compiler.optimizer#lset<=/eq? chicken.compiler.optimizer#list-tabulate chicken.compiler.optimizer#lset-intersection/eq? chicken.compiler.optimizer#lset-union/eq? chicken.compiler.optimizer#lset-difference/eq? chicken.compiler.optimizer#lset-adjoin/eq? chicken.compiler.optimizer#list-index chicken.compiler.optimizer#last chicken.compiler.optimizer#unzip1 chicken.compiler.optimizer#remove chicken.compiler.optimizer#filter-map chicken.compiler.optimizer#filter chicken.compiler.optimizer#alist-cons chicken.compiler.optimizer#delete-duplicates chicken.compiler.optimizer#fifth chicken.compiler.optimizer#fourth chicken.compiler.optimizer#third chicken.compiler.optimizer#second chicken.compiler.optimizer#first chicken.compiler.optimizer#delete chicken.compiler.optimizer#concatenate chicken.compiler.optimizer#cons* chicken.compiler.optimizer#any chicken.compiler.optimizer#every chicken.compiler.optimizer#append-map chicken.compiler.optimizer#split-at chicken.compiler.optimizer#drop chicken.compiler.optimizer#take chicken.compiler.optimizer#span chicken.compiler.optimizer#partition) 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#span 
o|inlining procedure: k3513 
o|inlining procedure: k3513 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#drop 
o|inlining procedure: k3571 
o|inlining procedure: k3571 
o|merged explicitly consed rest parameter: lsts108 
o|inlining procedure: k3604 
o|inlining procedure: k3619 
o|inlining procedure: k3619 
o|inlining procedure: k3604 
o|inlining procedure: k3659 
o|inlining procedure: k3659 
o|inlining procedure: k3691 
o|contracted procedure: "(mini-srfi-1.scm:77) g161170" 
o|inlining procedure: k3691 
o|inlining procedure: k3740 
o|contracted procedure: "(mini-srfi-1.scm:76) g134143" 
o|inlining procedure: k3740 
o|inlining procedure: k3783 
o|inlining procedure: k3783 
o|inlining procedure: k3814 
o|inlining procedure: k3814 
o|merged explicitly consed rest parameter: xs209 
o|inlining procedure: k3844 
o|inlining procedure: k3844 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#concatenate 
o|inlining procedure: k3900 
o|inlining procedure: k3900 
o|inlining procedure: k4031 
o|inlining procedure: k4031 
o|inlining procedure: k4023 
o|inlining procedure: k4023 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#remove 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#list-index 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#lset-difference/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#lset-union/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#lset-intersection/eq? 
o|inlining procedure: k4422 
o|inlining procedure: k4422 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#length+ 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#find 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#find-tail 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#iota 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#make-list 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#posq 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#posv 
o|inlining procedure: k4702 
o|inlining procedure: k4702 
o|inlining procedure: k4739 
o|inlining procedure: k4739 
o|inlining procedure: k4755 
o|inlining procedure: k4755 
o|inlining procedure: k4787 
o|inlining procedure: "(optimizer.scm:89) chicken.compiler.optimizer#first" 
o|inlining procedure: k4787 
o|inlining procedure: "(optimizer.scm:96) chicken.compiler.optimizer#first" 
o|inlining procedure: k4864 
o|contracted procedure: "(optimizer.scm:102) chicken.compiler.optimizer#last" 
o|inlining procedure: k4180 
o|inlining procedure: k4180 
o|inlining procedure: k4864 
o|inlining procedure: k4897 
o|inlining procedure: k4897 
o|inlining procedure: k4927 
o|inlining procedure: k4927 
o|inlining procedure: "(optimizer.scm:110) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:109) chicken.compiler.optimizer#first" 
o|substituted constant variable: a4963 
o|substituted constant variable: a4965 
o|substituted constant variable: a4970 
o|substituted constant variable: a4972 
o|substituted constant variable: a4974 
o|inlining procedure: k4978 
o|inlining procedure: k4978 
o|substituted constant variable: a4985 
o|substituted constant variable: a4987 
o|substituted constant variable: a4989 
o|substituted constant variable: a4991 
o|inlining procedure: k5015 
o|contracted procedure: "(optimizer.scm:131) g566634" 
o|propagated global variable: g642643 chicken.compiler.support#mark-variable 
o|inlining procedure: k5015 
o|contracted procedure: "(optimizer.scm:130) chicken.compiler.optimizer#delete-duplicates" 
o|inlining procedure: k3975 
o|inlining procedure: k3975 
o|inlining procedure: k5102 
o|contracted procedure: "(optimizer.scm:172) g694701" 
o|inlining procedure: k5102 
o|inlining procedure: k5131 
o|inlining procedure: k5131 
o|inlining procedure: k5143 
o|inlining procedure: k5155 
o|inlining procedure: k5155 
o|inlining procedure: k5211 
o|inlining procedure: k5211 
o|inlining procedure: "(optimizer.scm:180) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:179) chicken.compiler.optimizer#first" 
o|inlining procedure: k5143 
o|inlining procedure: "(optimizer.scm:178) chicken.compiler.optimizer#second" 
o|inlining procedure: k5259 
o|inlining procedure: k5259 
o|inlining procedure: k5265 
o|inlining procedure: k5277 
o|inlining procedure: k5289 
o|inlining procedure: k5301 
o|inlining procedure: k5313 
o|inlining procedure: k5323 
o|consed rest parameter at call site: "(optimizer.scm:219) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: k5323 
o|inlining procedure: k5313 
o|inlining procedure: k5301 
o|inlining procedure: k5289 
o|inlining procedure: "(optimizer.scm:207) chicken.compiler.optimizer#first" 
o|inlining procedure: k5277 
o|inlining procedure: "(optimizer.scm:205) chicken.compiler.optimizer#first" 
o|inlining procedure: k5386 
o|inlining procedure: k5386 
o|inlining procedure: k5398 
o|inlining procedure: k5398 
o|inlining procedure: k5265 
o|inlining procedure: k5415 
o|inlining procedure: k5415 
o|inlining procedure: k5434 
o|inlining procedure: k5455 
o|inlining procedure: k5455 
o|contracted procedure: "(optimizer.scm:236) node-value677" 
o|inlining procedure: "(optimizer.scm:168) chicken.compiler.optimizer#first" 
o|contracted procedure: "(optimizer.scm:233) constant-node?676" 
o|inlining procedure: k5434 
o|inlining procedure: k5482 
o|inlining procedure: k5498 
o|contracted procedure: "(optimizer.scm:254) chicken.compiler.optimizer#lset-adjoin/eq?" 
o|inlining procedure: k4239 
o|inlining procedure: k4239 
o|propagated global variable: lst348 chicken.compiler.optimizer#broken-constant-nodes 
o|inlining procedure: k5498 
o|inlining procedure: k5482 
o|substituted constant variable: a5545 
o|substituted constant variable: a5547 
o|substituted constant variable: a5549 
o|inlining procedure: k5556 
o|inlining procedure: k5556 
o|inlining procedure: k5582 
o|inlining procedure: k5618 
o|inlining procedure: k5618 
o|inlining procedure: k5645 
o|inlining procedure: k5645 
o|inlining procedure: "(optimizer.scm:287) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:282) chicken.compiler.optimizer#first" 
o|inlining procedure: k5582 
o|inlining procedure: k5698 
o|inlining procedure: "(optimizer.scm:308) chicken.compiler.optimizer#second" 
o|inlining procedure: k5698 
o|inlining procedure: k5743 
o|inlining procedure: k5743 
o|inlining procedure: "(optimizer.scm:313) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:313) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:311) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:311) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:310) chicken.compiler.optimizer#first" 
o|inlining procedure: k5818 
o|inlining procedure: k5818 
o|inlining procedure: "(optimizer.scm:302) chicken.compiler.optimizer#first" 
o|inlining procedure: k5831 
o|contracted procedure: "(optimizer.scm:325) chicken.compiler.optimizer#partition" 
o|inlining procedure: k3411 
o|inlining procedure: k3411 
o|inlining procedure: "(optimizer.scm:337) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:336) chicken.compiler.optimizer#fourth" 
o|inlining procedure: "(optimizer.scm:330) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:330) chicken.compiler.optimizer#first" 
o|inlining procedure: k5935 
o|inlining procedure: "(optimizer.scm:350) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:349) chicken.compiler.optimizer#fourth" 
o|inlining procedure: "(optimizer.scm:347) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:346) chicken.compiler.optimizer#first" 
o|inlining procedure: k5935 
o|inlining procedure: "(optimizer.scm:320) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:319) chicken.compiler.optimizer#third" 
o|inlining procedure: k5831 
o|inlining procedure: k6010 
o|inlining procedure: k6038 
o|propagated global variable: g983984 chicken.compiler.support#db-put! 
o|inlining procedure: "(optimizer.scm:382) chicken.compiler.optimizer#first" 
o|inlining procedure: k6091 
o|inlining procedure: k6091 
o|inlining procedure: "(optimizer.scm:374) chicken.compiler.optimizer#third" 
o|inlining procedure: k6038 
o|inlining procedure: k6148 
o|inlining procedure: k6172 
o|propagated global variable: g10761077 chicken.compiler.support#db-put! 
o|inlining procedure: "(optimizer.scm:454) chicken.compiler.optimizer#first" 
o|inlining procedure: k6248 
o|inlining procedure: k6248 
o|inlining procedure: "(optimizer.scm:441) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k6172 
o|inlining procedure: k6288 
o|inlining procedure: k6288 
o|inlining procedure: k6303 
o|inlining procedure: k6338 
o|inlining procedure: k6338 
o|inlining procedure: k6303 
o|inlining procedure: k6389 
o|inlining procedure: k6389 
o|inlining procedure: k6467 
o|inlining procedure: k6528 
o|inlining procedure: k6528 
o|inlining procedure: k6568 
o|inlining procedure: k6568 
o|substituted constant variable: a6585 
o|inlining procedure: k6467 
o|inlining procedure: k6607 
o|inlining procedure: k6619 
o|inlining procedure: k6637 
o|inlining procedure: k6637 
o|contracted procedure: "(optimizer.scm:431) chicken.compiler.optimizer#within-unrolling-limit" 
o|inlining procedure: k7434 
o|inlining procedure: k7434 
o|inlining procedure: k7443 
o|inlining procedure: k7443 
o|inlining procedure: k6652 
o|inlining procedure: k6652 
o|inlining procedure: "(optimizer.scm:430) chicken.compiler.optimizer#fourth" 
o|substituted constant variable: a6663 
o|inlining procedure: k6619 
o|inlining procedure: k6607 
o|inlining procedure: "(optimizer.scm:421) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:417) chicken.compiler.optimizer#third" 
o|inlining procedure: k6148 
o|inlining procedure: "(optimizer.scm:526) chicken.compiler.optimizer#first" 
o|inlining procedure: k6709 
o|inlining procedure: "(optimizer.scm:523) chicken.compiler.optimizer#first" 
o|inlining procedure: k6709 
o|inlining procedure: k6740 
o|inlining procedure: k6752 
o|inlining procedure: k6764 
o|propagated global variable: g10201021 chicken.compiler.support#expression-has-side-effects? 
o|inlining procedure: k6791 
o|inlining procedure: k6791 
o|inlining procedure: k6764 
o|inlining procedure: "(optimizer.scm:398) chicken.compiler.optimizer#third" 
o|inlining procedure: k6752 
o|inlining procedure: "(optimizer.scm:394) chicken.compiler.optimizer#first" 
o|inlining procedure: k6740 
o|inlining procedure: k6851 
o|inlining procedure: "(optimizer.scm:371) chicken.compiler.optimizer#first" 
o|inlining procedure: k6851 
o|inlining procedure: k6882 
o|inlining procedure: k6882 
o|inlining procedure: "(optimizer.scm:362) chicken.compiler.optimizer#first" 
o|inlining procedure: k6896 
o|inlining procedure: k6936 
o|inlining procedure: k6936 
o|inlining procedure: "(optimizer.scm:535) chicken.compiler.optimizer#first" 
o|inlining procedure: k6896 
o|substituted constant variable: a6975 
o|substituted constant variable: a6977 
o|inlining procedure: k6010 
o|inlining procedure: k6987 
o|inlining procedure: k6987 
o|inlining procedure: k7020 
o|inlining procedure: k7020 
o|inlining procedure: k7050 
o|inlining procedure: k7050 
o|inlining procedure: k7075 
o|substituted constant variable: a7085 
o|inlining procedure: k7075 
o|inlining procedure: k7092 
o|substituted constant variable: a7102 
o|inlining procedure: k7092 
o|inlining procedure: k7125 
o|inlining procedure: "(optimizer.scm:557) chicken.compiler.optimizer#first" 
o|inlining procedure: k7125 
o|inlining procedure: "(optimizer.scm:544) chicken.compiler.optimizer#first" 
o|inlining procedure: k7167 
o|inlining procedure: "(optimizer.scm:575) chicken.compiler.optimizer#first" 
o|inlining procedure: k7167 
o|inlining procedure: k7207 
o|inlining procedure: k7207 
o|substituted constant variable: a7220 
o|substituted constant variable: a7222 
o|substituted constant variable: a7224 
o|substituted constant variable: a7226 
o|substituted constant variable: a7228 
o|substituted constant variable: a7230 
o|substituted constant variable: a7232 
o|substituted constant variable: a7234 
o|substituted constant variable: a7236 
o|substituted constant variable: a7238 
o|inlining procedure: k7248 
o|inlining procedure: k7248 
o|inlining procedure: k7295 
o|inlining procedure: k7295 
o|inlining procedure: k7393 
o|contracted procedure: "(optimizer.scm:617) g13101317" 
o|inlining procedure: k7364 
o|inlining procedure: k7364 
o|inlining procedure: k7393 
o|propagated global variable: g13161318 chicken.compiler.optimizer#simplified-ops 
o|contracted procedure: "(optimizer.scm:605) chicken.compiler.optimizer#perform-pre-optimization!" 
o|inlining procedure: k7484 
o|inlining procedure: k7484 
o|inlining procedure: k7513 
o|inlining procedure: k7540 
o|inlining procedure: "(optimizer.scm:688) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:685) chicken.compiler.optimizer#first" 
o|inlining procedure: k7540 
o|substituted constant variable: a7621 
o|inlining procedure: "(optimizer.scm:676) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:675) chicken.compiler.optimizer#third" 
o|inlining procedure: k7513 
o|inlining procedure: k7644 
o|substituted constant variable: a7663 
o|inlining procedure: k7644 
o|substituted constant variable: a7668 
o|inlining procedure: "(optimizer.scm:668) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:668) chicken.compiler.optimizer#second" 
o|inlining procedure: k7706 
o|inlining procedure: k7706 
o|merged explicitly consed rest parameter: ss1422 
o|inlining procedure: k10592 
o|inlining procedure: "(optimizer.scm:1549) chicken.compiler.optimizer#first" 
o|inlining procedure: k10617 
o|inlining procedure: k10629 
o|inlining procedure: k10644 
o|inlining procedure: k10653 
o|inlining procedure: k10665 
o|inlining procedure: "(optimizer.scm:1547) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1547) chicken.compiler.optimizer#first" 
o|inlining procedure: k10665 
o|inlining procedure: "(optimizer.scm:1544) chicken.compiler.optimizer#first" 
o|inlining procedure: k10653 
o|inlining procedure: k10644 
o|inlining procedure: k10629 
o|inlining procedure: k10617 
o|inlining procedure: "(optimizer.scm:1535) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1533) chicken.compiler.optimizer#third" 
o|inlining procedure: k10592 
o|inlining procedure: "(optimizer.scm:1550) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1550) chicken.compiler.optimizer#first" 
o|inlining procedure: k10727 
o|inlining procedure: "(optimizer.scm:1553) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1552) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1552) chicken.compiler.optimizer#first" 
o|inlining procedure: k10727 
o|inlining procedure: k10765 
o|inlining procedure: k10765 
o|substituted constant variable: a10786 
o|substituted constant variable: a10788 
o|substituted constant variable: a10790 
o|inlining procedure: k10806 
o|inlining procedure: k10824 
o|inlining procedure: k10824 
o|inlining procedure: "(optimizer.scm:1564) chicken.compiler.optimizer#first" 
o|inlining procedure: k10806 
o|inlining procedure: k10851 
o|inlining procedure: "(optimizer.scm:1577) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1574) chicken.compiler.optimizer#third" 
o|inlining procedure: k10851 
o|inlining procedure: k10879 
o|inlining procedure: "(optimizer.scm:1581) chicken.compiler.optimizer#second" 
o|inlining procedure: k10879 
o|inlining procedure: k10914 
o|inlining procedure: k10920 
o|inlining procedure: k10920 
o|inlining procedure: "(optimizer.scm:1585) chicken.compiler.optimizer#first" 
o|inlining procedure: k10914 
o|inlining procedure: k10938 
o|inlining procedure: k10963 
o|inlining procedure: k10963 
o|inlining procedure: "(optimizer.scm:1590) chicken.compiler.optimizer#second" 
o|inlining procedure: k10938 
o|inlining procedure: k10983 
o|inlining procedure: k10983 
o|inlining procedure: k11002 
o|inlining procedure: k11002 
o|inlining procedure: "(optimizer.scm:1598) chicken.compiler.optimizer#first" 
o|inlining procedure: k11016 
o|inlining procedure: k11031 
o|inlining procedure: k11031 
o|inlining procedure: k11056 
o|inlining procedure: "(optimizer.scm:1613) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1611) chicken.compiler.optimizer#second" 
o|inlining procedure: k11056 
o|inlining procedure: "(optimizer.scm:1608) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1606) chicken.compiler.optimizer#first" 
o|inlining procedure: k11016 
o|inlining procedure: k11107 
o|inlining procedure: k11107 
o|inlining procedure: "(optimizer.scm:1619) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k11129 
o|inlining procedure: "(optimizer.scm:1625) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1625) chicken.compiler.optimizer#first" 
o|inlining procedure: k11129 
o|inlining procedure: k11152 
o|inlining procedure: "(optimizer.scm:1628) chicken.compiler.optimizer#second" 
o|inlining procedure: k11152 
o|inlining procedure: "(optimizer.scm:1627) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1627) chicken.compiler.optimizer#first" 
o|substituted constant variable: a11187 
o|substituted constant variable: a11189 
o|substituted constant variable: a11191 
o|substituted constant variable: a11193 
o|substituted constant variable: a11195 
o|substituted constant variable: a11197 
o|substituted constant variable: a11199 
o|substituted constant variable: a11201 
o|substituted constant variable: a11203 
o|substituted constant variable: a11205 
o|inlining procedure: k11209 
o|contracted procedure: "(optimizer.scm:1634) chicken.compiler.optimizer#lset=/eq?" 
o|inlining procedure: k4458 
o|inlining procedure: k4458 
o|inlining procedure: k11209 
o|inlining procedure: "(optimizer.scm:1713) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1706) chicken.compiler.optimizer#second" 
o|inlining procedure: k11238 
o|inlining procedure: k11396 
o|contracted procedure: "(optimizer.scm:1738) g24742481" 
o|inlining procedure: k11396 
o|inlining procedure: k11419 
o|contracted procedure: "(optimizer.scm:1728) g24642465" 
o|inlining procedure: "(optimizer.scm:1732) chicken.compiler.optimizer#first" 
o|inlining procedure: k11419 
o|inlining procedure: k11488 
o|inlining procedure: k11488 
o|inlining procedure: k11547 
o|inlining procedure: k11571 
o|inlining procedure: "(optimizer.scm:1677) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1675) chicken.compiler.optimizer#first" 
o|inlining procedure: k11607 
o|inlining procedure: k11607 
o|inlining procedure: "(optimizer.scm:1672) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1668) chicken.compiler.optimizer#first" 
o|inlining procedure: k11571 
o|inlining procedure: "(optimizer.scm:1683) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1666) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1662) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1661) chicken.compiler.optimizer#first" 
o|inlining procedure: k11547 
o|inlining procedure: k11722 
o|inlining procedure: "(optimizer.scm:1693) chicken.compiler.optimizer#second" 
o|inlining procedure: k11722 
o|inlining procedure: k11751 
o|inlining procedure: k11751 
o|inlining procedure: "(optimizer.scm:1690) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1689) chicken.compiler.optimizer#first" 
o|inlining procedure: k11780 
o|inlining procedure: k11780 
o|substituted constant variable: a11801 
o|substituted constant variable: a11803 
o|inlining procedure: "(optimizer.scm:1656) chicken.compiler.optimizer#first" 
o|inlining procedure: k11238 
o|inlining procedure: k11818 
o|inlining procedure: k11818 
o|substituted constant variable: a11833 
o|inlining procedure: "(optimizer.scm:1642) chicken.compiler.optimizer#third" 
o|contracted procedure: "(optimizer.scm:1638) chicken.compiler.optimizer#unzip1" 
o|inlining procedure: k4140 
o|contracted procedure: "(mini-srfi-1.scm:143) g312321" 
o|inlining procedure: k4140 
o|inlining procedure: k11879 
o|substituted constant variable: a11901 
o|inlining procedure: k11879 
o|inlining procedure: k11938 
o|inlining procedure: k11967 
o|inlining procedure: k11967 
o|inlining procedure: k11997 
o|inlining procedure: k12015 
o|contracted procedure: "(optimizer.scm:1809) user-lambda?2511" 
o|inlining procedure: k11905 
o|inlining procedure: "(optimizer.scm:1784) chicken.compiler.optimizer#third" 
o|inlining procedure: k11905 
o|inlining procedure: k12015 
o|inlining procedure: "(optimizer.scm:1803) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1802) chicken.compiler.optimizer#first" 
o|inlining procedure: k11997 
o|inlining procedure: "(optimizer.scm:1794) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1793) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1792) chicken.compiler.optimizer#first" 
o|inlining procedure: k11938 
o|inlining procedure: "(optimizer.scm:1825) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1820) chicken.compiler.optimizer#third" 
o|inlining procedure: k12135 
o|inlining procedure: k12135 
o|substituted constant variable: a12159 
o|substituted constant variable: a12161 
o|substituted constant variable: a12163 
o|inlining procedure: "(optimizer.scm:1856) chicken.compiler.optimizer#first" 
o|inlining procedure: k12236 
o|inlining procedure: k12236 
o|inlining procedure: "(optimizer.scm:1851) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1849) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1848) chicken.compiler.optimizer#first" 
o|consed rest parameter at call site: "(optimizer.scm:1940) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: "(optimizer.scm:1946) chicken.compiler.optimizer#second" 
o|inlining procedure: k12375 
o|inlining procedure: k12375 
o|inlining procedure: k12405 
o|inlining procedure: k12405 
o|inlining procedure: k12431 
o|inlining procedure: k12431 
o|consed rest parameter at call site: "(optimizer.scm:1923) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: k12578 
o|inlining procedure: "(optimizer.scm:1911) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k12578 
o|inlining procedure: "(optimizer.scm:1909) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1907) chicken.compiler.optimizer#second" 
o|consed rest parameter at call site: "(optimizer.scm:1905) chicken.compiler.optimizer#append-map" 3 
o|inlining procedure: "(optimizer.scm:1879) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1877) chicken.compiler.optimizer#second" 
o|inlining procedure: k12671 
o|inlining procedure: k12671 
o|inlining procedure: k12738 
o|contracted procedure: "(optimizer.scm:1865) g26932702" 
o|inlining procedure: "(optimizer.scm:1865) chicken.compiler.optimizer#third" 
o|inlining procedure: k12738 
o|inlining procedure: k12772 
o|inlining procedure: k12772 
o|inlining procedure: k12819 
o|inlining procedure: k12819 
o|consed rest parameter at call site: "(optimizer.scm:947) chicken.compiler.optimizer#register-simplifications" 2 
o|inlining procedure: k12861 
o|inlining procedure: k12873 
o|inlining procedure: k12908 
o|inlining procedure: k12908 
o|inlining procedure: k12873 
o|inlining procedure: k12861 
o|inlining procedure: k13004 
o|inlining procedure: k13004 
o|consed rest parameter at call site: "(optimizer.scm:730) chicken.compiler.optimizer#register-simplifications" 2 
o|inlining procedure: k13085 
o|inlining procedure: k13100 
o|inlining procedure: k13100 
o|substituted constant variable: a13174 
o|inlining procedure: k13085 
o|inlining procedure: k13218 
o|inlining procedure: k13227 
o|inlining procedure: k13245 
o|inlining procedure: k13245 
o|substituted constant variable: a13335 
o|inlining procedure: k13227 
o|inlining procedure: k13218 
o|inlining procedure: k13403 
o|substituted constant variable: a13430 
o|inlining procedure: k13403 
o|inlining procedure: k13505 
o|inlining procedure: k13517 
o|inlining procedure: k13541 
o|inlining procedure: "(optimizer.scm:813) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:813) chicken.compiler.optimizer#first" 
o|inlining procedure: k13541 
o|inlining procedure: k13571 
o|inlining procedure: k13608 
o|inlining procedure: "(optimizer.scm:833) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:831) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:831) chicken.compiler.optimizer#first" 
o|inlining procedure: k13608 
o|contracted procedure: "(optimizer.scm:836) chicken.compiler.optimizer#reorganize-recursive-bindings" 
o|inlining procedure: k7765 
o|inlining procedure: k7765 
o|inlining procedure: k7815 
o|inlining procedure: k7847 
o|inlining procedure: k7847 
o|inlining procedure: k7815 
o|inlining procedure: k7892 
o|contracted procedure: "(optimizer.scm:1046) chicken.compiler.optimizer#lset<=/eq?" 
o|inlining procedure: k7892 
o|contracted procedure: "(optimizer.scm:1045) chicken.compiler.optimizer#filter-map" 
o|inlining procedure: k4078 
o|inlining procedure: k4078 
o|inlining procedure: k4067 
o|inlining procedure: k4067 
o|consed rest parameter at call site: "(optimizer.scm:1039) chicken.compiler.optimizer#append-map" 3 
o|inlining procedure: k7939 
o|inlining procedure: k7939 
o|inlining procedure: k7957 
o|inlining procedure: k7979 
o|inlining procedure: k7979 
o|inlining procedure: k8010 
o|contracted procedure: "(optimizer.scm:1066) g18111812" 
o|inlining procedure: k8010 
o|inlining procedure: k8057 
o|inlining procedure: k8057 
o|inlining procedure: k7957 
o|inlining procedure: k8149 
o|inlining procedure: k8149 
o|inlining procedure: k8172 
o|inlining procedure: k8172 
o|inlining procedure: k8195 
o|inlining procedure: k8195 
o|inlining procedure: k8232 
o|inlining procedure: k8232 
o|inlining procedure: k13663 
o|inlining procedure: k13663 
o|inlining procedure: k13669 
o|inlining procedure: k13681 
o|inlining procedure: k13693 
o|inlining procedure: "(optimizer.scm:830) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:830) chicken.compiler.optimizer#first" 
o|inlining procedure: k13693 
o|inlining procedure: "(optimizer.scm:829) chicken.compiler.optimizer#first" 
o|inlining procedure: k13681 
o|inlining procedure: "(optimizer.scm:827) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:826) chicken.compiler.optimizer#first" 
o|inlining procedure: k13669 
o|inlining procedure: "(optimizer.scm:820) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:818) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:817) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:817) chicken.compiler.optimizer#first" 
o|inlining procedure: k13571 
o|substituted constant variable: a13757 
o|substituted constant variable: a13759 
o|inlining procedure: "(optimizer.scm:809) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:808) chicken.compiler.optimizer#first" 
o|inlining procedure: k13517 
o|inlining procedure: "(optimizer.scm:807) chicken.compiler.optimizer#first" 
o|inlining procedure: k13505 
o|inlining procedure: k13799 
o|inlining procedure: k13811 
o|consed rest parameter at call site: "(optimizer.scm:782) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: k13811 
o|substituted constant variable: a13838 
o|inlining procedure: k13799 
o|inlining procedure: k13926 
o|inlining procedure: k13938 
o|inlining procedure: k13950 
o|inlining procedure: k13950 
o|substituted constant variable: a13975 
o|substituted constant variable: a13984 
o|inlining procedure: k13938 
o|inlining procedure: k13926 
o|consed rest parameter at call site: "(optimizer.scm:711) chicken.compiler.optimizer#register-simplifications" 2 
o|inlining procedure: k14109 
o|inlining procedure: k14109 
o|inlining procedure: k14126 
o|inlining procedure: k14126 
o|contracted procedure: "(optimizer.scm:719) chicken.compiler.optimizer#simplify-named-call" 
o|inlining procedure: k8310 
o|inlining procedure: k8310 
o|inlining procedure: k8319 
o|inlining procedure: k8319 
o|inlining procedure: k8384 
o|inlining procedure: k8399 
o|inlining procedure: k8399 
o|inlining procedure: "(optimizer.scm:1127) chicken.compiler.optimizer#second" 
o|inlining procedure: k8437 
o|inlining procedure: k8449 
o|inlining procedure: k8449 
o|inlining procedure: k8437 
o|inlining procedure: "(optimizer.scm:1119) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1118) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1117) chicken.compiler.optimizer#first" 
o|inlining procedure: k8384 
o|inlining procedure: k8500 
o|inlining procedure: k8509 
o|inlining procedure: "(optimizer.scm:1141) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1136) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1135) chicken.compiler.optimizer#third" 
o|inlining procedure: k8509 
o|inlining procedure: "(optimizer.scm:1133) chicken.compiler.optimizer#first" 
o|inlining procedure: k8500 
o|inlining procedure: k8558 
o|inlining procedure: k8567 
o|inlining procedure: k8591 
o|contracted procedure: "(optimizer.scm:1149) g19181919" 
o|inlining procedure: k8591 
o|inlining procedure: "(optimizer.scm:1152) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1148) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1148) chicken.compiler.optimizer#second" 
o|inlining procedure: k8567 
o|inlining procedure: k8558 
o|inlining procedure: k8669 
o|inlining procedure: k8675 
o|inlining procedure: "(optimizer.scm:1166) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1165) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1164) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1162) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1161) chicken.compiler.optimizer#first" 
o|inlining procedure: k8675 
o|substituted constant variable: a8726 
o|inlining procedure: k8669 
o|inlining procedure: k8731 
o|inlining procedure: k8740 
o|inlining procedure: k8752 
o|inlining procedure: "(optimizer.scm:1180) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1179) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1178) chicken.compiler.optimizer#first" 
o|inlining procedure: k8752 
o|inlining procedure: "(optimizer.scm:1174) chicken.compiler.optimizer#third" 
o|substituted constant variable: a8806 
o|inlining procedure: k8740 
o|inlining procedure: k8731 
o|inlining procedure: k8817 
o|inlining procedure: k8829 
o|inlining procedure: "(optimizer.scm:1191) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1190) chicken.compiler.optimizer#first" 
o|inlining procedure: k8829 
o|substituted constant variable: a8880 
o|inlining procedure: k8817 
o|inlining procedure: "(optimizer.scm:1184) chicken.compiler.optimizer#third" 
o|inlining procedure: k8885 
o|inlining procedure: k8900 
o|inlining procedure: k8909 
o|inlining procedure: "(optimizer.scm:1204) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1202) chicken.compiler.optimizer#second" 
o|inlining procedure: k8909 
o|inlining procedure: "(optimizer.scm:1198) chicken.compiler.optimizer#first" 
o|inlining procedure: k8900 
o|inlining procedure: "(optimizer.scm:1196) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k8885 
o|inlining procedure: k8968 
o|inlining procedure: "(optimizer.scm:1210) chicken.compiler.optimizer#first" 
o|inlining procedure: k8968 
o|inlining procedure: k8983 
o|inlining procedure: k8992 
o|inlining procedure: k9019 
o|inlining procedure: k9054 
o|inlining procedure: k9089 
o|inlining procedure: "(optimizer.scm:1233) chicken.compiler.optimizer#first" 
o|inlining procedure: k9089 
o|inlining procedure: "(optimizer.scm:1234) chicken.compiler.optimizer#second" 
o|inlining procedure: k9054 
o|inlining procedure: k9131 
o|inlining procedure: k9131 
o|inlining procedure: k9165 
o|contracted procedure: "(optimizer.scm:1222) g19751984" 
o|inlining procedure: k9165 
o|inlining procedure: k9019 
o|inlining procedure: k9199 
o|inlining procedure: k9199 
o|inlining procedure: "(optimizer.scm:1221) chicken.compiler.optimizer#fourth" 
o|inlining procedure: "(optimizer.scm:1220) chicken.compiler.optimizer#third" 
o|substituted constant variable: a9228 
o|inlining procedure: k8992 
o|inlining procedure: k8983 
o|inlining procedure: k9235 
o|inlining procedure: k9247 
o|inlining procedure: k9286 
o|inlining procedure: "(optimizer.scm:1256) chicken.compiler.optimizer#third" 
o|inlining procedure: k9286 
o|inlining procedure: "(optimizer.scm:1257) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1254) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1253) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1251) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1250) chicken.compiler.optimizer#first" 
o|inlining procedure: k9247 
o|inlining procedure: "(optimizer.scm:1246) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k9235 
o|inlining procedure: k9318 
o|inlining procedure: k9327 
o|inlining procedure: k9345 
o|consed rest parameter at call site: "(optimizer.scm:1269) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: "(optimizer.scm:1269) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1268) chicken.compiler.optimizer#second" 
o|inlining procedure: k9345 
o|inlining procedure: "(optimizer.scm:1267) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1265) chicken.compiler.optimizer#first" 
o|inlining procedure: k9327 
o|inlining procedure: "(optimizer.scm:1263) chicken.compiler.optimizer#third" 
o|inlining procedure: k9318 
o|inlining procedure: k9394 
o|inlining procedure: k9403 
o|inlining procedure: k9421 
o|inlining procedure: k9421 
o|consed rest parameter at call site: "(optimizer.scm:1284) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: "(optimizer.scm:1284) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1283) chicken.compiler.optimizer#first" 
o|substituted constant variable: a9462 
o|inlining procedure: "(optimizer.scm:1280) chicken.compiler.optimizer#third" 
o|inlining procedure: k9403 
o|inlining procedure: "(optimizer.scm:1278) chicken.compiler.optimizer#second" 
o|inlining procedure: k9394 
o|inlining procedure: k9467 
o|inlining procedure: k9476 
o|inlining procedure: k9491 
o|consed rest parameter at call site: "(optimizer.scm:1296) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: "(optimizer.scm:1294) chicken.compiler.optimizer#second" 
o|inlining procedure: k9491 
o|inlining procedure: "(optimizer.scm:1293) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1292) chicken.compiler.optimizer#third" 
o|inlining procedure: k9476 
o|inlining procedure: k9467 
o|inlining procedure: k9537 
o|inlining procedure: k9546 
o|inlining procedure: k9558 
o|inlining procedure: k9587 
o|inlining procedure: "(optimizer.scm:1311) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k9587 
o|inlining procedure: "(optimizer.scm:1311) chicken.compiler.optimizer#third" 
o|inlining procedure: k9558 
o|inlining procedure: "(optimizer.scm:1305) chicken.compiler.optimizer#fourth" 
o|inlining procedure: "(optimizer.scm:1304) chicken.compiler.optimizer#first" 
o|inlining procedure: k9546 
o|inlining procedure: "(optimizer.scm:1302) chicken.compiler.optimizer#second" 
o|inlining procedure: k9537 
o|inlining procedure: k9608 
o|inlining procedure: k9617 
o|inlining procedure: k9629 
o|consed rest parameter at call site: "(optimizer.scm:1323) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: "(optimizer.scm:1323) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1322) chicken.compiler.optimizer#third" 
o|inlining procedure: k9664 
o|inlining procedure: k9664 
o|inlining procedure: "(optimizer.scm:1324) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1321) chicken.compiler.optimizer#first" 
o|inlining procedure: k9629 
o|propagated global variable: tmp20802082 chicken.compiler.support#unsafe 
o|propagated global variable: tmp20802082 chicken.compiler.support#unsafe 
o|inlining procedure: "(optimizer.scm:1319) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k9617 
o|substituted constant variable: a9692 
o|inlining procedure: k9608 
o|inlining procedure: k9718 
o|inlining procedure: k9730 
o|inlining procedure: k9766 
o|inlining procedure: k9766 
o|inlining procedure: "(optimizer.scm:1353) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1354) chicken.compiler.optimizer#second" 
o|inlining procedure: k9805 
o|substituted constant variable: a9813 
o|inlining procedure: k9805 
o|propagated global variable: tmp21012103 chicken.compiler.support#unsafe 
o|propagated global variable: tmp21012103 chicken.compiler.support#unsafe 
o|inlining procedure: k9730 
o|inlining procedure: k9718 
o|inlining procedure: "(optimizer.scm:1341) chicken.compiler.optimizer#fourth" 
o|inlining procedure: "(optimizer.scm:1340) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1338) chicken.compiler.optimizer#first" 
o|inlining procedure: k9827 
o|inlining procedure: k9836 
o|inlining procedure: k9868 
o|inlining procedure: "(optimizer.scm:1371) chicken.compiler.optimizer#third" 
o|inlining procedure: k9868 
o|inlining procedure: "(optimizer.scm:1372) chicken.compiler.optimizer#second" 
o|inlining procedure: k9836 
o|inlining procedure: "(optimizer.scm:1364) chicken.compiler.optimizer#first" 
o|inlining procedure: k9827 
o|inlining procedure: k9901 
o|inlining procedure: k9910 
o|inlining procedure: "(optimizer.scm:1380) chicken.compiler.optimizer#first" 
o|inlining procedure: k9910 
o|inlining procedure: k9901 
o|inlining procedure: k9935 
o|inlining procedure: k9944 
o|inlining procedure: k9976 
o|inlining procedure: k9976 
o|substituted constant variable: a10068 
o|inlining procedure: k9944 
o|inlining procedure: k9935 
o|inlining procedure: k10078 
o|inlining procedure: k10090 
o|inlining procedure: "(optimizer.scm:1425) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1422) chicken.compiler.optimizer#second" 
o|inlining procedure: k10090 
o|inlining procedure: "(optimizer.scm:1416) chicken.compiler.optimizer#first" 
o|inlining procedure: k10078 
o|inlining procedure: "(optimizer.scm:1414) chicken.compiler.optimizer#fourth" 
o|inlining procedure: k10159 
o|inlining procedure: k10168 
o|inlining procedure: k10210 
o|inlining procedure: "(optimizer.scm:1448) chicken.compiler.optimizer#first" 
o|inlining procedure: k10210 
o|inlining procedure: k10249 
o|inlining procedure: k10249 
o|inlining procedure: k10288 
o|inlining procedure: "(optimizer.scm:1444) chicken.compiler.optimizer#first" 
o|inlining procedure: k10288 
o|inlining procedure: "(optimizer.scm:1439) chicken.compiler.optimizer#third" 
o|inlining procedure: "(optimizer.scm:1439) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1438) chicken.compiler.optimizer#fourth" 
o|inlining procedure: "(optimizer.scm:1436) chicken.compiler.optimizer#first" 
o|inlining procedure: k10168 
o|inlining procedure: k10159 
o|inlining procedure: k10330 
o|inlining procedure: k10339 
o|inlining procedure: k10366 
o|inlining procedure: k10366 
o|inlining procedure: "(optimizer.scm:1481) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1470) chicken.compiler.optimizer#third" 
o|inlining procedure: k10339 
o|inlining procedure: k10330 
o|inlining procedure: "(optimizer.scm:1466) chicken.compiler.optimizer#fourth" 
o|inlining procedure: "(optimizer.scm:1464) chicken.compiler.optimizer#first" 
o|inlining procedure: k10394 
o|inlining procedure: k10403 
o|consed rest parameter at call site: "(optimizer.scm:1495) chicken.compiler.optimizer#cons*" 2 
o|inlining procedure: k10460 
o|contracted procedure: "(optimizer.scm:1506) defarg1866" 
o|inlining procedure: k8351 
o|inlining procedure: k8351 
o|inlining procedure: k10460 
o|inlining procedure: "(optimizer.scm:1496) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1494) chicken.compiler.optimizer#second" 
o|inlining procedure: "(optimizer.scm:1492) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:1491) chicken.compiler.optimizer#first" 
o|inlining procedure: k10403 
o|inlining procedure: k10394 
o|substituted constant variable: a10532 
o|substituted constant variable: a10534 
o|substituted constant variable: a10536 
o|substituted constant variable: a10538 
o|substituted constant variable: a10540 
o|substituted constant variable: a10542 
o|substituted constant variable: a10544 
o|substituted constant variable: a10546 
o|substituted constant variable: a10548 
o|substituted constant variable: a10550 
o|substituted constant variable: a10552 
o|substituted constant variable: a10554 
o|substituted constant variable: a10556 
o|substituted constant variable: a10558 
o|substituted constant variable: a10560 
o|substituted constant variable: a10562 
o|substituted constant variable: a10564 
o|substituted constant variable: a10566 
o|substituted constant variable: a10568 
o|substituted constant variable: a10570 
o|substituted constant variable: a10572 
o|substituted constant variable: a10574 
o|substituted constant variable: a10576 
o|replaced variables: 3057 
o|removed binding forms: 453 
o|substituted constant variable: r351414176 
o|substituted constant variable: r362014182 
o|substituted constant variable: r366014184 
o|substituted constant variable: r381514192 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#second 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#third 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#fourth 
o|substituted constant variable: r402414201 
o|substituted constant variable: r442314202 
o|substituted constant variable: r515614268 
o|substituted constant variable: r514414281 
o|substituted constant variable: r532414295 
o|substituted constant variable: r531414296 
o|substituted constant variable: r530214297 
o|substituted constant variable: r529014298 
o|substituted constant variable: r527814304 
o|substituted constant variable: r538714310 
o|substituted constant variable: r539914312 
o|substituted constant variable: r539914313 
o|substituted constant variable: r526614314 
o|inlining procedure: k5434 
o|inlining procedure: k5504 
o|inlining procedure: k5504 
o|inlining procedure: k5434 
o|substituted constant variable: r581914390 
o|converted assignments to bindings: (cfk1084) 
o|substituted constant variable: r663814501 
o|substituted constant variable: r744414505 
o|substituted constant variable: r662014513 
o|substituted constant variable: r660814514 
o|substituted constant variable: r671014537 
o|substituted constant variable: r679214542 
o|substituted constant variable: r676514543 
o|substituted constant variable: r675314549 
o|substituted constant variable: r674114555 
o|substituted constant variable: r685214562 
o|inlining procedure: k6996 
o|substituted constant variable: r712614596 
o|substituted constant variable: r764514648 
o|substituted constant variable: r1066614682 
o|substituted constant variable: r1065414688 
o|substituted constant variable: r1064514689 
o|substituted constant variable: r1063014690 
o|substituted constant variable: r1061814691 
o|substituted constant variable: r1085214752 
o|substituted constant variable: r1092114761 
o|substituted constant variable: r1092114762 
o|substituted constant variable: r1091514768 
o|substituted constant variable: r1096414770 
o|substituted constant variable: r1096414771 
o|substituted constant variable: r1098414779 
o|substituted constant variable: r1100314780 
o|substituted constant variable: r1100314781 
o|substituted constant variable: r1103214789 
o|substituted constant variable: r1105714790 
o|inlining procedure: k11063 
o|inlining procedure: k11063 
o|substituted constant variable: r1105714801 
o|substituted constant variable: r1115314838 
o|substituted constant variable: r445914851 
o|substituted constant variable: r1121014852 
o|substituted constant variable: r1181914949 
o|inlining procedure: k11885 
o|inlining procedure: k11885 
o|substituted constant variable: r1190614970 
o|substituted constant variable: r1201614971 
o|substituted constant variable: r1199814982 
o|inlining procedure: "(optimizer.scm:1870) chicken.compiler.optimizer#first" 
o|inlining procedure: "(optimizer.scm:947) chicken.compiler.optimizer#register-simplifications" 
o|substituted constant variable: r1287415088 
o|substituted constant variable: r1286215089 
o|substituted constant variable: r1300515091 
o|inlining procedure: "(optimizer.scm:730) chicken.compiler.optimizer#register-simplifications" 
o|substituted constant variable: r1308615095 
o|substituted constant variable: r1322815100 
o|substituted constant variable: r1321915101 
o|substituted constant variable: r1340415103 
o|substituted constant variable: r776615137 
o|substituted constant variable: r784815140 
o|substituted constant variable: r789315143 
o|substituted constant variable: r406815147 
o|converted assignments to bindings: (find-path1697) 
o|substituted constant variable: r1366415167 
o|substituted constant variable: r1369415181 
o|substituted constant variable: r1368215187 
o|substituted constant variable: r1367015198 
o|substituted constant variable: r1357215219 
o|substituted constant variable: r1351815230 
o|substituted constant variable: r1350615236 
o|substituted constant variable: r1381215239 
o|substituted constant variable: r1380015240 
o|substituted constant variable: r1395115244 
o|substituted constant variable: r1393915245 
o|substituted constant variable: r1392715246 
o|inlining procedure: "(optimizer.scm:711) chicken.compiler.optimizer#register-simplifications" 
o|substituted constant variable: r1411015247 
o|substituted constant variable: r832015256 
o|substituted constant variable: r845015267 
o|substituted constant variable: r843815268 
o|substituted constant variable: r851015302 
o|substituted constant variable: r850115308 
o|substituted constant variable: r856815328 
o|substituted constant variable: r867615357 
o|substituted constant variable: r867015358 
o|substituted constant variable: r875315377 
o|substituted constant variable: r874115383 
o|substituted constant variable: r883015397 
o|substituted constant variable: r881815398 
o|substituted constant variable: r891015417 
o|substituted constant variable: r890115423 
o|substituted constant variable: r896915436 
o|substituted constant variable: r902015460 
o|substituted constant variable: r899315473 
o|substituted constant variable: r924815511 
o|substituted constant variable: r923615517 
o|substituted constant variable: r934615531 
o|substituted constant variable: r932815542 
o|substituted constant variable: r940415568 
o|substituted constant variable: r939515574 
o|substituted constant variable: r949215583 
o|substituted constant variable: r947715594 
o|substituted constant variable: r955915613 
o|substituted constant variable: r954715624 
o|substituted constant variable: r953815630 
o|substituted constant variable: r966515645 
o|substituted constant variable: r963015656 
o|substituted constant variable: r961815662 
o|inlining procedure: k9766 
o|substituted constant variable: r980615681 
o|substituted constant variable: r973115682 
o|substituted constant variable: r971915683 
o|substituted constant variable: r983715715 
o|substituted constant variable: r991115729 
o|substituted constant variable: r990215730 
o|substituted constant variable: r994515735 
o|substituted constant variable: r1009115749 
o|substituted constant variable: r1007915755 
o|substituted constant variable: r1028915779 
o|substituted constant variable: r1028915779 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r1016915801 
o|substituted constant variable: r1034015819 
o|substituted constant variable: r1033115820 
o|substituted constant variable: r1040415857 
o|simplifications: ((let . 2)) 
o|replaced variables: 1142 
o|removed binding forms: 2467 
o|inlining procedure: k5164 
o|inlining procedure: "(optimizer.scm:186) chicken.compiler.optimizer#alist-cons" 
o|inlining procedure: k5128 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: k5256 
o|inlining procedure: "(optimizer.scm:313) chicken.compiler.optimizer#alist-cons" 
o|inlining procedure: "(optimizer.scm:457) chicken.compiler.optimizer#alist-cons" 
o|inlining procedure: k7323 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#register-simplifications 
o|inlining procedure: "(optimizer.scm:1587) chicken.compiler.optimizer#alist-cons" 
o|substituted constant variable: r110571479015985 
o|substituted constant variable: r110571479015988 
o|inlining procedure: "(optimizer.scm:1667) chicken.compiler.optimizer#alist-cons" 
o|inlining procedure: "(optimizer.scm:1692) chicken.compiler.optimizer#alist-cons" 
o|inlining procedure: "(optimizer.scm:1778) chicken.compiler.optimizer#alist-cons" 
o|substituted constant variable: class142116061 
o|substituted constant variable: class142116069 
o|inlining procedure: "(optimizer.scm:1017) chicken.compiler.optimizer#alist-cons" 
o|inlining procedure: "(optimizer.scm:1029) chicken.compiler.optimizer#alist-cons" 
o|inlining procedure: "(optimizer.scm:1043) chicken.compiler.optimizer#alist-cons" 
o|substituted constant variable: class142116120 
o|inlining procedure: "(optimizer.scm:725) chicken.compiler.optimizer#alist-cons" 
o|removed call to pure procedure with unused result: "(optimizer.scm:1222) ##sys#slot" 
o|inlining procedure: "(optimizer.scm:1342) chicken.compiler.optimizer#fifth" 
o|inlining procedure: "(optimizer.scm:1437) chicken.compiler.optimizer#fifth" 
o|inlining procedure: "(optimizer.scm:1477) chicken.compiler.optimizer#fifth" 
o|replaced variables: 12 
o|removed binding forms: 915 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#fifth 
o|removed side-effect free assignment to unused variable: chicken.compiler.optimizer#alist-cons 
o|substituted constant variable: y25116195 
o|substituted constant variable: r512916202 
o|substituted constant variable: r512916202 
o|substituted constant variable: r525716205 
o|substituted constant variable: r525716205 
o|substituted constant variable: r525716208 
o|substituted constant variable: r525716208 
o|substituted constant variable: r525716211 
o|substituted constant variable: r525716211 
o|substituted constant variable: r525716214 
o|substituted constant variable: r525716214 
o|substituted constant variable: r525716217 
o|substituted constant variable: r525716217 
o|substituted constant variable: r525716220 
o|substituted constant variable: r525716220 
o|substituted constant variable: r525716223 
o|substituted constant variable: r525716223 
o|substituted constant variable: r525716226 
o|substituted constant variable: r525716226 
o|substituted constant variable: r525716229 
o|substituted constant variable: r525716229 
o|substituted constant variable: r525716232 
o|substituted constant variable: r525716232 
o|substituted constant variable: r525716235 
o|substituted constant variable: r525716235 
o|substituted constant variable: r525716238 
o|substituted constant variable: r525716238 
o|substituted constant variable: x25016308 
o|substituted constant variable: y25116407 
o|contracted procedure: k9190 
o|inlining procedure: k9871 
o|replaced variables: 35 
o|removed binding forms: 47 
o|removed conditional forms: 13 
o|substituted constant variable: r987216597 
o|removed binding forms: 54 
o|removed conditional forms: 1 
o|removed binding forms: 1 
o|simplifications: ((if . 46) (let . 41) (##core#call . 1305)) 
o|  call simplifications:
o|    scheme#>=
o|    scheme#symbol?
o|    scheme#cddddr	4
o|    scheme#*
o|    scheme#<=
o|    chicken.fixnum#fx<
o|    scheme#=	10
o|    chicken.base#fixnum?
o|    chicken.fixnum#fx=
o|    ##sys#cons	17
o|    ##sys#list	87
o|    scheme#assoc
o|    scheme#-
o|    chicken.fixnum#fx>	2
o|    scheme#set-car!
o|    scheme#list?	6
o|    scheme#>	5
o|    scheme#length	44
o|    scheme#<	6
o|    ##sys#call-with-values	6
o|    scheme#cadddr	16
o|    scheme#+	8
o|    scheme#cddr	6
o|    scheme#member	4
o|    scheme#list	150
o|    scheme#cadr	55
o|    scheme#caddr	34
o|    scheme#caar	2
o|    scheme#assq	10
o|    scheme#set-cdr!	3
o|    scheme#equal?	6
o|    scheme#eq?	149
o|    scheme#memq	17
o|    chicken.fixnum#fx>=
o|    chicken.fixnum#fx+
o|    scheme#not	60
o|    scheme#null?	32
o|    scheme#apply	3
o|    scheme#cdr	39
o|    ##sys#setslot	18
o|    ##sys#check-list	32
o|    scheme#pair?	63
o|    ##sys#slot	106
o|    scheme#values	8
o|    chicken.fixnum#fx<=	3
o|    scheme#car	178
o|    chicken.fixnum#fx-	2
o|    scheme#cons	102
o|contracted procedure: k3516 
o|contracted procedure: k3523 
o|contracted procedure: k3533 
o|contracted procedure: k3574 
o|contracted procedure: k3588 
o|contracted procedure: k3598 
o|contracted procedure: k3592 
o|contracted procedure: k3607 
o|contracted procedure: k3610 
o|contracted procedure: k3622 
o|contracted procedure: k3638 
o|contracted procedure: k3646 
o|contracted procedure: k3653 
o|contracted procedure: k3677 
o|contracted procedure: k3694 
o|contracted procedure: k3716 
o|contracted procedure: k3712 
o|contracted procedure: k3697 
o|contracted procedure: k3700 
o|contracted procedure: k3708 
o|contracted procedure: k3723 
o|contracted procedure: k3731 
o|contracted procedure: k3743 
o|contracted procedure: k3765 
o|contracted procedure: k3761 
o|contracted procedure: k3746 
o|contracted procedure: k3749 
o|contracted procedure: k3757 
o|contracted procedure: k3780 
o|contracted procedure: k3789 
o|contracted procedure: k3802 
o|contracted procedure: k3817 
o|contracted procedure: k3832 
o|contracted procedure: k3847 
o|contracted procedure: k3858 
o|contracted procedure: k3903 
o|contracted procedure: k3929 
o|contracted procedure: k4014 
o|contracted procedure: k4026 
o|contracted procedure: k4044 
o|contracted procedure: k4052 
o|contracted procedure: k4425 
o|contracted procedure: k4440 
o|contracted procedure: k4709 
o|contracted procedure: k4712 
o|contracted procedure: k4719 
o|contracted procedure: k4746 
o|contracted procedure: k4758 
o|contracted procedure: k4768 
o|contracted procedure: k4772 
o|contracted procedure: k4790 
o|contracted procedure: k4793 
o|contracted procedure: k4814 
o|contracted procedure: k4810 
o|contracted procedure: k4821 
o|contracted procedure: k4835 
o|contracted procedure: k4824 
o|contracted procedure: k4831 
o|contracted procedure: k4841 
o|contracted procedure: k4857 
o|contracted procedure: k4861 
o|contracted procedure: k4867 
o|contracted procedure: k4193 
o|contracted procedure: k4183 
o|contracted procedure: k4891 
o|contracted procedure: k4894 
o|contracted procedure: k4900 
o|contracted procedure: k4909 
o|contracted procedure: k4912 
o|contracted procedure: k4915 
o|contracted procedure: k4933 
o|contracted procedure: k4956 
o|contracted procedure: k4975 
o|contracted procedure: k5006 
o|contracted procedure: k5018 
o|contracted procedure: k5028 
o|contracted procedure: k5032 
o|contracted procedure: k5035 
o|contracted procedure: k3978 
o|contracted procedure: k3981 
o|contracted procedure: k3991 
o|contracted procedure: k5093 
o|contracted procedure: k5105 
o|contracted procedure: k5119 
o|contracted procedure: k5108 
o|contracted procedure: k5115 
o|contracted procedure: k5140 
o|contracted procedure: k5158 
o|contracted procedure: k5161 
o|contracted procedure: k5178 
o|contracted procedure: k5164 
o|contracted procedure: k400816199 
o|contracted procedure: k5182 
o|contracted procedure: k5186 
o|contracted procedure: k5190 
o|contracted procedure: k5199 
o|contracted procedure: k5202 
o|contracted procedure: k5214 
o|contracted procedure: k5217 
o|contracted procedure: k5220 
o|contracted procedure: k5228 
o|contracted procedure: k5236 
o|contracted procedure: k5243 
o|contracted procedure: k5253 
o|contracted procedure: k5262 
o|contracted procedure: k5274 
o|contracted procedure: k5280 
o|contracted procedure: k5286 
o|contracted procedure: k5292 
o|contracted procedure: k5298 
o|contracted procedure: k5310 
o|contracted procedure: k5320 
o|contracted procedure: k5340 
o|contracted procedure: k5344 
o|contracted procedure: k5383 
o|contracted procedure: k5389 
o|contracted procedure: k5395 
o|contracted procedure: k5401 
o|contracted procedure: k5418 
o|contracted procedure: k5437 
o|contracted procedure: k5470 
o|contracted procedure: k5443 
o|contracted procedure: k5458 
o|contracted procedure: k5455 
o|contracted procedure: k5476 
o|contracted procedure: k5485 
o|contracted procedure: k5537 
o|contracted procedure: k5541 
o|contracted procedure: k5492 
o|contracted procedure: k5501 
o|contracted procedure: k4242 
o|contracted procedure: k4268 
o|contracted procedure: k4248 
o|contracted procedure: k4262 
o|contracted procedure: k5525 
o|contracted procedure: k5533 
o|contracted procedure: k5529 
o|contracted procedure: k5585 
o|contracted procedure: k5607 
o|contracted procedure: k5682 
o|contracted procedure: k5678 
o|contracted procedure: k5621 
o|contracted procedure: k5628 
o|contracted procedure: k5634 
o|contracted procedure: k5642 
o|contracted procedure: k5664 
o|contracted procedure: k5686 
o|contracted procedure: k5692 
o|contracted procedure: k5695 
o|contracted procedure: k5716 
o|contracted procedure: k5726 
o|contracted procedure: k5734 
o|contracted procedure: k5746 
o|contracted procedure: k5749 
o|contracted procedure: k5752 
o|contracted procedure: k5760 
o|contracted procedure: k5768 
o|contracted procedure: k5781 
o|contracted procedure: k400816251 
o|contracted procedure: k5789 
o|contracted procedure: k5792 
o|contracted procedure: k5799 
o|contracted procedure: k5807 
o|contracted procedure: k5815 
o|contracted procedure: k5834 
o|contracted procedure: k5837 
o|contracted procedure: k5840 
o|contracted procedure: k3414 
o|contracted procedure: k3438 
o|contracted procedure: k3449 
o|contracted procedure: k3457 
o|contracted procedure: k5903 
o|contracted procedure: k5907 
o|contracted procedure: k5915 
o|contracted procedure: k5883 
o|contracted procedure: k5887 
o|contracted procedure: k5895 
o|contracted procedure: k5899 
o|contracted procedure: k5977 
o|contracted procedure: k5981 
o|contracted procedure: k5989 
o|contracted procedure: k5957 
o|contracted procedure: k5961 
o|contracted procedure: k5969 
o|contracted procedure: k5973 
o|contracted procedure: k5998 
o|contracted procedure: k6004 
o|contracted procedure: k6013 
o|contracted procedure: k6016 
o|contracted procedure: k6025 
o|contracted procedure: k6028 
o|contracted procedure: k6047 
o|contracted procedure: k6067 
o|contracted procedure: k6081 
o|contracted procedure: k6094 
o|contracted procedure: k6104 
o|contracted procedure: k6108 
o|contracted procedure: k6133 
o|contracted procedure: k6141 
o|contracted procedure: k6137 
o|contracted procedure: k6157 
o|contracted procedure: k6166 
o|contracted procedure: k6192 
o|contracted procedure: k6234 
o|contracted procedure: k400816268 
o|contracted procedure: k6224 
o|propagated global variable: z25216265 chicken.compiler.optimizer#inline-history 
o|contracted procedure: k6238 
o|contracted procedure: k6251 
o|contracted procedure: k6261 
o|contracted procedure: k6265 
o|contracted procedure: k6269 
o|contracted procedure: k6273 
o|contracted procedure: k6464 
o|contracted procedure: k6291 
o|contracted procedure: k6306 
o|contracted procedure: k6309 
o|contracted procedure: k6315 
o|contracted procedure: k6323 
o|contracted procedure: k6341 
o|contracted procedure: k6344 
o|contracted procedure: k6347 
o|contracted procedure: k6355 
o|contracted procedure: k6363 
o|contracted procedure: k6399 
o|contracted procedure: k6403 
o|contracted procedure: k6436 
o|contracted procedure: k6449 
o|contracted procedure: k6453 
o|contracted procedure: k6459 
o|contracted procedure: k6591 
o|contracted procedure: k6479 
o|contracted procedure: k6504 
o|contracted procedure: k6511 
o|contracted procedure: k6519 
o|contracted procedure: k6531 
o|contracted procedure: k6534 
o|contracted procedure: k6537 
o|contracted procedure: k6545 
o|contracted procedure: k6553 
o|contracted procedure: k6564 
o|contracted procedure: k6571 
o|contracted procedure: k6587 
o|contracted procedure: k6581 
o|contracted procedure: k6604 
o|contracted procedure: k6616 
o|contracted procedure: k6622 
o|contracted procedure: k6646 
o|contracted procedure: k7422 
o|contracted procedure: k7431 
o|contracted procedure: k7462 
o|contracted procedure: k7440 
o|contracted procedure: k7446 
o|contracted procedure: k6649 
o|contracted procedure: k6659 
o|contracted procedure: k6693 
o|contracted procedure: k6699 
o|contracted procedure: k6712 
o|contracted procedure: k6719 
o|contracted procedure: k6737 
o|contracted procedure: k6743 
o|contracted procedure: k6755 
o|contracted procedure: k6761 
o|contracted procedure: k6794 
o|contracted procedure: k6813 
o|contracted procedure: k6824 
o|contracted procedure: k6845 
o|contracted procedure: k6854 
o|contracted procedure: k6865 
o|contracted procedure: k6876 
o|contracted procedure: k6899 
o|contracted procedure: k6905 
o|contracted procedure: k6968 
o|contracted procedure: k6918 
o|contracted procedure: k6922 
o|contracted procedure: k6939 
o|contracted procedure: k6942 
o|contracted procedure: k6945 
o|contracted procedure: k6953 
o|contracted procedure: k6961 
o|contracted procedure: k6981 
o|contracted procedure: k6984 
o|contracted procedure: k7038 
o|contracted procedure: k7087 
o|contracted procedure: k7078 
o|contracted procedure: k7104 
o|contracted procedure: k7095 
o|contracted procedure: k7041 
o|contracted procedure: k7053 
o|contracted procedure: k7063 
o|contracted procedure: k7067 
o|contracted procedure: k7108 
o|contracted procedure: k7116 
o|contracted procedure: k7119 
o|contracted procedure: k7128 
o|contracted procedure: k7134 
o|contracted procedure: k7145 
o|contracted procedure: k7170 
o|contracted procedure: k7176 
o|contracted procedure: k7204 
o|contracted procedure: k7210 
o|contracted procedure: k7251 
o|contracted procedure: k7277 
o|contracted procedure: k7283 
o|contracted procedure: k7292 
o|contracted procedure: k7329 
o|contracted procedure: k7335 
o|contracted procedure: k7341 
o|contracted procedure: k7347 
o|contracted procedure: k7384 
o|contracted procedure: k7396 
o|contracted procedure: k7406 
o|contracted procedure: k7410 
o|contracted procedure: k7367 
o|contracted procedure: k7381 
o|propagated global variable: g13161318 chicken.compiler.optimizer#simplified-ops 
o|contracted procedure: k7413 
o|contracted procedure: k7487 
o|contracted procedure: k7498 
o|contracted procedure: k7504 
o|contracted procedure: k7519 
o|contracted procedure: k7522 
o|contracted procedure: k7534 
o|contracted procedure: k7546 
o|contracted procedure: k7556 
o|contracted procedure: k7576 
o|contracted procedure: k7572 
o|contracted procedure: k7586 
o|contracted procedure: k7589 
o|contracted procedure: k7596 
o|contracted procedure: k7623 
o|contracted procedure: k7611 
o|contracted procedure: k7626 
o|contracted procedure: k7633 
o|contracted procedure: k7670 
o|contracted procedure: k7647 
o|contracted procedure: k7665 
o|contracted procedure: k7653 
o|contracted procedure: k7673 
o|contracted procedure: k7688 
o|contracted procedure: k7694 
o|contracted procedure: k7697 
o|contracted procedure: k7709 
o|contracted procedure: k7719 
o|contracted procedure: k7723 
o|contracted procedure: k8287 
o|contracted procedure: k8298 
o|contracted procedure: k10595 
o|contracted procedure: k10598 
o|contracted procedure: k10614 
o|contracted procedure: k10620 
o|contracted procedure: k10626 
o|contracted procedure: k10632 
o|contracted procedure: k10656 
o|contracted procedure: k10662 
o|contracted procedure: k10687 
o|contracted procedure: k10691 
o|contracted procedure: k10668 
o|contracted procedure: k10675 
o|contracted procedure: k10679 
o|contracted procedure: k10683 
o|contracted procedure: k10699 
o|contracted procedure: k10713 
o|contracted procedure: k10720 
o|contracted procedure: k10724 
o|contracted procedure: k10730 
o|contracted procedure: k10740 
o|contracted procedure: k10744 
o|contracted procedure: k10748 
o|contracted procedure: k10756 
o|contracted procedure: k10768 
o|contracted procedure: k10778 
o|contracted procedure: k10782 
o|contracted procedure: k10809 
o|contracted procedure: k10812 
o|contracted procedure: k10815 
o|contracted procedure: k10838 
o|contracted procedure: k10821 
o|contracted procedure: k10830 
o|contracted procedure: k10834 
o|contracted procedure: k10848 
o|contracted procedure: k10858 
o|contracted procedure: k10865 
o|contracted procedure: k10872 
o|contracted procedure: k10882 
o|contracted procedure: k10888 
o|contracted procedure: k10905 
o|contracted procedure: k10892 
o|contracted procedure: k10911 
o|contracted procedure: k10923 
o|contracted procedure: k400816298 
o|contracted procedure: k10927 
o|contracted procedure: k10935 
o|contracted procedure: k10941 
o|contracted procedure: k10966 
o|contracted procedure: k10970 
o|contracted procedure: k10974 
o|contracted procedure: k10980 
o|contracted procedure: k11005 
o|contracted procedure: k11009 
o|contracted procedure: k11013 
o|contracted procedure: k11019 
o|contracted procedure: k11022 
o|contracted procedure: k11028 
o|contracted procedure: k11034 
o|contracted procedure: k11050 
o|contracted procedure: k11053 
o|contracted procedure: k11060 
o|contracted procedure: k11067 
o|contracted procedure: k11075 
o|contracted procedure: k11071 
o|contracted procedure: k11100 
o|contracted procedure: k11103 
o|contracted procedure: k11113 
o|contracted procedure: k11117 
o|contracted procedure: k11132 
o|contracted procedure: k11139 
o|contracted procedure: k11143 
o|contracted procedure: k11149 
o|contracted procedure: k11162 
o|contracted procedure: k11170 
o|contracted procedure: k11174 
o|contracted procedure: k4474 
o|contracted procedure: k4478 
o|contracted procedure: k4461 
o|contracted procedure: k11835 
o|contracted procedure: k11232 
o|contracted procedure: k11244 
o|contracted procedure: k11253 
o|contracted procedure: k11264 
o|contracted procedure: k11330 
o|contracted procedure: k11323 
o|contracted procedure: k11273 
o|contracted procedure: k11287 
o|contracted procedure: k11283 
o|contracted procedure: k11295 
o|contracted procedure: k11305 
o|contracted procedure: k11299 
o|contracted procedure: k11320 
o|contracted procedure: k11316 
o|contracted procedure: k11308 
o|contracted procedure: k11336 
o|contracted procedure: k11345 
o|contracted procedure: k11354 
o|contracted procedure: k11399 
o|contracted procedure: k11413 
o|contracted procedure: k11365 
o|contracted procedure: k11402 
o|contracted procedure: k11409 
o|contracted procedure: k11383 
o|contracted procedure: k11422 
o|contracted procedure: k11471 
o|contracted procedure: k11464 
o|contracted procedure: k11431 
o|contracted procedure: k11435 
o|contracted procedure: k11438 
o|contracted procedure: k11479 
o|contracted procedure: k11491 
o|contracted procedure: k11501 
o|contracted procedure: k11505 
o|contracted procedure: k11511 
o|contracted procedure: k11528 
o|contracted procedure: k11532 
o|contracted procedure: k11550 
o|contracted procedure: k11553 
o|contracted procedure: k11556 
o|contracted procedure: k11568 
o|contracted procedure: k11703 
o|contracted procedure: k11574 
o|contracted procedure: k400816313 
o|contracted procedure: k11578 
o|contracted procedure: k11673 
o|contracted procedure: k11584 
o|contracted procedure: k11597 
o|contracted procedure: k11601 
o|contracted procedure: k11669 
o|contracted procedure: k11604 
o|contracted procedure: k11612 
o|contracted procedure: k11615 
o|contracted procedure: k11631 
o|contracted procedure: k11639 
o|contracted procedure: k11643 
o|contracted procedure: k11651 
o|contracted procedure: k11699 
o|contracted procedure: k11679 
o|contracted procedure: k11692 
o|contracted procedure: k11713 
o|contracted procedure: k11716 
o|contracted procedure: k11719 
o|contracted procedure: k11725 
o|contracted procedure: k400816320 
o|contracted procedure: k11729 
o|contracted procedure: k11739 
o|contracted procedure: k11742 
o|contracted procedure: k11754 
o|contracted procedure: k11764 
o|contracted procedure: k11768 
o|contracted procedure: k11771 
o|contracted procedure: k11783 
o|contracted procedure: k11793 
o|contracted procedure: k11797 
o|contracted procedure: k11815 
o|contracted procedure: k11821 
o|contracted procedure: k11828 
o|contracted procedure: k11838 
o|contracted procedure: k4123 
o|contracted procedure: k4131 
o|contracted procedure: k4143 
o|contracted procedure: k4165 
o|contracted procedure: k4161 
o|contracted procedure: k4146 
o|contracted procedure: k4149 
o|contracted procedure: k4157 
o|contracted procedure: k11882 
o|contracted procedure: k11898 
o|contracted procedure: k11890 
o|contracted procedure: k400816335 
o|contracted procedure: k11894 
o|contracted procedure: k11941 
o|contracted procedure: k11944 
o|contracted procedure: k11947 
o|contracted procedure: k11950 
o|contracted procedure: k11964 
o|contracted procedure: k11974 
o|contracted procedure: k11981 
o|contracted procedure: k11994 
o|contracted procedure: k12000 
o|contracted procedure: k12003 
o|contracted procedure: k12006 
o|contracted procedure: k12012 
o|contracted procedure: k12031 
o|contracted procedure: k12035 
o|contracted procedure: k12018 
o|contracted procedure: k12024 
o|contracted procedure: k11908 
o|contracted procedure: k11915 
o|contracted procedure: k12062 
o|contracted procedure: k12075 
o|contracted procedure: k12078 
o|contracted procedure: k12085 
o|contracted procedure: k12108 
o|contracted procedure: k12126 
o|contracted procedure: k12138 
o|contracted procedure: k12148 
o|contracted procedure: k12152 
o|contracted procedure: k12172 
o|contracted procedure: k12182 
o|contracted procedure: k12187 
o|contracted procedure: k12190 
o|contracted procedure: k12196 
o|contracted procedure: k12199 
o|contracted procedure: k12202 
o|contracted procedure: k12214 
o|contracted procedure: k12239 
o|contracted procedure: k12242 
o|contracted procedure: k12245 
o|contracted procedure: k12253 
o|contracted procedure: k12261 
o|contracted procedure: k12275 
o|contracted procedure: k12303 
o|contracted procedure: k12306 
o|contracted procedure: k12337 
o|contracted procedure: k12345 
o|contracted procedure: k12359 
o|contracted procedure: k12349 
o|contracted procedure: k12366 
o|contracted procedure: k12378 
o|contracted procedure: k12388 
o|contracted procedure: k12392 
o|contracted procedure: k12396 
o|contracted procedure: k12408 
o|contracted procedure: k12418 
o|contracted procedure: k12422 
o|contracted procedure: k12428 
o|contracted procedure: k12448 
o|contracted procedure: k12452 
o|contracted procedure: k12464 
o|contracted procedure: k12468 
o|contracted procedure: k12496 
o|contracted procedure: k12510 
o|contracted procedure: k12514 
o|contracted procedure: k12522 
o|contracted procedure: k12526 
o|contracted procedure: k12534 
o|contracted procedure: k12542 
o|contracted procedure: k12550 
o|contracted procedure: k12572 
o|contracted procedure: k12581 
o|contracted procedure: k12615 
o|contracted procedure: k12591 
o|contracted procedure: k12595 
o|contracted procedure: k12611 
o|contracted procedure: k12619 
o|contracted procedure: k12636 
o|contracted procedure: k12639 
o|contracted procedure: k12662 
o|contracted procedure: k12674 
o|contracted procedure: k12696 
o|contracted procedure: k12692 
o|contracted procedure: k12677 
o|contracted procedure: k12680 
o|contracted procedure: k12688 
o|contracted procedure: k12707 
o|contracted procedure: k12717 
o|contracted procedure: k12729 
o|contracted procedure: k12741 
o|contracted procedure: k12763 
o|contracted procedure: k12726 
o|contracted procedure: k12759 
o|contracted procedure: k12744 
o|contracted procedure: k12747 
o|contracted procedure: k12755 
o|contracted procedure: k12775 
o|contracted procedure: k12778 
o|contracted procedure: k12781 
o|contracted procedure: k12789 
o|contracted procedure: k12797 
o|contracted procedure: k12803 
o|contracted procedure: k12813 
o|contracted procedure: k12822 
o|contracted procedure: k12832 
o|contracted procedure: k12836 
o|contracted procedure: k13047 
o|contracted procedure: k13043 
o|contracted procedure: k13027 
o|contracted procedure: k13039 
o|contracted procedure: k13035 
o|contracted procedure: k13031 
o|contracted procedure: k12994 
o|contracted procedure: k12998 
o|contracted procedure: k13011 
o|contracted procedure: k13023 
o|contracted procedure: k12840 
o|contracted procedure: k12982 
o|contracted procedure: k12990 
o|contracted procedure: k12986 
o|contracted procedure: k12978 
o|contracted procedure: k12848 
o|contracted procedure: k12852 
o|contracted procedure: k12858 
o|contracted procedure: k12864 
o|contracted procedure: k12966 
o|contracted procedure: k12870 
o|contracted procedure: k12962 
o|contracted procedure: k12879 
o|contracted procedure: k12886 
o|contracted procedure: k12890 
o|contracted procedure: k12898 
o|contracted procedure: k12911 
o|contracted procedure: k12920 
o|contracted procedure: k12932 
o|contracted procedure: k12947 
o|contracted procedure: k12955 
o|contracted procedure: k12844 
o|contracted procedure: k13998 
o|contracted procedure: k14062 
o|contracted procedure: k14078 
o|contracted procedure: k14066 
o|contracted procedure: k14074 
o|contracted procedure: k14070 
o|contracted procedure: k14002 
o|contracted procedure: k14058 
o|contracted procedure: k14010 
o|contracted procedure: k14018 
o|contracted procedure: k14038 
o|contracted procedure: k14054 
o|contracted procedure: k14042 
o|contracted procedure: k14050 
o|contracted procedure: k14046 
o|contracted procedure: k14022 
o|contracted procedure: k14034 
o|contracted procedure: k14030 
o|contracted procedure: k14026 
o|contracted procedure: k14014 
o|contracted procedure: k14006 
o|contracted procedure: k13916 
o|contracted procedure: k13920 
o|contracted procedure: k13929 
o|contracted procedure: k13986 
o|contracted procedure: k13947 
o|contracted procedure: k13977 
o|contracted procedure: k13953 
o|contracted procedure: k13960 
o|contracted procedure: k13051 
o|contracted procedure: k13852 
o|contracted procedure: k13896 
o|contracted procedure: k13912 
o|contracted procedure: k13900 
o|contracted procedure: k13908 
o|contracted procedure: k13904 
o|contracted procedure: k13856 
o|contracted procedure: k13892 
o|contracted procedure: k13864 
o|contracted procedure: k13876 
o|contracted procedure: k13888 
o|contracted procedure: k13884 
o|contracted procedure: k13880 
o|contracted procedure: k13872 
o|contracted procedure: k13868 
o|contracted procedure: k13860 
o|contracted procedure: k13789 
o|contracted procedure: k13793 
o|contracted procedure: k13802 
o|contracted procedure: k13840 
o|contracted procedure: k13814 
o|contracted procedure: k13821 
o|contracted procedure: k13055 
o|contracted procedure: k13781 
o|contracted procedure: k13785 
o|contracted procedure: k13476 
o|contracted procedure: k13480 
o|contracted procedure: k13490 
o|contracted procedure: k13508 
o|contracted procedure: k13777 
o|contracted procedure: k13514 
o|contracted procedure: k13520 
o|contracted procedure: k13526 
o|contracted procedure: k13529 
o|contracted procedure: k13544 
o|contracted procedure: k13559 
o|contracted procedure: k13551 
o|contracted procedure: k13555 
o|contracted procedure: k13565 
o|contracted procedure: k13574 
o|contracted procedure: k13749 
o|contracted procedure: k13753 
o|contracted procedure: k13580 
o|contracted procedure: k13745 
o|contracted procedure: k13587 
o|contracted procedure: k13593 
o|contracted procedure: k13630 
o|contracted procedure: k13618 
o|contracted procedure: k13622 
o|contracted procedure: k13626 
o|contracted procedure: k13638 
o|contracted procedure: k13644 
o|contracted procedure: k7744 
o|contracted procedure: k7747 
o|contracted procedure: k7750 
o|contracted procedure: k7797 
o|contracted procedure: k7768 
o|contracted procedure: k7793 
o|contracted procedure: k7771 
o|contracted procedure: k7774 
o|contracted procedure: k7780 
o|contracted procedure: k400816370 
o|contracted procedure: k7803 
o|contracted procedure: k7867 
o|contracted procedure: k7818 
o|contracted procedure: k7841 
o|contracted procedure: k400816377 
o|contracted procedure: k7825 
o|contracted procedure: k7833 
o|contracted procedure: k7863 
o|contracted procedure: k7850 
o|contracted procedure: k7875 
o|contracted procedure: k400816384 
o|contracted procedure: k7882 
o|contracted procedure: k7910 
o|contracted procedure: k7895 
o|contracted procedure: k7906 
o|contracted procedure: k4058 
o|contracted procedure: k4070 
o|contracted procedure: k4093 
o|contracted procedure: k4101 
o|contracted procedure: k7927 
o|contracted procedure: k7942 
o|contracted procedure: k7960 
o|contracted procedure: k7967 
o|contracted procedure: k8136 
o|contracted procedure: k7973 
o|contracted procedure: k7976 
o|contracted procedure: k7986 
o|contracted procedure: k8001 
o|contracted procedure: k7997 
o|contracted procedure: k7993 
o|contracted procedure: k8013 
o|contracted procedure: k8037 
o|contracted procedure: k8022 
o|contracted procedure: k8026 
o|contracted procedure: k8045 
o|contracted procedure: k8048 
o|contracted procedure: k8060 
o|contracted procedure: k8069 
o|contracted procedure: k8073 
o|contracted procedure: k8081 
o|contracted procedure: k8093 
o|contracted procedure: k8089 
o|contracted procedure: k8085 
o|contracted procedure: k8104 
o|contracted procedure: k8112 
o|contracted procedure: k8115 
o|contracted procedure: k8130 
o|contracted procedure: k8126 
o|contracted procedure: k8122 
o|contracted procedure: k8143 
o|contracted procedure: k8152 
o|contracted procedure: k8162 
o|contracted procedure: k8166 
o|contracted procedure: k8175 
o|contracted procedure: k8185 
o|contracted procedure: k8189 
o|contracted procedure: k8223 
o|contracted procedure: k8198 
o|contracted procedure: k8208 
o|contracted procedure: k8212 
o|contracted procedure: k8216 
o|contracted procedure: k8220 
o|contracted procedure: k8271 
o|contracted procedure: k8235 
o|contracted procedure: k8261 
o|contracted procedure: k8265 
o|contracted procedure: k8257 
o|contracted procedure: k8238 
o|contracted procedure: k8241 
o|contracted procedure: k8249 
o|contracted procedure: k8253 
o|contracted procedure: k13666 
o|contracted procedure: k13741 
o|contracted procedure: k13672 
o|contracted procedure: k13678 
o|contracted procedure: k13684 
o|contracted procedure: k13690 
o|contracted procedure: k13696 
o|contracted procedure: k13705 
o|contracted procedure: k13713 
o|contracted procedure: k13721 
o|contracted procedure: k13729 
o|contracted procedure: k13737 
o|contracted procedure: k13765 
o|contracted procedure: k13773 
o|contracted procedure: k13059 
o|contracted procedure: k13448 
o|contracted procedure: k13472 
o|contracted procedure: k13468 
o|contracted procedure: k13452 
o|contracted procedure: k13464 
o|contracted procedure: k13460 
o|contracted procedure: k13456 
o|contracted procedure: k13393 
o|contracted procedure: k13397 
o|contracted procedure: k13440 
o|contracted procedure: k13406 
o|contracted procedure: k13432 
o|contracted procedure: k13412 
o|contracted procedure: k13419 
o|contracted procedure: k13427 
o|contracted procedure: k13063 
o|contracted procedure: k13353 
o|contracted procedure: k13389 
o|contracted procedure: k13385 
o|contracted procedure: k13357 
o|contracted procedure: k13381 
o|contracted procedure: k13365 
o|contracted procedure: k13377 
o|contracted procedure: k13373 
o|contracted procedure: k13369 
o|contracted procedure: k13361 
o|contracted procedure: k13208 
o|contracted procedure: k13212 
o|contracted procedure: k13349 
o|contracted procedure: k13224 
o|contracted procedure: k13230 
o|contracted procedure: k13337 
o|contracted procedure: k13236 
o|contracted procedure: k13248 
o|contracted procedure: k13258 
o|contracted procedure: k13270 
o|contracted procedure: k13289 
o|contracted procedure: k13297 
o|contracted procedure: k13306 
o|contracted procedure: k13311 
o|contracted procedure: k13318 
o|contracted procedure: k13332 
o|contracted procedure: k13067 
o|contracted procedure: k13184 
o|contracted procedure: k13204 
o|contracted procedure: k13200 
o|contracted procedure: k13188 
o|contracted procedure: k13196 
o|contracted procedure: k13192 
o|contracted procedure: k13075 
o|contracted procedure: k13079 
o|contracted procedure: k13176 
o|contracted procedure: k13091 
o|contracted procedure: k13103 
o|contracted procedure: k13128 
o|contracted procedure: k13136 
o|contracted procedure: k13145 
o|contracted procedure: k13150 
o|contracted procedure: k13157 
o|contracted procedure: k13171 
o|contracted procedure: k13071 
o|contracted procedure: k14173 
o|contracted procedure: k14165 
o|contracted procedure: k14169 
o|contracted procedure: k14161 
o|contracted procedure: k14157 
o|contracted procedure: k14086 
o|contracted procedure: k14090 
o|contracted procedure: k14103 
o|contracted procedure: k14112 
o|contracted procedure: k14123 
o|contracted procedure: k14134 
o|contracted procedure: k14126 
o|contracted procedure: k400816411 
o|contracted procedure: k14138 
o|propagated global variable: z25216408 chicken.compiler.optimizer#simplified-ops 
o|contracted procedure: k14150 
o|contracted procedure: k8307 
o|contracted procedure: k8322 
o|contracted procedure: k8338 
o|contracted procedure: k8345 
o|contracted procedure: k8387 
o|contracted procedure: k8409 
o|contracted procedure: k8413 
o|contracted procedure: k8425 
o|contracted procedure: k8421 
o|contracted procedure: k8487 
o|contracted procedure: k8491 
o|contracted procedure: k8428 
o|contracted procedure: k8431 
o|contracted procedure: k8434 
o|contracted procedure: k8440 
o|contracted procedure: k8446 
o|contracted procedure: k8452 
o|contracted procedure: k8459 
o|contracted procedure: k8463 
o|contracted procedure: k8497 
o|contracted procedure: k8551 
o|contracted procedure: k8555 
o|contracted procedure: k8506 
o|contracted procedure: k8518 
o|contracted procedure: k8521 
o|contracted procedure: k8524 
o|contracted procedure: k8531 
o|contracted procedure: k8535 
o|contracted procedure: k8547 
o|contracted procedure: k8543 
o|contracted procedure: k8561 
o|contracted procedure: k8660 
o|contracted procedure: k8576 
o|contracted procedure: k8582 
o|contracted procedure: k8594 
o|contracted procedure: k8618 
o|contracted procedure: k8603 
o|contracted procedure: k8607 
o|contracted procedure: k8626 
o|contracted procedure: k8633 
o|contracted procedure: k8637 
o|contracted procedure: k8645 
o|contracted procedure: k8652 
o|contracted procedure: k8656 
o|contracted procedure: k8666 
o|contracted procedure: k8728 
o|contracted procedure: k8678 
o|contracted procedure: k8723 
o|contracted procedure: k8691 
o|contracted procedure: k8703 
o|contracted procedure: k8711 
o|contracted procedure: k8695 
o|contracted procedure: k8715 
o|contracted procedure: k8719 
o|contracted procedure: k8734 
o|contracted procedure: k8808 
o|contracted procedure: k8749 
o|contracted procedure: k8755 
o|contracted procedure: k8758 
o|contracted procedure: k8761 
o|contracted procedure: k8768 
o|contracted procedure: k8772 
o|contracted procedure: k8800 
o|contracted procedure: k8780 
o|contracted procedure: k8788 
o|contracted procedure: k8784 
o|contracted procedure: k8796 
o|contracted procedure: k8814 
o|contracted procedure: k8820 
o|contracted procedure: k8823 
o|contracted procedure: k8882 
o|contracted procedure: k8832 
o|contracted procedure: k8845 
o|contracted procedure: k8849 
o|contracted procedure: k8877 
o|contracted procedure: k8857 
o|contracted procedure: k8861 
o|contracted procedure: k8873 
o|contracted procedure: k8869 
o|contracted procedure: k8888 
o|contracted procedure: k8894 
o|contracted procedure: k8897 
o|contracted procedure: k8955 
o|contracted procedure: k8959 
o|contracted procedure: k8906 
o|contracted procedure: k8919 
o|contracted procedure: k8923 
o|contracted procedure: k8951 
o|contracted procedure: k8931 
o|contracted procedure: k8939 
o|contracted procedure: k8947 
o|contracted procedure: k8965 
o|contracted procedure: k8977 
o|contracted procedure: k8986 
o|contracted procedure: k9225 
o|contracted procedure: k9001 
o|contracted procedure: k9008 
o|contracted procedure: k9012 
o|contracted procedure: k9028 
o|contracted procedure: k9039 
o|contracted procedure: k9042 
o|contracted procedure: k9057 
o|contracted procedure: k9064 
o|contracted procedure: k9092 
o|contracted procedure: k9089 
o|contracted procedure: k9072 
o|contracted procedure: k9068 
o|contracted procedure: k9085 
o|contracted procedure: k9125 
o|contracted procedure: k9105 
o|contracted procedure: k9113 
o|contracted procedure: k9109 
o|contracted procedure: k9134 
o|contracted procedure: k9137 
o|contracted procedure: k9140 
o|contracted procedure: k9148 
o|contracted procedure: k9156 
o|contracted procedure: k9168 
o|contracted procedure: k9171 
o|contracted procedure: k9174 
o|contracted procedure: k9182 
o|contracted procedure: k9211 
o|contracted procedure: k9196 
o|contracted procedure: k9205 
o|contracted procedure: k9221 
o|contracted procedure: k9232 
o|contracted procedure: k9241 
o|contracted procedure: k9244 
o|contracted procedure: k9253 
o|contracted procedure: k9315 
o|contracted procedure: k9266 
o|contracted procedure: k9278 
o|contracted procedure: k9270 
o|contracted procedure: k9303 
o|contracted procedure: k9289 
o|contracted procedure: k9296 
o|contracted procedure: k9307 
o|contracted procedure: k9311 
o|contracted procedure: k9321 
o|contracted procedure: k9330 
o|contracted procedure: k9333 
o|contracted procedure: k9342 
o|contracted procedure: k9348 
o|contracted procedure: k9374 
o|contracted procedure: k9358 
o|contracted procedure: k9370 
o|contracted procedure: k9381 
o|contracted procedure: k9385 
o|contracted procedure: k9391 
o|contracted procedure: k9406 
o|contracted procedure: k9409 
o|contracted procedure: k9412 
o|contracted procedure: k9464 
o|contracted procedure: k9418 
o|contracted procedure: k9424 
o|contracted procedure: k9431 
o|contracted procedure: k9435 
o|contracted procedure: k9458 
o|contracted procedure: k9442 
o|contracted procedure: k9454 
o|contracted procedure: k9470 
o|contracted procedure: k9485 
o|contracted procedure: k9488 
o|contracted procedure: k9497 
o|contracted procedure: k9516 
o|contracted procedure: k9519 
o|contracted procedure: k9528 
o|contracted procedure: k9534 
o|contracted procedure: k9601 
o|contracted procedure: k9605 
o|contracted procedure: k9543 
o|contracted procedure: k9597 
o|contracted procedure: k9555 
o|contracted procedure: k9561 
o|contracted procedure: k9564 
o|contracted procedure: k9571 
o|contracted procedure: k9575 
o|contracted procedure: k9587 
o|contracted procedure: k9583 
o|contracted procedure: k9611 
o|contracted procedure: k9694 
o|contracted procedure: k9620 
o|contracted procedure: k9626 
o|contracted procedure: k9686 
o|contracted procedure: k9638 
o|contracted procedure: k9661 
o|contracted procedure: k9645 
o|contracted procedure: k9657 
o|contracted procedure: k9682 
o|contracted procedure: k9667 
o|contracted procedure: k9674 
o|contracted procedure: k9678 
o|contracted procedure: k9700 
o|contracted procedure: k9703 
o|contracted procedure: k9706 
o|contracted procedure: k9709 
o|contracted procedure: k9712 
o|contracted procedure: k9724 
o|contracted procedure: k9727 
o|contracted procedure: k9739 
o|contracted procedure: k9746 
o|contracted procedure: k9750 
o|contracted procedure: k9769 
o|inlining procedure: k9758 
o|contracted procedure: k9776 
o|contracted procedure: k9789 
o|contracted procedure: k9785 
o|contracted procedure: k9766 
o|inlining procedure: k9758 
o|contracted procedure: k9792 
o|contracted procedure: k9799 
o|contracted procedure: k9824 
o|contracted procedure: k9817 
o|contracted procedure: k396316424 
o|contracted procedure: k9830 
o|contracted procedure: k9888 
o|contracted procedure: k9892 
o|contracted procedure: k9839 
o|contracted procedure: k9852 
o|contracted procedure: k9856 
o|contracted procedure: k9864 
o|contracted procedure: k9884 
o|contracted procedure: k9871 
o|contracted procedure: k9898 
o|contracted procedure: k9907 
o|contracted procedure: k9920 
o|contracted procedure: k9924 
o|contracted procedure: k9932 
o|contracted procedure: k9938 
o|contracted procedure: k10065 
o|contracted procedure: k9953 
o|contracted procedure: k9963 
o|contracted procedure: k9967 
o|contracted procedure: k9979 
o|contracted procedure: k9986 
o|contracted procedure: k9990 
o|contracted procedure: k10007 
o|contracted procedure: k10011 
o|contracted procedure: k10023 
o|contracted procedure: k10061 
o|contracted procedure: k10033 
o|contracted procedure: k10037 
o|contracted procedure: k10045 
o|contracted procedure: k10049 
o|contracted procedure: k10072 
o|contracted procedure: k10075 
o|contracted procedure: k10081 
o|contracted procedure: k10084 
o|contracted procedure: k10156 
o|contracted procedure: k10093 
o|contracted procedure: k10106 
o|contracted procedure: k10110 
o|contracted procedure: k10152 
o|contracted procedure: k10118 
o|contracted procedure: k10140 
o|contracted procedure: k10148 
o|contracted procedure: k10162 
o|contracted procedure: k10174 
o|contracted procedure: k396316431 
o|contracted procedure: k10177 
o|contracted procedure: k10180 
o|contracted procedure: k10183 
o|contracted procedure: k10192 
o|contracted procedure: k10199 
o|contracted procedure: k10203 
o|contracted procedure: k10278 
o|contracted procedure: k10213 
o|contracted procedure: k10220 
o|contracted procedure: k10228 
o|contracted procedure: k10224 
o|contracted procedure: k10235 
o|contracted procedure: k10239 
o|contracted procedure: k10252 
o|contracted procedure: k10259 
o|contracted procedure: k10263 
o|contracted procedure: k10270 
o|contracted procedure: k10274 
o|contracted procedure: k10291 
o|contracted procedure: k10298 
o|contracted procedure: k10288 
o|contracted procedure: k10318 
o|contracted procedure: k10321 
o|contracted procedure: k10324 
o|contracted procedure: k10327 
o|contracted procedure: k10336 
o|contracted procedure: k10348 
o|contracted procedure: k10351 
o|contracted procedure: k10358 
o|contracted procedure: k10362 
o|contracted procedure: k10369 
o|contracted procedure: k396316436 
o|contracted procedure: k10380 
o|contracted procedure: k10376 
o|contracted procedure: k10391 
o|contracted procedure: k10387 
o|contracted procedure: k10397 
o|contracted procedure: k10409 
o|contracted procedure: k10521 
o|contracted procedure: k10525 
o|contracted procedure: k10415 
o|contracted procedure: k10517 
o|contracted procedure: k10422 
o|contracted procedure: k10454 
o|contracted procedure: k10463 
o|contracted procedure: k10469 
o|contracted procedure: k10486 
o|contracted procedure: k8354 
o|contracted procedure: k8376 
o|contracted procedure: k8363 
o|contracted procedure: k8370 
o|contracted procedure: k10492 
o|contracted procedure: k10499 
o|contracted procedure: k10509 
o|contracted procedure: k10513 
o|contracted procedure: k14082 
o|simplifications: ((if . 16) (let . 368)) 
o|removed binding forms: 1219 
o|contracted procedure: k4705 
o|contracted procedure: k4817 
o|contracted procedure: k4939 
o|substituted constant variable: r5341 
o|contracted procedure: k6470 
o|contracted procedure: k6631 
o|contracted procedure: k7531 
o|contracted procedure: k8313 
o|contracted procedure: k8579 
o|contracted procedure: k9022 
o|contracted procedure: k9351 
o|contracted procedure: k9715 
o|contracted procedure: k9758 
o|inlining procedure: k9868 
o|inlining procedure: k9868 
o|replaced variables: 5 
o|removed binding forms: 12 
o|removed binding forms: 5 
o|direct leaf routine/allocation: mark558 3 
o|direct leaf routine/allocation: touch560 0 
o|direct leaf routine/allocation: loop333 0 
o|direct leaf routine/allocation: touch678 0 
o|direct leaf routine/allocation: for-each-loop693711 0 
o|direct leaf routine/allocation: g733742 0 
o|direct leaf routine/allocation: touch1367 0 
o|direct leaf routine/allocation: close2510 6 
o|direct leaf routine/allocation: g293294 3 
o|direct leaf routine/allocation: g14401441 35 
o|direct leaf routine/allocation: argc-ok?1865 0 
o|contracted procedure: "(optimizer.scm:97) k4850" 
o|contracted procedure: k4877 
o|converted assignments to bindings: (loop333) 
o|contracted procedure: "(optimizer.scm:122) k4927" 
o|converted assignments to bindings: (for-each-loop693711) 
o|contracted procedure: "(optimizer.scm:187) k5167" 
o|contracted procedure: "(optimizer.scm:187) k516716192" 
o|contracted procedure: "(optimizer.scm:181) k5232" 
o|contracted procedure: "(optimizer.scm:217) k5329" 
o|contracted procedure: "(optimizer.scm:235) k5448" 
o|contracted procedure: "(optimizer.scm:257) k5515" 
o|contracted procedure: "(optimizer.scm:284) k5597" 
o|contracted procedure: "(optimizer.scm:288) k5624" 
o|contracted procedure: "(optimizer.scm:306) k5707" 
o|contracted procedure: "(optimizer.scm:326) k5873" 
o|contracted procedure: "(optimizer.scm:342) k5947" 
o|contracted procedure: "(optimizer.scm:377) k6059" 
o|contracted procedure: "(optimizer.scm:458) k6227" 
o|contracted procedure: "(optimizer.scm:471) k6312" 
o|contracted procedure: "(optimizer.scm:480) k6383" 
o|contracted procedure: "(optimizer.scm:546) k6993" 
o|contracted procedure: "(optimizer.scm:551) k7014" 
o|contracted procedure: "(optimizer.scm:558) k7026" 
o|contracted procedure: "(optimizer.scm:583) k7185" 
o|contracted procedure: "(optimizer.scm:1815) k11984" 
o|contracted procedure: "(optimizer.scm:1828) k12118" 
o|contracted procedure: "(optimizer.scm:1293) k9494" 
o|converted assignments to bindings: (argc-ok?1865) 
o|simplifications: ((let . 3)) 
o|removed binding forms: 25 
o|customizable procedures: (loop2182 lp2121 k9504 k9025 map-loop19691987 map-loop19972014 loop2021 foldr19131916 loop1432 k13119 loop1589 k13280 loop1566 k13611 map-loop16571676 g16891711 for-each-loop16881716 g17291736 for-each-loop17281744 g17531760 for-each-loop17521770 g17901791 foldl17831787 k7982 foldr18191822 g18241825 foldr18061809 foldr278281 g283284 a7889 find-path1697 find1700 loop21515 loop11493 foldr16371640 g16421643 g25162609 for-each-loop25152796 g26262635 map-loop26202676 map-loop26872707 map-loop27282745 k12434 chicken.compiler.optimizer#append-map loop2758 descend2752 g27192764 for-each-loop27182789 g27712778 for-each-loop27702784 chicken.compiler.optimizer#list-tabulate map-loop26452662 g25862593 for-each-loop25852603 k11956 k11970 walk2512 map-loop306324 k11241 for-each-loop24192429 for-each-loop24022412 g23812382 rec2355 g23482435 for-each-loop23472447 foldr24592462 for-each-loop24732486 k11037 k10990 k10951 chicken.compiler.optimizer#every rec2251 g22292236 for-each-loop22282239 scan2200 walk2199 transform2201 g13751382 for-each-loop13741410 test1368 k7516 k7543 k7552 k7298 for-each-loop13091321 lp1294 k7173 k7122 k7023 for-each-loop12531265 g12071216 map-loop12011226 k6041 k6770 k6123 k6151 loop1350 k6175 g11661175 map-loop11601185 chicken.compiler.optimizer#split-at loop1095 g11161125 map-loop11101135 invalidate-gae!679 g10611068 for-each-loop10601078 g968975 for-each-loop967985 walk-generic685 a5864 loop67 k5704 k5719 g886895 map-loop880905 g855856 k5648 g827828 replace-var683 walk1684 k5507 loop350 maybe-replace-rest-arg-calls681 walk682 k5268 test675 chicken.compiler.optimizer#cons* map-loop727745 simplify680 chicken.compiler.optimizer#delete loop243 for-each-loop565644 k4844 remember559 scan-each561 k4796 chicken.compiler.optimizer#filter g584591 for-each-loop583595 scan562 loop428 foldr260263 g265266 loop223 loop210 loop197 loop184 chicken.compiler.optimizer#any map-loop128146 map-loop155173 loop124 foldr113116 g118119 loop100 chicken.compiler.optimizer#take) 
o|calls to known targets: 553 
o|identified direct recursive calls: f_3511 1 
o|identified direct recursive calls: f_3569 1 
o|identified direct recursive calls: f_3617 1 
o|identified direct recursive calls: f_3689 1 
o|identified direct recursive calls: f_3738 1 
o|identified direct recursive calls: f_3842 1 
o|identified direct recursive calls: f_4021 1 
o|identified direct recursive calls: f_4178 1 
o|identified direct recursive calls: f_5100 1 
o|identified direct recursive calls: f_5209 1 
o|identified direct recursive calls: f_4237 2 
o|identified direct recursive calls: f_7429 2 
o|identified direct recursive calls: f_11417 1 
o|identified direct recursive calls: f_4138 1 
o|unused rest argument: _2783 f_12353 
o|unused rest argument: _2762 f_12504 
o|identified direct recursive calls: f_12669 1 
o|unused rest argument: _2715 f_12711 
o|identified direct recursive calls: f_12736 1 
o|identified direct recursive calls: f_12906 1 
o|identified direct recursive calls: f_4065 1 
o|identified direct recursive calls: f_8055 1 
o|identified direct recursive calls: f_8008 1 
o|identified direct recursive calls: f_8230 1 
o|identified direct recursive calls: f_8305 1 
o|identified direct recursive calls: f_8589 1 
o|identified direct recursive calls: f_9052 1 
o|identified direct recursive calls: f_10458 1 
o|fast box initializations: 90 
o|fast global references: 60 
o|fast global assignments: 19 
o|dropping unused closure argument: f_3511 
o|dropping unused closure argument: f_3563 
o|dropping unused closure argument: f_3602 
o|dropping unused closure argument: f_3772 
o|dropping unused closure argument: f_3806 
o|dropping unused closure argument: f_3836 
o|dropping unused closure argument: f_3892 
o|dropping unused closure argument: f_4012 
o|dropping unused closure argument: f_4178 
o|dropping unused closure argument: f_4414 
o|dropping unused closure argument: f_5086 
o|dropping unused closure argument: f_5100 
*/
/* end of file */
