/* Generated from irregex.scm by the CHICKEN compiler
   http://www.call-cc.org
   Version 5.4.0rc1 (prerelease) (rev bc191a47)
   linux-unix-gnu-x86-64 [ 64bit dload ptables ]
   command line: irregex.scm -optimize-level 2 -include-path . -include-path ./ -inline -ignore-repository -feature chicken-bootstrap -no-warnings -specialize -consult-types-file ./types.db -explicit-use -no-trace -output-file irregex.c -emit-import-library chicken.irregex
   unit: irregex
   uses: expand library
*/
#include "chicken.h"

static C_PTABLE_ENTRY *create_ptable(void);
C_noret_decl(C_expand_toplevel)
C_externimport void C_ccall C_expand_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_library_toplevel)
C_externimport void C_ccall C_library_toplevel(C_word c,C_word *av) C_noret;

static C_TLS C_word lf[502];
static double C_possibly_force_alignment;
static C_char C_TLS li0[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,118,101,99,116,111,114,45,99,111,112,121,32,118,41,0};
static C_char C_TLS li1[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,63,32,120,41,0,0,0,0};
static C_char C_TLS li2[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,110,117,109,45,115,117,98,109,97,116,99,104,101,115,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li3[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,110,97,109,101,115,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li4[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,110,101,119,45,109,97,116,99,104,101,115,32,105,114,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li5[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,114,101,115,101,116,45,109,97,116,99,104,101,115,33,32,109,41,0,0,0,0,0,0};
static C_char C_TLS li6[] C_aligned={C_lihdr(0,0,40),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,99,111,112,121,45,109,97,116,99,104,101,115,32,109,41};
static C_char C_TLS li7[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,100,97,116,97,63,32,111,98,106,41,0,0,0,0,0,0,0};
static C_char C_TLS li8[] C_aligned={C_lihdr(0,0,48),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,110,117,109,45,115,117,98,109,97,116,99,104,101,115,32,109,41};
static C_char C_TLS li9[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,110,97,109,101,115,32,109,41,0};
static C_char C_TLS li10[] C_aligned={C_lihdr(0,0,51),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,115,116,97,114,116,45,99,104,117,110,107,32,109,32,46,32,111,112,116,41,0,0,0,0,0};
static C_char C_TLS li11[] C_aligned={C_lihdr(0,0,51),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,115,116,97,114,116,45,105,110,100,101,120,32,109,32,46,32,111,112,116,41,0,0,0,0,0};
static C_char C_TLS li12[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,101,110,100,45,99,104,117,110,107,32,109,32,46,32,111,112,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li13[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,101,110,100,45,105,110,100,101,120,32,109,32,46,32,111,112,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li14[] C_aligned={C_lihdr(0,0,16),40,108,112,32,108,115,32,117,110,107,110,111,119,110,63,41};
static C_char C_TLS li15[] C_aligned={C_lihdr(0,0,60),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,110,117,109,101,114,105,99,45,105,110,100,101,120,32,108,111,99,97,116,105,111,110,32,109,32,111,112,116,41,0,0,0,0};
static C_char C_TLS li16[] C_aligned={C_lihdr(0,0,48),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,118,97,108,105,100,45,105,110,100,101,120,63,32,109,32,110,41};
static C_char C_TLS li17[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,115,117,98,115,116,114,105,110,103,32,109,32,46,32,111,112,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li18[] C_aligned={C_lihdr(0,0,48),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,45,115,117,98,99,104,117,110,107,32,109,32,46,32,111,112,116,41};
static C_char C_TLS li19[] C_aligned={C_lihdr(0,0,12),40,102,95,56,53,55,48,32,99,110,107,41,0,0,0,0};
static C_char C_TLS li20[] C_aligned={C_lihdr(0,0,12),40,102,95,56,53,53,51,32,99,110,107,41,0,0,0,0};
static C_char C_TLS li21[] C_aligned={C_lihdr(0,0,14),40,108,111,111,112,32,99,110,107,32,114,101,115,41,0,0};
static C_char C_TLS li22[] C_aligned={C_lihdr(0,0,28),40,102,95,56,52,53,50,32,99,110,107,49,32,115,116,97,114,116,32,99,110,107,50,32,101,110,100,41,0,0,0,0};
static C_char C_TLS li23[] C_aligned={C_lihdr(0,0,59),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,109,97,107,101,45,105,114,114,101,103,101,120,45,99,104,117,110,107,101,114,32,103,101,116,45,110,101,120,116,32,103,101,116,45,115,116,114,32,46,32,111,41,0,0,0,0,0};
static C_char C_TLS li24[] C_aligned={C_lihdr(0,0,10),40,108,112,32,115,116,97,114,116,41,0,0,0,0,0,0};
static C_char C_TLS li25[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,104,117,110,107,101,114,45,112,114,101,118,45,99,104,97,114,32,99,110,107,32,115,116,97,114,116,32,101,110,100,41,0,0,0,0,0,0,0};
static C_char C_TLS li26[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,104,117,110,107,101,114,45,110,101,120,116,45,99,104,97,114,32,99,110,107,32,115,114,99,41,0,0,0,0,0};
static C_char C_TLS li27[] C_aligned={C_lihdr(0,0,8),40,115,99,97,110,32,105,41};
static C_char C_TLS li28[] C_aligned={C_lihdr(0,0,44),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,116,114,105,110,103,45,115,99,97,110,45,99,104,97,114,32,115,116,114,32,99,32,46,32,111,41,0,0,0,0};
static C_char C_TLS li29[] C_aligned={C_lihdr(0,0,7),40,108,112,32,108,115,41,0};
static C_char C_TLS li30[] C_aligned={C_lihdr(0,0,11),40,97,57,49,50,51,32,115,32,97,41,0,0,0,0,0};
static C_char C_TLS li31[] C_aligned={C_lihdr(0,0,48),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,116,114,105,110,103,45,99,97,116,45,114,101,118,101,114,115,101,32,115,116,114,105,110,103,45,108,105,115,116,41};
static C_char C_TLS li32[] C_aligned={C_lihdr(0,0,10),40,108,112,32,105,32,114,101,115,41,0,0,0,0,0,0};
static C_char C_TLS li33[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,122,101,114,111,45,116,111,32,110,41,0,0,0,0,0};
static C_char C_TLS li34[] C_aligned={C_lihdr(0,0,7),40,108,112,32,108,115,41,0};
static C_char C_TLS li35[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,102,105,110,100,32,112,114,101,100,32,108,115,41,0,0};
static C_char C_TLS li36[] C_aligned={C_lihdr(0,0,4),40,108,112,41,0,0,0,0};
static C_char C_TLS li37[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,108,97,115,116,32,108,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li38[] C_aligned={C_lihdr(0,0,14),40,108,112,32,104,101,97,100,32,116,97,105,108,41,0,0};
static C_char C_TLS li39[] C_aligned={C_lihdr(0,0,29),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,97,110,121,32,112,114,101,100,32,108,115,41,0,0,0};
static C_char C_TLS li40[] C_aligned={C_lihdr(0,0,14),40,108,112,32,104,101,97,100,32,116,97,105,108,41,0,0};
static C_char C_TLS li41[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,101,118,101,114,121,32,112,114,101,100,32,108,115,41,0};
static C_char C_TLS li42[] C_aligned={C_lihdr(0,0,11),40,108,112,32,108,115,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li43[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,102,111,108,100,32,107,111,110,115,32,107,110,105,108,32,108,115,41,0,0,0,0,0};
static C_char C_TLS li44[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,102,108,97,103,45,106,111,105,110,32,97,32,98,41,0};
static C_char C_TLS li45[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,102,108,97,103,45,99,108,101,97,114,32,97,32,98,41};
static C_char C_TLS li46[] C_aligned={C_lihdr(0,0,12),40,97,57,56,50,52,32,122,32,106,51,41,0,0,0,0};
static C_char C_TLS li47[] C_aligned={C_lihdr(0,0,12),40,97,57,56,49,56,32,121,32,106,50,41,0,0,0,0};
static C_char C_TLS li48[] C_aligned={C_lihdr(0,0,11),40,97,57,55,56,52,32,120,32,106,41,0,0,0,0,0};
static C_char C_TLS li49[] C_aligned={C_lihdr(0,0,9),40,108,112,32,105,32,108,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li50[] C_aligned={C_lihdr(0,0,8),40,115,107,105,112,32,105,41};
static C_char C_TLS li51[] C_aligned={C_lihdr(0,0,14),40,97,57,57,52,49,32,115,101,120,112,32,106,41,0,0};
static C_char C_TLS li52[] C_aligned={C_lihdr(0,0,14),40,97,57,57,56,48,32,115,101,120,112,32,106,41,0,0};
static C_char C_TLS li53[] C_aligned={C_lihdr(0,0,9),40,99,111,108,108,101,99,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li54[] C_aligned={C_lihdr(0,0,17),40,115,99,97,110,32,102,114,111,109,32,105,32,114,101,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li55[] C_aligned={C_lihdr(0,0,15),40,97,49,48,49,50,55,32,115,101,120,112,32,106,41,0};
static C_char C_TLS li56[] C_aligned={C_lihdr(0,0,15),40,97,49,48,49,52,53,32,115,101,120,112,32,106,41,0};
static C_char C_TLS li57[] C_aligned={C_lihdr(0,0,8),40,115,99,97,110,32,106,41};
static C_char C_TLS li58[] C_aligned={C_lihdr(0,0,12),40,102,95,57,55,53,50,32,105,32,107,41,0,0,0,0};
static C_char C_TLS li59[] C_aligned={C_lihdr(0,0,14),40,97,49,48,51,49,54,32,114,101,115,32,106,41,0,0};
static C_char C_TLS li60[] C_aligned={C_lihdr(0,0,50),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,119,105,116,104,45,114,101,97,100,45,102,114,111,109,45,115,116,114,105,110,103,32,115,116,114,32,105,32,112,114,111,99,41,0,0,0,0,0,0};
static C_char C_TLS li61[] C_aligned={C_lihdr(0,0,11),40,108,112,32,108,115,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li62[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,121,109,98,111,108,45,108,105,115,116,45,62,102,108,97,103,115,32,108,115,41,0};
static C_char C_TLS li63[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,109,97,121,98,101,45,115,116,114,105,110,103,45,62,115,114,101,32,111,98,106,41,0};
static C_char C_TLS li64[] C_aligned={C_lihdr(0,0,12),40,99,97,115,101,100,45,99,104,97,114,41,0,0,0,0};
static C_char C_TLS li65[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,49,52,55,49,32,103,49,52,56,51,41,0,0,0,0};
static C_char C_TLS li66[] C_aligned={C_lihdr(0,0,18),40,99,97,115,101,100,45,115,116,114,105,110,103,32,115,116,114,41,0,0,0,0,0,0};
static C_char C_TLS li67[] C_aligned={C_lihdr(0,0,9),40,99,111,108,108,101,99,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li68[] C_aligned={C_lihdr(0,0,6),40,108,112,32,105,41,0,0};
static C_char C_TLS li69[] C_aligned={C_lihdr(0,0,16),40,99,111,108,108,101,99,116,47,115,105,110,103,108,101,41};
static C_char C_TLS li70[] C_aligned={C_lihdr(0,0,16),40,108,112,32,108,115,32,116,101,114,109,32,114,101,115,41};
static C_char C_TLS li71[] C_aligned={C_lihdr(0,0,15),40,99,111,108,108,101,99,116,47,116,101,114,109,115,41,0};
static C_char C_TLS li72[] C_aligned={C_lihdr(0,0,6),40,115,97,118,101,41,0,0};
static C_char C_TLS li73[] C_aligned={C_lihdr(0,0,14),40,97,49,49,50,52,55,32,115,114,101,32,106,41,0,0};
static C_char C_TLS li74[] C_aligned={C_lihdr(0,0,6),40,106,111,105,110,41,0,0};
static C_char C_TLS li75[] C_aligned={C_lihdr(0,0,9),40,110,101,119,45,114,101,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li76[] C_aligned={C_lihdr(0,0,21),40,108,112,50,32,106,32,102,108,97,103,115,32,105,110,118,101,114,116,63,41,0,0,0};
static C_char C_TLS li77[] C_aligned={C_lihdr(0,0,14),40,97,49,50,48,48,55,32,115,114,101,32,106,41,0,0};
static C_char C_TLS li78[] C_aligned={C_lihdr(0,0,14),40,97,50,54,57,53,48,32,120,32,114,101,115,41,0,0};
static C_char C_TLS li79[] C_aligned={C_lihdr(0,0,12),40,97,49,51,53,48,57,32,99,32,106,41,0,0,0,0};
static C_char C_TLS li80[] C_aligned={C_lihdr(0,0,7),40,103,49,56,56,52,41,0};
static C_char C_TLS li81[] C_aligned={C_lihdr(0,0,13),40,97,49,51,56,51,57,32,99,104,32,106,41,0,0,0};
static C_char C_TLS li82[] C_aligned={C_lihdr(0,0,21),40,103,111,32,105,32,112,114,101,118,45,99,104,97,114,32,99,115,101,116,41,0,0,0};
static C_char C_TLS li83[] C_aligned={C_lihdr(0,0,9),40,99,111,108,108,101,99,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li84[] C_aligned={C_lihdr(0,0,15),40,108,112,32,105,32,102,114,111,109,32,114,101,115,41,0};
static C_char C_TLS li85[] C_aligned={C_lihdr(0,0,13),40,97,49,50,54,53,50,32,99,104,32,106,41,0,0,0};
static C_char C_TLS li86[] C_aligned={C_lihdr(0,0,7),40,108,112,50,32,106,41,0};
static C_char C_TLS li87[] C_aligned={C_lihdr(0,0,14),40,97,49,50,56,56,51,32,115,114,101,32,106,41,0,0};
static C_char C_TLS li88[] C_aligned={C_lihdr(0,0,8),40,115,99,97,110,32,105,41};
static C_char C_TLS li89[] C_aligned={C_lihdr(0,0,24),40,108,112,32,105,32,102,114,111,109,32,102,108,97,103,115,32,114,101,115,32,115,116,41};
static C_char C_TLS li90[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,116,114,105,110,103,45,62,115,114,101,32,115,116,114,32,46,32,111,41,0,0,0};
static C_char C_TLS li91[] C_aligned={C_lihdr(0,0,8),40,115,99,97,110,32,105,41};
static C_char C_TLS li92[] C_aligned={C_lihdr(0,0,51),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,116,114,105,110,103,45,112,97,114,115,101,45,104,101,120,45,101,115,99,97,112,101,32,115,116,114,32,105,32,101,110,100,41,0,0,0,0,0};
static C_char C_TLS li93[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,104,105,103,104,45,99,104,97,114,63,32,99,41,0,0};
static C_char C_TLS li94[] C_aligned={C_lihdr(0,0,6),40,98,121,116,101,41,0,0};
static C_char C_TLS li95[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,117,116,102,56,45,115,116,114,105,110,103,45,114,101,102,32,115,116,114,32,105,32,108,101,110,41,0,0,0,0,0};
static C_char C_TLS li96[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,117,116,102,56,45,108,111,119,101,115,116,45,100,105,103,105,116,45,111,102,45,108,101,110,103,116,104,32,108,101,110,41,0,0,0,0,0,0,0};
static C_char C_TLS li97[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,104,97,114,45,62,117,116,102,56,45,108,105,115,116,32,99,41,0,0,0,0,0};
static C_char C_TLS li98[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,48,55,55,32,103,50,48,56,57,41,0,0,0,0};
static C_char C_TLS li99[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,48,53,49,32,103,50,48,54,51,41,0,0,0,0};
static C_char C_TLS li100[] C_aligned={C_lihdr(0,0,56),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,117,110,105,99,111,100,101,45,114,97,110,103,101,45,104,101,108,112,101,114,32,111,110,101,32,108,115,32,112,114,101,102,105,120,32,114,101,115,41};
static C_char C_TLS li101[] C_aligned={C_lihdr(0,0,10),40,97,49,52,55,55,57,32,99,41,0,0,0,0,0,0};
static C_char C_TLS li102[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,49,49,51,32,103,50,49,50,53,41,0,0,0,0};
static C_char C_TLS li103[] C_aligned={C_lihdr(0,0,45),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,117,110,105,99,111,100,101,45,114,97,110,103,101,45,117,112,45,102,114,111,109,32,108,111,45,108,115,41,0,0,0};
static C_char C_TLS li104[] C_aligned={C_lihdr(0,0,10),40,97,49,52,57,49,56,32,99,41,0,0,0,0,0,0};
static C_char C_TLS li105[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,49,52,56,32,103,50,49,54,48,41,0,0,0,0};
static C_char C_TLS li106[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,117,110,105,99,111,100,101,45,114,97,110,103,101,45,117,112,45,116,111,32,104,105,45,108,115,41,0,0,0,0,0};
static C_char C_TLS li107[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,50,51,55,32,103,50,50,52,57,41,0,0,0,0};
static C_char C_TLS li108[] C_aligned={C_lihdr(0,0,9),40,103,50,50,50,48,32,105,41,0,0,0,0,0,0,0};
static C_char C_TLS li109[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,50,55,55,32,103,50,50,56,57,41,0,0,0,0};
static C_char C_TLS li110[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,50,49,52,32,103,50,50,50,54,41,0,0,0,0};
static C_char C_TLS li111[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,49,56,52,32,103,50,49,57,54,41,0,0,0,0};
static C_char C_TLS li112[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,51,49,53,32,103,50,51,50,55,41,0,0,0,0};
static C_char C_TLS li113[] C_aligned={C_lihdr(0,0,16),40,108,112,32,108,111,45,108,115,32,104,105,45,108,115,41};
static C_char C_TLS li114[] C_aligned={C_lihdr(0,0,20),40,108,112,32,108,115,32,97,108,116,115,32,108,111,45,99,115,101,116,41,0,0,0,0};
static C_char C_TLS li115[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,62,117,116,102,56,45,112,97,116,116,101,114,110,32,99,115,101,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li116[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,32,120,32,46,32,111,41,0};
static C_char C_TLS li117[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,116,114,105,110,103,45,62,105,114,114,101,103,101,120,32,115,116,114,32,46,32,111,41,0,0,0,0,0,0,0};
static C_char C_TLS li118[] C_aligned={C_lihdr(0,0,44),40,97,50,51,52,49,55,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li119[] C_aligned={C_lihdr(0,0,9),40,114,101,99,32,115,114,101,41,0,0,0,0,0,0,0};
static C_char C_TLS li120[] C_aligned={C_lihdr(0,0,45),40,102,95,50,51,53,50,55,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li121[] C_aligned={C_lihdr(0,0,8),40,97,50,51,53,53,54,41};
static C_char C_TLS li122[] C_aligned={C_lihdr(0,0,45),40,102,95,50,51,53,53,49,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li123[] C_aligned={C_lihdr(0,0,8),40,97,50,51,55,52,57,41};
static C_char C_TLS li124[] C_aligned={C_lihdr(0,0,45),40,102,95,50,51,55,52,52,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li125[] C_aligned={C_lihdr(0,0,8),40,97,50,51,55,55,53,41};
static C_char C_TLS li126[] C_aligned={C_lihdr(0,0,45),40,102,95,50,51,55,55,48,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li127[] C_aligned={C_lihdr(0,0,8),40,97,50,51,56,49,48,41};
static C_char C_TLS li128[] C_aligned={C_lihdr(0,0,45),40,102,95,50,51,56,48,53,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li129[] C_aligned={C_lihdr(0,0,8),40,97,50,51,56,53,54,41};
static C_char C_TLS li130[] C_aligned={C_lihdr(0,0,45),40,102,95,50,51,56,53,49,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li131[] C_aligned={C_lihdr(0,0,8),40,97,50,51,56,55,50,41};
static C_char C_TLS li132[] C_aligned={C_lihdr(0,0,44),40,97,50,51,56,54,54,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li133[] C_aligned={C_lihdr(0,0,8),40,97,50,51,57,49,53,41};
static C_char C_TLS li134[] C_aligned={C_lihdr(0,0,44),40,97,50,51,57,48,57,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li135[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,48,48,51,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li136[] C_aligned={C_lihdr(0,0,8),40,97,50,52,48,51,57,41};
static C_char C_TLS li137[] C_aligned={C_lihdr(0,0,44),40,97,50,52,48,50,49,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li138[] C_aligned={C_lihdr(0,0,16),40,98,111,100,121,52,53,56,55,32,99,111,117,110,116,41};
static C_char C_TLS li139[] C_aligned={C_lihdr(0,0,8),40,97,50,52,48,55,57,41};
static C_char C_TLS li140[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,48,55,49,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li141[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,49,53,53,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li142[] C_aligned={C_lihdr(0,0,8),40,97,50,52,49,57,53,41};
static C_char C_TLS li143[] C_aligned={C_lihdr(0,0,44),40,97,50,52,49,55,51,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li144[] C_aligned={C_lihdr(0,0,16),40,98,111,100,121,52,54,52,53,32,99,111,117,110,116,41};
static C_char C_TLS li145[] C_aligned={C_lihdr(0,0,8),40,97,50,52,50,51,57,41};
static C_char C_TLS li146[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,50,51,48,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li147[] C_aligned={C_lihdr(0,0,8),40,97,50,52,52,48,48,41};
static C_char C_TLS li148[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,51,56,54,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li149[] C_aligned={C_lihdr(0,0,44),40,97,50,52,52,48,55,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li150[] C_aligned={C_lihdr(0,0,8),40,97,50,52,52,51,53,41};
static C_char C_TLS li151[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,52,50,49,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li152[] C_aligned={C_lihdr(0,0,44),40,97,50,52,52,52,50,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li153[] C_aligned={C_lihdr(0,0,11),40,102,95,50,52,53,48,52,32,120,41,0,0,0,0,0};
static C_char C_TLS li154[] C_aligned={C_lihdr(0,0,8),40,97,50,52,52,57,56,41};
static C_char C_TLS li155[] C_aligned={C_lihdr(0,0,9),40,97,56,55,52,49,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li156[] C_aligned={C_lihdr(0,0,9),40,97,56,55,54,56,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li157[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,52,53,57,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li158[] C_aligned={C_lihdr(0,0,44),40,97,50,52,53,50,48,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li159[] C_aligned={C_lihdr(0,0,8),40,97,50,52,53,53,54,41};
static C_char C_TLS li160[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,53,52,50,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li161[] C_aligned={C_lihdr(0,0,44),40,97,50,52,53,54,51,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li162[] C_aligned={C_lihdr(0,0,46),40,102,95,50,52,53,57,53,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,50,41,0,0};
static C_char C_TLS li163[] C_aligned={C_lihdr(0,0,8),40,97,50,52,54,53,56,41};
static C_char C_TLS li164[] C_aligned={C_lihdr(0,0,46),40,102,95,50,52,54,53,51,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,50,41,0,0};
static C_char C_TLS li165[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,55,48,48,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li166[] C_aligned={C_lihdr(0,0,24),40,108,112,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,106,32,108,101,110,41};
static C_char C_TLS li167[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,55,51,54,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li168[] C_aligned={C_lihdr(0,0,8),40,97,50,52,57,57,55,41};
static C_char C_TLS li169[] C_aligned={C_lihdr(0,0,45),40,102,95,50,52,57,53,48,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li170[] C_aligned={C_lihdr(0,0,8),40,97,50,53,48,57,50,41};
static C_char C_TLS li171[] C_aligned={C_lihdr(0,0,44),40,97,50,53,48,53,55,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0,0};
static C_char C_TLS li172[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,50,57,51,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li173[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,51,53,49,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li174[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,52,52,51,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li175[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,52,55,51,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li176[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,53,50,52,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li177[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,54,51,49,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li178[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,54,54,52,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li179[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,55,50,57,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li180[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,56,49,56,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li181[] C_aligned={C_lihdr(0,0,9),40,108,112,32,115,114,99,50,41,0,0,0,0,0,0,0};
static C_char C_TLS li182[] C_aligned={C_lihdr(0,0,45),40,102,95,50,53,57,52,48,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li183[] C_aligned={C_lihdr(0,0,9),40,108,112,32,115,114,99,50,41,0,0,0,0,0,0,0};
static C_char C_TLS li184[] C_aligned={C_lihdr(0,0,45),40,102,95,50,54,48,51,57,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li185[] C_aligned={C_lihdr(0,0,21),40,108,112,32,115,114,101,32,110,32,102,108,97,103,115,32,110,101,120,116,41,0,0,0};
static C_char C_TLS li186[] C_aligned={C_lihdr(0,0,8),40,103,114,111,119,32,105,41};
static C_char C_TLS li187[] C_aligned={C_lihdr(0,0,16),40,97,49,55,50,49,55,32,108,111,51,32,104,105,51,41};
static C_char C_TLS li188[] C_aligned={C_lihdr(0,0,18),40,108,112,50,32,108,115,32,110,32,108,111,50,32,104,105,50,41,0,0,0,0,0,0};
static C_char C_TLS li189[] C_aligned={C_lihdr(0,0,16),40,97,49,55,50,57,57,32,108,111,51,32,104,105,51,41};
static C_char C_TLS li190[] C_aligned={C_lihdr(0,0,18),40,108,112,50,32,108,115,32,110,32,108,111,50,32,104,105,50,41,0,0,0,0,0,0};
static C_char C_TLS li191[] C_aligned={C_lihdr(0,0,16),40,97,49,55,51,57,53,32,108,111,52,32,104,105,52,41};
static C_char C_TLS li192[] C_aligned={C_lihdr(0,0,16),40,97,49,55,51,56,49,32,108,111,51,32,104,105,51,41};
static C_char C_TLS li193[] C_aligned={C_lihdr(0,0,16),40,97,49,55,51,54,55,32,108,111,50,32,104,105,50,41};
static C_char C_TLS li194[] C_aligned={C_lihdr(0,0,16),40,97,49,55,53,49,52,32,108,111,50,32,104,105,50,41};
static C_char C_TLS li195[] C_aligned={C_lihdr(0,0,14),40,97,49,55,54,54,56,32,108,111,32,104,105,41,0,0};
static C_char C_TLS li196[] C_aligned={C_lihdr(0,0,16),40,97,49,55,55,48,55,32,108,111,50,32,104,105,50,41};
static C_char C_TLS li197[] C_aligned={C_lihdr(0,0,16),40,97,49,55,55,53,52,32,108,111,50,32,104,105,50,41};
static C_char C_TLS li198[] C_aligned={C_lihdr(0,0,16),40,97,49,55,56,50,56,32,108,111,50,32,104,105,50,41};
static C_char C_TLS li199[] C_aligned={C_lihdr(0,0,16),40,97,49,55,56,53,54,32,108,111,50,32,104,105,50,41};
static C_char C_TLS li200[] C_aligned={C_lihdr(0,0,12),40,103,51,48,50,55,32,99,101,108,108,41,0,0,0,0};
static C_char C_TLS li201[] C_aligned={C_lihdr(0,0,23),40,108,112,32,115,114,101,32,110,32,108,111,32,104,105,32,114,101,116,117,114,110,41,0};
static C_char C_TLS li202[] C_aligned={C_lihdr(0,0,11),40,103,50,54,50,53,32,110,102,97,41,0,0,0,0,0};
static C_char C_TLS li203[] C_aligned={C_lihdr(0,0,11),40,103,50,54,49,52,32,110,102,97,41,0,0,0,0,0};
static C_char C_TLS li204[] C_aligned={C_lihdr(0,0,9),40,114,101,99,32,115,114,101,41,0,0,0,0,0,0,0};
static C_char C_TLS li205[] C_aligned={C_lihdr(0,0,9),40,103,50,51,56,48,32,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li206[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,51,55,52,32,103,50,51,56,54,41,0,0,0,0};
static C_char C_TLS li207[] C_aligned={C_lihdr(0,0,9),40,103,50,52,48,55,32,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li208[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,52,48,49,32,103,50,52,49,51,41,0,0,0,0};
static C_char C_TLS li209[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,52,52,52,32,103,50,52,53,54,41,0,0,0,0};
static C_char C_TLS li210[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,52,55,48,32,103,50,52,56,50,41,0,0,0,0};
static C_char C_TLS li211[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,50,53,48,52,32,103,50,53,49,54,41,0,0,0,0};
static C_char C_TLS li212[] C_aligned={C_lihdr(0,0,22),40,97,100,106,117,115,116,32,115,114,101,32,117,116,102,56,63,32,99,105,63,41,0,0};
static C_char C_TLS li213[] C_aligned={C_lihdr(0,0,38),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,62,105,114,114,101,103,101,120,32,115,114,101,32,46,32,111,41,0,0};
static C_char C_TLS li214[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,101,109,112,116,121,63,32,115,114,101,41};
static C_char C_TLS li215[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,97,110,121,63,32,115,114,101,41,0,0};
static C_char C_TLS li216[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,114,101,112,101,97,116,101,114,63,41,0};
static C_char C_TLS li217[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,98,111,115,63,32,115,114,101,41,0,0};
static C_char C_TLS li218[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,115,101,97,114,99,104,101,114,63,32,115,114,101,41,0,0,0,0,0};
static C_char C_TLS li219[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,99,111,110,115,117,109,101,114,63,32,115,114,101,41,0,0,0,0,0};
static C_char C_TLS li220[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,104,97,115,45,115,117,98,109,97,116,99,104,101,115,63,32,115,114,101,41,0,0,0,0,0,0,0};
static C_char C_TLS li221[] C_aligned={C_lihdr(0,0,15),40,99,111,117,110,116,32,115,114,101,32,115,117,109,41,0};
static C_char C_TLS li222[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,99,111,117,110,116,45,115,117,98,109,97,116,99,104,101,115,32,115,114,101,41,0,0,0,0,0,0};
static C_char C_TLS li223[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,115,101,113,117,101,110,99,101,41,0,0};
static C_char C_TLS li224[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,97,108,116,101,114,110,97,116,101,41,0};
static C_char C_TLS li225[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,51,48,54,52,32,103,51,48,55,54,41,0,0,0,0};
static C_char C_TLS li226[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,115,116,114,105,112,45,115,117,98,109,97,116,99,104,101,115,32,115,114,101,41,0,0,0,0,0,0};
static C_char C_TLS li227[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,110,97,109,101,115,32,115,114,101,32,110,32,110,97,109,101,115,41,0};
static C_char C_TLS li228[] C_aligned={C_lihdr(0,0,47),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,115,101,113,117,101,110,99,101,45,110,97,109,101,115,32,108,115,32,110,32,110,97,109,101,115,41,0};
static C_char C_TLS li229[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,51,50,48,53,32,103,51,50,49,55,41,0,0,0,0};
static C_char C_TLS li230[] C_aligned={C_lihdr(0,0,44),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,114,101,109,111,118,101,45,105,110,105,116,105,97,108,45,98,111,115,32,115,114,101,41,0,0,0,0};
static C_char C_TLS li231[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,115,101,97,114,99,104,32,120,32,115,116,114,32,46,32,111,41,0,0,0,0,0,0};
static C_char C_TLS li232[] C_aligned={C_lihdr(0,0,54),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,115,101,97,114,99,104,47,99,104,117,110,107,101,100,32,120,32,99,110,107,32,115,114,99,32,46,32,111,41,0,0};
static C_char C_TLS li233[] C_aligned={C_lihdr(0,0,7),40,108,112,50,32,105,41,0};
static C_char C_TLS li234[] C_aligned={C_lihdr(0,0,11),40,108,112,49,32,115,114,99,32,105,41,0,0,0,0,0};
static C_char C_TLS li235[] C_aligned={C_lihdr(0,0,10),40,97,49,57,55,55,49,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li236[] C_aligned={C_lihdr(0,0,13),40,108,112,50,32,105,32,115,116,97,116,101,41,0,0,0};
static C_char C_TLS li237[] C_aligned={C_lihdr(0,0,21),40,108,112,49,32,115,114,99,32,115,116,97,114,116,32,115,116,97,116,101,41,0,0,0};
static C_char C_TLS li238[] C_aligned={C_lihdr(0,0,8),40,97,49,57,50,51,51,41};
static C_char C_TLS li239[] C_aligned={C_lihdr(0,0,8),40,97,49,57,51,48,53,41};
static C_char C_TLS li240[] C_aligned={C_lihdr(0,0,19),40,108,112,32,115,114,99,50,32,115,116,114,32,105,32,101,110,100,41,0,0,0,0,0};
static C_char C_TLS li241[] C_aligned={C_lihdr(0,0,67),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,115,101,97,114,99,104,47,109,97,116,99,104,101,115,32,105,114,120,32,99,110,107,32,105,110,105,116,32,115,114,99,32,105,32,109,97,116,99,104,101,115,41,0,0,0,0,0};
static C_char C_TLS li242[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,32,105,114,120,32,115,116,114,32,46,32,111,41,0,0,0,0,0};
static C_char C_TLS li243[] C_aligned={C_lihdr(0,0,6),40,108,112,32,109,41,0,0};
static C_char C_TLS li244[] C_aligned={C_lihdr(0,0,8),40,97,49,57,54,50,54,41};
static C_char C_TLS li245[] C_aligned={C_lihdr(0,0,51),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,47,99,104,117,110,107,101,100,32,105,114,120,32,99,110,107,32,115,114,99,41,0,0,0,0,0};
static C_char C_TLS li246[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,109,97,116,99,104,63,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li247[] C_aligned={C_lihdr(0,0,7),40,103,51,53,49,52,41,0};
static C_char C_TLS li248[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,51,53,49,51,32,103,51,53,50,48,41,0,0,0,0,0,0,0};
static C_char C_TLS li249[] C_aligned={C_lihdr(0,0,52),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,102,105,110,97,108,105,122,101,33,32,102,105,110,97,108,105,122,101,114,32,109,101,109,111,114,121,32,109,97,116,99,104,101,115,41,0,0,0,0};
static C_char C_TLS li250[] C_aligned={C_lihdr(0,0,7),40,103,51,54,54,57,41,0};
static C_char C_TLS li251[] C_aligned={C_lihdr(0,0,9),40,102,95,50,48,50,49,49,41,0,0,0,0,0,0,0};
static C_char C_TLS li252[] C_aligned={C_lihdr(0,0,9),40,103,51,55,48,56,32,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li253[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,51,54,55,56,32,103,51,54,56,53,41,0,0,0,0,0,0,0};
static C_char C_TLS li254[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,51,55,48,50,32,103,51,55,49,52,41,0,0,0,0};
static C_char C_TLS li255[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,51,54,54,56,32,103,51,54,55,53,41,0,0,0,0,0,0,0};
static C_char C_TLS li256[] C_aligned={C_lihdr(0,0,10),40,97,50,48,52,48,48,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li257[] C_aligned={C_lihdr(0,0,41),40,108,112,50,32,105,32,115,116,97,116,101,32,114,101,115,45,115,114,99,32,114,101,115,45,105,110,100,101,120,32,102,105,110,97,108,105,122,101,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li258[] C_aligned={C_lihdr(0,0,49),40,108,112,49,32,115,114,99,32,115,116,97,114,116,32,115,116,97,116,101,32,114,101,115,45,115,114,99,32,114,101,115,45,105,110,100,101,120,32,102,105,110,97,108,105,122,101,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li259[] C_aligned={C_lihdr(0,0,7),40,103,51,53,56,53,41,0};
static C_char C_TLS li260[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,51,53,56,52,32,103,51,53,57,49,41,0,0,0,0,0,0,0};
static C_char C_TLS li261[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,51,53,52,52,32,105,41,0,0};
static C_char C_TLS li262[] C_aligned={C_lihdr(0,0,79),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,100,102,97,45,109,97,116,99,104,47,108,111,110,103,101,115,116,32,100,102,97,32,99,110,107,32,115,114,99,32,115,116,97,114,116,32,101,110,100,45,115,114,99,32,101,110,100,32,109,97,116,99,104,101,115,32,105,110,100,101,120,41,0};
static C_char C_TLS li263[] C_aligned={C_lihdr(0,0,16),40,97,51,48,56,49,50,32,101,115,99,32,46,32,111,41};
static C_char C_TLS li264[] C_aligned={C_lihdr(0,0,36),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,110,102,97,45,103,101,116,45,101,112,115,105,108,111,110,115,32,105,41,0,0,0,0};
static C_char C_TLS li265[] C_aligned={C_lihdr(0,0,40),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,110,102,97,45,97,100,100,45,101,112,115,105,108,111,110,33,32,105,32,120,32,116,41};
static C_char C_TLS li266[] C_aligned={C_lihdr(0,0,24),40,110,101,119,45,115,116,97,116,101,45,110,117,109,98,101,114,32,115,116,97,116,101,41};
static C_char C_TLS li267[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,51,56,56,51,32,105,41,0,0};
static C_char C_TLS li268[] C_aligned={C_lihdr(0,0,24),40,97,100,100,45,115,116,97,116,101,33,32,110,50,32,116,114,97,110,115,45,108,115,41};
static C_char C_TLS li269[] C_aligned={C_lihdr(0,0,29),40,101,120,116,101,110,100,45,115,116,97,116,101,33,32,110,101,120,116,32,116,114,97,110,115,45,99,115,41,0,0,0};
static C_char C_TLS li270[] C_aligned={C_lihdr(0,0,25),40,97,100,100,45,99,104,97,114,45,115,116,97,116,101,33,32,110,101,120,116,32,99,104,41,0,0,0,0,0,0,0};
static C_char C_TLS li271[] C_aligned={C_lihdr(0,0,12),40,108,112,50,32,105,32,110,101,120,116,41,0,0,0,0};
static C_char C_TLS li272[] C_aligned={C_lihdr(0,0,12),40,103,52,48,49,57,32,99,101,108,108,41,0,0,0,0};
static C_char C_TLS li273[] C_aligned={C_lihdr(0,0,20),40,108,112,32,108,115,32,110,32,102,108,97,103,115,32,110,101,120,116,41,0,0,0,0};
static C_char C_TLS li274[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,52,48,50,57,32,105,41,0,0};
static C_char C_TLS li275[] C_aligned={C_lihdr(0,0,16),40,108,112,32,115,114,101,32,109,97,120,32,114,101,115,41};
static C_char C_TLS li276[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,62,110,102,97,32,115,114,101,32,105,110,105,116,45,102,108,97,103,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li277[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,109,97,107,101,45,109,115,116,32,110,102,97,41,0,0};
static C_char C_TLS li278[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,109,115,116,45,99,111,112,121,32,109,115,116,41,0,0};
static C_char C_TLS li279[] C_aligned={C_lihdr(0,0,51),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,110,102,97,45,115,116,97,116,101,45,62,109,115,116,32,110,102,97,32,115,116,97,116,101,32,109,97,112,112,105,110,103,115,41,0,0,0,0,0};
static C_char C_TLS li280[] C_aligned={C_lihdr(0,0,7),40,103,52,48,56,55,41,0};
static C_char C_TLS li281[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,52,48,56,54,32,103,52,48,57,51,41,0,0,0,0,0,0,0};
static C_char C_TLS li282[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,109,115,116,45,97,100,100,33,32,110,102,97,32,109,115,116,32,115,116,97,116,101,32,109,97,112,112,105,110,103,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li283[] C_aligned={C_lihdr(0,0,10),40,108,112,32,105,32,97,99,99,41,0,0,0,0,0,0};
static C_char C_TLS li284[] C_aligned={C_lihdr(0,0,40),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,109,115,116,45,102,111,108,100,32,109,115,116,32,107,111,110,115,32,107,110,105,108,41};
static C_char C_TLS li285[] C_aligned={C_lihdr(0,0,10),40,103,52,50,53,56,32,116,114,41,0,0,0,0,0,0};
static C_char C_TLS li286[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,52,50,53,50,32,103,52,50,54,52,41,0,0,0,0};
static C_char C_TLS li287[] C_aligned={C_lihdr(0,0,21),40,100,111,108,111,111,112,52,50,52,52,32,105,32,115,116,97,116,101,115,41,0,0,0};
static C_char C_TLS li288[] C_aligned={C_lihdr(0,0,21),40,108,112,32,105,32,115,116,97,116,101,115,32,105,110,100,101,120,101,115,41,0,0,0};
static C_char C_TLS li289[] C_aligned={C_lihdr(0,0,36),40,108,112,51,32,99,108,111,115,117,114,101,45,115,108,111,116,115,32,115,116,97,116,101,45,115,108,111,116,115,32,99,109,100,115,41,0,0,0,0};
static C_char C_TLS li290[] C_aligned={C_lihdr(0,0,26),40,108,112,50,32,115,116,97,116,101,45,115,117,109,109,97,114,121,32,116,32,99,109,100,115,41,0,0,0,0,0,0};
static C_char C_TLS li291[] C_aligned={C_lihdr(0,0,6),40,108,112,32,105,41,0,0};
static C_char C_TLS li292[] C_aligned={C_lihdr(0,0,15),40,108,112,32,100,102,97,45,115,116,97,116,101,115,41,0};
static C_char C_TLS li293[] C_aligned={C_lihdr(0,0,37),40,108,112,50,32,116,114,97,110,115,32,117,110,109,97,114,107,101,100,45,115,116,97,116,101,115,32,100,102,97,45,116,114,97,110,115,41,0,0,0};
static C_char C_TLS li294[] C_aligned={C_lihdr(0,0,20),40,103,52,51,48,55,32,105,110,116,101,114,115,101,99,116,105,111,110,41,0,0,0,0};
static C_char C_TLS li295[] C_aligned={C_lihdr(0,0,20),40,108,112,32,108,115,32,99,115,32,115,116,97,116,101,32,114,101,115,41,0,0,0,0};
static C_char C_TLS li296[] C_aligned={C_lihdr(0,0,24),40,97,50,50,55,54,55,32,115,116,32,109,97,112,112,105,110,103,115,32,114,101,115,41};
static C_char C_TLS li297[] C_aligned={C_lihdr(0,0,43),40,108,112,32,117,110,109,97,114,107,101,100,45,115,116,97,116,101,115,32,109,97,114,107,101,100,45,115,116,97,116,101,115,32,100,102,97,45,115,105,122,101,41,0,0,0,0,0};
static C_char C_TLS li298[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,110,102,97,45,62,100,102,97,32,110,102,97,32,111,41};
static C_char C_TLS li299[] C_aligned={C_lihdr(0,0,10),40,108,112,32,109,32,114,101,115,41,0,0,0,0,0,0};
static C_char C_TLS li300[] C_aligned={C_lihdr(0,0,12),40,100,111,108,111,111,112,52,49,56,55,41,0,0,0,0};
static C_char C_TLS li301[] C_aligned={C_lihdr(0,0,11),40,103,52,51,52,50,32,116,97,103,41,0,0,0,0,0};
static C_char C_TLS li302[] C_aligned={C_lihdr(0,0,17),40,108,112,50,32,116,114,97,110,115,32,115,116,97,99,107,41,0,0,0,0,0,0,0};
static C_char C_TLS li303[] C_aligned={C_lihdr(0,0,29),40,108,112,32,115,116,97,99,107,32,112,114,105,111,114,105,116,105,101,115,32,99,108,111,115,117,114,101,41,0,0,0};
static C_char C_TLS li304[] C_aligned={C_lihdr(0,0,17),40,97,50,51,48,53,53,32,115,116,32,109,32,114,101,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li305[] C_aligned={C_lihdr(0,0,48),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,110,102,97,45,101,112,115,105,108,111,110,45,99,108,111,115,117,114,101,32,110,102,97,32,115,116,97,116,101,115,41};
static C_char C_TLS li306[] C_aligned={C_lihdr(0,0,10),40,97,50,51,49,55,57,32,99,41,0,0,0,0,0,0};
static C_char C_TLS li307[] C_aligned={C_lihdr(0,0,10),40,97,50,51,50,48,51,32,99,41,0,0,0,0,0,0};
static C_char C_TLS li308[] C_aligned={C_lihdr(0,0,16),40,108,112,50,32,115,49,32,115,50,32,99,109,100,115,41};
static C_char C_TLS li309[] C_aligned={C_lihdr(0,0,11),40,108,112,32,116,32,99,109,100,115,41,0,0,0,0,0};
static C_char C_TLS li310[] C_aligned={C_lihdr(0,0,79),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,116,97,103,45,115,101,116,45,99,111,109,109,97,110,100,115,45,102,111,114,45,99,108,111,115,117,114,101,32,110,102,97,32,111,114,105,103,45,115,116,97,116,101,32,99,108,111,115,117,114,101,32,99,111,112,121,45,99,109,100,115,41,0};
static C_char C_TLS li311[] C_aligned={C_lihdr(0,0,45),40,102,95,50,54,49,56,50,32,99,110,107,32,105,110,105,116,32,115,114,99,32,115,116,114,32,105,32,101,110,100,32,109,97,116,99,104,101,115,32,102,97,105,108,41,0,0,0};
static C_char C_TLS li312[] C_aligned={C_lihdr(0,0,47),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,99,115,101,116,45,62,112,114,111,99,101,100,117,114,101,32,99,115,101,116,32,110,101,120,116,41,0};
static C_char C_TLS li313[] C_aligned={C_lihdr(0,0,10),40,108,112,32,105,32,114,101,115,41,0,0,0,0,0,0};
static C_char C_TLS li314[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,62,112,108,105,115,116,32,99,115,41};
static C_char C_TLS li315[] C_aligned={C_lihdr(0,0,14),40,97,50,54,52,56,57,32,99,104,32,99,115,41,0,0};
static C_char C_TLS li316[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,116,114,105,110,103,45,62,99,115,101,116,32,115,41};
static C_char C_TLS li317[] C_aligned={C_lihdr(0,0,9),40,114,101,99,32,115,114,101,41,0,0,0,0,0,0,0};
static C_char C_TLS li318[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,53,50,53,48,32,103,53,50,54,50,41,0,0,0,0};
static C_char C_TLS li319[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,53,50,55,54,32,103,53,50,56,56,41,0,0,0,0};
static C_char C_TLS li320[] C_aligned={C_lihdr(0,0,14),40,97,50,54,54,57,51,32,120,32,114,101,115,41,0,0};
static C_char C_TLS li321[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,53,51,48,52,32,103,53,51,49,54,41,0,0,0,0};
static C_char C_TLS li322[] C_aligned={C_lihdr(0,0,11),40,108,112,32,108,115,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li323[] C_aligned={C_lihdr(0,0,11),40,108,112,32,108,115,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li324[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,53,51,51,49,32,103,53,51,52,51,41,0,0,0,0};
static C_char C_TLS li325[] C_aligned={C_lihdr(0,0,12),40,108,112,32,115,114,101,32,99,105,63,41,0,0,0,0};
static C_char C_TLS li326[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,62,99,115,101,116,32,115,114,101,32,111,41,0,0,0,0,0,0,0};
static C_char C_TLS li327[] C_aligned={C_lihdr(0,0,16),40,108,112,32,108,111,119,101,114,32,117,112,112,101,114,41};
static C_char C_TLS li328[] C_aligned={C_lihdr(0,0,40),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,99,111,110,116,97,105,110,115,63,32,99,115,101,116,32,99,104,41};
static C_char C_TLS li329[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,104,97,114,45,114,97,110,103,101,115,45,117,110,105,111,110,32,98,41,0,0,0};
static C_char C_TLS li330[] C_aligned={C_lihdr(0,0,21),40,117,110,105,111,110,45,114,97,110,103,101,32,97,32,98,32,114,101,115,41,0,0,0};
static C_char C_TLS li331[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,117,110,105,111,110,32,97,32,98,41};
static C_char C_TLS li332[] C_aligned={C_lihdr(0,0,14),40,100,105,102,102,32,97,32,98,32,114,101,115,41,0,0};
static C_char C_TLS li333[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,100,105,102,102,101,114,101,110,99,101,32,97,32,98,41,0,0,0};
static C_char C_TLS li334[] C_aligned={C_lihdr(0,0,19),40,105,110,116,101,114,115,101,99,116,32,97,32,98,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li335[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,105,110,116,101,114,115,101,99,116,105,111,110,32,97,32,98,41,0};
static C_char C_TLS li336[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,99,111,109,112,108,101,109,101,110,116,32,97,41,0,0,0,0,0};
static C_char C_TLS li337[] C_aligned={C_lihdr(0,0,11),40,108,112,32,108,115,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li338[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,99,97,115,101,45,105,110,115,101,110,115,105,116,105,118,101,32,97,41,0,0,0,0,0,0,0};
static C_char C_TLS li339[] C_aligned={C_lihdr(0,0,15),40,102,95,50,55,57,53,49,32,105,32,97,99,99,41,0};
static C_char C_TLS li340[] C_aligned={C_lihdr(0,0,19),40,108,112,32,115,114,99,32,102,114,111,109,32,105,32,97,99,99,41,0,0,0,0,0};
static C_char C_TLS li341[] C_aligned={C_lihdr(0,0,57),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,102,111,108,100,47,102,97,115,116,32,105,114,120,32,107,111,110,115,32,107,110,105,108,32,115,116,114,32,46,32,111,41,0,0,0,0,0,0,0};
static C_char C_TLS li342[] C_aligned={C_lihdr(0,0,15),40,107,111,110,115,50,32,105,32,109,32,97,99,99,41,0};
static C_char C_TLS li343[] C_aligned={C_lihdr(0,0,46),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,102,111,108,100,32,105,114,120,32,107,111,110,115,32,46,32,97,114,103,115,41,0,0};
static C_char C_TLS li344[] C_aligned={C_lihdr(0,0,19),40,102,95,50,56,49,55,49,32,115,114,99,32,105,32,97,99,99,41,0,0,0,0,0};
static C_char C_TLS li345[] C_aligned={C_lihdr(0,0,16),40,108,112,32,115,116,97,114,116,32,105,32,97,99,99,41};
static C_char C_TLS li346[] C_aligned={C_lihdr(0,0,71),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,102,111,108,100,47,99,104,117,110,107,101,100,47,102,97,115,116,32,105,114,120,32,107,111,110,115,32,107,110,105,108,32,99,110,107,32,115,116,97,114,116,32,46,32,111,41,0};
static C_char C_TLS li347[] C_aligned={C_lihdr(0,0,17),40,107,111,110,115,50,32,115,32,105,32,109,32,97,99,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li348[] C_aligned={C_lihdr(0,0,54),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,102,111,108,100,47,99,104,117,110,107,101,100,32,105,114,120,32,107,111,110,115,32,46,32,97,114,103,115,41,0,0};
static C_char C_TLS li349[] C_aligned={C_lihdr(0,0,45),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,114,101,112,108,97,99,101,32,105,114,120,32,115,116,114,32,46,32,111,41,0,0,0};
static C_char C_TLS li350[] C_aligned={C_lihdr(0,0,16),40,97,50,56,50,57,51,32,105,32,109,32,97,99,99,41};
static C_char C_TLS li351[] C_aligned={C_lihdr(0,0,14),40,97,50,56,51,52,52,32,105,32,97,99,99,41,0,0};
static C_char C_TLS li352[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,114,101,112,108,97,99,101,47,97,108,108,32,105,114,120,32,115,116,114,32,46,32,111,41,0,0,0,0,0,0,0};
static C_char C_TLS li353[] C_aligned={C_lihdr(0,0,9),40,103,53,54,53,56,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li354[] C_aligned={C_lihdr(0,0,11),40,108,112,32,108,115,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li355[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,97,112,112,108,121,45,109,97,116,99,104,32,109,32,108,115,41,0,0,0,0,0,0};
static C_char C_TLS li356[] C_aligned={C_lihdr(0,0,14),40,97,50,56,54,49,55,32,105,32,109,32,97,41,0,0};
static C_char C_TLS li357[] C_aligned={C_lihdr(0,0,12),40,97,50,56,54,50,55,32,105,32,97,41,0,0,0,0};
static C_char C_TLS li358[] C_aligned={C_lihdr(0,0,45),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,101,120,116,114,97,99,116,32,105,114,120,32,115,116,114,32,46,32,111,41,0,0,0};
static C_char C_TLS li359[] C_aligned={C_lihdr(0,0,14),40,97,50,56,54,53,56,32,105,32,109,32,97,41,0,0};
static C_char C_TLS li360[] C_aligned={C_lihdr(0,0,21),40,108,112,32,108,115,32,114,101,115,32,119,97,115,45,99,104,97,114,63,41,0,0,0};
static C_char C_TLS li361[] C_aligned={C_lihdr(0,0,12),40,97,50,56,55,49,54,32,105,32,97,41,0,0,0,0};
static C_char C_TLS li362[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,115,112,108,105,116,32,105,114,120,32,115,116,114,32,46,32,111,41,0,0,0,0,0};
static C_char C_TLS li363[] C_aligned={C_lihdr(0,0,8),40,115,99,97,110,32,105,41};
static C_char C_TLS li364[] C_aligned={C_lihdr(0,0,44),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,116,114,105,110,103,45,115,99,97,110,45,99,104,97,114,32,115,116,114,32,99,32,46,32,111,41,0,0,0,0};
static C_char C_TLS li365[] C_aligned={C_lihdr(0,0,13),40,108,111,111,112,32,108,115,32,114,101,115,41,0,0,0};
static C_char C_TLS li366[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,113,117,111,116,101,32,115,116,114,41,0,0,0,0,0};
static C_char C_TLS li367[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,53,57,53,55,32,103,53,57,54,57,41,0,0,0,0};
static C_char C_TLS li368[] C_aligned={C_lihdr(0,0,10),40,97,50,57,48,52,56,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li369[] C_aligned={C_lihdr(0,0,11),40,108,112,50,32,105,32,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li370[] C_aligned={C_lihdr(0,0,15),40,108,112,49,32,108,115,32,101,109,112,116,121,63,41,0};
static C_char C_TLS li371[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,105,114,114,101,103,101,120,45,111,112,116,32,108,115,41};
static C_char C_TLS li372[] C_aligned={C_lihdr(0,0,7),40,108,112,32,108,115,41,0};
static C_char C_TLS li373[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,99,115,101,116,45,62,115,116,114,105,110,103,32,108,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li374[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,48,53,55,32,103,54,48,54,52,41,0,0,0,0,0,0,0};
static C_char C_TLS li375[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,48,55,54,32,103,54,48,56,51,41,0,0,0,0,0,0,0};
static C_char C_TLS li376[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,48,57,51,32,103,54,49,48,48,41,0,0,0,0,0,0,0};
static C_char C_TLS li377[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,49,49,50,32,103,54,49,49,57,41,0,0,0,0,0,0,0};
static C_char C_TLS li378[] C_aligned={C_lihdr(0,0,9),40,103,54,49,51,52,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li379[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,49,51,51,32,103,54,49,52,48,41,0,0,0,0,0,0,0};
static C_char C_TLS li380[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,49,55,53,32,103,54,49,56,50,41,0,0,0,0,0,0,0};
static C_char C_TLS li381[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,50,51,48,32,103,54,50,51,55,41,0,0,0,0,0,0,0};
static C_char C_TLS li382[] C_aligned={C_lihdr(0,0,6),40,108,112,32,120,41,0,0};
static C_char C_TLS li383[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,115,114,101,45,62,115,116,114,105,110,103,32,111,98,106,41,0,0,0,0,0,0,0};
static C_char C_TLS li384[] C_aligned={C_lihdr(0,0,14),40,108,111,111,112,50,32,114,101,115,116,32,115,41,0,0};
static C_char C_TLS li385[] C_aligned={C_lihdr(0,0,13),40,108,111,111,112,32,99,115,32,100,105,114,41,0,0,0};
static C_char C_TLS li386[] C_aligned={C_lihdr(0,0,29),40,99,104,105,99,107,101,110,46,105,114,114,101,103,101,120,35,103,108,111,98,45,62,115,114,101,32,115,41,0,0,0};
static C_char C_TLS li387[] C_aligned={C_lihdr(0,0,10),40,97,51,48,57,55,52,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li388[] C_aligned={C_lihdr(0,0,22),40,97,51,48,57,55,55,32,115,114,99,49,32,105,32,115,114,99,50,32,106,41,0,0};
static C_char C_TLS li389[] C_aligned={C_lihdr(0,0,14),40,97,51,49,48,49,49,32,109,32,111,117,116,41,0,0};
static C_char C_TLS li390[] C_aligned={C_lihdr(0,0,10),40,116,111,112,108,101,118,101,108,41,0,0,0,0,0,0};


C_noret_decl(f33662)
static void C_ccall f33662(C_word c,C_word *av) C_noret;
C_noret_decl(f33666)
static void C_ccall f33666(C_word c,C_word *av) C_noret;
C_noret_decl(f_10027)
static void C_fcall f_10027(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_10030)
static void C_fcall f_10030(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10044)
static void C_ccall f_10044(C_word c,C_word *av) C_noret;
C_noret_decl(f_10069)
static void C_ccall f_10069(C_word c,C_word *av) C_noret;
C_noret_decl(f_10076)
static void C_ccall f_10076(C_word c,C_word *av) C_noret;
C_noret_decl(f_10095)
static void C_ccall f_10095(C_word c,C_word *av) C_noret;
C_noret_decl(f_10128)
static void C_ccall f_10128(C_word c,C_word *av) C_noret;
C_noret_decl(f_10146)
static void C_ccall f_10146(C_word c,C_word *av) C_noret;
C_noret_decl(f_10166)
static void C_ccall f_10166(C_word c,C_word *av) C_noret;
C_noret_decl(f_10246)
static void C_fcall f_10246(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10256)
static void C_fcall f_10256(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10259)
static void C_ccall f_10259(C_word c,C_word *av) C_noret;
C_noret_decl(f_10266)
static void C_ccall f_10266(C_word c,C_word *av) C_noret;
C_noret_decl(f_10269)
static void C_ccall f_10269(C_word c,C_word *av) C_noret;
C_noret_decl(f_10317)
static void C_ccall f_10317(C_word c,C_word *av) C_noret;
C_noret_decl(f_10338)
static void C_fcall f_10338(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10344)
static void C_fcall f_10344(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10362)
static void C_fcall f_10362(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10373)
static void C_fcall f_10373(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10461)
static void C_ccall f_10461(C_word c,C_word *av) C_noret;
C_noret_decl(f_10473)
static void C_ccall f_10473(C_word c,C_word *av) C_noret;
C_noret_decl(f_10477)
static void C_ccall f_10477(C_word c,C_word *av) C_noret;
C_noret_decl(f_10483)
static void C_ccall f_10483(C_word c,C_word *av) C_noret;
C_noret_decl(f_10488)
static void C_fcall f_10488(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_10491)
static C_word C_fcall f_10491(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_10513)
static void C_fcall f_10513(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10530)
static void C_ccall f_10530(C_word c,C_word *av) C_noret;
C_noret_decl(f_10533)
static void C_ccall f_10533(C_word c,C_word *av) C_noret;
C_noret_decl(f_10535)
static void C_fcall f_10535(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10569)
static void C_fcall f_10569(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10583)
static void C_ccall f_10583(C_word c,C_word *av) C_noret;
C_noret_decl(f_10587)
static void C_ccall f_10587(C_word c,C_word *av) C_noret;
C_noret_decl(f_10589)
static void C_fcall f_10589(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10596)
static void C_ccall f_10596(C_word c,C_word *av) C_noret;
C_noret_decl(f_10605)
static void C_fcall f_10605(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10625)
static void C_ccall f_10625(C_word c,C_word *av) C_noret;
C_noret_decl(f_10629)
static void C_ccall f_10629(C_word c,C_word *av) C_noret;
C_noret_decl(f_10633)
static void C_ccall f_10633(C_word c,C_word *av) C_noret;
C_noret_decl(f_10661)
static void C_fcall f_10661(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10665)
static void C_ccall f_10665(C_word c,C_word *av) C_noret;
C_noret_decl(f_10668)
static void C_fcall f_10668(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10671)
static void C_fcall f_10671(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10674)
static void C_ccall f_10674(C_word c,C_word *av) C_noret;
C_noret_decl(f_10679)
static void C_fcall f_10679(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_10682)
static C_word C_fcall f_10682(C_word *a,C_word t0);
C_noret_decl(f_10752)
static void C_ccall f_10752(C_word c,C_word *av) C_noret;
C_noret_decl(f_10768)
static void C_ccall f_10768(C_word c,C_word *av) C_noret;
C_noret_decl(f_10844)
static void C_ccall f_10844(C_word c,C_word *av) C_noret;
C_noret_decl(f_10855)
static void C_ccall f_10855(C_word c,C_word *av) C_noret;
C_noret_decl(f_10869)
static void C_ccall f_10869(C_word c,C_word *av) C_noret;
C_noret_decl(f_10891)
static void C_ccall f_10891(C_word c,C_word *av) C_noret;
C_noret_decl(f_10894)
static void C_fcall f_10894(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10906)
static void C_ccall f_10906(C_word c,C_word *av) C_noret;
C_noret_decl(f_10966)
static void C_ccall f_10966(C_word c,C_word *av) C_noret;
C_noret_decl(f_10995)
static void C_fcall f_10995(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11126)
static void C_ccall f_11126(C_word c,C_word *av) C_noret;
C_noret_decl(f_11132)
static void C_ccall f_11132(C_word c,C_word *av) C_noret;
C_noret_decl(f_11147)
static void C_ccall f_11147(C_word c,C_word *av) C_noret;
C_noret_decl(f_11218)
static void C_ccall f_11218(C_word c,C_word *av) C_noret;
C_noret_decl(f_11248)
static void C_ccall f_11248(C_word c,C_word *av) C_noret;
C_noret_decl(f_11258)
static void C_fcall f_11258(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11280)
static void C_ccall f_11280(C_word c,C_word *av) C_noret;
C_noret_decl(f_11315)
static void C_ccall f_11315(C_word c,C_word *av) C_noret;
C_noret_decl(f_11330)
static void C_ccall f_11330(C_word c,C_word *av) C_noret;
C_noret_decl(f_11356)
static void C_ccall f_11356(C_word c,C_word *av) C_noret;
C_noret_decl(f_11379)
static void C_ccall f_11379(C_word c,C_word *av) C_noret;
C_noret_decl(f_11402)
static void C_ccall f_11402(C_word c,C_word *av) C_noret;
C_noret_decl(f_11444)
static void C_ccall f_11444(C_word c,C_word *av) C_noret;
C_noret_decl(f_11467)
static void C_ccall f_11467(C_word c,C_word *av) C_noret;
C_noret_decl(f_11470)
static void C_ccall f_11470(C_word c,C_word *av) C_noret;
C_noret_decl(f_11496)
static void C_ccall f_11496(C_word c,C_word *av) C_noret;
C_noret_decl(f_11500)
static void C_ccall f_11500(C_word c,C_word *av) C_noret;
C_noret_decl(f_11504)
static void C_ccall f_11504(C_word c,C_word *av) C_noret;
C_noret_decl(f_11556)
static void C_ccall f_11556(C_word c,C_word *av) C_noret;
C_noret_decl(f_11581)
static void C_ccall f_11581(C_word c,C_word *av) C_noret;
C_noret_decl(f_11584)
static void C_ccall f_11584(C_word c,C_word *av) C_noret;
C_noret_decl(f_11614)
static void C_ccall f_11614(C_word c,C_word *av) C_noret;
C_noret_decl(f_11618)
static void C_ccall f_11618(C_word c,C_word *av) C_noret;
C_noret_decl(f_11633)
static void C_ccall f_11633(C_word c,C_word *av) C_noret;
C_noret_decl(f_11636)
static void C_ccall f_11636(C_word c,C_word *av) C_noret;
C_noret_decl(f_11657)
static void C_ccall f_11657(C_word c,C_word *av) C_noret;
C_noret_decl(f_11661)
static void C_ccall f_11661(C_word c,C_word *av) C_noret;
C_noret_decl(f_11684)
static void C_ccall f_11684(C_word c,C_word *av) C_noret;
C_noret_decl(f_11715)
static void C_fcall f_11715(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_11718)
static C_word C_fcall f_11718(C_word t0,C_word t1);
C_noret_decl(f_11727)
static C_word C_fcall f_11727(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_11871)
static void C_ccall f_11871(C_word c,C_word *av) C_noret;
C_noret_decl(f_11902)
static void C_ccall f_11902(C_word c,C_word *av) C_noret;
C_noret_decl(f_11993)
static void C_ccall f_11993(C_word c,C_word *av) C_noret;
C_noret_decl(f_12008)
static void C_ccall f_12008(C_word c,C_word *av) C_noret;
C_noret_decl(f_12028)
static void C_ccall f_12028(C_word c,C_word *av) C_noret;
C_noret_decl(f_12032)
static void C_ccall f_12032(C_word c,C_word *av) C_noret;
C_noret_decl(f_12051)
static void C_fcall f_12051(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12060)
static void C_ccall f_12060(C_word c,C_word *av) C_noret;
C_noret_decl(f_12076)
static void C_ccall f_12076(C_word c,C_word *av) C_noret;
C_noret_decl(f_12079)
static void C_ccall f_12079(C_word c,C_word *av) C_noret;
C_noret_decl(f_12082)
static void C_ccall f_12082(C_word c,C_word *av) C_noret;
C_noret_decl(f_12085)
static void C_ccall f_12085(C_word c,C_word *av) C_noret;
C_noret_decl(f_12094)
static void C_fcall f_12094(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12204)
static void C_ccall f_12204(C_word c,C_word *av) C_noret;
C_noret_decl(f_12280)
static void C_ccall f_12280(C_word c,C_word *av) C_noret;
C_noret_decl(f_12307)
static void C_ccall f_12307(C_word c,C_word *av) C_noret;
C_noret_decl(f_12330)
static void C_ccall f_12330(C_word c,C_word *av) C_noret;
C_noret_decl(f_12357)
static void C_ccall f_12357(C_word c,C_word *av) C_noret;
C_noret_decl(f_12384)
static void C_ccall f_12384(C_word c,C_word *av) C_noret;
C_noret_decl(f_12415)
static void C_ccall f_12415(C_word c,C_word *av) C_noret;
C_noret_decl(f_12450)
static void C_ccall f_12450(C_word c,C_word *av) C_noret;
C_noret_decl(f_12473)
static void C_ccall f_12473(C_word c,C_word *av) C_noret;
C_noret_decl(f_12496)
static void C_ccall f_12496(C_word c,C_word *av) C_noret;
C_noret_decl(f_12527)
static void C_ccall f_12527(C_word c,C_word *av) C_noret;
C_noret_decl(f_12550)
static void C_ccall f_12550(C_word c,C_word *av) C_noret;
C_noret_decl(f_12573)
static void C_ccall f_12573(C_word c,C_word *av) C_noret;
C_noret_decl(f_12596)
static void C_ccall f_12596(C_word c,C_word *av) C_noret;
C_noret_decl(f_12619)
static void C_ccall f_12619(C_word c,C_word *av) C_noret;
C_noret_decl(f_12642)
static void C_ccall f_12642(C_word c,C_word *av) C_noret;
C_noret_decl(f_12653)
static void C_ccall f_12653(C_word c,C_word *av) C_noret;
C_noret_decl(f_12673)
static void C_ccall f_12673(C_word c,C_word *av) C_noret;
C_noret_decl(f_12677)
static void C_ccall f_12677(C_word c,C_word *av) C_noret;
C_noret_decl(f_12701)
static void C_fcall f_12701(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12704)
static void C_ccall f_12704(C_word c,C_word *av) C_noret;
C_noret_decl(f_12707)
static void C_ccall f_12707(C_word c,C_word *av) C_noret;
C_noret_decl(f_12742)
static void C_ccall f_12742(C_word c,C_word *av) C_noret;
C_noret_decl(f_12746)
static void C_ccall f_12746(C_word c,C_word *av) C_noret;
C_noret_decl(f_12773)
static void C_ccall f_12773(C_word c,C_word *av) C_noret;
C_noret_decl(f_12781)
static void C_fcall f_12781(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12841)
static void C_ccall f_12841(C_word c,C_word *av) C_noret;
C_noret_decl(f_12884)
static void C_ccall f_12884(C_word c,C_word *av) C_noret;
C_noret_decl(f_12896)
static void C_ccall f_12896(C_word c,C_word *av) C_noret;
C_noret_decl(f_12905)
static void C_ccall f_12905(C_word c,C_word *av) C_noret;
C_noret_decl(f_12925)
static void C_ccall f_12925(C_word c,C_word *av) C_noret;
C_noret_decl(f_12929)
static void C_ccall f_12929(C_word c,C_word *av) C_noret;
C_noret_decl(f_12933)
static void C_ccall f_12933(C_word c,C_word *av) C_noret;
C_noret_decl(f_12985)
static void C_ccall f_12985(C_word c,C_word *av) C_noret;
C_noret_decl(f_13001)
static void C_ccall f_13001(C_word c,C_word *av) C_noret;
C_noret_decl(f_13065)
static void C_ccall f_13065(C_word c,C_word *av) C_noret;
C_noret_decl(f_13091)
static void C_ccall f_13091(C_word c,C_word *av) C_noret;
C_noret_decl(f_13120)
static void C_ccall f_13120(C_word c,C_word *av) C_noret;
C_noret_decl(f_13148)
static void C_ccall f_13148(C_word c,C_word *av) C_noret;
C_noret_decl(f_13169)
static void C_ccall f_13169(C_word c,C_word *av) C_noret;
C_noret_decl(f_13187)
static void C_ccall f_13187(C_word c,C_word *av) C_noret;
C_noret_decl(f_13301)
static void C_fcall f_13301(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13320)
static void C_ccall f_13320(C_word c,C_word *av) C_noret;
C_noret_decl(f_13332)
static void C_ccall f_13332(C_word c,C_word *av) C_noret;
C_noret_decl(f_13335)
static void C_ccall f_13335(C_word c,C_word *av) C_noret;
C_noret_decl(f_13366)
static void C_ccall f_13366(C_word c,C_word *av) C_noret;
C_noret_decl(f_13369)
static void C_ccall f_13369(C_word c,C_word *av) C_noret;
C_noret_decl(f_13410)
static void C_fcall f_13410(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_13445)
static void C_ccall f_13445(C_word c,C_word *av) C_noret;
C_noret_decl(f_13455)
static void C_ccall f_13455(C_word c,C_word *av) C_noret;
C_noret_decl(f_13462)
static void C_ccall f_13462(C_word c,C_word *av) C_noret;
C_noret_decl(f_13483)
static void C_fcall f_13483(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13493)
static void C_ccall f_13493(C_word c,C_word *av) C_noret;
C_noret_decl(f_13510)
static void C_ccall f_13510(C_word c,C_word *av) C_noret;
C_noret_decl(f_13527)
static void C_ccall f_13527(C_word c,C_word *av) C_noret;
C_noret_decl(f_13538)
static void C_ccall f_13538(C_word c,C_word *av) C_noret;
C_noret_decl(f_13539)
static C_word C_fcall f_13539(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_13560)
static void C_fcall f_13560(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13572)
static void C_fcall f_13572(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13582)
static void C_ccall f_13582(C_word c,C_word *av) C_noret;
C_noret_decl(f_13685)
static void C_ccall f_13685(C_word c,C_word *av) C_noret;
C_noret_decl(f_13694)
static void C_fcall f_13694(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13700)
static void C_ccall f_13700(C_word c,C_word *av) C_noret;
C_noret_decl(f_13703)
static void C_ccall f_13703(C_word c,C_word *av) C_noret;
C_noret_decl(f_13713)
static void C_ccall f_13713(C_word c,C_word *av) C_noret;
C_noret_decl(f_13720)
static void C_ccall f_13720(C_word c,C_word *av) C_noret;
C_noret_decl(f_13724)
static void C_ccall f_13724(C_word c,C_word *av) C_noret;
C_noret_decl(f_13768)
static void C_ccall f_13768(C_word c,C_word *av) C_noret;
C_noret_decl(f_13807)
static void C_fcall f_13807(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13817)
static void C_ccall f_13817(C_word c,C_word *av) C_noret;
C_noret_decl(f_13821)
static void C_ccall f_13821(C_word c,C_word *av) C_noret;
C_noret_decl(f_13825)
static void C_ccall f_13825(C_word c,C_word *av) C_noret;
C_noret_decl(f_13840)
static void C_ccall f_13840(C_word c,C_word *av) C_noret;
C_noret_decl(f_13848)
static void C_ccall f_13848(C_word c,C_word *av) C_noret;
C_noret_decl(f_13852)
static void C_ccall f_13852(C_word c,C_word *av) C_noret;
C_noret_decl(f_13871)
static void C_ccall f_13871(C_word c,C_word *av) C_noret;
C_noret_decl(f_13924)
static void C_fcall f_13924(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13938)
static void C_ccall f_13938(C_word c,C_word *av) C_noret;
C_noret_decl(f_13942)
static void C_ccall f_13942(C_word c,C_word *av) C_noret;
C_noret_decl(f_13946)
static void C_ccall f_13946(C_word c,C_word *av) C_noret;
C_noret_decl(f_13956)
static void C_ccall f_13956(C_word c,C_word *av) C_noret;
C_noret_decl(f_14014)
static void C_ccall f_14014(C_word c,C_word *av) C_noret;
C_noret_decl(f_14035)
static void C_fcall f_14035(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_14038)
static C_word C_fcall f_14038(C_word t0,C_word t1);
C_noret_decl(f_14230)
static void C_fcall f_14230(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14268)
static void C_fcall f_14268(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14344)
static void C_fcall f_14344(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14485)
static void C_ccall f_14485(C_word c,C_word *av) C_noret;
C_noret_decl(f_14488)
static void C_ccall f_14488(C_word c,C_word *av) C_noret;
C_noret_decl(f_14509)
static void C_ccall f_14509(C_word c,C_word *av) C_noret;
C_noret_decl(f_14514)
static void C_fcall f_14514(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_14546)
static void C_ccall f_14546(C_word c,C_word *av) C_noret;
C_noret_decl(f_14571)
static void C_ccall f_14571(C_word c,C_word *av) C_noret;
C_noret_decl(f_14575)
static void C_ccall f_14575(C_word c,C_word *av) C_noret;
C_noret_decl(f_14586)
static void C_ccall f_14586(C_word c,C_word *av) C_noret;
C_noret_decl(f_14594)
static void C_ccall f_14594(C_word c,C_word *av) C_noret;
C_noret_decl(f_14620)
static void C_fcall f_14620(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_14650)
static void C_ccall f_14650(C_word c,C_word *av) C_noret;
C_noret_decl(f_14660)
static void C_ccall f_14660(C_word c,C_word *av) C_noret;
C_noret_decl(f_14668)
static void C_ccall f_14668(C_word c,C_word *av) C_noret;
C_noret_decl(f_14684)
static void C_ccall f_14684(C_word c,C_word *av) C_noret;
C_noret_decl(f_14686)
static void C_fcall f_14686(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14722)
static void C_fcall f_14722(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14758)
static void C_fcall f_14758(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14778)
static void C_ccall f_14778(C_word c,C_word *av) C_noret;
C_noret_decl(f_14780)
static void C_ccall f_14780(C_word c,C_word *av) C_noret;
C_noret_decl(f_14812)
static void C_ccall f_14812(C_word c,C_word *av) C_noret;
C_noret_decl(f_14819)
static void C_ccall f_14819(C_word c,C_word *av) C_noret;
C_noret_decl(f_14825)
static void C_ccall f_14825(C_word c,C_word *av) C_noret;
C_noret_decl(f_14841)
static void C_ccall f_14841(C_word c,C_word *av) C_noret;
C_noret_decl(f_14843)
static void C_fcall f_14843(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14883)
static void C_ccall f_14883(C_word c,C_word *av) C_noret;
C_noret_decl(f_14889)
static void C_ccall f_14889(C_word c,C_word *av) C_noret;
C_noret_decl(f_14897)
static void C_fcall f_14897(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14917)
static void C_ccall f_14917(C_word c,C_word *av) C_noret;
C_noret_decl(f_14919)
static void C_ccall f_14919(C_word c,C_word *av) C_noret;
C_noret_decl(f_14951)
static void C_ccall f_14951(C_word c,C_word *av) C_noret;
C_noret_decl(f_14958)
static void C_ccall f_14958(C_word c,C_word *av) C_noret;
C_noret_decl(f_14964)
static void C_ccall f_14964(C_word c,C_word *av) C_noret;
C_noret_decl(f_14980)
static void C_ccall f_14980(C_word c,C_word *av) C_noret;
C_noret_decl(f_14982)
static void C_fcall f_14982(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15022)
static void C_ccall f_15022(C_word c,C_word *av) C_noret;
C_noret_decl(f_15028)
static void C_ccall f_15028(C_word c,C_word *av) C_noret;
C_noret_decl(f_15047)
static void C_ccall f_15047(C_word c,C_word *av) C_noret;
C_noret_decl(f_15056)
static void C_fcall f_15056(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15068)
static void C_fcall f_15068(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15080)
static void C_ccall f_15080(C_word c,C_word *av) C_noret;
C_noret_decl(f_15086)
static void C_ccall f_15086(C_word c,C_word *av) C_noret;
C_noret_decl(f_15088)
static void C_fcall f_15088(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15136)
static void C_ccall f_15136(C_word c,C_word *av) C_noret;
C_noret_decl(f_15144)
static void C_ccall f_15144(C_word c,C_word *av) C_noret;
C_noret_decl(f_15151)
static void C_ccall f_15151(C_word c,C_word *av) C_noret;
C_noret_decl(f_15157)
static void C_ccall f_15157(C_word c,C_word *av) C_noret;
C_noret_decl(f_15189)
static void C_ccall f_15189(C_word c,C_word *av) C_noret;
C_noret_decl(f_15191)
static void C_fcall f_15191(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15241)
static void C_ccall f_15241(C_word c,C_word *av) C_noret;
C_noret_decl(f_15259)
static void C_fcall f_15259(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15284)
static void C_ccall f_15284(C_word c,C_word *av) C_noret;
C_noret_decl(f_15327)
static void C_ccall f_15327(C_word c,C_word *av) C_noret;
C_noret_decl(f_15329)
static void C_fcall f_15329(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15418)
static void C_ccall f_15418(C_word c,C_word *av) C_noret;
C_noret_decl(f_15420)
static void C_fcall f_15420(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15475)
static void C_fcall f_15475(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15483)
static void C_ccall f_15483(C_word c,C_word *av) C_noret;
C_noret_decl(f_15485)
static void C_fcall f_15485(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_15499)
static void C_ccall f_15499(C_word c,C_word *av) C_noret;
C_noret_decl(f_15503)
static void C_ccall f_15503(C_word c,C_word *av) C_noret;
C_noret_decl(f_15521)
static void C_ccall f_15521(C_word c,C_word *av) C_noret;
C_noret_decl(f_15530)
static void C_fcall f_15530(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15545)
static void C_ccall f_15545(C_word c,C_word *av) C_noret;
C_noret_decl(f_15597)
static void C_fcall f_15597(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_15600)
static void C_fcall f_15600(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15657)
static void C_fcall f_15657(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15668)
static void C_ccall f_15668(C_word c,C_word *av) C_noret;
C_noret_decl(f_15670)
static void C_fcall f_15670(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15695)
static void C_ccall f_15695(C_word c,C_word *av) C_noret;
C_noret_decl(f_15718)
static void C_fcall f_15718(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15729)
static void C_ccall f_15729(C_word c,C_word *av) C_noret;
C_noret_decl(f_15731)
static void C_fcall f_15731(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15756)
static void C_ccall f_15756(C_word c,C_word *av) C_noret;
C_noret_decl(f_15772)
static void C_fcall f_15772(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15781)
static void C_ccall f_15781(C_word c,C_word *av) C_noret;
C_noret_decl(f_15787)
static void C_ccall f_15787(C_word c,C_word *av) C_noret;
C_noret_decl(f_15797)
static void C_ccall f_15797(C_word c,C_word *av) C_noret;
C_noret_decl(f_15804)
static void C_ccall f_15804(C_word c,C_word *av) C_noret;
C_noret_decl(f_15839)
static void C_ccall f_15839(C_word c,C_word *av) C_noret;
C_noret_decl(f_15841)
static void C_fcall f_15841(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15866)
static void C_ccall f_15866(C_word c,C_word *av) C_noret;
C_noret_decl(f_15895)
static void C_ccall f_15895(C_word c,C_word *av) C_noret;
C_noret_decl(f_15897)
static void C_fcall f_15897(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15922)
static void C_ccall f_15922(C_word c,C_word *av) C_noret;
C_noret_decl(f_15986)
static void C_fcall f_15986(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15996)
static void C_ccall f_15996(C_word c,C_word *av) C_noret;
C_noret_decl(f_15999)
static void C_ccall f_15999(C_word c,C_word *av) C_noret;
C_noret_decl(f_16001)
static void C_fcall f_16001(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16048)
static void C_ccall f_16048(C_word c,C_word *av) C_noret;
C_noret_decl(f_16055)
static void C_ccall f_16055(C_word c,C_word *av) C_noret;
C_noret_decl(f_16109)
static void C_ccall f_16109(C_word c,C_word *av) C_noret;
C_noret_decl(f_16176)
static void C_ccall f_16176(C_word c,C_word *av) C_noret;
C_noret_decl(f_16184)
static void C_ccall f_16184(C_word c,C_word *av) C_noret;
C_noret_decl(f_16186)
static void C_ccall f_16186(C_word c,C_word *av) C_noret;
C_noret_decl(f_16190)
static void C_ccall f_16190(C_word c,C_word *av) C_noret;
C_noret_decl(f_16193)
static void C_ccall f_16193(C_word c,C_word *av) C_noret;
C_noret_decl(f_16196)
static void C_ccall f_16196(C_word c,C_word *av) C_noret;
C_noret_decl(f_16199)
static void C_ccall f_16199(C_word c,C_word *av) C_noret;
C_noret_decl(f_16205)
static void C_ccall f_16205(C_word c,C_word *av) C_noret;
C_noret_decl(f_16208)
static void C_ccall f_16208(C_word c,C_word *av) C_noret;
C_noret_decl(f_16211)
static void C_ccall f_16211(C_word c,C_word *av) C_noret;
C_noret_decl(f_16214)
static void C_ccall f_16214(C_word c,C_word *av) C_noret;
C_noret_decl(f_16217)
static void C_ccall f_16217(C_word c,C_word *av) C_noret;
C_noret_decl(f_16232)
static void C_ccall f_16232(C_word c,C_word *av) C_noret;
C_noret_decl(f_16246)
static void C_ccall f_16246(C_word c,C_word *av) C_noret;
C_noret_decl(f_16251)
static void C_fcall f_16251(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16277)
static void C_ccall f_16277(C_word c,C_word *av) C_noret;
C_noret_decl(f_16281)
static void C_fcall f_16281(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16319)
static void C_ccall f_16319(C_word c,C_word *av) C_noret;
C_noret_decl(f_16336)
static void C_fcall f_16336(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16379)
static void C_fcall f_16379(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16486)
static void C_ccall f_16486(C_word c,C_word *av) C_noret;
C_noret_decl(f_16509)
static void C_fcall f_16509(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16587)
static C_word C_fcall f_16587(C_word t0);
C_noret_decl(f_16632)
static void C_ccall f_16632(C_word c,C_word *av) C_noret;
C_noret_decl(f_16649)
static void C_fcall f_16649(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16721)
static void C_ccall f_16721(C_word c,C_word *av) C_noret;
C_noret_decl(f_16725)
static void C_ccall f_16725(C_word c,C_word *av) C_noret;
C_noret_decl(f_16762)
static void C_fcall f_16762(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16838)
static void C_ccall f_16838(C_word c,C_word *av) C_noret;
C_noret_decl(f_16842)
static void C_ccall f_16842(C_word c,C_word *av) C_noret;
C_noret_decl(f_16879)
static void C_fcall f_16879(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16892)
static void C_ccall f_16892(C_word c,C_word *av) C_noret;
C_noret_decl(f_16955)
static void C_ccall f_16955(C_word c,C_word *av) C_noret;
C_noret_decl(f_16981)
static void C_ccall f_16981(C_word c,C_word *av) C_noret;
C_noret_decl(f_16994)
static void C_fcall f_16994(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17000)
static void C_ccall f_17000(C_word c,C_word *av) C_noret;
C_noret_decl(f_17021)
static void C_ccall f_17021(C_word c,C_word *av) C_noret;
C_noret_decl(f_17027)
static void C_fcall f_17027(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17057)
static void C_ccall f_17057(C_word c,C_word *av) C_noret;
C_noret_decl(f_17094)
static void C_ccall f_17094(C_word c,C_word *av) C_noret;
C_noret_decl(f_17097)
static void C_ccall f_17097(C_word c,C_word *av) C_noret;
C_noret_decl(f_17104)
static void C_ccall f_17104(C_word c,C_word *av) C_noret;
C_noret_decl(f_17106)
static void C_fcall f_17106(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_17109)
static void C_fcall f_17109(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17149)
static void C_fcall f_17149(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17165)
static void C_ccall f_17165(C_word c,C_word *av) C_noret;
C_noret_decl(f_17178)
static void C_fcall f_17178(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17185)
static void C_fcall f_17185(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_17218)
static void C_ccall f_17218(C_word c,C_word *av) C_noret;
C_noret_decl(f_17248)
static void C_ccall f_17248(C_word c,C_word *av) C_noret;
C_noret_decl(f_17263)
static void C_fcall f_17263(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_17300)
static void C_ccall f_17300(C_word c,C_word *av) C_noret;
C_noret_decl(f_17316)
static void C_ccall f_17316(C_word c,C_word *av) C_noret;
C_noret_decl(f_17320)
static void C_ccall f_17320(C_word c,C_word *av) C_noret;
C_noret_decl(f_17333)
static void C_ccall f_17333(C_word c,C_word *av) C_noret;
C_noret_decl(f_17356)
static void C_ccall f_17356(C_word c,C_word *av) C_noret;
C_noret_decl(f_17359)
static void C_ccall f_17359(C_word c,C_word *av) C_noret;
C_noret_decl(f_17366)
static void C_fcall f_17366(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17368)
static void C_ccall f_17368(C_word c,C_word *av) C_noret;
C_noret_decl(f_17382)
static void C_ccall f_17382(C_word c,C_word *av) C_noret;
C_noret_decl(f_17396)
static void C_ccall f_17396(C_word c,C_word *av) C_noret;
C_noret_decl(f_17421)
static void C_ccall f_17421(C_word c,C_word *av) C_noret;
C_noret_decl(f_17425)
static void C_ccall f_17425(C_word c,C_word *av) C_noret;
C_noret_decl(f_17502)
static void C_fcall f_17502(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17515)
static void C_ccall f_17515(C_word c,C_word *av) C_noret;
C_noret_decl(f_17551)
static void C_ccall f_17551(C_word c,C_word *av) C_noret;
C_noret_decl(f_17560)
static void C_fcall f_17560(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17660)
static void C_ccall f_17660(C_word c,C_word *av) C_noret;
C_noret_decl(f_17669)
static void C_ccall f_17669(C_word c,C_word *av) C_noret;
C_noret_decl(f_17687)
static void C_fcall f_17687(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17690)
static void C_fcall f_17690(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17708)
static void C_ccall f_17708(C_word c,C_word *av) C_noret;
C_noret_decl(f_17755)
static void C_ccall f_17755(C_word c,C_word *av) C_noret;
C_noret_decl(f_17829)
static void C_ccall f_17829(C_word c,C_word *av) C_noret;
C_noret_decl(f_17857)
static void C_ccall f_17857(C_word c,C_word *av) C_noret;
C_noret_decl(f_17882)
static void C_fcall f_17882(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17901)
static void C_fcall f_17901(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17922)
static void C_fcall f_17922(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17932)
static void C_fcall f_17932(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17940)
static void C_ccall f_17940(C_word c,C_word *av) C_noret;
C_noret_decl(f_18171)
static void C_ccall f_18171(C_word c,C_word *av) C_noret;
C_noret_decl(f_18194)
static void C_ccall f_18194(C_word c,C_word *av) C_noret;
C_noret_decl(f_18203)
static C_word C_fcall f_18203(C_word *a,C_word t0);
C_noret_decl(f_18226)
static C_word C_fcall f_18226(C_word *a,C_word t0);
C_noret_decl(f_18249)
static void C_ccall f_18249(C_word c,C_word *av) C_noret;
C_noret_decl(f_18322)
static void C_fcall f_18322(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18347)
static void C_ccall f_18347(C_word c,C_word *av) C_noret;
C_noret_decl(f_18382)
static void C_fcall f_18382(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_18405)
static void C_ccall f_18405(C_word c,C_word *av) C_noret;
C_noret_decl(f_18409)
static void C_ccall f_18409(C_word c,C_word *av) C_noret;
C_noret_decl(f_18430)
static void C_fcall f_18430(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_18532)
static void C_fcall f_18532(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18716)
static void C_fcall f_18716(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_18738)
static void C_ccall f_18738(C_word c,C_word *av) C_noret;
C_noret_decl(f_18744)
static void C_ccall f_18744(C_word c,C_word *av) C_noret;
C_noret_decl(f_18748)
static void C_ccall f_18748(C_word c,C_word *av) C_noret;
C_noret_decl(f_18765)
static void C_fcall f_18765(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18798)
static void C_ccall f_18798(C_word c,C_word *av) C_noret;
C_noret_decl(f_18835)
static void C_ccall f_18835(C_word c,C_word *av) C_noret;
C_noret_decl(f_18837)
static void C_fcall f_18837(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18862)
static void C_ccall f_18862(C_word c,C_word *av) C_noret;
C_noret_decl(f_18930)
static void C_ccall f_18930(C_word c,C_word *av) C_noret;
C_noret_decl(f_18932)
static void C_ccall f_18932(C_word c,C_word *av) C_noret;
C_noret_decl(f_18936)
static void C_ccall f_18936(C_word c,C_word *av) C_noret;
C_noret_decl(f_18945)
static void C_fcall f_18945(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18951)
static void C_ccall f_18951(C_word c,C_word *av) C_noret;
C_noret_decl(f_18954)
static void C_ccall f_18954(C_word c,C_word *av) C_noret;
C_noret_decl(f_19022)
static void C_ccall f_19022(C_word c,C_word *av) C_noret;
C_noret_decl(f_19026)
static void C_ccall f_19026(C_word c,C_word *av) C_noret;
C_noret_decl(f_19029)
static void C_ccall f_19029(C_word c,C_word *av) C_noret;
C_noret_decl(f_19032)
static void C_ccall f_19032(C_word c,C_word *av) C_noret;
C_noret_decl(f_19035)
static void C_ccall f_19035(C_word c,C_word *av) C_noret;
C_noret_decl(f_19065)
static void C_fcall f_19065(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_19084)
static void C_ccall f_19084(C_word c,C_word *av) C_noret;
C_noret_decl(f_19109)
static void C_ccall f_19109(C_word c,C_word *av) C_noret;
C_noret_decl(f_19126)
static void C_fcall f_19126(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_19130)
static void C_ccall f_19130(C_word c,C_word *av) C_noret;
C_noret_decl(f_19135)
static void C_fcall f_19135(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19142)
static void C_ccall f_19142(C_word c,C_word *av) C_noret;
C_noret_decl(f_19165)
static void C_ccall f_19165(C_word c,C_word *av) C_noret;
C_noret_decl(f_19175)
static void C_ccall f_19175(C_word c,C_word *av) C_noret;
C_noret_decl(f_19196)
static void C_ccall f_19196(C_word c,C_word *av) C_noret;
C_noret_decl(f_19214)
static void C_ccall f_19214(C_word c,C_word *av) C_noret;
C_noret_decl(f_19220)
static void C_ccall f_19220(C_word c,C_word *av) C_noret;
C_noret_decl(f_19234)
static void C_ccall f_19234(C_word c,C_word *av) C_noret;
C_noret_decl(f_19240)
static void C_fcall f_19240(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_19247)
static void C_ccall f_19247(C_word c,C_word *av) C_noret;
C_noret_decl(f_19277)
static void C_ccall f_19277(C_word c,C_word *av) C_noret;
C_noret_decl(f_19290)
static void C_ccall f_19290(C_word c,C_word *av) C_noret;
C_noret_decl(f_19297)
static void C_ccall f_19297(C_word c,C_word *av) C_noret;
C_noret_decl(f_19304)
static void C_ccall f_19304(C_word c,C_word *av) C_noret;
C_noret_decl(f_19306)
static void C_ccall f_19306(C_word c,C_word *av) C_noret;
C_noret_decl(f_19314)
static void C_ccall f_19314(C_word c,C_word *av) C_noret;
C_noret_decl(f_19318)
static void C_ccall f_19318(C_word c,C_word *av) C_noret;
C_noret_decl(f_19327)
static void C_fcall f_19327(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19333)
static void C_ccall f_19333(C_word c,C_word *av) C_noret;
C_noret_decl(f_19336)
static void C_ccall f_19336(C_word c,C_word *av) C_noret;
C_noret_decl(f_19404)
static void C_ccall f_19404(C_word c,C_word *av) C_noret;
C_noret_decl(f_19408)
static void C_ccall f_19408(C_word c,C_word *av) C_noret;
C_noret_decl(f_19411)
static void C_ccall f_19411(C_word c,C_word *av) C_noret;
C_noret_decl(f_19426)
static void C_ccall f_19426(C_word c,C_word *av) C_noret;
C_noret_decl(f_19449)
static void C_ccall f_19449(C_word c,C_word *av) C_noret;
C_noret_decl(f_19460)
static void C_ccall f_19460(C_word c,C_word *av) C_noret;
C_noret_decl(f_19496)
static void C_ccall f_19496(C_word c,C_word *av) C_noret;
C_noret_decl(f_19506)
static void C_ccall f_19506(C_word c,C_word *av) C_noret;
C_noret_decl(f_19512)
static void C_ccall f_19512(C_word c,C_word *av) C_noret;
C_noret_decl(f_19518)
static void C_ccall f_19518(C_word c,C_word *av) C_noret;
C_noret_decl(f_19528)
static void C_ccall f_19528(C_word c,C_word *av) C_noret;
C_noret_decl(f_19530)
static void C_fcall f_19530(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19540)
static void C_fcall f_19540(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19559)
static void C_ccall f_19559(C_word c,C_word *av) C_noret;
C_noret_decl(f_19572)
static void C_ccall f_19572(C_word c,C_word *av) C_noret;
C_noret_decl(f_19604)
static void C_ccall f_19604(C_word c,C_word *av) C_noret;
C_noret_decl(f_19627)
static void C_ccall f_19627(C_word c,C_word *av) C_noret;
C_noret_decl(f_19632)
static void C_ccall f_19632(C_word c,C_word *av) C_noret;
C_noret_decl(f_19639)
static void C_ccall f_19639(C_word c,C_word *av) C_noret;
C_noret_decl(f_19690)
static void C_fcall f_19690(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_19697)
static void C_ccall f_19697(C_word c,C_word *av) C_noret;
C_noret_decl(f_19700)
static void C_ccall f_19700(C_word c,C_word *av) C_noret;
C_noret_decl(f_19705)
static void C_fcall f_19705(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_19757)
static void C_ccall f_19757(C_word c,C_word *av) C_noret;
C_noret_decl(f_19772)
static void C_ccall f_19772(C_word c,C_word *av) C_noret;
C_noret_decl(f_19808)
static void C_ccall f_19808(C_word c,C_word *av) C_noret;
C_noret_decl(f_19818)
static void C_ccall f_19818(C_word c,C_word *av) C_noret;
C_noret_decl(f_19828)
static void C_fcall f_19828(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_19830)
static C_word C_fcall f_19830(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_19888)
static void C_fcall f_19888(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19916)
static void C_ccall f_19916(C_word c,C_word *av) C_noret;
C_noret_decl(f_19920)
static void C_ccall f_19920(C_word c,C_word *av) C_noret;
C_noret_decl(f_19925)
static void C_fcall f_19925(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19945)
static void C_ccall f_19945(C_word c,C_word *av) C_noret;
C_noret_decl(f_19947)
static void C_fcall f_19947(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8) C_noret;
C_noret_decl(f_19972)
static void C_ccall f_19972(C_word c,C_word *av) C_noret;
C_noret_decl(f_19984)
static void C_fcall f_19984(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19987)
static void C_ccall f_19987(C_word c,C_word *av) C_noret;
C_noret_decl(f_20000)
static void C_fcall f_20000(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7) C_noret;
C_noret_decl(f_20004)
static void C_ccall f_20004(C_word c,C_word *av) C_noret;
C_noret_decl(f_20007)
static void C_ccall f_20007(C_word c,C_word *av) C_noret;
C_noret_decl(f_20012)
static void C_fcall f_20012(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_20022)
static void C_fcall f_20022(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20025)
static void C_ccall f_20025(C_word c,C_word *av) C_noret;
C_noret_decl(f_20035)
static void C_ccall f_20035(C_word c,C_word *av) C_noret;
C_noret_decl(f_20070)
static void C_ccall f_20070(C_word c,C_word *av) C_noret;
C_noret_decl(f_20122)
static void C_ccall f_20122(C_word c,C_word *av) C_noret;
C_noret_decl(f_20134)
static void C_ccall f_20134(C_word c,C_word *av) C_noret;
C_noret_decl(f_20158)
static void C_ccall f_20158(C_word c,C_word *av) C_noret;
C_noret_decl(f_20159)
static C_word C_fcall f_20159(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_20188)
static void C_ccall f_20188(C_word c,C_word *av) C_noret;
C_noret_decl(f_20197)
static void C_fcall f_20197(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20211)
static void C_ccall f_20211(C_word c,C_word *av) C_noret;
C_noret_decl(f_20230)
static void C_ccall f_20230(C_word c,C_word *av) C_noret;
C_noret_decl(f_20238)
static void C_fcall f_20238(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20248)
static void C_ccall f_20248(C_word c,C_word *av) C_noret;
C_noret_decl(f_20261)
static void C_fcall f_20261(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20286)
static void C_ccall f_20286(C_word c,C_word *av) C_noret;
C_noret_decl(f_20295)
static void C_fcall f_20295(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20331)
static void C_fcall f_20331(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20334)
static void C_ccall f_20334(C_word c,C_word *av) C_noret;
C_noret_decl(f_20373)
static void C_fcall f_20373(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20376)
static void C_ccall f_20376(C_word c,C_word *av) C_noret;
C_noret_decl(f_20401)
static void C_ccall f_20401(C_word c,C_word *av) C_noret;
C_noret_decl(f_20441)
static C_word C_fcall f_20441(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_20469)
static void C_fcall f_20469(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20594)
static C_word C_fcall f_20594(C_word t0,C_word t1);
C_noret_decl(f_20628)
static C_word C_fcall f_20628(C_word *a,C_word t0,C_word t1,C_word t2,C_word t3);
C_noret_decl(f_20769)
static void C_fcall f_20769(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20773)
static void C_ccall f_20773(C_word c,C_word *av) C_noret;
C_noret_decl(f_20776)
static void C_ccall f_20776(C_word c,C_word *av) C_noret;
C_noret_decl(f_20778)
static void C_fcall f_20778(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_20781)
static void C_fcall f_20781(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20791)
static void C_fcall f_20791(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20795)
static void C_fcall f_20795(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20804)
static void C_ccall f_20804(C_word c,C_word *av) C_noret;
C_noret_decl(f_20807)
static void C_ccall f_20807(C_word c,C_word *av) C_noret;
C_noret_decl(f_20816)
static void C_fcall f_20816(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20852)
static void C_fcall f_20852(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20863)
static void C_ccall f_20863(C_word c,C_word *av) C_noret;
C_noret_decl(f_20869)
static void C_fcall f_20869(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20886)
static void C_ccall f_20886(C_word c,C_word *av) C_noret;
C_noret_decl(f_20919)
static void C_ccall f_20919(C_word c,C_word *av) C_noret;
C_noret_decl(f_20925)
static void C_ccall f_20925(C_word c,C_word *av) C_noret;
C_noret_decl(f_20932)
static void C_ccall f_20932(C_word c,C_word *av) C_noret;
C_noret_decl(f_20943)
static void C_ccall f_20943(C_word c,C_word *av) C_noret;
C_noret_decl(f_20957)
static void C_fcall f_20957(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20975)
static void C_ccall f_20975(C_word c,C_word *av) C_noret;
C_noret_decl(f_21000)
static void C_ccall f_21000(C_word c,C_word *av) C_noret;
C_noret_decl(f_21027)
static void C_ccall f_21027(C_word c,C_word *av) C_noret;
C_noret_decl(f_21058)
static void C_ccall f_21058(C_word c,C_word *av) C_noret;
C_noret_decl(f_21065)
static void C_ccall f_21065(C_word c,C_word *av) C_noret;
C_noret_decl(f_21077)
static void C_ccall f_21077(C_word c,C_word *av) C_noret;
C_noret_decl(f_21107)
static void C_ccall f_21107(C_word c,C_word *av) C_noret;
C_noret_decl(f_21121)
static void C_fcall f_21121(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21124)
static void C_ccall f_21124(C_word c,C_word *av) C_noret;
C_noret_decl(f_21130)
static void C_ccall f_21130(C_word c,C_word *av) C_noret;
C_noret_decl(f_21144)
static void C_ccall f_21144(C_word c,C_word *av) C_noret;
C_noret_decl(f_21168)
static void C_fcall f_21168(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21171)
static void C_ccall f_21171(C_word c,C_word *av) C_noret;
C_noret_decl(f_21178)
static void C_ccall f_21178(C_word c,C_word *av) C_noret;
C_noret_decl(f_21195)
static void C_ccall f_21195(C_word c,C_word *av) C_noret;
C_noret_decl(f_21211)
static void C_ccall f_21211(C_word c,C_word *av) C_noret;
C_noret_decl(f_21214)
static void C_ccall f_21214(C_word c,C_word *av) C_noret;
C_noret_decl(f_21217)
static void C_ccall f_21217(C_word c,C_word *av) C_noret;
C_noret_decl(f_21223)
static void C_ccall f_21223(C_word c,C_word *av) C_noret;
C_noret_decl(f_21233)
static void C_ccall f_21233(C_word c,C_word *av) C_noret;
C_noret_decl(f_21237)
static void C_ccall f_21237(C_word c,C_word *av) C_noret;
C_noret_decl(f_21248)
static void C_ccall f_21248(C_word c,C_word *av) C_noret;
C_noret_decl(f_21252)
static void C_ccall f_21252(C_word c,C_word *av) C_noret;
C_noret_decl(f_21256)
static void C_ccall f_21256(C_word c,C_word *av) C_noret;
C_noret_decl(f_21264)
static void C_ccall f_21264(C_word c,C_word *av) C_noret;
C_noret_decl(f_21272)
static void C_ccall f_21272(C_word c,C_word *av) C_noret;
C_noret_decl(f_21287)
static void C_ccall f_21287(C_word c,C_word *av) C_noret;
C_noret_decl(f_21293)
static void C_ccall f_21293(C_word c,C_word *av) C_noret;
C_noret_decl(f_21307)
static void C_ccall f_21307(C_word c,C_word *av) C_noret;
C_noret_decl(f_21321)
static void C_ccall f_21321(C_word c,C_word *av) C_noret;
C_noret_decl(f_21327)
static void C_ccall f_21327(C_word c,C_word *av) C_noret;
C_noret_decl(f_21330)
static void C_ccall f_21330(C_word c,C_word *av) C_noret;
C_noret_decl(f_21357)
static void C_ccall f_21357(C_word c,C_word *av) C_noret;
C_noret_decl(f_21361)
static void C_ccall f_21361(C_word c,C_word *av) C_noret;
C_noret_decl(f_21381)
static void C_ccall f_21381(C_word c,C_word *av) C_noret;
C_noret_decl(f_21387)
static void C_ccall f_21387(C_word c,C_word *av) C_noret;
C_noret_decl(f_21390)
static void C_ccall f_21390(C_word c,C_word *av) C_noret;
C_noret_decl(f_21393)
static void C_ccall f_21393(C_word c,C_word *av) C_noret;
C_noret_decl(f_21409)
static void C_ccall f_21409(C_word c,C_word *av) C_noret;
C_noret_decl(f_21417)
static void C_ccall f_21417(C_word c,C_word *av) C_noret;
C_noret_decl(f_21429)
static void C_ccall f_21429(C_word c,C_word *av) C_noret;
C_noret_decl(f_21459)
static void C_ccall f_21459(C_word c,C_word *av) C_noret;
C_noret_decl(f_21465)
static void C_ccall f_21465(C_word c,C_word *av) C_noret;
C_noret_decl(f_21468)
static void C_ccall f_21468(C_word c,C_word *av) C_noret;
C_noret_decl(f_21471)
static void C_ccall f_21471(C_word c,C_word *av) C_noret;
C_noret_decl(f_21487)
static void C_ccall f_21487(C_word c,C_word *av) C_noret;
C_noret_decl(f_21495)
static void C_ccall f_21495(C_word c,C_word *av) C_noret;
C_noret_decl(f_21503)
static void C_ccall f_21503(C_word c,C_word *av) C_noret;
C_noret_decl(f_21507)
static void C_ccall f_21507(C_word c,C_word *av) C_noret;
C_noret_decl(f_21526)
static void C_fcall f_21526(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21544)
static void C_ccall f_21544(C_word c,C_word *av) C_noret;
C_noret_decl(f_21672)
static void C_ccall f_21672(C_word c,C_word *av) C_noret;
C_noret_decl(f_21678)
static void C_ccall f_21678(C_word c,C_word *av) C_noret;
C_noret_decl(f_21681)
static void C_ccall f_21681(C_word c,C_word *av) C_noret;
C_noret_decl(f_21689)
static void C_fcall f_21689(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21728)
static void C_fcall f_21728(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_21763)
static void C_fcall f_21763(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21770)
static void C_ccall f_21770(C_word c,C_word *av) C_noret;
C_noret_decl(f_21796)
static void C_ccall f_21796(C_word c,C_word *av) C_noret;
C_noret_decl(f_21892)
static void C_fcall f_21892(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21896)
static void C_ccall f_21896(C_word c,C_word *av) C_noret;
C_noret_decl(f_21909)
static void C_ccall f_21909(C_word c,C_word *av) C_noret;
C_noret_decl(f_21921)
static void C_fcall f_21921(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21925)
static void C_ccall f_21925(C_word c,C_word *av) C_noret;
C_noret_decl(f_21932)
static void C_ccall f_21932(C_word c,C_word *av) C_noret;
C_noret_decl(f_21938)
static void C_fcall f_21938(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21942)
static void C_ccall f_21942(C_word c,C_word *av) C_noret;
C_noret_decl(f_21945)
static void C_ccall f_21945(C_word c,C_word *av) C_noret;
C_noret_decl(f_21947)
static void C_fcall f_21947(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_21954)
static void C_fcall f_21954(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21961)
static C_word C_fcall f_21961(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_21996)
static void C_ccall f_21996(C_word c,C_word *av) C_noret;
C_noret_decl(f_22009)
static void C_fcall f_22009(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22110)
static void C_ccall f_22110(C_word c,C_word *av) C_noret;
C_noret_decl(f_22116)
static void C_fcall f_22116(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22122)
static void C_fcall f_22122(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22175)
static void C_fcall f_22175(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22246)
static void C_fcall f_22246(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22299)
static void C_fcall f_22299(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22308)
static void C_fcall f_22308(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22328)
static void C_ccall f_22328(C_word c,C_word *av) C_noret;
C_noret_decl(f_22357)
static C_word C_fcall f_22357(C_word t0,C_word t1);
C_noret_decl(f_22381)
static void C_fcall f_22381(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22388)
static void C_ccall f_22388(C_word c,C_word *av) C_noret;
C_noret_decl(f_22391)
static void C_ccall f_22391(C_word c,C_word *av) C_noret;
C_noret_decl(f_22394)
static void C_ccall f_22394(C_word c,C_word *av) C_noret;
C_noret_decl(f_22397)
static void C_ccall f_22397(C_word c,C_word *av) C_noret;
C_noret_decl(f_22413)
static void C_fcall f_22413(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_22430)
static void C_ccall f_22430(C_word c,C_word *av) C_noret;
C_noret_decl(f_22465)
static void C_ccall f_22465(C_word c,C_word *av) C_noret;
C_noret_decl(f_22469)
static void C_fcall f_22469(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_22497)
static void C_ccall f_22497(C_word c,C_word *av) C_noret;
C_noret_decl(f_22500)
static void C_fcall f_22500(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22506)
static void C_ccall f_22506(C_word c,C_word *av) C_noret;
C_noret_decl(f_22592)
static void C_ccall f_22592(C_word c,C_word *av) C_noret;
C_noret_decl(f_22595)
static void C_ccall f_22595(C_word c,C_word *av) C_noret;
C_noret_decl(f_22600)
static void C_fcall f_22600(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22610)
static void C_ccall f_22610(C_word c,C_word *av) C_noret;
C_noret_decl(f_22613)
static void C_ccall f_22613(C_word c,C_word *av) C_noret;
C_noret_decl(f_22633)
static void C_fcall f_22633(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22641)
static void C_fcall f_22641(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22674)
static void C_ccall f_22674(C_word c,C_word *av) C_noret;
C_noret_decl(f_22676)
static void C_fcall f_22676(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22701)
static void C_ccall f_22701(C_word c,C_word *av) C_noret;
C_noret_decl(f_22714)
static void C_fcall f_22714(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_22753)
static void C_ccall f_22753(C_word c,C_word *av) C_noret;
C_noret_decl(f_22768)
static void C_ccall f_22768(C_word c,C_word *av) C_noret;
C_noret_decl(f_22789)
static void C_fcall f_22789(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_22807)
static void C_ccall f_22807(C_word c,C_word *av) C_noret;
C_noret_decl(f_22816)
static void C_ccall f_22816(C_word c,C_word *av) C_noret;
C_noret_decl(f_22830)
static void C_fcall f_22830(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22834)
static void C_ccall f_22834(C_word c,C_word *av) C_noret;
C_noret_decl(f_22837)
static void C_ccall f_22837(C_word c,C_word *av) C_noret;
C_noret_decl(f_22843)
static void C_ccall f_22843(C_word c,C_word *av) C_noret;
C_noret_decl(f_22846)
static void C_fcall f_22846(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22849)
static void C_ccall f_22849(C_word c,C_word *av) C_noret;
C_noret_decl(f_22866)
static void C_ccall f_22866(C_word c,C_word *av) C_noret;
C_noret_decl(f_22938)
static void C_ccall f_22938(C_word c,C_word *av) C_noret;
C_noret_decl(f_22942)
static void C_ccall f_22942(C_word c,C_word *av) C_noret;
C_noret_decl(f_22946)
static void C_ccall f_22946(C_word c,C_word *av) C_noret;
C_noret_decl(f_22948)
static void C_fcall f_22948(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_22971)
static void C_fcall f_22971(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_23000)
static void C_fcall f_23000(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23004)
static void C_fcall f_23004(C_word t0,C_word t1) C_noret;
C_noret_decl(f_23028)
static void C_fcall f_23028(C_word t0,C_word t1) C_noret;
C_noret_decl(f_23056)
static void C_ccall f_23056(C_word c,C_word *av) C_noret;
C_noret_decl(f_23066)
static void C_fcall f_23066(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23076)
static void C_ccall f_23076(C_word c,C_word *av) C_noret;
C_noret_decl(f_23081)
static void C_fcall f_23081(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_23096)
static void C_fcall f_23096(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_23116)
static void C_fcall f_23116(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_23139)
static void C_fcall f_23139(C_word t0,C_word t1) C_noret;
C_noret_decl(f_23171)
static void C_ccall f_23171(C_word c,C_word *av) C_noret;
C_noret_decl(f_23178)
static void C_ccall f_23178(C_word c,C_word *av) C_noret;
C_noret_decl(f_23180)
static void C_ccall f_23180(C_word c,C_word *av) C_noret;
C_noret_decl(f_23204)
static void C_ccall f_23204(C_word c,C_word *av) C_noret;
C_noret_decl(f_23248)
static void C_fcall f_23248(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23261)
static void C_fcall f_23261(C_word t0,C_word t1) C_noret;
C_noret_decl(f_23275)
static void C_fcall f_23275(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_23302)
static void C_fcall f_23302(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_23383)
static void C_ccall f_23383(C_word c,C_word *av) C_noret;
C_noret_decl(f_23399)
static void C_ccall f_23399(C_word c,C_word *av) C_noret;
C_noret_decl(f_23409)
static void C_ccall f_23409(C_word c,C_word *av) C_noret;
C_noret_decl(f_23418)
static void C_ccall f_23418(C_word c,C_word *av) C_noret;
C_noret_decl(f_23458)
static void C_fcall f_23458(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_23461)
static void C_fcall f_23461(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23484)
static void C_ccall f_23484(C_word c,C_word *av) C_noret;
C_noret_decl(f_23500)
static void C_fcall f_23500(C_word t0,C_word t1) C_noret;
C_noret_decl(f_23507)
static void C_ccall f_23507(C_word c,C_word *av) C_noret;
C_noret_decl(f_23527)
static void C_ccall f_23527(C_word c,C_word *av) C_noret;
C_noret_decl(f_23547)
static void C_ccall f_23547(C_word c,C_word *av) C_noret;
C_noret_decl(f_23550)
static void C_ccall f_23550(C_word c,C_word *av) C_noret;
C_noret_decl(f_23551)
static void C_ccall f_23551(C_word c,C_word *av) C_noret;
C_noret_decl(f_23557)
static void C_ccall f_23557(C_word c,C_word *av) C_noret;
C_noret_decl(f_23573)
static void C_ccall f_23573(C_word c,C_word *av) C_noret;
C_noret_decl(f_23701)
static void C_ccall f_23701(C_word c,C_word *av) C_noret;
C_noret_decl(f_23720)
static void C_ccall f_23720(C_word c,C_word *av) C_noret;
C_noret_decl(f_23743)
static void C_ccall f_23743(C_word c,C_word *av) C_noret;
C_noret_decl(f_23744)
static void C_ccall f_23744(C_word c,C_word *av) C_noret;
C_noret_decl(f_23750)
static void C_ccall f_23750(C_word c,C_word *av) C_noret;
C_noret_decl(f_23769)
static void C_ccall f_23769(C_word c,C_word *av) C_noret;
C_noret_decl(f_23770)
static void C_ccall f_23770(C_word c,C_word *av) C_noret;
C_noret_decl(f_23776)
static void C_ccall f_23776(C_word c,C_word *av) C_noret;
C_noret_decl(f_23798)
static void C_ccall f_23798(C_word c,C_word *av) C_noret;
C_noret_decl(f_23804)
static void C_ccall f_23804(C_word c,C_word *av) C_noret;
C_noret_decl(f_23805)
static void C_ccall f_23805(C_word c,C_word *av) C_noret;
C_noret_decl(f_23811)
static void C_ccall f_23811(C_word c,C_word *av) C_noret;
C_noret_decl(f_23843)
static void C_ccall f_23843(C_word c,C_word *av) C_noret;
C_noret_decl(f_23849)
static void C_ccall f_23849(C_word c,C_word *av) C_noret;
C_noret_decl(f_23851)
static void C_ccall f_23851(C_word c,C_word *av) C_noret;
C_noret_decl(f_23857)
static void C_ccall f_23857(C_word c,C_word *av) C_noret;
C_noret_decl(f_23867)
static void C_ccall f_23867(C_word c,C_word *av) C_noret;
C_noret_decl(f_23873)
static void C_ccall f_23873(C_word c,C_word *av) C_noret;
C_noret_decl(f_23897)
static void C_ccall f_23897(C_word c,C_word *av) C_noret;
C_noret_decl(f_23903)
static void C_ccall f_23903(C_word c,C_word *av) C_noret;
C_noret_decl(f_23910)
static void C_ccall f_23910(C_word c,C_word *av) C_noret;
C_noret_decl(f_23916)
static void C_ccall f_23916(C_word c,C_word *av) C_noret;
C_noret_decl(f_23999)
static void C_fcall f_23999(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24002)
static void C_fcall f_24002(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24003)
static void C_ccall f_24003(C_word c,C_word *av) C_noret;
C_noret_decl(f_24016)
static void C_ccall f_24016(C_word c,C_word *av) C_noret;
C_noret_decl(f_24022)
static void C_ccall f_24022(C_word c,C_word *av) C_noret;
C_noret_decl(f_24035)
static void C_ccall f_24035(C_word c,C_word *av) C_noret;
C_noret_decl(f_24040)
static void C_ccall f_24040(C_word c,C_word *av) C_noret;
C_noret_decl(f_24071)
static void C_ccall f_24071(C_word c,C_word *av) C_noret;
C_noret_decl(f_24075)
static void C_ccall f_24075(C_word c,C_word *av) C_noret;
C_noret_decl(f_24080)
static void C_ccall f_24080(C_word c,C_word *av) C_noret;
C_noret_decl(f_24151)
static void C_fcall f_24151(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24154)
static void C_fcall f_24154(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24155)
static void C_ccall f_24155(C_word c,C_word *av) C_noret;
C_noret_decl(f_24168)
static void C_ccall f_24168(C_word c,C_word *av) C_noret;
C_noret_decl(f_24174)
static void C_ccall f_24174(C_word c,C_word *av) C_noret;
C_noret_decl(f_24184)
static void C_ccall f_24184(C_word c,C_word *av) C_noret;
C_noret_decl(f_24196)
static void C_ccall f_24196(C_word c,C_word *av) C_noret;
C_noret_decl(f_24209)
static void C_ccall f_24209(C_word c,C_word *av) C_noret;
C_noret_decl(f_24230)
static void C_ccall f_24230(C_word c,C_word *av) C_noret;
C_noret_decl(f_24240)
static void C_ccall f_24240(C_word c,C_word *av) C_noret;
C_noret_decl(f_24244)
static void C_ccall f_24244(C_word c,C_word *av) C_noret;
C_noret_decl(f_24250)
static void C_ccall f_24250(C_word c,C_word *av) C_noret;
C_noret_decl(f_24322)
static void C_ccall f_24322(C_word c,C_word *av) C_noret;
C_noret_decl(f_24372)
static void C_ccall f_24372(C_word c,C_word *av) C_noret;
C_noret_decl(f_24385)
static void C_ccall f_24385(C_word c,C_word *av) C_noret;
C_noret_decl(f_24386)
static void C_ccall f_24386(C_word c,C_word *av) C_noret;
C_noret_decl(f_24393)
static void C_ccall f_24393(C_word c,C_word *av) C_noret;
C_noret_decl(f_24401)
static void C_ccall f_24401(C_word c,C_word *av) C_noret;
C_noret_decl(f_24408)
static void C_ccall f_24408(C_word c,C_word *av) C_noret;
C_noret_decl(f_24420)
static void C_ccall f_24420(C_word c,C_word *av) C_noret;
C_noret_decl(f_24421)
static void C_ccall f_24421(C_word c,C_word *av) C_noret;
C_noret_decl(f_24428)
static void C_ccall f_24428(C_word c,C_word *av) C_noret;
C_noret_decl(f_24436)
static void C_ccall f_24436(C_word c,C_word *av) C_noret;
C_noret_decl(f_24443)
static void C_ccall f_24443(C_word c,C_word *av) C_noret;
C_noret_decl(f_24458)
static void C_ccall f_24458(C_word c,C_word *av) C_noret;
C_noret_decl(f_24459)
static void C_ccall f_24459(C_word c,C_word *av) C_noret;
C_noret_decl(f_24463)
static void C_ccall f_24463(C_word c,C_word *av) C_noret;
C_noret_decl(f_24469)
static void C_ccall f_24469(C_word c,C_word *av) C_noret;
C_noret_decl(f_24476)
static void C_ccall f_24476(C_word c,C_word *av) C_noret;
C_noret_decl(f_24485)
static void C_ccall f_24485(C_word c,C_word *av) C_noret;
C_noret_decl(f_24495)
static void C_ccall f_24495(C_word c,C_word *av) C_noret;
C_noret_decl(f_24499)
static void C_ccall f_24499(C_word c,C_word *av) C_noret;
C_noret_decl(f_24504)
static void C_ccall f_24504(C_word c,C_word *av) C_noret;
C_noret_decl(f_24521)
static void C_ccall f_24521(C_word c,C_word *av) C_noret;
C_noret_decl(f_24530)
static void C_ccall f_24530(C_word c,C_word *av) C_noret;
C_noret_decl(f_24541)
static void C_ccall f_24541(C_word c,C_word *av) C_noret;
C_noret_decl(f_24542)
static void C_ccall f_24542(C_word c,C_word *av) C_noret;
C_noret_decl(f_24546)
static void C_ccall f_24546(C_word c,C_word *av) C_noret;
C_noret_decl(f_24557)
static void C_ccall f_24557(C_word c,C_word *av) C_noret;
C_noret_decl(f_24564)
static void C_ccall f_24564(C_word c,C_word *av) C_noret;
C_noret_decl(f_24576)
static void C_ccall f_24576(C_word c,C_word *av) C_noret;
C_noret_decl(f_24579)
static void C_ccall f_24579(C_word c,C_word *av) C_noret;
C_noret_decl(f_24582)
static void C_ccall f_24582(C_word c,C_word *av) C_noret;
C_noret_decl(f_24591)
static void C_fcall f_24591(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24594)
static void C_ccall f_24594(C_word c,C_word *av) C_noret;
C_noret_decl(f_24595)
static void C_ccall f_24595(C_word c,C_word *av) C_noret;
C_noret_decl(f_24652)
static void C_ccall f_24652(C_word c,C_word *av) C_noret;
C_noret_decl(f_24653)
static void C_ccall f_24653(C_word c,C_word *av) C_noret;
C_noret_decl(f_24659)
static void C_ccall f_24659(C_word c,C_word *av) C_noret;
C_noret_decl(f_24695)
static void C_ccall f_24695(C_word c,C_word *av) C_noret;
C_noret_decl(f_24700)
static void C_ccall f_24700(C_word c,C_word *av) C_noret;
C_noret_decl(f_24732)
static void C_ccall f_24732(C_word c,C_word *av) C_noret;
C_noret_decl(f_24735)
static void C_fcall f_24735(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24736)
static void C_ccall f_24736(C_word c,C_word *av) C_noret;
C_noret_decl(f_24740)
static void C_ccall f_24740(C_word c,C_word *av) C_noret;
C_noret_decl(f_24758)
static void C_fcall f_24758(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7) C_noret;
C_noret_decl(f_24771)
static void C_ccall f_24771(C_word c,C_word *av) C_noret;
C_noret_decl(f_24785)
static void C_ccall f_24785(C_word c,C_word *av) C_noret;
C_noret_decl(f_24789)
static void C_ccall f_24789(C_word c,C_word *av) C_noret;
C_noret_decl(f_24803)
static void C_ccall f_24803(C_word c,C_word *av) C_noret;
C_noret_decl(f_24809)
static void C_ccall f_24809(C_word c,C_word *av) C_noret;
C_noret_decl(f_24822)
static void C_ccall f_24822(C_word c,C_word *av) C_noret;
C_noret_decl(f_24829)
static void C_ccall f_24829(C_word c,C_word *av) C_noret;
C_noret_decl(f_24836)
static void C_ccall f_24836(C_word c,C_word *av) C_noret;
C_noret_decl(f_24858)
static void C_ccall f_24858(C_word c,C_word *av) C_noret;
C_noret_decl(f_24862)
static void C_ccall f_24862(C_word c,C_word *av) C_noret;
C_noret_decl(f_24949)
static void C_ccall f_24949(C_word c,C_word *av) C_noret;
C_noret_decl(f_24950)
static void C_ccall f_24950(C_word c,C_word *av) C_noret;
C_noret_decl(f_24998)
static void C_ccall f_24998(C_word c,C_word *av) C_noret;
C_noret_decl(f_25058)
static void C_ccall f_25058(C_word c,C_word *av) C_noret;
C_noret_decl(f_25093)
static void C_ccall f_25093(C_word c,C_word *av) C_noret;
C_noret_decl(f_25293)
static void C_ccall f_25293(C_word c,C_word *av) C_noret;
C_noret_decl(f_25313)
static void C_ccall f_25313(C_word c,C_word *av) C_noret;
C_noret_decl(f_25322)
static void C_ccall f_25322(C_word c,C_word *av) C_noret;
C_noret_decl(f_25328)
static void C_ccall f_25328(C_word c,C_word *av) C_noret;
C_noret_decl(f_25334)
static void C_ccall f_25334(C_word c,C_word *av) C_noret;
C_noret_decl(f_25351)
static void C_ccall f_25351(C_word c,C_word *av) C_noret;
C_noret_decl(f_25388)
static void C_ccall f_25388(C_word c,C_word *av) C_noret;
C_noret_decl(f_25397)
static void C_ccall f_25397(C_word c,C_word *av) C_noret;
C_noret_decl(f_25403)
static void C_ccall f_25403(C_word c,C_word *av) C_noret;
C_noret_decl(f_25409)
static void C_ccall f_25409(C_word c,C_word *av) C_noret;
C_noret_decl(f_25443)
static void C_ccall f_25443(C_word c,C_word *av) C_noret;
C_noret_decl(f_25473)
static void C_ccall f_25473(C_word c,C_word *av) C_noret;
C_noret_decl(f_25480)
static void C_ccall f_25480(C_word c,C_word *av) C_noret;
C_noret_decl(f_25517)
static void C_ccall f_25517(C_word c,C_word *av) C_noret;
C_noret_decl(f_25524)
static void C_ccall f_25524(C_word c,C_word *av) C_noret;
C_noret_decl(f_25531)
static void C_fcall f_25531(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25540)
static void C_fcall f_25540(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25559)
static void C_ccall f_25559(C_word c,C_word *av) C_noret;
C_noret_decl(f_25576)
static void C_ccall f_25576(C_word c,C_word *av) C_noret;
C_noret_decl(f_25583)
static void C_ccall f_25583(C_word c,C_word *av) C_noret;
C_noret_decl(f_25604)
static void C_ccall f_25604(C_word c,C_word *av) C_noret;
C_noret_decl(f_25624)
static void C_ccall f_25624(C_word c,C_word *av) C_noret;
C_noret_decl(f_25631)
static void C_ccall f_25631(C_word c,C_word *av) C_noret;
C_noret_decl(f_25638)
static void C_fcall f_25638(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25657)
static void C_ccall f_25657(C_word c,C_word *av) C_noret;
C_noret_decl(f_25664)
static void C_ccall f_25664(C_word c,C_word *av) C_noret;
C_noret_decl(f_25671)
static void C_fcall f_25671(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25694)
static void C_ccall f_25694(C_word c,C_word *av) C_noret;
C_noret_decl(f_25715)
static void C_ccall f_25715(C_word c,C_word *av) C_noret;
C_noret_decl(f_25722)
static void C_ccall f_25722(C_word c,C_word *av) C_noret;
C_noret_decl(f_25729)
static void C_ccall f_25729(C_word c,C_word *av) C_noret;
C_noret_decl(f_25736)
static void C_fcall f_25736(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25745)
static void C_fcall f_25745(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25765)
static void C_ccall f_25765(C_word c,C_word *av) C_noret;
C_noret_decl(f_25781)
static void C_ccall f_25781(C_word c,C_word *av) C_noret;
C_noret_decl(f_25798)
static void C_ccall f_25798(C_word c,C_word *av) C_noret;
C_noret_decl(f_25818)
static void C_ccall f_25818(C_word c,C_word *av) C_noret;
C_noret_decl(f_25822)
static void C_ccall f_25822(C_word c,C_word *av) C_noret;
C_noret_decl(f_25825)
static void C_ccall f_25825(C_word c,C_word *av) C_noret;
C_noret_decl(f_25831)
static void C_fcall f_25831(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25876)
static void C_ccall f_25876(C_word c,C_word *av) C_noret;
C_noret_decl(f_25940)
static void C_ccall f_25940(C_word c,C_word *av) C_noret;
C_noret_decl(f_25957)
static void C_ccall f_25957(C_word c,C_word *av) C_noret;
C_noret_decl(f_25959)
static void C_fcall f_25959(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_25969)
static void C_ccall f_25969(C_word c,C_word *av) C_noret;
C_noret_decl(f_25975)
static void C_ccall f_25975(C_word c,C_word *av) C_noret;
C_noret_decl(f_25981)
static void C_ccall f_25981(C_word c,C_word *av) C_noret;
C_noret_decl(f_25997)
static void C_ccall f_25997(C_word c,C_word *av) C_noret;
C_noret_decl(f_26003)
static void C_ccall f_26003(C_word c,C_word *av) C_noret;
C_noret_decl(f_26025)
static void C_ccall f_26025(C_word c,C_word *av) C_noret;
C_noret_decl(f_26039)
static void C_ccall f_26039(C_word c,C_word *av) C_noret;
C_noret_decl(f_26056)
static void C_ccall f_26056(C_word c,C_word *av) C_noret;
C_noret_decl(f_26058)
static void C_fcall f_26058(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26068)
static void C_ccall f_26068(C_word c,C_word *av) C_noret;
C_noret_decl(f_26074)
static void C_ccall f_26074(C_word c,C_word *av) C_noret;
C_noret_decl(f_26080)
static void C_ccall f_26080(C_word c,C_word *av) C_noret;
C_noret_decl(f_26096)
static void C_ccall f_26096(C_word c,C_word *av) C_noret;
C_noret_decl(f_26154)
static void C_ccall f_26154(C_word c,C_word *av) C_noret;
C_noret_decl(f_26180)
static void C_fcall f_26180(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26182)
static void C_ccall f_26182(C_word c,C_word *av) C_noret;
C_noret_decl(f_26195)
static void C_ccall f_26195(C_word c,C_word *av) C_noret;
C_noret_decl(f_26214)
static void C_ccall f_26214(C_word c,C_word *av) C_noret;
C_noret_decl(f_26223)
static void C_ccall f_26223(C_word c,C_word *av) C_noret;
C_noret_decl(f_26229)
static void C_ccall f_26229(C_word c,C_word *av) C_noret;
C_noret_decl(f_26235)
static void C_ccall f_26235(C_word c,C_word *av) C_noret;
C_noret_decl(f_26241)
static void C_ccall f_26241(C_word c,C_word *av) C_noret;
C_noret_decl(f_26393)
static void C_fcall f_26393(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26405)
static void C_fcall f_26405(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_26455)
static void C_fcall f_26455(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_26473)
static void C_ccall f_26473(C_word c,C_word *av) C_noret;
C_noret_decl(f_26484)
static void C_fcall f_26484(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26490)
static void C_ccall f_26490(C_word c,C_word *av) C_noret;
C_noret_decl(f_26502)
static void C_ccall f_26502(C_word c,C_word *av) C_noret;
C_noret_decl(f_26504)
static void C_fcall f_26504(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26514)
static void C_fcall f_26514(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_26517)
static void C_fcall f_26517(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26543)
static void C_ccall f_26543(C_word c,C_word *av) C_noret;
C_noret_decl(f_26564)
static void C_ccall f_26564(C_word c,C_word *av) C_noret;
C_noret_decl(f_26568)
static void C_ccall f_26568(C_word c,C_word *av) C_noret;
C_noret_decl(f_26581)
static void C_ccall f_26581(C_word c,C_word *av) C_noret;
C_noret_decl(f_26583)
static void C_fcall f_26583(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26608)
static void C_ccall f_26608(C_word c,C_word *av) C_noret;
C_noret_decl(f_26632)
static void C_ccall f_26632(C_word c,C_word *av) C_noret;
C_noret_decl(f_26645)
static void C_ccall f_26645(C_word c,C_word *av) C_noret;
C_noret_decl(f_26647)
static void C_fcall f_26647(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26672)
static void C_ccall f_26672(C_word c,C_word *av) C_noret;
C_noret_decl(f_26694)
static void C_ccall f_26694(C_word c,C_word *av) C_noret;
C_noret_decl(f_26702)
static void C_ccall f_26702(C_word c,C_word *av) C_noret;
C_noret_decl(f_26715)
static void C_ccall f_26715(C_word c,C_word *av) C_noret;
C_noret_decl(f_26717)
static void C_fcall f_26717(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26742)
static void C_ccall f_26742(C_word c,C_word *av) C_noret;
C_noret_decl(f_26762)
static void C_ccall f_26762(C_word c,C_word *av) C_noret;
C_noret_decl(f_26772)
static void C_ccall f_26772(C_word c,C_word *av) C_noret;
C_noret_decl(f_26787)
static void C_ccall f_26787(C_word c,C_word *av) C_noret;
C_noret_decl(f_26800)
static void C_ccall f_26800(C_word c,C_word *av) C_noret;
C_noret_decl(f_26802)
static void C_fcall f_26802(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26827)
static void C_ccall f_26827(C_word c,C_word *av) C_noret;
C_noret_decl(f_26949)
static void C_ccall f_26949(C_word c,C_word *av) C_noret;
C_noret_decl(f_26951)
static void C_ccall f_26951(C_word c,C_word *av) C_noret;
C_noret_decl(f_26969)
static void C_ccall f_26969(C_word c,C_word *av) C_noret;
C_noret_decl(f_26971)
static void C_fcall f_26971(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27004)
static void C_fcall f_27004(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_27056)
static C_word C_fcall f_27056(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_27092)
static void C_ccall f_27092(C_word c,C_word *av) C_noret;
C_noret_decl(f_27100)
static void C_ccall f_27100(C_word c,C_word *av) C_noret;
C_noret_decl(f_27104)
static void C_ccall f_27104(C_word c,C_word *av) C_noret;
C_noret_decl(f_27106)
static void C_fcall f_27106(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_27120)
static void C_ccall f_27120(C_word c,C_word *av) C_noret;
C_noret_decl(f_27124)
static void C_ccall f_27124(C_word c,C_word *av) C_noret;
C_noret_decl(f_27128)
static void C_ccall f_27128(C_word c,C_word *av) C_noret;
C_noret_decl(f_27141)
static void C_ccall f_27141(C_word c,C_word *av) C_noret;
C_noret_decl(f_27145)
static void C_ccall f_27145(C_word c,C_word *av) C_noret;
C_noret_decl(f_27149)
static void C_ccall f_27149(C_word c,C_word *av) C_noret;
C_noret_decl(f_27287)
static void C_fcall f_27287(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27295)
static void C_ccall f_27295(C_word c,C_word *av) C_noret;
C_noret_decl(f_27299)
static void C_ccall f_27299(C_word c,C_word *av) C_noret;
C_noret_decl(f_27301)
static void C_fcall f_27301(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_27315)
static void C_ccall f_27315(C_word c,C_word *av) C_noret;
C_noret_decl(f_27328)
static void C_ccall f_27328(C_word c,C_word *av) C_noret;
C_noret_decl(f_27332)
static void C_ccall f_27332(C_word c,C_word *av) C_noret;
C_noret_decl(f_27378)
static void C_fcall f_27378(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27381)
static void C_fcall f_27381(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27388)
static void C_fcall f_27388(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27483)
static void C_ccall f_27483(C_word c,C_word *av) C_noret;
C_noret_decl(f_27491)
static void C_ccall f_27491(C_word c,C_word *av) C_noret;
C_noret_decl(f_27495)
static void C_ccall f_27495(C_word c,C_word *av) C_noret;
C_noret_decl(f_27497)
static void C_fcall f_27497(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_27514)
static void C_ccall f_27514(C_word c,C_word *av) C_noret;
C_noret_decl(f_27609)
static void C_fcall f_27609(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27617)
static void C_ccall f_27617(C_word c,C_word *av) C_noret;
C_noret_decl(f_27619)
static void C_fcall f_27619(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27627)
static void C_ccall f_27627(C_word c,C_word *av) C_noret;
C_noret_decl(f_27629)
static void C_fcall f_27629(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_27643)
static void C_ccall f_27643(C_word c,C_word *av) C_noret;
C_noret_decl(f_27649)
static void C_fcall f_27649(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27658)
static void C_ccall f_27658(C_word c,C_word *av) C_noret;
C_noret_decl(f_27662)
static void C_ccall f_27662(C_word c,C_word *av) C_noret;
C_noret_decl(f_27666)
static void C_ccall f_27666(C_word c,C_word *av) C_noret;
C_noret_decl(f_27670)
static void C_ccall f_27670(C_word c,C_word *av) C_noret;
C_noret_decl(f_27694)
static void C_ccall f_27694(C_word c,C_word *av) C_noret;
C_noret_decl(f_27704)
static void C_ccall f_27704(C_word c,C_word *av) C_noret;
C_noret_decl(f_27713)
static void C_ccall f_27713(C_word c,C_word *av) C_noret;
C_noret_decl(f_27717)
static void C_ccall f_27717(C_word c,C_word *av) C_noret;
C_noret_decl(f_27721)
static void C_ccall f_27721(C_word c,C_word *av) C_noret;
C_noret_decl(f_27725)
static void C_ccall f_27725(C_word c,C_word *av) C_noret;
C_noret_decl(f_27735)
static void C_ccall f_27735(C_word c,C_word *av) C_noret;
C_noret_decl(f_27750)
static void C_ccall f_27750(C_word c,C_word *av) C_noret;
C_noret_decl(f_27754)
static void C_ccall f_27754(C_word c,C_word *av) C_noret;
C_noret_decl(f_27757)
static void C_ccall f_27757(C_word c,C_word *av) C_noret;
C_noret_decl(f_27760)
static void C_ccall f_27760(C_word c,C_word *av) C_noret;
C_noret_decl(f_27769)
static void C_fcall f_27769(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27772)
static void C_fcall f_27772(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27781)
static void C_ccall f_27781(C_word c,C_word *av) C_noret;
C_noret_decl(f_27784)
static void C_ccall f_27784(C_word c,C_word *av) C_noret;
C_noret_decl(f_27792)
static void C_fcall f_27792(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_27805)
static void C_ccall f_27805(C_word c,C_word *av) C_noret;
C_noret_decl(f_27840)
static void C_ccall f_27840(C_word c,C_word *av) C_noret;
C_noret_decl(f_27843)
static void C_ccall f_27843(C_word c,C_word *av) C_noret;
C_noret_decl(f_27951)
static void C_ccall f_27951(C_word c,C_word *av) C_noret;
C_noret_decl(f_27968)
static void C_ccall f_27968(C_word c,C_word *av) C_noret;
C_noret_decl(f_27972)
static void C_ccall f_27972(C_word c,C_word *av) C_noret;
C_noret_decl(f_27973)
static void C_ccall f_27973(C_word c,C_word *av) C_noret;
C_noret_decl(f_27981)
static void C_ccall f_27981(C_word c,C_word *av) C_noret;
C_noret_decl(f_27996)
static void C_ccall f_27996(C_word c,C_word *av) C_noret;
C_noret_decl(f_28000)
static void C_ccall f_28000(C_word c,C_word *av) C_noret;
C_noret_decl(f_28003)
static void C_ccall f_28003(C_word c,C_word *av) C_noret;
C_noret_decl(f_28012)
static void C_ccall f_28012(C_word c,C_word *av) C_noret;
C_noret_decl(f_28018)
static void C_ccall f_28018(C_word c,C_word *av) C_noret;
C_noret_decl(f_28026)
static void C_fcall f_28026(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_28039)
static void C_ccall f_28039(C_word c,C_word *av) C_noret;
C_noret_decl(f_28089)
static void C_ccall f_28089(C_word c,C_word *av) C_noret;
C_noret_decl(f_28099)
static void C_ccall f_28099(C_word c,C_word *av) C_noret;
C_noret_decl(f_28113)
static void C_ccall f_28113(C_word c,C_word *av) C_noret;
C_noret_decl(f_28116)
static void C_ccall f_28116(C_word c,C_word *av) C_noret;
C_noret_decl(f_28119)
static void C_ccall f_28119(C_word c,C_word *av) C_noret;
C_noret_decl(f_28171)
static void C_ccall f_28171(C_word c,C_word *av) C_noret;
C_noret_decl(f_28178)
static void C_ccall f_28178(C_word c,C_word *av) C_noret;
C_noret_decl(f_28182)
static void C_ccall f_28182(C_word c,C_word *av) C_noret;
C_noret_decl(f_28183)
static void C_ccall f_28183(C_word c,C_word *av) C_noret;
C_noret_decl(f_28191)
static void C_ccall f_28191(C_word c,C_word *av) C_noret;
C_noret_decl(f_28206)
static void C_ccall f_28206(C_word c,C_word *av) C_noret;
C_noret_decl(f_28210)
static void C_ccall f_28210(C_word c,C_word *av) C_noret;
C_noret_decl(f_28213)
static void C_ccall f_28213(C_word c,C_word *av) C_noret;
C_noret_decl(f_28227)
static void C_ccall f_28227(C_word c,C_word *av) C_noret;
C_noret_decl(f_28231)
static void C_ccall f_28231(C_word c,C_word *av) C_noret;
C_noret_decl(f_28235)
static void C_ccall f_28235(C_word c,C_word *av) C_noret;
C_noret_decl(f_28243)
static void C_ccall f_28243(C_word c,C_word *av) C_noret;
C_noret_decl(f_28285)
static void C_ccall f_28285(C_word c,C_word *av) C_noret;
C_noret_decl(f_28289)
static void C_ccall f_28289(C_word c,C_word *av) C_noret;
C_noret_decl(f_28294)
static void C_ccall f_28294(C_word c,C_word *av) C_noret;
C_noret_decl(f_28328)
static void C_ccall f_28328(C_word c,C_word *av) C_noret;
C_noret_decl(f_28335)
static void C_ccall f_28335(C_word c,C_word *av) C_noret;
C_noret_decl(f_28343)
static void C_ccall f_28343(C_word c,C_word *av) C_noret;
C_noret_decl(f_28345)
static void C_ccall f_28345(C_word c,C_word *av) C_noret;
C_noret_decl(f_28366)
static void C_ccall f_28366(C_word c,C_word *av) C_noret;
C_noret_decl(f_28378)
static void C_fcall f_28378(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_28384)
static void C_fcall f_28384(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_28411)
static void C_ccall f_28411(C_word c,C_word *av) C_noret;
C_noret_decl(f_28436)
static void C_ccall f_28436(C_word c,C_word *av) C_noret;
C_noret_decl(f_28462)
static void C_ccall f_28462(C_word c,C_word *av) C_noret;
C_noret_decl(f_28526)
static void C_ccall f_28526(C_word c,C_word *av) C_noret;
C_noret_decl(f_28558)
static void C_fcall f_28558(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_28588)
static void C_ccall f_28588(C_word c,C_word *av) C_noret;
C_noret_decl(f_28609)
static void C_ccall f_28609(C_word c,C_word *av) C_noret;
C_noret_decl(f_28613)
static void C_ccall f_28613(C_word c,C_word *av) C_noret;
C_noret_decl(f_28618)
static void C_ccall f_28618(C_word c,C_word *av) C_noret;
C_noret_decl(f_28626)
static void C_ccall f_28626(C_word c,C_word *av) C_noret;
C_noret_decl(f_28628)
static void C_ccall f_28628(C_word c,C_word *av) C_noret;
C_noret_decl(f_28644)
static void C_ccall f_28644(C_word c,C_word *av) C_noret;
C_noret_decl(f_28648)
static void C_ccall f_28648(C_word c,C_word *av) C_noret;
C_noret_decl(f_28654)
static void C_fcall f_28654(C_word t0,C_word t1) C_noret;
C_noret_decl(f_28659)
static void C_ccall f_28659(C_word c,C_word *av) C_noret;
C_noret_decl(f_28673)
static void C_ccall f_28673(C_word c,C_word *av) C_noret;
C_noret_decl(f_28717)
static void C_ccall f_28717(C_word c,C_word *av) C_noret;
C_noret_decl(f_28725)
static void C_fcall f_28725(C_word t0,C_word t1) C_noret;
C_noret_decl(f_28727)
static void C_fcall f_28727(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_28768)
static void C_ccall f_28768(C_word c,C_word *av) C_noret;
C_noret_decl(f_28808)
static void C_ccall f_28808(C_word c,C_word *av) C_noret;
C_noret_decl(f_28842)
static void C_ccall f_28842(C_word c,C_word *av) C_noret;
C_noret_decl(f_28855)
static void C_fcall f_28855(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_28885)
static void C_ccall f_28885(C_word c,C_word *av) C_noret;
C_noret_decl(f_28893)
static void C_ccall f_28893(C_word c,C_word *av) C_noret;
C_noret_decl(f_28897)
static void C_ccall f_28897(C_word c,C_word *av) C_noret;
C_noret_decl(f_28899)
static void C_fcall f_28899(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_28918)
static void C_ccall f_28918(C_word c,C_word *av) C_noret;
C_noret_decl(f_28942)
static void C_ccall f_28942(C_word c,C_word *av) C_noret;
C_noret_decl(f_28959)
static void C_ccall f_28959(C_word c,C_word *av) C_noret;
C_noret_decl(f_28966)
static void C_ccall f_28966(C_word c,C_word *av) C_noret;
C_noret_decl(f_28989)
static void C_ccall f_28989(C_word c,C_word *av) C_noret;
C_noret_decl(f_29010)
static void C_ccall f_29010(C_word c,C_word *av) C_noret;
C_noret_decl(f_29012)
static void C_fcall f_29012(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29022)
static void C_fcall f_29022(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29049)
static void C_ccall f_29049(C_word c,C_word *av) C_noret;
C_noret_decl(f_29079)
static void C_ccall f_29079(C_word c,C_word *av) C_noret;
C_noret_decl(f_29084)
static void C_fcall f_29084(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_29096)
static void C_fcall f_29096(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_29116)
static void C_ccall f_29116(C_word c,C_word *av) C_noret;
C_noret_decl(f_29151)
static void C_ccall f_29151(C_word c,C_word *av) C_noret;
C_noret_decl(f_29159)
static void C_ccall f_29159(C_word c,C_word *av) C_noret;
C_noret_decl(f_29195)
static void C_ccall f_29195(C_word c,C_word *av) C_noret;
C_noret_decl(f_29209)
static void C_fcall f_29209(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29213)
static void C_ccall f_29213(C_word c,C_word *av) C_noret;
C_noret_decl(f_29216)
static void C_ccall f_29216(C_word c,C_word *av) C_noret;
C_noret_decl(f_29221)
static void C_fcall f_29221(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29231)
static void C_ccall f_29231(C_word c,C_word *av) C_noret;
C_noret_decl(f_29242)
static void C_ccall f_29242(C_word c,C_word *av) C_noret;
C_noret_decl(f_29245)
static void C_ccall f_29245(C_word c,C_word *av) C_noret;
C_noret_decl(f_29252)
static void C_ccall f_29252(C_word c,C_word *av) C_noret;
C_noret_decl(f_29264)
static void C_ccall f_29264(C_word c,C_word *av) C_noret;
C_noret_decl(f_29279)
static void C_ccall f_29279(C_word c,C_word *av) C_noret;
C_noret_decl(f_29289)
static void C_ccall f_29289(C_word c,C_word *av) C_noret;
C_noret_decl(f_29293)
static void C_ccall f_29293(C_word c,C_word *av) C_noret;
C_noret_decl(f_29296)
static void C_ccall f_29296(C_word c,C_word *av) C_noret;
C_noret_decl(f_29301)
static void C_fcall f_29301(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29324)
static void C_fcall f_29324(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29327)
static void C_ccall f_29327(C_word c,C_word *av) C_noret;
C_noret_decl(f_29334)
static void C_ccall f_29334(C_word c,C_word *av) C_noret;
C_noret_decl(f_29339)
static void C_fcall f_29339(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29349)
static void C_ccall f_29349(C_word c,C_word *av) C_noret;
C_noret_decl(f_29369)
static void C_fcall f_29369(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29379)
static void C_ccall f_29379(C_word c,C_word *av) C_noret;
C_noret_decl(f_29421)
static void C_ccall f_29421(C_word c,C_word *av) C_noret;
C_noret_decl(f_29428)
static void C_ccall f_29428(C_word c,C_word *av) C_noret;
C_noret_decl(f_29433)
static void C_fcall f_29433(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29443)
static void C_ccall f_29443(C_word c,C_word *av) C_noret;
C_noret_decl(f_29463)
static void C_ccall f_29463(C_word c,C_word *av) C_noret;
C_noret_decl(f_29466)
static void C_ccall f_29466(C_word c,C_word *av) C_noret;
C_noret_decl(f_29469)
static void C_ccall f_29469(C_word c,C_word *av) C_noret;
C_noret_decl(f_29478)
static void C_ccall f_29478(C_word c,C_word *av) C_noret;
C_noret_decl(f_29483)
static void C_fcall f_29483(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29493)
static void C_ccall f_29493(C_word c,C_word *av) C_noret;
C_noret_decl(f_29517)
static void C_ccall f_29517(C_word c,C_word *av) C_noret;
C_noret_decl(f_29520)
static void C_ccall f_29520(C_word c,C_word *av) C_noret;
C_noret_decl(f_29521)
static void C_fcall f_29521(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29525)
static void C_ccall f_29525(C_word c,C_word *av) C_noret;
C_noret_decl(f_29537)
static void C_ccall f_29537(C_word c,C_word *av) C_noret;
C_noret_decl(f_29542)
static void C_fcall f_29542(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29552)
static void C_ccall f_29552(C_word c,C_word *av) C_noret;
C_noret_decl(f_29576)
static void C_fcall f_29576(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29579)
static void C_ccall f_29579(C_word c,C_word *av) C_noret;
C_noret_decl(f_29590)
static void C_fcall f_29590(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29593)
static void C_ccall f_29593(C_word c,C_word *av) C_noret;
C_noret_decl(f_29600)
static void C_ccall f_29600(C_word c,C_word *av) C_noret;
C_noret_decl(f_29605)
static void C_fcall f_29605(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29615)
static void C_ccall f_29615(C_word c,C_word *av) C_noret;
C_noret_decl(f_29673)
static void C_fcall f_29673(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29676)
static void C_ccall f_29676(C_word c,C_word *av) C_noret;
C_noret_decl(f_29679)
static void C_ccall f_29679(C_word c,C_word *av) C_noret;
C_noret_decl(f_29686)
static void C_ccall f_29686(C_word c,C_word *av) C_noret;
C_noret_decl(f_29690)
static void C_ccall f_29690(C_word c,C_word *av) C_noret;
C_noret_decl(f_29703)
static void C_ccall f_29703(C_word c,C_word *av) C_noret;
C_noret_decl(f_29716)
static void C_ccall f_29716(C_word c,C_word *av) C_noret;
C_noret_decl(f_29719)
static void C_ccall f_29719(C_word c,C_word *av) C_noret;
C_noret_decl(f_29726)
static void C_ccall f_29726(C_word c,C_word *av) C_noret;
C_noret_decl(f_29737)
static void C_fcall f_29737(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29746)
static void C_fcall f_29746(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29749)
static void C_ccall f_29749(C_word c,C_word *av) C_noret;
C_noret_decl(f_29752)
static void C_ccall f_29752(C_word c,C_word *av) C_noret;
C_noret_decl(f_29759)
static void C_ccall f_29759(C_word c,C_word *av) C_noret;
C_noret_decl(f_29784)
static void C_ccall f_29784(C_word c,C_word *av) C_noret;
C_noret_decl(f_29822)
static void C_ccall f_29822(C_word c,C_word *av) C_noret;
C_noret_decl(f_29825)
static void C_ccall f_29825(C_word c,C_word *av) C_noret;
C_noret_decl(f_29828)
static void C_ccall f_29828(C_word c,C_word *av) C_noret;
C_noret_decl(f_29835)
static void C_ccall f_29835(C_word c,C_word *av) C_noret;
C_noret_decl(f_29840)
static void C_fcall f_29840(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29850)
static void C_ccall f_29850(C_word c,C_word *av) C_noret;
C_noret_decl(f_29886)
static void C_ccall f_29886(C_word c,C_word *av) C_noret;
C_noret_decl(f_30050)
static void C_ccall f_30050(C_word c,C_word *av) C_noret;
C_noret_decl(f_30063)
static void C_ccall f_30063(C_word c,C_word *av) C_noret;
C_noret_decl(f_30072)
static void C_ccall f_30072(C_word c,C_word *av) C_noret;
C_noret_decl(f_30083)
static void C_ccall f_30083(C_word c,C_word *av) C_noret;
C_noret_decl(f_30087)
static void C_ccall f_30087(C_word c,C_word *av) C_noret;
C_noret_decl(f_30089)
static void C_fcall f_30089(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_30120)
static void C_ccall f_30120(C_word c,C_word *av) C_noret;
C_noret_decl(f_30167)
static void C_ccall f_30167(C_word c,C_word *av) C_noret;
C_noret_decl(f_30187)
static void C_ccall f_30187(C_word c,C_word *av) C_noret;
C_noret_decl(f_30197)
static void C_fcall f_30197(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_30224)
static void C_ccall f_30224(C_word c,C_word *av) C_noret;
C_noret_decl(f_30246)
static void C_fcall f_30246(C_word t0,C_word t1) C_noret;
C_noret_decl(f_30348)
static void C_ccall f_30348(C_word c,C_word *av) C_noret;
C_noret_decl(f_30813)
static void C_ccall f_30813(C_word c,C_word *av) C_noret;
C_noret_decl(f_30975)
static void C_ccall f_30975(C_word c,C_word *av) C_noret;
C_noret_decl(f_30978)
static void C_ccall f_30978(C_word c,C_word *av) C_noret;
C_noret_decl(f_31012)
static void C_ccall f_31012(C_word c,C_word *av) C_noret;
C_noret_decl(f_31016)
static void C_ccall f_31016(C_word c,C_word *av) C_noret;
C_noret_decl(f_31019)
static void C_ccall f_31019(C_word c,C_word *av) C_noret;
C_noret_decl(f_31022)
static void C_ccall f_31022(C_word c,C_word *av) C_noret;
C_noret_decl(f_31025)
static void C_ccall f_31025(C_word c,C_word *av) C_noret;
C_noret_decl(f_31028)
static void C_ccall f_31028(C_word c,C_word *av) C_noret;
C_noret_decl(f_7541)
static void C_ccall f_7541(C_word c,C_word *av) C_noret;
C_noret_decl(f_7544)
static void C_ccall f_7544(C_word c,C_word *av) C_noret;
C_noret_decl(f_7546)
static void C_fcall f_7546(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7550)
static void C_ccall f_7550(C_word c,C_word *av) C_noret;
C_noret_decl(f_7553)
static void C_ccall f_7553(C_word c,C_word *av) C_noret;
C_noret_decl(f_7559)
static void C_ccall f_7559(C_word c,C_word *av) C_noret;
C_noret_decl(f_7601)
static void C_ccall f_7601(C_word c,C_word *av) C_noret;
C_noret_decl(f_7619)
static void C_ccall f_7619(C_word c,C_word *av) C_noret;
C_noret_decl(f_7628)
static void C_fcall f_7628(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7636)
static void C_ccall f_7636(C_word c,C_word *av) C_noret;
C_noret_decl(f_7649)
static void C_ccall f_7649(C_word c,C_word *av) C_noret;
C_noret_decl(f_7651)
static void C_fcall f_7651(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7658)
static void C_ccall f_7658(C_word c,C_word *av) C_noret;
C_noret_decl(f_7660)
static void C_fcall f_7660(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7674)
static void C_ccall f_7674(C_word c,C_word *av) C_noret;
C_noret_decl(f_7692)
static void C_ccall f_7692(C_word c,C_word *av) C_noret;
C_noret_decl(f_7698)
static void C_ccall f_7698(C_word c,C_word *av) C_noret;
C_noret_decl(f_7723)
static void C_ccall f_7723(C_word c,C_word *av) C_noret;
C_noret_decl(f_7769)
static void C_ccall f_7769(C_word c,C_word *av) C_noret;
C_noret_decl(f_7782)
static void C_ccall f_7782(C_word c,C_word *av) C_noret;
C_noret_decl(f_7784)
static void C_ccall f_7784(C_word c,C_word *av) C_noret;
C_noret_decl(f_7788)
static void C_ccall f_7788(C_word c,C_word *av) C_noret;
C_noret_decl(f_7809)
static void C_ccall f_7809(C_word c,C_word *av) C_noret;
C_noret_decl(f_7813)
static void C_ccall f_7813(C_word c,C_word *av) C_noret;
C_noret_decl(f_7838)
static void C_ccall f_7838(C_word c,C_word *av) C_noret;
C_noret_decl(f_7842)
static void C_ccall f_7842(C_word c,C_word *av) C_noret;
C_noret_decl(f_7867)
static void C_ccall f_7867(C_word c,C_word *av) C_noret;
C_noret_decl(f_7871)
static void C_ccall f_7871(C_word c,C_word *av) C_noret;
C_noret_decl(f_7960)
static void C_fcall f_7960(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8028)
static void C_fcall f_8028(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8070)
static void C_ccall f_8070(C_word c,C_word *av) C_noret;
C_noret_decl(f_8072)
static void C_fcall f_8072(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8142)
static void C_ccall f_8142(C_word c,C_word *av) C_noret;
C_noret_decl(f_8144)
static void C_ccall f_8144(C_word c,C_word *av) C_noret;
C_noret_decl(f_8148)
static void C_ccall f_8148(C_word c,C_word *av) C_noret;
C_noret_decl(f_8205)
static void C_ccall f_8205(C_word c,C_word *av) C_noret;
C_noret_decl(f_8207)
static void C_ccall f_8207(C_word c,C_word *av) C_noret;
C_noret_decl(f_8211)
static void C_ccall f_8211(C_word c,C_word *av) C_noret;
C_noret_decl(f_8288)
static void C_ccall f_8288(C_word c,C_word *av) C_noret;
C_noret_decl(f_8292)
static void C_ccall f_8292(C_word c,C_word *av) C_noret;
C_noret_decl(f_8378)
static void C_ccall f_8378(C_word c,C_word *av) C_noret;
C_noret_decl(f_8412)
static void C_ccall f_8412(C_word c,C_word *av) C_noret;
C_noret_decl(f_8418)
static void C_fcall f_8418(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8452)
static void C_ccall f_8452(C_word c,C_word *av) C_noret;
C_noret_decl(f_8466)
static void C_ccall f_8466(C_word c,C_word *av) C_noret;
C_noret_decl(f_8473)
static void C_ccall f_8473(C_word c,C_word *av) C_noret;
C_noret_decl(f_8479)
static void C_fcall f_8479(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8497)
static void C_ccall f_8497(C_word c,C_word *av) C_noret;
C_noret_decl(f_8501)
static void C_ccall f_8501(C_word c,C_word *av) C_noret;
C_noret_decl(f_8505)
static void C_ccall f_8505(C_word c,C_word *av) C_noret;
C_noret_decl(f_8512)
static void C_ccall f_8512(C_word c,C_word *av) C_noret;
C_noret_decl(f_8520)
static void C_ccall f_8520(C_word c,C_word *av) C_noret;
C_noret_decl(f_8524)
static void C_ccall f_8524(C_word c,C_word *av) C_noret;
C_noret_decl(f_8528)
static void C_ccall f_8528(C_word c,C_word *av) C_noret;
C_noret_decl(f_8532)
static void C_ccall f_8532(C_word c,C_word *av) C_noret;
C_noret_decl(f_8536)
static void C_ccall f_8536(C_word c,C_word *av) C_noret;
C_noret_decl(f_8540)
static void C_ccall f_8540(C_word c,C_word *av) C_noret;
C_noret_decl(f_8544)
static void C_ccall f_8544(C_word c,C_word *av) C_noret;
C_noret_decl(f_8553)
static void C_ccall f_8553(C_word c,C_word *av) C_noret;
C_noret_decl(f_8561)
static void C_ccall f_8561(C_word c,C_word *av) C_noret;
C_noret_decl(f_8570)
static void C_ccall f_8570(C_word c,C_word *av) C_noret;
C_noret_decl(f_8628)
static void C_fcall f_8628(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8632)
static void C_ccall f_8632(C_word c,C_word *av) C_noret;
C_noret_decl(f_8646)
static void C_fcall f_8646(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8650)
static void C_ccall f_8650(C_word c,C_word *av) C_noret;
C_noret_decl(f_8663)
static void C_ccall f_8663(C_word c,C_word *av) C_noret;
C_noret_decl(f_8674)
static void C_ccall f_8674(C_word c,C_word *av) C_noret;
C_noret_decl(f_8676)
static void C_fcall f_8676(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8683)
static void C_ccall f_8683(C_word c,C_word *av) C_noret;
C_noret_decl(f_8696)
static void C_ccall f_8696(C_word c,C_word *av) C_noret;
C_noret_decl(f_8703)
static void C_ccall f_8703(C_word c,C_word *av) C_noret;
C_noret_decl(f_8742)
static void C_ccall f_8742(C_word c,C_word *av) C_noret;
C_noret_decl(f_8769)
static void C_ccall f_8769(C_word c,C_word *av) C_noret;
C_noret_decl(f_8801)
static void C_ccall f_8801(C_word c,C_word *av) C_noret;
C_noret_decl(f_8808)
static void C_ccall f_8808(C_word c,C_word *av) C_noret;
C_noret_decl(f_8823)
static void C_ccall f_8823(C_word c,C_word *av) C_noret;
C_noret_decl(f_8836)
static void C_fcall f_8836(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8879)
static void C_fcall f_8879(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8936)
static void C_fcall f_8936(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8974)
static void C_fcall f_8974(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_8977)
static void C_fcall f_8977(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8985)
static void C_ccall f_8985(C_word c,C_word *av) C_noret;
C_noret_decl(f_8998)
static void C_ccall f_8998(C_word c,C_word *av) C_noret;
C_noret_decl(f_9017)
static void C_ccall f_9017(C_word c,C_word *av) C_noret;
C_noret_decl(f_9114)
static void C_fcall f_9114(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9122)
static void C_ccall f_9122(C_word c,C_word *av) C_noret;
C_noret_decl(f_9124)
static void C_ccall f_9124(C_word c,C_word *av) C_noret;
C_noret_decl(f_9138)
static void C_ccall f_9138(C_word c,C_word *av) C_noret;
C_noret_decl(f_9143)
static C_word C_fcall f_9143(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_9164)
static void C_fcall f_9164(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9180)
static void C_fcall f_9180(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9201)
static void C_fcall f_9201(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9207)
static void C_fcall f_9207(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9220)
static void C_ccall f_9220(C_word c,C_word *av) C_noret;
C_noret_decl(f_9262)
static void C_fcall f_9262(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9277)
static C_word C_fcall f_9277(C_word t0);
C_noret_decl(f_9300)
static void C_fcall f_9300(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9316)
static void C_fcall f_9316(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9329)
static void C_ccall f_9329(C_word c,C_word *av) C_noret;
C_noret_decl(f_9343)
static void C_fcall f_9343(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9361)
static void C_fcall f_9361(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9377)
static void C_ccall f_9377(C_word c,C_word *av) C_noret;
C_noret_decl(f_9388)
static void C_fcall f_9388(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9394)
static void C_fcall f_9394(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9412)
static void C_ccall f_9412(C_word c,C_word *av) C_noret;
C_noret_decl(f_9718)
static void C_ccall f_9718(C_word c,C_word *av) C_noret;
C_noret_decl(f_9727)
static void C_ccall f_9727(C_word c,C_word *av) C_noret;
C_noret_decl(f_9745)
static void C_fcall f_9745(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9752)
static void C_fcall f_9752(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9779)
static void C_fcall f_9779(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9785)
static void C_ccall f_9785(C_word c,C_word *av) C_noret;
C_noret_decl(f_9799)
static void C_ccall f_9799(C_word c,C_word *av) C_noret;
C_noret_decl(f_9819)
static void C_ccall f_9819(C_word c,C_word *av) C_noret;
C_noret_decl(f_9825)
static void C_ccall f_9825(C_word c,C_word *av) C_noret;
C_noret_decl(f_9842)
static void C_ccall f_9842(C_word c,C_word *av) C_noret;
C_noret_decl(f_9846)
static void C_ccall f_9846(C_word c,C_word *av) C_noret;
C_noret_decl(f_9893)
static void C_fcall f_9893(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9942)
static void C_ccall f_9942(C_word c,C_word *av) C_noret;
C_noret_decl(f_9970)
static void C_fcall f_9970(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9981)
static void C_ccall f_9981(C_word c,C_word *av) C_noret;
C_noret_decl(C_irregex_toplevel)
C_externexport void C_ccall C_irregex_toplevel(C_word c,C_word *av) C_noret;

C_noret_decl(trf_10027)
static void C_ccall trf_10027(C_word c,C_word *av) C_noret;
static void C_ccall trf_10027(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_10027(t0,t1,t2,t3,t4);}

C_noret_decl(trf_10030)
static void C_ccall trf_10030(C_word c,C_word *av) C_noret;
static void C_ccall trf_10030(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10030(t0,t1);}

C_noret_decl(trf_10246)
static void C_ccall trf_10246(C_word c,C_word *av) C_noret;
static void C_ccall trf_10246(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10246(t0,t1,t2);}

C_noret_decl(trf_10256)
static void C_ccall trf_10256(C_word c,C_word *av) C_noret;
static void C_ccall trf_10256(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10256(t0,t1);}

C_noret_decl(trf_10338)
static void C_ccall trf_10338(C_word c,C_word *av) C_noret;
static void C_ccall trf_10338(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10338(t0,t1);}

C_noret_decl(trf_10344)
static void C_ccall trf_10344(C_word c,C_word *av) C_noret;
static void C_ccall trf_10344(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10344(t0,t1,t2,t3);}

C_noret_decl(trf_10362)
static void C_ccall trf_10362(C_word c,C_word *av) C_noret;
static void C_ccall trf_10362(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10362(t0,t1);}

C_noret_decl(trf_10373)
static void C_ccall trf_10373(C_word c,C_word *av) C_noret;
static void C_ccall trf_10373(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10373(t0,t1);}

C_noret_decl(trf_10488)
static void C_ccall trf_10488(C_word c,C_word *av) C_noret;
static void C_ccall trf_10488(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_10488(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_10513)
static void C_ccall trf_10513(C_word c,C_word *av) C_noret;
static void C_ccall trf_10513(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10513(t0,t1,t2);}

C_noret_decl(trf_10535)
static void C_ccall trf_10535(C_word c,C_word *av) C_noret;
static void C_ccall trf_10535(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10535(t0,t1,t2);}

C_noret_decl(trf_10569)
static void C_ccall trf_10569(C_word c,C_word *av) C_noret;
static void C_ccall trf_10569(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10569(t0,t1);}

C_noret_decl(trf_10589)
static void C_ccall trf_10589(C_word c,C_word *av) C_noret;
static void C_ccall trf_10589(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10589(t0,t1);}

C_noret_decl(trf_10605)
static void C_ccall trf_10605(C_word c,C_word *av) C_noret;
static void C_ccall trf_10605(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10605(t0,t1);}

C_noret_decl(trf_10661)
static void C_ccall trf_10661(C_word c,C_word *av) C_noret;
static void C_ccall trf_10661(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10661(t0,t1);}

C_noret_decl(trf_10668)
static void C_ccall trf_10668(C_word c,C_word *av) C_noret;
static void C_ccall trf_10668(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10668(t0,t1);}

C_noret_decl(trf_10671)
static void C_ccall trf_10671(C_word c,C_word *av) C_noret;
static void C_ccall trf_10671(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10671(t0,t1);}

C_noret_decl(trf_10679)
static void C_ccall trf_10679(C_word c,C_word *av) C_noret;
static void C_ccall trf_10679(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_10679(t0,t1,t2,t3,t4);}

C_noret_decl(trf_10894)
static void C_ccall trf_10894(C_word c,C_word *av) C_noret;
static void C_ccall trf_10894(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10894(t0,t1);}

C_noret_decl(trf_10995)
static void C_ccall trf_10995(C_word c,C_word *av) C_noret;
static void C_ccall trf_10995(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10995(t0,t1);}

C_noret_decl(trf_11258)
static void C_ccall trf_11258(C_word c,C_word *av) C_noret;
static void C_ccall trf_11258(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11258(t0,t1);}

C_noret_decl(trf_11715)
static void C_ccall trf_11715(C_word c,C_word *av) C_noret;
static void C_ccall trf_11715(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_11715(t0,t1,t2,t3,t4);}

C_noret_decl(trf_12051)
static void C_ccall trf_12051(C_word c,C_word *av) C_noret;
static void C_ccall trf_12051(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12051(t0,t1);}

C_noret_decl(trf_12094)
static void C_ccall trf_12094(C_word c,C_word *av) C_noret;
static void C_ccall trf_12094(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12094(t0,t1);}

C_noret_decl(trf_12701)
static void C_ccall trf_12701(C_word c,C_word *av) C_noret;
static void C_ccall trf_12701(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12701(t0,t1);}

C_noret_decl(trf_12781)
static void C_ccall trf_12781(C_word c,C_word *av) C_noret;
static void C_ccall trf_12781(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12781(t0,t1,t2);}

C_noret_decl(trf_13301)
static void C_ccall trf_13301(C_word c,C_word *av) C_noret;
static void C_ccall trf_13301(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13301(t0,t1,t2,t3);}

C_noret_decl(trf_13410)
static void C_ccall trf_13410(C_word c,C_word *av) C_noret;
static void C_ccall trf_13410(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_13410(t0,t1,t2,t3,t4);}

C_noret_decl(trf_13483)
static void C_ccall trf_13483(C_word c,C_word *av) C_noret;
static void C_ccall trf_13483(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13483(t0,t1);}

C_noret_decl(trf_13560)
static void C_ccall trf_13560(C_word c,C_word *av) C_noret;
static void C_ccall trf_13560(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13560(t0,t1);}

C_noret_decl(trf_13572)
static void C_ccall trf_13572(C_word c,C_word *av) C_noret;
static void C_ccall trf_13572(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13572(t0,t1);}

C_noret_decl(trf_13694)
static void C_ccall trf_13694(C_word c,C_word *av) C_noret;
static void C_ccall trf_13694(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13694(t0,t1);}

C_noret_decl(trf_13807)
static void C_ccall trf_13807(C_word c,C_word *av) C_noret;
static void C_ccall trf_13807(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13807(t0,t1);}

C_noret_decl(trf_13924)
static void C_ccall trf_13924(C_word c,C_word *av) C_noret;
static void C_ccall trf_13924(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13924(t0,t1);}

C_noret_decl(trf_14035)
static void C_ccall trf_14035(C_word c,C_word *av) C_noret;
static void C_ccall trf_14035(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_14035(t0,t1,t2,t3);}

C_noret_decl(trf_14230)
static void C_ccall trf_14230(C_word c,C_word *av) C_noret;
static void C_ccall trf_14230(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14230(t0,t1,t2);}

C_noret_decl(trf_14268)
static void C_ccall trf_14268(C_word c,C_word *av) C_noret;
static void C_ccall trf_14268(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14268(t0,t1);}

C_noret_decl(trf_14344)
static void C_ccall trf_14344(C_word c,C_word *av) C_noret;
static void C_ccall trf_14344(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14344(t0,t1);}

C_noret_decl(trf_14514)
static void C_ccall trf_14514(C_word c,C_word *av) C_noret;
static void C_ccall trf_14514(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_14514(t0,t1,t2,t3);}

C_noret_decl(trf_14620)
static void C_ccall trf_14620(C_word c,C_word *av) C_noret;
static void C_ccall trf_14620(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_14620(t0,t1,t2,t3,t4);}

C_noret_decl(trf_14686)
static void C_ccall trf_14686(C_word c,C_word *av) C_noret;
static void C_ccall trf_14686(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14686(t0,t1,t2);}

C_noret_decl(trf_14722)
static void C_ccall trf_14722(C_word c,C_word *av) C_noret;
static void C_ccall trf_14722(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14722(t0,t1,t2);}

C_noret_decl(trf_14758)
static void C_ccall trf_14758(C_word c,C_word *av) C_noret;
static void C_ccall trf_14758(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14758(t0,t1);}

C_noret_decl(trf_14843)
static void C_ccall trf_14843(C_word c,C_word *av) C_noret;
static void C_ccall trf_14843(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14843(t0,t1,t2);}

C_noret_decl(trf_14897)
static void C_ccall trf_14897(C_word c,C_word *av) C_noret;
static void C_ccall trf_14897(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14897(t0,t1);}

C_noret_decl(trf_14982)
static void C_ccall trf_14982(C_word c,C_word *av) C_noret;
static void C_ccall trf_14982(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14982(t0,t1,t2);}

C_noret_decl(trf_15056)
static void C_ccall trf_15056(C_word c,C_word *av) C_noret;
static void C_ccall trf_15056(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15056(t0,t1,t2);}

C_noret_decl(trf_15068)
static void C_ccall trf_15068(C_word c,C_word *av) C_noret;
static void C_ccall trf_15068(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15068(t0,t1);}

C_noret_decl(trf_15088)
static void C_ccall trf_15088(C_word c,C_word *av) C_noret;
static void C_ccall trf_15088(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15088(t0,t1,t2);}

C_noret_decl(trf_15191)
static void C_ccall trf_15191(C_word c,C_word *av) C_noret;
static void C_ccall trf_15191(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15191(t0,t1,t2);}

C_noret_decl(trf_15259)
static void C_ccall trf_15259(C_word c,C_word *av) C_noret;
static void C_ccall trf_15259(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15259(t0,t1,t2);}

C_noret_decl(trf_15329)
static void C_ccall trf_15329(C_word c,C_word *av) C_noret;
static void C_ccall trf_15329(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15329(t0,t1,t2);}

C_noret_decl(trf_15420)
static void C_ccall trf_15420(C_word c,C_word *av) C_noret;
static void C_ccall trf_15420(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15420(t0,t1,t2);}

C_noret_decl(trf_15475)
static void C_ccall trf_15475(C_word c,C_word *av) C_noret;
static void C_ccall trf_15475(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15475(t0,t1);}

C_noret_decl(trf_15485)
static void C_ccall trf_15485(C_word c,C_word *av) C_noret;
static void C_ccall trf_15485(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_15485(t0,t1,t2,t3,t4);}

C_noret_decl(trf_15530)
static void C_ccall trf_15530(C_word c,C_word *av) C_noret;
static void C_ccall trf_15530(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15530(t0,t1);}

C_noret_decl(trf_15597)
static void C_ccall trf_15597(C_word c,C_word *av) C_noret;
static void C_ccall trf_15597(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_15597(t0,t1,t2,t3,t4);}

C_noret_decl(trf_15600)
static void C_ccall trf_15600(C_word c,C_word *av) C_noret;
static void C_ccall trf_15600(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15600(t0,t1,t2);}

C_noret_decl(trf_15657)
static void C_ccall trf_15657(C_word c,C_word *av) C_noret;
static void C_ccall trf_15657(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15657(t0,t1,t2);}

C_noret_decl(trf_15670)
static void C_ccall trf_15670(C_word c,C_word *av) C_noret;
static void C_ccall trf_15670(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15670(t0,t1,t2);}

C_noret_decl(trf_15718)
static void C_ccall trf_15718(C_word c,C_word *av) C_noret;
static void C_ccall trf_15718(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15718(t0,t1,t2);}

C_noret_decl(trf_15731)
static void C_ccall trf_15731(C_word c,C_word *av) C_noret;
static void C_ccall trf_15731(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15731(t0,t1,t2);}

C_noret_decl(trf_15772)
static void C_ccall trf_15772(C_word c,C_word *av) C_noret;
static void C_ccall trf_15772(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15772(t0,t1);}

C_noret_decl(trf_15841)
static void C_ccall trf_15841(C_word c,C_word *av) C_noret;
static void C_ccall trf_15841(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15841(t0,t1,t2);}

C_noret_decl(trf_15897)
static void C_ccall trf_15897(C_word c,C_word *av) C_noret;
static void C_ccall trf_15897(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15897(t0,t1,t2);}

C_noret_decl(trf_15986)
static void C_ccall trf_15986(C_word c,C_word *av) C_noret;
static void C_ccall trf_15986(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15986(t0,t1);}

C_noret_decl(trf_16001)
static void C_ccall trf_16001(C_word c,C_word *av) C_noret;
static void C_ccall trf_16001(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16001(t0,t1,t2);}

C_noret_decl(trf_16251)
static void C_ccall trf_16251(C_word c,C_word *av) C_noret;
static void C_ccall trf_16251(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16251(t0,t1,t2);}

C_noret_decl(trf_16281)
static void C_ccall trf_16281(C_word c,C_word *av) C_noret;
static void C_ccall trf_16281(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16281(t0,t1,t2);}

C_noret_decl(trf_16336)
static void C_ccall trf_16336(C_word c,C_word *av) C_noret;
static void C_ccall trf_16336(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16336(t0,t1);}

C_noret_decl(trf_16379)
static void C_ccall trf_16379(C_word c,C_word *av) C_noret;
static void C_ccall trf_16379(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16379(t0,t1);}

C_noret_decl(trf_16509)
static void C_ccall trf_16509(C_word c,C_word *av) C_noret;
static void C_ccall trf_16509(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16509(t0,t1);}

C_noret_decl(trf_16649)
static void C_ccall trf_16649(C_word c,C_word *av) C_noret;
static void C_ccall trf_16649(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16649(t0,t1);}

C_noret_decl(trf_16762)
static void C_ccall trf_16762(C_word c,C_word *av) C_noret;
static void C_ccall trf_16762(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16762(t0,t1);}

C_noret_decl(trf_16879)
static void C_ccall trf_16879(C_word c,C_word *av) C_noret;
static void C_ccall trf_16879(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16879(t0,t1);}

C_noret_decl(trf_16994)
static void C_ccall trf_16994(C_word c,C_word *av) C_noret;
static void C_ccall trf_16994(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16994(t0,t1);}

C_noret_decl(trf_17027)
static void C_ccall trf_17027(C_word c,C_word *av) C_noret;
static void C_ccall trf_17027(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17027(t0,t1);}

C_noret_decl(trf_17106)
static void C_ccall trf_17106(C_word c,C_word *av) C_noret;
static void C_ccall trf_17106(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_17106(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_17109)
static void C_ccall trf_17109(C_word c,C_word *av) C_noret;
static void C_ccall trf_17109(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17109(t0,t1,t2);}

C_noret_decl(trf_17149)
static void C_ccall trf_17149(C_word c,C_word *av) C_noret;
static void C_ccall trf_17149(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17149(t0,t1);}

C_noret_decl(trf_17178)
static void C_ccall trf_17178(C_word c,C_word *av) C_noret;
static void C_ccall trf_17178(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17178(t0,t1);}

C_noret_decl(trf_17185)
static void C_ccall trf_17185(C_word c,C_word *av) C_noret;
static void C_ccall trf_17185(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_17185(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_17263)
static void C_ccall trf_17263(C_word c,C_word *av) C_noret;
static void C_ccall trf_17263(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_17263(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_17366)
static void C_ccall trf_17366(C_word c,C_word *av) C_noret;
static void C_ccall trf_17366(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17366(t0,t1);}

C_noret_decl(trf_17502)
static void C_ccall trf_17502(C_word c,C_word *av) C_noret;
static void C_ccall trf_17502(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17502(t0,t1);}

C_noret_decl(trf_17560)
static void C_ccall trf_17560(C_word c,C_word *av) C_noret;
static void C_ccall trf_17560(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17560(t0,t1);}

C_noret_decl(trf_17687)
static void C_ccall trf_17687(C_word c,C_word *av) C_noret;
static void C_ccall trf_17687(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17687(t0,t1);}

C_noret_decl(trf_17690)
static void C_ccall trf_17690(C_word c,C_word *av) C_noret;
static void C_ccall trf_17690(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17690(t0,t1);}

C_noret_decl(trf_17882)
static void C_ccall trf_17882(C_word c,C_word *av) C_noret;
static void C_ccall trf_17882(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17882(t0,t1);}

C_noret_decl(trf_17901)
static void C_ccall trf_17901(C_word c,C_word *av) C_noret;
static void C_ccall trf_17901(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17901(t0,t1);}

C_noret_decl(trf_17922)
static void C_ccall trf_17922(C_word c,C_word *av) C_noret;
static void C_ccall trf_17922(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17922(t0,t1);}

C_noret_decl(trf_17932)
static void C_ccall trf_17932(C_word c,C_word *av) C_noret;
static void C_ccall trf_17932(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17932(t0,t1,t2);}

C_noret_decl(trf_18322)
static void C_ccall trf_18322(C_word c,C_word *av) C_noret;
static void C_ccall trf_18322(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18322(t0,t1,t2);}

C_noret_decl(trf_18382)
static void C_ccall trf_18382(C_word c,C_word *av) C_noret;
static void C_ccall trf_18382(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_18382(t0,t1,t2,t3);}

C_noret_decl(trf_18430)
static void C_ccall trf_18430(C_word c,C_word *av) C_noret;
static void C_ccall trf_18430(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_18430(t0,t1,t2,t3);}

C_noret_decl(trf_18532)
static void C_ccall trf_18532(C_word c,C_word *av) C_noret;
static void C_ccall trf_18532(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18532(t0,t1);}

C_noret_decl(trf_18716)
static void C_ccall trf_18716(C_word c,C_word *av) C_noret;
static void C_ccall trf_18716(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_18716(t0,t1,t2,t3);}

C_noret_decl(trf_18765)
static void C_ccall trf_18765(C_word c,C_word *av) C_noret;
static void C_ccall trf_18765(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18765(t0,t1);}

C_noret_decl(trf_18837)
static void C_ccall trf_18837(C_word c,C_word *av) C_noret;
static void C_ccall trf_18837(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18837(t0,t1,t2);}

C_noret_decl(trf_18945)
static void C_ccall trf_18945(C_word c,C_word *av) C_noret;
static void C_ccall trf_18945(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18945(t0,t1);}

C_noret_decl(trf_19065)
static void C_ccall trf_19065(C_word c,C_word *av) C_noret;
static void C_ccall trf_19065(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_19065(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_19126)
static void C_ccall trf_19126(C_word c,C_word *av) C_noret;
static void C_ccall trf_19126(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_19126(t0,t1,t2,t3);}

C_noret_decl(trf_19135)
static void C_ccall trf_19135(C_word c,C_word *av) C_noret;
static void C_ccall trf_19135(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19135(t0,t1,t2);}

C_noret_decl(trf_19240)
static void C_ccall trf_19240(C_word c,C_word *av) C_noret;
static void C_ccall trf_19240(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_19240(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_19327)
static void C_ccall trf_19327(C_word c,C_word *av) C_noret;
static void C_ccall trf_19327(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19327(t0,t1);}

C_noret_decl(trf_19530)
static void C_ccall trf_19530(C_word c,C_word *av) C_noret;
static void C_ccall trf_19530(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19530(t0,t1,t2);}

C_noret_decl(trf_19540)
static void C_ccall trf_19540(C_word c,C_word *av) C_noret;
static void C_ccall trf_19540(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19540(t0,t1);}

C_noret_decl(trf_19690)
static void C_ccall trf_19690(C_word c,C_word *av) C_noret;
static void C_ccall trf_19690(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_19690(t0,t1,t2,t3,t4);}

C_noret_decl(trf_19705)
static void C_ccall trf_19705(C_word c,C_word *av) C_noret;
static void C_ccall trf_19705(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_19705(t0,t1,t2,t3);}

C_noret_decl(trf_19828)
static void C_ccall trf_19828(C_word c,C_word *av) C_noret;
static void C_ccall trf_19828(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_19828(t0,t1,t2,t3);}

C_noret_decl(trf_19888)
static void C_ccall trf_19888(C_word c,C_word *av) C_noret;
static void C_ccall trf_19888(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19888(t0,t1,t2);}

C_noret_decl(trf_19925)
static void C_ccall trf_19925(C_word c,C_word *av) C_noret;
static void C_ccall trf_19925(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19925(t0,t1,t2);}

C_noret_decl(trf_19947)
static void C_ccall trf_19947(C_word c,C_word *av) C_noret;
static void C_ccall trf_19947(C_word c,C_word *av){
C_word t0=av[8];
C_word t1=av[7];
C_word t2=av[6];
C_word t3=av[5];
C_word t4=av[4];
C_word t5=av[3];
C_word t6=av[2];
C_word t7=av[1];
C_word t8=av[0];
f_19947(t0,t1,t2,t3,t4,t5,t6,t7,t8);}

C_noret_decl(trf_19984)
static void C_ccall trf_19984(C_word c,C_word *av) C_noret;
static void C_ccall trf_19984(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19984(t0,t1);}

C_noret_decl(trf_20000)
static void C_ccall trf_20000(C_word c,C_word *av) C_noret;
static void C_ccall trf_20000(C_word c,C_word *av){
C_word t0=av[7];
C_word t1=av[6];
C_word t2=av[5];
C_word t3=av[4];
C_word t4=av[3];
C_word t5=av[2];
C_word t6=av[1];
C_word t7=av[0];
f_20000(t0,t1,t2,t3,t4,t5,t6,t7);}

C_noret_decl(trf_20012)
static void C_ccall trf_20012(C_word c,C_word *av) C_noret;
static void C_ccall trf_20012(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_20012(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_20022)
static void C_ccall trf_20022(C_word c,C_word *av) C_noret;
static void C_ccall trf_20022(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20022(t0,t1);}

C_noret_decl(trf_20197)
static void C_ccall trf_20197(C_word c,C_word *av) C_noret;
static void C_ccall trf_20197(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20197(t0,t1,t2);}

C_noret_decl(trf_20238)
static void C_ccall trf_20238(C_word c,C_word *av) C_noret;
static void C_ccall trf_20238(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20238(t0,t1,t2);}

C_noret_decl(trf_20261)
static void C_ccall trf_20261(C_word c,C_word *av) C_noret;
static void C_ccall trf_20261(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20261(t0,t1,t2);}

C_noret_decl(trf_20295)
static void C_ccall trf_20295(C_word c,C_word *av) C_noret;
static void C_ccall trf_20295(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20295(t0,t1,t2);}

C_noret_decl(trf_20331)
static void C_ccall trf_20331(C_word c,C_word *av) C_noret;
static void C_ccall trf_20331(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20331(t0,t1);}

C_noret_decl(trf_20373)
static void C_ccall trf_20373(C_word c,C_word *av) C_noret;
static void C_ccall trf_20373(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20373(t0,t1);}

C_noret_decl(trf_20469)
static void C_ccall trf_20469(C_word c,C_word *av) C_noret;
static void C_ccall trf_20469(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20469(t0,t1,t2);}

C_noret_decl(trf_20769)
static void C_ccall trf_20769(C_word c,C_word *av) C_noret;
static void C_ccall trf_20769(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20769(t0,t1,t2);}

C_noret_decl(trf_20778)
static void C_ccall trf_20778(C_word c,C_word *av) C_noret;
static void C_ccall trf_20778(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_20778(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_20781)
static void C_ccall trf_20781(C_word c,C_word *av) C_noret;
static void C_ccall trf_20781(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20781(t0,t1,t2);}

C_noret_decl(trf_20791)
static void C_ccall trf_20791(C_word c,C_word *av) C_noret;
static void C_ccall trf_20791(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20791(t0,t1,t2,t3);}

C_noret_decl(trf_20795)
static void C_ccall trf_20795(C_word c,C_word *av) C_noret;
static void C_ccall trf_20795(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20795(t0,t1);}

C_noret_decl(trf_20816)
static void C_ccall trf_20816(C_word c,C_word *av) C_noret;
static void C_ccall trf_20816(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20816(t0,t1,t2);}

C_noret_decl(trf_20852)
static void C_ccall trf_20852(C_word c,C_word *av) C_noret;
static void C_ccall trf_20852(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20852(t0,t1,t2,t3);}

C_noret_decl(trf_20869)
static void C_ccall trf_20869(C_word c,C_word *av) C_noret;
static void C_ccall trf_20869(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20869(t0,t1,t2,t3);}

C_noret_decl(trf_20957)
static void C_ccall trf_20957(C_word c,C_word *av) C_noret;
static void C_ccall trf_20957(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20957(t0,t1,t2,t3);}

C_noret_decl(trf_21121)
static void C_ccall trf_21121(C_word c,C_word *av) C_noret;
static void C_ccall trf_21121(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21121(t0,t1);}

C_noret_decl(trf_21168)
static void C_ccall trf_21168(C_word c,C_word *av) C_noret;
static void C_ccall trf_21168(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21168(t0,t1);}

C_noret_decl(trf_21526)
static void C_ccall trf_21526(C_word c,C_word *av) C_noret;
static void C_ccall trf_21526(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21526(t0,t1,t2);}

C_noret_decl(trf_21689)
static void C_ccall trf_21689(C_word c,C_word *av) C_noret;
static void C_ccall trf_21689(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21689(t0,t1,t2);}

C_noret_decl(trf_21728)
static void C_ccall trf_21728(C_word c,C_word *av) C_noret;
static void C_ccall trf_21728(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_21728(t0,t1,t2,t3,t4);}

C_noret_decl(trf_21763)
static void C_ccall trf_21763(C_word c,C_word *av) C_noret;
static void C_ccall trf_21763(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21763(t0,t1);}

C_noret_decl(trf_21892)
static void C_ccall trf_21892(C_word c,C_word *av) C_noret;
static void C_ccall trf_21892(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21892(t0,t1);}

C_noret_decl(trf_21921)
static void C_ccall trf_21921(C_word c,C_word *av) C_noret;
static void C_ccall trf_21921(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21921(t0,t1);}

C_noret_decl(trf_21938)
static void C_ccall trf_21938(C_word c,C_word *av) C_noret;
static void C_ccall trf_21938(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21938(t0,t1,t2,t3);}

C_noret_decl(trf_21947)
static void C_ccall trf_21947(C_word c,C_word *av) C_noret;
static void C_ccall trf_21947(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_21947(t0,t1,t2,t3,t4);}

C_noret_decl(trf_21954)
static void C_ccall trf_21954(C_word c,C_word *av) C_noret;
static void C_ccall trf_21954(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21954(t0,t1);}

C_noret_decl(trf_22009)
static void C_ccall trf_22009(C_word c,C_word *av) C_noret;
static void C_ccall trf_22009(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22009(t0,t1,t2);}

C_noret_decl(trf_22116)
static void C_ccall trf_22116(C_word c,C_word *av) C_noret;
static void C_ccall trf_22116(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22116(t0,t1);}

C_noret_decl(trf_22122)
static void C_ccall trf_22122(C_word c,C_word *av) C_noret;
static void C_ccall trf_22122(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22122(t0,t1);}

C_noret_decl(trf_22175)
static void C_ccall trf_22175(C_word c,C_word *av) C_noret;
static void C_ccall trf_22175(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22175(t0,t1,t2,t3);}

C_noret_decl(trf_22246)
static void C_ccall trf_22246(C_word c,C_word *av) C_noret;
static void C_ccall trf_22246(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22246(t0,t1,t2);}

C_noret_decl(trf_22299)
static void C_ccall trf_22299(C_word c,C_word *av) C_noret;
static void C_ccall trf_22299(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22299(t0,t1,t2,t3);}

C_noret_decl(trf_22308)
static void C_ccall trf_22308(C_word c,C_word *av) C_noret;
static void C_ccall trf_22308(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22308(t0,t1,t2,t3);}

C_noret_decl(trf_22381)
static void C_ccall trf_22381(C_word c,C_word *av) C_noret;
static void C_ccall trf_22381(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22381(t0,t1,t2);}

C_noret_decl(trf_22413)
static void C_ccall trf_22413(C_word c,C_word *av) C_noret;
static void C_ccall trf_22413(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_22413(t0,t1,t2,t3,t4);}

C_noret_decl(trf_22469)
static void C_ccall trf_22469(C_word c,C_word *av) C_noret;
static void C_ccall trf_22469(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_22469(t0,t1,t2,t3,t4);}

C_noret_decl(trf_22500)
static void C_ccall trf_22500(C_word c,C_word *av) C_noret;
static void C_ccall trf_22500(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22500(t0,t1);}

C_noret_decl(trf_22600)
static void C_ccall trf_22600(C_word c,C_word *av) C_noret;
static void C_ccall trf_22600(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22600(t0,t1,t2,t3);}

C_noret_decl(trf_22633)
static void C_ccall trf_22633(C_word c,C_word *av) C_noret;
static void C_ccall trf_22633(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22633(t0,t1,t2);}

C_noret_decl(trf_22641)
static void C_ccall trf_22641(C_word c,C_word *av) C_noret;
static void C_ccall trf_22641(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22641(t0,t1);}

C_noret_decl(trf_22676)
static void C_ccall trf_22676(C_word c,C_word *av) C_noret;
static void C_ccall trf_22676(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22676(t0,t1,t2);}

C_noret_decl(trf_22714)
static void C_ccall trf_22714(C_word c,C_word *av) C_noret;
static void C_ccall trf_22714(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_22714(t0,t1,t2,t3,t4);}

C_noret_decl(trf_22789)
static void C_ccall trf_22789(C_word c,C_word *av) C_noret;
static void C_ccall trf_22789(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_22789(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_22830)
static void C_ccall trf_22830(C_word c,C_word *av) C_noret;
static void C_ccall trf_22830(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22830(t0,t1,t2);}

C_noret_decl(trf_22846)
static void C_ccall trf_22846(C_word c,C_word *av) C_noret;
static void C_ccall trf_22846(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22846(t0,t1);}

C_noret_decl(trf_22948)
static void C_ccall trf_22948(C_word c,C_word *av) C_noret;
static void C_ccall trf_22948(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_22948(t0,t1,t2,t3,t4);}

C_noret_decl(trf_22971)
static void C_ccall trf_22971(C_word c,C_word *av) C_noret;
static void C_ccall trf_22971(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22971(t0,t1,t2,t3);}

C_noret_decl(trf_23000)
static void C_ccall trf_23000(C_word c,C_word *av) C_noret;
static void C_ccall trf_23000(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23000(t0,t1,t2);}

C_noret_decl(trf_23004)
static void C_ccall trf_23004(C_word c,C_word *av) C_noret;
static void C_ccall trf_23004(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_23004(t0,t1);}

C_noret_decl(trf_23028)
static void C_ccall trf_23028(C_word c,C_word *av) C_noret;
static void C_ccall trf_23028(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_23028(t0,t1);}

C_noret_decl(trf_23066)
static void C_ccall trf_23066(C_word c,C_word *av) C_noret;
static void C_ccall trf_23066(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23066(t0,t1,t2);}

C_noret_decl(trf_23081)
static void C_ccall trf_23081(C_word c,C_word *av) C_noret;
static void C_ccall trf_23081(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_23081(t0,t1,t2,t3,t4);}

C_noret_decl(trf_23096)
static void C_ccall trf_23096(C_word c,C_word *av) C_noret;
static void C_ccall trf_23096(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_23096(t0,t1,t2,t3);}

C_noret_decl(trf_23116)
static void C_ccall trf_23116(C_word c,C_word *av) C_noret;
static void C_ccall trf_23116(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_23116(t0,t1,t2,t3,t4);}

C_noret_decl(trf_23139)
static void C_ccall trf_23139(C_word c,C_word *av) C_noret;
static void C_ccall trf_23139(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_23139(t0,t1);}

C_noret_decl(trf_23248)
static void C_ccall trf_23248(C_word c,C_word *av) C_noret;
static void C_ccall trf_23248(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23248(t0,t1,t2);}

C_noret_decl(trf_23261)
static void C_ccall trf_23261(C_word c,C_word *av) C_noret;
static void C_ccall trf_23261(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_23261(t0,t1);}

C_noret_decl(trf_23275)
static void C_ccall trf_23275(C_word c,C_word *av) C_noret;
static void C_ccall trf_23275(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_23275(t0,t1,t2,t3,t4);}

C_noret_decl(trf_23302)
static void C_ccall trf_23302(C_word c,C_word *av) C_noret;
static void C_ccall trf_23302(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_23302(t0,t1,t2,t3,t4);}

C_noret_decl(trf_23458)
static void C_ccall trf_23458(C_word c,C_word *av) C_noret;
static void C_ccall trf_23458(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_23458(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_23461)
static void C_ccall trf_23461(C_word c,C_word *av) C_noret;
static void C_ccall trf_23461(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23461(t0,t1,t2);}

C_noret_decl(trf_23500)
static void C_ccall trf_23500(C_word c,C_word *av) C_noret;
static void C_ccall trf_23500(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_23500(t0,t1);}

C_noret_decl(trf_23999)
static void C_ccall trf_23999(C_word c,C_word *av) C_noret;
static void C_ccall trf_23999(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_23999(t0,t1);}

C_noret_decl(trf_24002)
static void C_ccall trf_24002(C_word c,C_word *av) C_noret;
static void C_ccall trf_24002(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_24002(t0,t1);}

C_noret_decl(trf_24151)
static void C_ccall trf_24151(C_word c,C_word *av) C_noret;
static void C_ccall trf_24151(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_24151(t0,t1);}

C_noret_decl(trf_24154)
static void C_ccall trf_24154(C_word c,C_word *av) C_noret;
static void C_ccall trf_24154(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_24154(t0,t1);}

C_noret_decl(trf_24591)
static void C_ccall trf_24591(C_word c,C_word *av) C_noret;
static void C_ccall trf_24591(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_24591(t0,t1);}

C_noret_decl(trf_24735)
static void C_ccall trf_24735(C_word c,C_word *av) C_noret;
static void C_ccall trf_24735(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_24735(t0,t1);}

C_noret_decl(trf_24758)
static void C_ccall trf_24758(C_word c,C_word *av) C_noret;
static void C_ccall trf_24758(C_word c,C_word *av){
C_word t0=av[7];
C_word t1=av[6];
C_word t2=av[5];
C_word t3=av[4];
C_word t4=av[3];
C_word t5=av[2];
C_word t6=av[1];
C_word t7=av[0];
f_24758(t0,t1,t2,t3,t4,t5,t6,t7);}

C_noret_decl(trf_25531)
static void C_ccall trf_25531(C_word c,C_word *av) C_noret;
static void C_ccall trf_25531(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25531(t0,t1);}

C_noret_decl(trf_25540)
static void C_ccall trf_25540(C_word c,C_word *av) C_noret;
static void C_ccall trf_25540(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25540(t0,t1);}

C_noret_decl(trf_25638)
static void C_ccall trf_25638(C_word c,C_word *av) C_noret;
static void C_ccall trf_25638(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25638(t0,t1);}

C_noret_decl(trf_25671)
static void C_ccall trf_25671(C_word c,C_word *av) C_noret;
static void C_ccall trf_25671(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25671(t0,t1);}

C_noret_decl(trf_25736)
static void C_ccall trf_25736(C_word c,C_word *av) C_noret;
static void C_ccall trf_25736(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25736(t0,t1);}

C_noret_decl(trf_25745)
static void C_ccall trf_25745(C_word c,C_word *av) C_noret;
static void C_ccall trf_25745(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25745(t0,t1);}

C_noret_decl(trf_25831)
static void C_ccall trf_25831(C_word c,C_word *av) C_noret;
static void C_ccall trf_25831(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25831(t0,t1);}

C_noret_decl(trf_25959)
static void C_ccall trf_25959(C_word c,C_word *av) C_noret;
static void C_ccall trf_25959(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_25959(t0,t1,t2);}

C_noret_decl(trf_26058)
static void C_ccall trf_26058(C_word c,C_word *av) C_noret;
static void C_ccall trf_26058(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26058(t0,t1,t2);}

C_noret_decl(trf_26180)
static void C_ccall trf_26180(C_word c,C_word *av) C_noret;
static void C_ccall trf_26180(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26180(t0,t1,t2);}

C_noret_decl(trf_26393)
static void C_ccall trf_26393(C_word c,C_word *av) C_noret;
static void C_ccall trf_26393(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26393(t0,t1);}

C_noret_decl(trf_26405)
static void C_ccall trf_26405(C_word c,C_word *av) C_noret;
static void C_ccall trf_26405(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_26405(t0,t1,t2,t3);}

C_noret_decl(trf_26455)
static void C_ccall trf_26455(C_word c,C_word *av) C_noret;
static void C_ccall trf_26455(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_26455(t0,t1,t2,t3);}

C_noret_decl(trf_26484)
static void C_ccall trf_26484(C_word c,C_word *av) C_noret;
static void C_ccall trf_26484(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26484(t0,t1);}

C_noret_decl(trf_26504)
static void C_ccall trf_26504(C_word c,C_word *av) C_noret;
static void C_ccall trf_26504(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26504(t0,t1,t2);}

C_noret_decl(trf_26514)
static void C_ccall trf_26514(C_word c,C_word *av) C_noret;
static void C_ccall trf_26514(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_26514(t0,t1,t2,t3);}

C_noret_decl(trf_26517)
static void C_ccall trf_26517(C_word c,C_word *av) C_noret;
static void C_ccall trf_26517(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26517(t0,t1,t2);}

C_noret_decl(trf_26583)
static void C_ccall trf_26583(C_word c,C_word *av) C_noret;
static void C_ccall trf_26583(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26583(t0,t1,t2);}

C_noret_decl(trf_26647)
static void C_ccall trf_26647(C_word c,C_word *av) C_noret;
static void C_ccall trf_26647(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26647(t0,t1,t2);}

C_noret_decl(trf_26717)
static void C_ccall trf_26717(C_word c,C_word *av) C_noret;
static void C_ccall trf_26717(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26717(t0,t1,t2);}

C_noret_decl(trf_26802)
static void C_ccall trf_26802(C_word c,C_word *av) C_noret;
static void C_ccall trf_26802(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26802(t0,t1,t2);}

C_noret_decl(trf_26971)
static void C_ccall trf_26971(C_word c,C_word *av) C_noret;
static void C_ccall trf_26971(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26971(t0,t1,t2);}

C_noret_decl(trf_27004)
static void C_ccall trf_27004(C_word c,C_word *av) C_noret;
static void C_ccall trf_27004(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_27004(t0,t1,t2,t3);}

C_noret_decl(trf_27106)
static void C_ccall trf_27106(C_word c,C_word *av) C_noret;
static void C_ccall trf_27106(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_27106(t0,t1,t2,t3,t4);}

C_noret_decl(trf_27287)
static void C_ccall trf_27287(C_word c,C_word *av) C_noret;
static void C_ccall trf_27287(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27287(t0,t1,t2);}

C_noret_decl(trf_27301)
static void C_ccall trf_27301(C_word c,C_word *av) C_noret;
static void C_ccall trf_27301(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_27301(t0,t1,t2,t3,t4);}

C_noret_decl(trf_27378)
static void C_ccall trf_27378(C_word c,C_word *av) C_noret;
static void C_ccall trf_27378(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27378(t0,t1);}

C_noret_decl(trf_27381)
static void C_ccall trf_27381(C_word c,C_word *av) C_noret;
static void C_ccall trf_27381(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27381(t0,t1);}

C_noret_decl(trf_27388)
static void C_ccall trf_27388(C_word c,C_word *av) C_noret;
static void C_ccall trf_27388(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27388(t0,t1);}

C_noret_decl(trf_27497)
static void C_ccall trf_27497(C_word c,C_word *av) C_noret;
static void C_ccall trf_27497(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_27497(t0,t1,t2,t3,t4);}

C_noret_decl(trf_27609)
static void C_ccall trf_27609(C_word c,C_word *av) C_noret;
static void C_ccall trf_27609(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27609(t0,t1);}

C_noret_decl(trf_27619)
static void C_ccall trf_27619(C_word c,C_word *av) C_noret;
static void C_ccall trf_27619(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27619(t0,t1);}

C_noret_decl(trf_27629)
static void C_ccall trf_27629(C_word c,C_word *av) C_noret;
static void C_ccall trf_27629(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_27629(t0,t1,t2,t3);}

C_noret_decl(trf_27649)
static void C_ccall trf_27649(C_word c,C_word *av) C_noret;
static void C_ccall trf_27649(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27649(t0,t1);}

C_noret_decl(trf_27769)
static void C_ccall trf_27769(C_word c,C_word *av) C_noret;
static void C_ccall trf_27769(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27769(t0,t1);}

C_noret_decl(trf_27772)
static void C_ccall trf_27772(C_word c,C_word *av) C_noret;
static void C_ccall trf_27772(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27772(t0,t1);}

C_noret_decl(trf_27792)
static void C_ccall trf_27792(C_word c,C_word *av) C_noret;
static void C_ccall trf_27792(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_27792(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_28026)
static void C_ccall trf_28026(C_word c,C_word *av) C_noret;
static void C_ccall trf_28026(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_28026(t0,t1,t2,t3,t4);}

C_noret_decl(trf_28378)
static void C_ccall trf_28378(C_word c,C_word *av) C_noret;
static void C_ccall trf_28378(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_28378(t0,t1,t2);}

C_noret_decl(trf_28384)
static void C_ccall trf_28384(C_word c,C_word *av) C_noret;
static void C_ccall trf_28384(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_28384(t0,t1,t2,t3);}

C_noret_decl(trf_28558)
static void C_ccall trf_28558(C_word c,C_word *av) C_noret;
static void C_ccall trf_28558(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_28558(t0,t1,t2);}

C_noret_decl(trf_28654)
static void C_ccall trf_28654(C_word c,C_word *av) C_noret;
static void C_ccall trf_28654(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_28654(t0,t1);}

C_noret_decl(trf_28725)
static void C_ccall trf_28725(C_word c,C_word *av) C_noret;
static void C_ccall trf_28725(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_28725(t0,t1);}

C_noret_decl(trf_28727)
static void C_ccall trf_28727(C_word c,C_word *av) C_noret;
static void C_ccall trf_28727(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_28727(t0,t1,t2,t3,t4);}

C_noret_decl(trf_28855)
static void C_ccall trf_28855(C_word c,C_word *av) C_noret;
static void C_ccall trf_28855(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_28855(t0,t1,t2);}

C_noret_decl(trf_28899)
static void C_ccall trf_28899(C_word c,C_word *av) C_noret;
static void C_ccall trf_28899(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_28899(t0,t1,t2,t3);}

C_noret_decl(trf_29012)
static void C_ccall trf_29012(C_word c,C_word *av) C_noret;
static void C_ccall trf_29012(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29012(t0,t1,t2);}

C_noret_decl(trf_29022)
static void C_ccall trf_29022(C_word c,C_word *av) C_noret;
static void C_ccall trf_29022(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29022(t0,t1);}

C_noret_decl(trf_29084)
static void C_ccall trf_29084(C_word c,C_word *av) C_noret;
static void C_ccall trf_29084(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_29084(t0,t1,t2,t3);}

C_noret_decl(trf_29096)
static void C_ccall trf_29096(C_word c,C_word *av) C_noret;
static void C_ccall trf_29096(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_29096(t0,t1,t2,t3);}

C_noret_decl(trf_29209)
static void C_ccall trf_29209(C_word c,C_word *av) C_noret;
static void C_ccall trf_29209(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29209(t0,t1);}

C_noret_decl(trf_29221)
static void C_ccall trf_29221(C_word c,C_word *av) C_noret;
static void C_ccall trf_29221(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29221(t0,t1,t2);}

C_noret_decl(trf_29301)
static void C_ccall trf_29301(C_word c,C_word *av) C_noret;
static void C_ccall trf_29301(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29301(t0,t1,t2);}

C_noret_decl(trf_29324)
static void C_ccall trf_29324(C_word c,C_word *av) C_noret;
static void C_ccall trf_29324(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29324(t0,t1);}

C_noret_decl(trf_29339)
static void C_ccall trf_29339(C_word c,C_word *av) C_noret;
static void C_ccall trf_29339(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29339(t0,t1,t2);}

C_noret_decl(trf_29369)
static void C_ccall trf_29369(C_word c,C_word *av) C_noret;
static void C_ccall trf_29369(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29369(t0,t1,t2);}

C_noret_decl(trf_29433)
static void C_ccall trf_29433(C_word c,C_word *av) C_noret;
static void C_ccall trf_29433(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29433(t0,t1,t2);}

C_noret_decl(trf_29483)
static void C_ccall trf_29483(C_word c,C_word *av) C_noret;
static void C_ccall trf_29483(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29483(t0,t1,t2);}

C_noret_decl(trf_29521)
static void C_ccall trf_29521(C_word c,C_word *av) C_noret;
static void C_ccall trf_29521(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29521(t0,t1,t2);}

C_noret_decl(trf_29542)
static void C_ccall trf_29542(C_word c,C_word *av) C_noret;
static void C_ccall trf_29542(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29542(t0,t1,t2);}

C_noret_decl(trf_29576)
static void C_ccall trf_29576(C_word c,C_word *av) C_noret;
static void C_ccall trf_29576(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29576(t0,t1);}

C_noret_decl(trf_29590)
static void C_ccall trf_29590(C_word c,C_word *av) C_noret;
static void C_ccall trf_29590(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29590(t0,t1);}

C_noret_decl(trf_29605)
static void C_ccall trf_29605(C_word c,C_word *av) C_noret;
static void C_ccall trf_29605(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29605(t0,t1,t2);}

C_noret_decl(trf_29673)
static void C_ccall trf_29673(C_word c,C_word *av) C_noret;
static void C_ccall trf_29673(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29673(t0,t1);}

C_noret_decl(trf_29737)
static void C_ccall trf_29737(C_word c,C_word *av) C_noret;
static void C_ccall trf_29737(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29737(t0,t1);}

C_noret_decl(trf_29746)
static void C_ccall trf_29746(C_word c,C_word *av) C_noret;
static void C_ccall trf_29746(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29746(t0,t1);}

C_noret_decl(trf_29840)
static void C_ccall trf_29840(C_word c,C_word *av) C_noret;
static void C_ccall trf_29840(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29840(t0,t1,t2);}

C_noret_decl(trf_30089)
static void C_ccall trf_30089(C_word c,C_word *av) C_noret;
static void C_ccall trf_30089(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_30089(t0,t1,t2,t3);}

C_noret_decl(trf_30197)
static void C_ccall trf_30197(C_word c,C_word *av) C_noret;
static void C_ccall trf_30197(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_30197(t0,t1,t2,t3);}

C_noret_decl(trf_30246)
static void C_ccall trf_30246(C_word c,C_word *av) C_noret;
static void C_ccall trf_30246(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_30246(t0,t1);}

C_noret_decl(trf_7546)
static void C_ccall trf_7546(C_word c,C_word *av) C_noret;
static void C_ccall trf_7546(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7546(t0,t1);}

C_noret_decl(trf_7628)
static void C_ccall trf_7628(C_word c,C_word *av) C_noret;
static void C_ccall trf_7628(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7628(t0,t1);}

C_noret_decl(trf_7651)
static void C_ccall trf_7651(C_word c,C_word *av) C_noret;
static void C_ccall trf_7651(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7651(t0,t1);}

C_noret_decl(trf_7660)
static void C_ccall trf_7660(C_word c,C_word *av) C_noret;
static void C_ccall trf_7660(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7660(t0,t1);}

C_noret_decl(trf_7960)
static void C_ccall trf_7960(C_word c,C_word *av) C_noret;
static void C_ccall trf_7960(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7960(t0,t1,t2,t3);}

C_noret_decl(trf_8028)
static void C_ccall trf_8028(C_word c,C_word *av) C_noret;
static void C_ccall trf_8028(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8028(t0,t1);}

C_noret_decl(trf_8072)
static void C_ccall trf_8072(C_word c,C_word *av) C_noret;
static void C_ccall trf_8072(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8072(t0,t1,t2,t3);}

C_noret_decl(trf_8418)
static void C_ccall trf_8418(C_word c,C_word *av) C_noret;
static void C_ccall trf_8418(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8418(t0,t1);}

C_noret_decl(trf_8479)
static void C_ccall trf_8479(C_word c,C_word *av) C_noret;
static void C_ccall trf_8479(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8479(t0,t1,t2,t3);}

C_noret_decl(trf_8628)
static void C_ccall trf_8628(C_word c,C_word *av) C_noret;
static void C_ccall trf_8628(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8628(t0,t1,t2);}

C_noret_decl(trf_8646)
static void C_ccall trf_8646(C_word c,C_word *av) C_noret;
static void C_ccall trf_8646(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8646(t0,t1,t2,t3);}

C_noret_decl(trf_8676)
static void C_ccall trf_8676(C_word c,C_word *av) C_noret;
static void C_ccall trf_8676(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8676(t0,t1,t2);}

C_noret_decl(trf_8836)
static void C_ccall trf_8836(C_word c,C_word *av) C_noret;
static void C_ccall trf_8836(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8836(t0,t1,t2);}

C_noret_decl(trf_8879)
static void C_ccall trf_8879(C_word c,C_word *av) C_noret;
static void C_ccall trf_8879(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8879(t0,t1,t2);}

C_noret_decl(trf_8936)
static void C_ccall trf_8936(C_word c,C_word *av) C_noret;
static void C_ccall trf_8936(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8936(t0,t1,t2);}

C_noret_decl(trf_8974)
static void C_ccall trf_8974(C_word c,C_word *av) C_noret;
static void C_ccall trf_8974(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_8974(t0,t1,t2,t3,t4);}

C_noret_decl(trf_8977)
static void C_ccall trf_8977(C_word c,C_word *av) C_noret;
static void C_ccall trf_8977(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8977(t0,t1);}

C_noret_decl(trf_9114)
static void C_ccall trf_9114(C_word c,C_word *av) C_noret;
static void C_ccall trf_9114(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9114(t0,t1);}

C_noret_decl(trf_9164)
static void C_ccall trf_9164(C_word c,C_word *av) C_noret;
static void C_ccall trf_9164(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9164(t0,t1);}

C_noret_decl(trf_9180)
static void C_ccall trf_9180(C_word c,C_word *av) C_noret;
static void C_ccall trf_9180(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9180(t0,t1,t2,t3);}

C_noret_decl(trf_9201)
static void C_ccall trf_9201(C_word c,C_word *av) C_noret;
static void C_ccall trf_9201(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9201(t0,t1,t2);}

C_noret_decl(trf_9207)
static void C_ccall trf_9207(C_word c,C_word *av) C_noret;
static void C_ccall trf_9207(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9207(t0,t1,t2);}

C_noret_decl(trf_9262)
static void C_ccall trf_9262(C_word c,C_word *av) C_noret;
static void C_ccall trf_9262(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9262(t0,t1);}

C_noret_decl(trf_9300)
static void C_ccall trf_9300(C_word c,C_word *av) C_noret;
static void C_ccall trf_9300(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9300(t0,t1,t2);}

C_noret_decl(trf_9316)
static void C_ccall trf_9316(C_word c,C_word *av) C_noret;
static void C_ccall trf_9316(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9316(t0,t1,t2,t3);}

C_noret_decl(trf_9343)
static void C_ccall trf_9343(C_word c,C_word *av) C_noret;
static void C_ccall trf_9343(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9343(t0,t1,t2);}

C_noret_decl(trf_9361)
static void C_ccall trf_9361(C_word c,C_word *av) C_noret;
static void C_ccall trf_9361(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9361(t0,t1,t2,t3);}

C_noret_decl(trf_9388)
static void C_ccall trf_9388(C_word c,C_word *av) C_noret;
static void C_ccall trf_9388(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9388(t0,t1,t2,t3);}

C_noret_decl(trf_9394)
static void C_ccall trf_9394(C_word c,C_word *av) C_noret;
static void C_ccall trf_9394(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9394(t0,t1,t2,t3);}

C_noret_decl(trf_9745)
static void C_ccall trf_9745(C_word c,C_word *av) C_noret;
static void C_ccall trf_9745(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9745(t0,t1,t2,t3);}

C_noret_decl(trf_9752)
static void C_ccall trf_9752(C_word c,C_word *av) C_noret;
static void C_ccall trf_9752(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9752(t0,t1,t2,t3);}

C_noret_decl(trf_9779)
static void C_ccall trf_9779(C_word c,C_word *av) C_noret;
static void C_ccall trf_9779(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9779(t0,t1,t2,t3);}

C_noret_decl(trf_9893)
static void C_ccall trf_9893(C_word c,C_word *av) C_noret;
static void C_ccall trf_9893(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9893(t0,t1,t2);}

C_noret_decl(trf_9970)
static void C_ccall trf_9970(C_word c,C_word *av) C_noret;
static void C_ccall trf_9970(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9970(t0,t1);}

/* f33662 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f33662(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f33662,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[124],t1);
/* irregex-core.scm:854: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* f33666 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f33666(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f33666,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[125],t1);
/* irregex-core.scm:854: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* scan */
static void C_fcall f_10027(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,0,4)))){
C_save_and_reclaim_args((void *)trf_10027,5,t0,t1,t2,t3,t4);}
a=C_alloc(23);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10030,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=((C_word*)t0)[2],a[6]=((C_word)li53),tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_fixnum_greater_or_equal_p(t3,((C_word*)((C_word*)t0)[3])[1]))){
/* irregex-core.scm:682: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[78];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=C_i_string_ref(((C_word*)t0)[2],t3);
switch(t6){
case C_make_character(34):
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10069,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10076,a[2]=t7,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:684: collect */
t9=t5;
f_10030(t9,t8);
case C_make_character(92):
t7=C_a_i_fixnum_plus(&a,2,t3,C_fix(1));
t8=C_a_i_fixnum_plus(&a,2,t3,C_fix(2));
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10095,a[2]=((C_word*)t0)[5],a[3]=t1,a[4]=t7,a[5]=t8,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:685: collect */
t10=t5;
f_10030(t10,t9);
default:
t7=C_a_i_fixnum_plus(&a,2,t3,C_fix(1));
/* irregex-core.scm:686: scan */
t14=t1;
t15=t2;
t16=t7;
t17=t4;
t1=t14;
t2=t15;
t3=t16;
t4=t17;
goto loop;}}}

/* collect in scan */
static void C_fcall f_10030(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_10030,2,t0,t1);}
a=C_alloc(4);
t2=C_eqp(((C_word*)t0)[2],((C_word*)t0)[3]);
if(C_truep(t2)){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10044,a[2]=t1,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:680: scheme#substring */
t4=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[2];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k10042 in collect in scan */
static void C_ccall f_10044(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10044,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10067 in scan */
static void C_ccall f_10069(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_10069,c,av);}
a=C_alloc(5);
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* irregex-core.scm:684: k */
t3=((C_word*)t0)[3];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k10074 in scan */
static void C_ccall f_10076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10076,c,av);}
/* irregex-core.scm:684: string-cat-reverse */
f_9114(((C_word*)t0)[2],t1);}

/* k10093 in scan */
static void C_ccall f_10095(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10095,c,av);}
/* irregex-core.scm:685: scan */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10027(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* a10127 */
static void C_ccall f_10128(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10128,c,av);}
/* irregex-core.scm:690: read */
t4=((C_word*)((C_word*)t0)[2])[1];
f_9752(t4,t1,t3,((C_word*)t0)[3]);}

/* a10145 */
static void C_ccall f_10146(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_10146,c,av);}
a=C_alloc(5);
t4=C_eqp(t2,lf[79]);
if(C_truep(t4)){
/* irregex-core.scm:694: k */
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
av2[2]=C_make_character(32);
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=C_eqp(t2,lf[80]);
if(C_truep(t5)){
/* irregex-core.scm:694: k */
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=C_make_character(10);
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10166,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_numberp(t2))){
/* ##sys#number->string */
t7=*((C_word*)lf[81]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
av2[3]=C_fix(10);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
/* irregex-core.scm:699: scheme#symbol->string */
t7=*((C_word*)lf[82]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}}}

/* k10164 in a10145 */
static void C_ccall f_10166(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10166,c,av);}
/* irregex-core.scm:694: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_i_string_ref(t1,C_fix(0));
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* scan */
static void C_fcall f_10246(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_10246,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_fixnum_greater_or_equal_p(t2,((C_word*)((C_word*)t0)[2])[1]);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10256,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t3)){
t5=t4;
f_10256(t5,t3);}
else{
t5=C_i_string_ref(((C_word*)t0)[4],t2);
t6=C_u_i_char_whitespacep(t5);
t7=t4;
f_10256(t7,(C_truep(t6)?t6:C_u_i_memq(t5,lf[86])));}}

/* k10254 in scan */
static void C_fcall f_10256(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_10256,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10259,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:717: scheme#substring */
t3=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* irregex-core.scm:719: scan */
t2=((C_word*)((C_word*)t0)[7])[1];
f_10246(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}}

/* k10257 in k10254 in scan */
static void C_ccall f_10259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_10259,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10266,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:718: scheme#string->number */
t3=*((C_word*)lf[85]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10264 in k10257 in k10254 in scan */
static void C_ccall f_10266(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_10266,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10269,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t1)){
/* irregex-core.scm:718: k */
t3=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* irregex-core.scm:718: scheme#string->symbol */
t3=*((C_word*)lf[84]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k10267 in k10264 in k10257 in k10254 in scan */
static void C_ccall f_10269(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10269,c,av);}
/* irregex-core.scm:718: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a10316 in chicken.irregex#with-read-from-string in k7767 in k7542 in k7539 */
static void C_ccall f_10317(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10317,c,av);}
t4=C_eqp(t2,lf[87]);
if(C_truep(t4)){
/* irregex-core.scm:722: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[88];
av2[3]=((C_word*)t0)[2];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
/* irregex-core.scm:723: proc */
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* chicken.irregex#symbol-list->flags in k7767 in k7542 in k7539 */
static void C_fcall f_10338(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_10338,2,t1,t2);}
a=C_alloc(6);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10344,a[2]=t4,a[3]=((C_word)li61),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_10344(t6,t1,t2,C_fix(0));}

/* lp in chicken.irregex#symbol-list->flags in k7767 in k7542 in k7539 */
static void C_fcall f_10344(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,2)))){
C_save_and_reclaim_args((void *)trf_10344,4,t0,t1,t2,t3);}
a=C_alloc(13);
t4=C_i_pairp(t2);
if(C_truep(C_i_not(t4))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_cdr(t2);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10362,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
t7=C_u_i_car(t2);
t8=C_eqp(t7,lf[90]);
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10373,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t5,a[5]=t3,a[6]=t7,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
if(C_truep(t8)){
t10=t9;
f_10373(t10,t8);}
else{
t10=C_eqp(t7,lf[99]);
t11=t9;
f_10373(t11,(C_truep(t10)?t10:C_eqp(t7,lf[100])));}}}

/* k10360 in lp in chicken.irregex#symbol-list->flags in k7767 in k7542 in k7539 */
static void C_fcall f_10362(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_10362,2,t0,t1);}
/* irregex-core.scm:739: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10344(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k10371 in lp in chicken.irregex#symbol-list->flags in k7767 in k7542 in k7539 */
static void C_fcall f_10373(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_10373,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:739: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10344(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_fixnum_or(((C_word*)t0)[5],C_fix(2)));}
else{
t2=C_eqp(((C_word*)t0)[6],lf[91]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[6],lf[92]));
if(C_truep(t3)){
/* irregex-core.scm:739: lp */
t4=((C_word*)((C_word*)t0)[2])[1];
f_10344(t4,((C_word*)t0)[3],((C_word*)t0)[4],C_fixnum_or(((C_word*)t0)[5],C_fix(4)));}
else{
t4=C_eqp(((C_word*)t0)[6],lf[93]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[6],lf[94]));
if(C_truep(t5)){
t6=((C_word*)t0)[7];
f_10362(t6,C_fixnum_or(((C_word*)t0)[5],C_fix(8)));}
else{
t6=C_eqp(((C_word*)t0)[6],lf[95]);
t7=(C_truep(t6)?t6:C_eqp(((C_word*)t0)[6],lf[96]));
if(C_truep(t7)){
t8=((C_word*)t0)[7];
f_10362(t8,C_fixnum_or(((C_word*)t0)[5],C_fix(16)));}
else{
t8=C_eqp(((C_word*)t0)[6],lf[97]);
t9=(C_truep(t8)?t8:C_eqp(((C_word*)t0)[6],lf[98]));
if(C_truep(t9)){
t10=((C_word*)t0)[7];
f_10362(t10,C_fixnum_or(((C_word*)t0)[5],C_fix(32)));}
else{
/* irregex-core.scm:739: lp */
t10=((C_word*)((C_word*)t0)[2])[1];
f_10344(t10,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}}}}}}

/* chicken.irregex#maybe-string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10461(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10461,c,av);}
if(C_truep(C_i_stringp(t2))){
/* irregex-core.scm:751: string->sre */
t3=*((C_word*)lf[102]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +5,c,4)))){
C_save_and_reclaim((void*)f_10473,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+5);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10477,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_stringp(t2);
if(C_truep(C_i_not(t5))){
/* irregex-core.scm:754: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=lf[197];
av2[3]=lf[198];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_10477(2,av2);}}}

/* k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10477(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10477,c,av);}
a=C_alloc(5);
t2=C_i_string_length(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10483,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:756: symbol-list->flags */
f_10338(t3,((C_word*)t0)[4]);}

/* k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,7)))){
C_save_and_reclaim((void *)f_10483,c,av);}
a=C_alloc(8);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10488,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word)li89),tmp=(C_word)a,a+=6,tmp));
t5=((C_word*)t3)[1];
f_10488(t5,((C_word*)t0)[4],C_fix(0),C_fix(0),t1,C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST);}

/* lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10488(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word t69;
C_word t70;
C_word t71;
C_word t72;
C_word t73;
C_word t74;
C_word t75;
C_word t76;
C_word t77;
C_word t78;
C_word t79;
C_word t80;
C_word t81;
C_word t82;
C_word t83;
C_word t84;
C_word t85;
C_word t86;
C_word t87;
C_word t88;
C_word t89;
C_word t90;
C_word t91;
C_word t92;
C_word t93;
C_word t94;
C_word t95;
C_word t96;
C_word t97;
C_word t98;
C_word t99;
C_word t100;
C_word t101;
C_word t102;
C_word t103;
C_word t104;
C_word t105;
C_word t106;
C_word t107;
C_word t108;
C_word t109;
C_word t110;
C_word t111;
C_word t112;
C_word t113;
C_word t114;
C_word t115;
C_word t116;
C_word t117;
C_word t118;
C_word t119;
C_word t120;
C_word t121;
C_word t122;
C_word t123;
C_word t124;
C_word t125;
C_word t126;
C_word t127;
C_word t128;
C_word t129;
C_word t130;
C_word t131;
C_word t132;
C_word t133;
C_word t134;
C_word t135;
C_word t136;
C_word t137;
C_word t138;
C_word t139;
C_word t140;
C_word t141;
C_word t142;
C_word t143;
C_word t144;
C_word t145;
C_word t146;
C_word t147;
C_word t148;
C_word t149;
C_word t150;
C_word t151;
C_word t152;
C_word t153;
C_word t154;
C_word t155;
C_word t156;
C_word t157;
C_word t158;
C_word t159;
C_word t160;
C_word t161;
C_word t162;
C_word t163;
C_word t164;
C_word t165;
C_word t166;
C_word t167;
C_word t168;
C_word t169;
C_word t170;
C_word t171;
C_word t172;
C_word t173;
C_word t174;
C_word t175;
C_word t176;
C_word t177;
C_word t178;
C_word t179;
C_word t180;
C_word t181;
C_word t182;
C_word t183;
C_word t184;
C_word t185;
C_word t186;
C_word t187;
C_word t188;
C_word t189;
C_word t190;
C_word t191;
C_word t192;
C_word t193;
C_word t194;
C_word t195;
C_word t196;
C_word t197;
C_word t198;
C_word t199;
C_word t200;
C_word t201;
C_word t202;
C_word t203;
C_word t204;
C_word t205;
C_word t206;
C_word t207;
C_word t208;
C_word t209;
C_word t210;
C_word t211;
C_word t212;
C_word t213;
C_word t214;
C_word t215;
C_word t216;
C_word t217;
C_word t218;
C_word t219;
C_word t220;
C_word t221;
C_word t222;
C_word t223;
C_word t224;
C_word t225;
C_word t226;
C_word t227;
C_word t228;
C_word t229;
C_word t230;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(105,0,6)))){
C_save_and_reclaim_args((void *)trf_10488,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(105);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_SCHEME_UNDEFINED;
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10491,a[2]=t4,a[3]=((C_word)li64),tmp=(C_word)a,a+=4,tmp));
t19=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10513,a[2]=t4,a[3]=t8,a[4]=((C_word)li66),tmp=(C_word)a,a+=5,tmp));
t20=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10569,a[2]=t2,a[3]=t3,a[4]=t5,a[5]=t10,a[6]=((C_word*)t0)[2],a[7]=((C_word)li67),tmp=(C_word)a,a+=8,tmp));
t21=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10589,a[2]=t4,a[3]=t3,a[4]=t5,a[5]=t10,a[6]=((C_word*)t0)[2],a[7]=t8,a[8]=t2,a[9]=((C_word)li69),tmp=(C_word)a,a+=10,tmp));
t22=t15=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10661,a[2]=t4,a[3]=t12,a[4]=((C_word)li71),tmp=(C_word)a,a+=5,tmp);
t23=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10894,a[2]=t4,a[3]=t6,a[4]=t12,a[5]=((C_word)li72),tmp=(C_word)a,a+=6,tmp));
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[3]))){
if(C_truep(C_i_pairp(t6))){
/* irregex-core.scm:849: chicken.base#error */
t24=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t24;
av2[1]=t1;
av2[2]=lf[123];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t24+1)))(4,av2);}}
else{
/* irregex-core.scm:850: collect/terms */
t24=t15;
f_10661(t24,t1);}}
else{
t24=C_i_string_ref(((C_word*)t0)[2],t2);
switch(t24){
case C_make_character(46):
t25=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t26=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t27=C_fixnum_and(t4,C_fix(8));
t28=C_eqp(C_fix(8),t27);
if(C_truep(t28)){
t29=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f33662,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t25,a[5]=t26,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:856: collect */
t30=((C_word*)t12)[1];
f_10569(t30,t29);}
else{
t29=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f33666,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t25,a[5]=t26,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:856: collect */
t30=((C_word*)t12)[1];
f_10569(t30,t29);}
case C_make_character(63):
t25=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10966,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:859: collect/single */
t26=((C_word*)t14)[1];
f_10589(t26,t25);
default:
t25=C_eqp(t24,C_make_character(43));
t26=(C_truep(t25)?t25:C_eqp(t24,C_make_character(42)));
if(C_truep(t26)){
t27=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11126,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=t4,a[7]=t6,a[8]=t24,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:880: collect/single */
t28=((C_word*)t14)[1];
f_10589(t28,t27);}
else{
switch(t24){
case C_make_character(40):
t27=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
if(C_truep(C_i_integer_greater_or_equalp(t27,((C_word*)t0)[3]))){
/* irregex-core.scm:895: chicken.base#error */
t28=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t28;
av2[1]=t1;
av2[2]=lf[140];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t28+1)))(4,av2);}}
else{
t28=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t29=C_i_string_ref(((C_word*)t0)[2],t28);
if(C_truep(C_i_not(C_u_i_memq(t29,lf[141])))){
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t32=C_fixnum_or(t4,C_fix(1));
t33=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11218,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t32,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:897: save */
t34=((C_word*)t17)[1];
f_10894(t34,t33);}
else{
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
if(C_truep(C_i_integer_greater_or_equalp(t30,((C_word*)t0)[3]))){
/* irregex-core.scm:899: chicken.base#error */
t31=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t31;
av2[1]=t1;
av2[2]=lf[142];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t31+1)))(4,av2);}}
else{
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t32=C_i_string_ref(((C_word*)t0)[2],t31);
t33=C_eqp(t32,C_make_character(42));
if(C_truep(t33)){
t34=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t35=C_i_string_ref(((C_word*)t0)[2],t34);
t36=C_eqp(C_make_character(39),t35);
if(C_truep(t36)){
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t38=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11248,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=t4,a[6]=t6,a[7]=t12,a[8]=((C_word)li73),tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:902: with-read-from-string */
f_9745(t1,((C_word*)t0)[2],t37,t38);}
else{
/* irregex-core.scm:907: chicken.base#error */
t37=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t37;
av2[1]=t1;
av2[2]=lf[144];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t37+1)))(4,av2);}}}
else{
t34=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t35=C_i_string_ref(((C_word*)t0)[2],t34);
switch(t35){
case C_make_character(35):
t36=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11315,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t4,a[6]=t6,a[7]=t12,tmp=(C_word)a,a+=8,tmp);
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
/* irregex-core.scm:911: string-scan-char */
t38=lf[54];{
C_word av2[5];
av2[0]=t38;
av2[1]=t36;
av2[2]=((C_word*)t0)[2];
av2[3]=C_make_character(41);
av2[4]=t37;
((C_proc)(void*)(*((C_word*)t38+1)))(5,av2);}
case C_make_character(58):
t36=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t38=C_fixnum_not(C_fix(1));
t39=C_fixnum_and(t4,t38);
t40=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11356,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t36,a[5]=t37,a[6]=t39,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:914: save */
t41=((C_word*)t17)[1];
f_10894(t41,t40);
case C_make_character(61):
t36=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t38=C_fixnum_not(C_fix(1));
t39=C_fixnum_and(t4,t38);
t40=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11379,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t36,a[5]=t37,a[6]=t39,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:917: save */
t41=((C_word*)t17)[1];
f_10894(t41,t40);
case C_make_character(33):
t36=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t38=C_fixnum_not(C_fix(1));
t39=C_fixnum_and(t4,t38);
t40=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11402,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t36,a[5]=t37,a[6]=t39,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:920: save */
t41=((C_word*)t17)[1];
f_10894(t41,t40);
case C_make_character(60):
t36=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
if(C_truep(C_i_integer_greater_or_equalp(t36,((C_word*)t0)[3]))){
/* irregex-core.scm:924: chicken.base#error */
t37=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t37;
av2[1]=t1;
av2[2]=lf[147];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t37+1)))(4,av2);}}
else{
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t38=C_i_string_ref(((C_word*)t0)[2],t37);
switch(t38){
case C_make_character(61):
t39=C_a_i_fixnum_plus(&a,2,t2,C_fix(4));
t40=C_a_i_fixnum_plus(&a,2,t2,C_fix(4));
t41=C_fixnum_not(C_fix(1));
t42=C_fixnum_and(t4,t41);
t43=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11444,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t39,a[5]=t40,a[6]=t42,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:929: save */
t44=((C_word*)t17)[1];
f_10894(t44,t43);
case C_make_character(33):
t39=C_a_i_fixnum_plus(&a,2,t2,C_fix(4));
t40=C_a_i_fixnum_plus(&a,2,t2,C_fix(4));
t41=C_fixnum_not(C_fix(1));
t42=C_fixnum_and(t4,t41);
t43=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11467,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t39,a[5]=t40,a[6]=t42,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:932: save */
t44=((C_word*)t17)[1];
f_10894(t44,t43);
default:
t39=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11470,a[2]=t4,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t17,a[6]=t2,a[7]=((C_word*)t0)[2],tmp=(C_word)a,a+=8,tmp);
t40=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t41=C_i_string_ref(((C_word*)t0)[2],t40);
if(C_truep(C_u_i_char_alphabeticp(t41))){
t42=C_a_i_fixnum_plus(&a,2,t2,C_fix(4));
/* irregex-core.scm:936: string-scan-char */
t43=lf[54];{
C_word av2[5];
av2[0]=t43;
av2[1]=t39;
av2[2]=((C_word*)t0)[2];
av2[3]=C_make_character(62);
av2[4]=t42;
((C_proc)(void*)(*((C_word*)t43+1)))(5,av2);}}
else{
t42=t39;{
C_word av2[2];
av2[0]=t42;
av2[1]=C_SCHEME_FALSE;
f_11470(2,av2);}}}}
case C_make_character(62):
t36=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t38=C_fixnum_not(C_fix(1));
t39=C_fixnum_and(t4,t38);
t40=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11556,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t36,a[5]=t37,a[6]=t39,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:945: save */
t41=((C_word*)t17)[1];
f_10894(t41,t40);
case C_make_character(40):
t36=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
if(C_truep(C_i_integer_greater_or_equalp(t36,((C_word*)t0)[3]))){
/* irregex-core.scm:953: chicken.base#error */
t37=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t37;
av2[1]=t1;
av2[2]=lf[152];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t37+1)))(4,av2);}}
else{
t37=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t38=C_i_string_ref(((C_word*)t0)[2],t37);
if(C_truep(C_u_i_char_numericp(t38))){
t39=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11581,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=t17,a[7]=t2,tmp=(C_word)a,a+=8,tmp);
t40=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
/* irregex-core.scm:955: string-scan-char */
t41=lf[54];{
C_word av2[5];
av2[0]=t41;
av2[1]=t39;
av2[2]=((C_word*)t0)[2];
av2[3]=C_make_character(41);
av2[4]=t40;
((C_proc)(void*)(*((C_word*)t41+1)))(5,av2);}}
else{
t39=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
t40=C_i_string_ref(((C_word*)t0)[2],t39);
if(C_truep(C_u_i_char_alphabeticp(t40))){
t41=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11633,a[2]=t4,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t17,a[6]=t2,a[7]=((C_word*)t0)[2],tmp=(C_word)a,a+=8,tmp);
t42=C_a_i_fixnum_plus(&a,2,t2,C_fix(3));
/* irregex-core.scm:962: string-scan-char */
t43=lf[54];{
C_word av2[5];
av2[0]=t43;
av2[1]=t41;
av2[2]=((C_word*)t0)[2];
av2[3]=C_make_character(41);
av2[4]=t42;
((C_proc)(void*)(*((C_word*)t43+1)))(5,av2);}}
else{
t41=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t42=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t43=C_fixnum_not(C_fix(1));
t44=C_fixnum_and(t4,t43);
t45=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11684,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t41,a[5]=t42,a[6]=t44,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:968: save */
t46=((C_word*)t17)[1];
f_10894(t46,t45);}}}
case C_make_character(123):
/* irregex-core.scm:970: chicken.base#error */
t36=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t36;
av2[1]=t1;
av2[2]=lf[155];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t36+1)))(4,av2);}
default:
t36=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t37=C_SCHEME_UNDEFINED;
t38=(*a=C_VECTOR_TYPE|1,a[1]=t37,tmp=(C_word)a,a+=2,tmp);
t39=C_set_block_item(t38,0,(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11715,a[2]=t4,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=t38,a[7]=((C_word*)t0)[4],a[8]=t6,a[9]=t12,a[10]=((C_word)li76),tmp=(C_word)a,a+=11,tmp));
t40=((C_word*)t38)[1];
f_11715(t40,t1,t36,t4,C_SCHEME_FALSE);}}}}}
case C_make_character(41):
if(C_truep(C_i_nullp(t6))){
/* irregex-core.scm:1010: chicken.base#error */
t27=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t27;
av2[1]=t1;
av2[2]=lf[160];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t27+1)))(4,av2);}}
else{
t27=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t28=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t29=C_i_caar(t6);
t30=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11993,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t27,a[6]=t28,a[7]=t29,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1014: collect/terms */
t31=t15;
f_10661(t31,t30);}
case C_make_character(91):
t27=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12008,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=t6,a[5]=t12,a[6]=((C_word)li77),tmp=(C_word)a,a+=7,tmp);
t28=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12032,a[2]=t1,a[3]=t27,tmp=(C_word)a,a+=4,tmp);
t29=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t30=C_i_string_length(((C_word*)t0)[2]);
t31=C_fixnum_lessp(t29,t30);
t32=(C_truep(t31)?C_eqp(C_make_character(94),C_i_string_ref(((C_word*)t0)[2],t29)):C_SCHEME_FALSE);
t33=C_fixnum_and(t4,C_fix(32));
t34=C_eqp(C_fix(32),t33);
t35=C_SCHEME_UNDEFINED;
t36=(*a=C_VECTOR_TYPE|1,a[1]=t35,tmp=(C_word)a,a+=2,tmp);
t37=C_set_block_item(t36,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13410,a[2]=t30,a[3]=((C_word*)t0)[2],a[4]=t36,a[5]=t4,a[6]=t32,a[7]=t29,a[8]=t34,a[9]=((C_word)li82),tmp=(C_word)a,a+=10,tmp));
if(C_truep(t32)){
t38=C_fixnum_plus(t29,C_fix(1));
t39=C_fixnum_and(t4,C_fix(4));
t40=C_eqp(C_fix(4),t39);
if(C_truep(t40)){
t41=C_a_i_cons(&a,2,C_make_character(10),C_make_character(10));
t42=C_a_i_vector1(&a,1,t41);
/* irregex-core.scm:1309: go */
t43=((C_word*)t36)[1];
f_13410(t43,t28,t38,C_SCHEME_FALSE,t42);}
else{
t41=C_a_i_vector(&a,0);
/* irregex-core.scm:1309: go */
t42=((C_word*)t36)[1];
f_13410(t42,t28,t38,C_SCHEME_FALSE,t41);}}
else{
t38=C_a_i_vector(&a,0);
/* irregex-core.scm:1314: go */
t39=((C_word*)t36)[1];
f_13410(t39,t28,t29,C_SCHEME_FALSE,t38);}
case C_make_character(123):
t27=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t28=C_i_integer_greater_or_equalp(t27,((C_word*)t0)[3]);
t29=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12051,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=((C_word*)t0)[2],a[10]=t14,tmp=(C_word)a,a+=11,tmp);
if(C_truep(t28)){
t30=t29;
f_12051(t30,t28);}
else{
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t31=C_i_string_ref(((C_word*)t0)[2],t30);
t32=C_u_i_char_numericp(t31);
if(C_truep(t32)){
t33=t29;
f_12051(t33,C_i_not(t32));}
else{
t33=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t34=C_i_string_ref(((C_word*)t0)[2],t33);
t35=t29;
f_12051(t35,C_i_not(C_eqp(C_make_character(44),t34)));}}
case C_make_character(92):
t27=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
if(C_truep(C_i_integer_greater_or_equalp(t27,((C_word*)t0)[3]))){
/* irregex-core.scm:1057: chicken.base#error */
t28=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t28;
av2[1]=t1;
av2[2]=lf[177];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t28+1)))(4,av2);}}
else{
t28=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t29=C_i_string_ref(((C_word*)t0)[2],t28);
switch(t29){
case C_make_character(100):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12280,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1062: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(68):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_list(&a,2,lf[179],lf[178]);
t33=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12307,a[2]=t32,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1064: collect */
t34=((C_word*)t12)[1];
f_10569(t34,t33);
case C_make_character(115):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12330,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1066: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(83):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_list(&a,2,lf[179],lf[79]);
t33=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12357,a[2]=t32,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1068: collect */
t34=((C_word*)t12)[1];
f_10569(t34,t33);
case C_make_character(119):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_list(&a,1,lf[180]);
t33=C_a_i_list(&a,3,lf[103],lf[181],t32);
t34=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12384,a[2]=t33,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1071: collect */
t35=((C_word*)t12)[1];
f_10569(t35,t34);
case C_make_character(87):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_list(&a,1,lf[182]);
t33=C_a_i_list(&a,3,lf[103],lf[181],t32);
t34=C_a_i_list(&a,2,lf[179],t33);
t35=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12415,a[2]=t34,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1074: collect */
t36=((C_word*)t12)[1];
f_10569(t36,t35);
case C_make_character(98):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_list(&a,3,lf[103],lf[183],lf[184]);
t33=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12450,a[2]=t32,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1077: collect */
t34=((C_word*)t12)[1];
f_10569(t34,t33);
case C_make_character(66):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12473,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1079: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(65):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12496,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1081: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(90):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_list(&a,2,lf[131],C_make_character(10));
t33=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12527,a[2]=t32,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1084: collect */
t34=((C_word*)t12)[1];
f_10569(t34,t33);
case C_make_character(122):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12550,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1086: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(82):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12573,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1088: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(75):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12596,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1090: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(60):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12619,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1093: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(62):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12642,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1095: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(120):
t30=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12653,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=t6,a[5]=t12,a[6]=((C_word)li85),tmp=(C_word)a,a+=7,tmp);
t31=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12677,a[2]=t1,a[3]=t30,tmp=(C_word)a,a+=4,tmp);
t32=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
/* irregex-core.scm:1100: string-parse-hex-escape */
f_13301(t31,((C_word*)t0)[2],t32,((C_word*)t0)[3]);
case C_make_character(107):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_i_string_ref(((C_word*)t0)[2],t30);
if(C_truep(C_i_not(C_u_i_memq(t31,lf[189])))){
/* irregex-core.scm:1104: chicken.base#error */
t32=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t32;
av2[1]=t1;
av2[2]=lf[190];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t32+1)))(4,av2);}}
else{
t32=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12701,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],a[6]=t6,a[7]=t12,a[8]=t2,tmp=(C_word)a,a+=9,tmp);
switch(t31){
case C_make_character(60):
t33=t32;
f_12701(t33,C_make_character(62));
case C_make_character(123):
t33=t32;
f_12701(t33,C_make_character(125));
case C_make_character(40):
t33=t32;
f_12701(t33,C_make_character(41));
default:
t33=C_eqp(t31,C_make_character(91));
t34=t32;
f_12701(t34,(C_truep(t33)?C_make_character(93):t31));}}
case C_make_character(81):
t30=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12773,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t4,a[6]=t6,a[7]=((C_word*)t0)[2],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1119: collect */
t31=((C_word*)t12)[1];
f_10569(t31,t30);
case C_make_character(39):
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12884,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=t6,a[5]=t12,a[6]=((C_word)li87),tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:1136: with-read-from-string */
f_9745(t1,((C_word*)t0)[2],t30,t31);
default:
if(C_truep(C_u_i_char_numericp(t29))){
t30=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12905,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=t6,a[7]=t12,a[8]=t2,a[9]=((C_word*)t0)[2],tmp=(C_word)a,a+=10,tmp);
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_list(&a,1,t31);
t33=C_i_string_length(((C_word*)t0)[2]);
t34=C_i_pairp(t32);
t35=(C_truep(t34)?C_u_i_car(t32):C_fix(0));
t36=C_SCHEME_UNDEFINED;
t37=(*a=C_VECTOR_TYPE|1,a[1]=t36,tmp=(C_word)a,a+=2,tmp);
t38=C_set_block_item(t37,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8936,a[2]=t33,a[3]=((C_word*)t0)[2],a[4]=t37,a[5]=((C_word)li88),tmp=(C_word)a,a+=6,tmp));
t39=((C_word*)t37)[1];
f_8936(t39,t30,t35);}
else{
if(C_truep(C_u_i_char_alphabeticp(t29))){
t30=C_i_assq(t29,lf[168]);
if(C_truep(t30)){
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t32=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t33=C_i_cdr(t30);
t34=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12985,a[2]=t33,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t31,a[6]=t32,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1163: collect */
t35=((C_word*)t12)[1];
f_10569(t35,t34);}
else{
/* irregex-core.scm:1164: chicken.base#error */
t31=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t31;
av2[1]=t1;
av2[2]=lf[194];
av2[3]=((C_word*)t0)[2];
av2[4]=t29;
((C_proc)(void*)(*((C_word*)t31+1)))(5,av2);}}}
else{
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13001,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t30,a[5]=t31,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1166: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);}}}}
case C_make_character(124):
t27=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t28=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t29=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13065,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t27,a[5]=t28,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1168: collect */
t30=((C_word*)t12)[1];
f_10569(t30,t29);
case C_make_character(94):
t27=C_fixnum_and(t4,C_fix(4));
t28=C_eqp(C_fix(4),t27);
t29=(C_truep(t28)?lf[195]:lf[186]);
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t32=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13091,a[2]=t29,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1171: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(36):
t27=C_fixnum_and(t4,C_fix(4));
t28=C_eqp(C_fix(4),t27);
t29=(C_truep(t28)?lf[196]:lf[187]);
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t31=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t32=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13120,a[2]=t29,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t30,a[6]=t31,a[7]=t4,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1174: collect */
t33=((C_word*)t12)[1];
f_10569(t33,t32);
case C_make_character(32):
t27=C_fixnum_and(t4,C_fix(16));
t28=C_eqp(C_fix(16),t27);
if(C_truep(t28)){
t29=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t31=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13148,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t29,a[5]=t30,a[6]=t4,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1177: collect */
t32=((C_word*)t12)[1];
f_10569(t32,t31);}
else{
t29=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:1178: lp */
t225=t1;
t226=t29;
t227=t3;
t228=t4;
t229=t5;
t230=t6;
t1=t225;
t2=t226;
t3=t227;
t4=t228;
t5=t229;
t6=t230;
goto loop;}
case C_make_character(35):
t27=C_fixnum_and(t4,C_fix(16));
t28=C_eqp(C_fix(16),t27);
if(C_truep(t28)){
t29=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13169,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t4,a[6]=t6,a[7]=t12,tmp=(C_word)a,a+=8,tmp);
t30=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:1181: string-scan-char */
t31=lf[54];{
C_word av2[5];
av2[0]=t31;
av2[1]=t29;
av2[2]=((C_word*)t0)[2];
av2[3]=C_make_character(10);
av2[4]=t30;
((C_proc)(void*)(*((C_word*)t31+1)))(5,av2);}}
else{
t29=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:1184: lp */
t225=t1;
t226=t29;
t227=t3;
t228=t4;
t229=t5;
t230=t6;
t1=t225;
t2=t226;
t3=t227;
t4=t228;
t5=t229;
t6=t230;
goto loop;}
default:
t27=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:1186: lp */
t225=t1;
t226=t27;
t227=t3;
t228=t4;
t229=t5;
t230=t6;
t1=t225;
t2=t226;
t3=t227;
t4=t228;
t5=t229;
t6=t230;
goto loop;}}}}}

/* cased-char in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static C_word C_fcall f_10491(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_stack_overflow_check;{}
t2=C_fixnum_and(((C_word*)t0)[2],C_fix(2));
t3=C_eqp(C_fix(2),t2);
t4=(C_truep(t3)?C_u_i_char_alphabeticp(t1):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_u_i_char_upper_casep(t1);
t6=(C_truep(t5)?C_u_i_char_downcase(t1):C_u_i_char_upcase(t1));
return(C_a_i_list(&a,3,lf[103],t1,t6));}
else{
return(t1);}}

/* cased-string in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10513(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_10513,3,t0,t1,t2);}
a=C_alloc(11);
t3=C_fixnum_and(((C_word*)t0)[2],C_fix(2));
t4=C_eqp(C_fix(2),t3);
if(C_truep(t4)){
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10530,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t7,a[5]=t8,tmp=(C_word)a,a+=6,tmp);
/* ##sys#string->list */
t10=*((C_word*)lf[105]+1);{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k10528 in cased-string in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10530(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_10530,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10533,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10535,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t4,a[5]=((C_word*)t0)[5],a[6]=((C_word)li65),tmp=(C_word)a,a+=7,tmp));
t6=((C_word*)t4)[1];
f_10535(t6,t2,t1);}

/* k10531 in k10528 in cased-string in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10533,c,av);}
a=C_alloc(3);
/* irregex-core.scm:768: sre-sequence */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(
/* irregex-core.scm:768: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop1471 in k10528 in cased-string in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10535(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_10535,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=(
/* irregex-core.scm:768: g1477 */
  f_10491(C_a_i(&a,9),((C_word*)((C_word*)t0)[2])[1],C_slot(t2,C_fix(0)))
);
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[3])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[3])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* collect in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10569(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_10569,2,t0,t1);}
a=C_alloc(8);
t2=C_eqp(((C_word*)t0)[2],((C_word*)t0)[3]);
if(C_truep(t2)){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10583,a[2]=t1,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10587,a[2]=((C_word*)t0)[5],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:772: scheme#substring */
t5=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k10581 in collect in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10583(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10583,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10585 in collect in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10587(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10587,c,av);}
/* irregex-core.scm:772: cased-string */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10513(t2,((C_word*)t0)[3],t1);}

/* collect/single in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10589(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,0,3)))){
C_save_and_reclaim_args((void *)trf_10589,2,t0,t1);}
a=C_alloc(17);
t2=C_fixnum_and(((C_word*)t0)[2],C_fix(32));
t3=C_eqp(C_fix(32),t2);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10596,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t3,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t5=(C_truep(t3)?C_fixnum_greaterp(((C_word*)t0)[8],C_fix(1)):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=C_fixnum_difference(((C_word*)t0)[8],C_fix(1));
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14230,a[2]=((C_word*)t0)[6],a[3]=t8,a[4]=((C_word)li68),tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_14230(t10,t4,t6);}
else{
t6=t4;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_fixnum_difference(((C_word*)t0)[8],C_fix(1));
f_10596(2,av2);}}}

/* k10594 in collect/single in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10596(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,4)))){
C_save_and_reclaim((void *)f_10596,c,av);}
a=C_alloc(21);
if(C_truep(C_fixnum_lessp(t1,((C_word*)t0)[2]))){
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10605,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10633,a[2]=t2,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[8])){
/* irregex-core.scm:785: utf8-string-ref */
f_14035(t3,((C_word*)t0)[6],t1,C_fixnum_difference(((C_word*)t0)[9],t1));}
else{
/* irregex-core.scm:784: cased-char */
t4=t2;
f_10605(t4,(
/* irregex-core.scm:784: cased-char */
  f_10491(C_a_i(&a,9),((C_word*)((C_word*)t0)[7])[1],C_i_string_ref(((C_word*)t0)[6],t1))
));}}}

/* k10603 in k10594 in collect/single in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10605(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_10605,2,t0,t1);}
a=C_alloc(9);
t2=C_eqp(((C_word*)t0)[2],((C_word*)t0)[3]);
if(C_truep(t2)){
t3=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t1,((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10625,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10629,a[2]=((C_word*)t0)[6],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:792: scheme#substring */
t5=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k10623 in k10603 in k10594 in collect/single in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10625(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10625,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10627 in k10603 in k10594 in collect/single in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10629,c,av);}
/* irregex-core.scm:792: cased-string */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10513(t2,((C_word*)t0)[3],t1);}

/* k10631 in k10594 in collect/single in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10633(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_10633,c,av);}
a=C_alloc(9);
/* irregex-core.scm:784: cased-char */
t2=((C_word*)t0)[2];
f_10605(t2,(
/* irregex-core.scm:784: cased-char */
  f_10491(C_a_i(&a,9),((C_word*)((C_word*)t0)[3])[1],t1)
));}

/* collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10661(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_10661,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10665,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:798: collect */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10569(t3,t2);}

/* k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10665(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_10665,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10668,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_pairp(t1))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10891,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:801: last */
f_9262(t3,t1);}
else{
t3=t2;
f_10668(t3,C_SCHEME_FALSE);}}

/* k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10668(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_10668,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10671,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=(C_truep(t1)?C_u_i_memq(C_i_car(t1),lf[121]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10869,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:807: ##sys#fast-reverse */
t5=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
if(C_truep(t1)){
t4=C_i_car(t1);
t5=t2;
f_10671(t5,C_a_i_list1(&a,1,t4));}
else{
t4=t2;
f_10671(t4,C_SCHEME_FALSE);}}}

/* k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10671(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_10671,2,t0,t1);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10674,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=C_i_car(((C_word*)t0)[4]);
if(C_truep((C_truep(C_eqp(t3,lf[119]))?C_SCHEME_TRUE:(C_truep(C_eqp(t3,lf[120]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10844,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:811: ##sys#fast-reverse */
t5=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10855,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:812: ##sys#fast-reverse */
t5=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
f_10674(2,av2);}}}

/* k10672 in k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_10674,c,av);}
a=C_alloc(8);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10679,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word)li70),tmp=(C_word)a,a+=6,tmp));
t5=((C_word*)t3)[1];
f_10679(t5,((C_word*)t0)[4],t1,C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST);}

/* lp in k10672 in k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10679(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(31,0,4)))){
C_save_and_reclaim_args((void *)trf_10679,5,t0,t1,t2,t3,t4);}
a=C_alloc(31);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10682,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_nullp(t2))){
t6=(
/* irregex-core.scm:819: shift */
  f_10682(C_a_i(&a,6),t5)
);
t7=(
/* irregex-core.scm:819: sre-alternate */
  f_18226(C_a_i(&a,3),t6)
);
t8=C_fixnum_and(((C_word*)t0)[2],C_fix(1));
t9=C_eqp(C_fix(1),t8);
t10=(C_truep(t9)?C_a_i_list2(&a,2,lf[108],t7):t7);
if(C_truep(((C_word*)t0)[3])){
t11=C_i_car(((C_word*)t0)[3]);
t12=C_eqp(lf[109],t11);
if(C_truep(t12)){
t13=C_i_pairp(t10);
if(C_truep(C_i_not(t13))){
t14=t1;{
C_word av2[2];
av2[0]=t14;
av2[1]=lf[110];
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t14=C_i_car(t10);
if(C_truep((C_truep(C_eqp(t14,lf[111]))?C_SCHEME_TRUE:(C_truep(C_eqp(t14,lf[112]))?C_SCHEME_TRUE:(C_truep(C_eqp(t14,lf[113]))?C_SCHEME_TRUE:(C_truep(C_eqp(t14,lf[114]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))))){
t15=t1;{
C_word av2[2];
av2[0]=t15;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t15=C_eqp(lf[115],C_u_i_car(t10));
if(C_truep(t15)){
t16=C_i_cadr(t10);
t17=C_u_i_cdr(t10);
t18=(
/* irregex-core.scm:834: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t17))
);
t19=t1;{
C_word av2[2];
av2[0]=t19;
av2[1]=C_a_i_list(&a,3,lf[109],t16,t18);
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}
else{
t16=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10752,a[2]=t10,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:836: scheme#cadadr */
t17=*((C_word*)lf[117]+1);{
C_word av2[3];
av2[0]=t17;
av2[1]=t16;
av2[2]=t10;
((C_proc)(void*)(*((C_word*)t17+1)))(3,av2);}}}}}
else{
t13=C_a_i_list(&a,1,t10);
/* irregex-core.scm:839: ##sys#append */
t14=*((C_word*)lf[118]+1);{
C_word av2[4];
av2[0]=t14;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=t13;
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}}
else{
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}
else{
t6=C_i_car(t2);
t7=C_eqp(lf[103],t6);
if(C_truep(t7)){
t8=C_u_i_cdr(t2);
t9=(
/* irregex-core.scm:841: shift */
  f_10682(C_a_i(&a,6),t5)
);
/* irregex-core.scm:841: lp */
t20=t1;
t21=t8;
t22=C_SCHEME_END_OF_LIST;
t23=t9;
t1=t20;
t2=t21;
t3=t22;
t4=t23;
goto loop;}
else{
t8=C_u_i_cdr(t2);
t9=C_u_i_car(t2);
t10=C_a_i_cons(&a,2,t9,t3);
/* irregex-core.scm:842: lp */
t20=t1;
t21=t8;
t22=t10;
t23=t4;
t1=t20;
t2=t21;
t3=t22;
t4=t23;
goto loop;}}}

/* shift in lp in k10672 in k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static C_word C_fcall f_10682(C_word *a,C_word t0){
C_word tmp;
C_word t1;
C_word t2;
C_stack_overflow_check;{}
t1=(
/* irregex-core.scm:816: sre-sequence */
  f_18203(C_a_i(&a,3),((C_word*)t0)[2])
);
return(C_a_i_cons(&a,2,t1,((C_word*)t0)[3]));}

/* k10750 in lp in k10672 in k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10752(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10752,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10768,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:837: scheme#cddadr */
t3=*((C_word*)lf[116]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10766 in k10750 in lp in k10672 in k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,1)))){
C_save_and_reclaim((void *)f_10768,c,av);}
a=C_alloc(18);
t2=(
/* irregex-core.scm:837: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
t3=(
/* irregex-core.scm:838: sre-alternate */
  f_18226(C_a_i(&a,3),C_i_cddr(((C_word*)t0)[2]))
);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list(&a,4,lf[109],((C_word*)t0)[4],t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10842 in k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10844(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10844,c,av);}
/* irregex-core.scm:811: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_cddr(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k10853 in k10669 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10855,c,av);}
/* irregex-core.scm:812: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_cdr(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k10867 in k10666 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10869,c,av);}
a=C_alloc(6);
t2=C_i_cadr(t1);
t3=((C_word*)t0)[2];
f_10671(t3,C_a_i_list2(&a,2,lf[120],t2));}

/* k10889 in k10663 in collect/terms in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10891(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10891,c,av);}
t2=((C_word*)t0)[2];
f_10668(t2,C_u_i_memq(t1,lf[122]));}

/* save in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10894(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_10894,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10906,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:844: collect */
t3=((C_word*)((C_word*)t0)[4])[1];
f_10569(t3,t2);}

/* k10904 in save in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10906(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10906,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10964 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_10966(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,4)))){
C_save_and_reclaim((void *)f_10966,c,av);}
a=C_alloc(28);
if(C_truep(C_i_nullp(t1))){
/* irregex-core.scm:861: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[126];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=C_i_car(t1);
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t4=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10995,a[2]=t1,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=t3,a[6]=t4,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_i_pairp(t2))){
t6=C_u_i_car(t2);
t7=C_eqp(t6,lf[127]);
if(C_truep(t7)){
t8=C_u_i_cdr(t2);
t9=t5;
f_10995(t9,C_a_i_cons(&a,2,lf[128],t8));}
else{
t8=C_eqp(t6,lf[129]);
if(C_truep(t8)){
t9=C_u_i_cdr(t2);
t10=C_a_i_cons(&a,2,C_SCHEME_FALSE,t9);
t11=C_a_i_cons(&a,2,C_fix(1),t10);
t12=t5;
f_10995(t12,C_a_i_cons(&a,2,lf[130],t11));}
else{
t9=C_eqp(t6,lf[131]);
if(C_truep(t9)){
t10=C_u_i_cdr(t2);
t11=t5;
f_10995(t11,C_a_i_cons(&a,2,lf[132],t10));}
else{
t10=C_eqp(t6,lf[133]);
if(C_truep(t10)){
t11=C_u_i_cdr(t2);
t12=t5;
f_10995(t12,C_a_i_cons(&a,2,lf[130],t11));}
else{
t11=C_eqp(t6,lf[134]);
if(C_truep(t11)){
t12=C_i_cadr(t2);
t13=C_u_i_cdr(t2);
t14=C_a_i_cons(&a,2,t12,t13);
t15=t5;
f_10995(t15,C_a_i_cons(&a,2,lf[130],t14));}
else{
t12=C_eqp(t6,lf[135]);
if(C_truep(t12)){
t13=C_i_cadr(t2);
t14=C_u_i_cdr(t2);
t15=C_u_i_cdr(t14);
t16=C_a_i_cons(&a,2,C_SCHEME_FALSE,t15);
t17=C_a_i_cons(&a,2,t13,t16);
t18=t5;
f_10995(t18,C_a_i_cons(&a,2,lf[130],t17));}
else{
t13=t5;
f_10995(t13,C_a_i_list(&a,2,lf[131],t2));}}}}}}}
else{
t6=t5;
f_10995(t6,C_a_i_list(&a,2,lf[131],t2));}}}

/* k10993 in k10964 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_10995(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,6)))){
C_save_and_reclaim_args((void *)trf_10995,2,t0,t1);}
a=C_alloc(3);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
/* irregex-core.scm:863: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_10488(t4,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t3,((C_word*)t0)[8]);}

/* k11124 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_11126,c,av);}
a=C_alloc(12);
t2=C_i_pairp(t1);
t3=(C_truep(t2)?C_u_i_car(t1):lf[110]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11132,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
t5=C_a_i_string(&a,1,((C_word*)t0)[8]);
/* irregex-core.scm:882: scheme#string->symbol */
t6=*((C_word*)lf[84]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k11130 in k11124 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11132(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_11132,c,av);}
a=C_alloc(11);
t2=(
/* irregex-core.scm:884: sre-repeater? */
  f_16587(((C_word*)t0)[2])
);
if(C_truep(t2)){
/* irregex-core.scm:885: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[137];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11147,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:886: sre-empty? */
t4=lf[139];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
f_16319(3,av2);}}}

/* k11145 in k11130 in k11124 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11147(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,6)))){
C_save_and_reclaim((void *)f_11147,c,av);}
a=C_alloc(19);
if(C_truep(t1)){
/* irregex-core.scm:887: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[138];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[5],C_fix(1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[5],C_fix(1));
t4=C_a_i_list2(&a,2,((C_word*)t0)[6],((C_word*)t0)[7]);
t5=C_i_cdr(((C_word*)t0)[4]);
t6=C_a_i_cons(&a,2,t4,t5);
/* irregex-core.scm:889: lp */
t7=((C_word*)((C_word*)t0)[8])[1];
f_10488(t7,((C_word*)t0)[2],t2,t3,((C_word*)t0)[9],t6,((C_word*)t0)[10]);}}

/* k11216 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11218(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11218,c,av);}
/* irregex-core.scm:897: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_END_OF_LIST,t1);}

/* a11247 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11248(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_11248,c,av);}
a=C_alloc(10);
t4=C_fixnum_greater_or_equal_p(t3,((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11258,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t4)){
t6=t5;
f_11258(t6,t4);}
else{
t6=C_i_string_ref(((C_word*)t0)[3],t3);
t7=t5;
f_11258(t7,C_i_not(C_eqp(C_make_character(41),t6)));}}

/* k11256 in a11247 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_11258(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_11258,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
/* irregex-core.scm:905: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[143];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_fixnum_plus(((C_word*)t0)[4],C_fix(1));
t3=C_fixnum_plus(((C_word*)t0)[4],C_fix(1));
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11280,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=t3,a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:906: collect */
t5=((C_word*)((C_word*)t0)[9])[1];
f_10569(t5,t4);}}

/* k11278 in k11256 in a11247 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_11280,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:906: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k11313 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_11315,c,av);}
a=C_alloc(8);
t2=C_fixnum_plus(t1,((C_word*)t0)[2]);
t3=C_fixnum_plus(t1,C_fix(1));
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11330,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:912: collect */
t5=((C_word*)((C_word*)t0)[7])[1];
f_10569(t5,t4);}

/* k11328 in k11313 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11330,c,av);}
/* irregex-core.scm:912: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,((C_word*)t0)[7]);}

/* k11354 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11356(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11356,c,av);}
/* irregex-core.scm:914: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_END_OF_LIST,t1);}

/* k11377 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11379,c,av);}
/* irregex-core.scm:916: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],lf[145],t1);}

/* k11400 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11402(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11402,c,av);}
/* irregex-core.scm:919: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],lf[146],t1);}

/* k11442 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11444(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11444,c,av);}
/* irregex-core.scm:928: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],lf[148],t1);}

/* k11465 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11467(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11467,c,av);}
/* irregex-core.scm:931: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],lf[149],t1);}

/* k11468 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11470(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_11470,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=C_fixnum_plus(t1,C_fix(1));
t3=C_fixnum_plus(t1,C_fix(1));
t4=C_fixnum_not(C_fix(1));
t5=C_fixnum_and(((C_word*)t0)[2],t4);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11500,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=t3,a[6]=t5,a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11504,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
t8=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[6],C_fix(3));
/* irregex-core.scm:939: scheme#substring */
t9=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t7;
av2[2]=((C_word*)t0)[7];
av2[3]=t8;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
/* irregex-core.scm:942: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[150];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k11494 in k11498 in k11468 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11496,c,av);}
/* irregex-core.scm:938: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t1);}

/* k11498 in k11468 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_11500,c,av);}
a=C_alloc(14);
t2=C_a_i_list(&a,2,t1,lf[120]);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11496,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t2,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:941: save */
t4=((C_word*)((C_word*)t0)[7])[1];
f_10894(t4,t3);}

/* k11502 in k11468 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11504,c,av);}
/* irregex-core.scm:939: scheme#string->symbol */
t2=*((C_word*)lf[84]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11554 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11556(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11556,c,av);}
/* irregex-core.scm:944: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],lf[151],t1);}

/* k11579 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_11581,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11584,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11618,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[7],C_fix(3));
/* irregex-core.scm:956: scheme#substring */
t5=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=t4;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k11582 in k11579 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11584(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_11584,c,av);}
a=C_alloc(24);
if(C_truep(C_i_not(t1))){
/* irregex-core.scm:958: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[153];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t4=C_fixnum_not(C_fix(1));
t5=C_fixnum_and(((C_word*)t0)[5],t4);
t6=C_a_i_list(&a,2,t1,lf[109]);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11614,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=t3,a[6]=t5,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:960: save */
t8=((C_word*)((C_word*)t0)[7])[1];
f_10894(t8,t7);}}

/* k11612 in k11582 in k11579 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11614,c,av);}
/* irregex-core.scm:959: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t1);}

/* k11616 in k11579 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11618(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11618,c,av);}
/* irregex-core.scm:956: scheme#string->number */
t2=*((C_word*)lf[85]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11631 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11633(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_11633,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11636,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11661,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[6],C_fix(3));
/* irregex-core.scm:963: scheme#substring */
t5=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=t4;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k11634 in k11631 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,2)))){
C_save_and_reclaim((void *)f_11636,c,av);}
a=C_alloc(24);
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t4=C_fixnum_not(C_fix(1));
t5=C_fixnum_and(((C_word*)t0)[3],t4);
t6=C_a_i_list(&a,2,t1,lf[109]);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11657,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t2,a[5]=t3,a[6]=t5,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:965: save */
t8=((C_word*)((C_word*)t0)[6])[1];
f_10894(t8,t7);}

/* k11655 in k11634 in k11631 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11657,c,av);}
/* irregex-core.scm:964: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t1);}

/* k11659 in k11631 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11661(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11661,c,av);}
/* irregex-core.scm:963: scheme#string->symbol */
t2=*((C_word*)lf[84]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11682 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11684,c,av);}
/* irregex-core.scm:967: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],lf[154],t1);}

/* lp2 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_11715(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(38,0,4)))){
C_save_and_reclaim_args((void *)trf_11715,5,t0,t1,t2,t3,t4);}
a=C_alloc(38);
t5=C_SCHEME_UNDEFINED;
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11718,a[2]=t4,a[3]=t3,a[4]=((C_word)li74),tmp=(C_word)a,a+=5,tmp);
t9=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11727,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word)li75),tmp=(C_word)a,a+=5,tmp));
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[3]))){
/* irregex-core.scm:984: chicken.base#error */
t10=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t10;
av2[1]=t1;
av2[2]=lf[158];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
t10=C_i_string_ref(((C_word*)t0)[4],t2);
switch(t10){
case C_make_character(105):
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=(
/* irregex-core.scm:988: join */
  f_11718(t5,C_fix(2))
);
/* irregex-core.scm:988: lp2 */
t28=t1;
t29=t11;
t30=t12;
t31=t4;
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;
case C_make_character(109):
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=(
/* irregex-core.scm:990: join */
  f_11718(t5,C_fix(4))
);
/* irregex-core.scm:990: lp2 */
t28=t1;
t29=t11;
t30=t12;
t31=t4;
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;
case C_make_character(120):
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=(
/* irregex-core.scm:992: join */
  f_11718(t5,C_fix(16))
);
/* irregex-core.scm:992: lp2 */
t28=t1;
t29=t11;
t30=t12;
t31=t4;
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;
case C_make_character(117):
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=(
/* irregex-core.scm:995: join */
  f_11718(t5,C_fix(32))
);
/* irregex-core.scm:995: lp2 */
t28=t1;
t29=t11;
t30=t12;
t31=t4;
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;
case C_make_character(45):
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:998: lp2 */
t28=t1;
t29=t11;
t30=t3;
t31=C_i_not(t4);
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;
case C_make_character(41):
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t13=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11871,a[2]=t7,a[3]=((C_word*)t0)[7],a[4]=t1,a[5]=t11,a[6]=t12,a[7]=t3,a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1000: collect */
t14=((C_word*)((C_word*)t0)[9])[1];
f_10569(t14,t13);
case C_make_character(58):
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t13=(
/* irregex-core.scm:1003: new-res */
  f_11727(C_a_i(&a,6),((C_word*)t7)[1],C_SCHEME_END_OF_LIST)
);
t14=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11902,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[7],a[5]=t1,a[6]=t11,a[7]=t12,a[8]=t3,a[9]=t13,tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:1004: collect */
t15=((C_word*)((C_word*)t0)[9])[1];
f_10569(t15,t14);
default:
/* irregex-core.scm:1006: chicken.base#error */
t11=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t11;
av2[1]=t1;
av2[2]=lf[159];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t11+1)))(4,av2);}}}}

/* join in lp2 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static C_word C_fcall f_11718(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;{}
if(C_truep(((C_word*)t0)[2])){
t2=lf[64];
t3=lf[64];
return(C_fixnum_and(((C_word*)t0)[3],C_fixnum_not(t1)));}
else{
t2=lf[63];
t3=lf[63];
return((C_truep(t1)?C_fixnum_or(((C_word*)t0)[3],t1):((C_word*)t0)[3]));}}

/* new-res in lp2 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static C_word C_fcall f_11727(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_stack_overflow_check;{}
t2=C_fixnum_and(((C_word*)t0)[2],C_fix(32));
t3=C_eqp(C_fix(32),t2);
t4=C_fixnum_and(((C_word*)t0)[3],C_fix(32));
t5=C_eqp(C_fix(32),t4);
t6=C_eqp(t3,t5);
return((C_truep(t6)?t1:(C_truep(t5)?C_a_i_cons(&a,2,lf[156],t1):C_a_i_cons(&a,2,lf[157],t1))));}

/* k11869 in lp2 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_11871,c,av);}
a=C_alloc(6);
t2=(
/* irregex-core.scm:1000: new-res */
  f_11727(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],t1)
);
/* irregex-core.scm:1000: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k11900 in lp2 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11902(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_11902,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[3]);
/* irregex-core.scm:1003: lp */
t4=((C_word*)((C_word*)t0)[4])[1];
f_10488(t4,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],t3);}

/* k11991 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_11993(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_11993,c,av);}
a=C_alloc(3);
t2=C_i_cdar(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
/* irregex-core.scm:1011: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_10488(t4,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t3,C_u_i_cdr(((C_word*)t0)[2]));}

/* a12007 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12008(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12008,c,av);}
a=C_alloc(9);
t4=C_fixnum_plus(t3,C_fix(1));
t5=C_fixnum_plus(t3,C_fix(1));
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12028,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t4,a[6]=t5,a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[4],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1019: collect */
t7=((C_word*)((C_word*)t0)[5])[1];
f_10569(t7,t6);}

/* k12026 in a12007 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12028(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12028,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1019: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12030 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12032(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12032,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_apply(4,av2);}}

/* k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_12051(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,6)))){
C_save_and_reclaim_args((void *)trf_12051,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* irregex-core.scm:1026: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12060,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[9],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1028: collect/single */
t3=((C_word*)((C_word*)t0)[10])[1];
f_10589(t3,t2);}}

/* k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12060(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_12060,c,av);}
a=C_alloc(15);
if(C_truep(C_i_nullp(t1))){
/* irregex-core.scm:1031: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[174];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
t2=C_i_car(t1);
t3=C_u_i_cdr(t1);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12076,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
t5=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[6],C_fix(1));
/* irregex-core.scm:1035: string-scan-char */
t6=lf[54];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
av2[3]=C_make_character(125);
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}

/* k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_12076,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12079,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12204,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[8],C_fix(1));
/* irregex-core.scm:1036: scheme#substring */
t5=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
av2[3]=t4;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k12077 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_12079,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12082,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:1038: scheme#string->number */
t3=*((C_word*)lf[85]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12080 in k12077 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12082(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_12082,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12085,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[3])))){
/* irregex-core.scm:1040: scheme#string->number */
t3=*((C_word*)lf[85]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_12085(2,av2);}}}

/* k12083 in k12080 in k12077 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_12085,c,av);}
a=C_alloc(12);
t2=C_i_not(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_12094,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,tmp=(C_word)a,a+=12,tmp);
if(C_truep(t2)){
t4=t3;
f_12094(t4,t2);}
else{
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[4])))){
t4=C_i_cadr(((C_word*)t0)[4]);
t5=C_i_equalp(lf[176],t4);
t6=C_i_not(t5);
t7=t3;
f_12094(t7,(C_truep(t6)?C_i_not(t1):C_SCHEME_FALSE));}
else{
t4=t3;
f_12094(t4,C_SCHEME_FALSE);}}}

/* k12092 in k12083 in k12080 in k12077 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_12094(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,0,6)))){
C_save_and_reclaim_args((void *)trf_12094,2,t0,t1);}
a=C_alloc(25);
if(C_truep(t1)){
/* irregex-core.scm:1046: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[175];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[3])))){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t4=C_a_i_list(&a,3,lf[134],((C_word*)t0)[5],((C_word*)t0)[6]);
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[7]);
/* irregex-core.scm:1048: lp */
t6=((C_word*)((C_word*)t0)[8])[1];
f_10488(t6,((C_word*)t0)[2],t2,t3,((C_word*)t0)[9],t5,((C_word*)t0)[10]);}
else{
if(C_truep(((C_word*)t0)[11])){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t4=C_a_i_list(&a,4,lf[133],((C_word*)t0)[5],((C_word*)t0)[11],((C_word*)t0)[6]);
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[7]);
/* irregex-core.scm:1050: lp */
t6=((C_word*)((C_word*)t0)[8])[1];
f_10488(t6,((C_word*)t0)[2],t2,t3,((C_word*)t0)[9],t5,((C_word*)t0)[10]);}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t4=C_a_i_list(&a,3,lf[135],((C_word*)t0)[5],((C_word*)t0)[6]);
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[7]);
/* irregex-core.scm:1052: lp */
t6=((C_word*)((C_word*)t0)[8])[1];
f_10488(t6,((C_word*)t0)[2],t2,t3,((C_word*)t0)[9],t5,((C_word*)t0)[10]);}}}}

/* k12202 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_12204,c,av);}
a=C_alloc(8);
t2=C_i_string_length(t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8974,a[2]=t1,a[3]=t2,a[4]=t4,a[5]=((C_word)li84),tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_8974(t6,((C_word*)t0)[2],C_fix(0),C_fix(0),C_SCHEME_END_OF_LIST);}

/* k12278 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12280,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[178],t1);
/* irregex-core.scm:1062: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12305 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12307(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12307,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1064: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12328 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12330,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[79],t1);
/* irregex-core.scm:1066: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12355 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12357,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1068: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12382 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12384(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12384,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1070: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12413 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12415,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1073: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12448 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12450(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12450,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1076: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12471 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12473,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[185],t1);
/* irregex-core.scm:1079: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12494 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12496,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[186],t1);
/* irregex-core.scm:1081: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12525 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12527(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_12527,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[187],t1);
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t2);
/* irregex-core.scm:1083: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_10488(t4,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t3,((C_word*)t0)[8]);}

/* k12548 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12550(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12550,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[187],t1);
/* irregex-core.scm:1086: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12571 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12573,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[80],t1);
/* irregex-core.scm:1088: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12594 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12596(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12596,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[188],t1);
/* irregex-core.scm:1090: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12617 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12619(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12619,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[183],t1);
/* irregex-core.scm:1093: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12640 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12642,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[184],t1);
/* irregex-core.scm:1095: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* a12652 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12653(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12653,c,av);}
a=C_alloc(9);
t4=C_fixnum_plus(t3,C_fix(1));
t5=C_fixnum_plus(t3,C_fix(1));
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12673,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t4,a[6]=t5,a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[4],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1099: collect */
t7=((C_word*)((C_word*)t0)[5])[1];
f_10569(t7,t6);}

/* k12671 in a12652 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12673(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12673,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1099: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12675 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12677(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12677,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_apply(4,av2);}}

/* k12699 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_12701(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,4)))){
C_save_and_reclaim_args((void *)trf_12701,2,t0,t1);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12704,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[8],C_fix(2));
/* irregex-core.scm:1106: string-scan-char */
t4=lf[54];{
C_word av2[5];
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12702 in k12699 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12704(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_12704,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12707,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t1)){
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[8],C_fix(3));
/* irregex-core.scm:1107: scheme#substring */
t4=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=t3;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_12707(2,av2);}}}

/* k12705 in k12702 in k12699 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_12707,c,av);}
a=C_alloc(10);
t2=C_fixnum_and(((C_word*)t0)[2],C_fix(2));
t3=C_eqp(C_fix(2),t2);
t4=(C_truep(t3)?lf[191]:lf[192]);
if(C_truep(C_i_not(((C_word*)t0)[3]))){
/* irregex-core.scm:1113: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[193];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=C_fixnum_plus(((C_word*)t0)[3],C_fix(1));
t6=C_fixnum_plus(((C_word*)t0)[3],C_fix(1));
t7=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12746,a[2]=t4,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[4],a[5]=t5,a[6]=t6,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:1115: scheme#string->symbol */
t8=*((C_word*)lf[84]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}

/* k12740 in k12744 in k12705 in k12702 in k12699 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12742,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1114: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12744 in k12705 in k12702 in k12699 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12746(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_12746,c,av);}
a=C_alloc(15);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12742,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1116: collect */
t4=((C_word*)((C_word*)t0)[9])[1];
f_10569(t4,t3);}

/* k12771 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12773(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_12773,c,av);}
a=C_alloc(18);
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2));
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12781,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=t4,a[10]=((C_word)li86),tmp=(C_word)a,a+=11,tmp));
t6=((C_word*)t4)[1];
f_12781(t6,((C_word*)t0)[8],t2);}

/* lp2 in k12771 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_12781(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,6)))){
C_save_and_reclaim_args((void *)trf_12781,3,t0,t1,t2);}
a=C_alloc(29);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
/* irregex-core.scm:1123: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,t1,t2,C_fixnum_plus(((C_word*)t0)[4],C_fix(2)),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}
else{
t3=C_i_string_ref(((C_word*)t0)[8],t2);
t4=C_eqp(C_make_character(92),t3);
if(C_truep(t4)){
t5=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
if(C_truep(C_i_integer_greater_or_equalp(t5,((C_word*)t0)[2]))){
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:1127: lp */
t7=((C_word*)((C_word*)t0)[3])[1];
f_10488(t7,t1,t6,C_fixnum_plus(((C_word*)t0)[4],C_fix(2)),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}
else{
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t7=C_i_string_ref(((C_word*)t0)[8],t6);
t8=C_eqp(C_make_character(69),t7);
if(C_truep(t8)){
t9=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t10=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t11=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12841,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t9,a[6]=t10,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1130: scheme#substring */
t12=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t12;
av2[1]=t11;
av2[2]=((C_word*)t0)[8];
av2[3]=C_fixnum_plus(((C_word*)t0)[4],C_fix(2));
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t12+1)))(5,av2);}}
else{
t9=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
/* irregex-core.scm:1132: lp2 */
t13=t1;
t14=t9;
t1=t13;
t2=t14;
goto loop;}}}
else{
t5=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:1134: lp2 */
t13=t1;
t14=t5;
t1=t13;
t2=t14;
goto loop;}}}

/* k12839 in lp2 in k12771 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12841,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:1129: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* a12883 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12884(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_12884,c,av);}
a=C_alloc(8);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12896,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1138: collect */
t5=((C_word*)((C_word*)t0)[5])[1];
f_10569(t5,t4);}

/* k12894 in a12883 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12896,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1138: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12903 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_12905,c,av);}
a=C_alloc(17);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=C_fixnum_and(((C_word*)t0)[3],C_fix(2));
t4=C_eqp(C_fix(2),t3);
t5=(C_truep(t4)?lf[191]:lf[192]);
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12929,a[2]=t5,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12933,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
t8=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[8],C_fix(1));
/* irregex-core.scm:1156: scheme#substring */
t9=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t7;
av2[2]=((C_word*)t0)[9];
av2[3]=t8;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* k12923 in k12927 in k12903 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12925,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1158: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k12927 in k12903 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_12929,c,av);}
a=C_alloc(14);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12925,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1157: collect */
t4=((C_word*)((C_word*)t0)[8])[1];
f_10569(t4,t3);}

/* k12931 in k12903 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12933(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12933,c,av);}
/* irregex-core.scm:1155: scheme#string->number */
t2=*((C_word*)lf[85]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12983 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_12985(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_12985,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1162: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k12999 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_13001,c,av);}
/* irregex-core.scm:1166: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,((C_word*)t0)[7]);}

/* k13063 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13065(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_13065,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[103],t1);
/* irregex-core.scm:1168: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_10488(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t2,((C_word*)t0)[7]);}

/* k13089 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_13091,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1171: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k13118 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13120(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_13120,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1174: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10488(t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t2,((C_word*)t0)[8]);}

/* k13146 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_13148,c,av);}
/* irregex-core.scm:1177: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,((C_word*)t0)[7]);}

/* k13167 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_13169,c,av);}
a=C_alloc(13);
t2=(C_truep(t1)?t1:C_a_i_fixnum_difference(&a,2,((C_word*)t0)[2],C_fix(1)));
t3=C_fixnum_plus(t2,C_fix(1));
t4=C_fixnum_plus(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13187,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t3,a[5]=t4,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1183: collect */
t6=((C_word*)((C_word*)t0)[7])[1];
f_10569(t6,t5);}

/* k13185 in k13167 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13187(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_13187,c,av);}
/* irregex-core.scm:1183: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10488(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,((C_word*)t0)[7]);}

/* chicken.irregex#string-parse-hex-escape in k7767 in k7542 in k7539 */
static void C_fcall f_13301(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,4)))){
C_save_and_reclaim_args((void *)trf_13301,4,t1,t2,t3,t4);}
a=C_alloc(21);
if(C_truep(C_fixnum_greater_or_equal_p(t3,t4))){
/* irregex-core.scm:1206: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[199];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=C_i_string_ref(t2,t3);
t6=C_eqp(C_make_character(123),t5);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13320,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t8=C_a_i_fixnum_plus(&a,2,t3,C_fix(1));
t9=C_a_i_list(&a,1,t8);
t10=C_i_string_length(t2);
t11=C_i_pairp(t9);
t12=(C_truep(t11)?C_u_i_car(t9):C_fix(0));
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8879,a[2]=t10,a[3]=t2,a[4]=t14,a[5]=((C_word)li91),tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_8879(t16,t7,t12);}
else{
t7=C_a_i_fixnum_plus(&a,2,t3,C_fix(1));
if(C_truep(C_fixnum_greater_or_equal_p(t7,t4))){
/* irregex-core.scm:1217: chicken.base#error */
t8=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t8;
av2[1]=t1;
av2[2]=lf[202];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13366,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t9=C_a_i_fixnum_plus(&a,2,t3,C_fix(2));
/* irregex-core.scm:1219: scheme#substring */
t10=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t10;
av2[1]=t8;
av2[2]=t2;
av2[3]=t3;
av2[4]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}}}}

/* k13318 in chicken.irregex#string-parse-hex-escape in k7767 in k7542 in k7539 */
static void C_ccall f_13320(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_13320,c,av);}
a=C_alloc(9);
if(C_truep(C_i_not(t1))){
/* irregex-core.scm:1210: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[200];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13332,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
/* irregex-core.scm:1211: scheme#substring */
t4=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=t3;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k13330 in k13318 in chicken.irregex#string-parse-hex-escape in k7767 in k7542 in k7539 */
static void C_ccall f_13332(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13332,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13335,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1212: scheme#string->number */
t3=*((C_word*)lf[85]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=C_fix(16);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k13333 in k13330 in k13318 in chicken.irregex#string-parse-hex-escape in k7767 in k7542 in k7539 */
static void C_ccall f_13335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_13335,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_make_character(C_unfix(t1));
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list2(&a,2,t2,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* irregex-core.scm:1215: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[201];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k13364 in chicken.irregex#string-parse-hex-escape in k7767 in k7542 in k7539 */
static void C_ccall f_13366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13366,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13369,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1220: scheme#string->number */
t3=*((C_word*)lf[85]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=C_fix(16);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k13367 in k13364 in chicken.irregex#string-parse-hex-escape in k7767 in k7542 in k7539 */
static void C_ccall f_13369(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_13369,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_make_character(C_unfix(t1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2));
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list2(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* irregex-core.scm:1223: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[203];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_13410(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,0,5)))){
C_save_and_reclaim_args((void *)trf_13410,5,t0,t1,t2,t3,t4);}
a=C_alloc(25);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
/* irregex-core.scm:1231: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word av2[6];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[161];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
av2[5]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}
else{
t5=C_i_string_ref(((C_word*)t0)[3],t2);
switch(t5){
case C_make_character(93):
t6=C_i_vector_length(t4);
t7=C_eqp(t6,C_fix(0));
if(C_truep(t7)){
t8=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13445,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t8,tmp=(C_word)a,a+=5,tmp);
t10=C_a_i_cons(&a,2,C_make_character(93),C_make_character(93));
t11=C_a_i_vector1(&a,1,t10);
/* irregex-core.scm:3809: cset-union */
t12=lf[162];{
C_word av2[4];
av2[0]=t12;
av2[1]=t9;
av2[2]=t4;
av2[3]=t11;
f_27092(4,av2);}}
else{
t8=C_fixnum_and(((C_word*)t0)[5],C_fix(2));
t9=C_eqp(C_fix(2),t8);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13455,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t9)){
/* irregex-core.scm:1239: cset-case-insensitive */
f_27619(t10,t4);}
else{
t11=t10;{
C_word av2[2];
av2[0]=t11;
av2[1]=t4;
f_13455(2,av2);}}}
case C_make_character(45):
t6=C_eqp(t2,((C_word*)t0)[7]);
t7=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_13483,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t5,a[6]=t4,a[7]=t3,a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[2],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
if(C_truep(t6)){
t8=t7;
f_13483(t8,t6);}
else{
t8=C_fixnum_plus(((C_word*)t0)[7],C_fix(1));
t9=C_eqp(t2,t8);
t10=(C_truep(t9)?C_eqp(C_make_character(94),C_i_string_ref(((C_word*)t0)[3],((C_word*)t0)[7])):C_SCHEME_FALSE);
if(C_truep(t10)){
t11=t7;
f_13483(t11,t10);}
else{
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=t7;
f_13483(t12,C_eqp(C_make_character(93),C_i_string_ref(((C_word*)t0)[3],t11)));}}
case C_make_character(91):
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t7=C_i_string_ref(((C_word*)t0)[3],t6);
t8=C_eqp(C_make_character(94),t7);
t9=(C_truep(t8)?C_a_i_fixnum_plus(&a,2,t2,C_fix(2)):C_a_i_fixnum_plus(&a,2,t2,C_fix(1)));
t10=C_i_string_ref(((C_word*)t0)[3],t9);
t11=C_eqp(t10,C_make_character(58));
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13685,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t4,a[6]=t8,a[7]=t9,tmp=(C_word)a,a+=8,tmp);
t13=C_a_i_fixnum_plus(&a,2,t9,C_fix(1));
/* irregex-core.scm:1273: string-scan-char */
t14=lf[54];{
C_word av2[5];
av2[0]=t14;
av2[1]=t12;
av2[2]=((C_word*)t0)[3];
av2[3]=C_make_character(58);
av2[4]=t13;
((C_proc)(void*)(*((C_word*)t14+1)))(5,av2);}}
else{
t12=C_eqp(t10,C_make_character(61));
t13=(C_truep(t12)?t12:C_eqp(t10,C_make_character(46)));
if(C_truep(t13)){
/* irregex-core.scm:1282: chicken.base#error */
t14=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t14;
av2[1]=t1;
av2[2]=lf[173];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}
else{
t14=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t15=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13768,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t14,tmp=(C_word)a,a+=5,tmp);
t16=C_a_i_cons(&a,2,C_make_character(91),C_make_character(91));
t17=C_a_i_vector1(&a,1,t16);
/* irregex-core.scm:3809: cset-union */
t18=lf[162];{
C_word av2[4];
av2[0]=t18;
av2[1]=t15;
av2[2]=t4;
av2[3]=t17;
f_27092(4,av2);}}}
case C_make_character(92):
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t7=C_i_string_ref(((C_word*)t0)[3],t6);
t8=C_eqp(t7,C_make_character(100));
t9=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13807,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t4,a[6]=t7,a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[2],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t8)){
t10=t9;
f_13807(t10,t8);}
else{
t10=C_eqp(t7,C_make_character(68));
if(C_truep(t10)){
t11=t9;
f_13807(t11,t10);}
else{
t11=C_eqp(t7,C_make_character(115));
if(C_truep(t11)){
t12=t9;
f_13807(t12,t11);}
else{
t12=C_eqp(t7,C_make_character(83));
if(C_truep(t12)){
t13=t9;
f_13807(t13,t12);}
else{
t13=C_eqp(t7,C_make_character(119));
t14=t9;
f_13807(t14,(C_truep(t13)?t13:C_eqp(t7,C_make_character(87))));}}}}
default:
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13924,a[2]=t5,a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=t4,a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)t0)[8])){
t7=C_fix(C_character_code(t5));
t8=t6;
f_13924(t8,C_and(C_fixnum_less_or_equal_p(C_fix(128),t7),C_fixnum_less_or_equal_p(t7,C_fix(255))));}
else{
t7=t6;
f_13924(t7,C_SCHEME_FALSE);}}}}

/* k13443 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13445(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13445,c,av);}
/* irregex-core.scm:1236: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_make_character(93),t1);}

/* k13453 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13455(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13455,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13462,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
/* irregex-core.scm:1240: cset-complement */
f_27609(t2,t1);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
f_13462(2,av2);}}}

/* k13460 in k13453 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_13462,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26949,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26951,a[2]=((C_word)li78),tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26969,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3758: scheme#vector->list */
t5=*((C_word*)lf[163]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_13483(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(30,0,4)))){
C_save_and_reclaim_args((void *)trf_13483,2,t0,t1);}
a=C_alloc(30);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13493,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=C_a_i_cons(&a,2,((C_word*)t0)[5],((C_word*)t0)[5]);
t5=C_a_i_vector1(&a,1,t4);
/* irregex-core.scm:3809: cset-union */
t6=lf[162];{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=t5;
f_27092(4,av2);}}
else{
if(C_truep(C_i_not(((C_word*)t0)[7]))){
/* irregex-core.scm:1249: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[3];
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[166];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_i_string_ref(((C_word*)t0)[8],t2);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13510,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[6],a[5]=((C_word)li79),tmp=(C_word)a,a+=6,tmp);
t5=C_eqp(C_make_character(92),t3);
t6=(C_truep(t5)?C_i_assq(t3,lf[168]):C_SCHEME_FALSE);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13538,a[2]=((C_word*)t0)[4],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t6)){
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13539,a[2]=((C_word*)t0)[2],a[3]=((C_word)li80),tmp=(C_word)a,a+=4,tmp);
t9=(
/* irregex-core.scm:1257: g1884 */
  f_13539(C_a_i(&a,6),t8,t6)
);{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=t4;
av2[3]=t9;
C_apply(4,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13560,a[2]=((C_word*)t0)[2],a[3]=t7,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],a[6]=t3,a[7]=((C_word*)t0)[4],a[8]=t4,a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
t9=C_eqp(C_make_character(92),t3);
if(C_truep(t9)){
t10=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2));
t11=t8;
f_13560(t11,C_eqp(C_i_string_ref(((C_word*)t0)[8],t10),C_make_character(120)));}
else{
t10=t8;
f_13560(t10,C_SCHEME_FALSE);}}}}}

/* k13491 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13493(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13493,c,av);}
/* irregex-core.scm:1247: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* a13509 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13510(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_13510,c,av);}
a=C_alloc(10);
if(C_truep(C_i_char_lessp(t2,((C_word*)t0)[2]))){
/* irregex-core.scm:1255: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[167];
av2[3]=((C_word*)t0)[2];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13527,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_a_i_cons(&a,2,((C_word*)t0)[2],t2);
t6=C_a_i_vector1(&a,1,t5);
/* irregex-core.scm:1256: cset-union */
t7=lf[162];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
av2[3]=t6;
f_27092(4,av2);}}}

/* k13525 in a13509 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13527(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13527,c,av);}
/* irregex-core.scm:1256: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_FALSE,t1);}

/* k13536 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13538(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13538,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_apply(4,av2);}}

/* g1884 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static C_word C_fcall f_13539(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;{}
t2=C_i_cdr(t1);
t3=C_fixnum_plus(((C_word*)t0)[2],C_fix(3));
return(C_a_i_list2(&a,2,t2,t3));}

/* k13558 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_13560(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_13560,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(3));
/* irregex-core.scm:1262: string-parse-hex-escape */
f_13301(((C_word*)t0)[3],((C_word*)t0)[4],t2,((C_word*)t0)[5]);}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13572,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[9])){
t3=C_fix(C_character_code(((C_word*)t0)[6]));
t4=t2;
f_13572(t4,C_and(C_fixnum_less_or_equal_p(C_fix(128),t3),C_fixnum_less_or_equal_p(t3,C_fix(255))));}
else{
t3=t2;
f_13572(t3,C_SCHEME_FALSE);}}}

/* k13570 in k13558 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_13572(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_13572,2,t0,t1);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_fix(C_character_code(((C_word*)t0)[2]));
t3=C_i_vector_ref(lf[170],t2);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13582,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t5=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:1265: utf8-string-ref */
f_14035(t4,((C_word*)t0)[6],t5,t3);}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(2));
t3=C_a_i_list2(&a,2,((C_word*)t0)[2],t2);{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=t3;
C_apply(4,av2);}}}

/* k13580 in k13570 in k13558 in k13481 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13582(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_13582,c,av);}
a=C_alloc(6);
t2=C_fixnum_plus(C_fixnum_plus(((C_word*)t0)[2],C_fix(1)),((C_word*)t0)[3]);
t3=C_a_i_list2(&a,2,t1,t2);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=t3;
C_apply(4,av2);}}

/* k13683 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13685(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_13685,c,av);}
a=C_alloc(9);
t2=C_i_not(t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13694,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t2)){
t4=t3;
f_13694(t4,t2);}
else{
t4=C_fixnum_plus(t1,C_fix(1));
t5=C_i_string_ref(((C_word*)t0)[3],t4);
t6=t3;
f_13694(t6,C_i_not(C_eqp(C_make_character(93),t5)));}}

/* k13692 in k13683 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_13694(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,4)))){
C_save_and_reclaim_args((void *)trf_13694,2,t0,t1);}
a=C_alloc(18);
if(C_truep(t1)){
/* irregex-core.scm:1275: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[171];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13700,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13720,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13724,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[8],C_fix(1));
/* irregex-core.scm:1278: scheme#substring */
t6=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
av2[3]=t5;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}

/* k13698 in k13692 in k13683 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13700(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_13700,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13703,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
/* irregex-core.scm:1279: cset-complement */
f_27609(t2,t1);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
f_13703(2,av2);}}}

/* k13701 in k13698 in k13692 in k13683 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13703(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_13703,c,av);}
a=C_alloc(10);
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13713,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1280: cset-union */
t4=lf[162];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=t1;
f_27092(4,av2);}}

/* k13711 in k13701 in k13698 in k13692 in k13683 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13713(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13713,c,av);}
/* irregex-core.scm:1280: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_FALSE,t1);}

/* k13718 in k13692 in k13683 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13720,c,av);}
/* irregex-core.scm:1276: sre->cset */
f_26504(((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST);}

/* k13722 in k13692 in k13683 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13724(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13724,c,av);}
/* irregex-core.scm:1277: scheme#string->symbol */
t2=*((C_word*)lf[84]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k13766 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13768,c,av);}
/* irregex-core.scm:1284: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_make_character(91),t1);}

/* k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_13807(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,4)))){
C_save_and_reclaim_args((void *)trf_13807,2,t0,t1);}
a=C_alloc(20);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13817,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13821,a[2]=t3,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13825,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=C_a_i_string(&a,2,C_make_character(92),((C_word*)t0)[6]);
/* irregex-core.scm:1291: string->sre */
t7=*((C_word*)lf[102]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t5;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t2=C_eqp(((C_word*)t0)[6],C_make_character(120));
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13840,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word)li81),tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13852,a[2]=((C_word*)t0)[4],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2));
/* irregex-core.scm:1296: string-parse-hex-escape */
f_13301(t4,((C_word*)t0)[7],t5,((C_word*)t0)[8]);}
else{
t3=C_i_assq(((C_word*)t0)[6],lf[168]);
t4=(C_truep(t3)?C_i_cdr(t3):((C_word*)t0)[6]);
t5=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2));
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13871,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t5,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t7=C_a_i_cons(&a,2,t4,t4);
t8=C_a_i_vector1(&a,1,t7);
/* irregex-core.scm:3809: cset-union */
t9=lf[162];{
C_word av2[4];
av2[0]=t9;
av2[1]=t6;
av2[2]=((C_word*)t0)[5];
av2[3]=t8;
f_27092(4,av2);}}}}

/* k13815 in k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13817(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13817,c,av);}
/* irregex-core.scm:1289: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_FALSE,t1);}

/* k13819 in k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13821(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13821,c,av);}
/* irregex-core.scm:1290: cset-union */
t2=lf[162];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
f_27092(4,av2);}}

/* k13823 in k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13825,c,av);}
/* irregex-core.scm:1291: sre->cset */
f_26504(((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST);}

/* a13839 in k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_13840,c,av);}
a=C_alloc(11);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13848,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t5=C_a_i_cons(&a,2,t2,t2);
t6=C_a_i_vector1(&a,1,t5);
/* irregex-core.scm:3809: cset-union */
t7=lf[162];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
av2[3]=t6;
f_27092(4,av2);}}

/* k13846 in a13839 in k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13848(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13848,c,av);}
/* irregex-core.scm:1295: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* k13850 in k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13852,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_apply(4,av2);}}

/* k13869 in k13805 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13871,c,av);}
/* irregex-core.scm:1300: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* k13922 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_13924(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,4)))){
C_save_and_reclaim_args((void *)trf_13924,2,t0,t1);}
a=C_alloc(16);
if(C_truep(t1)){
t2=C_fix(C_character_code(((C_word*)t0)[2]));
t3=C_i_vector_ref(lf[170],t2);
t4=C_fixnum_plus(((C_word*)t0)[3],t3);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13938,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t4,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[3],a[8]=t3,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1305: utf8-string-ref */
f_14035(t5,((C_word*)t0)[7],((C_word*)t0)[3],t3);}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13956,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t2,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t4=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[2]);
t5=C_a_i_vector1(&a,1,t4);
/* irregex-core.scm:3809: cset-union */
t6=lf[162];{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=t5;
f_27092(4,av2);}}}

/* k13936 in k13922 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_13938,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13942,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13946,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1306: utf8-string-ref */
f_14035(t3,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k13940 in k13936 in k13922 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13942,c,av);}
/* irregex-core.scm:1304: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* k13944 in k13936 in k13922 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13946(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13946,c,av);}
a=C_alloc(5);
t2=C_a_i_cons(&a,2,t1,t1);
t3=C_a_i_vector1(&a,1,t2);
/* irregex-core.scm:3809: cset-union */
t4=lf[162];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t3;
f_27092(4,av2);}}

/* k13954 in k13922 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_13956(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13956,c,av);}
/* irregex-core.scm:1307: go */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13410(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* chicken.irregex#high-char? in k7767 in k7542 in k7539 */
static void C_ccall f_14014(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14014,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fixnum_less_or_equal_p(C_fix(128),C_fix(C_character_code(t2)));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.irregex#utf8-string-ref in k7767 in k7542 in k7539 */
static void C_fcall f_14035(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_14035,4,t1,t2,t3,t4);}
a=C_alloc(9);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14038,a[2]=t2,a[3]=((C_word)li94),tmp=(C_word)a,a+=4,tmp);
switch(t4){
case C_fix(1):
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_i_string_ref(t2,t3);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}
case C_fix(2):
t6=(
/* irregex-core.scm:1368: byte */
  f_14038(t5,t3)
);
t7=C_fixnum_and(t6,C_fix(31));
t8=C_fixnum_shift_left(t7,C_fix(6));
t9=(
/* irregex-core.scm:1369: byte */
  f_14038(t5,C_fixnum_plus(t3,C_fix(1)))
);
t10=C_fixnum_and(t9,C_fix(63));
t11=C_a_i_fixnum_plus(&a,2,t8,t10);
t12=t1;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_make_character(C_unfix(t11));
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}
case C_fix(3):
t6=(
/* irregex-core.scm:1372: byte */
  f_14038(t5,t3)
);
t7=C_fixnum_and(t6,C_fix(15));
t8=C_fixnum_shift_left(t7,C_fix(12));
t9=(
/* irregex-core.scm:1373: byte */
  f_14038(t5,C_fixnum_plus(t3,C_fix(1)))
);
t10=C_fixnum_and(t9,C_fix(63));
t11=C_fixnum_shift_left(t10,C_fix(6));
t12=(
/* irregex-core.scm:1374: byte */
  f_14038(t5,C_fixnum_plus(t3,C_fix(2)))
);
t13=C_fixnum_and(t12,C_fix(63));
t14=C_fixnum_plus(C_fixnum_plus(t8,t11),t13);
t15=t1;{
C_word av2[2];
av2[0]=t15;
av2[1]=C_make_character(C_unfix(t14));
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}
case C_fix(4):
t6=(
/* irregex-core.scm:1377: byte */
  f_14038(t5,t3)
);
t7=C_fixnum_and(t6,C_fix(7));
t8=C_fixnum_shift_left(t7,C_fix(18));
t9=(
/* irregex-core.scm:1378: byte */
  f_14038(t5,C_fixnum_plus(t3,C_fix(1)))
);
t10=C_fixnum_and(t9,C_fix(63));
t11=C_fixnum_shift_left(t10,C_fix(12));
t12=(
/* irregex-core.scm:1379: byte */
  f_14038(t5,C_fixnum_plus(t3,C_fix(2)))
);
t13=C_fixnum_and(t12,C_fix(63));
t14=C_fixnum_shift_left(t13,C_fix(6));
t15=(
/* irregex-core.scm:1380: byte */
  f_14038(t5,C_fixnum_plus(t3,C_fix(3)))
);
t16=C_fixnum_and(t15,C_fix(63));
t17=C_fixnum_plus(C_fixnum_plus(C_fixnum_plus(t8,t11),t14),t16);
t18=t1;{
C_word av2[2];
av2[0]=t18;
av2[1]=C_make_character(C_unfix(t17));
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}
default:
/* irregex-core.scm:1382: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word av2[6];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[205];
av2[3]=t2;
av2[4]=t4;
av2[5]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(6,av2);}}}

/* byte in chicken.irregex#utf8-string-ref in k7767 in k7542 in k7539 */
static C_word C_fcall f_14038(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
t2=C_i_string_ref(((C_word*)t0)[2],t1);
return(C_fix(C_character_code(t2)));}

/* lp in collect/single in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_14230(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_14230,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,C_fix(0));
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_string_ref(((C_word*)t0)[2],t2);
t5=C_fix(C_character_code(t4));
t6=C_fixnum_lessp(t5,C_fix(128));
t7=(C_truep(t6)?t6:C_fixnum_greater_or_equal_p(t5,C_fix(192)));
if(C_truep(t7)){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_a_i_fixnum_difference(&a,2,t2,C_fix(1));
/* irregex-core.scm:1391: lp */
t10=t1;
t11=t8;
t1=t10;
t2=t11;
goto loop;}}}

/* chicken.irregex#utf8-lowest-digit-of-length in k7767 in k7542 in k7539 */
static void C_fcall f_14268(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_14268,2,t1,t2);}
switch(t2){
case C_fix(1):
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
case C_fix(2):
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_fix(192);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
case C_fix(3):
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_fix(224);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
case C_fix(4):
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_fix(240);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
default:
/* irregex-core.scm:1396: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[207];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* chicken.irregex#char->utf8-list in k7767 in k7542 in k7539 */
static void C_fcall f_14344(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_14344,2,t1,t2);}
a=C_alloc(12);
t3=C_fix(C_character_code(t2));
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(127)))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_a_i_list1(&a,1,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(2047)))){
t4=C_fixnum_shift_right(t3,C_fix(6));
t5=C_fixnum_or(C_fix(192),t4);
t6=C_fixnum_and(t3,C_fix(63));
t7=C_fixnum_or(C_fix(128),t6);
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_a_i_list2(&a,2,t5,t7);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(65535)))){
t4=C_fixnum_shift_right(t3,C_fix(12));
t5=C_fixnum_or(C_fix(224),t4);
t6=C_fixnum_shift_right(t3,C_fix(6));
t7=C_fixnum_and(t6,C_fix(63));
t8=C_fixnum_or(C_fix(128),t7);
t9=C_fixnum_and(t3,C_fix(63));
t10=C_fixnum_or(C_fix(128),t9);
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=C_a_i_list3(&a,3,t5,t8,t10);
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(2097151)))){
t4=C_fixnum_shift_right(t3,C_fix(18));
t5=C_fixnum_or(C_fix(240),t4);
t6=C_fixnum_shift_right(t3,C_fix(12));
t7=C_fixnum_and(t6,C_fix(63));
t8=C_fixnum_or(C_fix(128),t7);
t9=C_fixnum_shift_right(t3,C_fix(6));
t10=C_fixnum_and(t9,C_fix(63));
t11=C_fixnum_or(C_fix(128),t10);
t12=C_fixnum_and(t3,C_fix(63));
t13=C_fixnum_or(C_fix(128),t12);
t14=t1;{
C_word av2[2];
av2[0]=t14;
av2[1]=C_a_i_list4(&a,4,t5,t8,t11,t13);
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
/* irregex-core.scm:1419: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[209];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}}}}

/* k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_14485,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_14488,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1423: char->utf8-list */
f_14344(t2,((C_word*)t0)[8]);}

/* k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14488(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,4)))){
C_save_and_reclaim((void *)f_14488,c,av);}
a=C_alloc(36);
t2=C_eqp(C_u_i_length(((C_word*)t0)[2]),C_u_i_length(t1));
if(C_truep(C_i_not(t2))){
t3=C_i_length(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15047,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t5=C_i_car(((C_word*)t0)[2]);
t6=C_make_character(C_unfix(t5));
t7=C_u_i_car(((C_word*)t0)[2]);
t8=C_fixnum_less_or_equal_p(t7,C_fix(127));
t9=(C_truep(t8)?C_a_i_list(&a,3,lf[52],t6,C_make_character(127)):C_a_i_list(&a,3,lf[52],t6,C_make_character(255)));
t10=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t11=t10;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=((C_word*)t12)[1];
t14=C_u_i_cdr(((C_word*)t0)[2]);
t15=C_i_check_list_2(t14,lf[211]);
t16=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15327,a[2]=t9,a[3]=t3,a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t17=C_SCHEME_UNDEFINED;
t18=(*a=C_VECTOR_TYPE|1,a[1]=t17,tmp=(C_word)a,a+=2,tmp);
t19=C_set_block_item(t18,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15329,a[2]=t12,a[3]=t18,a[4]=t13,a[5]=((C_word)li111),tmp=(C_word)a,a+=6,tmp));
t20=((C_word*)t18)[1];
f_15329(t20,t16,t14);}
else{
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14514,a[2]=t4,a[3]=((C_word)li113),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_14514(t6,((C_word*)t0)[8],((C_word*)t0)[2],t1);}}

/* k14507 in k15045 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_14509,c,av);}
a=C_alloc(12);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
t3=(
/* irregex-core.scm:1425: sre-alternate */
  f_18226(C_a_i(&a,3),t2)
);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[3]);
/* irregex-core.scm:1539: lp */
t5=((C_word*)((C_word*)t0)[4])[1];
f_15485(t5,((C_word*)t0)[5],((C_word*)t0)[6],t4,((C_word*)t0)[7]);}

/* lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_14514(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_14514,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_car(t2);
t5=C_i_car(t3);
t6=C_eqp(t4,t5);
if(C_truep(t6)){
t7=C_u_i_car(t2);
t8=C_make_character(C_unfix(t7));
if(C_truep(C_i_nullp(C_u_i_cdr(t2)))){
t9=C_a_i_cons(&a,2,t8,C_SCHEME_END_OF_LIST);
/* irregex-core.scm:1430: sre-sequence */
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=(
/* irregex-core.scm:1430: sre-sequence */
  f_18203(C_a_i(&a,3),t9)
);
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14546,a[2]=t8,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1433: lp */
t12=t9;
t13=C_u_i_cdr(t2);
t14=C_u_i_cdr(t3);
t1=t12;
t2=t13;
t3=t14;
goto loop;}}
else{
t7=C_fixnum_plus(C_u_i_car(t2),C_fix(1));
t8=C_u_i_car(t3);
t9=C_eqp(t7,t8);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14571,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1435: unicode-range-up-from */
f_14758(t10,t2);}
else{
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14586,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1438: unicode-range-up-from */
f_14758(t10,t2);}}}

/* k14544 in lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14546(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14546,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t2);
/* irregex-core.scm:1430: sre-sequence */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(
/* irregex-core.scm:1430: sre-sequence */
  f_18203(C_a_i(&a,3),t3)
);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k14569 in lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14571(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14571,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14575,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1436: unicode-range-up-to */
f_14897(t2,((C_word*)t0)[3]);}

/* k14573 in k14569 in lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14575(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14575,c,av);}
a=C_alloc(9);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1435: sre-alternate */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* irregex-core.scm:1435: sre-alternate */
  f_18226(C_a_i(&a,3),t2)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14584 in lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,3)))){
C_save_and_reclaim((void *)f_14586,c,av);}
a=C_alloc(28);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_fixnum_plus(t2,C_fix(1));
t4=C_make_character(C_unfix(t3));
t5=C_i_car(((C_word*)t0)[3]);
t6=C_fixnum_difference(t5,C_fix(1));
t7=C_make_character(C_unfix(t6));
t8=(C_truep(C_u_i_char_equalp(t4,t7))?t4:C_a_i_list(&a,3,lf[52],t4,t7));
t9=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t10=t9;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=((C_word*)t11)[1];
t13=C_u_i_cdr(((C_word*)t0)[2]);
t14=C_i_check_list_2(t13,lf[211]);
t15=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15418,a[2]=t8,a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15420,a[2]=t11,a[3]=t17,a[4]=t12,a[5]=((C_word)li112),tmp=(C_word)a,a+=6,tmp));
t19=((C_word*)t17)[1];
f_15420(t19,t15,t13);}

/* k14592 in k15416 in k14584 in lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_14594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_14594,c,av);}
a=C_alloc(12);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],t1);
/* irregex-core.scm:1438: sre-alternate */
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* irregex-core.scm:1438: sre-alternate */
  f_18226(C_a_i(&a,3),t2)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.irregex#unicode-range-helper in k7767 in k7542 in k7539 */
static void C_fcall f_14620(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(28,0,3)))){
C_save_and_reclaim_args((void *)trf_14620,5,t1,t2,t3,t4,t5);}
a=C_alloc(28);
if(C_truep(C_i_nullp(t3))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_i_cdr(t3);
t7=C_u_i_car(t3);
t8=C_a_i_cons(&a,2,t7,t4);
t9=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14650,a[2]=t5,a[3]=t1,a[4]=t2,a[5]=t6,a[6]=t8,tmp=(C_word)a,a+=7,tmp);
t10=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t11=t10;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=((C_word*)t12)[1];
t14=C_i_check_list_2(t4,lf[211]);
t15=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14660,a[2]=t3,a[3]=t9,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14722,a[2]=t12,a[3]=t17,a[4]=t13,a[5]=((C_word)li99),tmp=(C_word)a,a+=6,tmp));
t19=((C_word*)t17)[1];
f_14722(t19,t15,t4);}}

/* k14648 in chicken.irregex#unicode-range-helper in k7767 in k7542 in k7539 */
static void C_ccall f_14650(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_14650,c,av);}
a=C_alloc(6);
t2=(
/* irregex-core.scm:1449: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[2]);
/* irregex-core.scm:1445: unicode-range-helper */
f_14620(((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t3);}

/* k14658 in chicken.irregex#unicode-range-helper in k7767 in k7542 in k7539 */
static void C_ccall f_14660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_14660,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14668,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1451: one */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k14666 in k14658 in chicken.irregex#unicode-range-helper in k7767 in k7542 in k7539 */
static void C_ccall f_14668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_14668,c,av);}
a=C_alloc(18);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_u_i_cdr(((C_word*)t0)[2]);
t7=C_i_check_list_2(t6,lf[211]);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14684,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14686,a[2]=t4,a[3]=t10,a[4]=t5,a[5]=((C_word)li98),tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_14686(t12,t8,t6);}

/* k14682 in k14666 in k14658 in chicken.irregex#unicode-range-helper in k7767 in k7542 in k7539 */
static void C_ccall f_14684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_14684,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1450: ##sys#append */
t3=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* map-loop2077 in k14666 in k14658 in chicken.irregex#unicode-range-helper in k7767 in k7542 in k7539 */
static void C_fcall f_14686(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_14686,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=C_a_i_list(&a,3,lf[52],C_make_character(128),C_make_character(255));
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* map-loop2051 in chicken.irregex#unicode-range-helper in k7767 in k7542 in k7539 */
static void C_fcall f_14722(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_14722,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_make_character(C_unfix(t3));
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_fcall f_14758(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_14758,2,t1,t2);}
a=C_alloc(13);
t3=C_i_car(t2);
t4=C_make_character(C_unfix(t3));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14778,a[2]=t4,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14780,a[2]=t2,a[3]=((C_word)li101),tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14889,a[2]=t5,a[3]=t6,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1465: ##sys#fast-reverse */
t8=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=C_u_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}

/* k14776 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_14778,c,av);}
a=C_alloc(12);
t2=(
/* irregex-core.scm:1461: sre-alternate */
  f_18226(C_a_i(&a,3),t1)
);
t3=C_a_i_list2(&a,2,((C_word*)t0)[2],t2);
/* irregex-core.scm:1459: sre-sequence */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(
/* irregex-core.scm:1459: sre-sequence */
  f_18203(C_a_i(&a,3),t3)
);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a14779 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14780,c,av);}
a=C_alloc(9);
t3=C_i_car(((C_word*)t0)[2]);
t4=C_fixnum_plus(t3,C_fix(1));
t5=C_make_character(C_unfix(t4));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_list(&a,3,lf[52],t5,C_make_character(255));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k14810 in k14887 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14812(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_14812,c,av);}
a=C_alloc(6);
t2=(
/* irregex-core.scm:1468: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
t3=C_a_i_list1(&a,1,t2);
/* irregex-core.scm:1462: unicode-range-helper */
f_14620(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_END_OF_LIST,t3);}

/* k14817 in k14887 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_14819,c,av);}
a=C_alloc(12);
t2=C_i_check_list_2(t1,lf[211]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14843,a[2]=((C_word*)t0)[4],a[3]=t5,a[4]=((C_word*)t0)[5],a[5]=((C_word)li102),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_14843(t7,t3,t1);}

/* k14823 in k14817 in k14887 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14825,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14841,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1471: last */
f_9262(t2,((C_word*)t0)[3]);}

/* k14839 in k14823 in k14817 in k14887 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_14841,c,av);}
a=C_alloc(12);
t2=C_make_character(C_unfix(t1));
t3=C_a_i_list(&a,3,lf[52],t2,C_make_character(255));
t4=C_a_i_list(&a,1,t3);
/* irregex-core.scm:1469: scheme#append */
t5=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* map-loop2113 in k14817 in k14887 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_fcall f_14843(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_14843,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_make_character(C_unfix(t3));
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k14881 in k14887 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14883(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14883,c,av);}
/* irregex-core.scm:1470: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_cdr(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k14887 in chicken.irregex#unicode-range-up-from in k7767 in k7542 in k7539 */
static void C_ccall f_14889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_14889,c,av);}
a=C_alloc(19);
t2=C_i_cdr(t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14812,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14819,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=t6,a[5]=t7,tmp=(C_word)a,a+=6,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14883,a[2]=t8,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1470: ##sys#fast-reverse */
t10=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t10;
av2[1]=t9;
av2[2]=C_u_i_cdr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}

/* chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_fcall f_14897(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_14897,2,t1,t2);}
a=C_alloc(13);
t3=C_i_car(t2);
t4=C_make_character(C_unfix(t3));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14917,a[2]=t4,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14919,a[2]=t2,a[3]=((C_word)li104),tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15028,a[2]=t5,a[3]=t6,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1481: ##sys#fast-reverse */
t8=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=C_u_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}

/* k14915 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_14917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_14917,c,av);}
a=C_alloc(12);
t2=(
/* irregex-core.scm:1477: sre-alternate */
  f_18226(C_a_i(&a,3),t1)
);
t3=C_a_i_list2(&a,2,((C_word*)t0)[2],t2);
/* irregex-core.scm:1475: sre-sequence */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(
/* irregex-core.scm:1475: sre-sequence */
  f_18203(C_a_i(&a,3),t3)
);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a14918 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_14919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14919,c,av);}
a=C_alloc(9);
t3=C_i_car(((C_word*)t0)[2]);
t4=C_fixnum_difference(t3,C_fix(1));
t5=C_make_character(C_unfix(t4));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_list(&a,3,lf[52],C_make_character(128),t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k14949 in k15026 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_14951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_14951,c,av);}
a=C_alloc(6);
t2=(
/* irregex-core.scm:1484: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
t3=C_a_i_list1(&a,1,t2);
/* irregex-core.scm:1478: unicode-range-helper */
f_14620(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_END_OF_LIST,t3);}

/* k14956 in k15026 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_14958(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_14958,c,av);}
a=C_alloc(12);
t2=C_i_check_list_2(t1,lf[211]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14964,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14982,a[2]=((C_word*)t0)[4],a[3]=t5,a[4]=((C_word*)t0)[5],a[5]=((C_word)li105),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_14982(t7,t3,t1);}

/* k14962 in k14956 in k15026 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_14964(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14964,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14980,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1488: last */
f_9262(t2,((C_word*)t0)[3]);}

/* k14978 in k14962 in k14956 in k15026 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_14980(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_14980,c,av);}
a=C_alloc(12);
t2=C_make_character(C_unfix(t1));
t3=C_a_i_list(&a,3,lf[52],C_make_character(128),t2);
t4=C_a_i_list(&a,1,t3);
/* irregex-core.scm:1485: scheme#append */
t5=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* map-loop2148 in k14956 in k15026 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_fcall f_14982(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_14982,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_make_character(C_unfix(t3));
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15020 in k15026 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_15022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15022,c,av);}
/* irregex-core.scm:1486: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_cdr(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k15026 in chicken.irregex#unicode-range-up-to in k7767 in k7542 in k7539 */
static void C_ccall f_15028(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_15028,c,av);}
a=C_alloc(19);
t2=C_i_cdr(t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14951,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14958,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=t6,a[5]=t7,tmp=(C_word)a,a+=6,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15022,a[2]=t8,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1486: ##sys#fast-reverse */
t10=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t10;
av2[1]=t9;
av2[2]=C_u_i_cdr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}

/* k15045 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_15047,c,av);}
a=C_alloc(11);
t2=(
/* irregex-core.scm:1492: sre-alternate */
  f_18226(C_a_i(&a,3),t1)
);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_14509,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1426: unicode-range-up-to */
f_14897(t3,((C_word*)t0)[7]);}

/* g2220 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15056(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_15056,3,t0,t1,t2);}
a=C_alloc(10);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15068,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15144,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1505: utf8-lowest-digit-of-length */
f_14268(t4,C_fixnum_plus(C_fixnum_plus(t2,((C_word*)t0)[2]),C_fix(1)));}

/* k15066 in g2220 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15068(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_15068,2,t0,t1);}
a=C_alloc(11);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15080,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t4,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1509: zero-to */
f_9164(t6,C_fixnum_plus(((C_word*)t0)[3],((C_word*)t0)[4]));}

/* k15078 in k15066 in g2220 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_15080,c,av);}
a=C_alloc(12);
t2=C_i_check_list_2(t1,lf[211]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15086,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15088,a[2]=((C_word*)t0)[4],a[3]=t5,a[4]=((C_word*)t0)[5],a[5]=((C_word)li107),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_15088(t7,t3,t1);}

/* k15084 in k15078 in k15066 in g2220 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15086(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_15086,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:1503: sre-sequence */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* irregex-core.scm:1503: sre-sequence */
  f_18203(C_a_i(&a,3),t2)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop2237 in k15078 in k15066 in g2220 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15088(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_15088,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=C_a_i_list(&a,3,lf[52],C_make_character(128),C_make_character(255));
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15134 in k15142 in g2220 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15136(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_15136,c,av);}
a=C_alloc(9);
t2=C_make_character(C_unfix(t1));
t3=((C_word*)t0)[2];
f_15068(t3,C_a_i_list(&a,3,lf[52],((C_word*)t0)[3],t2));}

/* k15142 in g2220 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_15144,c,av);}
a=C_alloc(13);
t2=C_make_character(C_unfix(t1));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15136,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=C_fixnum_plus(C_fixnum_plus(((C_word*)t0)[3],((C_word*)t0)[4]),C_fix(1));
switch(t4){
case C_fix(1):
t5=((C_word*)t0)[2];
f_15068(t5,C_a_i_list(&a,3,lf[52],t2,C_make_character(127)));
case C_fix(2):
t5=((C_word*)t0)[2];
f_15068(t5,C_a_i_list(&a,3,lf[52],t2,C_make_character(223)));
case C_fix(3):
t5=((C_word*)t0)[2];
f_15068(t5,C_a_i_list(&a,3,lf[52],t2,C_make_character(239)));
case C_fix(4):
t5=((C_word*)t0)[2];
f_15068(t5,C_a_i_list(&a,3,lf[52],t2,C_make_character(247)));
default:
/* irregex-core.scm:1401: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[215];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k15149 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15151(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_15151,c,av);}
a=C_alloc(14);
t2=C_i_check_list_2(t1,lf[211]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15157,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15259,a[2]=((C_word*)t0)[5],a[3]=t5,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word)li110),tmp=(C_word)a,a+=7,tmp));
t7=((C_word*)t5)[1];
f_15259(t7,t3,t1);}

/* k15155 in k15149 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_15157,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15241,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t3=C_i_car(((C_word*)t0)[2]);
t4=C_fixnum_difference(t3,C_fix(1));
t5=C_make_character(C_unfix(t4));
t6=C_fix(C_character_code(t5));
/* irregex-core.scm:1514: utf8-lowest-digit-of-length */
f_14268(t2,C_i_vector_ref(lf[170],t6));}

/* k15187 in k15239 in k15155 in k15149 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15189(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_15189,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=(
/* irregex-core.scm:1512: sre-sequence */
  f_18203(C_a_i(&a,3),t2)
);
t4=C_a_i_list1(&a,1,t3);
/* irregex-core.scm:1493: scheme#append */
t5=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* map-loop2277 in k15239 in k15155 in k15149 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15191(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_15191,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=C_a_i_list(&a,3,lf[52],C_make_character(128),C_make_character(255));
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15239 in k15155 in k15149 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,3)))){
C_save_and_reclaim((void *)f_15241,c,av);}
a=C_alloc(28);
t2=C_make_character(C_unfix(t1));
t3=C_fixnum_difference(C_u_i_car(((C_word*)t0)[2]),C_fix(1));
t4=C_make_character(C_unfix(t3));
t5=C_a_i_list(&a,3,lf[52],t2,t4);
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=C_u_i_cdr(((C_word*)t0)[2]);
t11=C_i_check_list_2(t10,lf[211]);
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15189,a[2]=t5,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15191,a[2]=t8,a[3]=t14,a[4]=t9,a[5]=((C_word)li109),tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_15191(t16,t12,t10);}

/* map-loop2214 in k15149 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15259(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15259,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15284,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1501: g2220 */
t4=((C_word*)t0)[4];
f_15056(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15282 in map-loop2214 in k15149 in k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_15284,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15259(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k15325 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,3)))){
C_save_and_reclaim((void *)f_15327,c,av);}
a=C_alloc(36);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=(
/* irregex-core.scm:1495: sre-sequence */
  f_18203(C_a_i(&a,3),t2)
);
t4=C_a_i_list1(&a,1,t3);
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15056,a[2]=((C_word*)t0)[3],a[3]=((C_word)li108),tmp=(C_word)a,a+=4,tmp);
t10=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15151,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t4,a[5]=t7,a[6]=t9,a[7]=t8,tmp=(C_word)a,a+=8,tmp);
t11=C_i_length(((C_word*)t0)[4]);
t12=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
t13=C_s_a_u_i_integer_minus(&a,2,t11,t12);
/* irregex-core.scm:1510: zero-to */
f_9164(t10,t13);}

/* map-loop2184 in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15329(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_15329,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=C_a_i_list(&a,3,lf[52],C_make_character(128),C_make_character(255));
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15416 in k14584 in lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15418(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_15418,c,av);}
a=C_alloc(11);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=(
/* irregex-core.scm:1525: sre-sequence */
  f_18203(C_a_i(&a,3),t2)
);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14594,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1440: unicode-range-up-to */
f_14897(t4,((C_word*)t0)[5]);}

/* map-loop2315 in k14584 in lp in k14486 in k14483 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15420(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_15420,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=C_a_i_list(&a,3,lf[52],C_make_character(128),C_make_character(255));
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15475(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_15475,2,t1,t2);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15483,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1532: cset->plist */
f_26393(t3,t2);}

/* k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_15483,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15485,a[2]=t3,a[3]=((C_word)li114),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_15485(t5,((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST);}

/* lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15485(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_15485,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15499,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15503,a[2]=t4,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1534: ##sys#fast-reverse */
t7=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=C_i_car(t2);
t6=C_fix(C_character_code(t5));
t7=C_fixnum_less_or_equal_p(C_fix(128),t6);
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15530,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t7)){
t9=t8;
f_15530(t9,t7);}
else{
t9=C_i_cadr(t2);
t10=t8;
f_15530(t10,C_fixnum_less_or_equal_p(C_fix(128),C_fix(C_character_code(t9))));}}}

/* k15497 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15499(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15499,c,av);}
a=C_alloc(3);
/* irregex-core.scm:1534: sre-alternate */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(
/* irregex-core.scm:1534: sre-alternate */
  f_18226(C_a_i(&a,3),t1)
);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k15501 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15503(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_15503,c,av);}
a=C_alloc(4);
if(C_truep(C_i_nullp(((C_word*)t0)[2]))){
/* irregex-core.scm:1534: scheme#append */
t2=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15521,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1537: ##sys#fast-reverse */
t3=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k15519 in k15501 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_15521,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[52],t1);
t3=C_a_i_list1(&a,1,t2);
/* irregex-core.scm:1534: scheme#append */
t4=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_fcall f_15530(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,4)))){
C_save_and_reclaim_args((void *)trf_15530,2,t0,t1);}
a=C_alloc(16);
if(C_truep(t1)){
t2=C_i_cddr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15545,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t4=C_u_i_car(((C_word*)t0)[2]);
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=C_u_i_car(t5);
t7=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_14485,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[6],a[7]=t3,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1422: char->utf8-list */
f_14344(t7,t4);}
else{
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_u_i_cdr(((C_word*)t0)[2]);
t4=C_u_i_car(t3);
t5=C_u_i_car(((C_word*)t0)[2]);
t6=C_a_i_cons(&a,2,t5,((C_word*)t0)[6]);
t7=C_a_i_cons(&a,2,t4,t6);
/* irregex-core.scm:1542: lp */
t8=((C_word*)((C_word*)t0)[4])[1];
f_15485(t8,((C_word*)t0)[5],t2,((C_word*)t0)[3],t7);}}

/* k15543 in k15528 in lp in k15481 in chicken.irregex#cset->utf8-pattern in k7767 in k7542 in k7539 */
static void C_ccall f_15545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_15545,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:1539: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_15485(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2,((C_word*)t0)[6]);}

/* adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15597(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,4)))){
C_save_and_reclaim_args((void *)trf_15597,5,t0,t1,t2,t3,t4);}
a=C_alloc(29);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15600,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t4,a[5]=((C_word)li204),tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(t2))){
t6=C_u_i_car(t2);
t7=C_eqp(t6,lf[156]);
if(C_truep(t7)){
t8=(
/* irregex-core.scm:1552: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t2))
);
/* irregex-core.scm:1552: adjust */
t24=t1;
t25=t8;
t26=C_SCHEME_TRUE;
t27=t4;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
goto loop;}
else{
t8=C_eqp(t6,lf[157]);
if(C_truep(t8)){
t9=(
/* irregex-core.scm:1553: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t2))
);
/* irregex-core.scm:1553: adjust */
t24=t1;
t25=t9;
t26=C_SCHEME_FALSE;
t27=t4;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
goto loop;}
else{
t9=C_eqp(t6,lf[225]);
if(C_truep(t9)){
t10=C_u_i_car(t2);
t11=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t12=t11;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=((C_word*)t13)[1];
t15=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15657,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word)li205),tmp=(C_word)a,a+=5,tmp);
t16=C_u_i_cdr(t2);
t17=C_i_check_list_2(t16,lf[211]);
t18=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15668,a[2]=t1,a[3]=t10,tmp=(C_word)a,a+=4,tmp);
t19=C_SCHEME_UNDEFINED;
t20=(*a=C_VECTOR_TYPE|1,a[1]=t19,tmp=(C_word)a,a+=2,tmp);
t21=C_set_block_item(t20,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15670,a[2]=t13,a[3]=t20,a[4]=t15,a[5]=t14,a[6]=((C_word)li206),tmp=(C_word)a,a+=7,tmp));
t22=((C_word*)t20)[1];
f_15670(t22,t18,t16);}
else{
t10=C_eqp(t6,lf[226]);
if(C_truep(t10)){
t11=C_u_i_car(t2);
t12=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t13=t12;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=((C_word*)t14)[1];
t16=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15718,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word)li207),tmp=(C_word)a,a+=5,tmp);
t17=C_u_i_cdr(t2);
t18=C_i_check_list_2(t17,lf[211]);
t19=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15729,a[2]=t1,a[3]=t11,tmp=(C_word)a,a+=4,tmp);
t20=C_SCHEME_UNDEFINED;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=C_set_block_item(t21,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15731,a[2]=t14,a[3]=t21,a[4]=t16,a[5]=t15,a[6]=((C_word)li208),tmp=(C_word)a,a+=7,tmp));
t23=((C_word*)t21)[1];
f_15731(t23,t19,t17);}
else{
t11=C_eqp(t6,lf[52]);
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15772,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=t4,a[6]=t6,a[7]=t5,tmp=(C_word)a,a+=8,tmp);
if(C_truep(t11)){
t13=t12;
f_15772(t13,t11);}
else{
t13=C_eqp(t6,lf[179]);
if(C_truep(t13)){
t14=t12;
f_15772(t14,t13);}
else{
t14=C_eqp(t6,lf[234]);
t15=t12;
f_15772(t15,(C_truep(t14)?t14:C_eqp(t6,lf[247])));}}}}}}}
else{
t6=C_eqp(t2,lf[124]);
if(C_truep(t6)){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=(C_truep(t3)?lf[274]:lf[124]);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(t2,lf[125]);
if(C_truep(t7)){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=(C_truep(t3)?lf[275]:lf[125]);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15986,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t3)){
t9=C_charp(t2);
t10=t8;
f_15986(t10,(C_truep(t9)?C_fixnum_less_or_equal_p(C_fix(128),C_fix(C_character_code(t2))):C_SCHEME_FALSE));}
else{
t9=t8;
f_15986(t9,C_SCHEME_FALSE);}}}}}

/* rec in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15600(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_15600,3,t0,t1,t2);}
/* irregex-core.scm:1548: adjust */
t3=((C_word*)((C_word*)t0)[2])[1];
f_15597(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* g2380 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15657(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_15657,3,t0,t1,t2);}
/* irregex-core.scm:1555: adjust */
t3=((C_word*)((C_word*)t0)[2])[1];
f_15597(t3,t1,t2,((C_word*)t0)[3],C_SCHEME_FALSE);}

/* k15666 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15668,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop2374 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15670(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15670,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15695,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1555: g2380 */
t4=((C_word*)t0)[4];
f_15657(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15693 in map-loop2374 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15695(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_15695,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15670(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* g2407 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15718(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_15718,3,t0,t1,t2);}
/* irregex-core.scm:1557: adjust */
t3=((C_word*)((C_word*)t0)[2])[1];
f_15597(t3,t1,t2,((C_word*)t0)[3],C_SCHEME_TRUE);}

/* k15727 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15729,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop2401 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15731(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15731,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15756,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1557: g2407 */
t4=((C_word*)t0)[4];
f_15718(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15754 in map-loop2401 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15756(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_15756,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15731(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15772(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,3)))){
C_save_and_reclaim_args((void *)trf_15772,2,t0,t1);}
a=C_alloc(20);
if(C_truep(t1)){
if(C_truep(C_i_not(((C_word*)t0)[2]))){
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15781,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1561: sre->cset */
f_26504(t2,((C_word*)t0)[4],C_a_i_list(&a,1,((C_word*)t0)[5]));}}
else{
t2=C_eqp(((C_word*)t0)[6],lf[127]);
if(C_truep(t2)){
t3=(
/* irregex-core.scm:1568: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[4]))
);
t4=C_eqp(t3,lf[124]);
if(C_truep(t4)){
t5=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[272];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(t3,lf[125]);
if(C_truep(t5)){
t6=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t6;
av2[1]=lf[273];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=C_u_i_cdr(((C_word*)t0)[4]);
t11=C_i_check_list_2(t10,lf[211]);
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15839,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15841,a[2]=t8,a[3]=t14,a[4]=((C_word*)t0)[7],a[5]=t9,a[6]=((C_word)li209),tmp=(C_word)a,a+=7,tmp));
t16=((C_word*)t14)[1];
f_15841(t16,t12,t10);}}}
else{
t3=C_u_i_car(((C_word*)t0)[4]);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=C_u_i_cdr(((C_word*)t0)[4]);
t9=C_i_check_list_2(t8,lf[211]);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15895,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15897,a[2]=t6,a[3]=t12,a[4]=((C_word*)t0)[7],a[5]=t7,a[6]=((C_word)li210),tmp=(C_word)a,a+=7,tmp));
t14=((C_word*)t12)[1];
f_15897(t14,t10,t8);}}}

/* k15779 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_15781,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15787,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15804,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1562: cset->plist */
f_26393(t3,t1);}

/* k15785 in k15779 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_15787,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15797,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1564: cset->utf8-pattern */
f_15475(t2,((C_word*)t0)[4]);}
else{
/* irregex-core.scm:1565: cset->utf8-pattern */
f_15475(((C_word*)t0)[3],((C_word*)t0)[4]);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k15795 in k15785 in k15779 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15797(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_15797,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list2(&a,2,lf[225],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k15802 in k15779 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15804,c,av);}
/* irregex-core.scm:1562: any */
f_9300(((C_word*)t0)[2],lf[204],t1);}

/* k15837 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15839(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15839,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[127],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop2444 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15841(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15841,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15866,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1572: g2450 */
t4=((C_word*)t0)[4];
f_15600(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15864 in map-loop2444 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_15866,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15841(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k15893 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15895,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop2470 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15897(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15897,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15922,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1574: g2476 */
t4=((C_word*)t0)[4];
f_15600(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15920 in map-loop2470 in k15770 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15922(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_15922,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15897(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k15984 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_15986(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_15986,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15996,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1581: char->utf8-list */
f_14344(t6,((C_word*)t0)[3]);}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k15994 in k15984 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_15996,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15999,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16001,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=((C_word)li211),tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_16001(t6,t2,t1);}

/* k15997 in k15994 in k15984 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_15999(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15999,c,av);}
a=C_alloc(3);
/* irregex-core.scm:1581: sre-sequence */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(
/* irregex-core.scm:1581: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop2504 in k15994 in k15984 in adjust in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_16001(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16001,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_make_character(C_unfix(t3));
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.irregex#irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16048(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +5,c,2)))){
C_save_and_reclaim((void*)f_16048,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+5);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16055,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1598: irregex? */
t5=*((C_word*)lf[5]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k16053 in chicken.irregex#irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_16055,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_nullp(((C_word*)t0)[4]))){
t2=lf[218];
t3=C_slot(t2,C_fix(0));
if(C_truep(C_i_equalp(t3,((C_word*)t0)[3]))){
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fix(1));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(2));
if(C_truep(C_i_equalp(t4,((C_word*)t0)[3]))){
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_slot(t2,C_fix(3));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_slot(t2,C_fix(4));
if(C_truep(C_i_equalp(t5,((C_word*)t0)[3]))){
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_slot(t2,C_fix(5));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_slot(t2,C_fix(6));
if(C_truep(C_i_equalp(t6,((C_word*)t0)[3]))){
t7=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_slot(t2,C_fix(7));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_slot(t2,C_fix(8));
if(C_truep(C_i_equalp(t7,((C_word*)t0)[3]))){
t8=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_slot(t2,C_fix(9));
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16109,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_stringp(((C_word*)t0)[3]))){
/* irregex-core.scm:1603: string->irregex */
t9=*((C_word*)lf[219]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
/* irregex-core.scm:1604: sre->irregex */
t9=*((C_word*)lf[220]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}}}}}}}
else{
if(C_truep(C_i_stringp(((C_word*)t0)[3]))){{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[219]+1);
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
C_apply(5,av2);}}
else{{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[220]+1);
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
C_apply(5,av2);}}}}}

/* k16107 in k16053 in chicken.irregex#irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16109(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_16109,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(10));
t3=C_i_setslot(((C_word*)t0)[2],t2,((C_word*)t0)[3]);
t4=C_fixnum_plus(t2,C_fix(1));
t5=C_i_setslot(((C_word*)t0)[2],t4,t1);
t6=C_fixnum_plus(t2,C_fix(2));
t7=C_fixnum_modulo(t6,C_fix(10));
t8=C_i_set_i_slot(((C_word*)t0)[2],C_fix(10),t7);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* chicken.irregex#string->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16176(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_16176,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16184,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t4;
av2[2]=*((C_word*)lf[102]+1);
av2[3]=t2;
av2[4]=t3;
C_apply(5,av2);}}

/* k16182 in chicken.irregex#string->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16184(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_16184,c,av);}{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[220]+1);
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
C_apply(5,av2);}}

/* chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16186(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +5,c,2)))){
C_save_and_reclaim((void*)f_16186,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+5);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16190,a[2]=t3,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1614: symbol-list->flags */
f_10338(t4,t3);}

/* k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16190(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_16190,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16193,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=C_fixnum_and(t1,C_fix(32));
t4=C_eqp(C_fix(32),t3);
t5=C_fixnum_and(t1,C_fix(2));
t6=C_eqp(C_fix(2),t5);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15597,a[2]=t8,a[3]=((C_word)li212),tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_15597(t10,t2,((C_word*)t0)[4],t4,t6);}

/* k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16193(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_16193,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16196,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1618: sre-searcher? */
t3=lf[271];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
f_16721(3,av2);}}

/* k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16196(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_16196,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16199,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t1)){
/* irregex-core.scm:1619: sre-remove-initial-bos */
t3=lf[270];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
f_18748(3,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
f_16199(2,av2);}}}

/* k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16199(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,3)))){
C_save_and_reclaim((void *)f_16199,c,av);}
a=C_alloc(27);
t2=(C_truep(C_u_i_memq(lf[221],((C_word*)t0)[2]))?C_fix(1):(C_truep(C_u_i_memq(lf[222],((C_word*)t0)[2]))?C_fix(50):C_fix(10)));
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16205,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=t2,tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_u_i_memq(lf[269],((C_word*)t0)[2]))){
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_16205(2,av2);}}
else{
if(C_truep(((C_word*)t0)[3])){
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_TRUE;
f_16205(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16277,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=C_a_i_list(&a,2,lf[127],lf[124]);
t6=C_a_i_list(&a,3,lf[115],t5,t1);
/* irregex-core.scm:1627: sre->nfa */
f_20769(t4,t6,((C_word*)t0)[5]);}}}

/* k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16205(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_16205,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_16208,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t1)){
/* irregex-core.scm:1631: sre->nfa */
f_20769(t2,((C_word*)t0)[6],((C_word*)t0)[4]);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_16208(2,av2);}}}

/* k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16208(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_16208,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16211,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16251,a[2]=((C_word*)t0)[8],a[3]=((C_word)li202),tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1631: g2625 */
t4=t3;
f_16251(t4,t2,t1);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_16211(2,av2);}}}

/* k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_16211,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_16214,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1635: sre-count-submatches */
f_16994(t2,((C_word*)t0)[7]);}

/* k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16214(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_16214,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_16217,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:1636: sre-names */
f_18430(t2,((C_word*)t0)[8],C_fix(1),C_SCHEME_END_OF_LIST);}

/* k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16217(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_16217,c,av);}
a=C_alloc(14);
t2=C_a_i_list(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17094,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_pairp(t2))){
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_car(t2);
f_17094(2,av2);}}
else{
/* irregex-core.scm:1732: sre-names */
f_18430(t3,((C_word*)t0)[9],C_fix(1),C_SCHEME_END_OF_LIST);}}

/* k16230 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16232(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_16232,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_record8(&a,8,lf[6],C_SCHEME_FALSE,C_SCHEME_FALSE,t1,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16246(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,4)))){
C_save_and_reclaim((void *)f_16246,c,av);}
a=C_alloc(21);
t2=(C_truep(t1)?C_fixnum_or(((C_word*)t0)[2],C_fix(2)):((C_word*)t0)[2]);
if(C_truep(((C_word*)t0)[3])){
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_record8(&a,8,lf[6],((C_word*)t0)[3],((C_word*)t0)[5],C_SCHEME_FALSE,t2,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16232,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],tmp=(C_word)a,a+=7,tmp);
t4=C_a_i_list(&a,2,((C_word*)t0)[9],((C_word*)t0)[8]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23409,a[2]=t6,a[3]=t4,a[4]=t3,a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
t8=C_i_pairp(t4);
t9=(C_truep(t8)?C_i_pairp(C_u_i_cdr(t4)):C_SCHEME_FALSE);
if(C_truep(t9)){
t10=t7;{
C_word *av2=av;
av2[0]=t10;
av2[1]=C_i_cadr(t4);
f_23409(2,av2);}}
else{
/* irregex-core.scm:3133: sre-names */
f_18430(t7,((C_word*)t0)[10],C_fix(1),C_SCHEME_END_OF_LIST);}}}

/* g2625 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_16251(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_16251,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_vector_length(t2);
t4=C_a_i_fixnum_quotient_checked(&a,2,t3,C_fix(4));
t5=C_fixnum_times(((C_word*)t0)[2],t4);
/* irregex-core.scm:1633: nfa->dfa */
f_22381(t1,t2,C_a_i_list(&a,1,t5));}

/* k16275 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_16277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_16277,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16281,a[2]=((C_word*)t0)[2],a[3]=((C_word)li203),tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1625: g2614 */
t3=t2;
f_16281(t3,((C_word*)t0)[3],t1);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_16205(2,av2);}}}

/* g2614 in k16275 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_16281(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_16281,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_vector_length(t2);
t4=C_a_i_fixnum_quotient_checked(&a,2,t3,C_fix(4));
t5=C_fixnum_times(((C_word*)t0)[2],t4);
/* irregex-core.scm:1629: nfa->dfa */
f_22381(t1,t2,C_a_i_list(&a,1,t5));}

/* chicken.irregex#sre-empty? in k7767 in k7542 in k7539 */
static void C_ccall f_16319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_16319,c,av);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[127]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16336,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t4)){
t6=t5;
f_16336(t6,t4);}
else{
t6=C_eqp(t3,lf[131]);
if(C_truep(t6)){
t7=t5;
f_16336(t7,t6);}
else{
t7=C_eqp(t3,lf[111]);
if(C_truep(t7)){
t8=t5;
f_16336(t8,t7);}
else{
t8=C_eqp(t3,lf[113]);
if(C_truep(t8)){
t9=t5;
f_16336(t9,t8);}
else{
t9=C_eqp(t3,lf[112]);
t10=t5;
f_16336(t10,(C_truep(t9)?t9:C_eqp(t3,lf[114])));}}}}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_memq(t2,lf[276]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16334 in chicken.irregex#sre-empty? in k7767 in k7542 in k7539 */
static void C_fcall f_16336(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_16336,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[3],lf[133]);
if(C_truep(t2)){
t3=C_i_cadr(((C_word*)t0)[4]);
t4=C_i_numberp(t3);
t5=C_i_not(t4);
if(C_truep(t5)){
t6=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_u_i_cdr(((C_word*)t0)[4]);
t7=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t7;
av2[1]=C_i_zerop(C_u_i_car(t6));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
t3=C_eqp(((C_word*)t0)[3],lf[103]);
if(C_truep(t3)){
/* irregex-core.scm:1657: any */
f_9300(((C_word*)t0)[2],lf[139],C_u_i_cdr(((C_word*)t0)[4]));}
else{
t4=C_eqp(((C_word*)t0)[3],lf[227]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16379,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t4)){
if(C_truep(t4)){
/* irregex-core.scm:1659: every */
f_9343(((C_word*)t0)[2],lf[139],C_u_i_cdr(((C_word*)t0)[4]));}
else{
t6=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t6=C_eqp(((C_word*)t0)[3],lf[115]);
if(C_truep(t6)){
if(C_truep(t6)){
/* irregex-core.scm:1659: every */
f_9343(((C_word*)t0)[2],lf[139],C_u_i_cdr(((C_word*)t0)[4]));}
else{
t7=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
t7=C_eqp(((C_word*)t0)[3],lf[245]);
if(C_truep(t7)){
t8=t5;
f_16379(t8,t7);}
else{
t8=C_eqp(((C_word*)t0)[3],lf[108]);
if(C_truep(t8)){
t9=t5;
f_16379(t9,t8);}
else{
t9=C_eqp(((C_word*)t0)[3],lf[119]);
if(C_truep(t9)){
t10=t5;
f_16379(t10,t9);}
else{
t10=C_eqp(((C_word*)t0)[3],lf[120]);
if(C_truep(t10)){
t11=t5;
f_16379(t11,t10);}
else{
t11=C_eqp(((C_word*)t0)[3],lf[129]);
t12=t5;
f_16379(t12,(C_truep(t11)?t11:C_eqp(((C_word*)t0)[3],lf[239])));}}}}}}}}}}

/* k16377 in k16334 in chicken.irregex#sre-empty? in k7767 in k7542 in k7539 */
static void C_fcall f_16379(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_16379,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:1659: every */
f_9343(((C_word*)t0)[2],lf[139],C_u_i_cdr(((C_word*)t0)[3]));}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.irregex#sre-any? in k7767 in k7542 in k7539 */
static void C_ccall f_16486(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_16486,c,av);}
a=C_alloc(5);
t3=C_eqp(t2,lf[124]);
if(C_truep(t3)){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t2))){
t4=C_u_i_car(t2);
t5=C_eqp(t4,lf[115]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16509,a[2]=t2,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t5)){
t7=t6;
f_16509(t7,t5);}
else{
t7=C_eqp(t4,lf[227]);
if(C_truep(t7)){
t8=t6;
f_16509(t8,t7);}
else{
t8=C_eqp(t4,lf[245]);
if(C_truep(t8)){
t9=t6;
f_16509(t9,t8);}
else{
t9=C_eqp(t4,lf[108]);
if(C_truep(t9)){
t10=t6;
f_16509(t10,t9);}
else{
t10=C_eqp(t4,lf[119]);
t11=t6;
f_16509(t11,(C_truep(t10)?t10:C_eqp(t4,lf[120])));}}}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* k16507 in chicken.irregex#sre-any? in k7767 in k7542 in k7539 */
static void C_fcall f_16509(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_16509,2,t0,t1);}
if(C_truep(t1)){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[2])))){
t2=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_nullp(t2))){
t3=C_u_i_cdr(((C_word*)t0)[2]);
/* irregex-core.scm:1668: sre-any? */
t4=lf[277];{
C_word av2[3];
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=C_u_i_car(t3);
f_16486(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[103]);
if(C_truep(t2)){
/* irregex-core.scm:1669: every */
f_9343(((C_word*)t0)[3],lf[277],C_u_i_cdr(((C_word*)t0)[2]));}
else{
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* chicken.irregex#sre-repeater? in k7767 in k7542 in k7539 */
static C_word C_fcall f_16587(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_u_i_car(t1);
t3=C_u_i_memq(t2,lf[278]);
if(C_truep(t3)){
return(t3);}
else{
t4=C_u_i_car(t1);
if(C_truep((C_truep(C_eqp(t4,lf[245]))?C_SCHEME_TRUE:(C_truep(C_eqp(t4,lf[108]))?C_SCHEME_TRUE:(C_truep(C_eqp(t4,lf[119]))?C_SCHEME_TRUE:(C_truep(C_eqp(t4,lf[120]))?C_SCHEME_TRUE:(C_truep(C_eqp(t4,lf[115]))?C_SCHEME_TRUE:(C_truep(C_eqp(t4,lf[227]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))))))){
if(C_truep(C_i_pairp(C_u_i_cdr(t1)))){
t5=C_i_cddr(t1);
if(C_truep(C_i_nullp(t5))){
t6=C_u_i_cdr(t1);
t8=C_u_i_car(t6);
t1=t8;
goto loop;}
else{
return(C_SCHEME_FALSE);}}
else{
return(C_SCHEME_FALSE);}}
else{
return(C_SCHEME_FALSE);}}}
else{
return(C_SCHEME_FALSE);}}

/* chicken.irregex#sre-bos? in k7767 in k7542 in k7539 */
static void C_ccall f_16632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_16632,c,av);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[115]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16649,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t4)){
t6=t5;
f_16649(t6,t4);}
else{
t6=C_eqp(t3,lf[227]);
if(C_truep(t6)){
t7=t5;
f_16649(t7,t6);}
else{
t7=C_eqp(t3,lf[245]);
if(C_truep(t7)){
t8=t5;
f_16649(t8,t7);}
else{
t8=C_eqp(t3,lf[108]);
if(C_truep(t8)){
t9=t5;
f_16649(t9,t8);}
else{
t9=C_eqp(t3,lf[119]);
t10=t5;
f_16649(t10,(C_truep(t9)?t9:C_eqp(t3,lf[120])));}}}}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_eqp(lf[186],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16647 in chicken.irregex#sre-bos? in k7767 in k7542 in k7539 */
static void C_fcall f_16649(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_16649,2,t0,t1);}
if(C_truep(t1)){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[2])))){
/* irregex-core.scm:1684: sre-bos? */
t2=lf[279];{
C_word av2[3];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_i_cadr(((C_word*)t0)[2]);
f_16632(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[103]);
if(C_truep(t2)){
/* irregex-core.scm:1685: every */
f_9343(((C_word*)t0)[3],lf[279],C_u_i_cdr(((C_word*)t0)[2]));}
else{
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* chicken.irregex#sre-searcher? in k7767 in k7542 in k7539 */
static void C_ccall f_16721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_16721,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16725,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1691: sre-bos? */
t4=lf[279];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
f_16632(3,av2);}}

/* k16723 in chicken.irregex#sre-searcher? in k7767 in k7542 in k7539 */
static void C_ccall f_16725(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_16725,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t2=C_u_i_car(((C_word*)t0)[3]);
t3=C_eqp(t2,lf[127]);
t4=(C_truep(t3)?t3:C_eqp(t2,lf[129]));
if(C_truep(t4)){
t5=(
/* irregex-core.scm:1694: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[3]))
);
/* irregex-core.scm:1694: sre-any? */
t6=lf[277];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[2];
av2[2]=t5;
f_16486(3,av2);}}
else{
t5=C_eqp(t2,lf[115]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16762,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t5)){
t7=t6;
f_16762(t7,t5);}
else{
t7=C_eqp(t2,lf[227]);
if(C_truep(t7)){
t8=t6;
f_16762(t8,t7);}
else{
t8=C_eqp(t2,lf[245]);
if(C_truep(t8)){
t9=t6;
f_16762(t9,t8);}
else{
t9=C_eqp(t2,lf[108]);
if(C_truep(t9)){
t10=t6;
f_16762(t10,t9);}
else{
t10=C_eqp(t2,lf[119]);
t11=t6;
f_16762(t11,(C_truep(t10)?t10:C_eqp(t2,lf[120])));}}}}}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* k16760 in k16723 in chicken.irregex#sre-searcher? in k7767 in k7542 in k7539 */
static void C_fcall f_16762(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_16762,2,t0,t1);}
if(C_truep(t1)){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[2])))){
/* irregex-core.scm:1696: sre-searcher? */
t2=lf[271];{
C_word av2[3];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_i_cadr(((C_word*)t0)[2]);
f_16721(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[103]);
if(C_truep(t2)){
/* irregex-core.scm:1697: every */
f_9343(((C_word*)t0)[3],lf[271],C_u_i_cdr(((C_word*)t0)[2]));}
else{
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* chicken.irregex#sre-consumer? in k7767 in k7542 in k7539 */
static void C_ccall f_16838(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_16838,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16842,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:1702: sre-bos? */
t4=lf[279];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
f_16632(3,av2);}}

/* k16840 in chicken.irregex#sre-consumer? in k7767 in k7542 in k7539 */
static void C_ccall f_16842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_16842,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t2=C_u_i_car(((C_word*)t0)[3]);
t3=C_eqp(t2,lf[127]);
t4=(C_truep(t3)?t3:C_eqp(t2,lf[129]));
if(C_truep(t4)){
t5=(
/* irregex-core.scm:1705: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[3]))
);
/* irregex-core.scm:1705: sre-any? */
t6=lf[277];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[2];
av2[2]=t5;
f_16486(3,av2);}}
else{
t5=C_eqp(t2,lf[115]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16879,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t5)){
t7=t6;
f_16879(t7,t5);}
else{
t7=C_eqp(t2,lf[227]);
if(C_truep(t7)){
t8=t6;
f_16879(t8,t7);}
else{
t8=C_eqp(t2,lf[245]);
if(C_truep(t8)){
t9=t6;
f_16879(t9,t8);}
else{
t9=C_eqp(t2,lf[108]);
if(C_truep(t9)){
t10=t6;
f_16879(t10,t9);}
else{
t10=C_eqp(t2,lf[119]);
t11=t6;
f_16879(t11,(C_truep(t10)?t10:C_eqp(t2,lf[120])));}}}}}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* k16877 in k16840 in chicken.irregex#sre-consumer? in k7767 in k7542 in k7539 */
static void C_fcall f_16879(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_16879,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[2])))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16892,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1707: last */
f_9262(t2,((C_word*)t0)[2]);}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[103]);
if(C_truep(t2)){
/* irregex-core.scm:1708: every */
f_9343(((C_word*)t0)[3],lf[253],C_u_i_cdr(((C_word*)t0)[2]));}
else{
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k16890 in k16877 in k16840 in chicken.irregex#sre-consumer? in k7767 in k7542 in k7539 */
static void C_ccall f_16892(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16892,c,av);}
/* irregex-core.scm:1707: sre-consumer? */
t2=lf[253];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
f_16838(3,av2);}}

/* chicken.irregex#sre-has-submatches? in k7767 in k7542 in k7539 */
static void C_ccall f_16955(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_16955,c,av);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_u_i_memq(t3,lf[281]);
if(C_truep(t4)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(lf[235],C_u_i_car(t2));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16981,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1715: string->sre */
t7=*((C_word*)lf[102]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_cadr(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
/* irregex-core.scm:1716: any */
f_9300(t1,lf[280],C_u_i_cdr(t2));}}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16979 in chicken.irregex#sre-has-submatches? in k7767 in k7542 in k7539 */
static void C_ccall f_16981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16981,c,av);}
/* irregex-core.scm:1715: sre-has-submatches? */
t2=lf[280];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
f_16955(3,av2);}}

/* chicken.irregex#sre-count-submatches in k7767 in k7542 in k7539 */
static void C_fcall f_16994(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_16994,2,t1,t2);}
a=C_alloc(6);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17000,a[2]=t4,a[3]=((C_word)li221),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_fix(0);
f_17000(4,av2);}}

/* count in chicken.irregex#sre-count-submatches in k7767 in k7542 in k7539 */
static void C_ccall f_17000(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_17000,c,av);}
a=C_alloc(14);
if(C_truep(C_i_pairp(t2))){
t4=C_u_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17021,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_eqp(t4,lf[245]);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17027,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t2,a[6]=t4,a[7]=t5,tmp=(C_word)a,a+=8,tmp);
if(C_truep(t6)){
t8=t7;
f_17027(t8,t6);}
else{
t8=C_eqp(t4,lf[108]);
if(C_truep(t8)){
t9=t7;
f_17027(t9,t8);}
else{
t9=C_eqp(t4,lf[119]);
t10=t7;
f_17027(t10,(C_truep(t9)?t9:C_eqp(t4,lf[120])));}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k17019 in count in chicken.irregex#sre-count-submatches in k7767 in k7542 in k7539 */
static void C_ccall f_17021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_17021,c,av);}
/* irregex-core.scm:1721: fold */
f_9388(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1],C_fixnum_plus(((C_word*)t0)[4],t1),C_u_i_cdr(((C_word*)t0)[5]));}

/* k17025 in count in chicken.irregex#sre-count-submatches in k7767 in k7542 in k7539 */
static void C_fcall f_17027(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,4)))){
C_save_and_reclaim_args((void *)trf_17027,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
/* irregex-core.scm:1721: fold */
f_9388(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)),C_u_i_cdr(((C_word*)t0)[5]));}
else{
t2=C_eqp(((C_word*)t0)[6],lf[244]);
if(C_truep(t2)){
t3=C_fixnum_plus(C_i_cadr(((C_word*)t0)[5]),C_i_caddr(((C_word*)t0)[5]));
/* irregex-core.scm:1721: fold */
f_9388(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1],C_fixnum_plus(((C_word*)t0)[4],t3),C_u_i_cdr(((C_word*)t0)[5]));}
else{
t3=C_eqp(((C_word*)t0)[6],lf[235]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17057,a[2]=((C_word*)t0)[7],tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1726: string->sre */
t5=*((C_word*)lf[102]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_cadr(((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_s_a_i_plus(&a,2,((C_word*)t0)[4],C_fix(0));
/* irregex-core.scm:1721: fold */
f_9388(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1],t4,C_u_i_cdr(((C_word*)t0)[5]));}}}}

/* k17055 in k17025 in count in chicken.irregex#sre-count-submatches in k7767 in k7542 in k7539 */
static void C_ccall f_17057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17057,c,av);}
/* irregex-core.scm:1726: sre-count-submatches */
f_16994(((C_word*)t0)[2],t1);}

/* k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17094(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_17094,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17097,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18194,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1733: sre-count-submatches */
f_16994(t3,((C_word*)t0)[10]);}

/* k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17097(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,7)))){
C_save_and_reclaim((void *)f_17097,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17104,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17106,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[10],a[5]=((C_word)li201),tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_17106(t6,t2,((C_word*)t0)[11],C_fix(1),C_fix(0),C_fix(0),*((C_word*)lf[266]+1));}

/* k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17104(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_17104,c,av);}
a=C_alloc(11);
t2=C_i_vector_set(((C_word*)t0)[2],C_fix(0),t1);
t3=(C_truep(((C_word*)t0)[3])?C_fixnum_or(C_fix(0),C_fix(1)):C_fix(0));
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_16246,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:1640: sre-consumer? */
t5=lf[253];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[10];
f_16838(3,av2);}}

/* lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17106(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,6)))){
C_save_and_reclaim_args((void *)trf_17106,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(19);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17109,a[2]=t4,a[3]=t5,a[4]=t6,a[5]=((C_word)li186),tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(t2))){
if(C_truep(C_i_stringp(C_u_i_car(t2)))){
/* irregex-core.scm:1742: grow */
t8=t7;
f_17109(t8,t1,C_fix(1));}
else{
t8=C_u_i_car(t2);
t9=C_eqp(t8,lf[52]);
t10=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_17149,a[2]=t7,a[3]=t1,a[4]=t8,a[5]=((C_word*)t0)[2],a[6]=t3,a[7]=t4,a[8]=t5,a[9]=t6,a[10]=t2,a[11]=((C_word*)t0)[3],a[12]=((C_word*)t0)[4],tmp=(C_word)a,a+=13,tmp);
if(C_truep(t9)){
t11=t10;
f_17149(t11,t9);}
else{
t11=C_eqp(t8,lf[179]);
if(C_truep(t11)){
t12=t10;
f_17149(t12,t11);}
else{
t12=C_eqp(t8,lf[234]);
t13=t10;
f_17149(t13,(C_truep(t12)?t12:C_eqp(t8,lf[247])));}}}}
else{
if(C_truep(C_charp(t2))){
/* irregex-core.scm:1857: grow */
t8=t7;
f_17109(t8,t1,C_fix(1));}
else{
if(C_truep(C_i_stringp(t2))){
/* irregex-core.scm:1859: grow */
t8=t7;
f_17109(t8,t1,C_block_size(t2));}
else{
if(C_truep((C_truep(C_eqp(t2,lf[124]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[125]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
/* irregex-core.scm:1861: grow */
t8=t7;
f_17109(t8,t1,C_fix(1));}
else{
if(C_truep((C_truep(C_eqp(t2,lf[110]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[186]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[187]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[195]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[196]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[183]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[184]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[185]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[264]))?C_SCHEME_TRUE:C_SCHEME_FALSE))))))))))){
/* irregex-core.scm:1863: return */
t8=t6;{
C_word av2[4];
av2[0]=t8;
av2[1]=t1;
av2[2]=t4;
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
t8=C_i_assq(t2,lf[248]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18171,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
t10=C_i_cdr(t8);
if(C_truep(C_i_closurep(t10))){
/* irregex-core.scm:1867: g3031 */
t11=C_u_i_cdr(t8);{
C_word av2[2];
av2[0]=t11;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
/* irregex-core.scm:1867: lp */
t14=t1;
t15=C_u_i_cdr(t8);
t16=t3;
t17=t4;
t18=t5;
t19=t6;
t1=t14;
t2=t15;
t3=t16;
t4=t17;
t5=t18;
t6=t19;
goto loop;}}
else{
/* irregex-core.scm:1869: chicken.base#error */
t9=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t9;
av2[1]=t1;
av2[2]=lf[261];
av2[3]=lf[265];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}}}}}}}

/* grow in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17109(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_17109,3,t0,t1,t2);}
t3=C_fixnum_plus(((C_word*)t0)[2],t2);
if(C_truep(((C_word*)t0)[3])){
/* irregex-core.scm:1738: return */
t4=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
av2[3]=C_fixnum_plus(((C_word*)t0)[3],t2);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
/* irregex-core.scm:1738: return */
t4=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17149(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_17149,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
/* irregex-core.scm:1745: grow */
t2=((C_word*)t0)[2];
f_17109(t2,((C_word*)t0)[3],C_fix(1));}
else{
t2=C_eqp(((C_word*)t0)[4],lf[235]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17165,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1747: string->sre */
t4=*((C_word*)lf[102]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_cadr(((C_word*)t0)[10]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_eqp(((C_word*)t0)[4],lf[115]);
t4=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17178,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[4],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
if(C_truep(t3)){
t5=t4;
f_17178(t5,t3);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[227]);
if(C_truep(t5)){
t6=t4;
f_17178(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[225]);
if(C_truep(t6)){
t7=t4;
f_17178(t7,t6);}
else{
t7=C_eqp(((C_word*)t0)[4],lf[226]);
t8=t4;
f_17178(t8,(C_truep(t7)?t7:C_eqp(((C_word*)t0)[4],lf[239])));}}}}}}

/* k17163 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17165(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17165,c,av);}
/* irregex-core.scm:1747: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17106(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17178(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,6)))){
C_save_and_reclaim_args((void *)trf_17178,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17185,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t4,a[6]=((C_word*)t0)[6],a[7]=((C_word)li188),tmp=(C_word)a,a+=8,tmp));
t6=((C_word*)t4)[1];
f_17185(t6,((C_word*)t0)[7],t2,((C_word*)t0)[8],C_fix(0),C_fix(0));}
else{
t2=C_eqp(((C_word*)t0)[9],lf[103]);
if(C_truep(t2)){
t3=C_u_i_cdr(((C_word*)t0)[2]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17263,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t5,a[6]=((C_word*)t0)[6],a[7]=((C_word)li190),tmp=(C_word)a,a+=8,tmp));
t7=((C_word*)t5)[1];
f_17263(t7,((C_word*)t0)[7],t3,((C_word*)t0)[8],C_SCHEME_FALSE,C_fix(0));}
else{
t3=C_eqp(((C_word*)t0)[9],lf[109]);
if(C_truep(t3)){
t4=C_i_nullp(C_u_i_cdr(((C_word*)t0)[2]));
t5=(C_truep(t4)?t4:C_i_nullp(C_i_cddr(((C_word*)t0)[2])));
if(C_truep(t5)){
/* irregex-core.scm:1771: return */
t6=((C_word*)t0)[5];{
C_word av2[4];
av2[0]=t6;
av2[1]=((C_word*)t0)[7];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17356,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[4],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1773: sre-count-submatches */
f_16994(t6,C_u_i_car(((C_word*)t0)[2]));}}
else{
t4=C_eqp(((C_word*)t0)[9],lf[244]);
if(C_truep(t4)){
t5=(
/* irregex-core.scm:1792: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cdddr(((C_word*)t0)[2]))
);
t6=C_i_cadr(((C_word*)t0)[2]);
/* irregex-core.scm:1792: lp */
t7=((C_word*)((C_word*)t0)[6])[1];
f_17106(t7,((C_word*)t0)[7],t5,C_fixnum_plus(((C_word*)t0)[8],t6),((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t5=C_eqp(((C_word*)t0)[9],lf[245]);
t6=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17502,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[4],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(t5)){
t7=t6;
f_17502(t7,t5);}
else{
t7=C_eqp(((C_word*)t0)[9],lf[108]);
if(C_truep(t7)){
t8=t6;
f_17502(t8,t7);}
else{
t8=C_eqp(((C_word*)t0)[9],lf[119]);
t9=t6;
f_17502(t9,(C_truep(t8)?t8:C_eqp(((C_word*)t0)[9],lf[120])));}}}}}}}

/* lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17185(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,6)))){
C_save_and_reclaim_args((void *)trf_17185,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t6=C_fixnum_plus(((C_word*)t0)[2],t4);
if(C_truep(((C_word*)t0)[3])){
if(C_truep(t5)){
/* irregex-core.scm:1751: return */
t7=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_fixnum_plus(((C_word*)t0)[3],t5);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
/* irregex-core.scm:1751: return */
t7=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
/* irregex-core.scm:1751: return */
t7=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
t6=C_i_car(t2);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17218,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t5,a[6]=((C_word*)t0)[5],a[7]=((C_word)li187),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1752: lp */
t8=((C_word*)((C_word*)t0)[6])[1];
f_17106(t8,t1,t6,t3,C_fix(0),C_fix(0),t7);}}

/* a17217 in lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17218(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_17218,c,av);}
a=C_alloc(10);
t4=C_i_cdr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17248,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=t3,a[7]=((C_word*)t0)[6],a[8]=t1,a[9]=t4,tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:1755: sre-count-submatches */
f_16994(t5,C_u_i_car(((C_word*)t0)[2]));}

/* k17246 in a17217 in lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17248(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17248,c,av);}
t2=C_fixnum_plus(((C_word*)t0)[2],t1);
t3=C_fixnum_plus(((C_word*)t0)[3],((C_word*)t0)[4]);
if(C_truep(((C_word*)t0)[5])){
if(C_truep(((C_word*)t0)[6])){
/* irregex-core.scm:1754: lp2 */
t4=((C_word*)((C_word*)t0)[7])[1];
f_17185(t4,((C_word*)t0)[8],((C_word*)t0)[9],t2,t3,C_fixnum_plus(((C_word*)t0)[5],((C_word*)t0)[6]));}
else{
/* irregex-core.scm:1754: lp2 */
t4=((C_word*)((C_word*)t0)[7])[1];
f_17185(t4,((C_word*)t0)[8],((C_word*)t0)[9],t2,t3,C_SCHEME_FALSE);}}
else{
/* irregex-core.scm:1754: lp2 */
t4=((C_word*)((C_word*)t0)[7])[1];
f_17185(t4,((C_word*)t0)[8],((C_word*)t0)[9],t2,t3,C_SCHEME_FALSE);}}

/* lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17263(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,6)))){
C_save_and_reclaim_args((void *)trf_17263,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t6=(C_truep(t4)?C_fixnum_plus(((C_word*)t0)[2],t4):C_fixnum_plus(((C_word*)t0)[2],C_fix(1)));
if(C_truep(((C_word*)t0)[3])){
if(C_truep(t5)){
/* irregex-core.scm:1761: return */
t7=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_fixnum_plus(((C_word*)t0)[3],t5);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
/* irregex-core.scm:1761: return */
t7=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
/* irregex-core.scm:1761: return */
t7=((C_word*)t0)[4];{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
t6=C_i_car(t2);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17300,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=t5,a[6]=t4,a[7]=((C_word)li189),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1762: lp */
t8=((C_word*)((C_word*)t0)[6])[1];
f_17106(t8,t1,t6,t3,C_fix(0),C_fix(0),t7);}}

/* a17299 in lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17300(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_17300,c,av);}
a=C_alloc(10);
t4=C_i_cdr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17333,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t4,a[6]=((C_word*)t0)[5],a[7]=t3,a[8]=((C_word*)t0)[6],a[9]=t2,tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:1765: sre-count-submatches */
f_16994(t5,C_u_i_car(((C_word*)t0)[2]));}

/* k17314 in k17331 in a17299 in lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_17316(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_17316,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17320,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[6])){
if(C_truep(((C_word*)t0)[7])){
/* irregex-core.scm:1767: scheme#max */
t3=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* irregex-core.scm:1764: lp2 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_17263(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1,C_SCHEME_FALSE);}}
else{
/* irregex-core.scm:1764: lp2 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_17263(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1,C_SCHEME_FALSE);}}

/* k17318 in k17314 in k17331 in a17299 in lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_17320(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17320,c,av);}
/* irregex-core.scm:1764: lp2 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17263(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1);}

/* k17331 in a17299 in lp2 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17333(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_17333,c,av);}
a=C_alloc(8);
t2=C_fixnum_plus(((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17316,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)t0)[8])){
/* irregex-core.scm:1766: scheme#min */
t4=*((C_word*)lf[255]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
av2[3]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[9];
f_17316(2,av2);}}}

/* k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17356(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_17356,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17359,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:1774: sre-count-submatches */
f_16994(t2,C_i_cadr(((C_word*)t0)[2]));}

/* k17357 in k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17359(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_17359,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17366,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t3=C_i_cadr(((C_word*)t0)[2]);
t4=C_i_numberp(t3);
if(C_truep(t4)){
t5=t2;
f_17366(t5,(C_truep(t4)?lf[110]:C_u_i_car(C_u_i_cdr(((C_word*)t0)[2]))));}
else{
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=C_i_symbolp(C_u_i_car(t5));
t7=t2;
f_17366(t7,(C_truep(t6)?lf[110]:C_u_i_car(C_u_i_cdr(((C_word*)t0)[2]))));}}

/* k17364 in k17357 in k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17366(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,6)))){
C_save_and_reclaim_args((void *)trf_17366,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17368,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word)li193),tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1775: lp */
t3=((C_word*)((C_word*)t0)[7])[1];
f_17106(t3,((C_word*)t0)[8],t1,((C_word*)t0)[3],((C_word*)t0)[9],((C_word*)t0)[10],t2);}

/* a17367 in k17364 in k17357 in k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_17368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,6)))){
C_save_and_reclaim((void *)f_17368,c,av);}
a=C_alloc(11);
t4=C_i_caddr(((C_word*)t0)[2]);
t5=C_fixnum_plus(((C_word*)t0)[3],((C_word*)t0)[4]);
t6=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17382,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=t3,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word)li192),tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:1780: lp */
t7=((C_word*)((C_word*)t0)[7])[1];
f_17106(t7,t1,t4,t5,C_fix(0),C_fix(0),t6);}

/* a17381 in a17367 in k17364 in k17357 in k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_17382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,6)))){
C_save_and_reclaim((void *)f_17382,c,av);}
a=C_alloc(8);
t4=C_i_cdddr(((C_word*)t0)[2]);
t5=C_i_pairp(t4);
t6=(C_truep(t5)?C_i_cadddr(((C_word*)t0)[2]):lf[110]);
t7=C_fixnum_plus(C_fixnum_plus(((C_word*)t0)[3],((C_word*)t0)[4]),((C_word*)t0)[5]);
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17396,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=t3,a[5]=((C_word*)t0)[8],a[6]=t2,a[7]=((C_word)li191),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1782: lp */
t9=((C_word*)((C_word*)t0)[9])[1];
f_17106(t9,t1,t6,t7,C_fix(0),C_fix(0),t8);}

/* a17395 in a17381 in a17367 in k17364 in k17357 in k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in ... */
static void C_ccall f_17396(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_17396,c,av);}
a=C_alloc(8);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17425,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t3,a[6]=((C_word*)t0)[5],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:1787: scheme#min */
t5=*((C_word*)lf[255]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k17419 in k17423 in a17395 in a17381 in a17367 in k17364 in k17357 in k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in ... */
static void C_ccall f_17421(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17421,c,av);}
/* irregex-core.scm:1787: return */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_fixnum_plus(((C_word*)t0)[5],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17423 in a17395 in a17381 in a17367 in k17364 in k17357 in k17354 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in ... */
static void C_ccall f_17425(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_17425,c,av);}
a=C_alloc(6);
t2=C_fixnum_plus(((C_word*)t0)[2],t1);
if(C_truep(((C_word*)t0)[3])){
if(C_truep(((C_word*)t0)[4])){
if(C_truep(((C_word*)t0)[5])){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17421,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1789: scheme#max */
t4=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
/* irregex-core.scm:1787: return */
t3=((C_word*)t0)[6];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[7];
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}
else{
/* irregex-core.scm:1787: return */
t3=((C_word*)t0)[6];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[7];
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}
else{
/* irregex-core.scm:1787: return */
t3=((C_word*)t0)[6];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[7];
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17502(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,6)))){
C_save_and_reclaim_args((void *)trf_17502,2,t0,t1);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_eqp(lf[108],C_u_i_car(((C_word*)t0)[2]));
t3=(C_truep(t2)?(
/* irregex-core.scm:1794: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[2]))
):(
/* irregex-core.scm:1794: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cddr(((C_word*)t0)[2]))
));
t4=C_fixnum_plus(((C_word*)t0)[3],C_fix(1));
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17515,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word)li194),tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1794: lp */
t6=((C_word*)((C_word*)t0)[6])[1];
f_17106(t6,((C_word*)t0)[7],t3,t4,((C_word*)t0)[8],((C_word*)t0)[9],t5);}
else{
t2=C_eqp(((C_word*)t0)[10],lf[192]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[10],lf[191]));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17551,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
t5=C_i_cadr(((C_word*)t0)[2]);
if(C_truep(C_i_numberp(t5))){
t6=t4;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_u_i_car(C_u_i_cdr(((C_word*)t0)[2]));
f_17551(2,av2);}}
else{
t6=C_u_i_cdr(((C_word*)t0)[2]);
t7=C_i_assq(C_u_i_car(t6),((C_word*)t0)[11]);
if(C_truep(t7)){
t8=t4;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_i_cdr(t7);
f_17551(2,av2);}}
else{
t8=C_u_i_cdr(((C_word*)t0)[2]);
/* irregex-core.scm:1804: chicken.base#error */
t9=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t9;
av2[1]=t4;
av2[2]=lf[259];
av2[3]=C_u_i_car(t8);
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}}}
else{
t4=C_eqp(((C_word*)t0)[10],lf[127]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[10],lf[128]));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17660,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
t7=(
/* irregex-core.scm:1816: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[2]))
);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17669,a[2]=((C_word)li195),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1816: lp */
t9=((C_word*)((C_word*)t0)[6])[1];
f_17106(t9,t6,t7,((C_word*)t0)[3],((C_word*)t0)[8],((C_word*)t0)[9],t8);}
else{
t6=C_eqp(((C_word*)t0)[10],lf[133]);
t7=(C_truep(t6)?t6:C_eqp(((C_word*)t0)[10],lf[130]));
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17687,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
t9=C_i_cadr(((C_word*)t0)[2]);
if(C_truep(C_i_numberp(t9))){
t10=C_i_caddr(((C_word*)t0)[2]);
if(C_truep(C_i_numberp(t10))){
t11=C_u_i_cdr(((C_word*)t0)[2]);
t12=C_u_i_car(t11);
t13=C_u_i_cdr(((C_word*)t0)[2]);
t14=C_u_i_cdr(t13);
t15=t8;
f_17687(t15,C_fixnum_greaterp(t12,C_u_i_car(t14)));}
else{
t11=t8;
f_17687(t11,C_SCHEME_FALSE);}}
else{
t10=t8;
f_17687(t10,C_SCHEME_FALSE);}}
else{
t8=C_eqp(((C_word*)t0)[10],lf[129]);
if(C_truep(t8)){
t9=(
/* irregex-core.scm:1835: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[2]))
);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17829,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[8],a[4]=((C_word)li198),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1835: lp */
t11=((C_word*)((C_word*)t0)[6])[1];
f_17106(t11,((C_word*)t0)[7],t9,((C_word*)t0)[3],((C_word*)t0)[8],((C_word*)t0)[9],t10);}
else{
t9=C_eqp(((C_word*)t0)[10],lf[131]);
t10=(C_truep(t9)?t9:C_eqp(((C_word*)t0)[10],lf[132]));
if(C_truep(t10)){
t11=(
/* irregex-core.scm:1839: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[2]))
);
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17857,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[8],a[5]=((C_word)li199),tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1839: lp */
t13=((C_word*)((C_word*)t0)[6])[1];
f_17106(t13,((C_word*)t0)[7],t11,((C_word*)t0)[3],((C_word*)t0)[8],((C_word*)t0)[9],t12);}
else{
t11=C_eqp(((C_word*)t0)[10],lf[134]);
t12=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17882,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t11)){
t13=t12;
f_17882(t13,t11);}
else{
t13=C_eqp(((C_word*)t0)[10],lf[263]);
if(C_truep(t13)){
t14=t12;
f_17882(t14,t13);}
else{
t14=C_eqp(((C_word*)t0)[10],lf[135]);
t15=t12;
f_17882(t15,(C_truep(t14)?t14:C_eqp(((C_word*)t0)[10],lf[260])));}}}}}}}}}

/* a17514 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17515(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_17515,c,av);}
a=C_alloc(3);
t4=C_a_i_cons(&a,2,t2,t3);
t5=C_i_vector_set(((C_word*)t0)[2],((C_word*)t0)[3],t4);
/* irregex-core.scm:1799: return */
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k17549 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_17551,c,av);}
a=C_alloc(9);
t2=C_i_not(C_i_integerp(t1));
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17560,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t2)){
t4=t3;
f_17560(t4,t2);}
else{
t4=C_block_size(((C_word*)t0)[4]);
t5=t3;
f_17560(t5,C_i_not(C_and(C_fixnum_lessp(C_fix(0),t1),C_fixnum_lessp(t1,t4))));}}

/* k17558 in k17549 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17560(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_17560,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:1808: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[256];
av2[3]=lf[257];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=C_i_vector_ref(((C_word*)t0)[4],((C_word*)t0)[5]);
if(C_truep(C_i_not(t2))){
/* irregex-core.scm:1810: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[256];
av2[3]=lf[258];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=C_i_vector_ref(((C_word*)t0)[4],((C_word*)t0)[5]);
t4=C_i_car(t3);
t5=C_i_vector_ref(((C_word*)t0)[4],((C_word*)t0)[5]);
t6=C_i_cdr(t5);
t7=C_fixnum_plus(((C_word*)t0)[6],t4);
if(C_truep(((C_word*)t0)[7])){
if(C_truep(t6)){
/* irregex-core.scm:1814: return */
t8=((C_word*)t0)[8];{
C_word av2[4];
av2[0]=t8;
av2[1]=((C_word*)t0)[2];
av2[2]=t7;
av2[3]=C_fixnum_plus(((C_word*)t0)[7],t6);
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
/* irregex-core.scm:1814: return */
t8=((C_word*)t0)[8];{
C_word av2[4];
av2[0]=t8;
av2[1]=((C_word*)t0)[2];
av2[2]=t7;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}}
else{
/* irregex-core.scm:1814: return */
t8=((C_word*)t0)[8];{
C_word av2[4];
av2[0]=t8;
av2[1]=((C_word*)t0)[2];
av2[2]=t7;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}}}}

/* k17658 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17660,c,av);}
/* irregex-core.scm:1817: return */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a17668 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17669(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17669,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k17685 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17687(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_17687,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17690,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t1)){
t3=t2;
f_17690(t3,t1);}
else{
t3=C_u_i_cdr(((C_word*)t0)[6]);
t4=C_i_not(C_u_i_car(t3));
t5=t2;
f_17690(t5,(C_truep(t4)?C_i_caddr(((C_word*)t0)[6]):C_SCHEME_FALSE));}}

/* k17688 in k17685 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17690(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,6)))){
C_save_and_reclaim_args((void *)trf_17690,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
/* irregex-core.scm:1824: return */
t2=((C_word*)t0)[2];{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
if(C_truep(C_i_caddr(((C_word*)t0)[6]))){
t2=C_u_i_cdr(((C_word*)t0)[6]);
t3=C_u_i_cdr(t2);
t4=(
/* irregex-core.scm:1827: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t3))
);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17708,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word)li196),tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:1827: lp */
t6=((C_word*)((C_word*)t0)[7])[1];
f_17106(t6,((C_word*)t0)[3],t4,((C_word*)t0)[8],C_fix(0),C_fix(0),t5);}
else{
t2=(
/* irregex-core.scm:1831: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cdddr(((C_word*)t0)[6]))
);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17755,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word)li197),tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1831: lp */
t4=((C_word*)((C_word*)t0)[7])[1];
f_17106(t4,((C_word*)t0)[3],t2,((C_word*)t0)[8],C_fix(0),C_fix(0),t3);}}}

/* a17707 in k17688 in k17685 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_17708(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17708,c,av);}
t4=C_i_cadr(((C_word*)t0)[2]);
t5=C_fixnum_times(t4,t2);
t6=C_fixnum_plus(((C_word*)t0)[3],t5);
if(C_truep(((C_word*)t0)[4])){
if(C_truep(t3)){
t7=C_i_caddr(((C_word*)t0)[2]);
t8=C_fixnum_times(t7,t3);
/* irregex-core.scm:1829: return */
t9=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t9;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_fixnum_plus(((C_word*)t0)[4],t8);
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
/* irregex-core.scm:1829: return */
t7=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
/* irregex-core.scm:1829: return */
t7=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}

/* a17754 in k17688 in k17685 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_17755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17755,c,av);}
t4=C_i_cadr(((C_word*)t0)[2]);
t5=C_fixnum_times(t4,t2);
/* irregex-core.scm:1833: return */
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=C_fixnum_plus(((C_word*)t0)[4],t5);
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* a17828 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17829,c,av);}
/* irregex-core.scm:1837: return */
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=C_fixnum_plus(((C_word*)t0)[3],t2);
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* a17856 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_17857(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17857,c,av);}
if(C_truep(((C_word*)t0)[2])){
if(C_truep(t3)){
/* irregex-core.scm:1841: return */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[4];
av2[3]=C_fixnum_plus(((C_word*)t0)[2],t3);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
/* irregex-core.scm:1841: return */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}
else{
/* irregex-core.scm:1841: return */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k17880 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17882(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_17882,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17901,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t4=C_u_i_car(((C_word*)t0)[2]);
if(C_truep((C_truep(C_eqp(t4,lf[135]))?C_SCHEME_TRUE:(C_truep(C_eqp(t4,lf[260]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=C_u_i_cdr(t5);
t7=t3;
f_17901(t7,C_a_i_cons(&a,2,C_SCHEME_FALSE,t6));}
else{
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=C_u_i_car(t5);
t7=C_u_i_cdr(((C_word*)t0)[2]);
t8=C_u_i_cdr(t7);
t9=t3;
f_17901(t9,C_a_i_cons(&a,2,t6,t8));}}
else{
t2=C_eqp(((C_word*)t0)[9],lf[111]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17922,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t2)){
t4=t3;
f_17922(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[9],lf[112]);
if(C_truep(t4)){
t5=t3;
f_17922(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[9],lf[113]);
t6=t3;
f_17922(t6,(C_truep(t5)?t5:C_eqp(((C_word*)t0)[9],lf[114])));}}}}

/* k17899 in k17880 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17901(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,6)))){
C_save_and_reclaim_args((void *)trf_17901,2,t0,t1);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_cons(&a,2,lf[133],t2);
/* irregex-core.scm:1843: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_17106(t4,((C_word*)t0)[4],t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k17920 in k17880 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_17922(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_17922,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
/* irregex-core.scm:1848: return */
t2=((C_word*)t0)[2];{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_i_assq(C_u_i_car(((C_word*)t0)[6]),lf[248]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17932,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[6],a[8]=((C_word)li200),tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:1850: g3027 */
t4=t3;
f_17932(t4,((C_word*)t0)[3],t2);}
else{
/* irregex-core.scm:1855: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[261];
av2[3]=lf[262];
av2[4]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}}

/* g3027 in k17920 in k17880 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_fcall f_17932(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_17932,3,t0,t1,t2);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17940,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);{
C_word av2[4];
av2[0]=0;
av2[1]=t3;
av2[2]=C_i_cdr(t2);
av2[3]=C_i_cdr(((C_word*)t0)[7]);
C_apply(4,av2);}}

/* k17938 in g3027 in k17920 in k17880 in k17500 in k17176 in k17147 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_17940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17940,c,av);}
/* irregex-core.scm:1853: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17106(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k18169 in lp in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_18171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_18171,c,av);}
/* irregex-core.scm:1867: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17106(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k18192 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_18194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_18194,c,av);}
/* irregex-core.scm:1733: scheme#make-vector */
t2=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fixnum_plus(C_fix(1),t1);
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.irregex#sre-sequence in k7767 in k7542 in k7539 */
static C_word C_fcall f_18203(C_word *a,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;{}
if(C_truep(C_i_nullp(t1))){
return(lf[110]);}
else{
t2=C_i_cdr(t1);
t3=C_i_nullp(t2);
return((C_truep(t3)?C_u_i_car(t1):C_a_i_cons(&a,2,lf[115],t1)));}}

/* chicken.irregex#sre-alternate in k7767 in k7542 in k7539 */
static C_word C_fcall f_18226(C_word *a,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;{}
if(C_truep(C_i_nullp(t1))){
return(lf[282]);}
else{
t2=C_i_cdr(t1);
t3=C_i_nullp(t2);
return((C_truep(t3)?C_u_i_car(t1):C_a_i_cons(&a,2,lf[103],t1)));}}

/* chicken.irregex#sre-strip-submatches in k7767 in k7542 in k7539 */
static void C_ccall f_18249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
loop:
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
av[0]=t0;
av[1]=t1;
av[2]=t2;
C_save_and_reclaim((void *)f_18249,c,av);}
a=C_alloc(13);
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=C_eqp(t4,lf[245]);
t6=(C_truep(t5)?t5:C_eqp(t4,lf[108]));
if(C_truep(t6)){
t7=(
/* irregex-core.scm:1894: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t2))
);
/* irregex-core.scm:1894: sre-strip-submatches */
t19=t1;
t20=t7;
t1=t19;
t2=t20;
c=3;
goto loop;}
else{
t7=C_eqp(t4,lf[119]);
t8=(C_truep(t7)?t7:C_eqp(t4,lf[120]));
if(C_truep(t8)){
t9=(
/* irregex-core.scm:1895: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cddr(t2))
);
/* irregex-core.scm:1895: sre-strip-submatches */
t19=t1;
t20=t9;
t1=t19;
t2=t20;
c=3;
goto loop;}
else{
t9=C_eqp(t4,lf[244]);
if(C_truep(t9)){
t10=(
/* irregex-core.scm:1896: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cdddr(t2))
);
/* irregex-core.scm:1896: sre-strip-submatches */
t19=t1;
t20=t10;
t1=t19;
t2=t20;
c=3;
goto loop;}
else{
t10=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t11=t10;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=((C_word*)t12)[1];
t14=lf[283];
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18322,a[2]=t12,a[3]=t16,a[4]=t13,a[5]=((C_word)li225),tmp=(C_word)a,a+=6,tmp));
t18=((C_word*)t16)[1];
f_18322(t18,t1,t2);}}}}}

/* map-loop3064 in chicken.irregex#sre-strip-submatches in k7767 in k7542 in k7539 */
static void C_fcall f_18322(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_18322,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18347,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1897: g3070 */
t4=lf[283];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_18249(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18345 in map-loop3064 in chicken.irregex#sre-strip-submatches in k7767 in k7542 in k7539 */
static void C_ccall f_18347(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_18347,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_18322(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* lp in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_18382(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_18382,4,t0,t1,t2,t3);}
a=C_alloc(9);
if(C_truep(C_i_nullp(t2))){
/* irregex-core.scm:1905: ##sys#fast-reverse */
t4=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=C_i_car(t2);
if(C_truep(C_i_stringp(t4))){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18405,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18409,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* ##sys#string->list */
t7=*((C_word*)lf[105]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_u_i_car(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=C_u_i_cdr(t2);
t6=C_u_i_car(t2);
t7=C_a_i_cons(&a,2,t6,t3);
/* irregex-core.scm:1909: lp */
t9=t1;
t10=t5;
t11=t7;
t1=t9;
t2=t10;
t3=t11;
goto loop;}}}

/* k18403 in lp in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_18405(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_18405,c,av);}
/* irregex-core.scm:1907: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_18382(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4]);}

/* k18407 in lp in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_18409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_18409,c,av);}
/* irregex-core.scm:1907: scheme#append */
t2=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_u_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.irregex#sre-names in k7767 in k7542 in k7539 */
static void C_fcall f_18430(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_18430,4,t1,t2,t3,t4);}
a=C_alloc(9);
t5=C_i_pairp(t2);
if(C_truep(C_i_not(t5))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_i_car(t2);
t7=C_eqp(t6,lf[245]);
t8=(C_truep(t7)?t7:C_eqp(t6,lf[108]));
if(C_truep(t8)){
t9=(
/* irregex-core.scm:1916: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t2))
);
/* irregex-core.scm:1916: sre-names */
t28=t1;
t29=t9;
t30=C_fixnum_plus(t3,C_fix(1));
t31=t4;
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;}
else{
t9=C_eqp(t6,lf[119]);
t10=(C_truep(t9)?t9:C_eqp(t6,lf[120]));
if(C_truep(t10)){
t11=(
/* irregex-core.scm:1918: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cddr(t2))
);
t12=C_fixnum_plus(t3,C_fix(1));
t13=C_i_cadr(t2);
t14=C_a_i_cons(&a,2,t13,t3);
t15=C_a_i_cons(&a,2,t14,t4);
/* irregex-core.scm:1918: sre-names */
t28=t1;
t29=t11;
t30=t12;
t31=t15;
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;}
else{
t11=C_eqp(t6,lf[244]);
if(C_truep(t11)){
t12=(
/* irregex-core.scm:1922: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cdddr(t2))
);
t13=C_i_cadr(t2);
/* irregex-core.scm:1922: sre-names */
t28=t1;
t29=t12;
t30=C_fixnum_plus(t3,t13);
t31=t4;
t1=t28;
t2=t29;
t3=t30;
t4=t31;
goto loop;}
else{
t12=C_eqp(t6,lf[115]);
t13=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18532,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t12)){
t14=t13;
f_18532(t14,t12);}
else{
t14=C_eqp(t6,lf[227]);
if(C_truep(t14)){
t15=t13;
f_18532(t15,t14);}
else{
t15=C_eqp(t6,lf[103]);
if(C_truep(t15)){
t16=t13;
f_18532(t16,t15);}
else{
t16=C_eqp(t6,lf[127]);
if(C_truep(t16)){
t17=t13;
f_18532(t17,t16);}
else{
t17=C_eqp(t6,lf[129]);
if(C_truep(t17)){
t18=t13;
f_18532(t18,t17);}
else{
t18=C_eqp(t6,lf[131]);
if(C_truep(t18)){
t19=t13;
f_18532(t19,t18);}
else{
t19=C_eqp(t6,lf[128]);
if(C_truep(t19)){
t20=t13;
f_18532(t20,t19);}
else{
t20=C_eqp(t6,lf[132]);
if(C_truep(t20)){
t21=t13;
f_18532(t21,t20);}
else{
t21=C_eqp(t6,lf[225]);
if(C_truep(t21)){
t22=t13;
f_18532(t22,t21);}
else{
t22=C_eqp(t6,lf[226]);
if(C_truep(t22)){
t23=t13;
f_18532(t23,t22);}
else{
t23=C_eqp(t6,lf[239]);
if(C_truep(t23)){
t24=t13;
f_18532(t24,t23);}
else{
t24=C_eqp(t6,lf[111]);
if(C_truep(t24)){
t25=t13;
f_18532(t25,t24);}
else{
t25=C_eqp(t6,lf[113]);
if(C_truep(t25)){
t26=t13;
f_18532(t26,t25);}
else{
t26=C_eqp(t6,lf[112]);
t27=t13;
f_18532(t27,(C_truep(t26)?t26:C_eqp(t6,lf[114])));}}}}}}}}}}}}}}}}}}

/* k18530 in chicken.irregex#sre-names in k7767 in k7542 in k7539 */
static void C_fcall f_18532(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_18532,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:1925: sre-sequence-names */
f_18716(((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[3]),((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t2=C_eqp(((C_word*)t0)[6],lf[134]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[6],lf[135]));
if(C_truep(t3)){
/* irregex-core.scm:1927: sre-sequence-names */
f_18716(((C_word*)t0)[2],C_i_cddr(((C_word*)t0)[3]),((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t4=C_eqp(((C_word*)t0)[6],lf[133]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[6],lf[130]));
if(C_truep(t5)){
/* irregex-core.scm:1929: sre-sequence-names */
f_18716(((C_word*)t0)[2],C_i_cdddr(((C_word*)t0)[3]),((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t6=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t6;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}

/* chicken.irregex#sre-sequence-names in k7767 in k7542 in k7539 */
static void C_fcall f_18716(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_18716,4,t1,t2,t3,t4);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_cdr(t2);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18744,a[2]=t3,a[3]=t1,a[4]=t5,a[5]=t2,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:1937: sre-count-submatches */
f_16994(t6,C_u_i_car(t2));}}

/* k18736 in k18742 in chicken.irregex#sre-sequence-names in k7767 in k7542 in k7539 */
static void C_ccall f_18738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18738,c,av);}
/* irregex-core.scm:1936: sre-sequence-names */
f_18716(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k18742 in chicken.irregex#sre-sequence-names in k7767 in k7542 in k7539 */
static void C_ccall f_18744(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_18744,c,av);}
a=C_alloc(5);
t2=C_fixnum_plus(((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18738,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:1938: sre-names */
f_18430(t3,C_u_i_car(((C_word*)t0)[5]),((C_word*)t0)[2],((C_word*)t0)[6]);}

/* chicken.irregex#sre-remove-initial-bos in k7767 in k7542 in k7539 */
static void C_ccall f_18748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_18748,c,av);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[115]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18765,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t4)){
t6=t5;
f_18765(t6,t4);}
else{
t6=C_eqp(t3,lf[227]);
if(C_truep(t6)){
t7=t5;
f_18765(t7,t6);}
else{
t7=C_eqp(t3,lf[245]);
if(C_truep(t7)){
t8=t5;
f_18765(t8,t7);}
else{
t8=C_eqp(t3,lf[108]);
if(C_truep(t8)){
t9=t5;
f_18765(t9,t8);}
else{
t9=C_eqp(t3,lf[119]);
if(C_truep(t9)){
t10=t5;
f_18765(t10,t9);}
else{
t10=C_eqp(t3,lf[120]);
if(C_truep(t10)){
t11=t5;
f_18765(t11,t10);}
else{
t11=C_eqp(t3,lf[127]);
t12=t5;
f_18765(t12,(C_truep(t11)?t11:C_eqp(t3,lf[129])));}}}}}}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18763 in chicken.irregex#sre-remove-initial-bos in k7767 in k7542 in k7539 */
static void C_fcall f_18765(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,3)))){
C_save_and_reclaim_args((void *)trf_18765,2,t0,t1);}
a=C_alloc(16);
if(C_truep(t1)){
t2=C_i_pairp(C_u_i_cdr(((C_word*)t0)[2]));
if(C_truep(C_i_not(t2))){
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_cadr(((C_word*)t0)[2]);
t4=C_eqp(lf[186],t3);
if(C_truep(t4)){
t5=C_u_i_car(((C_word*)t0)[2]);
t6=C_u_i_cdr(((C_word*)t0)[2]);
t7=C_u_i_cdr(t6);
t8=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t8;
av2[1]=C_a_i_cons(&a,2,t5,t7);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t5=C_u_i_car(((C_word*)t0)[2]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18798,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t5,tmp=(C_word)a,a+=5,tmp);
t7=C_u_i_cdr(((C_word*)t0)[2]);
/* irregex-core.scm:1952: sre-remove-initial-bos */
t8=lf[270];{
C_word av2[3];
av2[0]=t8;
av2[1]=t6;
av2[2]=C_u_i_car(t7);
f_18748(3,av2);}}}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[103]);
if(C_truep(t2)){
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=lf[270];
t8=C_u_i_cdr(((C_word*)t0)[2]);
t9=C_i_check_list_2(t8,lf[211]);
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18835,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18837,a[2]=t5,a[3]=t12,a[4]=t6,a[5]=((C_word)li229),tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_18837(t14,t10,t8);}
else{
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k18796 in k18763 in chicken.irregex#sre-remove-initial-bos in k7767 in k7542 in k7539 */
static void C_ccall f_18798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_18798,c,av);}
a=C_alloc(6);
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k18833 in k18763 in chicken.irregex#sre-remove-initial-bos in k7767 in k7542 in k7539 */
static void C_ccall f_18835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18835,c,av);}
a=C_alloc(3);
/* irregex-core.scm:1954: sre-alternate */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(
/* irregex-core.scm:1954: sre-alternate */
  f_18226(C_a_i(&a,3),t1)
);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop3205 in k18763 in chicken.irregex#sre-remove-initial-bos in k7767 in k7542 in k7539 */
static void C_fcall f_18837(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_18837,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18862,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1954: g3211 */
t4=lf[270];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_18748(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18860 in map-loop3205 in k18763 in chicken.irregex#sre-remove-initial-bos in k7767 in k7542 in k7539 */
static void C_ccall f_18862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_18862,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_18837(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_18930(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word t69;
C_word t70;
C_word t71;
C_word t72;
C_word t73;
C_word t74;
C_word t75;
C_word t76;
C_word t77;
C_word t78;
C_word t79;
C_word t80;
C_word t81;
C_word t82;
C_word t83;
C_word t84;
C_word t85;
C_word t86;
C_word t87;
C_word t88;
C_word t89;
C_word t90;
C_word t91;
C_word t92;
C_word t93;
C_word t94;
C_word t95;
C_word t96;
C_word t97;
C_word t98;
C_word t99;
C_word t100;
C_word t101;
C_word t102;
C_word t103;
C_word t104;
C_word t105;
C_word t106;
C_word t107;
C_word t108;
C_word t109;
C_word t110;
C_word t111;
C_word t112;
C_word t113;
C_word t114;
C_word t115;
C_word t116;
C_word t117;
C_word t118;
C_word t119;
C_word t120;
C_word t121;
C_word t122;
C_word t123;
C_word t124;
C_word t125;
C_word t126;
C_word t127;
C_word t128;
C_word t129;
C_word t130;
C_word t131;
C_word t132;
C_word t133;
C_word t134;
C_word t135;
C_word t136;
C_word t137;
C_word t138;
C_word t139;
C_word t140;
C_word t141;
C_word t142;
C_word t143;
C_word t144;
C_word t145;
C_word t146;
C_word t147;
C_word t148;
C_word t149;
C_word t150;
C_word t151;
C_word t152;
C_word t153;
C_word t154;
C_word t155;
C_word t156;
C_word t157;
C_word t158;
C_word t159;
C_word t160;
C_word t161;
C_word t162;
C_word t163;
C_word t164;
C_word t165;
C_word t166;
C_word t167;
C_word t168;
C_word t169;
C_word t170;
C_word t171;
C_word t172;
C_word t173;
C_word t174;
C_word t175;
C_word t176;
C_word t177;
C_word t178;
C_word t179;
C_word t180;
C_word t181;
C_word t182;
C_word t183;
C_word t184;
C_word t185;
C_word t186;
C_word t187;
C_word t188;
C_word t189;
C_word t190;
C_word t191;
C_word t192;
C_word t193;
C_word t194;
C_word t195;
C_word t196;
C_word t197;
C_word t198;
C_word t199;
C_word t200;
C_word t201;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(1667,c,10)))){
C_save_and_reclaim((void *)f_18930,c,av);}
a=C_alloc(1667);
t2=C_mutate(&lf[285] /* (set! chicken.irregex#irregex-basic-string-chunker ...) */,t1);
t3=C_mutate((C_word*)lf[286]+1 /* (set! chicken.irregex#irregex-search ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18932,a[2]=((C_word)li231),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[287]+1 /* (set! chicken.irregex#irregex-search/chunked ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19022,a[2]=((C_word)li232),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate(&lf[292] /* (set! chicken.irregex#irregex-search/matches ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19065,a[2]=((C_word)li241),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[298]+1 /* (set! chicken.irregex#irregex-match ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19314,a[2]=((C_word)li242),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[299]+1 /* (set! chicken.irregex#irregex-match/chunked ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19404,a[2]=((C_word)li245),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[304]+1 /* (set! chicken.irregex#irregex-match? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19632,a[2]=((C_word)li246),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate(&lf[305] /* (set! chicken.irregex#finalize! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19828,a[2]=((C_word)li249),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate(&lf[295] /* (set! chicken.irregex#dfa-match/longest ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19947,a[2]=((C_word)li262),tmp=(C_word)a,a+=3,tmp));
t11=C_a_i_cons(&a,2,lf[124],lf[53]);
t12=C_a_i_string(&a,1,C_make_character(10));
t13=C_a_i_list(&a,1,t12);
t14=C_a_i_list(&a,4,lf[125],lf[247],lf[53],t13);
t15=C_a_i_list(&a,6,lf[307],lf[52],C_make_character(97),C_make_character(122),C_make_character(65),C_make_character(90));
t16=C_a_i_cons(&a,2,lf[308],lf[307]);
t17=C_a_i_list(&a,8,lf[181],lf[52],C_make_character(97),C_make_character(122),C_make_character(65),C_make_character(90),C_make_character(48),C_make_character(57));
t18=C_a_i_cons(&a,2,lf[309],lf[181]);
t19=C_a_i_cons(&a,2,lf[310],lf[181]);
t20=C_a_i_list(&a,4,lf[311],lf[52],C_make_character(97),C_make_character(122));
t21=C_a_i_cons(&a,2,lf[312],lf[311]);
t22=C_a_i_list(&a,4,lf[313],lf[52],C_make_character(65),C_make_character(90));
t23=C_a_i_cons(&a,2,lf[314],lf[313]);
t24=C_a_i_list(&a,4,lf[178],lf[52],C_make_character(48),C_make_character(57));
t25=C_a_i_cons(&a,2,lf[315],lf[178]);
t26=C_a_i_cons(&a,2,lf[316],lf[178]);
t27=C_a_i_list(&a,25,lf[317],lf[103],C_make_character(33),C_make_character(34),C_make_character(35),C_make_character(37),C_make_character(38),C_make_character(39),C_make_character(40),C_make_character(41),C_make_character(42),C_make_character(44),C_make_character(45),C_make_character(46),C_make_character(47),C_make_character(58),C_make_character(59),C_make_character(63),C_make_character(64),C_make_character(91),C_make_character(92),C_make_character(93),C_make_character(95),C_make_character(123),C_make_character(125));
t28=C_a_i_cons(&a,2,lf[318],lf[317]);
t29=C_a_i_list(&a,13,lf[319],lf[103],lf[181],lf[317],C_make_character(36),C_make_character(43),C_make_character(60),C_make_character(61),C_make_character(62),C_make_character(94),C_make_character(96),C_make_character(124),C_make_character(126));
t30=C_a_i_cons(&a,2,lf[320],lf[319]);
t31=C_a_i_list(&a,4,lf[321],lf[103],C_make_character(32),C_make_character(9));
t32=C_a_i_list(&a,7,lf[322],lf[103],lf[321],C_make_character(10),C_make_character(12),C_make_character(13),C_make_character(11));
t33=C_a_i_cons(&a,2,lf[79],lf[322]);
t34=C_a_i_cons(&a,2,lf[323],lf[322]);
t35=C_a_i_list(&a,4,lf[324],lf[103],lf[319],lf[322]);
t36=C_a_i_cons(&a,2,lf[325],lf[324]);
t37=C_a_i_list(&a,4,lf[326],lf[52],C_make_character(0),C_make_character(31));
t38=C_a_i_cons(&a,2,lf[327],lf[326]);
t39=C_a_i_list(&a,5,lf[52],C_make_character(97),C_make_character(102),C_make_character(65),C_make_character(70));
t40=C_a_i_list(&a,4,lf[328],lf[103],lf[178],t39);
t41=C_a_i_cons(&a,2,lf[329],lf[328]);
t42=C_a_i_list(&a,4,lf[330],lf[52],C_make_character(0),C_make_character(127));
t43=C_a_i_list(&a,6,lf[331],lf[52],C_make_character(0),C_make_character(9),C_make_character(11),C_make_character(127));
t44=C_a_i_list(&a,3,lf[115],C_make_character(13),C_make_character(10));
t45=C_a_i_list(&a,3,lf[52],C_make_character(10),C_make_character(13));
t46=C_a_i_list(&a,4,lf[80],lf[103],t44,t45);
t47=C_a_i_list(&a,3,lf[103],lf[181],C_make_character(95));
t48=C_a_i_list(&a,2,lf[129],t47);
t49=C_a_i_list(&a,5,lf[231],lf[115],lf[183],t48,lf[184]);
t50=C_a_i_list(&a,4,lf[332],lf[52],C_make_character(128),C_make_character(193));
t51=C_a_i_list(&a,3,lf[52],C_make_character(194),C_make_character(223));
t52=C_a_i_list(&a,4,lf[333],lf[115],t51,lf[332]);
t53=C_a_i_list(&a,3,lf[52],C_make_character(224),C_make_character(239));
t54=C_a_i_list(&a,5,lf[334],lf[115],t53,lf[332],lf[332]);
t55=C_a_i_list(&a,3,lf[52],C_make_character(240),C_make_character(247));
t56=C_a_i_list(&a,6,lf[335],lf[115],t55,lf[332],lf[332],lf[332]);
t57=C_a_i_list(&a,6,lf[274],lf[103],lf[330],lf[333],lf[334],lf[335]);
t58=C_a_i_list(&a,6,lf[275],lf[103],lf[331],lf[333],lf[334],lf[335]);
t59=C_a_i_list(&a,3,lf[103],C_make_character(43),C_make_character(45));
t60=C_a_i_list(&a,2,lf[131],t59);
t61=C_a_i_list(&a,2,lf[129],lf[178]);
t62=C_a_i_list(&a,4,lf[336],lf[115],t60,t61);
t63=C_a_i_list(&a,3,lf[103],C_make_character(43),C_make_character(45));
t64=C_a_i_list(&a,2,lf[131],t63);
t65=C_a_i_list(&a,2,lf[129],lf[178]);
t66=C_a_i_list(&a,2,lf[129],lf[178]);
t67=C_a_i_list(&a,3,lf[131],C_make_character(46),t66);
t68=C_a_i_list(&a,3,lf[103],C_make_character(101),C_make_character(69));
t69=C_a_i_list(&a,3,lf[131],t68,lf[336]);
t70=C_a_i_list(&a,6,lf[337],lf[115],t64,t65,t67,t69);
t71=C_a_i_list(&a,1,lf[338]);
t72=C_a_i_list(&a,4,lf[339],lf[103],lf[308],t71);
t73=C_a_i_list(&a,1,lf[340]);
t74=C_a_i_list(&a,5,lf[341],lf[103],lf[339],lf[316],t73);
t75=C_a_i_list(&a,2,lf[127],lf[341]);
t76=C_a_i_list(&a,3,lf[115],lf[339],t75);
t77=C_a_i_list(&a,1,lf[342]);
t78=C_a_i_list(&a,2,lf[127],lf[341]);
t79=C_a_i_list(&a,3,lf[131],lf[339],t78);
t80=C_a_i_list(&a,3,lf[115],t77,t79);
t81=C_a_i_list(&a,2,lf[127],lf[343]);
t82=C_a_i_list(&a,3,lf[115],lf[344],t81);
t83=C_a_i_list(&a,5,lf[345],lf[103],t76,t80,t82);
t84=C_a_i_list(&a,2,lf[127],lf[79]);
t85=C_a_i_list(&a,2,lf[127],lf[125]);
t86=C_a_i_list(&a,5,lf[127],t84,lf[346],t85,lf[80]);
t87=C_a_i_list(&a,2,lf[129],lf[79]);
t88=C_a_i_list(&a,4,lf[347],lf[115],t86,t87);
t89=C_a_i_list(&a,3,lf[348],C_make_character(92),C_make_character(34));
t90=C_a_i_list(&a,5,lf[349],lf[115],C_make_character(34),t89,C_make_character(34));
t91=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30813,a[2]=((C_word)li263),tmp=(C_word)a,a+=3,tmp);
t92=C_a_i_cons(&a,2,lf[348],t91);
t93=C_a_i_list(&a,2,lf[52],lf[350]);
t94=C_a_i_list(&a,2,lf[131],t93);
t95=C_a_i_list(&a,2,lf[131],lf[178]);
t96=C_a_i_list(&a,5,lf[351],lf[115],t94,t95,lf[178]);
t97=C_a_i_list(&a,4,lf[134],C_fix(3),C_make_character(46),lf[351]);
t98=C_a_i_list(&a,4,lf[352],lf[115],lf[351],t97);
t99=C_a_i_list(&a,4,lf[133],C_fix(0),C_fix(4),lf[328]);
t100=C_a_i_list(&a,2,lf[131],C_make_character(58));
t101=C_a_i_list(&a,4,lf[133],C_fix(0),C_fix(4),lf[328]);
t102=C_a_i_list(&a,6,lf[133],C_fix(1),C_fix(7),C_make_character(58),t100,t101);
t103=C_a_i_list(&a,4,lf[353],lf[115],t99,t102);
t104=C_a_i_list(&a,4,lf[354],lf[103],lf[352],lf[353]);
t105=C_a_i_list(&a,4,lf[103],lf[181],C_make_character(95),C_make_character(45));
t106=C_a_i_list(&a,3,lf[355],lf[129],t105);
t107=C_a_i_list(&a,3,lf[129],C_make_character(46),lf[355]);
t108=C_a_i_list(&a,4,lf[356],lf[115],lf[355],t107);
t109=C_a_i_list(&a,3,lf[134],C_fix(2),lf[308]);
t110=C_a_i_list(&a,16,lf[103],lf[357],lf[358],lf[359],lf[360],lf[361],lf[362],lf[363],lf[364],lf[365],lf[366],lf[367],lf[368],lf[369],lf[370],t109);
t111=C_a_i_list(&a,3,lf[371],lf[226],t110);
t112=C_a_i_list(&a,3,lf[129],lf[355],C_make_character(46));
t113=C_a_i_list(&a,4,lf[372],lf[115],t112,lf[371]);
t114=C_a_i_list(&a,6,lf[103],lf[181],C_make_character(95),C_make_character(45),C_make_character(46),C_make_character(43));
t115=C_a_i_list(&a,3,lf[373],lf[129],t114);
t116=C_a_i_list(&a,5,lf[374],lf[115],lf[373],C_make_character(64),lf[356]);
t117=C_a_i_list(&a,4,lf[115],lf[375],lf[328],lf[328]);
t118=C_a_i_list(&a,14,lf[376],lf[103],lf[310],C_make_character(95),C_make_character(45),C_make_character(43),C_make_character(92),C_make_character(61),C_make_character(126),C_make_character(46),C_make_character(44),C_make_character(38),C_make_character(59),t117);
t119=C_a_i_list(&a,4,lf[115],lf[377],lf[328],lf[328]);
t120=C_a_i_list(&a,11,lf[378],lf[103],lf[310],C_make_character(95),C_make_character(45),C_make_character(43),C_make_character(92),C_make_character(61),C_make_character(126),C_make_character(38),t119);
t121=C_a_i_list(&a,2,lf[131],lf[379]);
t122=C_a_i_list(&a,3,lf[103],lf[356],lf[352]);
t123=C_a_i_list(&a,2,lf[129],lf[178]);
t124=C_a_i_list(&a,3,lf[131],lf[380],t123);
t125=C_a_i_list(&a,3,lf[103],lf[376],lf[381]);
t126=C_a_i_list(&a,2,lf[127],t125);
t127=C_a_i_list(&a,2,lf[127],lf[376]);
t128=C_a_i_list(&a,3,lf[131],lf[382],t127);
t129=C_a_i_list(&a,2,lf[127],lf[376]);
t130=C_a_i_list(&a,3,lf[131],t129,lf[378]);
t131=C_a_i_list(&a,3,lf[131],lf[383],t130);
t132=C_a_i_list(&a,5,lf[131],lf[384],t126,t128,t131);
t133=C_a_i_list(&a,8,lf[385],lf[226],lf[386],t121,lf[387],t122,t124,t132);
t134=C_a_i_list(&a,31,t42,t43,t46,t49,t50,t52,t54,t56,t57,t58,t62,t70,t72,t74,t83,t88,t90,t92,t96,t98,t103,t104,t106,t108,t111,t113,t115,t116,t118,t120,t133);
t135=C_a_i_cons(&a,2,t41,t134);
t136=C_a_i_cons(&a,2,t40,t135);
t137=C_a_i_cons(&a,2,t38,t136);
t138=C_a_i_cons(&a,2,t37,t137);
t139=C_a_i_cons(&a,2,t36,t138);
t140=C_a_i_cons(&a,2,t35,t139);
t141=C_a_i_cons(&a,2,t34,t140);
t142=C_a_i_cons(&a,2,t33,t141);
t143=C_a_i_cons(&a,2,t32,t142);
t144=C_a_i_cons(&a,2,t31,t143);
t145=C_a_i_cons(&a,2,t30,t144);
t146=C_a_i_cons(&a,2,t29,t145);
t147=C_a_i_cons(&a,2,t28,t146);
t148=C_a_i_cons(&a,2,t27,t147);
t149=C_a_i_cons(&a,2,t26,t148);
t150=C_a_i_cons(&a,2,t25,t149);
t151=C_a_i_cons(&a,2,t24,t150);
t152=C_a_i_cons(&a,2,t23,t151);
t153=C_a_i_cons(&a,2,t22,t152);
t154=C_a_i_cons(&a,2,t21,t153);
t155=C_a_i_cons(&a,2,t20,t154);
t156=C_a_i_cons(&a,2,t19,t155);
t157=C_a_i_cons(&a,2,t18,t156);
t158=C_a_i_cons(&a,2,t17,t157);
t159=C_a_i_cons(&a,2,t16,t158);
t160=C_a_i_cons(&a,2,t15,t159);
t161=C_a_i_cons(&a,2,t14,t160);
t162=C_a_i_cons(&a,2,t11,t161);
t163=C_mutate(&lf[248] /* (set! chicken.irregex#sre-named-definitions ...) */,t162);
t164=C_mutate(&lf[388] /* (set! chicken.irregex#nfa-get-epsilons ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20594,a[2]=((C_word)li264),tmp=(C_word)a,a+=3,tmp));
t165=C_mutate(&lf[389] /* (set! chicken.irregex#nfa-add-epsilon! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20628,a[2]=((C_word)li265),tmp=(C_word)a,a+=3,tmp));
t166=C_mutate(&lf[268] /* (set! chicken.irregex#sre->nfa ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20769,a[2]=((C_word)li276),tmp=(C_word)a,a+=3,tmp));
t167=C_mutate(&lf[396] /* (set! chicken.irregex#make-mst ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21892,a[2]=((C_word)li277),tmp=(C_word)a,a+=3,tmp));
t168=C_mutate(&lf[397] /* (set! chicken.irregex#mst-copy ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21921,a[2]=((C_word)li278),tmp=(C_word)a,a+=3,tmp));
t169=C_mutate(&lf[398] /* (set! chicken.irregex#nfa-state->mst ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21938,a[2]=((C_word)li279),tmp=(C_word)a,a+=3,tmp));
t170=C_mutate(&lf[399] /* (set! chicken.irregex#mst-add! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21947,a[2]=((C_word)li282),tmp=(C_word)a,a+=3,tmp));
t171=C_mutate(&lf[400] /* (set! chicken.irregex#mst-fold ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22299,a[2]=((C_word)li284),tmp=(C_word)a,a+=3,tmp));
t172=C_mutate(&lf[267] /* (set! chicken.irregex#nfa->dfa ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22381,a[2]=((C_word)li298),tmp=(C_word)a,a+=3,tmp));
t173=C_mutate(&lf[403] /* (set! chicken.irregex#nfa-epsilon-closure ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23066,a[2]=((C_word)li305),tmp=(C_word)a,a+=3,tmp));
t174=C_mutate(&lf[402] /* (set! chicken.irregex#tag-set-commands-for-closure ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23081,a[2]=((C_word)li310),tmp=(C_word)a,a+=3,tmp));
t175=C_mutate(&lf[223] /* (set! chicken.irregex#sre-cset->procedure ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26180,a[2]=((C_word)li312),tmp=(C_word)a,a+=3,tmp));
t176=C_mutate(&lf[216] /* (set! chicken.irregex#cset->plist ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26393,a[2]=((C_word)li314),tmp=(C_word)a,a+=3,tmp));
t177=C_mutate(&lf[391] /* (set! chicken.irregex#string->cset ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26484,a[2]=((C_word)li316),tmp=(C_word)a,a+=3,tmp));
t178=C_mutate(&lf[172] /* (set! chicken.irregex#sre->cset ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26504,a[2]=((C_word)li326),tmp=(C_word)a,a+=3,tmp));
t179=C_mutate(&lf[296] /* (set! chicken.irregex#cset-contains? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26971,a[2]=((C_word)li328),tmp=(C_word)a,a+=3,tmp));
t180=C_mutate(&lf[408] /* (set! chicken.irregex#char-ranges-union ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27056,a[2]=((C_word)li329),tmp=(C_word)a,a+=3,tmp));
t181=C_mutate(&lf[162] /* (set! chicken.irregex#cset-union ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27092,a[2]=((C_word)li331),tmp=(C_word)a,a+=3,tmp));
t182=C_mutate(&lf[404] /* (set! chicken.irregex#cset-difference ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27287,a[2]=((C_word)li333),tmp=(C_word)a,a+=3,tmp));
t183=C_mutate(&lf[405] /* (set! chicken.irregex#cset-intersection ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27483,a[2]=((C_word)li335),tmp=(C_word)a,a+=3,tmp));
t184=C_mutate(&lf[164] /* (set! chicken.irregex#cset-complement ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27609,a[2]=((C_word)li336),tmp=(C_word)a,a+=3,tmp));
t185=C_mutate(&lf[165] /* (set! chicken.irregex#cset-case-insensitive ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27619,a[2]=((C_word)li338),tmp=(C_word)a,a+=3,tmp));
t186=C_mutate(&lf[410] /* (set! chicken.irregex#irregex-fold/fast ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27750,a[2]=((C_word)li341),tmp=(C_word)a,a+=3,tmp));
t187=C_mutate((C_word*)lf[415]+1 /* (set! chicken.irregex#irregex-fold ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27968,a[2]=((C_word)li343),tmp=(C_word)a,a+=3,tmp));
t188=C_mutate(&lf[417] /* (set! chicken.irregex#irregex-fold/chunked/fast ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27996,a[2]=((C_word)li346),tmp=(C_word)a,a+=3,tmp));
t189=C_mutate((C_word*)lf[420]+1 /* (set! chicken.irregex#irregex-fold/chunked ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28178,a[2]=((C_word)li348),tmp=(C_word)a,a+=3,tmp));
t190=C_mutate((C_word*)lf[422]+1 /* (set! chicken.irregex#irregex-replace ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28206,a[2]=((C_word)li349),tmp=(C_word)a,a+=3,tmp));
t191=C_mutate((C_word*)lf[426]+1 /* (set! chicken.irregex#irregex-replace/all ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28285,a[2]=((C_word)li352),tmp=(C_word)a,a+=3,tmp));
t192=C_mutate(&lf[423] /* (set! chicken.irregex#irregex-apply-match ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28378,a[2]=((C_word)li355),tmp=(C_word)a,a+=3,tmp));
t193=C_mutate((C_word*)lf[433]+1 /* (set! chicken.irregex#irregex-extract ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28609,a[2]=((C_word)li358),tmp=(C_word)a,a+=3,tmp));
t194=C_mutate((C_word*)lf[436]+1 /* (set! chicken.irregex#irregex-split ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28644,a[2]=((C_word)li362),tmp=(C_word)a,a+=3,tmp));
t195=C_mutate(&lf[54] /* (set! chicken.irregex#string-scan-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28842,a[2]=((C_word)li364),tmp=(C_word)a,a+=3,tmp));
t196=C_mutate((C_word*)lf[440]+1 /* (set! chicken.irregex#irregex-quote ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28885,a[2]=((C_word)li366),tmp=(C_word)a,a+=3,tmp));
t197=C_mutate((C_word*)lf[443]+1 /* (set! chicken.irregex#irregex-opt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28942,a[2]=((C_word)li371),tmp=(C_word)a,a+=3,tmp));
t198=C_mutate(&lf[447] /* (set! chicken.irregex#cset->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29209,a[2]=((C_word)li373),tmp=(C_word)a,a+=3,tmp));
t199=C_mutate((C_word*)lf[452]+1 /* (set! chicken.irregex#sre->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29289,a[2]=((C_word)li383),tmp=(C_word)a,a+=3,tmp));
t200=C_mutate((C_word*)lf[486]+1 /* (set! chicken.irregex#glob->sre ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30072,a[2]=((C_word)li386),tmp=(C_word)a,a+=3,tmp));
t201=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t201;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t201+1)))(2,av2);}}

/* chicken.irregex#irregex-search in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_18932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_18932,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18936,a[2]=t4,a[3]=t3,a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_i_stringp(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:1972: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[288];
av2[3]=lf[291];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_18936(2,av2);}}}

/* k18934 in chicken.irregex#irregex-search in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_18936(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18936,c,av);}
a=C_alloc(6);
t2=C_i_pairp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_u_i_car(((C_word*)t0)[2]):C_SCHEME_FALSE);
t4=(C_truep(t3)?t3:C_fix(0));
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18945,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t6=C_i_pairp(C_u_i_cdr(((C_word*)t0)[2]));
t7=t5;
f_18945(t7,(C_truep(t6)?C_i_cadr(((C_word*)t0)[2]):C_SCHEME_FALSE));}
else{
t6=t5;
f_18945(t6,C_SCHEME_FALSE);}}

/* k18943 in k18934 in chicken.irregex#irregex-search in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_18945(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_18945,2,t0,t1);}
a=C_alloc(7);
t2=(C_truep(t1)?t1:C_i_string_length(((C_word*)t0)[2]));
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18951,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_integerp(((C_word*)t0)[3]))){
t4=C_i_exactp(((C_word*)t0)[3]);
if(C_truep(C_i_not(t4))){
/* irregex-core.scm:1976: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[288];
av2[3]=lf[290];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=t3;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_18951(2,av2);}}}
else{
/* irregex-core.scm:1976: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[288];
av2[3]=lf[290];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k18949 in k18943 in k18934 in chicken.irregex#irregex-search in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_18951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_18951,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18954,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_integerp(((C_word*)t0)[4]))){
t3=C_i_exactp(((C_word*)t0)[4]);
if(C_truep(C_i_not(t3))){
/* irregex-core.scm:1978: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[288];
av2[3]=lf[289];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_18954(2,av2);}}}
else{
/* irregex-core.scm:1978: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[288];
av2[3]=lf[289];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k18952 in k18949 in k18943 in k18934 in chicken.irregex#irregex-search in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_18954(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_18954,c,av);}
a=C_alloc(9);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
/* irregex-core.scm:1979: irregex-search/chunked */
t3=*((C_word*)lf[287]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[6];
av2[3]=lf[285];
av2[4]=t2;
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* chicken.irregex#irregex-search/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c<5) C_bad_min_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-5)*C_SIZEOF_PAIR +6,c,2)))){
C_save_and_reclaim((void*)f_19022,c,av);}
a=C_alloc((c-5)*C_SIZEOF_PAIR+6);
t5=C_build_rest(&a,c,5,av);
C_word t6;
C_word t7;
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19026,a[2]=t3,a[3]=t4,a[4]=t1,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:1985: irregex */
t7=*((C_word*)lf[217]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k19024 in chicken.irregex#irregex-search/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19026(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_19026,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19029,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:1986: irregex-new-matches */
f_7628(t2,t1);}

/* k19027 in k19024 in chicken.irregex#irregex-search/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19029(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_19029,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19032,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_car(((C_word*)t0)[6]);
f_19032(2,av2);}}
else{
/* irregex-core.scm:1987: g3263 */
t3=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k19030 in k19027 in k19024 in chicken.irregex#irregex-search/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19032(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_19032,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19035,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_not(C_i_integerp(t1)))){
/* irregex-core.scm:1988: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[288];
av2[3]=lf[293];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_19035(2,av2);}}}

/* k19033 in k19030 in k19027 in k19024 in chicken.irregex#irregex-search/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,7)))){
C_save_and_reclaim((void *)f_19035,c,av);}
a=C_alloc(3);
t2=C_i_setslot(((C_word*)t0)[2],C_fix(3),((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]);
/* irregex-core.scm:1990: irregex-search/matches */
f_19065(((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[3],t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[2]);}

/* chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19065(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7){
C_word tmp;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,9)))){
C_save_and_reclaim_args((void *)trf_19065,7,t1,t2,t3,t4,t5,t6,t7);}
a=C_alloc(20);
t8=C_i_check_structure_2(t2,lf[6],lf[294]);
if(C_truep(C_slot(t2,C_fix(1)))){
t9=C_slot(t2,C_fix(4));
t10=C_fixnum_and(t9,C_fix(1));
t11=C_eqp(C_fix(1),t10);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19084,a[2]=t7,a[3]=t5,a[4]=t6,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2000: dfa-match/longest */
f_19947(t12,C_slot(t2,C_fix(1)),t3,t5,t6,C_SCHEME_FALSE,C_SCHEME_FALSE,t7,C_fix(0));}
else{
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19109,a[2]=t2,a[3]=t3,a[4]=t7,a[5]=t1,a[6]=t5,a[7]=t6,tmp=(C_word)a,a+=8,tmp);
t13=C_slot(t2,C_fix(2));
t14=C_i_vector_ref(t3,C_fix(1));
t15=C_i_vector_ref(t3,C_fix(2));
t16=C_i_vector_ref(t3,C_fix(3));
t17=C_i_vector_ref(t3,C_fix(0));
t18=C_i_vector_ref(t13,C_fix(0));
t19=C_i_cadr(t18);
t20=C_i_cadr(t19);
t21=C_i_vector_ref(t13,t20);
t22=C_SCHEME_UNDEFINED;
t23=(*a=C_VECTOR_TYPE|1,a[1]=t22,tmp=(C_word)a,a+=2,tmp);
t24=C_set_block_item(t23,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_19690,a[2]=t7,a[3]=t13,a[4]=t23,a[5]=t15,a[6]=t17,a[7]=t16,a[8]=t14,a[9]=((C_word)li237),tmp=(C_word)a,a+=10,tmp));
t25=((C_word*)t23)[1];
f_19690(t25,t12,t5,t6,t21);}}
else{
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19196,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t10=C_i_check_structure_2(t2,lf[6],lf[297]);
t11=C_slot(t2,C_fix(3));
t12=C_i_vector_ref(t3,C_fix(1));
t13=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_19214,a[2]=t3,a[3]=t2,a[4]=t11,a[5]=t9,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:2033: g3331 */
t14=t12;{
C_word av2[3];
av2[0]=t14;
av2[1]=t13;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t14+1)))(3,av2);}}}

/* k19082 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19084(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19084,c,av);}
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_i_vector_set(t2,C_fix(0),((C_word*)t0)[3]);
t4=C_slot(((C_word*)t0)[2],C_fix(1));
t5=C_i_vector_set(t4,C_fix(1),((C_word*)t0)[4]);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19107 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19109(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_19109,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_i_vector_ref(((C_word*)t0)[3],C_fix(2));
t4=C_i_vector_ref(((C_word*)t0)[3],C_fix(3));
t5=C_i_vector_ref(((C_word*)t0)[3],C_fix(0));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_19126,a[2]=((C_word*)t0)[4],a[3]=t7,a[4]=t3,a[5]=t5,a[6]=t2,a[7]=((C_word*)t0)[3],a[8]=t4,a[9]=((C_word)li234),tmp=(C_word)a,a+=10,tmp));
t9=((C_word*)t7)[1];
f_19126(t9,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* lp1 in k19107 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19126(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_19126,4,t0,t1,t2,t3);}
a=C_alloc(11);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19130,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=t1,a[10]=t3,tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:2013: get-end */
t5=((C_word*)t0)[8];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k19128 in lp1 in k19107 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_19130,c,av);}
a=C_alloc(14);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19135,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=t3,a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word)li233),tmp=(C_word)a,a+=12,tmp));
t5=((C_word*)t3)[1];
f_19135(t5,((C_word*)t0)[9],((C_word*)t0)[10]);}

/* lp2 in k19128 in lp1 in k19107 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19135(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,9)))){
C_save_and_reclaim_args((void *)trf_19135,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19142,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:2016: dfa-match/longest */
f_19947(t3,((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[3],t2,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[2],C_fix(0));}

/* k19140 in lp2 in k19128 in lp1 in k19107 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_19142,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_i_vector_set(t2,C_fix(0),((C_word*)t0)[3]);
t4=C_slot(((C_word*)t0)[2],C_fix(1));
t5=C_i_vector_set(t4,C_fix(1),((C_word*)t0)[4]);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[4],((C_word*)t0)[6]))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19165,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2021: get-next */
t3=((C_word*)t0)[9];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
/* irregex-core.scm:2024: lp2 */
t2=((C_word*)((C_word*)t0)[10])[1];
f_19135(t2,((C_word*)t0)[5],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}}}

/* k19163 in k19140 in lp2 in k19128 in lp1 in k19107 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19165(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_19165,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19175,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2022: get-start */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19173 in k19163 in k19140 in lp2 in k19128 in lp1 in k19107 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19175(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19175,c,av);}
/* irregex-core.scm:2022: lp1 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19126(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k19194 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19196(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19196,c,av);}
if(C_truep(t1)){
t2=C_i_set_i_slot(t1,C_fix(4),C_SCHEME_FALSE);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19214(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_19214,c,av);}
a=C_alloc(11);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19220,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:2033: g3333 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,9)))){
C_save_and_reclaim((void *)f_19220,c,av);}
a=C_alloc(11);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(0));
t3=C_slot(((C_word*)t0)[3],C_fix(4));
t4=C_fixnum_and(t3,C_fix(1));
t5=C_eqp(C_fix(1),t4);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19234,a[2]=((C_word)li238),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:2038: matcher */
t7=((C_word*)t0)[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=((C_word*)t0)[9];
av2[7]=t1;
av2[8]=((C_word*)t0)[10];
av2[9]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(10,av2);}}
else{
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_19240,a[2]=((C_word*)t0)[10],a[3]=t7,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[6],a[8]=((C_word)li240),tmp=(C_word)a,a+=9,tmp));
t9=((C_word*)t7)[1];
f_19240(t9,((C_word*)t0)[5],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],t1);}}

/* a19233 in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19234(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19234,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* lp in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19240(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,9)))){
C_save_and_reclaim_args((void *)trf_19240,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(14);
t6=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19247,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t4,a[5]=t1,a[6]=t5,a[7]=((C_word*)t0)[3],a[8]=t3,a[9]=((C_word*)t0)[4],a[10]=((C_word*)t0)[5],tmp=(C_word)a,a+=11,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19306,a[2]=((C_word)li239),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:2044: matcher */
t8=((C_word*)t0)[6];{
C_word av2[10];
av2[0]=t8;
av2[1]=t6;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[7];
av2[4]=t2;
av2[5]=t3;
av2[6]=t4;
av2[7]=t5;
av2[8]=((C_word*)t0)[2];
av2[9]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(10,av2);}}

/* k19245 in lp in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_19247,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_i_vector_set(t2,C_fix(0),((C_word*)t0)[3]);
t4=C_slot(((C_word*)t0)[2],C_fix(1));
t5=C_i_vector_set(t4,C_fix(1),((C_word*)t0)[4]);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_lessp(((C_word*)t0)[4],((C_word*)t0)[6]))){
/* irregex-core.scm:2049: lp */
t2=((C_word*)((C_word*)t0)[7])[1];
f_19240(t2,((C_word*)t0)[5],((C_word*)t0)[3],((C_word*)t0)[8],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)),((C_word*)t0)[6]);}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19277,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2051: get-next */
t3=((C_word*)t0)[10];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}

/* k19275 in k19245 in lp in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19277,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19290,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2053: g3352 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19288 in k19275 in k19245 in lp in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_19290,c,av);}
a=C_alloc(7);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19297,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2053: g3354 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19295 in k19288 in k19275 in k19245 in lp in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_19297,c,av);}
a=C_alloc(7);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19304,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2053: g3356 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19302 in k19295 in k19288 in k19275 in k19245 in lp in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19304(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_19304,c,av);}
/* irregex-core.scm:2053: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19240(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1);}

/* a19305 in lp in k19218 in k19212 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19306(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19306,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.irregex#irregex-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_19314,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19318,a[2]=t4,a[3]=t3,a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_i_stringp(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:2060: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[300];
av2[3]=lf[303];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_19318(2,av2);}}}

/* k19316 in chicken.irregex#irregex-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19318,c,av);}
a=C_alloc(6);
t2=C_i_pairp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_u_i_car(((C_word*)t0)[2]):C_SCHEME_FALSE);
t4=(C_truep(t3)?t3:C_fix(0));
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19327,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t6=C_i_pairp(C_u_i_cdr(((C_word*)t0)[2]));
t7=t5;
f_19327(t7,(C_truep(t6)?C_i_cadr(((C_word*)t0)[2]):C_SCHEME_FALSE));}
else{
t6=t5;
f_19327(t6,C_SCHEME_FALSE);}}

/* k19325 in k19316 in chicken.irregex#irregex-match in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19327(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_19327,2,t0,t1);}
a=C_alloc(7);
t2=(C_truep(t1)?t1:C_i_string_length(((C_word*)t0)[2]));
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19333,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_integerp(((C_word*)t0)[3]))){
t4=C_i_exactp(((C_word*)t0)[3]);
if(C_truep(C_i_not(t4))){
/* irregex-core.scm:2064: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[300];
av2[3]=lf[302];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=t3;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_19333(2,av2);}}}
else{
/* irregex-core.scm:2064: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[300];
av2[3]=lf[302];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k19331 in k19325 in k19316 in chicken.irregex#irregex-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19333(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_19333,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19336,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_integerp(((C_word*)t0)[4]))){
t3=C_i_exactp(((C_word*)t0)[4]);
if(C_truep(C_i_not(t3))){
/* irregex-core.scm:2066: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[300];
av2[3]=lf[301];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
/* irregex-core.scm:2067: irregex-match/chunked */
t5=*((C_word*)lf[299]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[6];
av2[3]=lf[285];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}
else{
/* irregex-core.scm:2066: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[300];
av2[3]=lf[301];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k19334 in k19331 in k19325 in k19316 in chicken.irregex#irregex-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19336(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_19336,c,av);}
a=C_alloc(9);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
/* irregex-core.scm:2067: irregex-match/chunked */
t3=*((C_word*)lf[299]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[6];
av2[3]=lf[285];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19404(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_19404,c,av);}
a=C_alloc(5);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19408,a[2]=t3,a[3]=t4,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2072: irregex */
t6=*((C_word*)lf[217]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19408(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19408,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19411,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2073: irregex-new-matches */
f_7628(t2,t1);}

/* k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19411(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_19411,c,av);}
a=C_alloc(13);
t2=C_i_setslot(t1,C_fix(3),((C_word*)t0)[2]);
if(C_truep(C_slot(((C_word*)t0)[3],C_fix(1)))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19426,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=C_slot(((C_word*)t0)[3],C_fix(1));
t5=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19496,a[2]=t3,a[3]=t4,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2078: g3390 */
t7=t5;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t3=C_slot(((C_word*)t0)[3],C_fix(3));
t4=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19506,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t3,a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2089: g3410 */
t6=t4;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k19424 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19426,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19460,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=C_slot(((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:2080: g3393 */
t5=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_slot(t4,C_fix(2));
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19447 in k19458 in k19424 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19449(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19449,c,av);}
t2=C_i_vector_set(((C_word*)t0)[2],C_fix(1),t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k19458 in k19424 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_19460,c,av);}
a=C_alloc(5);
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(C_fix(0),C_fix(4));
t4=C_slot(t2,C_fixnum_plus(C_fix(3),t3));
t5=C_eqp(t1,t4);
if(C_truep(t5)){
t6=C_slot(((C_word*)t0)[2],C_fix(1));
t7=C_i_vector_set(t6,C_fix(0),((C_word*)t0)[3]);
t8=C_slot(((C_word*)t0)[2],C_fix(1));
t9=C_i_vector_ref(((C_word*)t0)[4],C_fix(2));
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19449,a[2]=t8,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2084: g3404 */
t11=t9;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k19494 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_19496,c,av);}
/* irregex-core.scm:2078: dfa-match/longest */
f_19947(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[6],C_fix(0));}

/* k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19506(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_19506,c,av);}
a=C_alloc(8);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19512,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:2089: g3413 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_19512,c,av);}
a=C_alloc(9);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_19518,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:2089: g3416 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19518(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,9)))){
C_save_and_reclaim((void *)f_19518,c,av);}
a=C_alloc(10);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19528,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19627,a[2]=((C_word)li244),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:2094: matcher */
t5=((C_word*)t0)[6];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
av2[4]=((C_word*)t0)[2];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[3];
av2[7]=t1;
av2[8]=((C_word*)t0)[8];
av2[9]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(10,av2);}}

/* k19526 in k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19528(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_19528,c,av);}
a=C_alloc(7);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19530,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word)li243),tmp=(C_word)a,a+=5,tmp));
t5=((C_word*)t3)[1];
f_19530(t5,((C_word*)t0)[3],t1);}

/* lp in k19526 in k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19530(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_19530,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19540,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t4=C_i_vector_ref(((C_word*)t0)[3],C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19604,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t6=C_slot(t2,C_fix(1));
/* irregex-core.scm:2097: g3427 */
t7=t4;{
C_word av2[3];
av2[0]=t7;
av2[1]=t5;
av2[2]=C_slot(t6,C_fix(2));
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19538 in lp in k19526 in k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19540(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_19540,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=C_i_set_i_slot(((C_word*)t0)[2],C_fix(4),C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_slot(((C_word*)t0)[2],C_fix(4)))){
t2=C_slot(((C_word*)t0)[2],C_fix(4));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19559,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2105: g3440 */
t4=t2;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* k19557 in k19538 in lp in k19526 in k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19559(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19559,c,av);}
/* irregex-core.scm:2105: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19530(t2,((C_word*)t0)[3],t1);}

/* k19570 in k19602 in lp in k19526 in k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19572,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(C_fix(0),C_fix(4));
t4=((C_word*)t0)[3];
f_19540(t4,C_eqp(t1,C_slot(t2,C_fixnum_plus(C_fix(3),t3))));}

/* k19602 in lp in k19526 in k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19604(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_19604,c,av);}
a=C_alloc(4);
if(C_truep(C_i_not(t1))){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19572,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=C_slot(((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:2099: g3433 */
t5=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_slot(t4,C_fix(2));
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t2=((C_word*)t0)[4];
f_19540(t2,C_SCHEME_FALSE);}}

/* a19626 in k19516 in k19510 in k19504 in k19409 in k19406 in chicken.irregex#irregex-match/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19627(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19627,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.irregex#irregex-match? in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +3,c,3)))){
C_save_and_reclaim((void*)f_19632,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+3);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19639,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t3;
av2[2]=*((C_word*)lf[298]+1);
av2[3]=t2;
C_apply(4,av2);}}

/* k19637 in chicken.irregex#irregex-match? in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19639,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_SCHEME_TRUE:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19690(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_19690,5,t0,t1,t2,t3,t4);}
a=C_alloc(12);
if(C_truep(t2)){
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19697,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=t1,a[9]=t3,a[10]=t4,a[11]=((C_word*)t0)[7],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:2136: get-str */
t6=((C_word*)t0)[8];{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k19695 in lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19697(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_19697,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19700,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:2137: get-end */
t3=((C_word*)t0)[11];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k19698 in k19695 in lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19700(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_19700,c,av);}
a=C_alloc(14);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19705,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=t3,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word)li236),tmp=(C_word)a,a+=12,tmp));
t5=((C_word*)t3)[1];
f_19705(t5,((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11]);}

/* lp2 in k19698 in k19695 in lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19705(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_19705,4,t0,t1,t2,t3);}
a=C_alloc(10);
if(C_truep(C_i_car(t3))){
t4=C_slot(((C_word*)t0)[2],C_fix(1));
t5=C_i_vector_set(t4,C_fix(2),((C_word*)t0)[3]);
t6=C_slot(((C_word*)t0)[2],C_fix(1));
t7=C_i_vector_set(t6,C_fix(3),t2);
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_lessp(t2,((C_word*)t0)[4]))){
t4=C_i_string_ref(((C_word*)t0)[5],t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19757,a[2]=t2,a[3]=((C_word*)t0)[6],a[4]=t1,a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19772,a[2]=t4,a[3]=((C_word)li235),tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2148: find */
f_9201(t5,t6,C_i_cdr(t3));}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19808,a[2]=((C_word*)t0)[8],a[3]=t1,a[4]=t3,a[5]=((C_word*)t0)[9],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2155: get-next */
t5=((C_word*)t0)[10];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}}

/* k19755 in lp2 in k19698 in k19695 in lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_19757,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t3=C_i_cadr(t1);
/* irregex-core.scm:2153: lp2 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_19705(t4,((C_word*)t0)[4],t2,C_i_vector_ref(((C_word*)t0)[5],t3));}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a19771 in lp2 in k19698 in k19695 in lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19772,c,av);}
t3=C_i_car(t2);
t4=C_eqp(((C_word*)t0)[2],t3);
if(C_truep(t4)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_charp(C_u_i_car(t2));
if(C_truep(C_i_not(t5))){
/* irregex-core.scm:2151: cset-contains? */
f_26971(t1,C_u_i_car(t2),((C_word*)t0)[2]);}
else{
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}

/* k19806 in lp2 in k19698 in k19695 in lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19808,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19818,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2156: get-start */
t3=((C_word*)t0)[5];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19816 in k19806 in lp2 in k19698 in k19695 in lp1 in chicken.irregex#irregex-search/matches in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19818(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19818,c,av);}
/* irregex-core.scm:2156: lp1 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19690(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5]);}

/* chicken.irregex#finalize! in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19828(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_19828,4,t1,t2,t3,t4);}
a=C_alloc(12);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19830,a[2]=t3,a[3]=t4,a[4]=((C_word)li247),tmp=(C_word)a,a+=5,tmp);
t6=C_i_check_list_2(t2,lf[306]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19888,a[2]=t5,a[3]=t8,a[4]=((C_word)li248),tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_19888(t10,t1,t2);}

/* g3514 in chicken.irregex#finalize! in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_19830(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_stack_overflow_check;{}
t2=C_i_car(t1);
t3=C_i_vector_ref(((C_word*)t0)[2],C_u_i_cdr(t1));
t4=C_i_vector_ref(t3,t2);
t5=C_slot(((C_word*)t0)[3],C_fix(1));
t6=C_a_i_fixnum_times(&a,2,t2,C_fix(2));
t7=C_s_a_u_i_integer_plus(&a,2,C_fix(4),t6);
t8=(C_truep(t4)?C_i_vector_set(t5,t7,C_i_car(t4)):C_i_vector_set(t5,t7,C_SCHEME_FALSE));
t9=C_slot(((C_word*)t0)[3],C_fix(1));
t10=C_a_i_fixnum_times(&a,2,t2,C_fix(2));
t11=C_s_a_u_i_integer_plus(&a,2,C_fix(5),t10);
return((C_truep(t4)?C_i_vector_set(t9,t11,C_i_cdr(t4)):C_i_vector_set(t9,t11,C_SCHEME_FALSE)));}

/* for-each-loop3513 in chicken.irregex#finalize! in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19888(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,2)))){
C_save_and_reclaim_args((void *)trf_19888,3,t0,t1,t2);}
a=C_alloc(20);
if(C_truep(C_i_pairp(t2))){
t3=(
/* irregex-core.scm:2159: g3514 */
  f_19830(C_a_i(&a,20),((C_word*)t0)[2],C_slot(t2,C_fix(0)))
);
t5=t1;
t6=C_slot(t2,C_fix(1));
t1=t5;
t2=t6;
goto loop;}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k19914 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19916(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_19916,c,av);}
a=C_alloc(10);
t2=C_a_i_fixnum_times(&a,2,t1,C_fix(2));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19920,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2171: scheme#make-vector */
t4=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19918 in k19914 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19920(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_19920,c,av);}
a=C_alloc(9);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19925,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word)li261),tmp=(C_word)a,a+=7,tmp));
t5=((C_word*)t3)[1];
f_19925(t5,((C_word*)t0)[4],C_fix(0));}

/* doloop3544 in k19918 in k19914 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19925(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_19925,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19945,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2174: scheme#make-vector */
t5=*((C_word*)lf[4]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k19943 in doloop3544 in k19918 in k19914 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_19945,c,av);}
a=C_alloc(5);
t2=C_i_vector_set(((C_word*)t0)[2],((C_word*)t0)[3],t1);
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
t4=((C_word*)((C_word*)t0)[4])[1];
f_19925(t4,((C_word*)t0)[5],t3);}

/* chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19947(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8,C_word t9){
C_word tmp;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,2)))){
C_save_and_reclaim_args((void *)trf_19947,9,t1,t2,t3,t4,t5,t6,t7,t8,t9);}
a=C_alloc(20);
t10=C_i_vector_ref(t3,C_fix(1));
t11=C_i_vector_ref(t3,C_fix(2));
t12=C_i_vector_ref(t3,C_fix(3));
t13=C_i_vector_ref(t3,C_fix(0));
t14=C_i_vector_ref(t2,C_fix(0));
t15=C_i_car(t14);
t16=C_i_not(C_i_zerop(t15));
t17=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_19972,a[2]=t14,a[3]=t2,a[4]=t4,a[5]=t5,a[6]=t11,a[7]=t9,a[8]=t8,a[9]=t6,a[10]=t13,a[11]=t16,a[12]=t7,a[13]=t12,a[14]=t10,a[15]=t1,tmp=(C_word)a,a+=16,tmp);
t18=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19916,a[2]=t15,a[3]=t17,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2170: irregex-match-num-submatches */
t19=*((C_word*)lf[17]+1);{
C_word av2[3];
av2[0]=t19;
av2[1]=t18;
av2[2]=t8;
((C_proc)(void*)(*((C_word*)t19+1)))(3,av2);}}

/* k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_19972,c,av);}
a=C_alloc(19);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=C_i_cadr(t2);
t4=C_i_vector_ref(((C_word*)t0)[3],t3);
t5=C_i_car(t4);
t6=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_19984,a[2]=t5,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t1,a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[3],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=t4,a[18]=t2,tmp=(C_word)a,a+=19,tmp);
if(C_truep(((C_word*)t0)[7])){
t7=C_slot(((C_word*)t0)[8],C_fix(1));
t8=C_fixnum_times(((C_word*)t0)[7],C_fix(4));
t9=C_fixnum_plus(C_fix(2),t8);
t10=C_i_vector_set(t7,t9,C_SCHEME_FALSE);
t11=C_slot(((C_word*)t0)[8],C_fix(1));
t12=C_fixnum_times(((C_word*)t0)[7],C_fix(4));
t13=t6;
f_19984(t13,C_i_vector_set(t11,C_fixnum_plus(C_fix(3),t12),C_SCHEME_FALSE));}
else{
t7=t6;
f_19984(t7,C_SCHEME_UNDEFINED);}}

/* k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_19984(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(31,0,3)))){
C_save_and_reclaim_args((void *)trf_19984,2,t0,t1);}
a=C_alloc(31);
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_19987,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],tmp=(C_word)a,a+=18,tmp);
if(C_truep(((C_word*)t0)[12])){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20441,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word)li259),tmp=(C_word)a,a+=6,tmp);
t4=C_i_cddr(((C_word*)t0)[18]);
t5=C_i_cdr(t4);
t6=C_i_check_list_2(t5,lf[306]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20469,a[2]=t3,a[3]=t8,a[4]=((C_word)li260),tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_20469(t10,t2,t5);}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_19987(2,av2);}}}

/* k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_19987(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,8)))){
C_save_and_reclaim((void *)f_19987,c,av);}
a=C_alloc(17);
t2=(C_truep(((C_word*)t0)[2])?((C_word*)t0)[3]:C_SCHEME_FALSE);
t3=(C_truep(((C_word*)t0)[2])?((C_word*)t0)[4]:C_SCHEME_FALSE);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_20000,a[2]=t5,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=((C_word*)t0)[15],a[14]=((C_word)li258),tmp=(C_word)a,a+=15,tmp));
t7=((C_word*)t5)[1];
f_20000(t7,((C_word*)t0)[16],((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[17],t2,t3,((C_word*)t0)[2]);}

/* lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20000(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7){
C_word tmp;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,2)))){
C_save_and_reclaim_args((void *)trf_20000,8,t0,t1,t2,t3,t4,t5,t6,t7);}
a=C_alloc(20);
t8=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_20004,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t2,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=t1,a[13]=t3,a[14]=t4,a[15]=t5,a[16]=t6,a[17]=t7,a[18]=((C_word*)t0)[11],a[19]=((C_word*)t0)[12],tmp=(C_word)a,a+=20,tmp);
/* irregex-core.scm:2205: get-str */
t9=((C_word*)t0)[13];{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}

/* k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20004(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_20004,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_20007,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
t3=C_eqp(((C_word*)t0)[7],((C_word*)t0)[8]);
if(C_truep(t3)){
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[18];
f_20007(2,av2);}}
else{
/* irregex-core.scm:2206: get-end */
t4=((C_word*)t0)[19];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20007(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,7)))){
C_save_and_reclaim((void *)f_20007,c,av);}
a=C_alloc(18);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_20012,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=t3,a[14]=((C_word*)t0)[12],a[15]=((C_word)li257),tmp=(C_word)a,a+=16,tmp));
t5=((C_word*)t3)[1];
f_20012(t5,((C_word*)t0)[13],((C_word*)t0)[14],((C_word*)t0)[15],((C_word*)t0)[16],((C_word*)t0)[17],((C_word*)t0)[18]);}

/* lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20012(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,3)))){
C_save_and_reclaim_args((void *)trf_20012,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(18);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t7=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_20022,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[6],a[11]=((C_word*)t0)[7],a[12]=((C_word*)t0)[8],a[13]=((C_word*)t0)[9],a[14]=((C_word*)t0)[10],tmp=(C_word)a,a+=15,tmp);
t8=(C_truep(((C_word*)t0)[5])?t4:C_SCHEME_FALSE);
if(C_truep(t8)){
t9=C_slot(((C_word*)t0)[6],C_fix(1));
t10=C_fixnum_times(((C_word*)t0)[5],C_fix(4));
t11=C_fixnum_plus(C_fix(2),t10);
t12=C_i_vector_set(t9,t11,t4);
t13=C_slot(((C_word*)t0)[6],C_fix(1));
t14=C_fixnum_times(((C_word*)t0)[5],C_fix(4));
t15=t7;
f_20022(t15,C_i_vector_set(t13,C_fixnum_plus(C_fix(3),t14),t5));}
else{
t9=t7;
f_20022(t9,C_SCHEME_UNDEFINED);}}
else{
t7=C_i_string_ref(((C_word*)t0)[11],t2);
t8=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_20122,a[2]=((C_word*)t0)[12],a[3]=t2,a[4]=((C_word*)t0)[13],a[5]=t1,a[6]=((C_word*)t0)[8],a[7]=t4,a[8]=t5,a[9]=((C_word*)t0)[14],a[10]=((C_word*)t0)[7],a[11]=t6,a[12]=((C_word*)t0)[6],a[13]=((C_word*)t0)[5],tmp=(C_word)a,a+=14,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20401,a[2]=t7,a[3]=((C_word)li256),tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2227: find */
f_9201(t8,t9,C_i_cdr(t3));}}

/* k20020 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20022(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_20022,2,t0,t1);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_20025,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
t3=C_eqp(((C_word*)t0)[12],((C_word*)t0)[13]);
if(C_truep(C_i_not(t3))){
/* irregex-core.scm:2218: get-next */
t4=((C_word*)t0)[14];{
C_word av2[3];
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=t2;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_20025(2,av2);}}}

/* k20023 in k20020 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_20025,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20035,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:2220: get-start */
t3=((C_word*)t0)[8];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
if(C_truep(((C_word*)t0)[9])){
t2=C_slot(((C_word*)t0)[10],C_fix(1));
t3=C_fixnum_times(((C_word*)t0)[9],C_fix(4));
t4=C_fixnum_plus(C_fix(2),t3);
if(C_truep(C_slot(t2,t4))){
t5=C_i_not(((C_word*)t0)[7]);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20070,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t5)){
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t5)?C_SCHEME_TRUE:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* irregex-core.scm:2223: finalize! */
f_19828(t6,((C_word*)t0)[7],((C_word*)t0)[11],((C_word*)t0)[10]);}}
else{
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* k20033 in k20023 in k20020 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_20035,c,av);}
/* irregex-core.scm:2220: lp1 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20000(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k20068 in k20023 in k20020 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20070(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20070,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_SCHEME_TRUE:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20122(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_20122,c,av);}
a=C_alloc(17);
if(C_truep(t1)){
t2=C_i_cadr(t1);
t3=C_i_vector_ref(((C_word*)t0)[2],t2);
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_20134,a[2]=t4,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t3,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[9])){
t6=C_i_cddr(t1);
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20158,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[6],a[5]=t6,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[11])){
if(C_truep(C_i_not(t4))){
/* irregex-core.scm:2242: finalize! */
f_19828(t7,((C_word*)t0)[11],((C_word*)t0)[10],((C_word*)t0)[12]);}
else{
t8=t7;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_20158(2,av2);}}}
else{
t8=t7;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_20158(2,av2);}}}
else{
t6=t5;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_20134(2,av2);}}}
else{
if(C_truep(((C_word*)t0)[7])){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20331,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[12],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[13])){
t3=C_slot(((C_word*)t0)[12],C_fix(1));
t4=C_fixnum_times(((C_word*)t0)[13],C_fix(4));
t5=C_fixnum_plus(C_fix(2),t4);
t6=C_i_vector_set(t3,t5,((C_word*)t0)[7]);
t7=C_slot(((C_word*)t0)[12],C_fix(1));
t8=C_fixnum_times(((C_word*)t0)[13],C_fix(4));
t9=t2;
f_20331(t9,C_i_vector_set(t7,C_fixnum_plus(C_fix(3),t8),((C_word*)t0)[8]));}
else{
t3=t2;
f_20331(t3,C_SCHEME_UNDEFINED);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20373,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[12],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[13])){
t3=C_slot(((C_word*)t0)[12],C_fix(1));
t4=C_fixnum_times(((C_word*)t0)[13],C_fix(4));
t5=t2;
f_20373(t5,C_slot(t3,C_fixnum_plus(C_fix(2),t4)));}
else{
t3=t2;
f_20373(t3,C_SCHEME_FALSE);}}}}

/* k20132 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,6)))){
C_save_and_reclaim((void *)f_20134,c,av);}
a=C_alloc(10);
if(C_truep(((C_word*)t0)[2])){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:2261: lp2 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_20012(t4,((C_word*)t0)[5],t2,((C_word*)t0)[6],((C_word*)t0)[7],t3,((C_word*)t0)[2]);}
else{
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:2262: lp2 */
t3=((C_word*)((C_word*)t0)[4])[1];
f_20012(t3,((C_word*)t0)[5],t2,((C_word*)t0)[6],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_FALSE);}}

/* k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20158(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_20158,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20159,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word)li250),tmp=(C_word)a,a+=6,tmp);
t3=C_i_cdr(((C_word*)t0)[5]);
t4=C_i_check_list_2(t3,lf[306]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20188,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20295,a[2]=t2,a[3]=t7,a[4]=((C_word)li255),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_20295(t9,t5,t3);}

/* g3669 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_20159(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;{}
t2=C_i_cdr(t1);
t3=C_i_vector_ref(((C_word*)t0)[2],t2);
t4=C_fixnum_plus(((C_word*)t0)[3],C_fix(1));
t5=C_a_i_cons(&a,2,((C_word*)t0)[4],t4);
return(C_i_vector_set(t3,C_u_i_car(t1),t5));}

/* k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_20188,c,av);}
a=C_alloc(21);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20197,a[2]=((C_word*)t0)[2],a[3]=((C_word)li252),tmp=(C_word)a,a+=4,tmp);
t7=C_u_i_car(((C_word*)t0)[3]);
t8=C_i_check_list_2(t7,lf[211]);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20230,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20261,a[2]=t4,a[3]=t11,a[4]=t6,a[5]=t5,a[6]=((C_word)li254),tmp=(C_word)a,a+=7,tmp));
t13=((C_word*)t11)[1];
f_20261(t13,t9,t7);}

/* g3708 in k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20197(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20197,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_i_vector_ref(t2,C_fix(0));
t4=C_i_vector_ref(t2,C_fix(1));
t5=C_i_vector_ref(((C_word*)t0)[2],t4);
t6=C_i_vector_ref(t2,C_fix(2));
t7=C_i_vector_ref(((C_word*)t0)[2],t6);
t8=C_i_vector_ref(t5,t3);
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20211,a[2]=t7,a[3]=t3,a[4]=t8,a[5]=((C_word)li251),tmp=(C_word)a,a+=6,tmp);
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* f_20211 in g3708 in k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20211,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_vector_set(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20228 in k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20230(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_20230,c,av);}
a=C_alloc(6);
t2=C_i_check_list_2(t1,lf[306]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20238,a[2]=t4,a[3]=((C_word)li253),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_20238(t6,((C_word*)t0)[2],t1);}

/* for-each-loop3678 in k20228 in k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20238(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20238,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20248,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2252: execute! */
t4=C_slot(t2,C_fix(0));{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k20246 in for-each-loop3678 in k20228 in k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20248(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20248,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_20238(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* map-loop3702 in k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20261(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20261,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20286,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2253: g3708 */
t4=((C_word*)t0)[4];
f_20197(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20284 in map-loop3702 in k20186 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20286,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20261(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* for-each-loop3668 in k20156 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20295(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_20295,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=(
/* irregex-core.scm:2243: g3669 */
  f_20159(C_a_i(&a,3),((C_word*)t0)[2],C_slot(t2,C_fix(0)))
);
t5=t1;
t6=C_slot(t2,C_fix(1));
t1=t5;
t2=t6;
goto loop;}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k20329 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20331(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_20331,2,t0,t1);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20334,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[3])){
/* irregex-core.scm:2268: finalize! */
f_19828(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20332 in k20329 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20334,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20371 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20373(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_20373,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20376,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[3])){
/* irregex-core.scm:2271: finalize! */
f_19828(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20374 in k20371 in k20120 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20376(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20376,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a20400 in lp2 in k20005 in k20002 in lp1 in k19985 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20401,c,av);}
t3=C_i_car(t2);
t4=C_eqp(((C_word*)t0)[2],t3);
if(C_truep(t4)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_charp(C_u_i_car(t2));
if(C_truep(C_i_not(t5))){
/* irregex-core.scm:2230: cset-contains? */
f_26971(t1,C_u_i_car(t2),((C_word*)t0)[2]);}
else{
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}

/* g3585 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_20441(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;{}
t2=C_i_cdr(t1);
t3=C_i_vector_ref(((C_word*)t0)[2],t2);
t4=C_u_i_car(t1);
t5=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
return(C_i_vector_set(t3,t4,t5));}

/* for-each-loop3584 in k19982 in k19970 in chicken.irregex#dfa-match/longest in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20469(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_20469,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=(
/* irregex-core.scm:2195: g3585 */
  f_20441(C_a_i(&a,3),((C_word*)t0)[2],C_slot(t2,C_fix(0)))
);
t5=t1;
t6=C_slot(t2,C_fix(1));
t1=t5;
t2=t6;
goto loop;}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* chicken.irregex#nfa-get-epsilons in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_20594(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;{}
t3=C_eqp(t2,C_fix(0));
if(C_truep(t3)){
return(C_SCHEME_END_OF_LIST);}
else{
t4=C_fixnum_times(t2,C_fix(4));
return(C_i_vector_ref(t1,C_fixnum_plus(t4,C_fix(1))));}}

/* chicken.irregex#nfa-add-epsilon! in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_20628(C_word *a,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_stack_overflow_check;{}
t5=(
/* irregex-core.scm:2428: nfa-get-epsilons */
  f_20594(t1,t2)
);
t6=C_i_assq(t3,t5);
if(C_truep(C_i_not(t6))){
t7=C_a_i_cons(&a,2,t3,t4);
t8=C_a_i_cons(&a,2,t7,t5);
t9=C_fixnum_times(t2,C_fix(4));
return(C_i_vector_set(t1,C_fixnum_plus(t9,C_fix(1)),t8));}
else{
t7=C_SCHEME_UNDEFINED;
return(t7);}}

/* chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20769(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_20769,3,t1,t2,t3);}
a=C_alloc(10);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20773,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_a_i_fixnum_times(&a,2,C_fix(128),C_fix(4));
/* irregex-core.scm:2454: scheme#make-vector */
t6=*((C_word*)lf[4]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20773(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,5)))){
C_save_and_reclaim((void *)f_20773,c,av);}
a=C_alloc(18);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20776,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t5=C_a_i_list1(&a,1,((C_word*)t0)[3]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21728,a[2]=t3,a[3]=t7,a[4]=((C_word)li275),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_21728(t9,t4,t5,C_fix(0),C_SCHEME_END_OF_LIST);}

/* k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,6)))){
C_save_and_reclaim((void *)f_20776,c,av);}
a=C_alloc(15);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20778,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t1,a[5]=((C_word)li273),tmp=(C_word)a,a+=6,tmp));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21672,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t6=C_a_i_list1(&a,1,((C_word*)t0)[4]);
/* irregex-core.scm:2671: lp */
t7=((C_word*)t3)[1];
f_20778(t7,t5,t6,C_fix(1),((C_word*)t0)[5],C_fix(0));}

/* lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20778(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(40,0,5)))){
C_save_and_reclaim_args((void *)trf_20778,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(40);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20781,a[2]=t3,a[3]=((C_word)li266),tmp=(C_word)a,a+=4,tmp));
t15=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20791,a[2]=((C_word*)t0)[2],a[3]=((C_word)li268),tmp=(C_word)a,a+=4,tmp));
t16=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20852,a[2]=t9,a[3]=t7,a[4]=((C_word)li269),tmp=(C_word)a,a+=5,tmp));
t17=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20869,a[2]=t4,a[3]=t11,a[4]=((C_word)li270),tmp=(C_word)a,a+=5,tmp));
if(C_truep(C_i_nullp(t2))){
t18=t1;{
C_word av2[2];
av2[0]=t18;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}
else{
t18=C_i_car(t2);
t19=C_eqp(lf[110],t18);
t20=(C_truep(t19)?t19:C_i_equalp(lf[390],C_u_i_car(t2)));
if(C_truep(t20)){
t21=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20919,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t9,a[5]=t7,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2502: lp */
t30=t21;
t31=C_u_i_cdr(t2);
t32=t3;
t33=t4;
t34=t5;
t1=t30;
t2=t31;
t3=t32;
t4=t33;
t5=t34;
goto loop;}
else{
if(C_truep(C_i_stringp(C_u_i_car(t2)))){
t21=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20943,a[2]=t2,a[3]=t13,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2509: lp */
t30=t21;
t31=C_u_i_cdr(t2);
t32=t3;
t33=t4;
t34=t5;
t1=t30;
t2=t31;
t3=t32;
t4=t33;
t5=t34;
goto loop;}
else{
if(C_truep(C_charp(C_u_i_car(t2)))){
t21=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21000,a[2]=t13,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2519: lp */
t30=t21;
t31=C_u_i_cdr(t2);
t32=t3;
t33=t4;
t34=t5;
t1=t30;
t2=t31;
t3=t32;
t4=t33;
t5=t34;
goto loop;}
else{
if(C_truep(C_i_symbolp(C_u_i_car(t2)))){
t21=C_i_assq(C_u_i_car(t2),lf[248]);
if(C_truep(t21)){
t22=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21027,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t3,a[6]=t4,a[7]=t5,tmp=(C_word)a,a+=8,tmp);
t23=C_i_cdr(t21);
if(C_truep(C_i_closurep(t23))){
/* irregex-core.scm:2523: g3916 */
t24=C_u_i_cdr(t21);{
C_word av2[2];
av2[0]=t24;
av2[1]=t22;
((C_proc)(void*)(*((C_word*)t24+1)))(2,av2);}}
else{
t24=C_u_i_cdr(t21);
t25=C_u_i_cdr(t2);
t26=C_a_i_cons(&a,2,t24,t25);
/* irregex-core.scm:2523: lp */
t30=t1;
t31=t26;
t32=t3;
t33=t4;
t34=t5;
t1=t30;
t2=t31;
t3=t32;
t4=t33;
t5=t34;
goto loop;}}
else{
t22=t1;{
C_word av2[2];
av2[0]=t22;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t22+1)))(2,av2);}}}
else{
if(C_truep(C_i_pairp(C_u_i_car(t2)))){
t21=C_i_caar(t2);
if(C_truep(C_i_stringp(t21))){
t22=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21058,a[2]=t11,a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=t3,a[7]=t4,a[8]=t5,tmp=(C_word)a,a+=9,tmp);
t23=C_fixnum_and(t4,C_fix(2));
t24=C_eqp(C_fix(2),t23);
if(C_truep(t24)){
t25=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21077,a[2]=t22,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:2534: string->cset */
f_26484(t25,C_i_caar(t2));}
else{
/* irregex-core.scm:2535: string->cset */
f_26484(t22,C_i_caar(t2));}}
else{
t22=C_i_caar(t2);
t23=C_eqp(t22,lf[115]);
t24=(C_truep(t23)?t23:C_eqp(t22,lf[227]));
if(C_truep(t24)){
t25=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21107,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t3,a[5]=t4,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
t26=C_u_i_car(t2);
/* irregex-core.scm:2541: scheme#append */
t27=*((C_word*)lf[73]+1);{
C_word av2[4];
av2[0]=t27;
av2[1]=t25;
av2[2]=C_u_i_cdr(t26);
av2[3]=C_u_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t27+1)))(4,av2);}}
else{
t25=C_eqp(t22,lf[225]);
t26=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_21121,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t7,a[6]=t4,a[7]=t3,a[8]=t5,a[9]=t22,a[10]=t11,a[11]=t9,a[12]=((C_word*)t0)[2],a[13]=((C_word*)t0)[4],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t25)){
t27=t26;
f_21121(t27,t25);}
else{
t27=C_eqp(t22,lf[226]);
if(C_truep(t27)){
t28=t26;
f_21121(t28,t27);}
else{
t28=C_eqp(t22,lf[156]);
t29=t26;
f_21121(t29,(C_truep(t28)?t28:C_eqp(t22,lf[157])));}}}}}
else{
t21=t1;{
C_word av2[2];
av2[0]=t21;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t21+1)))(2,av2);}}}}}}}}

/* new-state-number in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20781(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_20781,3,t0,t1,t2);}
/* irregex-core.scm:2479: scheme#max */
t3=*((C_word*)lf[254]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=C_fixnum_plus(C_fix(1),t2);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* add-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20791(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,3)))){
C_save_and_reclaim_args((void *)trf_20791,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20795,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t5=C_fixnum_times(t2,C_fix(4));
t6=C_i_vector_length(((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(C_fixnum_greater_or_equal_p(t5,t6))){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20804,a[2]=((C_word*)t0)[2],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t8=C_i_vector_length(((C_word*)((C_word*)t0)[2])[1]);
t9=C_a_i_fixnum_times(&a,2,C_fix(2),t8);
/* irregex-core.scm:2482: scheme#make-vector */
t10=*((C_word*)lf[4]+1);{
C_word av2[4];
av2[0]=t10;
av2[1]=t7;
av2[2]=t9;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t10+1)))(4,av2);}}
else{
t7=t4;
f_20795(t7,C_SCHEME_UNDEFINED);}}

/* k20793 in add-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20795(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,1)))){
C_save_and_reclaim_args((void *)trf_20795,2,t0,t1);}
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_fixnum_times(((C_word*)t0)[3],C_fix(4));
t4=C_i_vector_set(t2,t3,((C_word*)t0)[4]);
t5=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k20802 in add-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_20804,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20807,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_i_vector_length(((C_word*)((C_word*)t0)[2])[1]);
t4=C_a_i_fixnum_difference(&a,2,t3,C_fix(1));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20816,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t6,a[5]=((C_word)li267),tmp=(C_word)a,a+=6,tmp));
t8=((C_word*)t6)[1];
f_20816(t8,t2,t4);}

/* k20805 in k20802 in add-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20807,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];
f_20795(t3,t2);}

/* doloop3883 in k20802 in add-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20816(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20816,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_fixnum_lessp(t2,C_fix(0)))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_vector_ref(((C_word*)((C_word*)t0)[2])[1],t2);
t4=C_i_vector_set(((C_word*)t0)[3],t2,t3);
t5=C_a_i_fixnum_difference(&a,2,t2,C_fix(1));
t7=t1;
t8=t5;
t1=t7;
t2=t8;
goto loop;}}

/* extend-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20852(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20852,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(t2)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20863,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2491: new-state-number */
t5=((C_word*)((C_word*)t0)[3])[1];
f_20781(t5,t4,t2);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k20861 in extend-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20863(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_20863,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* irregex-core.scm:2491: add-state! */
t3=((C_word*)((C_word*)t0)[4])[1];
f_20791(t3,((C_word*)t0)[5],t1,t2);}

/* add-char-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20869(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,3)))){
C_save_and_reclaim_args((void *)trf_20869,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=C_u_i_char_upper_casep(t3);
t5=(C_truep(t4)?C_u_i_char_downcase(t3):C_u_i_char_upcase(t3));
t6=C_fixnum_and(((C_word*)t0)[2],C_fix(2));
t7=C_eqp(C_fix(2),t6);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20886,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t9=C_a_i_cons(&a,2,t3,t3);
t10=C_a_i_vector1(&a,1,t9);
t11=C_a_i_cons(&a,2,t5,t5);
t12=C_a_i_vector1(&a,1,t11);
/* irregex-core.scm:2495: cset-union */
t13=lf[162];{
C_word av2[4];
av2[0]=t13;
av2[1]=t8;
av2[2]=t10;
av2[3]=t12;
f_27092(4,av2);}}
else{
t8=C_a_i_cons(&a,2,t3,t3);
t9=C_a_i_vector1(&a,1,t8);
/* irregex-core.scm:2496: extend-state! */
t10=((C_word*)((C_word*)t0)[3])[1];
f_20852(t10,t1,t2,t9);}}

/* k20884 in add-char-state! in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20886(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20886,c,av);}
/* irregex-core.scm:2495: extend-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k20917 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20919,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20925,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20932,a[2]=((C_word*)t0)[4],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2504: new-state-number */
t4=((C_word*)((C_word*)t0)[5])[1];
f_20781(t4,t3,t1);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20923 in k20917 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_20925,c,av);}
a=C_alloc(6);
t2=(
/* irregex-core.scm:2505: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],t1,((C_word*)t0)[3],C_SCHEME_FALSE)
);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k20930 in k20917 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20932,c,av);}
/* irregex-core.scm:2504: add-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20791(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* k20941 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_20943,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=C_i_string_length(C_u_i_car(((C_word*)t0)[2]));
t3=C_a_i_fixnum_difference(&a,2,t2,C_fix(1));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20957,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word)li271),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_20957(t7,((C_word*)t0)[4],t3,t1);}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* lp2 in k20941 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_20957(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_20957,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_fixnum_lessp(t2,C_fix(0)))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fixnum_difference(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20975,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=C_i_car(((C_word*)t0)[3]);
/* irregex-core.scm:2516: add-char-state! */
t7=((C_word*)((C_word*)t0)[4])[1];
f_20869(t7,t5,t3,C_i_string_ref(t6,t2));}}

/* k20973 in lp2 in k20941 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_20975(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20975,c,av);}
/* irregex-core.scm:2515: lp2 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20957(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k20998 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21000(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21000,c,av);}
/* irregex-core.scm:2519: add-char-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20869(t2,((C_word*)t0)[3],t1,C_u_i_car(((C_word*)t0)[4]));}

/* k21025 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_21027,c,av);}
a=C_alloc(3);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
/* irregex-core.scm:2523: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_20778(t4,((C_word*)t0)[4],t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k21056 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21058(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_21058,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21065,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2536: lp */
t3=((C_word*)((C_word*)t0)[4])[1];
f_20778(t3,t2,C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k21063 in k21056 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21065(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21065,c,av);}
/* irregex-core.scm:2536: extend-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4]);}

/* k21075 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21077(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21077,c,av);}
/* irregex-core.scm:2534: cset-case-insensitive */
f_27619(((C_word*)t0)[2],t1);}

/* k21105 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21107(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21107,c,av);}
/* irregex-core.scm:2541: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21121(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,5)))){
C_save_and_reclaim_args((void *)trf_21121,2,t0,t1);}
a=C_alloc(14);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21124,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2543: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_20778(t3,t2,C_u_i_cdr(((C_word*)t0)[2]),((C_word*)t0)[7],((C_word*)t0)[6],((C_word*)t0)[8]);}
else{
t2=C_eqp(((C_word*)t0)[9],lf[52]);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_21168,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[5],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t2)){
t4=t3;
f_21168(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[9],lf[247]);
if(C_truep(t4)){
t5=t3;
f_21168(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[9],lf[234]);
t6=t3;
f_21168(t6,(C_truep(t5)?t5:C_eqp(((C_word*)t0)[9],lf[179])));}}}}

/* k21122 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_21124,c,av);}
a=C_alloc(7);
t2=C_i_caar(((C_word*)t0)[2]);
t3=(C_truep((C_truep(C_eqp(t2,lf[225]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[156]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))?lf[64]:lf[63]);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21130,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t5=C_u_i_car(((C_word*)t0)[2]);
t6=C_u_i_car(t5);
if(C_truep((C_truep(C_eqp(t6,lf[225]))?C_SCHEME_TRUE:(C_truep(C_eqp(t6,lf[226]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
/* irregex-core.scm:2543: g3943 */
t7=t3;{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
av2[3]=C_fix(2);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
/* irregex-core.scm:2543: g3943 */
t7=t3;{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
av2[3]=C_fix(32);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}

/* k21128 in k21122 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_21130,c,av);}
a=C_alloc(7);
if(C_truep(((C_word*)t0)[2])){
t2=C_i_cdar(((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21144,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t2,a[5]=t1,a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2552: new-state-number */
t4=((C_word*)((C_word*)t0)[6])[1];
f_20781(t4,t3,((C_word*)t0)[2]);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21142 in k21128 in k21122 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21144,c,av);}
/* irregex-core.scm:2552: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21168(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,5)))){
C_save_and_reclaim_args((void *)trf_21168,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21171,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=C_u_i_car(((C_word*)t0)[5]);
t4=C_fixnum_and(((C_word*)t0)[7],C_fix(2));
t5=C_eqp(C_fix(2),t4);
/* irregex-core.scm:2554: sre->cset */
f_26504(t2,t3,C_a_i_list(&a,1,t5));}
else{
t2=C_eqp(((C_word*)t0)[9],lf[103]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21195,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[12],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:2559: lp */
t4=((C_word*)((C_word*)t0)[4])[1];
f_20778(t4,t3,C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t3=C_eqp(((C_word*)t0)[9],lf[131]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21287,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[11],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:2583: lp */
t5=((C_word*)((C_word*)t0)[4])[1];
f_20778(t5,t4,C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t4=C_eqp(((C_word*)t0)[9],lf[129]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[9],lf[127]));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21321,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[11],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:2592: lp */
t7=((C_word*)((C_word*)t0)[4])[1];
f_20778(t7,t6,C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t6=C_eqp(((C_word*)t0)[9],lf[245]);
t7=(C_truep(t6)?t6:C_eqp(((C_word*)t0)[9],lf[108]));
if(C_truep(t7)){
t8=C_i_assq(C_u_i_car(((C_word*)t0)[5]),((C_word*)t0)[13]);
t9=C_i_cdr(t8);
t10=C_fixnum_shift_left(t9,C_fix(1));
t11=C_fixnum_plus(t10,C_fix(1));
t12=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_21381,a[2]=((C_word*)t0)[12],a[3]=t10,a[4]=t11,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[4],a[10]=((C_word*)t0)[7],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:2637: lp */
t13=((C_word*)((C_word*)t0)[4])[1];
f_20778(t13,t12,C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t8=C_eqp(((C_word*)t0)[9],lf[119]);
t9=(C_truep(t8)?t8:C_eqp(((C_word*)t0)[9],lf[120]));
if(C_truep(t9)){
t10=C_i_assq(C_u_i_car(((C_word*)t0)[5]),((C_word*)t0)[13]);
t11=C_i_cdr(t10);
t12=C_fixnum_shift_left(t11,C_fix(1));
t13=C_fixnum_plus(t12,C_fix(1));
t14=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_21459,a[2]=((C_word*)t0)[12],a[3]=t12,a[4]=t13,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[5],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:2650: lp */
t15=((C_word*)((C_word*)t0)[4])[1];
f_20778(t15,t14,C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t10=C_i_caar(((C_word*)t0)[5]);
t11=C_i_assq(t10,lf[248]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21526,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word)li272),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:2661: g4019 */
t13=t12;
f_21526(t13,((C_word*)t0)[3],t11);}
else{
t12=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}}}}}}}

/* k21169 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_21171,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21178,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2556: lp */
t3=((C_word*)((C_word*)t0)[4])[1];
f_20778(t3,t2,C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k21176 in k21169 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21178,c,av);}
/* irregex-core.scm:2556: extend-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4]);}

/* k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_21195,c,av);}
a=C_alloc(17);
if(C_truep(t1)){
t2=C_i_cdar(((C_word*)t0)[2]);
if(C_truep(C_i_nullp(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21211,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2564: new-state-number */
t4=((C_word*)((C_word*)t0)[5])[1];
f_20781(t4,t3,t1);}
else{
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_21214,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t1,a[9]=((C_word*)t0)[2],tmp=(C_word)a,a+=10,tmp);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21272,a[2]=((C_word*)t0)[7],a[3]=t3,a[4]=((C_word*)t0)[8],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2567: scheme#cddar */
t5=*((C_word*)lf[393]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21209 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21211,c,av);}
/* irregex-core.scm:2564: add-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20791(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21214(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_21214,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21217,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21256,a[2]=((C_word*)t0)[6],a[3]=t2,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[5],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:2572: scheme#cadar */
t4=*((C_word*)lf[392]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_21217(2,av2);}}}

/* k21215 in k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21217(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_21217,c,av);}
a=C_alloc(14);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21223,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21233,a[2]=((C_word*)t0)[5],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21237,a[2]=((C_word*)t0)[6],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2577: scheme#max */
t5=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21221 in k21215 in k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21223(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_21223,c,av);}
a=C_alloc(12);
t2=(
/* irregex-core.scm:2579: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],t1,((C_word*)t0)[3],C_SCHEME_FALSE)
);
t3=(
/* irregex-core.scm:2580: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],t1,((C_word*)t0)[4],C_SCHEME_FALSE)
);
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k21231 in k21215 in k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21233,c,av);}
/* irregex-core.scm:2577: add-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20791(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* k21235 in k21215 in k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21237,c,av);}
/* irregex-core.scm:2577: new-state-number */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20781(t2,((C_word*)t0)[3],t1);}

/* k21246 in k21254 in k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21248(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21248,c,av);}
/* irregex-core.scm:2572: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21250 in k21254 in k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21252(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21252,c,av);}
/* irregex-core.scm:2573: new-state-number */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20781(t2,((C_word*)t0)[3],t1);}

/* k21254 in k21212 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21256(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_21256,c,av);}
a=C_alloc(14);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21248,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21252,a[2]=((C_word*)t0)[6],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2573: scheme#max */
t5=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k21262 in k21270 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21264(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21264,c,av);}
/* irregex-core.scm:2567: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21270 in k21193 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21272(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21272,c,av);}
a=C_alloc(13);
t2=(
/* irregex-core.scm:2567: sre-alternate */
  f_18226(C_a_i(&a,3),t1)
);
t3=C_a_i_list1(&a,1,t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21264,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2568: new-state-number */
t5=((C_word*)((C_word*)t0)[6])[1];
f_20781(t5,t4,((C_word*)t0)[5]);}

/* k21285 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21287(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_21287,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21293,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_i_cdar(((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21307,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[6],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2587: new-state-number */
t5=((C_word*)((C_word*)t0)[7])[1];
f_20781(t5,t4,t1);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21291 in k21285 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_21293,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(
/* irregex-core.scm:2589: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],t1,((C_word*)t0)[3],C_SCHEME_FALSE)
);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21305 in k21285 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21307(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21307,c,av);}
/* irregex-core.scm:2587: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21319 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21321(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_21321,c,av);}
a=C_alloc(14);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21327,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21361,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[6],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2596: new-state-number */
t4=((C_word*)((C_word*)t0)[7])[1];
f_20781(t4,t3,t1);}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21325 in k21319 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21327,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21330,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=C_i_cdar(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21357,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[6],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2599: new-state-number */
t5=((C_word*)((C_word*)t0)[7])[1];
f_20781(t5,t4,t1);}

/* k21328 in k21325 in k21319 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_21330,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=C_i_caar(((C_word*)t0)[2]);
t3=C_eqp(lf[127],t2);
if(C_truep(t3)){
t4=(
/* irregex-core.scm:2604: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[3])[1],t1,((C_word*)t0)[4],C_SCHEME_FALSE)
);
t5=(
/* irregex-core.scm:2606: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[3])[1],((C_word*)t0)[4],t1,C_SCHEME_FALSE)
);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t4=(
/* irregex-core.scm:2606: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[3])[1],((C_word*)t0)[4],t1,C_SCHEME_FALSE)
);
t5=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21355 in k21325 in k21319 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21357,c,av);}
/* irregex-core.scm:2599: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21359 in k21319 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21361(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21361,c,av);}
/* irregex-core.scm:2595: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],lf[394],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k21379 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21381(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_21381,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_21387,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21429,a[2]=((C_word*)t0)[6],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2639: new-state-number */
t4=((C_word*)((C_word*)t0)[7])[1];
f_20781(t4,t3,t1);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21385 in k21379 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,2)))){
C_save_and_reclaim((void *)f_21387,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_21390,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t3=(
/* irregex-core.scm:2640: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cdar(((C_word*)t0)[9]))
);
t4=C_a_i_list1(&a,1,t3);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21417,a[2]=((C_word*)t0)[10],a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[11],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2641: new-state-number */
t6=((C_word*)((C_word*)t0)[8])[1];
f_20781(t6,t5,t1);}

/* k21388 in k21385 in k21379 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21390,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21393,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21409,a[2]=((C_word*)t0)[8],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2642: new-state-number */
t4=((C_word*)((C_word*)t0)[9])[1];
f_20781(t4,t3,t1);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_21393(2,av2);}}}

/* k21391 in k21388 in k21385 in k21379 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_21393,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(
/* irregex-core.scm:2644: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],t1,((C_word*)t0)[3],((C_word*)t0)[4])
);
t3=(
/* irregex-core.scm:2645: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7])
);
t4=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21407 in k21388 in k21385 in k21379 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21409,c,av);}
/* irregex-core.scm:2642: add-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20791(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* k21415 in k21385 in k21379 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21417(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21417,c,av);}
/* irregex-core.scm:2640: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21427 in k21379 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21429(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21429,c,av);}
/* irregex-core.scm:2639: add-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20791(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_21459,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_21465,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21507,a[2]=((C_word*)t0)[6],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2652: new-state-number */
t4=((C_word*)((C_word*)t0)[7])[1];
f_20781(t4,t3,t1);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21463 in k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21465(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_21465,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_21468,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21503,a[2]=((C_word*)t0)[9],a[3]=t2,a[4]=((C_word*)t0)[10],a[5]=t1,a[6]=((C_word*)t0)[8],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2653: scheme#cddar */
t4=*((C_word*)lf[393]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k21466 in k21463 in k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21468,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21471,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21487,a[2]=((C_word*)t0)[8],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2655: new-state-number */
t4=((C_word*)((C_word*)t0)[9])[1];
f_20781(t4,t3,t1);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_21471(2,av2);}}}

/* k21469 in k21466 in k21463 in k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21471(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_21471,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(
/* irregex-core.scm:2657: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],t1,((C_word*)t0)[3],((C_word*)t0)[4])
);
t3=(
/* irregex-core.scm:2658: nfa-add-epsilon! */
  f_20628(C_a_i(&a,6),((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7])
);
t4=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21485 in k21466 in k21463 in k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21487,c,av);}
/* irregex-core.scm:2655: add-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20791(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* k21493 in k21501 in k21463 in k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21495(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21495,c,av);}
/* irregex-core.scm:2653: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20778(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21501 in k21463 in k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21503(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21503,c,av);}
a=C_alloc(13);
t2=(
/* irregex-core.scm:2653: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
t3=C_a_i_list1(&a,1,t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21495,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2654: new-state-number */
t5=((C_word*)((C_word*)t0)[6])[1];
f_20781(t5,t4,((C_word*)t0)[5]);}

/* k21505 in k21457 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21507(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21507,c,av);}
/* irregex-core.scm:2652: add-state! */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20791(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* g4019 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21526(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_21526,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_cdr(t2);
if(C_truep(C_i_closurep(t3))){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21544,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);{
C_word av2[4];
av2[0]=0;
av2[1]=t4;
av2[2]=C_u_i_cdr(t2);
av2[3]=C_i_cdar(((C_word*)t0)[2]);
C_apply(4,av2);}}
else{
/* irregex-core.scm:2667: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[395];
av2[3]=C_i_caar(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k21542 in g4019 in k21166 in k21119 in lp in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21544(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_21544,c,av);}
a=C_alloc(3);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
/* irregex-core.scm:2665: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_20778(t4,((C_word*)t0)[4],t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k21670 in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21672(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21672,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21678,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_fixnum_plus(t1,C_fix(1));
/* irregex-core.scm:2673: scheme#make-vector */
t4=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=C_fixnum_times(C_fix(4),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21676 in k21670 in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21678(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_21678,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21681,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_block_size(t1);
t4=C_a_i_fixnum_difference(&a,2,t3,C_fix(1));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21689,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t6,a[5]=((C_word)li274),tmp=(C_word)a,a+=6,tmp));
t8=((C_word*)t6)[1];
f_21689(t8,t2,t4);}

/* k21679 in k21676 in k21670 in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21681,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* doloop4029 in k21676 in k21670 in k20774 in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21689(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_21689,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_fixnum_lessp(t2,C_fix(0)))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_vector_ref(((C_word*)((C_word*)t0)[2])[1],t2);
t4=C_i_vector_set(((C_word*)t0)[3],t2,t3);
t5=C_a_i_fixnum_difference(&a,2,t2,C_fix(1));
t7=t1;
t8=t5;
t1=t7;
t2=t8;
goto loop;}}

/* lp in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21728(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_21728,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
t5=C_i_pairp(t2);
if(C_truep(C_i_not(t5))){
t6=C_fixnum_shift_left(t3,C_fix(1));
t7=C_i_vector_set(((C_word*)((C_word*)t0)[2])[1],C_fix(0),t6);
t8=C_i_vector_set(((C_word*)((C_word*)t0)[2])[1],C_fix(1),C_fix(-1));
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t6=C_i_car(t2);
if(C_truep(C_i_pairp(t6))){
t7=C_i_caar(t2);
t8=C_eqp(t7,lf[245]);
t9=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21763,a[2]=t3,a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[3],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t8)){
t10=t9;
f_21763(t10,t8);}
else{
t10=C_eqp(t7,lf[108]);
if(C_truep(t10)){
t11=t9;
f_21763(t11,t10);}
else{
t11=C_eqp(t7,lf[119]);
t12=t9;
f_21763(t12,(C_truep(t11)?t11:C_eqp(t7,lf[120])));}}}
else{
/* irregex-core.scm:2475: lp */
t13=t1;
t14=C_u_i_cdr(t2);
t15=t3;
t16=t4;
t1=t13;
t2=t14;
t3=t15;
t4=t16;
goto loop;}}}

/* k21761 in lp in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21763(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_21763,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21770,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_u_i_car(((C_word*)t0)[3]);
/* irregex-core.scm:2472: scheme#append */
t4=*((C_word*)lf[73]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t2;
av2[2]=C_u_i_cdr(t3);
av2[3]=C_u_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21796,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2474: scheme#append */
t3=*((C_word*)lf[73]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_car(((C_word*)t0)[3]);
av2[3]=C_u_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k21768 in k21761 in lp in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21770(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_21770,c,av);}
a=C_alloc(6);
t2=C_fixnum_plus(((C_word*)t0)[2],C_fix(1));
t3=C_u_i_car(((C_word*)t0)[3]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[2]);
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[4]);
/* irregex-core.scm:2472: lp */
t6=((C_word*)((C_word*)t0)[5])[1];
f_21728(t6,((C_word*)t0)[6],t1,t2,t5);}

/* k21794 in k21761 in lp in k20771 in chicken.irregex#sre->nfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21796(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21796,c,av);}
/* irregex-core.scm:2474: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21728(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* chicken.irregex#make-mst in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21892(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,3)))){
C_save_and_reclaim_args((void *)trf_21892,2,t1,t2);}
a=C_alloc(14);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21896,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=C_i_vector_length(t2);
t5=C_a_i_fixnum_quotient_checked(&a,2,t4,C_fix(4));
t6=C_s_a_u_i_integer_plus(&a,2,t5,C_fix(3));
/* irregex-core.scm:2744: scheme#make-vector */
t7=*((C_word*)lf[4]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t3;
av2[2]=t6;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k21894 in chicken.irregex#make-mst in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_21896,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21909,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2745: scheme#make-vector */
t3=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_vector_ref(((C_word*)t0)[3],C_fix(0));
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k21907 in k21894 in chicken.irregex#make-mst in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21909(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21909,c,av);}
t2=C_i_vector_set(((C_word*)t0)[2],C_fix(0),t1);
t3=C_i_vector_set(((C_word*)t0)[2],C_fix(1),C_fix(0));
t4=C_i_vector_set(((C_word*)t0)[2],C_fix(2),C_fix(0));
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* chicken.irregex#mst-copy in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21921(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_21921,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21925,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2752: vector-copy */
f_7546(t3,t2);}

/* k21923 in chicken.irregex#mst-copy in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21925,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21932,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2753: vector-copy */
f_7546(t2,C_i_vector_ref(((C_word*)t0)[3],C_fix(0)));}

/* k21930 in k21923 in chicken.irregex#mst-copy in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21932,c,av);}
t2=C_i_vector_set(((C_word*)t0)[2],C_fix(0),t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.irregex#nfa-state->mst in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21938(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21938,4,t1,t2,t3,t4);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21942,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2757: make-mst */
f_21892(t5,t2);}

/* k21940 in chicken.irregex#nfa-state->mst in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_21942,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21945,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2758: mst-add! */
f_21947(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k21943 in k21940 in chicken.irregex#nfa-state->mst in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21945,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.irregex#mst-add! in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21947(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_21947,5,t1,t2,t3,t4,t5);}
a=C_alloc(10);
t6=C_i_vector_ref(t3,C_fix(2));
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21954,a[2]=t3,a[3]=t4,a[4]=t5,a[5]=t8,a[6]=t2,a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t10=C_fixnum_plus(t4,C_fix(3));
t11=C_i_vector_ref(t3,t10);
if(C_truep(C_i_not(t11))){
t12=C_fixnum_plus(((C_word*)t8)[1],t4);
t13=C_set_block_item(t8,0,t12);
t14=C_i_vector_ref(t3,C_fix(1));
t15=t9;
f_21954(t15,C_i_vector_set(t3,C_fix(1),C_fixnum_plus(t14,C_fix(1))));}
else{
t12=t9;
f_21954(t12,C_SCHEME_UNDEFINED);}}

/* k21952 in chicken.irregex#mst-add! in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_21954(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,3)))){
C_save_and_reclaim_args((void *)trf_21954,2,t0,t1);}
a=C_alloc(18);
t2=C_i_vector_set(((C_word*)t0)[2],C_fixnum_plus(((C_word*)t0)[3],C_fix(3)),((C_word*)t0)[4]);
t3=C_i_vector_ref(((C_word*)t0)[2],C_fix(0));
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21961,a[2]=t3,a[3]=((C_word*)t0)[5],a[4]=((C_word)li280),tmp=(C_word)a,a+=5,tmp);
t5=C_i_check_list_2(((C_word*)t0)[4],lf[306]);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21996,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22009,a[2]=t4,a[3]=t8,a[4]=((C_word)li281),tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_22009(t10,t6,((C_word*)t0)[4]);}

/* g4087 in k21952 in chicken.irregex#mst-add! in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_21961(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_stack_overflow_check;{}
t2=C_i_car(t1);
t3=C_u_i_cdr(t1);
t4=C_i_vector_ref(((C_word*)t0)[2],t2);
t5=C_i_memq(t3,t4);
if(C_truep(C_i_not(t5))){
t6=C_fixnum_plus(((C_word*)((C_word*)t0)[3])[1],t2);
t7=C_mutate(((C_word *)((C_word*)t0)[3])+1,t6);
t8=C_a_i_cons(&a,2,t3,t4);
return(C_i_vector_set(((C_word*)t0)[2],t2,t8));}
else{
t6=C_SCHEME_UNDEFINED;
return(t6);}}

/* k21994 in k21952 in chicken.irregex#mst-add! in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_21996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,1)))){
C_save_and_reclaim((void *)f_21996,c,av);}
a=C_alloc(10);
t2=C_i_vector_length(((C_word*)t0)[2]);
t3=C_a_i_fixnum_quotient_checked(&a,2,t2,C_fix(4));
t4=C_s_a_i_modulo(&a,2,((C_word*)((C_word*)t0)[3])[1],t3);
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_vector_set(((C_word*)t0)[5],C_fix(2),t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* for-each-loop4086 in k21952 in chicken.irregex#mst-add! in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22009(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_22009,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=(
/* irregex-core.scm:2769: g4087 */
  f_21961(C_a_i(&a,3),((C_word*)t0)[2],C_slot(t2,C_fix(0)))
);
t5=t1;
t6=C_slot(t2,C_fix(1));
t1=t5;
t2=t6;
goto loop;}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k22108 in k23002 in g4342 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22110(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_22110,c,av);}
a=C_alloc(17);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_22116,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=t4,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],a[14]=((C_word*)t0)[12],tmp=(C_word)a,a+=15,tmp);
t6=C_fixnum_plus(((C_word*)t0)[3],C_fix(3));
t7=C_i_vector_ref(((C_word*)t0)[2],t6);
if(C_truep(C_i_not(t7))){
t8=C_fixnum_plus(((C_word*)t4)[1],((C_word*)t0)[3]);
t9=C_set_block_item(t4,0,t8);
t10=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t11=t5;
f_22116(t11,C_i_vector_set(((C_word*)t0)[2],C_fix(1),C_fixnum_plus(t10,C_fix(1))));}
else{
t8=t5;
f_22116(t8,C_SCHEME_UNDEFINED);}}

/* k22114 in k22108 in k23002 in g4342 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22116(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_22116,2,t0,t1);}
a=C_alloc(14);
t2=C_i_vector_set(((C_word*)t0)[2],C_fixnum_plus(((C_word*)t0)[3],C_fix(3)),((C_word*)t0)[4]);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22122,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t4=C_i_memq(((C_word*)t0)[11],((C_word*)t0)[12]);
if(C_truep(C_i_not(t4))){
t5=C_fixnum_plus(((C_word*)((C_word*)t0)[6])[1],((C_word*)t0)[13]);
t6=C_mutate(((C_word *)((C_word*)t0)[6])+1,t5);
t7=C_a_i_cons(&a,2,((C_word*)t0)[11],((C_word*)t0)[12]);
t8=t3;
f_22122(t8,C_i_vector_set(((C_word*)t0)[14],((C_word*)t0)[13],t7));}
else{
t5=t3;
f_22122(t5,C_SCHEME_UNDEFINED);}}

/* k22120 in k22114 in k22108 in k23002 in g4342 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22122(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,3)))){
C_save_and_reclaim_args((void *)trf_22122,2,t0,t1);}
a=C_alloc(16);
t2=C_i_vector_length(((C_word*)t0)[2]);
t3=C_a_i_fixnum_quotient_checked(&a,2,t2,C_fix(4));
t4=C_s_a_i_modulo(&a,2,((C_word*)((C_word*)t0)[3])[1],t3);
t5=C_i_vector_set(((C_word*)t0)[4],C_fix(2),t4);
t6=C_i_cdr(((C_word*)t0)[5]);
t7=C_a_i_cons(&a,2,((C_word*)t0)[6],((C_word*)t0)[7]);
t8=C_a_i_cons(&a,2,t7,((C_word*)t0)[8]);
/* irregex-core.scm:3037: lp2 */
t9=((C_word*)((C_word*)t0)[9])[1];
f_22971(t9,((C_word*)t0)[10],t6,t8);}

/* lp in k23002 in g4342 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22175(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_22175,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t4=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_a_i_cons(&a,2,t4,t3);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=C_i_caar(t2);
t5=C_eqp(t4,((C_word*)t0)[2]);
if(C_truep(t5)){
t6=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t7=C_u_i_cdr(t2);
t8=C_a_i_cons(&a,2,t6,t7);
/* irregex-core.scm:2800: scheme#append */
t9=*((C_word*)lf[73]+1);{
C_word av2[4];
av2[0]=t9;
av2[1]=t1;
av2[2]=t3;
av2[3]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
t6=C_u_i_cdr(t2);
t7=C_u_i_car(t2);
t8=C_a_i_cons(&a,2,t7,t3);
/* irregex-core.scm:2801: lp */
t10=t1;
t11=t6;
t12=t8;
t1=t10;
t2=t11;
t3=t12;
goto loop;}}}

/* lp in lp in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22246(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_22246,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_vector_ref(((C_word*)t0)[3],t2);
t5=C_i_not(t4);
t6=C_i_vector_ref(((C_word*)t0)[4],t2);
t7=C_i_not(t6);
t8=C_eqp(t5,t7);
if(C_truep(t8)){
t9=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:2822: lp */
t11=t1;
t12=t9;
t1=t11;
t2=t12;
goto loop;}
else{
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}}

/* chicken.irregex#mst-fold in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22299(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_22299,4,t1,t2,t3,t4);}
a=C_alloc(9);
t5=C_i_vector_length(t2);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22308,a[2]=t5,a[3]=t2,a[4]=t7,a[5]=t3,a[6]=((C_word)li283),tmp=(C_word)a,a+=7,tmp));
t9=((C_word*)t7)[1];
f_22308(t9,t1,C_fix(3),t4);}

/* lp in chicken.irregex#mst-fold in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22308(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,4)))){
C_save_and_reclaim_args((void *)trf_22308,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_vector_ref(((C_word*)t0)[3],t2);
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22328,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t6,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t5)){
t8=C_a_i_fixnum_difference(&a,2,t2,C_fix(3));
/* irregex-core.scm:2831: kons */
t9=((C_word*)t0)[5];{
C_word av2[5];
av2[0]=t9;
av2[1]=t7;
av2[2]=t8;
av2[3]=t5;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
/* irregex-core.scm:2831: lp */
t10=t1;
t11=t6;
t12=t3;
t1=t10;
t2=t11;
t3=t12;
goto loop;}}}

/* k22326 in lp in chicken.irregex#mst-fold in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22328,c,av);}
/* irregex-core.scm:2831: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22308(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* doloop4187 in g4342 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_22357(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
t2=C_i_memq(t1,((C_word*)t0)[2]);
if(C_truep(C_i_not(t2))){
return(t1);}
else{
t4=C_fixnum_plus(t1,C_fix(1));
t1=t4;
goto loop;}}

/* chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22381(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,4)))){
C_save_and_reclaim_args((void *)trf_22381,3,t1,t2,t3);}
a=C_alloc(15);
t4=C_i_pairp(t3);
t5=(C_truep(t4)?C_u_i_car(t3):C_SCHEME_FALSE);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22388,a[2]=t2,a[3]=t5,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t7=C_i_vector_length(t2);
t8=C_a_i_fixnum_quotient_checked(&a,2,t7,C_fix(4));
t9=C_s_a_u_i_integer_minus(&a,2,t8,C_fix(1));
/* irregex-core.scm:2880: nfa-state->mst */
f_21938(t6,t2,t9,C_SCHEME_END_OF_LIST);}

/* k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22388(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_22388,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22391,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2881: nfa-epsilon-closure */
f_23066(t2,((C_word*)t0)[2],t1);}

/* k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22391(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_22391,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22394,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2884: tag-set-commands-for-closure */
f_23081(t2,((C_word*)t0)[2],((C_word*)t0)[5],t1,C_SCHEME_END_OF_LIST);}

/* k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22394(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22394,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22397,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:2885: make-mst */
f_21892(t2,((C_word*)t0)[3]);}

/* k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22397(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,5)))){
C_save_and_reclaim((void *)f_22397,c,av);}
a=C_alloc(36);
t2=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,C_SCHEME_FALSE,t2);
t4=C_a_i_cons(&a,2,((C_word*)t0)[3],t3);
t5=C_a_i_list(&a,1,t4);
t6=C_a_i_list3(&a,3,t1,C_SCHEME_FALSE,t5);
t7=C_a_i_list1(&a,1,((C_word*)t0)[3]);
t8=C_a_i_list1(&a,1,t6);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22413,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t10,a[6]=((C_word)li297),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_22413(t12,((C_word*)t0)[6],t7,t8,C_fix(0));}

/* lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22413(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,5)))){
C_save_and_reclaim_args((void *)trf_22413,5,t0,t1,t2,t3,t4);}
a=C_alloc(13);
if(C_truep(C_i_nullp(t2))){
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=C_i_vector_ref(((C_word*)t0)[3],C_fix(1));
t7=C_fixnum_plus(t6,C_fix(1));
t8=C_i_setslot(t5,C_fix(0),t7);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22430,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:2896: ##sys#fast-reverse */
t10=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}
else{
t5=(C_truep(((C_word*)t0)[4])?C_fixnum_greaterp(t4,((C_word*)t0)[4]):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_i_car(t2);
if(C_truep(C_i_assoc(t6,t3))){
/* irregex-core.scm:2900: lp */
t11=t1;
t12=C_u_i_cdr(t2);
t13=t3;
t14=t4;
t1=t11;
t2=t12;
t3=t13;
t4=t14;
goto loop;}
else{
t7=C_u_i_car(t2);
t8=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22465,a[2]=t2,a[3]=t7,a[4]=t3,a[5]=((C_word*)t0)[5],a[6]=t4,a[7]=((C_word*)t0)[3],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22768,a[2]=((C_word*)t0)[3],a[3]=((C_word)li296),tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2961: mst-fold */
f_22299(t8,t7,t9,C_SCHEME_END_OF_LIST);}}}}

/* k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,5)))){
C_save_and_reclaim((void *)f_22430,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22592,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22714,a[2]=t4,a[3]=((C_word)li288),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_22714(t6,t2,C_fix(0),t1,C_SCHEME_END_OF_LIST);}

/* k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22465(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_22465,c,av);}
a=C_alloc(11);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22469,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t4,a[7]=((C_word*)t0)[7],a[8]=((C_word)li293),tmp=(C_word)a,a+=9,tmp));
t6=((C_word*)t4)[1];
f_22469(t6,((C_word*)t0)[8],t1,t2,C_SCHEME_END_OF_LIST);}

/* lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22469(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_22469,5,t0,t1,t2,t3,t4);}
a=C_alloc(12);
if(C_truep(C_i_nullp(t2))){
t5=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t6=C_a_i_list3(&a,3,((C_word*)t0)[2],t5,t4);
t7=C_a_i_cons(&a,2,t6,((C_word*)t0)[3]);
/* irregex-core.scm:2908: lp */
t8=((C_word*)((C_word*)t0)[4])[1];
f_22413(t8,t1,t3,t7,C_fixnum_plus(((C_word*)t0)[5],C_fix(1)));}
else{
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22497,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:2911: nfa-epsilon-closure */
f_23066(t5,((C_word*)t0)[7],C_i_cdar(t2));}}

/* k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_22497,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22500,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t3=C_i_vector_ref(t1,C_fix(2));
t4=C_fixnum_times(t3,C_fix(4));
t5=C_fixnum_plus(t4,C_fix(2));
t6=C_i_vector_ref(((C_word*)t0)[7],t5);
t7=C_i_assoc(t1,t6);
t8=(C_truep(t7)?C_i_cdr(t7):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=t2;
f_22500(t9,t8);}
else{
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23399,a[2]=t1,a[3]=((C_word*)t0)[7],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t10=C_i_vector_ref(((C_word*)t0)[7],C_fix(0));
t11=C_i_vector_ref(t1,C_fix(0));
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23248,a[2]=t13,a[3]=t10,a[4]=t11,a[5]=t1,a[6]=((C_word)li292),tmp=(C_word)a,a+=7,tmp));
t15=((C_word*)t13)[1];
f_23248(t15,t9,((C_word*)t0)[8]);}}

/* k22498 in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22500(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,5)))){
C_save_and_reclaim_args((void *)trf_22500,2,t0,t1);}
a=C_alloc(10);
t2=(C_truep(t1)?C_i_cdr(t1):C_SCHEME_END_OF_LIST);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22506,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t2,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:2917: tag-set-commands-for-closure */
f_23081(t3,((C_word*)t0)[8],C_i_cdar(((C_word*)t0)[3]),((C_word*)t0)[2],t2);}

/* k22504 in k22498 in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22506(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_22506,c,av);}
a=C_alloc(15);
t2=(C_truep(((C_word*)t0)[2])?C_i_car(((C_word*)t0)[2]):((C_word*)t0)[3]);
t3=C_u_i_cdr(((C_word*)t0)[4]);
t4=(C_truep(((C_word*)t0)[2])?((C_word*)t0)[5]:C_a_i_cons(&a,2,t2,((C_word*)t0)[5]));
t5=C_i_caar(((C_word*)t0)[4]);
t6=C_a_i_cons(&a,2,((C_word*)t0)[6],t1);
t7=C_a_i_cons(&a,2,t5,t6);
t8=C_a_i_cons(&a,2,t2,t7);
t9=C_a_i_cons(&a,2,t8,((C_word*)t0)[7]);
/* irregex-core.scm:2920: lp2 */
t10=((C_word*)((C_word*)t0)[8])[1];
f_22469(t10,((C_word*)t0)[9],t3,t4,t9);}

/* k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22592(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22592,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22595,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2938: scheme#make-vector */
t3=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_length(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22595(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_22595,c,av);}
a=C_alloc(8);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22600,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word)li287),tmp=(C_word)a,a+=6,tmp));
t5=((C_word*)t3)[1];
f_22600(t5,((C_word*)t0)[3],C_fix(0),((C_word*)t0)[4]);}

/* doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22600(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_22600,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22610,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=t1,a[7]=t3,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:2942: scheme#cadar */
t5=*((C_word*)lf[392]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k22608 in doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22610(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22610,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22613,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:2943: scheme#caddar */
t3=*((C_word*)lf[401]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22611 in k22608 in doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_22613,c,av);}
a=C_alloc(26);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22633,a[2]=((C_word*)t0)[2],a[3]=((C_word)li285),tmp=(C_word)a,a+=4,tmp);
t7=C_i_check_list_2(t1,lf[211]);
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22674,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22676,a[2]=t4,a[3]=t10,a[4]=t6,a[5]=t5,a[6]=((C_word)li286),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_22676(t12,t8,t1);}

/* g4258 in k22611 in k22608 in doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22633(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_22633,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22641,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_cadr(t2))){
t4=C_u_i_cdr(t2);
t5=C_u_i_car(t4);
t6=C_i_vector_length(t5);
t7=C_eqp(t6,C_fix(1));
if(C_truep(t7)){
t8=C_i_vector_ref(t5,C_fix(0));
t9=C_i_car(t8);
t10=C_i_vector_ref(t5,C_fix(0));
t11=C_i_char_equalp(t9,C_i_cdr(t10));
t12=t3;
f_22641(t12,(C_truep(t11)?C_i_car(C_i_vector_ref(t5,C_fix(0))):t5));}
else{
t8=t3;
f_22641(t8,(C_truep(C_SCHEME_FALSE)?C_i_car(C_i_vector_ref(t5,C_fix(0))):t5));}}
else{
t4=t3;
f_22641(t4,C_SCHEME_FALSE);}}

/* k22639 in g4258 in k22611 in k22608 in doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22641(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,1)))){
C_save_and_reclaim_args((void *)trf_22641,2,t0,t1);}
a=C_alloc(6);
t2=C_i_assoc(C_u_i_car(((C_word*)t0)[2]),((C_word*)t0)[3]);
t3=C_i_cdr(t2);
t4=C_i_cddr(((C_word*)t0)[2]);
t5=C_a_i_cons(&a,2,t3,t4);
t6=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t6;
av2[1]=C_a_i_cons(&a,2,t1,t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k22672 in k22611 in k22608 in doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_22674,c,av);}
a=C_alloc(8);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_i_vector_set(((C_word*)t0)[3],((C_word*)t0)[4],t2);
t4=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[4],C_fix(1));
t5=((C_word*)((C_word*)t0)[5])[1];
f_22600(t5,((C_word*)t0)[6],t4,C_u_i_cdr(((C_word*)t0)[7]));}

/* map-loop4252 in k22611 in k22608 in doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22676(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_22676,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22701,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:2947: g4258 */
t4=((C_word*)t0)[4];
f_22633(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k22699 in map-loop4252 in k22611 in k22608 in doloop4244 in k22593 in k22590 in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_22701,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_22676(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* lp in k22428 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22714(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_22714,5,t0,t1,t2,t3,t4);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t3))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_fixnum_plus(t2,C_fix(1));
t6=C_i_cdr(t3);
t7=C_i_caar(t3);
t8=C_a_i_cons(&a,2,t7,t2);
t9=C_a_i_cons(&a,2,t8,t4);
/* irregex-core.scm:2936: lp */
t11=t1;
t12=t5;
t13=t6;
t14=t9;
t1=t11;
t2=t12;
t3=t13;
t4=t14;
goto loop;}}

/* k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22753(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,5)))){
C_save_and_reclaim((void *)f_22753,c,av);}
a=C_alloc(10);
t2=C_i_vector_length(t1);
t3=C_eqp(t2,C_fix(0));
t4=C_i_not(t3);
t5=(C_truep(t4)?t1:C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22830,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word)li294),tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:2968: g4307 */
t7=t6;
f_22830(t7,((C_word*)t0)[9],t5);}
else{
t6=C_u_i_cdr(((C_word*)t0)[2]);
t7=C_u_i_car(((C_word*)t0)[2]);
t8=C_a_i_cons(&a,2,t7,((C_word*)t0)[7]);
/* irregex-core.scm:3003: lp */
t9=((C_word*)((C_word*)t0)[3])[1];
f_22789(t9,((C_word*)t0)[9],t6,((C_word*)t0)[8],((C_word*)t0)[4],t8);}}

/* a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,6)))){
C_save_and_reclaim((void *)f_22768,c,av);}
a=C_alloc(8);
t5=C_eqp(t2,C_fix(0));
t6=(C_truep(t5)?C_SCHEME_END_OF_LIST:C_i_vector_ref(((C_word*)t0)[2],C_fixnum_times(t2,C_fix(4))));
if(C_truep(C_i_nullp(t6))){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_i_car(t6);
t8=C_u_i_cdr(t6);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22789,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t10,a[5]=((C_word)li295),tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_22789(t12,t1,t4,t7,t8,C_SCHEME_END_OF_LIST);}}

/* lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22789(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,5)))){
C_save_and_reclaim_args((void *)trf_22789,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(10);
if(C_truep(C_i_nullp(t2))){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22807,a[2]=t3,a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2975: nfa-state->mst */
f_21938(t6,((C_word*)t0)[2],t4,((C_word*)t0)[3]);}
else{
t6=C_i_caar(t2);
if(C_truep(C_i_equalp(t3,t6))){
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22816,a[2]=t1,a[3]=t2,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:2979: mst-add! */
f_21947(t7,((C_word*)t0)[2],C_i_cdar(t2),t4,((C_word*)t0)[3]);}
else{
t7=C_i_caar(t2);
t8=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22753,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=t4,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=t5,a[8]=t3,a[9]=t1,tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:2959: cset-intersection */
t9=lf[405];{
C_word av2[4];
av2[0]=t9;
av2[1]=t8;
av2[2]=t3;
av2[3]=t7;
f_27483(4,av2);}}}}

/* k22805 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_22807,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k22814 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22816(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22816,c,av);}
/* irregex-core.scm:2980: scheme#append */
t2=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* g4307 in k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22830(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_22830,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22834,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t1,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:2983: cset-difference */
f_27287(t3,((C_word*)t0)[8],C_i_caar(((C_word*)t0)[2]));}

/* k22832 in g4307 in k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22834(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_22834,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22837,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:2984: cset-difference */
f_27287(t2,C_i_caar(((C_word*)t0)[2]),((C_word*)t0)[10]);}

/* k22835 in k22832 in g4307 in k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22837(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22837,c,av);}
a=C_alloc(13);
t2=C_i_cdar(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22843,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=t1,a[12]=((C_word*)t0)[10],tmp=(C_word)a,a+=13,tmp);
t4=C_i_vector_length(t1);
t5=C_eqp(t4,C_fix(0));
if(C_truep(C_i_not(t5))){
/* irregex-core.scm:2988: mst-copy */
f_21921(t3,t2);}
else{
t6=t3;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_22843(2,av2);}}}

/* k22841 in k22835 in k22832 in g4307 in k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_22843,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22846,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(t1)){
t3=C_a_i_cons(&a,2,((C_word*)t0)[11],t1);
t4=t2;
f_22846(t4,C_a_i_cons(&a,2,t3,((C_word*)t0)[12]));}
else{
t3=t2;
f_22846(t3,((C_word*)t0)[12]);}}

/* k22844 in k22841 in k22835 in k22832 in g4307 in k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22846(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,5)))){
C_save_and_reclaim_args((void *)trf_22846,2,t0,t1);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22849,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:2992: mst-add! */
f_21947(t2,((C_word*)t0)[9],((C_word*)t0)[4],((C_word*)t0)[8],((C_word*)t0)[10]);}

/* k22847 in k22844 in k22841 in k22835 in k22832 in g4307 in k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_22849,c,av);}
a=C_alloc(7);
t2=C_i_vector_length(((C_word*)t0)[2]);
t3=C_eqp(t2,C_fix(0));
if(C_truep(t3)){
t4=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22866,a[2]=((C_word*)t0)[5],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:2999: scheme#append */
t6=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_u_i_cdr(((C_word*)t0)[6]);
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t4=C_u_i_cdr(((C_word*)t0)[6]);
t5=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t6=C_a_i_cons(&a,2,t5,((C_word*)t0)[7]);
/* irregex-core.scm:3000: lp */
t7=((C_word*)((C_word*)t0)[8])[1];
f_22789(t7,((C_word*)t0)[5],t4,((C_word*)t0)[2],((C_word*)t0)[9],t6);}}

/* k22864 in k22847 in k22844 in k22841 in k22835 in k22832 in g4307 in k22751 in lp in a22767 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_22866,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_22938,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22942,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=C_i_vector_length(((C_word*)t0)[2]);
t4=C_a_i_fixnum_quotient_checked(&a,2,t3,C_fix(4));
/* irregex-core.scm:3014: scheme#make-vector */
t5=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=t4;
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_22942,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22946,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3015: mst-copy */
f_21921(t2,((C_word*)t0)[5]);}

/* k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_22946(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_22946,c,av);}
a=C_alloc(7);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22948,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word)li303),tmp=(C_word)a,a+=5,tmp));
t5=((C_word*)t3)[1];
f_22948(t5,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22948(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_22948,5,t0,t1,t2,t3,t4);}
a=C_alloc(12);
if(C_truep(C_i_nullp(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_caar(t2);
t6=C_u_i_car(t2);
t7=C_u_i_cdr(t6);
t8=(
/* irregex-core.scm:3020: nfa-get-epsilons */
  f_20594(((C_word*)t0)[2],t5)
);
t9=C_u_i_cdr(t2);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22971,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=t4,a[5]=t5,a[6]=((C_word*)t0)[2],a[7]=t11,a[8]=t7,a[9]=((C_word)li302),tmp=(C_word)a,a+=10,tmp));
t13=((C_word*)t11)[1];
f_22971(t13,t1,t8,t9);}}

/* lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_22971(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,4)))){
C_save_and_reclaim_args((void *)trf_22971,4,t0,t1,t2,t3);}
a=C_alloc(18);
if(C_truep(C_i_nullp(t2))){
/* irregex-core.scm:3023: lp */
t4=((C_word*)((C_word*)t0)[2])[1];
f_22948(t4,t1,t3,((C_word*)t0)[3],((C_word*)t0)[4]);}
else{
t4=C_i_caar(t2);
t5=C_i_vector_ref(((C_word*)t0)[3],t4);
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[5],t5))){
t6=C_i_vector_set(((C_word*)t0)[3],t4,((C_word*)t0)[5]);
t7=C_i_cdar(t2);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_23000,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=((C_word*)t0)[6],a[5]=t2,a[6]=t3,a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word)li301),tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:3030: g4342 */
t9=t8;
f_23000(t9,t1,t7);}
else{
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23028,a[2]=t2,a[3]=t4,a[4]=((C_word*)t0)[8],a[5]=t3,a[6]=((C_word*)t0)[7],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t9=C_fixnum_plus(t4,C_fix(3));
t10=C_i_vector_ref(((C_word*)t0)[4],t9);
if(C_truep(C_i_not(t10))){
t11=C_i_vector_ref(((C_word*)t0)[4],C_fix(2));
t12=C_fixnum_plus(t11,t4);
t13=C_i_vector_length(((C_word*)t0)[6]);
t14=C_a_i_fixnum_quotient_checked(&a,2,t13,C_fix(4));
t15=C_s_a_i_modulo(&a,2,t12,t14);
t16=C_i_vector_set(((C_word*)t0)[4],C_fix(2),t15);
t17=C_i_vector_ref(((C_word*)t0)[4],C_fix(1));
t18=C_fixnum_plus(t17,C_fix(1));
t19=C_i_vector_set(((C_word*)t0)[4],C_fix(1),t18);
t20=t8;
f_23028(t20,C_i_vector_set(((C_word*)t0)[4],C_fixnum_plus(t4,C_fix(3)),((C_word*)t0)[8]));}
else{
t11=t8;
f_23028(t11,C_i_vector_set(((C_word*)t0)[4],C_fixnum_plus(t4,C_fix(3)),((C_word*)t0)[8]));}}}
else{
/* irregex-core.scm:3042: lp2 */
t21=t1;
t22=C_u_i_cdr(t2);
t23=t3;
t1=t21;
t2=t22;
t3=t23;
goto loop;}}}

/* g4342 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23000(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,2)))){
C_save_and_reclaim_args((void *)trf_23000,3,t0,t1,t2);}
a=C_alloc(15);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_23004,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=t1,a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
t4=C_i_vector_ref(((C_word*)t0)[4],C_fix(1));
t5=C_i_vector_ref(((C_word*)t0)[2],C_fix(0));
t6=C_i_vector_ref(t5,t2);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22357,a[2]=t6,a[3]=((C_word)li300),tmp=(C_word)a,a+=4,tmp);
t8=(
  f_22357(t7,C_fix(0))
);
if(C_truep(C_fixnum_greaterp(t8,t4))){
t9=C_i_vector_set(((C_word*)t0)[4],C_fix(1),t8);
t10=t3;
f_23004(t10,t8);}
else{
t9=t3;
f_23004(t9,t8);}}

/* k23002 in g4342 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23004(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,4)))){
C_save_and_reclaim_args((void *)trf_23004,2,t0,t1);}
a=C_alloc(21);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(0));
t3=C_i_vector_ref(t2,((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22110,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=t1,a[10]=t3,a[11]=((C_word*)t0)[3],a[12]=t2,tmp=(C_word)a,a+=13,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22175,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t6,a[5]=((C_word)li299),tmp=(C_word)a,a+=6,tmp));
t8=((C_word*)t6)[1];
f_22175(t8,t4,((C_word*)t0)[10],C_SCHEME_END_OF_LIST);}

/* k23026 in lp2 in lp in k22944 in k22940 in k22936 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23028(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_23028,2,t0,t1);}
a=C_alloc(6);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[5]);
/* irregex-core.scm:3041: lp2 */
t5=((C_word*)((C_word*)t0)[6])[1];
f_22971(t5,((C_word*)t0)[7],t2,t4);}

/* a23055 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23056,c,av);}
a=C_alloc(6);
t5=C_a_i_cons(&a,2,t2,t3);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_cons(&a,2,t5,t4);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23066(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,5)))){
C_save_and_reclaim_args((void *)trf_23066,3,t1,t2,t3);}
a=C_alloc(13);
t4=C_i_vector_ref(t3,C_fix(2));
t5=C_fixnum_times(t4,C_fix(4));
t6=C_fixnum_plus(t5,C_fix(3));
t7=C_i_vector_ref(t2,t6);
t8=C_i_assoc(t3,t7);
t9=(C_truep(t8)?C_i_cdr(t8):C_SCHEME_FALSE);
if(C_truep(t9)){
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23076,a[2]=t3,a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22938,a[2]=t2,a[3]=t10,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23056,a[2]=((C_word)li304),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3010: mst-fold */
f_22299(t11,t3,t12,C_SCHEME_END_OF_LIST);}}

/* k23074 in chicken.irregex#nfa-epsilon-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23076,c,av);}
a=C_alloc(6);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=C_fixnum_times(t2,C_fix(4));
t4=C_fixnum_plus(t3,C_fix(3));
t5=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t6=C_i_vector_ref(((C_word*)t0)[3],t4);
t7=C_a_i_cons(&a,2,t5,t6);
t8=C_i_vector_set(((C_word*)t0)[3],t4,t7);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23081(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_23081,5,t1,t2,t3,t4,t5);}
a=C_alloc(10);
t6=C_i_vector_ref(t2,C_fix(0));
t7=C_i_vector_ref(t4,C_fix(0));
t8=C_i_vector_ref(t3,C_fix(0));
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23096,a[2]=t6,a[3]=t7,a[4]=t8,a[5]=t10,a[6]=t5,a[7]=((C_word)li309),tmp=(C_word)a,a+=8,tmp));
t12=((C_word*)t10)[1];
f_23096(t12,t1,C_fix(0),C_SCHEME_END_OF_LIST);}

/* lp in chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23096(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_23096,4,t0,t1,t2,t3);}
a=C_alloc(9);
t4=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_vector_ref(((C_word*)t0)[3],t2);
t6=C_i_vector_ref(((C_word*)t0)[4],t2);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23116,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=t8,a[5]=((C_word*)t0)[6],a[6]=((C_word)li308),tmp=(C_word)a,a+=7,tmp));
t10=((C_word*)t8)[1];
f_23116(t10,t1,t5,t6,t3);}}

/* lp2 in lp in chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23116(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,3)))){
C_save_and_reclaim_args((void *)trf_23116,5,t0,t1,t2,t3,t4);}
a=C_alloc(19);
if(C_truep(C_i_nullp(t2))){
/* irregex-core.scm:3062: lp */
t5=((C_word*)((C_word*)t0)[2])[1];
f_23096(t5,t1,C_fixnum_plus(((C_word*)t0)[3],C_fix(1)),t4);}
else{
t5=C_i_car(t2);
t6=C_i_memq(t5,t3);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23139,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t6)){
t8=t7;
f_23139(t8,t6);}
else{
t8=C_i_nullp(((C_word*)t0)[5]);
if(C_truep(C_i_not(t8))){
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23171,a[2]=t7,a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23204,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word)li307),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3069: any */
f_9300(t9,t10,((C_word*)t0)[5]);}
else{
t9=t7;
f_23139(t9,C_SCHEME_FALSE);}}}}

/* k23137 in lp2 in lp in chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23139(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_23139,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
/* irregex-core.scm:3079: lp2 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_23116(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6]);}
else{
t2=C_u_i_cdr(((C_word*)t0)[4]);
t3=C_u_i_car(((C_word*)t0)[4]);
t4=C_a_i_cons(&a,2,((C_word*)t0)[7],t3);
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[6]);
/* irregex-core.scm:3080: lp2 */
t6=((C_word*)((C_word*)t0)[2])[1];
f_23116(t6,((C_word*)t0)[3],t2,((C_word*)t0)[5],t5);}}

/* k23169 in lp2 in lp in chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_23171,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23178,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23180,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word)li306),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3075: any */
f_9300(t2,t3,((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[2];
f_23139(t2,C_SCHEME_FALSE);}}

/* k23176 in k23169 in lp2 in lp in chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23178,c,av);}
t2=((C_word*)t0)[2];
f_23139(t2,C_i_not(t1));}

/* a23179 in k23169 in lp2 in lp in chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23180(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23180,c,av);}
t3=C_i_vector_ref(t2,C_fix(0));
t4=C_eqp(t3,((C_word*)t0)[2]);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?C_eqp(C_i_vector_ref(t2,C_fix(1)),C_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* a23203 in lp2 in lp in chicken.irregex#tag-set-commands-for-closure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23204,c,av);}
t3=C_i_vector_ref(t2,C_fix(0));
t4=C_eqp(t3,((C_word*)t0)[2]);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?C_eqp(C_i_vector_ref(t2,C_fix(2)),C_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* lp in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23248(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,3)))){
C_save_and_reclaim_args((void *)trf_23248,3,t0,t1,t2);}
a=C_alloc(19);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23261,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23383,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=C_i_caar(t2);
t6=C_i_vector_ref(t5,C_fix(2));
t7=C_i_vector_ref(((C_word*)t0)[5],C_fix(2));
t8=C_eqp(t6,t7);
if(C_truep(t8)){
t9=C_i_vector_ref(t5,C_fix(1));
t10=C_i_vector_ref(((C_word*)t0)[5],C_fix(1));
t11=C_eqp(t9,t10);
if(C_truep(t11)){
t12=C_i_vector_length(t5);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22246,a[2]=t12,a[3]=t5,a[4]=((C_word*)t0)[5],a[5]=t14,a[6]=((C_word)li291),tmp=(C_word)a,a+=7,tmp));
t16=((C_word*)t14)[1];
f_22246(t16,t4,C_fix(3));}
else{
t12=t3;
f_23261(t12,C_SCHEME_TRUE);}}
else{
t9=t3;
f_23261(t9,C_SCHEME_TRUE);}}}

/* k23259 in lp in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23261(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,5)))){
C_save_and_reclaim_args((void *)trf_23261,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
/* irregex-core.scm:3097: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_23248(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}
else{
t2=C_i_caar(((C_word*)t0)[4]);
t3=C_i_vector_ref(t2,C_fix(0));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23275,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=t5,a[6]=((C_word*)t0)[2],a[7]=((C_word)li290),tmp=(C_word)a,a+=8,tmp));
t7=((C_word*)t5)[1];
f_23275(t7,((C_word*)t0)[3],t3,C_fix(0),C_SCHEME_END_OF_LIST);}}

/* lp2 in k23259 in lp in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23275(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,5)))){
C_save_and_reclaim_args((void *)trf_23275,5,t0,t1,t2,t3,t4);}
a=C_alloc(11);
t5=C_eqp(t3,((C_word*)t0)[2]);
if(C_truep(t5)){
t6=C_i_caar(((C_word*)t0)[3]);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_a_i_cons(&a,2,t6,t4);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=C_i_vector_ref(((C_word*)t0)[4],t3);
t7=C_i_vector_ref(t2,t3);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_23302,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[3],a[7]=t9,a[8]=((C_word)li289),tmp=(C_word)a,a+=9,tmp));
t11=((C_word*)t9)[1];
f_23302(t11,t1,t6,t7,t4);}}

/* lp3 in lp2 in k23259 in lp in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_23302(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_23302,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
if(C_truep(C_i_nullp(t3))){
/* irregex-core.scm:3107: lp2 */
t5=((C_word*)((C_word*)t0)[2])[1];
f_23275(t5,t1,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)),t4);}
else{
/* irregex-core.scm:3108: lp */
t5=((C_word*)((C_word*)t0)[5])[1];
f_23248(t5,t1,C_i_cdr(((C_word*)t0)[6]));}}
else{
if(C_truep(C_i_nullp(t3))){
/* irregex-core.scm:3109: lp */
t5=((C_word*)((C_word*)t0)[5])[1];
f_23248(t5,t1,C_i_cdr(((C_word*)t0)[6]));}
else{
t5=C_i_cdr(t2);
t6=C_i_cdr(t3);
t7=C_u_i_car(t2);
t8=C_u_i_car(t3);
t9=C_eqp(t7,t8);
if(C_truep(t9)){
/* irregex-core.scm:3110: lp3 */
t15=t1;
t16=t5;
t17=t6;
t18=t4;
t1=t15;
t2=t16;
t3=t17;
t4=t18;
goto loop;}
else{
t10=C_u_i_car(t2);
t11=C_u_i_car(t3);
t12=C_a_i_vector3(&a,3,((C_word*)t0)[4],t10,t11);
t13=C_a_i_cons(&a,2,t12,t4);
/* irregex-core.scm:3110: lp3 */
t15=t1;
t16=t5;
t17=t6;
t18=t13;
t1=t15;
t2=t16;
t3=t17;
t4=t18;
goto loop;}}}}

/* k23381 in lp in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23383(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23383,c,av);}
t2=((C_word*)t0)[2];
f_23261(t2,C_i_not(t1));}

/* k23397 in k22495 in lp2 in k22463 in lp in k22395 in k22392 in k22389 in k22386 in chicken.irregex#nfa->dfa in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_23399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23399,c,av);}
a=C_alloc(6);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=C_fixnum_times(t2,C_fix(4));
t4=C_fixnum_plus(t3,C_fix(2));
t5=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t6=C_i_vector_ref(((C_word*)t0)[3],t4);
t7=C_a_i_cons(&a,2,t5,t6);
t8=C_i_vector_set(((C_word*)t0)[3],t4,t7);
t9=((C_word*)t0)[4];
f_22500(t9,t1);}

/* k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,10)))){
C_save_and_reclaim((void *)f_23409,c,av);}
a=C_alloc(10);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_i_pairp(((C_word*)t0)[3]);
t4=(C_truep(t3)?C_u_i_car(((C_word*)t0)[3]):C_fix(0));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23418,a[2]=((C_word)li118),tmp=(C_word)a,a+=3,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23458,a[2]=t7,a[3]=((C_word*)t0)[2],a[4]=((C_word)li185),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_23458(t9,((C_word*)t0)[4],((C_word*)t0)[5],C_fix(1),t4,t5);}

/* a23417 in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23418(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23418,c,av);}
t10=C_slot(t8,C_fix(1));
t11=C_i_car(t3);
t12=C_i_vector_set(t10,C_fix(0),t11);
t13=C_slot(t8,C_fix(1));
t14=C_i_vector_set(t13,C_fix(1),C_u_i_cdr(t3));
t15=C_slot(t8,C_fix(1));
t16=C_i_vector_set(t15,C_fix(2),t4);
t17=C_slot(t8,C_fix(1));
t18=C_i_vector_set(t17,C_fix(3),t6);
t19=C_i_setslot(t8,C_fix(4),t9);
t20=t1;{
C_word *av2=av;
av2[0]=t20;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t20+1)))(2,av2);}}

/* lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_23458(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,10)))){
C_save_and_reclaim_args((void *)trf_23458,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(18);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23461,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t4,a[5]=t5,a[6]=((C_word)li119),tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_pairp(t2))){
if(C_truep(C_i_stringp(C_u_i_car(t2)))){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23484,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t8=C_u_i_car(t2);
t9=C_fixnum_and(t4,C_fix(2));
t10=C_eqp(C_fix(2),t9);
/* irregex-core.scm:3150: sre->cset */
f_26504(t7,t8,C_a_i_list(&a,1,t10));}
else{
t7=C_u_i_car(t2);
t8=C_eqp(t7,lf[179]);
t9=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_23500,a[2]=t1,a[3]=t5,a[4]=t4,a[5]=t2,a[6]=t7,a[7]=t6,a[8]=((C_word*)t0)[2],a[9]=t3,a[10]=((C_word*)t0)[3],tmp=(C_word)a,a+=11,tmp);
if(C_truep(t8)){
t10=t9;
f_23500(t10,t8);}
else{
t10=C_eqp(t7,lf[247]);
if(C_truep(t10)){
t11=t9;
f_23500(t11,t10);}
else{
t11=C_eqp(t7,lf[234]);
t12=t9;
f_23500(t12,(C_truep(t11)?t11:C_eqp(t7,lf[52])));}}}}
else{
if(C_truep(C_i_symbolp(t2))){
t7=C_eqp(t2,lf[124]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25293,a[2]=t5,a[3]=((C_word)li172),tmp=(C_word)a,a+=4,tmp);
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=C_eqp(t2,lf[125]);
if(C_truep(t8)){
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25351,a[2]=t5,a[3]=((C_word)li173),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_eqp(t2,lf[186]);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25443,a[2]=t5,a[3]=((C_word)li174),tmp=(C_word)a,a+=4,tmp);
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t10=C_eqp(t2,lf[195]);
if(C_truep(t10)){
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25473,a[2]=t5,a[3]=((C_word)li175),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t11=C_eqp(t2,lf[183]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25524,a[2]=t5,a[3]=((C_word)li176),tmp=(C_word)a,a+=4,tmp);
t13=t1;{
C_word av2[2];
av2[0]=t13;
av2[1]=t12;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t12=C_eqp(t2,lf[187]);
if(C_truep(t12)){
t13=t1;{
C_word av2[2];
av2[0]=t13;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25631,a[2]=t5,a[3]=((C_word)li177),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t13=C_eqp(t2,lf[196]);
if(C_truep(t13)){
t14=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25664,a[2]=t5,a[3]=((C_word)li178),tmp=(C_word)a,a+=4,tmp);
t15=t1;{
C_word av2[2];
av2[0]=t15;
av2[1]=t14;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t14=C_eqp(t2,lf[184]);
if(C_truep(t14)){
t15=t1;{
C_word av2[2];
av2[0]=t15;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25729,a[2]=t5,a[3]=((C_word)li179),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t15=C_eqp(t2,lf[185]);
if(C_truep(t15)){
t16=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25818,a[2]=t5,a[3]=((C_word)li180),tmp=(C_word)a,a+=4,tmp);
t17=t1;{
C_word av2[2];
av2[0]=t17;
av2[1]=t16;
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}
else{
t16=C_eqp(t2,lf[110]);
if(C_truep(t16)){
t17=t1;{
C_word av2[2];
av2[0]=t17;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}
else{
t17=C_i_assq(t2,lf[248]);
if(C_truep(t17)){
/* irregex-core.scm:3591: rec */
t18=t6;
f_23461(t18,t1,C_i_cdr(t17));}
else{
/* irregex-core.scm:3592: chicken.base#error */
t18=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t18;
av2[1]=t1;
av2[2]=lf[249];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t18+1)))(4,av2);}}}}}}}}}}}}}
else{
if(C_truep(C_charp(t2))){
t7=C_fixnum_and(t4,C_fix(2));
t8=C_eqp(C_fix(2),t7);
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=(C_truep(t8)?(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25940,a[2]=t5,a[3]=t2,a[4]=((C_word)li182),tmp=(C_word)a,a+=5,tmp):(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26039,a[2]=t2,a[3]=t5,a[4]=((C_word)li184),tmp=(C_word)a,a+=5,tmp));
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
if(C_truep(C_i_stringp(t2))){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26154,a[2]=t6,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* ##sys#string->list */
t8=*((C_word*)lf[105]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
/* irregex-core.scm:3645: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[251];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}}}}

/* rec in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_23461(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_23461,3,t0,t1,t2);}
/* irregex-core.scm:3145: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_23458(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k23482 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23484(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_23484,c,av);}
/* irregex-core.scm:3149: sre-cset->procedure */
f_26180(((C_word*)t0)[2],t1,((C_word*)t0)[3]);}

/* k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_23500(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(39,0,10)))){
C_save_and_reclaim_args((void *)trf_23500,2,t0,t1);}
a=C_alloc(39);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23507,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_fixnum_and(((C_word*)t0)[4],C_fix(2));
t4=C_eqp(C_fix(2),t3);
/* irregex-core.scm:3155: sre->cset */
f_26504(t2,((C_word*)t0)[5],C_a_i_list(&a,1,t4));}
else{
t2=C_eqp(((C_word*)t0)[6],lf[103]);
if(C_truep(t2)){
t3=C_i_length(C_u_i_cdr(((C_word*)t0)[5]));
switch(t3){
case C_fix(0):
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23527,a[2]=((C_word)li120),tmp=(C_word)a,a+=3,tmp);
t5=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}
case C_fix(1):
/* irregex-core.scm:3160: rec */
t4=((C_word*)t0)[7];
f_23461(t4,((C_word*)t0)[2],C_i_cadr(((C_word*)t0)[5]));
default:
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23547,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3162: rec */
t5=((C_word*)t0)[7];
f_23461(t5,t4,C_i_cadr(((C_word*)t0)[5]));}}
else{
t3=C_eqp(((C_word*)t0)[6],lf[225]);
if(C_truep(t3)){
t4=(
/* irregex-core.scm:3172: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
t5=C_fixnum_not(C_fix(2));
/* irregex-core.scm:3172: lp */
t6=((C_word*)((C_word*)t0)[8])[1];
f_23458(t6,((C_word*)t0)[2],t4,((C_word*)t0)[9],C_fixnum_and(((C_word*)t0)[4],t5),((C_word*)t0)[3]);}
else{
t4=C_eqp(((C_word*)t0)[6],lf[226]);
if(C_truep(t4)){
t5=(
/* irregex-core.scm:3177: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
/* irregex-core.scm:3177: lp */
t6=((C_word*)((C_word*)t0)[8])[1];
f_23458(t6,((C_word*)t0)[2],t5,((C_word*)t0)[9],C_fixnum_or(((C_word*)t0)[4],C_fix(2)),((C_word*)t0)[3]);}
else{
t5=C_eqp(((C_word*)t0)[6],lf[156]);
if(C_truep(t5)){
t6=(
/* irregex-core.scm:3182: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
/* irregex-core.scm:3182: lp */
t7=((C_word*)((C_word*)t0)[8])[1];
f_23458(t7,((C_word*)t0)[2],t6,((C_word*)t0)[9],C_fixnum_or(((C_word*)t0)[4],C_fix(32)),((C_word*)t0)[3]);}
else{
t6=C_eqp(((C_word*)t0)[6],lf[157]);
if(C_truep(t6)){
t7=(
/* irregex-core.scm:3184: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
t8=C_fixnum_not(C_fix(32));
/* irregex-core.scm:3184: lp */
t9=((C_word*)((C_word*)t0)[8])[1];
f_23458(t9,((C_word*)t0)[2],t7,((C_word*)t0)[9],C_fixnum_and(((C_word*)t0)[4],t8),((C_word*)t0)[3]);}
else{
t7=C_eqp(((C_word*)t0)[6],lf[115]);
t8=(C_truep(t7)?t7:C_eqp(((C_word*)t0)[6],lf[227]));
if(C_truep(t8)){
t9=C_i_length(C_u_i_cdr(((C_word*)t0)[5]));
switch(t9){
case C_fix(0):
t10=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t10;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}
case C_fix(1):
/* irregex-core.scm:3188: rec */
t10=((C_word*)t0)[7];
f_23461(t10,((C_word*)t0)[2],C_i_cadr(((C_word*)t0)[5]));
default:
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23701,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
t11=(
/* irregex-core.scm:3190: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cddr(((C_word*)t0)[5]))
);
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23720,a[2]=((C_word*)t0)[8],a[3]=t10,a[4]=t11,a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3191: sre-count-submatches */
f_16994(t12,C_i_cadr(((C_word*)t0)[5]));}}
else{
t9=C_eqp(((C_word*)t0)[6],lf[131]);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23743,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t11=(
/* irregex-core.scm:3196: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
/* irregex-core.scm:3196: rec */
t12=((C_word*)t0)[7];
f_23461(t12,t10,t11);}
else{
t10=C_eqp(((C_word*)t0)[6],lf[132]);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23769,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t12=(
/* irregex-core.scm:3201: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
/* irregex-core.scm:3201: rec */
t13=((C_word*)t0)[7];
f_23461(t13,t11,t12);}
else{
t11=C_eqp(((C_word*)t0)[6],lf[127]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23798,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
t13=(
/* irregex-core.scm:3207: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
/* irregex-core.scm:3207: sre-empty? */
t14=lf[139];{
C_word av2[3];
av2[0]=t14;
av2[1]=t12;
av2[2]=t13;
f_16319(3,av2);}}
else{
t12=C_eqp(((C_word*)t0)[6],lf[128]);
if(C_truep(t12)){
t13=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23843,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
t14=(
/* irregex-core.scm:3217: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
/* irregex-core.scm:3217: sre-empty? */
t15=lf[139];{
C_word av2[3];
av2[0]=t15;
av2[1]=t13;
av2[2]=t14;
f_16319(3,av2);}}
else{
t13=C_eqp(((C_word*)t0)[6],lf[129]);
if(C_truep(t13)){
t14=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23897,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
t15=(
/* irregex-core.scm:3236: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
/* irregex-core.scm:3236: sre-empty? */
t16=lf[139];{
C_word av2[3];
av2[0]=t16;
av2[1]=t14;
av2[2]=t15;
f_16319(3,av2);}}
else{
t14=C_eqp(((C_word*)t0)[6],lf[134]);
if(C_truep(t14)){
t15=C_i_cadr(((C_word*)t0)[5]);
t16=C_u_i_cdr(((C_word*)t0)[5]);
t17=C_u_i_car(t16);
t18=C_u_i_cdr(((C_word*)t0)[5]);
t19=C_u_i_cdr(t18);
t20=C_a_i_cons(&a,2,t17,t19);
t21=C_a_i_cons(&a,2,t15,t20);
t22=C_a_i_cons(&a,2,lf[133],t21);
/* irregex-core.scm:3251: rec */
t23=((C_word*)t0)[7];
f_23461(t23,((C_word*)t0)[2],t22);}
else{
t15=C_eqp(((C_word*)t0)[6],lf[135]);
if(C_truep(t15)){
t16=C_i_cadr(((C_word*)t0)[5]);
t17=C_u_i_cdr(((C_word*)t0)[5]);
t18=C_u_i_cdr(t17);
t19=C_a_i_cons(&a,2,C_SCHEME_FALSE,t18);
t20=C_a_i_cons(&a,2,t16,t19);
t21=C_a_i_cons(&a,2,lf[133],t20);
/* irregex-core.scm:3253: rec */
t22=((C_word*)t0)[7];
f_23461(t22,((C_word*)t0)[2],t21);}
else{
t16=C_eqp(((C_word*)t0)[6],lf[133]);
if(C_truep(t16)){
t17=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23999,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
t18=C_i_cadr(((C_word*)t0)[5]);
if(C_truep(C_i_numberp(t18))){
t19=C_i_caddr(((C_word*)t0)[5]);
if(C_truep(C_i_numberp(t19))){
t20=C_u_i_cdr(((C_word*)t0)[5]);
t21=C_u_i_car(t20);
t22=C_u_i_cdr(((C_word*)t0)[5]);
t23=C_u_i_cdr(t22);
t24=t17;
f_23999(t24,C_fixnum_greaterp(t21,C_u_i_car(t23)));}
else{
t20=t17;
f_23999(t20,C_SCHEME_FALSE);}}
else{
t19=t17;
f_23999(t19,C_SCHEME_FALSE);}}
else{
t17=C_eqp(((C_word*)t0)[6],lf[130]);
if(C_truep(t17)){
t18=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24151,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
t19=C_i_cadr(((C_word*)t0)[5]);
if(C_truep(C_i_numberp(t19))){
t20=C_i_caddr(((C_word*)t0)[5]);
if(C_truep(C_i_numberp(t20))){
t21=C_u_i_cdr(((C_word*)t0)[5]);
t22=C_u_i_car(t21);
t23=C_u_i_cdr(((C_word*)t0)[5]);
t24=C_u_i_cdr(t23);
t25=t18;
f_24151(t25,C_fixnum_greaterp(t22,C_u_i_car(t24)));}
else{
t21=t18;
f_24151(t21,C_SCHEME_FALSE);}}
else{
t20=t18;
f_24151(t20,C_SCHEME_FALSE);}}
else{
t18=C_eqp(((C_word*)t0)[6],lf[231]);
if(C_truep(t18)){
t19=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24322,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t20=C_u_i_cdr(((C_word*)t0)[5]);
t21=C_a_i_list(&a,1,lf[184]);
/* irregex-core.scm:3324: ##sys#append */
t22=*((C_word*)lf[118]+1);{
C_word av2[4];
av2[0]=t22;
av2[1]=t19;
av2[2]=t20;
av2[3]=t21;
((C_proc)(void*)(*((C_word*)t22+1)))(4,av2);}}
else{
t19=C_eqp(((C_word*)t0)[6],lf[232]);
if(C_truep(t19)){
t20=C_a_i_list(&a,3,lf[103],lf[181],lf[233]);
t21=C_u_i_cdr(((C_word*)t0)[5]);
t22=C_a_i_cons(&a,2,lf[103],t21);
t23=C_a_i_list(&a,3,lf[234],t20,t22);
t24=C_a_i_list(&a,2,lf[129],t23);
t25=C_a_i_list(&a,4,lf[115],lf[183],t24,lf[184]);
/* irregex-core.scm:3326: rec */
t26=((C_word*)t0)[7];
f_23461(t26,((C_word*)t0)[2],t25);}
else{
t20=C_eqp(((C_word*)t0)[6],lf[235]);
if(C_truep(t20)){
t21=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24372,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3329: string->sre */
t22=*((C_word*)lf[102]+1);{
C_word av2[3];
av2[0]=t22;
av2[1]=t21;
av2[2]=C_i_cadr(((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t22+1)))(3,av2);}}
else{
t21=C_eqp(((C_word*)t0)[6],lf[111]);
if(C_truep(t21)){
t22=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24385,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t23=(
/* irregex-core.scm:3332: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
t24=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24408,a[2]=((C_word)li149),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3332: lp */
t25=((C_word*)((C_word*)t0)[8])[1];
f_23458(t25,t22,t23,((C_word*)t0)[9],((C_word*)t0)[4],t24);}
else{
t22=C_eqp(((C_word*)t0)[6],lf[112]);
if(C_truep(t22)){
t23=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24420,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t24=(
/* irregex-core.scm:3342: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
t25=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24443,a[2]=((C_word)li152),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3342: lp */
t26=((C_word*)((C_word*)t0)[8])[1];
f_23458(t26,t23,t24,((C_word*)t0)[9],((C_word*)t0)[4],t25);}
else{
t23=C_eqp(((C_word*)t0)[6],lf[113]);
t24=(C_truep(t23)?t23:C_eqp(((C_word*)t0)[6],lf[114]));
if(C_truep(t24)){
t25=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24458,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t26=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24530,a[2]=((C_word*)t0)[8],a[3]=t25,a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3353: scheme#append */
t27=*((C_word*)lf[73]+1);{
C_word av2[4];
av2[0]=t27;
av2[1]=t26;
av2[2]=C_u_i_cdr(((C_word*)t0)[5]);
av2[3]=lf[238];
((C_proc)(void*)(*((C_word*)t27+1)))(4,av2);}}
else{
t25=C_eqp(((C_word*)t0)[6],lf[239]);
if(C_truep(t25)){
t26=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24541,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t27=(
/* irregex-core.scm:3369: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
t28=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24564,a[2]=((C_word)li161),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3369: lp */
t29=((C_word*)((C_word*)t0)[8])[1];
f_23458(t29,t26,t27,((C_word*)t0)[9],((C_word*)t0)[4],t28);}
else{
t26=C_eqp(((C_word*)t0)[6],lf[109]);
if(C_truep(t26)){
t27=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_24576,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3379: sre-count-submatches */
f_16994(t27,C_i_cadr(((C_word*)t0)[5]));}
else{
t27=C_eqp(((C_word*)t0)[6],lf[192]);
t28=(C_truep(t27)?t27:C_eqp(((C_word*)t0)[6],lf[191]));
if(C_truep(t28)){
t29=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24732,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t30=C_i_cadr(((C_word*)t0)[5]);
if(C_truep(C_i_numberp(t30))){
t31=t29;{
C_word av2[2];
av2[0]=t31;
av2[1]=C_u_i_car(C_u_i_cdr(((C_word*)t0)[5]));
f_24732(2,av2);}}
else{
t31=C_u_i_cdr(((C_word*)t0)[5]);
t32=C_i_assq(C_u_i_car(t31),((C_word*)((C_word*)t0)[10])[1]);
if(C_truep(t32)){
t33=t29;{
C_word av2[2];
av2[0]=t33;
av2[1]=C_i_cdr(t32);
f_24732(2,av2);}}
else{
t33=C_u_i_cdr(((C_word*)t0)[5]);
/* irregex-core.scm:3411: chicken.base#error */
t34=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t34;
av2[1]=t29;
av2[2]=lf[243];
av2[3]=C_u_i_car(t33);
((C_proc)(void*)(*((C_word*)t34+1)))(4,av2);}}}}
else{
t29=C_eqp(((C_word*)t0)[6],lf[244]);
if(C_truep(t29)){
t30=(
/* irregex-core.scm:3451: sre-sequence */
  f_18203(C_a_i(&a,3),C_i_cdddr(((C_word*)t0)[5]))
);
t31=C_i_cadr(((C_word*)t0)[5]);
/* irregex-core.scm:3451: lp */
t32=((C_word*)((C_word*)t0)[8])[1];
f_23458(t32,((C_word*)t0)[2],t30,C_fixnum_plus(((C_word*)t0)[9],t31),((C_word*)t0)[4],((C_word*)t0)[3]);}
else{
t30=C_eqp(((C_word*)t0)[6],lf[245]);
t31=(C_truep(t30)?t30:C_eqp(((C_word*)t0)[6],lf[108]));
if(C_truep(t31)){
t32=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24949,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t33=(
/* irregex-core.scm:3454: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[5]))
);
t34=C_fixnum_plus(((C_word*)t0)[9],C_fix(1));
t35=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25058,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[3],a[4]=((C_word)li171),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3454: lp */
t36=((C_word*)((C_word*)t0)[8])[1];
f_23458(t36,t32,t33,t34,((C_word*)t0)[4],t35);}
else{
t32=C_eqp(((C_word*)t0)[6],lf[119]);
t33=(C_truep(t32)?t32:C_eqp(((C_word*)t0)[6],lf[120]));
if(C_truep(t33)){
t34=C_i_cddr(((C_word*)t0)[5]);
t35=C_a_i_cons(&a,2,lf[108],t34);
/* irregex-core.scm:3484: rec */
t36=((C_word*)t0)[7];
f_23461(t36,((C_word*)t0)[2],t35);}
else{
/* irregex-core.scm:3486: chicken.base#error */
t34=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t34;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[246];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t34+1)))(4,av2);}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}

/* k23505 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23507(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_23507,c,av);}
/* irregex-core.scm:3154: sre-cset->procedure */
f_26180(((C_word*)t0)[2],t1,((C_word*)t0)[3]);}

/* f_23527 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23527(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23527,c,av);}
/* irregex-core.scm:3159: fail */
t10=t9;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* k23545 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23547(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_23547,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23550,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(
/* irregex-core.scm:3163: sre-alternate */
  f_18226(C_a_i(&a,3),C_i_cddr(((C_word*)t0)[3]))
);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23573,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3164: sre-count-submatches */
f_16994(t4,C_i_cadr(((C_word*)t0)[3]));}

/* k23548 in k23545 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23550(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_23550,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23551,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word)li122),tmp=(C_word)a,a+=5,tmp);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_23551 in k23548 in k23545 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_23551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_23551,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23557,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li121),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3168: first */
t11=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a23556 */
static void C_ccall f_23557(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23557,c,av);}
/* irregex-core.scm:3170: rest */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k23571 in k23545 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_23573,c,av);}
/* irregex-core.scm:3163: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_23458(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_fixnum_plus(((C_word*)t0)[5],t1),((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k23699 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_23701,c,av);}
/* irregex-core.scm:3194: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_23458(t2,((C_word*)t0)[3],C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],t1);}

/* k23718 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_23720,c,av);}
/* irregex-core.scm:3190: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_23458(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_fixnum_plus(((C_word*)t0)[5],t1),((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k23741 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23743(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_23743,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23744,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word)li124),tmp=(C_word)a,a+=5,tmp);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_23744 in k23741 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23744(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_23744,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23750,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li123),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3198: body */
t11=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a23749 */
static void C_ccall f_23750(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23750,c,av);}
/* irregex-core.scm:3199: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k23767 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_23769,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23770,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word)li126),tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_23770 in k23767 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23770(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_23770,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23776,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li125),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3203: next */
t11=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a23775 */
static void C_ccall f_23776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23776,c,av);}
/* irregex-core.scm:3204: body */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k23796 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_23798,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
/* irregex-core.scm:3208: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[228];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23804,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(
/* irregex-core.scm:3210: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[3]))
);
t4=C_a_i_list2(&a,2,lf[129],t3);
/* irregex-core.scm:3210: rec */
t5=((C_word*)t0)[5];
f_23461(t5,t2,t4);}}

/* k23802 in k23796 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_23804,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23805,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li128),tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_23805 in k23802 in k23796 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_23805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_23805,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23811,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li127),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3212: body */
t11=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a23810 */
static void C_ccall f_23811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23811,c,av);}
/* irregex-core.scm:3214: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k23841 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,10)))){
C_save_and_reclaim((void *)f_23843,c,av);}
a=C_alloc(15);
if(C_truep(t1)){
/* irregex-core.scm:3218: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[229];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23849,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=(
/* irregex-core.scm:3222: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[3]))
);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23867,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=((C_word)li132),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3222: lp */
t7=((C_word*)((C_word*)t0)[5])[1];
f_23458(t7,t4,t5,((C_word*)t0)[6],((C_word*)t0)[7],t6);}}

/* k23847 in k23841 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_23849,c,av);}
a=C_alloc(5);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23851,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word)li130),tmp=(C_word)a,a+=5,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_23851 in k23847 in k23841 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_23851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_23851,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23857,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li129),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3231: next */
t11=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a23856 */
static void C_ccall f_23857(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23857,c,av);}
/* irregex-core.scm:3233: body */
t2=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* a23866 in k23841 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23867(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_23867,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23873,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li131),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3226: next */
t11=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a23872 in a23866 in k23841 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_23873(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23873,c,av);}
/* irregex-core.scm:3228: body */
t2=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k23895 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_23897(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,10)))){
C_save_and_reclaim((void *)f_23897,c,av);}
a=C_alloc(14);
if(C_truep(t1)){
/* irregex-core.scm:3237: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[230];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23903,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t5=(
/* irregex-core.scm:3241: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(((C_word*)t0)[3]))
);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23910,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=((C_word)li134),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3241: lp */
t7=((C_word*)((C_word*)t0)[5])[1];
f_23458(t7,t4,t5,((C_word*)t0)[6],((C_word*)t0)[7],t6);}}

/* k23901 in k23895 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23903(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23903,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)((C_word*)t0)[2])[1];
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a23909 in k23895 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_23910(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_23910,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23916,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li133),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3245: body */
t11=((C_word*)((C_word*)t0)[3])[1];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a23915 in a23909 in k23895 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_23916(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23916,c,av);}
/* irregex-core.scm:3247: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_23999(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_23999,2,t0,t1);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24002,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t1)){
t3=t2;
f_24002(t3,t1);}
else{
t3=C_u_i_cdr(((C_word*)t0)[3]);
t4=C_i_not(C_u_i_car(t3));
t5=t2;
f_24002(t5,(C_truep(t4)?C_i_caddr(((C_word*)t0)[3]):C_SCHEME_FALSE));}}

/* k24000 in k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_fcall f_24002(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(28,0,10)))){
C_save_and_reclaim_args((void *)trf_24002,2,t0,t1);}
a=C_alloc(28);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24003,a[2]=((C_word)li135),tmp=(C_word)a,a+=3,tmp);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_u_i_cdr(((C_word*)t0)[3]);
t11=C_u_i_car(t10);
t12=C_i_caddr(((C_word*)t0)[3]);
t13=C_u_i_cdr(((C_word*)t0)[3]);
t14=C_u_i_cdr(t13);
t15=(
/* irregex-core.scm:3265: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t14))
);
t16=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24016,a[2]=t5,a[3]=((C_word*)t0)[4],a[4]=t3,a[5]=t9,a[6]=((C_word*)t0)[5],a[7]=t7,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word)li138),tmp=(C_word)a,a+=11,tmp);
t17=C_set_block_item(t3,0,t11);
t18=C_set_block_item(t5,0,t12);
t19=C_set_block_item(t7,0,t15);
t20=C_set_block_item(t9,0,t16);
t21=(C_truep(C_i_zerop(((C_word*)t3)[1]))?(C_truep(((C_word*)t5)[1])?C_i_zerop(((C_word*)t5)[1]):C_SCHEME_FALSE):C_SCHEME_FALSE);
if(C_truep(t21)){
t22=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t22;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t22+1)))(2,av2);}}
else{
t22=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24071,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=t9,a[5]=((C_word)li140),tmp=(C_word)a,a+=6,tmp);
t23=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t23;
av2[1]=t22;
((C_proc)(void*)(*((C_word*)t23+1)))(2,av2);}}}}

/* f_24003 in k24000 in k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24003(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24003,c,av);}
/* irregex-core.scm:3260: fail */
t10=t9;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* body4587 in k24000 in k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24016(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,10)))){
C_save_and_reclaim((void *)f_24016,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24022,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word)li137),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3268: lp */
t4=((C_word*)((C_word*)t0)[6])[1];
f_23458(t4,t1,((C_word*)((C_word*)t0)[7])[1],((C_word*)t0)[8],((C_word*)t0)[9],t3);}

/* a24021 in body4587 in k24000 in k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in ... */
static void C_ccall f_24022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,9)))){
C_save_and_reclaim((void *)f_24022,c,av);}
a=C_alloc(14);
t10=(C_truep(((C_word*)((C_word*)t0)[2])[1])?C_eqp(((C_word*)t0)[3],((C_word*)((C_word*)t0)[2])[1]):C_SCHEME_FALSE);
if(C_truep(t10)){
/* irregex-core.scm:3273: next */
t11=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t9;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}
else{
t11=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_24035,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=t3,a[7]=t4,a[8]=t5,a[9]=t6,a[10]=t7,a[11]=t8,a[12]=t9,a[13]=t1,tmp=(C_word)a,a+=14,tmp);
/* irregex-core.scm:3274: body */
t12=((C_word*)((C_word*)t0)[6])[1];{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=C_fixnum_plus(C_fix(1),((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}}

/* k24033 in a24021 in body4587 in k24000 in k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in ... */
static void C_ccall f_24035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,9)))){
C_save_and_reclaim((void *)f_24035,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_24040,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word)li136),tmp=(C_word)a,a+=14,tmp);
/* irregex-core.scm:3272: g4606 */
t3=t1;{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[13];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=((C_word*)t0)[9];
av2[7]=((C_word*)t0)[10];
av2[8]=((C_word*)t0)[11];
av2[9]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(10,av2);}}

/* a24039 in k24033 in a24021 in body4587 in k24000 in k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in ... */
static void C_ccall f_24040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24040,c,av);}
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]))){
/* irregex-core.scm:3278: next */
t2=((C_word*)t0)[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=((C_word*)t0)[9];
av2[7]=((C_word*)t0)[10];
av2[8]=((C_word*)t0)[11];
av2[9]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3279: fail */
t2=((C_word*)t0)[12];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* f_24071 in k24000 in k23997 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24071(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_24071,c,av);}
a=C_alloc(13);
t10=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_24075,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,a[12]=t1,tmp=(C_word)a,a+=13,tmp);
/* irregex-core.scm:3283: body */
t11=((C_word*)((C_word*)t0)[4])[1];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
av2[2]=C_fix(1);
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}

/* k24073 */
static void C_ccall f_24075(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,9)))){
C_save_and_reclaim((void *)f_24075,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_24080,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word)li139),tmp=(C_word)a,a+=13,tmp);
/* irregex-core.scm:3282: g4618 */
t3=t1;{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[12];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(10,av2);}}

/* a24079 in k24073 */
static void C_ccall f_24080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24080,c,av);}
if(C_truep(C_i_zerop(((C_word*)((C_word*)t0)[2])[1]))){
/* irregex-core.scm:3286: next */
t2=((C_word*)t0)[3];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3287: fail */
t2=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_fcall f_24151(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_24151,2,t0,t1);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24154,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t1)){
t3=t2;
f_24154(t3,t1);}
else{
t3=C_u_i_cdr(((C_word*)t0)[3]);
t4=C_i_not(C_u_i_car(t3));
t5=t2;
f_24154(t5,(C_truep(t4)?C_i_caddr(((C_word*)t0)[3]):C_SCHEME_FALSE));}}

/* k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_fcall f_24154(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(28,0,10)))){
C_save_and_reclaim_args((void *)trf_24154,2,t0,t1);}
a=C_alloc(28);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24155,a[2]=((C_word)li141),tmp=(C_word)a,a+=3,tmp);
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_u_i_cdr(((C_word*)t0)[3]);
t11=C_u_i_car(t10);
t12=C_i_caddr(((C_word*)t0)[3]);
t13=C_u_i_cdr(((C_word*)t0)[3]);
t14=C_u_i_cdr(t13);
t15=(
/* irregex-core.scm:3299: sre-sequence */
  f_18203(C_a_i(&a,3),C_u_i_cdr(t14))
);
t16=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24168,a[2]=t3,a[3]=t9,a[4]=t5,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t7,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word)li144),tmp=(C_word)a,a+=11,tmp);
t17=C_set_block_item(t3,0,t11);
t18=C_set_block_item(t5,0,t12);
t19=C_set_block_item(t7,0,t15);
t20=C_set_block_item(t9,0,t16);
t21=(C_truep(C_i_zerop(((C_word*)t3)[1]))?(C_truep(((C_word*)t5)[1])?C_i_zerop(((C_word*)t5)[1]):C_SCHEME_FALSE):C_SCHEME_FALSE);
t22=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t22;
av2[1]=(C_truep(t21)?((C_word*)t0)[4]:(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24230,a[2]=t3,a[3]=t9,a[4]=((C_word*)t0)[4],a[5]=((C_word)li146),tmp=(C_word)a,a+=6,tmp));
((C_proc)(void*)(*((C_word*)t22+1)))(2,av2);}}}

/* f_24155 in k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24155,c,av);}
/* irregex-core.scm:3294: fail */
t10=t9;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* body4645 in k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24168(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,10)))){
C_save_and_reclaim((void *)f_24168,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24174,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word)li143),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3302: lp */
t4=((C_word*)((C_word*)t0)[6])[1];
f_23458(t4,t1,((C_word*)((C_word*)t0)[7])[1],((C_word*)t0)[8],((C_word*)t0)[9],t3);}

/* a24173 in body4645 in k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in ... */
static void C_ccall f_24174(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,9)))){
C_save_and_reclaim((void *)f_24174,c,av);}
a=C_alloc(14);
if(C_truep(C_fixnum_lessp(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]))){
t10=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24184,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3307: body */
t11=((C_word*)((C_word*)t0)[4])[1];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
av2[2]=C_fixnum_plus(C_fix(1),((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_24196,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=t9,a[5]=t2,a[6]=t3,a[7]=t4,a[8]=t5,a[9]=t6,a[10]=t7,a[11]=t8,a[12]=((C_word*)t0)[4],a[13]=((C_word)li142),tmp=(C_word)a,a+=14,tmp);
/* irregex-core.scm:3309: next */
t11=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}}

/* k24182 in a24173 in body4645 in k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in ... */
static void C_ccall f_24184(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24184,c,av);}
/* irregex-core.scm:3306: g4663 */
t2=t1;{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* a24195 in a24173 in body4645 in k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in ... */
static void C_ccall f_24196(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_24196,c,av);}
a=C_alloc(11);
t2=(C_truep(((C_word*)((C_word*)t0)[2])[1])?C_eqp(((C_word*)t0)[3],((C_word*)((C_word*)t0)[2])[1]):C_SCHEME_FALSE);
if(C_truep(t2)){
/* irregex-core.scm:3312: fail */
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24209,a[2]=t1,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[4],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3313: body */
t4=((C_word*)((C_word*)t0)[12])[1];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_fixnum_plus(C_fix(1),((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k24207 in a24195 in a24173 in body4645 in k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in ... */
static void C_ccall f_24209(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24209,c,av);}
/* irregex-core.scm:3311: g4666 */
t2=t1;{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* f_24230 in k24152 in k24149 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24230(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_24230,c,av);}
a=C_alloc(12);
if(C_truep(C_i_zerop(((C_word*)((C_word*)t0)[2])[1]))){
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_24240,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t5,a[6]=t6,a[7]=t7,a[8]=t8,a[9]=t9,a[10]=((C_word*)t0)[3],a[11]=((C_word)li145),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3319: next */
t11=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24250,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3322: body */
t11=((C_word*)((C_word*)t0)[3])[1];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
av2[2]=C_fix(1);
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}}

/* a24239 */
static void C_ccall f_24240(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_24240,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24244,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3321: body */
t3=((C_word*)((C_word*)t0)[10])[1];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_fix(1);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k24242 in a24239 */
static void C_ccall f_24244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24244,c,av);}
/* irregex-core.scm:3320: g4678 */
t2=t1;{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k24248 */
static void C_ccall f_24250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24250,c,av);}
/* irregex-core.scm:3318: g4680 */
t2=t1;{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k24320 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_24322,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[183],t1);
t3=C_a_i_cons(&a,2,lf[115],t2);
/* irregex-core.scm:3324: rec */
t4=((C_word*)t0)[2];
f_23461(t4,((C_word*)t0)[3],t3);}

/* k24370 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24372(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24372,c,av);}
/* irregex-core.scm:3329: rec */
t2=((C_word*)t0)[2];
f_23461(t2,((C_word*)t0)[3],t1);}

/* k24383 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24385(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_24385,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24386,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word)li148),tmp=(C_word)a,a+=5,tmp);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_24386 in k24383 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_24386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,9)))){
C_save_and_reclaim((void *)f_24386,c,av);}
a=C_alloc(15);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_24393,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24401,a[2]=((C_word)li147),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3337: check */
t12=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t12;
av2[1]=t10;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(10,av2);}}

/* k24391 */
static void C_ccall f_24393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24393,c,av);}
if(C_truep(t1)){
/* irregex-core.scm:3338: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3339: fail */
t2=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a24400 */
static void C_ccall f_24401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24401,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a24407 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24408(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24408,c,av);}
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* k24418 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24420(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_24420,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24421,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li151),tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_24421 in k24418 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_24421(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,9)))){
C_save_and_reclaim((void *)f_24421,c,av);}
a=C_alloc(15);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_24428,a[2]=t9,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=t3,a[7]=t4,a[8]=t5,a[9]=t6,a[10]=t7,a[11]=t8,tmp=(C_word)a,a+=12,tmp);
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24436,a[2]=((C_word)li150),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3347: check */
t12=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t12;
av2[1]=t10;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(10,av2);}}

/* k24426 */
static void C_ccall f_24428(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24428,c,av);}
if(C_truep(t1)){
/* irregex-core.scm:3348: fail */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* irregex-core.scm:3349: next */
t2=((C_word*)t0)[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=((C_word*)t0)[9];
av2[7]=((C_word*)t0)[10];
av2[8]=((C_word*)t0)[11];
av2[9]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}}

/* a24435 */
static void C_ccall f_24436(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24436,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a24442 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24443,c,av);}
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* k24456 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24458(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,10)))){
C_save_and_reclaim((void *)f_24458,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24459,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=((C_word)li157),tmp=(C_word)a,a+=6,tmp);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_24459 in k24456 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_24459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,7)))){
C_save_and_reclaim((void *)f_24459,c,av);}
a=C_alloc(25);
t10=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_24463,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t2,a[7]=t4,a[8]=t5,a[9]=t6,a[10]=t7,a[11]=t8,a[12]=t9,a[13]=((C_word*)t0)[4],tmp=(C_word)a,a+=14,tmp);
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8742,a[2]=t4,a[3]=t2,a[4]=((C_word)li155),tmp=(C_word)a,a+=5,tmp);
t12=C_i_vector_ref(t2,C_fix(1));
t13=C_i_vector_ref(t2,C_fix(2));
t14=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8769,a[2]=t4,a[3]=t6,a[4]=t2,a[5]=((C_word)li156),tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:400: make-irregex-chunker */
t15=*((C_word*)lf[45]+1);{
C_word *av2=av;
av2[0]=t15;
av2[1]=t10;
av2[2]=t11;
av2[3]=t12;
av2[4]=t13;
av2[5]=t14;
av2[6]=C_i_vector_ref(t2,C_fix(4));
av2[7]=C_i_vector_ref(t2,C_fix(5));
((C_proc)(void*)(*((C_word*)t15+1)))(8,av2);}}

/* k24461 */
static void C_ccall f_24463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_24463,c,av);}
a=C_alloc(15);
t2=C_i_vector_ref(t1,C_fix(1));
t3=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_24469,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
/* irregex-core.scm:3358: g4748 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k24467 in k24461 */
static void C_ccall f_24469(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_24469,c,av);}
a=C_alloc(17);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_vector_ref(((C_word*)t0)[3],C_fix(3));
t4=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_24476,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[3],a[15]=t1,a[16]=t2,tmp=(C_word)a,a+=17,tmp);
/* irregex-core.scm:3358: g4752 */
t5=t3;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_u_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k24474 in k24467 in k24461 */
static void C_ccall f_24476(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,9)))){
C_save_and_reclaim((void *)f_24476,c,av);}
a=C_alloc(22);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_eqp(t2,lf[113]);
t4=(C_truep(t3)?(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24504,a[2]=((C_word)li153),tmp=(C_word)a,a+=3,tmp):*((C_word*)lf[236]+1));
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_24485,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24495,a[2]=t4,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=C_u_i_car(((C_word*)t0)[6]);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24499,a[2]=((C_word)li154),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3363: check */
t9=((C_word*)t0)[13];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t9;
av2[1]=t6;
av2[2]=((C_word*)t0)[14];
av2[3]=((C_word*)t0)[6];
av2[4]=t7;
av2[5]=((C_word*)t0)[15];
av2[6]=((C_word*)t0)[16];
av2[7]=t1;
av2[8]=((C_word*)t0)[11];
av2[9]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(10,av2);}}

/* k24483 in k24474 in k24467 in k24461 */
static void C_ccall f_24485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24485,c,av);}
if(C_truep(t1)){
/* irregex-core.scm:3365: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3366: fail */
t2=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k24493 in k24474 in k24467 in k24461 */
static void C_ccall f_24495(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24495,c,av);}
/* irregex-core.scm:3362: g4754 */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a24498 in k24474 in k24467 in k24461 */
static void C_ccall f_24499(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24499,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_24504 in k24474 in k24467 in k24461 */
static void C_ccall f_24504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24504,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a24520 in k24528 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_24521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24521,c,av);}
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* k24528 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24530(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,10)))){
C_save_and_reclaim((void *)f_24530,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,lf[237],t1);
t3=(
/* irregex-core.scm:3352: sre-sequence */
  f_18203(C_a_i(&a,3),t2)
);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24521,a[2]=((C_word)li158),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3352: lp */
t5=((C_word*)((C_word*)t0)[2])[1];
f_23458(t5,((C_word*)t0)[3],t3,((C_word*)t0)[4],((C_word*)t0)[5],t4);}

/* k24539 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24541(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_24541,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24542,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li160),tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_24542 in k24539 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_24542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,9)))){
C_save_and_reclaim((void *)f_24542,c,av);}
a=C_alloc(14);
t10=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24546,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t7,a[9]=t8,a[10]=t9,tmp=(C_word)a,a+=11,tmp);
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24557,a[2]=((C_word)li159),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3374: once */
t12=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t12;
av2[1]=t10;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(10,av2);}}

/* k24544 */
static void C_ccall f_24546(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24546,c,av);}
if(C_truep(t1)){
/* irregex-core.scm:3376: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=t1;
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3377: fail */
t2=((C_word*)t0)[10];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a24556 */
static void C_ccall f_24557(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24557,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a24563 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24564,c,av);}
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24576(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,5)))){
C_save_and_reclaim((void *)f_24576,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_24579,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:3380: lp */
t3=((C_word*)((C_word*)t0)[5])[1];
f_23458(t3,t2,C_i_caddr(((C_word*)t0)[2]),((C_word*)t0)[7],C_fixnum_plus(((C_word*)t0)[6],t1),((C_word*)t0)[8]);}

/* k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_24579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,10)))){
C_save_and_reclaim((void *)f_24579,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_24582,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t3=C_i_cdddr(((C_word*)t0)[2]);
if(C_truep(C_i_pairp(t3))){
t4=C_i_cadddr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_24695,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
t6=C_u_i_cdr(((C_word*)t0)[2]);
t7=C_u_i_cdr(t6);
/* irregex-core.scm:3384: sre-count-submatches */
f_16994(t5,C_u_i_car(t7));}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24700,a[2]=((C_word)li165),tmp=(C_word)a,a+=3,tmp);
f_24582(2,av2);}}}

/* k24580 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24582(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_24582,c,av);}
a=C_alloc(10);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=C_i_numberp(t2);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_24591,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t3)){
t5=t4;
f_24591(t5,t3);}
else{
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=t4;
f_24591(t6,C_i_symbolp(C_u_i_car(t5)));}}

/* k24589 in k24580 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in ... */
static void C_fcall f_24591(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,5)))){
C_save_and_reclaim_args((void *)trf_24591,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24594,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_u_i_cdr(((C_word*)t0)[5]);
if(C_truep(C_i_symbolp(C_u_i_car(t3)))){
t4=C_u_i_cdr(((C_word*)t0)[5]);
t5=C_i_assq(C_u_i_car(t4),((C_word*)((C_word*)t0)[6])[1]);
if(C_truep(t5)){
t6=t2;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_i_cdr(t5);
f_24594(2,av2);}}
else{
/* irregex-core.scm:3396: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t2;
av2[2]=lf[240];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}
else{
t4=t2;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_i_cadr(((C_word*)t0)[5]);
f_24594(2,av2);}}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24652,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3403: lp */
t3=((C_word*)((C_word*)t0)[7])[1];
f_23458(t3,t2,C_i_cadr(((C_word*)t0)[5]),((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[2]);}}

/* k24592 in k24589 in k24580 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in ... */
static void C_ccall f_24594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,10)))){
C_save_and_reclaim((void *)f_24594,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24595,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word)li162),tmp=(C_word)a,a+=6,tmp);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_24595 in k24592 in k24589 in k24580 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in ... */
static void C_ccall f_24595(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24595,c,av);}
t10=C_slot(t8,C_fix(1));
t11=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t12=C_fixnum_plus(C_fix(2),t11);
if(C_truep(C_slot(t10,t12))){
/* irregex-core.scm:3400: pass */
t13=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t13;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t9;
((C_proc)(void*)(*((C_word*)t13+1)))(10,av2);}}
else{
/* irregex-core.scm:3401: fail */
t13=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t13;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t9;
((C_proc)(void*)(*((C_word*)t13+1)))(10,av2);}}}

/* k24650 in k24589 in k24580 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in ... */
static void C_ccall f_24652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_24652,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24653,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li164),tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_24653 in k24650 in k24589 in k24580 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in ... */
static void C_ccall f_24653(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,9)))){
C_save_and_reclaim((void *)f_24653,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_24659,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=t6,a[8]=t7,a[9]=t8,a[10]=t9,a[11]=((C_word)li163),tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3405: test */
t11=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(10,av2);}}

/* a24658 */
static void C_ccall f_24659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24659,c,av);}
/* irregex-core.scm:3406: fail */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* k24693 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24695(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_24695,c,av);}
/* irregex-core.scm:3382: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_23458(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_fixnum_plus(C_fixnum_plus(((C_word*)t0)[5],((C_word*)t0)[6]),t1),((C_word*)t0)[7],((C_word*)t0)[8]);}

/* f_24700 in k24577 in k24574 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24700(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24700,c,av);}
/* irregex-core.scm:3388: fail */
t10=t9;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* k24730 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_24732,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24735,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_eqp(C_u_i_car(((C_word*)t0)[4]),lf[191]);
if(C_truep(t3)){
t4=t2;
f_24735(t4,(C_truep(t3)?*((C_word*)lf[241]+1):*((C_word*)lf[242]+1)));}
else{
t4=C_fixnum_and(((C_word*)t0)[5],C_fix(2));
t5=C_eqp(C_fix(2),t4);
t6=t2;
f_24735(t6,(C_truep(t5)?*((C_word*)lf[241]+1):*((C_word*)lf[242]+1)));}}

/* k24733 in k24730 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_fcall f_24735(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,10)))){
C_save_and_reclaim_args((void *)trf_24735,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24736,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word)li167),tmp=(C_word)a,a+=6,tmp);
t3=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_24736 in k24733 in k24730 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in ... */
static void C_ccall f_24736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_24736,c,av);}
a=C_alloc(13);
t10=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_24740,a[2]=t9,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=t3,a[7]=t8,a[8]=((C_word*)t0)[3],a[9]=t4,a[10]=t5,a[11]=t6,a[12]=t7,tmp=(C_word)a,a+=13,tmp);
/* irregex-core.scm:3417: irregex-match-substring */
t11=*((C_word*)lf[40]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
av2[2]=t8;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t11+1)))(4,av2);}}

/* k24738 */
static void C_ccall f_24740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,8)))){
C_save_and_reclaim((void *)f_24740,c,av);}
a=C_alloc(13);
if(C_truep(C_i_not(t1))){
/* irregex-core.scm:3419: fail */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_i_string_length(t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24758,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[8],a[8]=t1,a[9]=t4,a[10]=((C_word)li166),tmp=(C_word)a,a+=11,tmp));
t6=((C_word*)t4)[1];
f_24758(t6,((C_word*)t0)[3],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[12],C_fix(0),t2);}}

/* lp in k24738 */
static void C_fcall f_24758(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7){
C_word tmp;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,4)))){
C_save_and_reclaim_args((void *)trf_24758,8,t0,t1,t2,t3,t4,t5,t6,t7);}
a=C_alloc(20);
t8=C_fixnum_difference(t5,t4);
if(C_truep(C_fixnum_less_or_equal_p(t7,t8))){
t9=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_24771,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t2,a[7]=t3,a[8]=t4,a[9]=t7,a[10]=t5,a[11]=((C_word*)t0)[5],a[12]=((C_word*)t0)[6],tmp=(C_word)a,a+=13,tmp);
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24785,a[2]=((C_word*)t0)[7],a[3]=t9,a[4]=t3,a[5]=t4,a[6]=t7,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:3430: scheme#substring */
t11=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[8];
av2[3]=t6;
av2[4]=C_i_string_length(((C_word*)t0)[8]);
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}
else{
t9=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24803,a[2]=((C_word*)t0)[3],a[3]=t5,a[4]=t4,a[5]=t6,a[6]=((C_word*)t0)[9],a[7]=t1,a[8]=t7,a[9]=((C_word*)t0)[6],a[10]=t2,tmp=(C_word)a,a+=11,tmp);
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24858,a[2]=((C_word*)t0)[7],a[3]=t9,a[4]=t3,a[5]=t4,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
t11=C_fixnum_difference(t5,t4);
/* irregex-core.scm:3437: scheme#substring */
t12=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t12;
av2[1]=t10;
av2[2]=((C_word*)t0)[8];
av2[3]=t6;
av2[4]=C_fixnum_plus(t6,t11);
((C_proc)(void*)(*((C_word*)t12+1)))(5,av2);}}}

/* k24769 in lp in k24738 */
static void C_ccall f_24771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_24771,c,av);}
if(C_truep(t1)){
/* irregex-core.scm:3432: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=C_fixnum_plus(((C_word*)t0)[8],((C_word*)t0)[9]);
av2[7]=((C_word*)t0)[10];
av2[8]=((C_word*)t0)[11];
av2[9]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3434: fail */
t2=((C_word*)t0)[12];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k24783 in lp in k24738 */
static void C_ccall f_24785(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_24785,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24789,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3431: scheme#substring */
t3=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=C_fixnum_plus(((C_word*)t0)[5],((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k24787 in k24783 in lp in k24738 */
static void C_ccall f_24789(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24789,c,av);}
/* irregex-core.scm:3430: compare */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k24801 in lp in k24738 */
static void C_ccall f_24803(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_24803,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(0));
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_24809,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:3439: g4864 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* irregex-core.scm:3449: fail */
t2=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k24807 in k24801 in lp in k24738 */
static void C_ccall f_24809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_24809,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_24822,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:3441: g4866 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* irregex-core.scm:3447: fail */
t2=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k24820 in k24807 in k24801 in lp in k24738 */
static void C_ccall f_24822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_24822,c,av);}
a=C_alloc(11);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24829,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3441: g4868 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k24827 in k24820 in k24807 in k24801 in lp in k24738 */
static void C_ccall f_24829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_24829,c,av);}
a=C_alloc(11);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_24836,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=t1,a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3441: g4870 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k24834 in k24827 in k24820 in k24807 in k24801 in lp in k24738 */
static void C_ccall f_24836(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,7)))){
C_save_and_reclaim((void *)f_24836,c,av);}
a=C_alloc(15);
t2=C_a_i_fixnum_difference(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_s_a_u_i_integer_plus(&a,2,((C_word*)t0)[4],t2);
t4=C_a_i_fixnum_difference(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* irregex-core.scm:3441: lp */
t5=((C_word*)((C_word*)t0)[5])[1];
f_24758(t5,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],t1,t3,C_fixnum_difference(((C_word*)t0)[10],t4));}

/* k24856 in lp in k24738 */
static void C_ccall f_24858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_24858,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24862,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3438: scheme#substring */
t3=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k24860 in k24856 in lp in k24738 */
static void C_ccall f_24862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24862,c,av);}
/* irregex-core.scm:3437: compare */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k24947 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_24949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,10)))){
C_save_and_reclaim((void *)f_24949,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24950,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li169),tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_24950 in k24947 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_24950(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,9)))){
C_save_and_reclaim((void *)f_24950,c,av);}
a=C_alloc(8);
t10=C_slot(t8,C_fix(1));
t11=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t12=C_slot(t10,t11);
t13=C_slot(t8,C_fix(1));
t14=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t15=C_fixnum_plus(C_fix(1),t14);
t16=C_slot(t13,t15);
t17=C_slot(t8,C_fix(1));
t18=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t19=C_i_vector_set(t17,t18,t4);
t20=C_slot(t8,C_fix(1));
t21=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t22=C_fixnum_plus(C_fix(1),t21);
t23=C_i_vector_set(t20,t22,t6);
t24=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24998,a[2]=t8,a[3]=((C_word*)t0)[2],a[4]=t12,a[5]=t16,a[6]=t9,a[7]=((C_word)li168),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3476: body */
t25=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t25;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t24;
((C_proc)(void*)(*((C_word*)t25+1)))(10,av2);}}

/* a24997 */
static void C_ccall f_24998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24998,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(((C_word*)t0)[3],C_fix(4));
t4=C_i_vector_set(t2,t3,((C_word*)t0)[4]);
t5=C_slot(((C_word*)t0)[2],C_fix(1));
t6=C_fixnum_times(((C_word*)t0)[3],C_fix(4));
t7=C_fixnum_plus(C_fix(1),t6);
t8=C_i_vector_set(t5,t7,((C_word*)t0)[5]);
/* irregex-core.scm:3482: fail */
t9=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t9;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* a25057 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25058(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,9)))){
C_save_and_reclaim((void *)f_25058,c,av);}
a=C_alloc(8);
t10=C_slot(t8,C_fix(1));
t11=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t12=C_fixnum_plus(C_fix(2),t11);
t13=C_slot(t10,t12);
t14=C_slot(t8,C_fix(1));
t15=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t16=C_slot(t14,C_fixnum_plus(C_fix(3),t15));
t17=C_slot(t8,C_fix(1));
t18=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t19=C_fixnum_plus(C_fix(2),t18);
t20=C_i_vector_set(t17,t19,t4);
t21=C_slot(t8,C_fix(1));
t22=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t23=C_fixnum_plus(C_fix(3),t22);
t24=C_i_vector_set(t21,t23,t6);
t25=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25093,a[2]=t8,a[3]=((C_word*)t0)[2],a[4]=t13,a[5]=t16,a[6]=t9,a[7]=((C_word)li170),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3464: next */
t26=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t26;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t25;
((C_proc)(void*)(*((C_word*)t26+1)))(10,av2);}}

/* a25092 in a25057 in k23498 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 in ... */
static void C_ccall f_25093(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25093,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(((C_word*)t0)[3],C_fix(4));
t4=C_fixnum_plus(C_fix(2),t3);
t5=C_i_vector_set(t2,t4,((C_word*)t0)[4]);
t6=C_slot(((C_word*)t0)[2],C_fix(1));
t7=C_fixnum_times(((C_word*)t0)[3],C_fix(4));
t8=C_fixnum_plus(C_fix(3),t7);
t9=C_i_vector_set(t6,t8,((C_word*)t0)[5]);
/* irregex-core.scm:3470: fail */
t10=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}

/* f_25293 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,9)))){
C_save_and_reclaim((void *)f_25293,c,av);}
a=C_alloc(8);
if(C_truep(C_fixnum_lessp(t6,t7))){
/* irregex-core.scm:3492: next */
t10=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=C_fixnum_plus(t6,C_fix(1));
av2[7]=t7;
av2[8]=t8;
av2[9]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(10,av2);}}
else{
t10=C_i_vector_ref(t2,C_fix(0));
t11=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25313,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,a[6]=t8,a[7]=t9,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3493: g4960 */
t12=t10;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}}

/* k25311 */
static void C_ccall f_25313(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_25313,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25322,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3495: g4965 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* irregex-core.scm:3499: fail */
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25320 in k25311 */
static void C_ccall f_25322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_25322,c,av);}
a=C_alloc(10);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_25328,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:3495: g4967 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25326 in k25320 in k25311 */
static void C_ccall f_25328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_25328,c,av);}
a=C_alloc(11);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_25334,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3495: g4969 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25332 in k25326 in k25320 in k25311 */
static void C_ccall f_25334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_25334,c,av);}
/* irregex-core.scm:3498: next */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=C_fixnum_plus(((C_word*)t0)[8],C_fix(1));
av2[7]=t1;
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}

/* f_25351 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25351(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,9)))){
C_save_and_reclaim((void *)f_25351,c,av);}
a=C_alloc(8);
if(C_truep(C_fixnum_lessp(t6,t7))){
t10=C_i_string_ref(t5,t6);
t11=C_eqp(C_make_character(10),t10);
if(C_truep(C_i_not(t11))){
t12=C_a_i_fixnum_plus(&a,2,t6,C_fix(1));
/* irregex-core.scm:3504: next */
t13=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t13;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t12;
av2[7]=t7;
av2[8]=t8;
av2[9]=t9;
((C_proc)(void*)(*((C_word*)t13+1)))(10,av2);}}
else{
/* irregex-core.scm:3505: fail */
t12=t9;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}
else{
t10=C_i_vector_ref(t2,C_fix(0));
t11=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25388,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,a[6]=t8,a[7]=t9,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3506: g4980 */
t12=t10;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}}

/* k25386 */
static void C_ccall f_25388(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_25388,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25397,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3508: g4985 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* irregex-core.scm:3514: fail */
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25395 in k25386 */
static void C_ccall f_25397(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_25397,c,av);}
a=C_alloc(10);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_25403,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:3508: g4987 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25401 in k25395 in k25386 */
static void C_ccall f_25403(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_25403,c,av);}
a=C_alloc(11);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_25409,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3508: g4989 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25407 in k25401 in k25395 in k25386 */
static void C_ccall f_25409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,9)))){
C_save_and_reclaim((void *)f_25409,c,av);}
a=C_alloc(5);
t2=C_i_string_ref(((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_eqp(C_make_character(10),t2);
if(C_truep(C_i_not(t3))){
t4=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:3512: next */
t5=((C_word*)t0)[4];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
av2[4]=((C_word*)t0)[8];
av2[5]=((C_word*)t0)[2];
av2[6]=t4;
av2[7]=t1;
av2[8]=((C_word*)t0)[9];
av2[9]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t5+1)))(10,av2);}}
else{
/* irregex-core.scm:3513: fail */
t4=((C_word*)t0)[10];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* f_25443 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_25443,c,av);}
t10=C_i_car(t3);
t11=C_eqp(t4,t10);
t12=(C_truep(t11)?C_i_eqvp(t6,C_u_i_cdr(t3)):C_SCHEME_FALSE);
if(C_truep(t12)){
/* irregex-core.scm:3518: next */
t13=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t13;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t6;
av2[7]=t7;
av2[8]=t8;
av2[9]=t9;
((C_proc)(void*)(*((C_word*)t13+1)))(10,av2);}}
else{
/* irregex-core.scm:3519: fail */
t13=t9;{
C_word *av2=av;
av2[0]=t13;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}}

/* f_25473 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_25473,c,av);}
a=C_alloc(20);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25480,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
t11=C_i_vector_ref(t2,C_fix(2));
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25517,a[2]=t6,a[3]=t10,a[4]=t5,a[5]=t2,a[6]=t3,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3522: g5009 */
t13=t11;{
C_word *av2=av;
av2[0]=t13;
av2[1]=t12;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}

/* k25478 */
static void C_ccall f_25480(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_25480,c,av);}
t2=C_i_not(t1);
t3=(C_truep(t2)?t2:C_eqp(C_make_character(10),t1));
if(C_truep(t3)){
/* irregex-core.scm:3526: next */
t4=((C_word*)t0)[2];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t4+1)))(10,av2);}}
else{
/* irregex-core.scm:3527: fail */
t4=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k25515 */
static void C_ccall f_25517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25517,c,av);}
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[2],t1))){
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_string_ref(((C_word*)t0)[4],C_fixnum_difference(((C_word*)t0)[2],C_fix(1)));
f_25480(2,av2);}}
else{
/* irregex-core.scm:3524: chunker-prev-char */
f_8646(((C_word*)t0)[3],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}}

/* f_25524 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,2)))){
C_save_and_reclaim((void *)f_25524,c,av);}
a=C_alloc(28);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25531,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
t11=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25540,a[2]=t6,a[3]=t7,a[4]=t5,a[5]=t10,a[6]=t2,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
t12=C_i_vector_ref(t2,C_fix(2));
t13=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25624,a[2]=t6,a[3]=t5,a[4]=t11,a[5]=t2,a[6]=t3,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3530: g5023 */
t14=t12;{
C_word *av2=av;
av2[0]=t14;
av2[1]=t13;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t14+1)))(3,av2);}}

/* k25529 */
static void C_fcall f_25531(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,9)))){
C_save_and_reclaim_args((void *)trf_25531,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:3541: next */
t2=((C_word*)t0)[2];{
C_word av2[10];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3542: fail */
t2=((C_word*)t0)[11];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25538 */
static void C_fcall f_25540(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_25540,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
if(C_truep(C_fixnum_lessp(((C_word*)t0)[2],((C_word*)t0)[3]))){
t2=C_i_string_ref(((C_word*)t0)[4],((C_word*)t0)[2]);
t3=C_u_i_char_alphabeticp(t2);
t4=((C_word*)t0)[5];
f_25531(t4,(C_truep(t3)?t3:C_u_i_char_numericp(t2)));}
else{
t2=C_i_vector_ref(((C_word*)t0)[6],C_fix(0));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25559,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3536: g5030 */
t4=t2;{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}
else{
t2=((C_word*)t0)[5];
f_25531(t2,C_SCHEME_FALSE);}}

/* k25557 in k25538 */
static void C_ccall f_25559(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_25559,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25576,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3539: g5033 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];
f_25531(t2,C_SCHEME_FALSE);}}

/* k25574 in k25557 in k25538 */
static void C_ccall f_25576(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_25576,c,av);}
a=C_alloc(4);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25583,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3539: g5035 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25581 in k25574 in k25557 in k25538 */
static void C_ccall f_25583(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25583,c,av);}
t2=C_i_string_ref(((C_word*)t0)[2],t1);
t3=C_u_i_char_alphabeticp(t2);
t4=((C_word*)t0)[3];
f_25531(t4,(C_truep(t3)?t3:C_u_i_char_numericp(t2)));}

/* k25602 in k25622 */
static void C_ccall f_25604(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25604,c,av);}
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];
f_25540(t3,t2);}
else{
t3=C_u_i_char_alphabeticp(t1);
t4=(C_truep(t3)?t3:C_u_i_char_numericp(t1));
t5=((C_word*)t0)[2];
f_25540(t5,C_i_not(t4));}}

/* k25622 */
static void C_ccall f_25624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_25624,c,av);}
a=C_alloc(3);
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[2],t1))){
t2=C_fixnum_difference(((C_word*)t0)[2],C_fix(1));
t3=C_i_string_ref(((C_word*)t0)[3],t2);
t4=C_u_i_char_alphabeticp(t3);
t5=(C_truep(t4)?t4:C_u_i_char_numericp(t3));
t6=((C_word*)t0)[4];
f_25540(t6,C_i_not(t5));}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25604,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3532: chunker-prev-char */
f_8646(t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}}

/* f_25631 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25631(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_25631,c,av);}
a=C_alloc(15);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25638,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
if(C_truep(C_fixnum_greater_or_equal_p(t6,t7))){
t11=C_i_vector_ref(t2,C_fix(0));
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25657,a[2]=t10,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3545: g5046 */
t13=t11;{
C_word *av2=av;
av2[0]=t13;
av2[1]=t12;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t11=t10;
f_25638(t11,C_SCHEME_FALSE);}}

/* k25636 */
static void C_fcall f_25638(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,9)))){
C_save_and_reclaim_args((void *)trf_25638,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:3546: next */
t2=((C_word*)t0)[2];{
C_word av2[10];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3547: fail */
t2=((C_word*)t0)[11];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25655 */
static void C_ccall f_25657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25657,c,av);}
t2=((C_word*)t0)[2];
f_25638(t2,C_i_not(t1));}

/* f_25664 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25664(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_25664,c,av);}
a=C_alloc(16);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25671,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
if(C_truep(C_fixnum_lessp(t6,t7))){
t11=t10;
f_25671(t11,C_eqp(C_make_character(10),C_i_string_ref(t5,t6)));}
else{
t11=C_i_vector_ref(t2,C_fix(0));
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25694,a[2]=t10,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3552: g5057 */
t13=t11;{
C_word *av2=av;
av2[0]=t13;
av2[1]=t12;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}}

/* k25669 */
static void C_fcall f_25671(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,9)))){
C_save_and_reclaim_args((void *)trf_25671,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:3558: next */
t2=((C_word*)t0)[2];{
C_word av2[10];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3559: fail */
t2=((C_word*)t0)[11];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25692 */
static void C_ccall f_25694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_25694,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=((C_word*)t0)[2];
f_25671(t2,C_SCHEME_TRUE);}
else{
t2=C_i_vector_ref(((C_word*)t0)[3],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25715,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3556: g5059 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k25713 in k25692 */
static void C_ccall f_25715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_25715,c,av);}
a=C_alloc(4);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25722,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3556: g5061 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25720 in k25713 in k25692 */
static void C_ccall f_25722(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25722,c,av);}
t2=((C_word*)t0)[2];
f_25671(t2,C_eqp(C_make_character(10),C_i_string_ref(((C_word*)t0)[3],t1)));}

/* f_25729 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_25729,c,av);}
a=C_alloc(23);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25736,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
t11=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25745,a[2]=t2,a[3]=t6,a[4]=t5,a[5]=t10,a[6]=t3,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_fixnum_lessp(t6,t7))){
t12=C_i_string_ref(t5,t6);
t13=C_u_i_char_alphabeticp(t12);
t14=(C_truep(t13)?t13:C_u_i_char_numericp(t12));
t15=t11;
f_25745(t15,C_i_not(t14));}
else{
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25798,a[2]=t11,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3564: chunker-next-char */
f_8676(t12,t2,t4);}}

/* k25734 */
static void C_fcall f_25736(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,9)))){
C_save_and_reclaim_args((void *)trf_25736,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:3570: next */
t2=((C_word*)t0)[2];{
C_word av2[10];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3571: fail */
t2=((C_word*)t0)[11];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25743 */
static void C_fcall f_25745(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_25745,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25781,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3566: g5076 */
t4=t2;{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[5];
f_25736(t2,C_SCHEME_FALSE);}}

/* k25763 in k25779 in k25743 */
static void C_ccall f_25765(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25765,c,av);}
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];
f_25736(t3,t2);}
else{
t3=C_u_i_char_alphabeticp(t1);
t4=((C_word*)t0)[2];
f_25736(t4,(C_truep(t3)?t3:C_u_i_char_numericp(t1)));}}

/* k25779 in k25743 */
static void C_ccall f_25781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_25781,c,av);}
a=C_alloc(3);
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[2],t1))){
t2=C_fixnum_difference(((C_word*)t0)[2],C_fix(1));
t3=C_i_string_ref(((C_word*)t0)[3],t2);
t4=C_u_i_char_alphabeticp(t3);
t5=((C_word*)t0)[4];
f_25736(t5,(C_truep(t4)?t4:C_u_i_char_numericp(t3)));}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25765,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3568: chunker-prev-char */
f_8646(t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}}

/* k25796 */
static void C_ccall f_25798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25798,c,av);}
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];
f_25745(t3,t2);}
else{
t3=C_u_i_char_alphabeticp(t1);
t4=(C_truep(t3)?t3:C_u_i_char_numericp(t1));
t5=((C_word*)t0)[2];
f_25745(t5,C_i_not(t4));}}

/* f_25818 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25818(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_25818,c,av);}
a=C_alloc(12);
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25822,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
if(C_truep(C_fixnum_lessp(t6,t7))){
t11=t10;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_i_string_ref(t5,t6);
f_25822(2,av2);}}
else{
/* irregex-core.scm:3576: chunker-next-char */
f_8676(t10,t2,t4);}}

/* k25820 */
static void C_ccall f_25822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,2)))){
C_save_and_reclaim((void *)f_25822,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_25825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,tmp=(C_word)a,a+=13,tmp);
t3=C_i_vector_ref(((C_word*)t0)[4],C_fix(2));
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25876,a[2]=((C_word*)t0)[8],a[3]=t2,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3577: g5092 */
t5=t3;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k25823 in k25820 */
static void C_ccall f_25825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_25825,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25831,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[12])){
if(C_truep(t1)){
t3=C_u_i_char_alphabeticp(((C_word*)t0)[12]);
t4=(C_truep(t3)?t3:C_u_i_char_numericp(((C_word*)t0)[12]));
if(C_truep(t4)){
t5=C_u_i_char_alphabeticp(t1);
t6=t2;
f_25831(t6,(C_truep(t5)?t5:C_u_i_char_numericp(t1)));}
else{
t5=C_u_i_char_alphabeticp(t1);
t6=(C_truep(t5)?t5:C_u_i_char_numericp(t1));
t7=t2;
f_25831(t7,C_i_not(t6));}}
else{
t3=t2;
f_25831(t3,C_SCHEME_FALSE);}}
else{
t3=t2;
f_25831(t3,C_SCHEME_FALSE);}}

/* k25829 in k25823 in k25820 */
static void C_fcall f_25831(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,9)))){
C_save_and_reclaim_args((void *)trf_25831,2,t0,t1);}
if(C_truep(t1)){
/* irregex-core.scm:3584: next */
t2=((C_word*)t0)[2];{
C_word av2[10];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=((C_word*)t0)[8];
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(10,av2);}}
else{
/* irregex-core.scm:3585: fail */
t2=((C_word*)t0)[11];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25874 in k25820 */
static void C_ccall f_25876(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25876,c,av);}
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[2],t1))){
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_string_ref(((C_word*)t0)[4],C_fixnum_difference(((C_word*)t0)[2],C_fix(1)));
f_25825(2,av2);}}
else{
/* irregex-core.scm:3579: chunker-prev-char */
f_8646(((C_word*)t0)[3],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}}

/* f_25940 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_25940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_25940,c,av);}
a=C_alloc(12);
if(C_truep(C_fixnum_greater_or_equal_p(t6,t7))){
t10=C_i_vector_ref(t2,C_fix(0));
t11=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25957,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t8,a[6]=t9,a[7]=((C_word*)t0)[3],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3598: g5119 */
t12=t10;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_26025,a[2]=t6,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t2,a[6]=t3,a[7]=t4,a[8]=t5,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3610: scheme#char-ci=? */
t11=*((C_word*)lf[250]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_string_ref(t5,t6);
((C_proc)(void*)(*((C_word*)t11+1)))(4,av2);}}}

/* k25955 */
static void C_ccall f_25957(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_25957,c,av);}
a=C_alloc(12);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_25959,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word)li181),tmp=(C_word)a,a+=10,tmp));
t5=((C_word*)t3)[1];
f_25959(t5,((C_word*)t0)[8],t1);}

/* lp in k25955 */
static void C_fcall f_25959(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_25959,3,t0,t1,t2);}
a=C_alloc(11);
if(C_truep(t2)){
t3=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_25969,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3600: g5110 */
t5=t3;{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
/* irregex-core.scm:3609: fail */
t3=((C_word*)t0)[7];{
C_word av2[2];
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k25967 in lp in k25955 */
static void C_ccall f_25969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_25969,c,av);}
a=C_alloc(12);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25975,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3600: g5112 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25973 in k25967 in lp in k25955 */
static void C_ccall f_25975(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_25975,c,av);}
a=C_alloc(13);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_25981,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* irregex-core.scm:3600: g5114 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k25979 in k25973 in k25967 in lp in k25955 */
static void C_ccall f_25981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_25981,c,av);}
a=C_alloc(12);
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[2],t1))){
t2=C_i_vector_ref(((C_word*)t0)[3],C_fix(0));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25997,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3604: g5116 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_26003,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[9],a[9]=t1,a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3605: scheme#char-ci=? */
t3=*((C_word*)lf[250]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
av2[3]=C_i_string_ref(((C_word*)t0)[9],((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k25995 in k25979 in k25973 in k25967 in lp in k25955 */
static void C_ccall f_25997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_25997,c,av);}
/* irregex-core.scm:3604: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_25959(t2,((C_word*)t0)[3],t1);}

/* k26001 in k25979 in k25973 in k25967 in lp in k25955 */
static void C_ccall f_26003(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,9)))){
C_save_and_reclaim((void *)f_26003,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* irregex-core.scm:3606: next */
t3=((C_word*)t0)[3];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=t2;
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(10,av2);}}
else{
/* irregex-core.scm:3608: fail */
t2=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k26023 */
static void C_ccall f_26025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,9)))){
C_save_and_reclaim((void *)f_26025,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* irregex-core.scm:3611: next */
t3=((C_word*)t0)[3];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=t2;
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(10,av2);}}
else{
/* irregex-core.scm:3612: fail */
t2=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* f_26039 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_26039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,9)))){
C_save_and_reclaim((void *)f_26039,c,av);}
a=C_alloc(9);
if(C_truep(C_fixnum_greater_or_equal_p(t6,t7))){
t10=C_i_vector_ref(t2,C_fix(0));
t11=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_26056,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t3,a[6]=t8,a[7]=t9,a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3616: g5143 */
t12=t10;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}
else{
t10=C_i_string_ref(t5,t6);
if(C_truep(C_i_char_equalp(((C_word*)t0)[2],t10))){
t11=C_a_i_fixnum_plus(&a,2,t6,C_fix(1));
/* irregex-core.scm:3629: next */
t12=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t12;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
av2[6]=t11;
av2[7]=t7;
av2[8]=t8;
av2[9]=t9;
((C_proc)(void*)(*((C_word*)t12+1)))(10,av2);}}
else{
/* irregex-core.scm:3630: fail */
t11=t9;{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}

/* k26054 */
static void C_ccall f_26056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_26056,c,av);}
a=C_alloc(12);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_26058,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word)li183),tmp=(C_word)a,a+=10,tmp));
t5=((C_word*)t3)[1];
f_26058(t5,((C_word*)t0)[8],t1);}

/* lp in k26054 */
static void C_fcall f_26058(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_26058,3,t0,t1,t2);}
a=C_alloc(11);
if(C_truep(t2)){
t3=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_26068,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3618: g5134 */
t5=t3;{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
/* irregex-core.scm:3627: fail */
t3=((C_word*)t0)[8];{
C_word av2[2];
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k26066 in lp in k26054 */
static void C_ccall f_26068(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_26068,c,av);}
a=C_alloc(12);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_26074,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3618: g5136 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k26072 in k26066 in lp in k26054 */
static void C_ccall f_26074(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_26074,c,av);}
a=C_alloc(13);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_26080,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* irregex-core.scm:3618: g5138 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k26078 in k26072 in k26066 in lp in k26054 */
static void C_ccall f_26080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,9)))){
C_save_and_reclaim((void *)f_26080,c,av);}
a=C_alloc(5);
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[2],t1))){
t2=C_i_vector_ref(((C_word*)t0)[3],C_fix(0));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26096,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3622: g5140 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=C_i_string_ref(((C_word*)t0)[7],((C_word*)t0)[2]);
if(C_truep(C_i_char_equalp(((C_word*)t0)[8],t2))){
t3=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* irregex-core.scm:3624: next */
t4=((C_word*)t0)[9];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[10];
av2[4]=((C_word*)t0)[6];
av2[5]=((C_word*)t0)[7];
av2[6]=t3;
av2[7]=t1;
av2[8]=((C_word*)t0)[11];
av2[9]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t4+1)))(10,av2);}}
else{
/* irregex-core.scm:3626: fail */
t3=((C_word*)t0)[12];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k26094 in k26078 in k26072 in k26066 in lp in k26054 */
static void C_ccall f_26096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26096,c,av);}
/* irregex-core.scm:3622: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_26058(t2,((C_word*)t0)[3],t1);}

/* k26152 in lp in k23407 in k16244 in k17102 in k17095 in k17092 in k16215 in k16212 in k16209 in k16206 in k16203 in k16197 in k16194 in k16191 in k16188 in chicken.irregex#sre->irregex in k7767 in k7542 in k7539 */
static void C_ccall f_26154(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26154,c,av);}
a=C_alloc(3);
t2=(
/* irregex-core.scm:3633: sre-sequence */
  f_18203(C_a_i(&a,3),t1)
);
/* irregex-core.scm:3633: rec */
t3=((C_word*)t0)[2];
f_23461(t3,((C_word*)t0)[3],t2);}

/* chicken.irregex#sre-cset->procedure in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26180(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,10)))){
C_save_and_reclaim_args((void *)trf_26180,3,t1,t2,t3);}
a=C_alloc(5);
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26182,a[2]=t3,a[3]=t2,a[4]=((C_word)li311),tmp=(C_word)a,a+=5,tmp);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* f_26182 in chicken.irregex#sre-cset->procedure in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8=av[8];
C_word t9=av[9];
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=10) C_bad_argc_2(c,10,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_26182,c,av);}
a=C_alloc(12);
if(C_truep(C_fixnum_lessp(t6,t7))){
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_26195,a[2]=t6,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t2,a[6]=t3,a[7]=t4,a[8]=t5,a[9]=t7,a[10]=t8,a[11]=t9,tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3657: cset-contains? */
f_26971(t10,((C_word*)t0)[3],C_i_string_ref(t5,t6));}
else{
t10=C_i_vector_ref(t2,C_fix(0));
t11=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_26214,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,a[6]=t8,a[7]=t9,a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3660: g5184 */
t12=t10;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}}

/* k26193 */
static void C_ccall f_26195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,9)))){
C_save_and_reclaim((void *)f_26195,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* irregex-core.scm:3658: next */
t3=((C_word*)t0)[3];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=t2;
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(10,av2);}}
else{
/* irregex-core.scm:3659: fail */
t2=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k26212 */
static void C_ccall f_26214(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_26214,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_26223,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* irregex-core.scm:3662: g5189 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* irregex-core.scm:3668: fail */
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k26221 in k26212 */
static void C_ccall f_26223(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_26223,c,av);}
a=C_alloc(11);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_26229,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3662: g5191 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k26227 in k26221 in k26212 */
static void C_ccall f_26229(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_26229,c,av);}
a=C_alloc(12);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_26235,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3662: g5193 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k26233 in k26227 in k26221 in k26212 */
static void C_ccall f_26235(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_26235,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_26241,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3665: cset-contains? */
f_26971(t2,((C_word*)t0)[11],C_i_string_ref(((C_word*)t0)[8],((C_word*)t0)[2]));}

/* k26239 in k26233 in k26227 in k26221 in k26212 */
static void C_ccall f_26241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,9)))){
C_save_and_reclaim((void *)f_26241,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* irregex-core.scm:3666: next */
t3=((C_word*)t0)[3];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
av2[6]=t2;
av2[7]=((C_word*)t0)[9];
av2[8]=((C_word*)t0)[10];
av2[9]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(10,av2);}}
else{
/* irregex-core.scm:3667: fail */
t2=((C_word*)t0)[11];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.irregex#cset->plist in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26393(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_26393,2,t1,t2);}
a=C_alloc(12);
t3=C_i_vector_length(t2);
t4=C_a_i_fixnum_difference(&a,2,t3,C_fix(1));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26405,a[2]=t2,a[3]=t6,a[4]=((C_word)li313),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_26405(t8,t1,t4,C_SCHEME_END_OF_LIST);}

/* lp in chicken.irregex#cset->plist in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26405(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_26405,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_eqp(t2,C_fix(-1));
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_fixnum_difference(t2,C_fix(1));
t6=C_i_vector_ref(((C_word*)t0)[2],t2);
t7=C_i_car(t6);
t8=C_i_vector_ref(((C_word*)t0)[2],t2);
t9=C_i_cdr(t8);
t10=C_a_i_cons(&a,2,t9,t3);
t11=C_a_i_cons(&a,2,t7,t10);
/* irregex-core.scm:3697: lp */
t13=t1;
t14=t5;
t15=t11;
t1=t13;
t2=t14;
t3=t15;
goto loop;}}

/* lp in k26770 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26455(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_26455,4,t0,t1,t2,t3);}
a=C_alloc(10);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_cddr(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26473,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=C_u_i_car(t2);
t7=C_u_i_cdr(t2);
t8=C_u_i_car(t7);
t9=C_a_i_cons(&a,2,t6,t8);
t10=C_a_i_vector1(&a,1,t9);
/* irregex-core.scm:3704: cset-union */
t11=lf[162];{
C_word av2[4];
av2[0]=t11;
av2[1]=t5;
av2[2]=t10;
av2[3]=t3;
f_27092(4,av2);}}}

/* k26471 in lp in k26770 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_26473,c,av);}
/* irregex-core.scm:3704: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_26455(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.irregex#string->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26484(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_26484,2,t1,t2);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26490,a[2]=((C_word)li315),tmp=(C_word)a,a+=3,tmp);
t4=C_a_i_vector(&a,0);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26502,a[2]=t1,a[3]=t3,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* ##sys#string->list */
t6=*((C_word*)lf[105]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* a26489 in chicken.irregex#string->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_26490,c,av);}
a=C_alloc(5);
t4=C_a_i_cons(&a,2,t2,t2);
t5=C_a_i_vector1(&a,1,t4);
/* irregex-core.scm:3809: cset-union */
t6=lf[162];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=t3;
av2[3]=t5;
f_27092(4,av2);}}

/* k26500 in chicken.irregex#string->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26502(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26502,c,av);}
/* irregex-core.scm:3707: fold */
f_9388(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26504(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_26504,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t3);
t5=(C_truep(t4)?C_u_i_car(t3):C_SCHEME_FALSE);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26514,a[2]=t7,a[3]=((C_word)li325),tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_26514(t9,t1,t2,t5);}

/* lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26514(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,4)))){
C_save_and_reclaim_args((void *)trf_26514,4,t0,t1,t2,t3);}
a=C_alloc(18);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26517,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word)li317),tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_pairp(t2))){
if(C_truep(C_i_stringp(C_u_i_car(t2)))){
if(C_truep(t3)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26543,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3719: string->cset */
f_26484(t5,C_u_i_car(t2));}
else{
/* irregex-core.scm:3720: string->cset */
f_26484(t1,C_u_i_car(t2));}}
else{
t5=C_u_i_car(t2);
t6=C_eqp(t5,lf[179]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26564,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26568,a[2]=t2,a[3]=t7,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3724: rec */
t9=t4;
f_26517(t9,t8,C_i_cadr(t2));}
else{
t7=C_eqp(t5,lf[234]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26632,a[2]=t2,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3726: rec */
t9=t4;
f_26517(t9,t8,C_i_cadr(t2));}
else{
t8=C_eqp(t5,lf[247]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26694,a[2]=((C_word)li320),tmp=(C_word)a,a+=3,tmp);
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26702,a[2]=t2,a[3]=t1,a[4]=t9,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3729: rec */
t11=t4;
f_26517(t11,t10,C_i_cadr(t2));}
else{
t9=C_eqp(t5,lf[52]);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26762,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26772,a[2]=t10,tmp=(C_word)a,a+=3,tmp);
t12=C_u_i_cdr(t2);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18382,a[2]=t14,a[3]=((C_word)li323),tmp=(C_word)a,a+=4,tmp));
t16=((C_word*)t14)[1];
f_18382(t16,t11,t12,C_SCHEME_END_OF_LIST);}
else{
t10=C_eqp(t5,lf[103]);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26787,a[2]=t2,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3737: rec */
t12=t4;
f_26517(t12,t11,C_i_cadr(t2));}
else{
t11=C_eqp(t5,lf[225]);
if(C_truep(t11)){
t12=(
/* irregex-core.scm:3739: sre-alternate */
  f_18226(C_a_i(&a,3),C_u_i_cdr(t2))
);
/* irregex-core.scm:3739: lp */
t17=t1;
t18=t12;
t19=C_SCHEME_FALSE;
t1=t17;
t2=t18;
t3=t19;
goto loop;}
else{
t12=C_eqp(t5,lf[226]);
if(C_truep(t12)){
t13=(
/* irregex-core.scm:3741: sre-alternate */
  f_18226(C_a_i(&a,3),C_u_i_cdr(t2))
);
/* irregex-core.scm:3741: lp */
t17=t1;
t18=t13;
t19=C_SCHEME_TRUE;
t1=t17;
t2=t18;
t3=t19;
goto loop;}
else{
/* irregex-core.scm:3743: chicken.base#error */
t13=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t13;
av2[1]=t1;
av2[2]=lf[406];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t13+1)))(4,av2);}}}}}}}}}}
else{
if(C_truep(C_charp(t2))){
if(C_truep(t3)){
t5=C_a_i_cons(&a,2,t2,t2);
t6=C_a_i_vector1(&a,1,t5);
/* irregex-core.scm:3745: cset-case-insensitive */
f_27619(t1,t6);}
else{
t5=C_a_i_cons(&a,2,t2,t2);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_a_i_vector1(&a,1,t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
if(C_truep(C_i_stringp(t2))){
t5=C_a_i_list1(&a,1,t2);
/* irregex-core.scm:3747: rec */
t6=t4;
f_26517(t6,t1,t5);}
else{
t5=C_i_assq(t2,lf[248]);
if(C_truep(t5)){
/* irregex-core.scm:3751: rec */
t6=t4;
f_26517(t6,t1,C_i_cdr(t5));}
else{
/* irregex-core.scm:3752: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[407];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}}}}

/* rec in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26517(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_26517,3,t0,t1,t2);}
/* irregex-core.scm:3714: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_26514(t3,t1,t2,((C_word*)t0)[3]);}

/* k26541 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26543(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26543,c,av);}
/* irregex-core.scm:3719: cset-case-insensitive */
f_27619(((C_word*)t0)[2],t1);}

/* k26562 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26564,c,av);}
/* irregex-core.scm:3723: cset-complement */
f_27609(((C_word*)t0)[2],t1);}

/* k26566 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26568(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_26568,c,av);}
a=C_alloc(18);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_cddr(((C_word*)t0)[2]);
t7=C_i_check_list_2(t6,lf[211]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26581,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26583,a[2]=t4,a[3]=t10,a[4]=((C_word*)t0)[4],a[5]=t5,a[6]=((C_word)li318),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_26583(t12,t8,t6);}

/* k26579 in k26566 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26581,c,av);}
/* irregex-core.scm:3724: fold */
f_9388(((C_word*)t0)[2],lf[162],((C_word*)t0)[3],t1);}

/* map-loop5250 in k26566 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26583(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_26583,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26608,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3724: g5256 */
t4=((C_word*)t0)[4];
f_26517(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k26606 in map-loop5250 in k26566 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26608(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26608,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_26583(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k26630 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_26632,c,av);}
a=C_alloc(18);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_cddr(((C_word*)t0)[2]);
t7=C_i_check_list_2(t6,lf[211]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26645,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26647,a[2]=t4,a[3]=t10,a[4]=((C_word*)t0)[4],a[5]=t5,a[6]=((C_word)li319),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_26647(t12,t8,t6);}

/* k26643 in k26630 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26645(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26645,c,av);}
/* irregex-core.scm:3726: fold */
f_9388(((C_word*)t0)[2],lf[405],((C_word*)t0)[3],t1);}

/* map-loop5276 in k26630 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26647(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_26647,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26672,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3726: g5282 */
t4=((C_word*)t0)[4];
f_26517(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k26670 in map-loop5276 in k26630 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26672(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26672,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_26647(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a26693 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_26694,c,av);}
/* irregex-core.scm:3728: cset-difference */
f_27287(t1,t3,t2);}

/* k26700 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26702(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_26702,c,av);}
a=C_alloc(19);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_cddr(((C_word*)t0)[2]);
t7=C_i_check_list_2(t6,lf[211]);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26715,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26717,a[2]=t4,a[3]=t10,a[4]=((C_word*)t0)[5],a[5]=t5,a[6]=((C_word)li321),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_26717(t12,t8,t6);}

/* k26713 in k26700 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26715,c,av);}
/* irregex-core.scm:3728: fold */
f_9388(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* map-loop5304 in k26700 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26717(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_26717,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26742,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3730: g5310 */
t4=((C_word*)t0)[4];
f_26517(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k26740 in map-loop5304 in k26700 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26742,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_26717(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k26760 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26762,c,av);}
if(C_truep(((C_word*)t0)[2])){
/* irregex-core.scm:3734: cset-case-insensitive */
f_27619(((C_word*)t0)[3],t1);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k26770 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_26772,c,av);}
a=C_alloc(7);
t2=C_a_i_vector(&a,0);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26455,a[2]=t4,a[3]=((C_word)li322),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_26455(t6,((C_word*)t0)[2],t1,t2);}

/* k26785 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_26787,c,av);}
a=C_alloc(18);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_cddr(((C_word*)t0)[2]);
t7=C_i_check_list_2(t6,lf[211]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26800,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26802,a[2]=t4,a[3]=t10,a[4]=((C_word*)t0)[4],a[5]=t5,a[6]=((C_word)li324),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_26802(t12,t8,t6);}

/* k26798 in k26785 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26800,c,av);}
/* irregex-core.scm:3737: fold */
f_9388(((C_word*)t0)[2],lf[162],((C_word*)t0)[3],t1);}

/* map-loop5331 in k26785 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26802(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_26802,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26827,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3737: g5337 */
t4=((C_word*)t0)[4];
f_26517(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k26825 in map-loop5331 in k26785 in lp in chicken.irregex#sre->cset in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_26827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26827,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_26802(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k26947 in k13460 in k13453 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_26949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_26949,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,lf[52],t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list2(&a,2,t2,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a26950 in k13460 in k13453 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_26951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_26951,c,av);}
a=C_alloc(6);
t4=C_i_car(t2);
t5=C_u_i_cdr(t2);
t6=C_a_i_cons(&a,2,t5,t3);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_a_i_cons(&a,2,t4,t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* k26967 in k13460 in k13453 in go in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_26969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26969,c,av);}
/* irregex-core.scm:3756: fold */
f_9388(((C_word*)t0)[2],((C_word*)t0)[3],C_SCHEME_END_OF_LIST,t1);}

/* chicken.irregex#cset-contains? in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_26971(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_26971,3,t1,t2,t3);}
a=C_alloc(8);
t4=C_block_size(t2);
switch(t4){
case C_fix(0):
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}
case C_fix(1):
t5=C_i_vector_ref(t2,C_fix(0));
t6=C_u_i_cdr(t5);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=(C_truep(C_u_i_char_less_or_equal_p(t3,t6))?C_u_i_char_less_or_equal_p(C_u_i_car(t5),t3):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}
default:
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27004,a[2]=t2,a[3]=t3,a[4]=t6,a[5]=((C_word)li327),tmp=(C_word)a,a+=6,tmp));
t8=((C_word*)t6)[1];
f_27004(t8,t1,C_fix(0),t4);}}

/* lp in chicken.irregex#cset-contains? in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27004(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_27004,4,t0,t1,t2,t3);}
a=C_alloc(5);
t4=C_fixnum_plus(t3,t2);
t5=C_fixnum_shift_right(t4,C_fix(1));
t6=C_i_vector_ref(((C_word*)t0)[2],t5);
t7=C_u_i_cdr(t6);
if(C_truep(C_u_i_char_lessp(t7,((C_word*)t0)[3]))){
t8=C_a_i_fixnum_plus(&a,2,t5,C_fix(1));
if(C_truep(C_fixnum_lessp(t8,t3))){
/* irregex-core.scm:3775: lp */
t10=t1;
t11=t8;
t12=t3;
t1=t10;
t2=t11;
t3=t12;
goto loop;}
else{
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
if(C_truep(C_i_char_lessp(((C_word*)t0)[3],C_u_i_car(t6)))){
if(C_truep(C_fixnum_lessp(t2,t5))){
/* irregex-core.scm:3777: lp */
t10=t1;
t11=t2;
t12=t5;
t1=t10;
t2=t11;
t3=t12;
goto loop;}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}

/* chicken.irregex#char-ranges-union in k18928 in k7767 in k7542 in k7539 */
static C_word C_fcall f_27056(C_word *a,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;{}
t3=C_i_car(t1);
t4=C_i_car(t2);
t5=C_i_char_less_or_equal_p(t3,t4);
t6=(C_truep(t5)?C_u_i_car(t1):C_u_i_car(t2));
if(C_truep(C_i_char_greater_or_equal_p(C_u_i_cdr(t1),C_u_i_cdr(t2)))){
t7=C_u_i_cdr(t1);
return(C_a_i_cons(&a,2,t6,t7));}
else{
t7=C_u_i_cdr(t2);
return(C_a_i_cons(&a,2,t6,t7));}}

/* chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_27092,c,av);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27100,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3785: scheme#vector->list */
t5=*((C_word*)lf[163]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27100(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_27100,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27104,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3786: scheme#vector->list */
t3=*((C_word*)lf[163]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27104(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_27104,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27106,a[2]=t3,a[3]=((C_word)li330),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_27106(t5,((C_word*)t0)[2],((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* union-range in k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27106(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,4)))){
C_save_and_reclaim_args((void *)trf_27106,5,t0,t1,t2,t3,t4);}
a=C_alloc(19);
if(C_truep(C_i_nullp(t2))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27120,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27124,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27128,a[2]=t6,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3789: ##sys#fast-reverse */
t8=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
if(C_truep(C_i_nullp(t3))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27141,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27145,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27149,a[2]=t6,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3790: ##sys#fast-reverse */
t8=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t5=C_i_car(t2);
t6=C_i_car(t3);
t7=C_i_cdr(t5);
t8=C_fix(C_character_code(t7));
t9=C_a_i_fixnum_plus(&a,2,t8,C_fix(1));
t10=C_i_car(t6);
t11=C_fix(C_character_code(t10));
if(C_truep(C_i_integer_lessp(t9,t11))){
t12=C_u_i_cdr(t2);
t13=C_a_i_cons(&a,2,t5,t4);
/* irregex-core.scm:3798: union-range */
t22=t1;
t23=t12;
t24=t3;
t25=t13;
t1=t22;
t2=t23;
t3=t24;
t4=t25;
goto loop;}
else{
t12=C_u_i_car(t5);
t13=C_fix(C_character_code(t12));
t14=C_u_i_cdr(t6);
t15=C_fix(C_character_code(t14));
t16=C_a_i_fixnum_plus(&a,2,t15,C_fix(1));
if(C_truep(C_i_integer_greaterp(t13,t16))){
t17=C_u_i_cdr(t3);
t18=C_a_i_cons(&a,2,t6,t4);
/* irregex-core.scm:3800: union-range */
t22=t1;
t23=t17;
t24=t2;
t25=t18;
t1=t22;
t2=t23;
t3=t24;
t4=t25;
goto loop;}
else{
if(C_truep(C_i_char_greater_or_equal_p(C_u_i_cdr(t5),C_u_i_car(t6)))){
t17=(
/* irregex-core.scm:3802: char-ranges-union */
  f_27056(C_a_i(&a,6),t5,t6)
);
t18=C_u_i_cdr(t2);
t19=C_a_i_cons(&a,2,t17,t18);
/* irregex-core.scm:3802: union-range */
t22=t1;
t23=t19;
t24=C_u_i_cdr(t3);
t25=t4;
t1=t22;
t2=t23;
t3=t24;
t4=t25;
goto loop;}
else{
t17=C_u_i_cdr(t2);
t18=(
/* irregex-core.scm:3806: char-ranges-union */
  f_27056(C_a_i(&a,6),t5,t6)
);
t19=C_u_i_cdr(t3);
t20=C_a_i_cons(&a,2,t18,t19);
/* irregex-core.scm:3805: union-range */
t22=t1;
t23=t17;
t24=t20;
t25=t4;
t1=t22;
t2=t23;
t3=t24;
t4=t25;
goto loop;}}}}}}

/* k27118 in union-range in k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27120(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27120,c,av);}
/* irregex-core.scm:3789: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27122 in union-range in k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27124,c,av);}
/* irregex-core.scm:3789: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27126 in union-range in k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27128(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27128,c,av);}
/* irregex-core.scm:3789: scheme#append */
t2=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k27139 in union-range in k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27141,c,av);}
/* irregex-core.scm:3790: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27143 in union-range in k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27145(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27145,c,av);}
/* irregex-core.scm:3790: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27147 in union-range in k27102 in k27098 in chicken.irregex#cset-union in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27149,c,av);}
/* irregex-core.scm:3790: scheme#append */
t2=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27287(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_27287,3,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27295,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3818: scheme#vector->list */
t5=*((C_word*)lf[163]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_27295,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27299,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3819: scheme#vector->list */
t3=*((C_word*)lf[163]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27299(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_27299,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27301,a[2]=t3,a[3]=((C_word)li332),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_27301(t5,((C_word*)t0)[2],((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* diff in k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27301(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,0,4)))){
C_save_and_reclaim_args((void *)trf_27301,5,t0,t1,t2,t3,t4);}
a=C_alloc(17);
if(C_truep(C_i_nullp(t2))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27315,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3821: ##sys#fast-reverse */
t6=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
if(C_truep(C_i_nullp(t3))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27328,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27332,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3822: ##sys#fast-reverse */
t7=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=C_i_car(t2);
t6=C_i_car(t3);
t7=C_i_cdr(t5);
t8=C_i_car(t6);
if(C_truep(C_i_char_lessp(t7,t8))){
t9=C_u_i_cdr(t2);
t10=C_a_i_cons(&a,2,t5,t4);
/* irregex-core.scm:3828: diff */
t18=t1;
t19=t9;
t20=t3;
t21=t10;
t1=t18;
t2=t19;
t3=t20;
t4=t21;
goto loop;}
else{
if(C_truep(C_i_char_greaterp(C_u_i_car(t5),C_u_i_cdr(t6)))){
/* irregex-core.scm:3830: diff */
t18=t1;
t19=t2;
t20=C_u_i_cdr(t3);
t21=t4;
t1=t18;
t2=t19;
t3=t20;
t4=t21;
goto loop;}
else{
t9=C_i_char_less_or_equal_p(C_u_i_car(t6),C_u_i_car(t5));
t10=(C_truep(t9)?C_i_char_greater_or_equal_p(C_u_i_cdr(t6),C_u_i_cdr(t5)):C_SCHEME_FALSE);
if(C_truep(t10)){
/* irregex-core.scm:3833: diff */
t18=t1;
t19=C_u_i_cdr(t2);
t20=t3;
t21=t4;
t1=t18;
t2=t19;
t3=t20;
t4=t21;
goto loop;}
else{
t11=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_27378,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,a[6]=t2,a[7]=t5,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_i_char_lessp(C_u_i_car(t5),C_u_i_car(t6)))){
t12=C_u_i_car(t5);
t13=C_u_i_car(t6);
t14=C_fix(C_character_code(t13));
t15=C_a_i_fixnum_difference(&a,2,t14,C_fix(1));
t16=C_make_character(C_unfix(t15));
t17=t11;
f_27378(t17,C_a_i_cons(&a,2,t12,t16));}
else{
t12=t11;
f_27378(t12,C_SCHEME_FALSE);}}}}}}}

/* k27313 in diff in k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27315,c,av);}
/* irregex-core.scm:3821: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27326 in diff in k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27328,c,av);}
/* irregex-core.scm:3822: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27330 in diff in k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27332(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27332,c,av);}
/* irregex-core.scm:3822: scheme#append */
t2=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k27376 in diff in k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27378(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,2)))){
C_save_and_reclaim_args((void *)trf_27378,2,t0,t1);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_27381,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_char_greaterp(C_u_i_cdr(((C_word*)t0)[7]),C_u_i_cdr(((C_word*)t0)[8])))){
t3=C_u_i_cdr(((C_word*)t0)[8]);
t4=C_fix(C_character_code(t3));
t5=C_a_i_fixnum_plus(&a,2,t4,C_fix(1));
t6=C_make_character(C_unfix(t5));
t7=C_u_i_cdr(((C_word*)t0)[7]);
t8=t2;
f_27381(t8,C_a_i_cons(&a,2,t6,t7));}
else{
t3=t2;
f_27381(t3,C_SCHEME_FALSE);}}

/* k27379 in k27376 in diff in k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27381(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_27381,2,t0,t1);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27388,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t1)){
t3=C_u_i_cdr(((C_word*)t0)[7]);
t4=t2;
f_27388(t4,C_a_i_cons(&a,2,t1,t3));}
else{
t3=t2;
f_27388(t3,C_u_i_cdr(((C_word*)t0)[7]));}}

/* k27386 in k27379 in k27376 in diff in k27297 in k27293 in chicken.irregex#cset-difference in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27388(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_27388,2,t0,t1);}
a=C_alloc(3);
if(C_truep(((C_word*)t0)[2])){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* irregex-core.scm:3840: diff */
t3=((C_word*)((C_word*)t0)[4])[1];
f_27301(t3,((C_word*)t0)[5],t1,((C_word*)t0)[6],t2);}
else{
/* irregex-core.scm:3840: diff */
t2=((C_word*)((C_word*)t0)[4])[1];
f_27301(t2,((C_word*)t0)[5],t1,((C_word*)t0)[6],((C_word*)t0)[3]);}}

/* chicken.irregex#cset-intersection in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_27483,c,av);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27491,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3851: scheme#vector->list */
t5=*((C_word*)lf[163]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k27489 in chicken.irregex#cset-intersection in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27491(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_27491,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27495,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3852: scheme#vector->list */
t3=*((C_word*)lf[163]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k27493 in k27489 in chicken.irregex#cset-intersection in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27495(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_27495,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27497,a[2]=t3,a[3]=((C_word)li334),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_27497(t5,((C_word*)t0)[2],((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* intersect in k27493 in k27489 in chicken.irregex#cset-intersection in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27497(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_27497,5,t0,t1,t2,t3,t4);}
a=C_alloc(6);
t5=C_i_nullp(t2);
t6=(C_truep(t5)?t5:C_i_nullp(t3));
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27514,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3855: ##sys#fast-reverse */
t8=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=C_i_car(t2);
t8=C_i_car(t3);
t9=C_i_cdr(t7);
t10=C_i_car(t8);
if(C_truep(C_i_char_lessp(t9,t10))){
/* irregex-core.scm:3860: intersect */
t25=t1;
t26=C_u_i_cdr(t2);
t27=t3;
t28=t4;
t1=t25;
t2=t26;
t3=t27;
t4=t28;
goto loop;}
else{
if(C_truep(C_i_char_greaterp(C_u_i_car(t7),C_u_i_cdr(t8)))){
/* irregex-core.scm:3862: intersect */
t25=t1;
t26=t2;
t27=C_u_i_cdr(t3);
t28=t4;
t1=t25;
t2=t26;
t3=t27;
t4=t28;
goto loop;}
else{
t11=C_u_i_car(t8);
t12=C_u_i_car(t7);
t13=C_i_char_lessp(t11,t12);
t14=(C_truep(t13)?t12:t11);
t15=C_u_i_cdr(t7);
t16=C_u_i_cdr(t8);
t17=C_i_char_lessp(t15,t16);
t18=(C_truep(t17)?C_a_i_cons(&a,2,t14,t15):C_a_i_cons(&a,2,t14,t16));
t19=C_i_char_greaterp(C_u_i_cdr(t7),C_u_i_cdr(t18));
t20=(C_truep(t19)?t2:C_u_i_cdr(t2));
t21=C_i_char_greaterp(C_u_i_cdr(t8),C_u_i_cdr(t18));
t22=(C_truep(t21)?t3:C_u_i_cdr(t3));
t23=C_a_i_cons(&a,2,t18,t4);
/* irregex-core.scm:3866: intersect */
t25=t1;
t26=t20;
t27=t22;
t28=t23;
t1=t25;
t2=t26;
t3=t27;
t4=t28;
goto loop;}}}}

/* k27512 in intersect in k27493 in k27489 in chicken.irregex#cset-intersection in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27514(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27514,c,av);}
/* irregex-core.scm:3855: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.irregex#cset-complement in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27609(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_27609,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27617,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3873: sre->cset */
f_26504(t3,lf[53],C_SCHEME_END_OF_LIST);}

/* k27615 in chicken.irregex#cset-complement in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27617,c,av);}
/* irregex-core.scm:3873: cset-difference */
f_27287(((C_word*)t0)[2],t1,((C_word*)t0)[3]);}

/* chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27619(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_27619,2,t1,t2);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27627,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3877: scheme#vector->list */
t4=*((C_word*)lf[163]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27627(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_27627,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27629,a[2]=t3,a[3]=((C_word)li337),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_27629(t5,((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST);}

/* lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27629(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_27629,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27643,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3878: ##sys#fast-reverse */
t5=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27649,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t5=C_i_caar(t2);
if(C_truep(C_u_i_char_alphabeticp(t5))){
t6=C_u_i_car(t2);
t7=t4;
f_27649(t7,C_u_i_char_alphabeticp(C_u_i_cdr(t6)));}
else{
t6=t4;
f_27649(t6,C_SCHEME_FALSE);}}}

/* k27641 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27643,c,av);}
/* irregex-core.scm:3878: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27649(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(22,0,2)))){
C_save_and_reclaim_args((void *)trf_27649,2,t0,t1);}
a=C_alloc(22);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27658,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27662,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27666,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27670,a[2]=((C_word*)t0)[2],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27694,a[2]=((C_word*)t0)[2],a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27704,a[2]=t7,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3884: ##sys#fast-reverse */
t9=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27713,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27717,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27721,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27725,a[2]=((C_word*)t0)[2],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27735,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:3889: ##sys#fast-reverse */
t8=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}

/* k27656 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27658(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27658,c,av);}
/* irregex-core.scm:3881: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_27629(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k27660 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27662(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27662,c,av);}
/* irregex-core.scm:3882: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27664 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27666(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27666,c,av);}
/* irregex-core.scm:3883: scheme#vector->list */
t2=*((C_word*)lf[163]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27668 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27670(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_27670,c,av);}
a=C_alloc(5);
t2=C_i_caar(((C_word*)t0)[2]);
t3=C_u_i_char_upper_casep(t2);
t4=(C_truep(t3)?C_u_i_char_downcase(t2):C_u_i_char_upcase(t2));
t5=C_i_cdar(((C_word*)t0)[2]);
t6=C_u_i_char_upper_casep(t5);
t7=(C_truep(t6)?C_u_i_char_downcase(t5):C_u_i_char_upcase(t5));
t8=C_a_i_cons(&a,2,t4,t7);
t9=C_a_i_vector1(&a,1,t8);
/* irregex-core.scm:3884: cset-union */
t10=lf[162];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t10;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=t9;
f_27092(4,av2);}}

/* k27692 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(2,c,3)))){
C_save_and_reclaim((void *)f_27694,c,av);}
a=C_alloc(2);
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_vector1(&a,1,t2);
/* irregex-core.scm:3884: cset-union */
t4=lf[162];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=t3;
f_27092(4,av2);}}

/* k27702 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27704(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27704,c,av);}
/* irregex-core.scm:3884: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27711 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27713(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27713,c,av);}
/* irregex-core.scm:3888: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_27629(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k27715 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27717,c,av);}
/* irregex-core.scm:3888: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27719 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27721,c,av);}
/* irregex-core.scm:3888: scheme#vector->list */
t2=*((C_word*)lf[163]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27723 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27725(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(2,c,3)))){
C_save_and_reclaim((void *)f_27725,c,av);}
a=C_alloc(2);
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_vector1(&a,1,t2);
/* irregex-core.scm:3889: cset-union */
t4=lf[162];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=t3;
f_27092(4,av2);}}

/* k27733 in k27647 in lp in k27625 in chicken.irregex#cset-case-insensitive in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27735,c,av);}
/* irregex-core.scm:3889: scheme#list->vector */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27750(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word *a;
if(c<6) C_bad_min_argc_2(c,6,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-6)*C_SIZEOF_PAIR +8,c,4)))){
C_save_and_reclaim((void*)f_27750,c,av);}
a=C_alloc((c-6)*C_SIZEOF_PAIR+8);
t6=C_build_rest(&a,c,6,av);
C_word t7;
C_word t8;
C_word t9;
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_27754,a[2]=t6,a[3]=t5,a[4]=t3,a[5]=t1,a[6]=t4,a[7]=t2,tmp=(C_word)a,a+=8,tmp);
t8=C_i_stringp(t5);
if(C_truep(C_i_not(t8))){
/* irregex-core.scm:3896: chicken.base#error */
t9=*((C_word*)lf[30]+1);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t7;
av2[2]=lf[411];
av2[3]=lf[414];
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t9=t7;{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_SCHEME_UNDEFINED;
f_27754(2,av2);}}}

/* k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27754(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_27754,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27757,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:3897: irregex */
t3=*((C_word*)lf[217]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_27757,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_27760,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3898: irregex-new-matches */
f_7628(t2,t1);}

/* k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_27760,c,av);}
a=C_alloc(13);
t2=C_i_pairp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_u_i_car(((C_word*)t0)[2]):C_SCHEME_FALSE);
t4=(C_truep(t3)?t3:(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27951,a[2]=((C_word)li339),tmp=(C_word)a,a+=3,tmp));
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_27769,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[2],tmp=(C_word)a,a+=10,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t6=C_i_pairp(C_u_i_cdr(((C_word*)t0)[2]));
t7=t5;
f_27769(t7,(C_truep(t6)?C_i_cadr(((C_word*)t0)[2]):C_fix(0)));}
else{
t6=t5;
f_27769(t6,C_fix(0));}}

/* k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27769(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_27769,2,t0,t1);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_27772,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[9]))){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[9])))){
t3=C_i_cddr(((C_word*)t0)[9]);
t4=C_i_pairp(t3);
t5=t2;
f_27772(t5,(C_truep(t4)?C_i_caddr(((C_word*)t0)[9]):C_i_string_length(((C_word*)t0)[2])));}
else{
t3=t2;
f_27772(t3,C_i_string_length(((C_word*)t0)[2]));}}
else{
t3=t2;
f_27772(t3,C_i_string_length(((C_word*)t0)[2]));}}

/* k27770 in k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27772(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(25,0,4)))){
C_save_and_reclaim_args((void *)trf_27772,2,t0,t1);}
a=C_alloc(25);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],t1);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_27781,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],a[8]=t3,a[9]=((C_word*)t0)[8],a[10]=t2,a[11]=((C_word*)t0)[3],a[12]=((C_word*)t0)[9],tmp=(C_word)a,a+=13,tmp);
if(C_truep(C_i_integerp(((C_word*)t0)[3]))){
t5=C_i_exactp(((C_word*)t0)[3]);
if(C_truep(C_i_not(t5))){
/* irregex-core.scm:3907: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t4;
av2[2]=lf[411];
av2[3]=lf[413];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t6=t4;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_27781(2,av2);}}}
else{
/* irregex-core.scm:3907: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[411];
av2[3]=lf[413];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k27779 in k27770 in k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_27781,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_27784,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
if(C_truep(C_i_integerp(((C_word*)t0)[3]))){
t3=C_i_exactp(((C_word*)t0)[3]);
if(C_truep(C_i_not(t3))){
/* irregex-core.scm:3909: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[411];
av2[3]=lf[412];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_27784(2,av2);}}}
else{
/* irregex-core.scm:3909: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[411];
av2[3]=lf[412];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k27782 in k27779 in k27770 in k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,6)))){
C_save_and_reclaim((void *)f_27784,c,av);}
a=C_alloc(13);
t2=lf[285];
t3=C_i_setslot(((C_word*)t0)[2],C_fix(3),lf[285]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_27792,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t5,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word)li340),tmp=(C_word)a,a+=11,tmp));
t7=((C_word*)t5)[1];
f_27792(t7,((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[11],((C_word*)t0)[12]);}

/* lp in k27782 in k27779 in k27770 in k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_27792(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,7)))){
C_save_and_reclaim_args((void *)trf_27792,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(12);
if(C_truep(C_fixnum_greater_or_equal_p(t4,((C_word*)t0)[2]))){
/* irregex-core.scm:3913: finish */
t6=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=t3;
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_27805,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t3,a[5]=t5,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[8],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3914: irregex-search/matches */
f_19065(t6,((C_word*)t0)[4],lf[285],((C_word*)t0)[9],t2,t4,((C_word*)t0)[7]);}}

/* k27803 in lp in k27782 in k27779 in k27770 in k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_27805,c,av);}
a=C_alloc(11);
if(C_truep(C_i_not(t1))){
/* irregex-core.scm:3922: finish */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_slot(t1,C_fix(1));
t3=C_slot(t2,C_fix(1));
t4=C_slot(t1,C_fix(1));
t5=C_fixnum_times(C_fix(0),C_fix(4));
t6=C_slot(t4,C_fixnum_plus(C_fix(3),t5));
t7=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_27840,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t6,a[6]=t3,a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3925: kons */
t8=((C_word*)t0)[11];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}}

/* k27838 in k27803 in lp in k27782 in k27779 in k27770 in k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_27840,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_27843,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:3926: irregex-reset-matches! */
f_7651(t2,((C_word*)t0)[10]);}

/* k27841 in k27838 in k27803 in lp in k27782 in k27779 in k27770 in k27767 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_27843,c,av);}
a=C_alloc(9);
t2=C_slot(((C_word*)t0)[2],C_fix(4));
t3=C_fixnum_and(t2,C_fix(2));
t4=C_eqp(C_fix(2),t3);
if(C_truep(t4)){
/* irregex-core.scm:3929: finish */
t5=((C_word*)t0)[3];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=C_eqp(((C_word*)t0)[5],((C_word*)t0)[7]);
if(C_truep(t5)){
t6=C_a_i_list3(&a,3,((C_word*)t0)[8],((C_word*)t0)[5],((C_word*)t0)[9]);
/* irregex-core.scm:3932: lp */
t7=((C_word*)((C_word*)t0)[10])[1];
f_27792(t7,((C_word*)t0)[4],t6,((C_word*)t0)[5],C_fixnum_plus(((C_word*)t0)[5],C_fix(1)),((C_word*)t0)[6]);}
else{
t6=C_a_i_list3(&a,3,((C_word*)t0)[8],((C_word*)t0)[5],((C_word*)t0)[9]);
/* irregex-core.scm:3934: lp */
t7=((C_word*)((C_word*)t0)[10])[1];
f_27792(t7,((C_word*)t0)[4],t6,((C_word*)t0)[5],((C_word*)t0)[5],((C_word*)t0)[6]);}}}

/* f_27951 in k27758 in k27755 in k27752 in chicken.irregex#irregex-fold/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_27951,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.irregex#irregex-fold in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27968(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_27968,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27972,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=C_i_closurep(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:3937: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[411];
av2[3]=lf[416];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_27972(2,av2);}}}

/* k27970 in chicken.irregex#irregex-fold in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_27972,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27973,a[2]=((C_word*)t0)[2],a[3]=((C_word)li342),tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[410];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
av2[5]=((C_word*)t0)[5];
C_apply(6,av2);}}

/* kons2 in k27970 in chicken.irregex#irregex-fold in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27973(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_27973,c,av);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27981,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3938: irregex-copy-matches */
f_7660(t5,t3);}

/* k27979 in kons2 in k27970 in chicken.irregex#irregex-fold in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_27981,c,av);}
/* irregex-core.scm:3938: kons */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_27996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word *a;
if(c<7) C_bad_min_argc_2(c,7,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-7)*C_SIZEOF_PAIR +8,c,2)))){
C_save_and_reclaim((void*)f_27996,c,av);}
a=C_alloc((c-7)*C_SIZEOF_PAIR+8);
t7=C_build_rest(&a,c,7,av);
C_word t8;
C_word t9;
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_28000,a[2]=t7,a[3]=t6,a[4]=t5,a[5]=t3,a[6]=t1,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3942: irregex */
t9=*((C_word*)lf[217]+1);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}

/* k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28000(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_28000,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_28003,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3943: irregex-new-matches */
f_7628(t2,t1);}

/* k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28003(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,5)))){
C_save_and_reclaim((void *)f_28003,c,av);}
a=C_alloc(13);
t2=C_i_pairp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_u_i_car(((C_word*)t0)[2]):C_SCHEME_FALSE);
t4=(C_truep(t3)?t3:(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28171,a[2]=((C_word)li344),tmp=(C_word)a,a+=3,tmp));
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_28012,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=t4,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t6=C_i_pairp(((C_word*)t0)[2]);
t7=(C_truep(t6)?C_i_pairp(C_u_i_cdr(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t7)){
t8=t5;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_i_cadr(((C_word*)t0)[2]);
f_28012(2,av2);}}
else{
/* irregex-core.scm:3945: g5555 */
t8=C_i_vector_ref(((C_word*)t0)[4],C_fix(2));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}

/* k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_28012,c,av);}
a=C_alloc(15);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_28018,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t2,a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[2],a[10]=t1,a[11]=((C_word*)t0)[9],tmp=(C_word)a,a+=12,tmp);
if(C_truep(C_i_not(C_i_integerp(t1)))){
/* irregex-core.scm:3949: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[418];
av2[3]=lf[419];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_28018(2,av2);}}}

/* k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28018(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,5)))){
C_save_and_reclaim((void *)f_28018,c,av);}
a=C_alloc(12);
t2=C_i_setslot(((C_word*)t0)[2],C_fix(3),((C_word*)t0)[3]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_28026,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=t4,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word)li345),tmp=(C_word)a,a+=10,tmp));
t6=((C_word*)t4)[1];
f_28026(t6,((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11]);}

/* lp in k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28026(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,7)))){
C_save_and_reclaim_args((void *)trf_28026,5,t0,t1,t2,t3,t4);}
a=C_alloc(12);
if(C_truep(C_i_not(t2))){
/* irregex-core.scm:3953: finish */
t5=((C_word*)t0)[2];{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_28039,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[6],a[11]=((C_word*)t0)[7],tmp=(C_word)a,a+=12,tmp);
/* irregex-core.scm:3954: irregex-search/matches */
f_19065(t5,((C_word*)t0)[5],((C_word*)t0)[3],((C_word*)t0)[8],t2,t3,((C_word*)t0)[6]);}}

/* k28037 in lp in k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_28039,c,av);}
a=C_alloc(9);
if(C_truep(C_i_not(t1))){
/* irregex-core.scm:3956: finish */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=C_slot(t1,C_fix(1));
t3=C_slot(t2,C_fix(2));
t4=C_slot(t1,C_fix(1));
t5=C_fixnum_times(C_fix(0),C_fix(4));
t6=C_slot(t4,C_fixnum_plus(C_fix(3),t5));
t7=C_eqp(t3,((C_word*)t0)[4]);
t8=(C_truep(t7)?C_eqp(t6,((C_word*)t0)[5]):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=C_i_vector_ref(((C_word*)t0)[7],C_fix(3));
t10=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_28113,a[2]=t6,a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[6],a[7]=t3,tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:3960: g5570 */
t11=t9;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t9=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_28116,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t3,a[6]=t6,a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3964: kons */
t10=((C_word*)t0)[11];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t10;
av2[1]=t9;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=t1;
av2[5]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t10+1)))(6,av2);}}}}

/* k28087 in k28111 in k28037 in lp in k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28089(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28089,c,av);}
a=C_alloc(6);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28099,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3962: g5575 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k28097 in k28087 in k28111 in k28037 in lp in k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_28099,c,av);}
/* irregex-core.scm:3962: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_28026(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5]);}

/* k28111 in k28037 in lp in k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28113(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_28113,c,av);}
a=C_alloc(6);
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[2],t1))){
t2=C_i_vector_ref(((C_word*)t0)[3],C_fix(0));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28089,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:3961: g5573 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* irregex-core.scm:3963: lp */
t2=((C_word*)((C_word*)t0)[4])[1];
f_28026(t2,((C_word*)t0)[5],((C_word*)t0)[7],C_fixnum_plus(((C_word*)t0)[2],C_fix(1)),((C_word*)t0)[6]);}}

/* k28114 in k28037 in lp in k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28116(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_28116,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_28119,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:3965: irregex-reset-matches! */
f_7651(t2,((C_word*)t0)[8]);}

/* k28117 in k28114 in k28037 in lp in k28016 in k28010 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_28119,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(4));
t3=C_fixnum_and(t2,C_fix(2));
t4=C_eqp(C_fix(2),t3);
if(C_truep(t4)){
/* irregex-core.scm:3967: finish */
t5=((C_word*)t0)[3];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
/* irregex-core.scm:3968: lp */
t5=((C_word*)((C_word*)t0)[8])[1];
f_28026(t5,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}}

/* f_28171 in k28001 in k27998 in chicken.irregex#irregex-fold/chunked/fast in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28171,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* chicken.irregex#irregex-fold/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_28178,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28182,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=C_i_closurep(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:3971: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[418];
av2[3]=lf[421];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_28182(2,av2);}}}

/* k28180 in chicken.irregex#irregex-fold/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,6)))){
C_save_and_reclaim((void *)f_28182,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28183,a[2]=((C_word*)t0)[2],a[3]=((C_word)li347),tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[417];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
av2[5]=((C_word*)t0)[5];
C_apply(6,av2);}}

/* kons2 in k28180 in chicken.irregex#irregex-fold/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28183(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_28183,c,av);}
a=C_alloc(7);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_28191,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:3972: irregex-copy-matches */
f_7660(t6,t4);}

/* k28189 in kons2 in k28180 in chicken.irregex#irregex-fold/chunked in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_28191,c,av);}
/* irregex-core.scm:3972: kons */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=t1;
av2[5]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* chicken.irregex#irregex-replace in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28206(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_28206,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28210,a[2]=t1,a[3]=t3,a[4]=t4,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_i_stringp(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:3976: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[424];
av2[3]=lf[425];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_28210(2,av2);}}}

/* k28208 in chicken.irregex#irregex-replace in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28210(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_28210,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28213,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3977: irregex-search */
t3=*((C_word*)lf[286]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k28211 in k28208 in chicken.irregex#irregex-replace in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28213(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_28213,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28227,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=C_slot(t1,C_fix(1));
t4=C_fixnum_times(C_fix(0),C_fix(4));
/* irregex-core.scm:3980: scheme#substring */
t5=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=C_slot(t3,C_fixnum_plus(C_fix(3),t4));
av2[4]=C_block_size(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k28225 in k28211 in k28208 in chicken.irregex#irregex-replace in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_28227,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28231,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28235,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3981: irregex-apply-match */
f_28378(t3,((C_word*)t0)[3],((C_word*)t0)[5]);}

/* k28229 in k28225 in k28211 in k28208 in chicken.irregex#irregex-replace in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28231(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_28231,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* irregex-core.scm:3979: string-cat-reverse */
f_9114(((C_word*)t0)[3],t2);}

/* k28233 in k28225 in k28211 in k28208 in chicken.irregex#irregex-replace in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28235(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_28235,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28243,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_slot(((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:3982: scheme#substring */
t4=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_fix(0);
av2[4]=C_slot(t3,C_fix(1));
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k28241 in k28233 in k28225 in k28211 in k28208 in chicken.irregex#irregex-replace in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28243(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_28243,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* irregex-core.scm:3981: scheme#append */
t3=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28285(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_28285,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28289,a[2]=t4,a[3]=t3,a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_i_stringp(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:3987: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[427];
av2[3]=lf[428];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_28289(2,av2);}}}

/* k28287 in chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28289(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,6)))){
C_save_and_reclaim((void *)f_28289,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28294,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li350),tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28345,a[2]=((C_word*)t0)[3],a[3]=((C_word)li351),tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3988: irregex-fold/fast */
t4=lf[410];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=t2;
av2[4]=C_SCHEME_END_OF_LIST;
av2[5]=((C_word*)t0)[3];
av2[6]=t3;
f_27750(7,av2);}}

/* a28293 in k28287 in chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_28294,c,av);}
a=C_alloc(7);
t5=C_slot(t3,C_fix(1));
t6=C_slot(t5,C_fix(1));
if(C_truep(C_fixnum_greater_or_equal_p(t2,t6))){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28328,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:3993: irregex-apply-match */
f_28378(t7,t3,((C_word*)t0)[2]);}
else{
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_28335,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:3994: irregex-apply-match */
f_28378(t7,t3,((C_word*)t0)[2]);}}

/* k28326 in a28293 in k28287 in chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_28328,c,av);}
/* irregex-core.scm:3993: scheme#append */
t2=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k28333 in a28293 in k28287 in chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_28335,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28343,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:3995: scheme#substring */
t3=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k28341 in k28333 in a28293 in k28287 in chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28343(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_28343,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:3994: scheme#append */
t3=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a28344 in k28287 in chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28345(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_28345,c,av);}
a=C_alloc(4);
t4=C_i_string_length(((C_word*)t0)[2]);
if(C_truep(C_fixnum_greater_or_equal_p(t2,t4))){
/* irregex-core.scm:4000: string-cat-reverse */
f_9114(t1,t3);}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28366,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:4002: scheme#substring */
t6=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}

/* k28364 in a28344 in k28287 in chicken.irregex#irregex-replace/all in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_28366,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:4000: string-cat-reverse */
f_9114(((C_word*)t0)[3],t2);}

/* chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28378(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_28378,3,t1,t2,t3);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28384,a[2]=t5,a[3]=t2,a[4]=((C_word)li354),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_28384(t7,t1,t3,C_SCHEME_END_OF_LIST);}

/* lp in chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28384(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_28384,4,t0,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
if(C_truep(C_i_integerp(t4))){
t5=C_u_i_cdr(t2);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28411,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:4011: irregex-match-substring */
t7=*((C_word*)lf[40]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=C_u_i_car(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
if(C_truep(C_i_closurep(C_u_i_car(t2)))){
t5=C_u_i_cdr(t2);
t6=C_u_i_car(t2);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28436,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:4013: g5631 */
t8=t6;{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
if(C_truep(C_i_symbolp(C_u_i_car(t2)))){
t5=C_u_i_car(t2);
t6=C_eqp(t5,lf[430]);
if(C_truep(t6)){
t7=C_u_i_cdr(t2);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28462,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t7,tmp=(C_word)a,a+=6,tmp);
t9=C_slot(((C_word*)t0)[3],C_fix(1));
t10=C_slot(t9,C_fix(0));
t11=C_i_car(t10);
t12=C_slot(((C_word*)t0)[3],C_fix(1));
/* irregex-core.scm:4018: scheme#substring */
t13=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t13;
av2[1]=t8;
av2[2]=t11;
av2[3]=C_fix(0);
av2[4]=C_slot(t12,C_fix(1));
((C_proc)(void*)(*((C_word*)t13+1)))(5,av2);}}
else{
t7=C_eqp(t5,lf[431]);
if(C_truep(t7)){
t8=C_slot(((C_word*)t0)[3],C_fix(1));
t9=C_slot(t8,C_fix(0));
t10=C_i_car(t9);
t11=C_u_i_cdr(t2);
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28526,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t11,tmp=(C_word)a,a+=6,tmp);
t13=C_slot(((C_word*)t0)[3],C_fix(1));
t14=C_fixnum_times(C_fix(0),C_fix(4));
/* irregex-core.scm:4025: scheme#substring */
t15=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t15;
av2[1]=t12;
av2[2]=t10;
av2[3]=C_slot(t13,C_fixnum_plus(C_fix(3),t14));
av2[4]=C_i_string_length(t10);
((C_proc)(void*)(*((C_word*)t15+1)))(5,av2);}}
else{
t8=C_u_i_car(t2);
t9=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_28588,a[2]=t8,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t3,a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:4031: irregex-match-names */
t10=*((C_word*)lf[19]+1);{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}}}
else{
t5=C_u_i_cdr(t2);
t6=C_u_i_car(t2);
t7=C_a_i_cons(&a,2,t6,t3);
/* irregex-core.scm:4036: lp */
t16=t1;
t17=t5;
t18=t7;
t1=t16;
t2=t17;
t3=t18;
goto loop;}}}}}

/* k28409 in lp in chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28411(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_28411,c,av);}
a=C_alloc(3);
t2=(C_truep(t1)?C_a_i_cons(&a,2,t1,((C_word*)t0)[2]):C_a_i_cons(&a,2,lf[429],((C_word*)t0)[2]));
/* irregex-core.scm:4010: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_28384(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k28434 in lp in chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28436(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_28436,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:4013: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_28384(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k28460 in lp in chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_28462,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:4017: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_28384(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k28524 in lp in chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_28526,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:4024: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_28384(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* g5658 in k28586 in lp in chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28558(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_28558,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_i_cdr(t2);
t4=C_i_cdr(((C_word*)t0)[2]);
t5=C_a_i_cons(&a,2,t3,t4);
/* irregex-core.scm:4032: lp */
t6=((C_word*)((C_word*)t0)[3])[1];
f_28384(t6,t1,t5,((C_word*)t0)[4]);}

/* k28586 in lp in chicken.irregex#irregex-apply-match in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28588(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_28588,c,av);}
a=C_alloc(6);
t2=C_i_assq(((C_word*)t0)[2],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28558,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word)li353),tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:4030: g5658 */
t4=t3;
f_28558(t4,((C_word*)t0)[6],t2);}
else{
/* irregex-core.scm:4034: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[6];
av2[2]=lf[432];
av2[3]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* chicken.irregex#irregex-extract in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28609(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_28609,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28613,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=C_i_stringp(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:4039: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[434];
av2[3]=lf[435];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_28613(2,av2);}}}

/* k28611 in chicken.irregex#irregex-extract in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,8)))){
C_save_and_reclaim((void *)f_28613,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28618,a[2]=((C_word)li356),tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28628,a[2]=((C_word)li357),tmp=(C_word)a,a+=3,tmp);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[410];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
av2[5]=C_SCHEME_END_OF_LIST;
av2[6]=((C_word*)t0)[4];
av2[7]=t3;
av2[8]=((C_word*)t0)[5];
C_apply(9,av2);}}

/* a28617 in k28611 in chicken.irregex#irregex-extract in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28618(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_28618,c,av);}
a=C_alloc(4);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28626,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:4042: irregex-match-substring */
t6=*((C_word*)lf[40]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k28624 in a28617 in k28611 in chicken.irregex#irregex-extract in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_28626,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a28627 in k28611 in chicken.irregex#irregex-extract in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_28628,c,av);}
/* irregex-core.scm:4045: ##sys#fast-reverse */
t4=*((C_word*)lf[69]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_28644,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28648,a[2]=t4,a[3]=t3,a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_i_stringp(t3);
if(C_truep(C_i_not(t6))){
/* irregex-core.scm:4049: chicken.base#error */
t7=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[438];
av2[3]=lf[439];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_28648(2,av2);}}}

/* k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28648(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28648,c,av);}
a=C_alloc(6);
t2=C_i_pairp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_u_i_car(((C_word*)t0)[2]):C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28654,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t5=C_i_pairp(C_u_i_cdr(((C_word*)t0)[2]));
t6=t4;
f_28654(t6,(C_truep(t5)?C_i_cadr(((C_word*)t0)[2]):C_i_string_length(((C_word*)t0)[3])));}
else{
t5=t4;
f_28654(t5,C_i_string_length(((C_word*)t0)[3]));}}

/* k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28654(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,8)))){
C_save_and_reclaim_args((void *)trf_28654,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28659,a[2]=((C_word*)t0)[2],a[3]=((C_word)li359),tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28717,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word)li361),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:4052: irregex-fold/fast */
t4=lf[410];{
C_word av2[9];
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
av2[4]=C_SCHEME_END_OF_LIST;
av2[5]=((C_word*)t0)[2];
av2[6]=t3;
av2[7]=((C_word*)t0)[5];
av2[8]=t1;
f_27750(9,av2);}}

/* a28658 in k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_28659,c,av);}
a=C_alloc(4);
t5=C_slot(t3,C_fix(1));
t6=C_slot(t5,C_fix(1));
t7=C_eqp(t2,t6);
if(C_truep(t7)){
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28673,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t9=C_slot(t3,C_fix(1));
/* irregex-core.scm:4059: scheme#substring */
t10=*((C_word*)lf[46]+1);{
C_word *av2=av;
av2[0]=t10;
av2[1]=t8;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=C_slot(t9,C_fix(1));
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}}

/* k28671 in a28658 in k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28673(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_28673,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a28716 in k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_28717,c,av);}
a=C_alloc(7);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28725,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t5)){
t6=t4;
f_28725(t6,t3);}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28808,a[2]=t4,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:4063: scheme#substring */
t7=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}}

/* k28723 in a28716 in k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28725(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_28725,2,t0,t1);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28727,a[2]=t3,a[3]=((C_word)li360),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_28727(t5,((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);}

/* lp in k28723 in a28716 in k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28727(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_28727,5,t0,t1,t2,t3,t4);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_car(t2);
if(C_truep(C_charp(t5))){
t6=C_u_i_cdr(t2);
t7=(C_truep(t4)?t4:C_i_nullp(t3));
if(C_truep(t7)){
t8=C_u_i_car(t2);
t9=C_a_i_string(&a,1,t8);
t10=C_a_i_cons(&a,2,t9,t3);
/* irregex-core.scm:4069: lp */
t12=t1;
t13=t6;
t14=t10;
t15=C_SCHEME_TRUE;
t1=t12;
t2=t13;
t3=t14;
t4=t15;
goto loop;}
else{
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28768,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t6,tmp=(C_word)a,a+=6,tmp);
t9=C_u_i_car(t2);
t10=C_a_i_string(&a,1,t9);
/* irregex-core.scm:4072: scheme#string-append */
t11=*((C_word*)lf[437]+1);{
C_word av2[4];
av2[0]=t11;
av2[1]=t8;
av2[2]=t10;
av2[3]=C_i_car(t3);
((C_proc)(void*)(*((C_word*)t11+1)))(4,av2);}}}
else{
t6=C_u_i_cdr(t2);
t7=C_u_i_car(t2);
t8=C_a_i_cons(&a,2,t7,t3);
/* irregex-core.scm:4075: lp */
t12=t1;
t13=t6;
t14=t8;
t15=C_SCHEME_FALSE;
t1=t12;
t2=t13;
t3=t14;
t4=t15;
goto loop;}}}

/* k28766 in lp in k28723 in a28716 in k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_28768,c,av);}
a=C_alloc(3);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
/* irregex-core.scm:4069: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_28727(t4,((C_word*)t0)[4],((C_word*)t0)[5],t3,C_SCHEME_TRUE);}

/* k28806 in a28716 in k28652 in k28646 in chicken.irregex#irregex-split in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_28808,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];
f_28725(t2,C_a_i_cons(&a,2,t1,((C_word*)t0)[3]));}

/* chicken.irregex#string-scan-char in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +9,c,3)))){
C_save_and_reclaim((void*)f_28842,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+9);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
t5=C_i_string_length(t2);
t6=C_i_pairp(t4);
t7=(C_truep(t6)?C_get_rest_arg(c,4,av,4,t0):C_fix(0));
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_28855,a[2]=t5,a[3]=t2,a[4]=t3,a[5]=t9,a[6]=((C_word)li363),tmp=(C_word)a,a+=7,tmp));
t11=((C_word*)t9)[1];
f_28855(t11,t1,t7);}

/* scan in chicken.irregex#string-scan-char in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28855(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_28855,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_string_ref(((C_word*)t0)[3],t2);
t5=C_eqp(((C_word*)t0)[4],t4);
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-utils.scm:14: scan */
t8=t1;
t9=t6;
t1=t8;
t2=t9;
goto loop;}}}

/* chicken.irregex#irregex-quote in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28885,c,av);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28893,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28897,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#string->list */
t5=*((C_word*)lf[105]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k28891 in chicken.irregex#irregex-quote in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28893(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_28893,c,av);}
/* ##sys#list->string */
t2=*((C_word*)lf[441]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k28895 in chicken.irregex#irregex-quote in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28897(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_28897,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28899,a[2]=t3,a[3]=((C_word)li365),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_28899(t5,((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST);}

/* loop in k28895 in chicken.irregex#irregex-quote in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_28899(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_28899,4,t0,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
/* irregex-utils.scm:20: ##sys#fast-reverse */
t4=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_28918,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=((C_word*)t0)[2],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* irregex-utils.scm:22: string-scan-char */
t6=lf[54];{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[442];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* k28916 in loop in k28895 in chicken.irregex#irregex-quote in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_28918,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,C_make_character(92),((C_word*)t0)[3]);
t4=C_a_i_cons(&a,2,((C_word*)t0)[4],t3);
/* irregex-utils.scm:23: loop */
t5=((C_word*)((C_word*)t0)[5])[1];
f_28899(t5,((C_word*)t0)[6],t2,t4);}
else{
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[3]);
/* irregex-utils.scm:24: loop */
t4=((C_word*)((C_word*)t0)[5])[1];
f_28899(t4,((C_word*)t0)[6],t2,t3);}}

/* chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_28942,c,av);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[444];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_cdr(t2);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29079,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-utils.scm:42: scheme#make-vector */
t5=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_fix(256);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}}

/* k28957 in k29114 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28959(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_28959,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28966,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* ##sys#list->string */
t3=*((C_word*)lf[441]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_a_i_cons(&a,2,lf[103],((C_word*)t0)[4]);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(((C_word*)t0)[3])?C_a_i_list(&a,2,lf[131],t2):t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k28964 in k28957 in k29114 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28966(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_28966,c,av);}
a=C_alloc(9);
t2=C_a_i_list1(&a,1,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(((C_word*)t0)[3])?C_a_i_list(&a,2,lf[131],t2):t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k28987 in k29157 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_28989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_28989,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29010,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29012,a[2]=t4,a[3]=t8,a[4]=t5,a[5]=((C_word)li367),tmp=(C_word)a,a+=6,tmp));
t10=((C_word*)t8)[1];
f_29012(t10,t6,((C_word*)t0)[3]);}
else{
t2=C_a_i_cons(&a,2,lf[115],((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
/* irregex-utils.scm:51: lp2 */
t4=((C_word*)((C_word*)t0)[5])[1];
f_29096(t4,((C_word*)t0)[6],((C_word*)t0)[7],t3);}}

/* k29008 in k28987 in k29157 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29010,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[437]+1);
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop5957 in k28987 in k29157 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29012(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_29012,3,t0,t1,t2);}
a=C_alloc(11);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29022,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
if(C_truep(C_charp(t4))){
t5=C_a_i_string(&a,1,t4);
t6=t3;
f_29022(t6,C_a_i_cons(&a,2,t5,C_SCHEME_END_OF_LIST));}
else{
t5=t3;
f_29022(t5,C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST));}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k29020 in map-loop5957 in k28987 in k29157 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29022(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,2)))){
C_save_and_reclaim_args((void *)trf_29022,2,t0,t1);}
t2=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t1);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t4=((C_word*)((C_word*)t0)[3])[1];
f_29012(t4,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a29048 in k29157 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29049(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29049,c,av);}
t3=C_i_stringp(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?t3:C_charp(t2));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_29079,c,av);}
a=C_alloc(7);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29084,a[2]=t1,a[3]=t3,a[4]=((C_word)li370),tmp=(C_word)a,a+=5,tmp));
t5=((C_word*)t3)[1];
f_29084(t5,((C_word*)t0)[2],((C_word*)t0)[3],C_SCHEME_FALSE);}

/* lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29084(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_29084,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29096,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t5,a[5]=((C_word)li369),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_29096(t7,t1,C_fix(0),C_SCHEME_END_OF_LIST);}
else{
t4=C_i_car(t2);
t5=C_i_string_length(t4);
t6=C_eqp(t5,C_fix(0));
if(C_truep(t6)){
/* irregex-utils.scm:60: lp1 */
t11=t1;
t12=C_u_i_cdr(t2);
t13=C_SCHEME_TRUE;
t1=t11;
t2=t12;
t3=t13;
goto loop;}
else{
t7=C_i_string_ref(t4,C_fix(0));
t8=C_fix(C_character_code(t7));
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_29195,a[2]=((C_word*)t0)[2],a[3]=t8,a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t2,a[7]=t3,tmp=(C_word)a,a+=8,tmp);
/* irregex-utils.scm:65: scheme#substring */
t10=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t10;
av2[1]=t9;
av2[2]=t4;
av2[3]=C_fix(1);
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}}}

/* lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29096(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,3)))){
C_save_and_reclaim_args((void *)trf_29096,4,t0,t1,t2,t3);}
a=C_alloc(19);
t4=C_eqp(t2,C_fix(256));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29116,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-utils.scm:47: ##sys#fast-reverse */
t6=*((C_word*)lf[69]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_make_character(C_unfix(t2));
t6=C_i_vector_ref(((C_word*)t0)[3],t2);
t7=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
if(C_truep(C_i_nullp(t6))){
/* irregex-utils.scm:51: lp2 */
t11=t1;
t12=t7;
t13=t3;
t1=t11;
t2=t12;
t3=t13;
goto loop;}
else{
if(C_truep(C_i_equalp(t6,lf[446]))){
t8=C_a_i_cons(&a,2,t5,t3);
/* irregex-utils.scm:51: lp2 */
t11=t1;
t12=t7;
t13=t8;
t1=t11;
t2=t12;
t3=t13;
goto loop;}
else{
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29151,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t7,tmp=(C_word)a,a+=6,tmp);
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_29159,a[2]=t5,a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=t7,a[7]=t8,tmp=(C_word)a,a+=8,tmp);
/* irregex-utils.scm:55: irregex-opt */
t10=*((C_word*)lf[443]+1);{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}}}}

/* k29114 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29116(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29116,c,av);}
a=C_alloc(6);
t2=C_i_cdr(t1);
if(C_truep(C_i_nullp(t2))){
t3=C_u_i_car(t1);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(((C_word*)t0)[3])?C_a_i_list(&a,2,lf[131],t3):t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28959,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:31: every */
f_9343(t3,*((C_word*)lf[445]+1),t1);}}

/* k29149 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29151(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_29151,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-utils.scm:51: lp2 */
t3=((C_word*)((C_word*)t0)[3])[1];
f_29096(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k29157 in lp2 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29159(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_29159,c,av);}
a=C_alloc(17);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
t3=C_i_cdr(t2);
if(C_truep(C_i_nullp(t3))){
t4=C_u_i_car(t2);
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[3]);
/* irregex-utils.scm:51: lp2 */
t6=((C_word*)((C_word*)t0)[4])[1];
f_29096(t6,((C_word*)t0)[5],((C_word*)t0)[6],t5);}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_28989,a[2]=((C_word*)t0)[7],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29049,a[2]=((C_word)li368),tmp=(C_word)a,a+=3,tmp);
/* irregex-utils.scm:35: every */
f_9343(t4,t5,t2);}}

/* k29193 in lp1 in k29077 in chicken.irregex#irregex-opt in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_29195,c,av);}
a=C_alloc(3);
t2=C_i_vector_ref(((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,t1,t2);
t4=C_i_vector_set(((C_word*)t0)[2],((C_word*)t0)[3],t3);
/* irregex-utils.scm:66: lp1 */
t5=((C_word*)((C_word*)t0)[4])[1];
f_29084(t5,((C_word*)t0)[5],C_u_i_cdr(((C_word*)t0)[6]),((C_word*)t0)[7]);}

/* chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29209(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_29209,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29213,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-utils.scm:71: chicken.base#open-output-string */
t4=*((C_word*)lf[451]+1);{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29213(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29213,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29216,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29221,a[2]=t4,a[3]=t1,a[4]=((C_word)li372),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_29221(t6,t2,((C_word*)t0)[3]);}

/* k29214 in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29216(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29216,c,av);}
/* irregex-utils.scm:82: chicken.base#get-output-string */
t2=*((C_word*)lf[448]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* lp in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29221(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,2)))){
C_save_and_reclaim_args((void *)trf_29221,3,t0,t1,t2);}
a=C_alloc(16);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29231,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_pairp(C_u_i_car(t2)))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29242,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29264,a[2]=t4,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t6=C_i_caar(t2);
t7=C_a_i_string(&a,1,t6);
/* irregex-utils.scm:77: irregex-quote */
t8=*((C_word*)lf[440]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t5;
av2[2]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29279,a[2]=t3,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t5=C_u_i_car(t2);
t6=C_a_i_string(&a,1,t5);
/* irregex-utils.scm:80: irregex-quote */
t7=*((C_word*)lf[440]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t4;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29229 in lp in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29231(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29231,c,av);}
/* irregex-utils.scm:81: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_29221(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* k29240 in lp in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_29242,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29245,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* ##sys#write-char/port */
t3=*((C_word*)lf[450]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(45);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k29243 in k29240 in lp in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29245,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29252,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_i_cdar(((C_word*)t0)[4]);
t4=C_a_i_string(&a,1,t3);
/* irregex-utils.scm:79: irregex-quote */
t5=*((C_word*)lf[440]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k29250 in k29243 in k29240 in lp in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29252(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29252,c,av);}
/* irregex-utils.scm:79: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29262 in lp in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29264(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29264,c,av);}
/* irregex-utils.scm:77: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29277 in lp in k29211 in chicken.irregex#cset->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29279(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29279,c,av);}
/* irregex-utils.scm:80: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29289(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_29289,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29293,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-utils.scm:85: chicken.base#open-output-string */
t4=*((C_word*)lf[451]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_29293,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29296,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29301,a[2]=t1,a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=((C_word)li382),tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_29301(t6,t2,((C_word*)t0)[3]);}

/* k29294 in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29296,c,av);}
/* irregex-utils.scm:153: chicken.base#get-output-string */
t2=*((C_word*)lf[448]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29301(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_29301,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[227]);
t5=(C_truep(t4)?t4:C_eqp(t3,lf[115]));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29324,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(C_u_i_cdr(t2)))){
t7=C_i_cddr(t2);
t8=C_i_pairp(t7);
t9=t6;
f_29324(t9,(C_truep(t8)?C_i_not(C_eqp(t2,((C_word*)t0)[4])):C_SCHEME_FALSE));}
else{
t7=t6;
f_29324(t7,C_SCHEME_FALSE);}}
else{
t6=C_eqp(t3,lf[108]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29421,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:96: scheme#display */
t8=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t7;
av2[2]=lf[456];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
t7=C_eqp(t3,lf[120]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29463,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:98: scheme#display */
t9=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[459];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
t8=C_eqp(t3,lf[103]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29517,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:101: scheme#display */
t10=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t10;
av2[1]=t9;
av2[2]=lf[462];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t10+1)))(4,av2);}}
else{
t9=C_eqp(t3,lf[127]);
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_29576,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=t3,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t9)){
t11=t10;
f_29576(t11,t9);}
else{
t11=C_eqp(t3,lf[129]);
if(C_truep(t11)){
t12=t10;
f_29576(t12,t11);}
else{
t12=C_eqp(t3,lf[131]);
if(C_truep(t12)){
t13=t10;
f_29576(t13,t12);}
else{
t13=C_eqp(t3,lf[128]);
t14=t10;
f_29576(t14,(C_truep(t13)?t13:C_eqp(t3,lf[132])));}}}}}}}}
else{
if(C_truep(C_i_symbolp(t2))){
t3=C_eqp(t2,lf[186]);
t4=(C_truep(t3)?t3:C_eqp(t2,lf[195]));
if(C_truep(t4)){
/* irregex-utils.scm:143: scheme#display */
t5=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[481];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=C_eqp(t2,lf[187]);
t6=(C_truep(t5)?t5:C_eqp(t2,lf[196]));
if(C_truep(t6)){
/* irregex-utils.scm:144: scheme#display */
t7=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[482];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t7=C_eqp(t2,lf[124]);
t8=(C_truep(t7)?t7:C_eqp(t2,lf[125]));
if(C_truep(t8)){
/* irregex-utils.scm:145: scheme#display */
t9=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t9;
av2[1]=t1;
av2[2]=lf[483];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
/* irregex-utils.scm:146: chicken.base#error */
t9=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t9;
av2[1]=t1;
av2[2]=lf[484];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}}}}
else{
if(C_truep(C_i_stringp(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30050,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-utils.scm:148: irregex-quote */
t4=*((C_word*)lf[440]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
if(C_truep(C_charp(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30063,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=C_a_i_string(&a,1,t2);
/* irregex-utils.scm:150: irregex-quote */
t5=*((C_word*)lf[440]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
/* irregex-utils.scm:152: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[485];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}}}}

/* k29322 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29324(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_29324,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29327,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:93: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[454];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[306]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29369,a[2]=t5,a[3]=((C_word*)t0)[5],a[4]=((C_word)li375),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_29369(t7,((C_word*)t0)[3],t2);}}

/* k29325 in k29322 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29327,c,av);}
a=C_alloc(11);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[306]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29334,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29339,a[2]=t6,a[3]=((C_word*)t0)[5],a[4]=((C_word)li374),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_29339(t8,t4,t2);}

/* k29332 in k29325 in k29322 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29334,c,av);}
/* irregex-utils.scm:93: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[453];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop6057 in k29325 in k29322 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29339(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29339,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29349,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:93: g6058 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_29301(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29347 in for-each-loop6057 in k29325 in k29322 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29349,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29339(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop6076 in k29322 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29369(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29369,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29379,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:94: g6077 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_29301(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29377 in for-each-loop6076 in k29322 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29379,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29369(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k29419 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29421(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29421,c,av);}
a=C_alloc(11);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[306]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29428,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29433,a[2]=t6,a[3]=((C_word*)t0)[5],a[4]=((C_word)li376),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_29433(t8,t4,t2);}

/* k29426 in k29419 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29428(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29428,c,av);}
/* irregex-utils.scm:96: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[455];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop6093 in k29419 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29433(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29433,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29443,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:96: g6094 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_29301(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29441 in for-each-loop6093 in k29419 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29443,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29433(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k29461 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29463,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29466,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:98: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k29464 in k29461 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29466(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29466,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29469,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:98: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[458];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k29467 in k29464 in k29461 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29469(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29469,c,av);}
a=C_alloc(11);
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[306]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29478,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29483,a[2]=t6,a[3]=((C_word*)t0)[5],a[4]=((C_word)li377),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_29483(t8,t4,t2);}

/* k29476 in k29467 in k29464 in k29461 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29478,c,av);}
/* irregex-utils.scm:99: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[457];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop6112 in k29467 in k29464 in k29461 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29483(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29483,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29493,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:99: g6113 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_29301(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29491 in for-each-loop6112 in k29467 in k29464 in k29461 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29493(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29493,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29483(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k29515 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29517,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29520,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:102: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_29301(t3,t2,C_i_cadr(((C_word*)t0)[4]));}

/* k29518 in k29515 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_29520,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29521,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li378),tmp=(C_word)a,a+=5,tmp);
t3=C_i_cddr(((C_word*)t0)[4]);
t4=C_i_check_list_2(t3,lf[306]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29537,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29542,a[2]=t7,a[3]=t2,a[4]=((C_word)li379),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_29542(t9,t5,t3);}

/* g6134 in k29518 in k29515 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29521(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_29521,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29525,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:103: scheme#display */
t4=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[460];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k29523 in g6134 in k29518 in k29515 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29525(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29525,c,av);}
/* irregex-utils.scm:103: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_29301(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k29535 in k29518 in k29515 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29537(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29537,c,av);}
/* irregex-utils.scm:104: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[461];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop6133 in k29518 in k29515 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29542(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29542,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29552,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:103: g6134 */
t4=((C_word*)t0)[3];
f_29521(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29550 in for-each-loop6133 in k29518 in k29515 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29552(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29552,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29542(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29576(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_29576,2,t0,t1);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29579,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_i_cddr(((C_word*)t0)[3]);
t4=C_i_pairp(t3);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29590,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t4)){
t6=t5;
f_29590(t6,t4);}
else{
t6=C_u_i_cdr(((C_word*)t0)[3]);
if(C_truep(C_i_stringp(C_u_i_car(t6)))){
t7=C_u_i_cdr(((C_word*)t0)[3]);
t8=C_i_string_length(C_u_i_car(t7));
t9=t5;
f_29590(t9,C_i_not(C_eqp(C_fix(1),t8)));}
else{
t7=t5;
f_29590(t7,C_SCHEME_FALSE);}}}
else{
t2=C_eqp(((C_word*)t0)[6],lf[465]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29673,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=C_i_cadr(((C_word*)t0)[3]);
if(C_truep(C_i_pairp(t4))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29703,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* irregex-utils.scm:113: scheme#caadr */
t6=*((C_word*)lf[471]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=t3;
f_29673(t5,C_SCHEME_FALSE);}}
else{
t3=C_eqp(((C_word*)t0)[6],lf[470]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29716,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:119: scheme#display */
t5=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[473];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t4=C_eqp(((C_word*)t0)[6],lf[247]);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_29737,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t4)){
t6=t5;
f_29737(t6,t4);}
else{
t6=C_eqp(((C_word*)t0)[6],lf[234]);
if(C_truep(t6)){
t7=t5;
f_29737(t7,t6);}
else{
t7=C_eqp(((C_word*)t0)[6],lf[52]);
t8=t5;
f_29737(t8,(C_truep(t7)?t7:C_eqp(((C_word*)t0)[6],lf[179])));}}}}}}

/* k29577 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29579,c,av);}
/* irregex-utils.scm:110: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_u_i_car(((C_word*)t0)[3]);
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29588 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29590(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_29590,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29593,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:108: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[464];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* irregex-utils.scm:109: lp */
t2=((C_word*)((C_word*)t0)[5])[1];
f_29301(t2,((C_word*)t0)[3],C_i_cadr(((C_word*)t0)[2]));}}

/* k29591 in k29588 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29593,c,av);}
a=C_alloc(11);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[306]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29600,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29605,a[2]=t6,a[3]=((C_word*)t0)[5],a[4]=((C_word)li380),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_29605(t8,t4,t2);}

/* k29598 in k29591 in k29588 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29600(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29600,c,av);}
/* irregex-utils.scm:108: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[463];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop6175 in k29591 in k29588 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29605(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29605,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29615,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:108: g6176 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_29301(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29613 in for-each-loop6175 in k29591 in k29588 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29615(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29615,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29605(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k29671 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29673(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_29673,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29676,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:114: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[468];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* irregex-utils.scm:117: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[469];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k29674 in k29671 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29676(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_29676,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29679,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29686,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29690,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* irregex-utils.scm:115: scheme#cdadr */
t5=*((C_word*)lf[467]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k29677 in k29674 in k29671 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29679(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29679,c,av);}
/* irregex-utils.scm:116: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[466];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29684 in k29674 in k29671 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29686,c,av);}
/* irregex-utils.scm:115: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29688 in k29674 in k29671 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29690(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29690,c,av);}
/* irregex-utils.scm:115: cset->string */
f_29209(((C_word*)t0)[2],t1);}

/* k29701 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29703(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29703,c,av);}
t2=((C_word*)t0)[2];
f_29673(t2,C_eqp(lf[470],t1));}

/* k29714 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29716(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_29716,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29719,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29726,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* irregex-utils.scm:120: cset->string */
f_29209(t3,C_u_i_cdr(((C_word*)t0)[4]));}

/* k29717 in k29714 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29719,c,av);}
/* irregex-utils.scm:121: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[472];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29724 in k29714 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29726,c,av);}
/* irregex-utils.scm:120: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29737(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_29737,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_eqp(C_make_character(126),C_u_i_car(((C_word*)t0)[2]));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29746,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t2)){
t4=t3;
f_29746(t4,t2);}
else{
t4=C_eqp(lf[247],C_u_i_car(((C_word*)t0)[2]));
if(C_truep(t4)){
t5=C_i_pairp(C_u_i_cdr(((C_word*)t0)[2]));
t6=t3;
f_29746(t6,(C_truep(t5)?C_eqp(lf[124],C_i_cadr(((C_word*)t0)[2])):C_SCHEME_FALSE));}
else{
t5=t3;
f_29746(t5,C_SCHEME_FALSE);}}}
else{
t2=C_eqp(((C_word*)t0)[6],lf[225]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[6],lf[226]));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29822,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:132: scheme#display */
t5=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[479];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
if(C_truep(C_i_stringp(C_u_i_car(((C_word*)t0)[2])))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29886,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* ##sys#string->list */
t5=*((C_word*)lf[105]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_u_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
/* irregex-utils.scm:140: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[480];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}}}

/* k29744 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29746(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_29746,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29749,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:126: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[475];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29784,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-utils.scm:130: sre->cset */
f_26504(t2,((C_word*)t0)[4],C_SCHEME_END_OF_LIST);}}

/* k29747 in k29744 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29749(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_29749,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29752,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29759,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_eqp(C_make_character(126),C_u_i_car(((C_word*)t0)[4]));
if(C_truep(t4)){
/* irregex-utils.scm:127: cset->string */
f_29209(t3,C_u_i_cdr(((C_word*)t0)[4]));}
else{
/* irregex-utils.scm:127: cset->string */
f_29209(t3,C_i_cddr(((C_word*)t0)[4]));}}

/* k29750 in k29747 in k29744 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29752(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29752,c,av);}
/* irregex-utils.scm:128: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[474];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29757 in k29747 in k29744 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29759,c,av);}
/* irregex-utils.scm:127: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k29782 in k29744 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_29784,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[470],t1);
/* irregex-utils.scm:130: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_29301(t3,((C_word*)t0)[3],t2);}

/* k29820 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29822,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_eqp(C_u_i_car(((C_word*)t0)[2]),lf[225]);
if(C_truep(t3)){
/* irregex-utils.scm:133: scheme#display */
t4=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[478];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_29825(2,av2);}}}

/* k29823 in k29820 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29825,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29828,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-utils.scm:134: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[477];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k29826 in k29823 in k29820 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29828,c,av);}
a=C_alloc(11);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[306]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29835,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29840,a[2]=t6,a[3]=((C_word*)t0)[5],a[4]=((C_word)li381),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_29840(t8,t4,t2);}

/* k29833 in k29826 in k29823 in k29820 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29835,c,av);}
/* irregex-utils.scm:136: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[476];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop6230 in k29826 in k29823 in k29820 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_29840(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29840,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29850,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* irregex-utils.scm:135: g6231 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_29301(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29848 in for-each-loop6230 in k29826 in k29823 in k29820 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29850,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29840(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k29884 in k29735 in k29574 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_29886(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_29886,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[470],t1);
/* irregex-utils.scm:139: lp */
t3=((C_word*)((C_word*)t0)[2])[1];
f_29301(t3,((C_word*)t0)[3],t2);}

/* k30048 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30050(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_30050,c,av);}
/* irregex-utils.scm:148: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k30061 in lp in k29291 in chicken.irregex#sre->string in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30063(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_30063,c,av);}
/* irregex-utils.scm:150: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30072(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_30072,c,av);}
a=C_alloc(6);
t3=C_i_check_string_2(t2,lf[487]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30083,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30087,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* ##sys#string->list */
t6=*((C_word*)lf[105]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k30081 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30083(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30083,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[227],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30087(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_30087,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30089,a[2]=t3,a[3]=((C_word)li385),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_30089(t5,((C_word*)t0)[2],t1,C_SCHEME_TRUE);}

/* loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_30089(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(61,0,4)))){
C_save_and_reclaim_args((void *)trf_30089,4,t0,t1,t2,t3);}
a=C_alloc(61);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=C_u_i_cdr(t2);
if(C_truep(C_i_char_equalp(t4,C_make_character(42)))){
if(C_truep(t3)){
t6=C_a_i_list(&a,1,lf[488]);
t7=C_a_i_list(&a,2,lf[179],t6);
t8=C_a_i_list(&a,1,lf[489]);
t9=C_a_i_list(&a,2,lf[179],t8);
t10=C_a_i_list(&a,2,lf[127],t9);
t11=C_a_i_list(&a,3,lf[227],t7,t10);
t12=C_a_i_list(&a,1,lf[490]);
t13=C_a_i_list(&a,2,lf[179],t12);
t14=C_a_i_list(&a,2,lf[127],t13);
t15=C_a_i_list(&a,3,lf[103],t11,t14);
t16=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30120,a[2]=t1,a[3]=t15,tmp=(C_word)a,a+=4,tmp);
/* irregex.scm:241: loop */
t18=t16;
t19=t5;
t20=C_SCHEME_FALSE;
t1=t18;
t2=t19;
t3=t20;
goto loop;}
else{
t6=C_a_i_list(&a,1,lf[491]);
t7=C_a_i_list(&a,2,lf[179],t6);
t8=C_a_i_list(&a,2,lf[127],t7);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30167,a[2]=t1,a[3]=t8,tmp=(C_word)a,a+=4,tmp);
/* irregex.scm:242: loop */
t18=t9;
t19=t5;
t20=C_SCHEME_FALSE;
t1=t18;
t2=t19;
t3=t20;
goto loop;}}
else{
if(C_truep(C_u_i_char_equalp(t4,C_make_character(63)))){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30187,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex.scm:243: loop */
t18=t6;
t19=t5;
t20=C_SCHEME_FALSE;
t1=t18;
t2=t19;
t3=t20;
goto loop;}
else{
if(C_truep(C_u_i_char_equalp(t4,C_make_character(91)))){
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30197,a[2]=((C_word*)t0)[2],a[3]=t7,a[4]=((C_word)li384),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_30197(t9,t1,t5,C_SCHEME_END_OF_LIST);}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30348,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* irregex.scm:265: loop */
t18=t6;
t19=t5;
t20=C_u_i_memq(t4,lf[493]);
t1=t18;
t2=t19;
t3=t20;
goto loop;}}}}}

/* k30118 in loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30120(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30120,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30165 in loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30167(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30167,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30185 in loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30187(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30187,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[124],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop2 in loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_30197(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_30197,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_i_pairp(t2);
if(C_truep(C_i_not(t4))){
/* irregex.scm:247: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[487];
av2[3]=lf[492];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=C_i_car(t2);
if(C_truep(C_i_char_equalp(C_make_character(93),t5))){
t6=C_i_length(t3);
t7=C_fixnum_greaterp(t6,C_fix(1));
t8=(C_truep(t7)?C_a_i_cons(&a,2,lf[103],t3):C_i_car(t3));
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30224,a[2]=t1,a[3]=t8,tmp=(C_word)a,a+=4,tmp);
/* irregex.scm:253: loop */
t10=((C_word*)((C_word*)t0)[2])[1];
f_30089(t10,t9,C_u_i_cdr(t2),C_SCHEME_FALSE);}
else{
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30246,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(C_u_i_cdr(t2)))){
t7=C_i_cddr(t2);
if(C_truep(C_i_pairp(t7))){
t8=C_u_i_cdr(t2);
t9=t6;
f_30246(t9,C_i_char_equalp(C_make_character(45),C_u_i_car(t8)));}
else{
t8=t6;
f_30246(t8,C_SCHEME_FALSE);}}
else{
t7=t6;
f_30246(t7,C_SCHEME_FALSE);}}}}

/* k30222 in loop2 in loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30224(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30224,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30244 in loop2 in loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_fcall f_30246(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_30246,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=C_i_cdddr(((C_word*)t0)[2]);
t3=C_u_i_car(((C_word*)t0)[2]);
t4=C_u_i_cdr(((C_word*)t0)[2]);
t5=C_u_i_cdr(t4);
t6=C_u_i_car(t5);
t7=C_a_i_list(&a,3,lf[52],t3,t6);
t8=C_a_i_cons(&a,2,t7,((C_word*)t0)[3]);
/* irregex.scm:257: loop2 */
t9=((C_word*)((C_word*)t0)[4])[1];
f_30197(t9,((C_word*)t0)[5],t2,t8);}
else{
t2=C_i_pairp(C_u_i_cdr(((C_word*)t0)[2]));
t3=(C_truep(t2)?C_i_char_equalp(C_make_character(45),C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_i_cddr(((C_word*)t0)[2]);
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=C_u_i_car(t5);
t7=C_a_i_list(&a,2,lf[179],t6);
t8=C_a_i_cons(&a,2,t7,((C_word*)t0)[3]);
/* irregex.scm:261: loop2 */
t9=((C_word*)((C_word*)t0)[4])[1];
f_30197(t9,((C_word*)t0)[5],t4,t8);}
else{
t4=C_u_i_cdr(((C_word*)t0)[2]);
t5=C_u_i_car(((C_word*)t0)[2]);
t6=C_a_i_cons(&a,2,t5,((C_word*)t0)[3]);
/* irregex.scm:264: loop2 */
t7=((C_word*)((C_word*)t0)[4])[1];
f_30197(t7,((C_word*)t0)[5],t4,t6);}}}

/* k30346 in loop in k30085 in chicken.irregex#glob->sre in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30348(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30348,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a30812 in k18928 in k7767 in k7542 in k7539 */
static void C_ccall f_30813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +30,c,1)))){
C_save_and_reclaim((void*)f_30813,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+30);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
t4=C_a_i_cons(&a,2,t2,t3);
t5=C_a_i_cons(&a,2,lf[179],t4);
t6=C_a_i_list(&a,3,lf[115],t2,lf[124]);
t7=C_a_i_list(&a,3,lf[103],t5,t6);
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_a_i_list(&a,2,lf[127],t7);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}

/* a30974 in k7767 in k7542 in k7539 */
static void C_ccall f_30975(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30975,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a30977 in k7767 in k7542 in k7539 */
static void C_ccall f_30978(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_30978,c,av);}
/* irregex-core.scm:1969: scheme#substring */
t6=*((C_word*)lf[46]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=C_i_car(t2);
av2[3]=t3;
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* a31011 in k7542 in k7539 */
static void C_ccall f_31012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_31012,c,av);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31016,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:160: irregex-match-num-submatches */
t5=*((C_word*)lf[17]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k31014 in a31011 in k7542 in k7539 */
static void C_ccall f_31016(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_31016,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31019,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:161: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[500];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k31017 in k31014 in a31011 in k7542 in k7539 */
static void C_ccall f_31019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_31019,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31022,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:162: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k31020 in k31017 in k31014 in a31011 in k7542 in k7539 */
static void C_ccall f_31022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_31022,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31025,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:163: scheme#display */
t3=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[499];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k31023 in k31020 in k31017 in k31014 in a31011 in k7542 in k7539 */
static void C_ccall f_31025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_31025,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31028,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_eqp(((C_word*)t0)[4],C_fix(0));
t4=(C_truep(t3)?t3:C_fixnum_greaterp(((C_word*)t0)[4],C_fix(1)));
if(C_truep(t4)){
/* irregex-core.scm:164: scheme#display */
t5=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[498];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
/* irregex-core.scm:165: scheme#display */
t5=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[497];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k31026 in k31023 in k31020 in k31017 in k31014 in a31011 in k7542 in k7539 */
static void C_ccall f_31028(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31028,c,av);}
/* irregex-core.scm:165: scheme#display */
t2=*((C_word*)lf[449]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[497];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k7539 */
static void C_ccall f_7541(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7541,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7544,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_expand_toplevel(2,av2);}}

/* k7542 in k7539 */
static void C_ccall f_7544(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,4)))){
C_save_and_reclaim((void *)f_7544,c,av);}
a=C_alloc(36);
t2=C_mutate(&lf[2] /* (set! chicken.irregex#vector-copy ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7546,a[2]=((C_word)li0),tmp=(C_word)a,a+=3,tmp));
t3=C_mutate((C_word*)lf[5]+1 /* (set! chicken.irregex#irregex? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7559,a[2]=((C_word)li1),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[7]+1 /* (set! chicken.irregex#irregex-num-submatches ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7601,a[2]=((C_word)li2),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[9]+1 /* (set! chicken.irregex#irregex-names ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7619,a[2]=((C_word)li3),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate(&lf[11] /* (set! chicken.irregex#irregex-new-matches ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7628,a[2]=((C_word)li4),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate(&lf[13] /* (set! chicken.irregex#irregex-reset-matches! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7651,a[2]=((C_word)li5),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate(&lf[15] /* (set! chicken.irregex#irregex-copy-matches ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7660,a[2]=((C_word)li6),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[16]+1 /* (set! chicken.irregex#irregex-match-data? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7692,a[2]=((C_word)li7),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[17]+1 /* (set! chicken.irregex#irregex-match-num-submatches ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7698,a[2]=((C_word)li8),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[19]+1 /* (set! chicken.irregex#irregex-match-names ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7723,a[2]=((C_word)li9),tmp=(C_word)a,a+=3,tmp));
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7769,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31012,a[2]=((C_word)li389),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:158: chicken.base#set-record-printer! */
t14=*((C_word*)lf[501]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t14;
av2[1]=t12;
av2[2]=lf[12];
av2[3]=t13;
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}

/* chicken.irregex#vector-copy in k7542 in k7539 */
static void C_fcall f_7546(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_7546,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7550,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:90: scheme#make-vector */
t4=*((C_word*)lf[4]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_vector_length(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k7548 in chicken.irregex#vector-copy in k7542 in k7539 */
static void C_ccall f_7550(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_7550,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7553,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:91: chicken.base#vector-copy! */
t3=*((C_word*)lf[3]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k7551 in k7548 in chicken.irregex#vector-copy in k7542 in k7539 */
static void C_ccall f_7553(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7553,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.irregex#irregex? in k7542 in k7539 */
static void C_ccall f_7559(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7559,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_structurep(t2,lf[6]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.irregex#irregex-num-submatches in k7542 in k7539 */
static void C_ccall f_7601(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7601,c,av);}
t3=C_i_check_structure_2(t2,lf[6],lf[8]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fix(5));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.irregex#irregex-names in k7542 in k7539 */
static void C_ccall f_7619(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7619,c,av);}
t3=C_i_check_structure_2(t2,lf[6],lf[10]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fix(7));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.irregex#irregex-new-matches in k7542 in k7539 */
static void C_fcall f_7628(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_7628,2,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7636,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7649,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:123: irregex-num-submatches */
t5=*((C_word*)lf[7]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k7634 in chicken.irregex#irregex-new-matches in k7542 in k7539 */
static void C_ccall f_7636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_7636,c,av);}
a=C_alloc(6);
t2=C_slot(((C_word*)t0)[2],C_fix(7));
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_record5(&a,5,lf[12],t1,t2,C_SCHEME_FALSE,C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7647 in chicken.irregex#irregex-new-matches in k7542 in k7539 */
static void C_ccall f_7649(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_7649,c,av);}
a=C_alloc(10);
t2=C_a_i_fixnum_plus(&a,2,C_fix(2),t1);
t3=C_s_a_u_i_integer_times(&a,2,C_fix(4),t2);
/* irregex-core.scm:123: scheme#make-vector */
t4=*((C_word*)lf[4]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* chicken.irregex#irregex-reset-matches! in k7542 in k7539 */
static void C_fcall f_7651(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_7651,2,t1,t2);}
a=C_alloc(4);
t3=C_slot(t2,C_fix(1));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7658,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:126: scheme#vector-fill! */
t5=*((C_word*)lf[14]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k7656 in chicken.irregex#irregex-reset-matches! in k7542 in k7539 */
static void C_ccall f_7658(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7658,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.irregex#irregex-copy-matches in k7542 in k7539 */
static void C_fcall f_7660(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_7660,2,t1,t2);}
a=C_alloc(4);
if(C_truep(C_i_structurep(t2,lf[12]))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7674,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:132: vector-copy */
f_7546(t3,C_slot(t2,C_fix(1)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k7672 in chicken.irregex#irregex-copy-matches in k7542 in k7539 */
static void C_ccall f_7674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_7674,c,av);}
a=C_alloc(6);
t2=C_slot(((C_word*)t0)[2],C_fix(2));
t3=C_slot(((C_word*)t0)[2],C_fix(3));
t4=C_slot(((C_word*)t0)[2],C_fix(4));
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_a_i_record5(&a,5,lf[12],t1,t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* chicken.irregex#irregex-match-data? in k7542 in k7539 */
static void C_ccall f_7692(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7692,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_structurep(t2,lf[12]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.irregex#irregex-match-num-submatches in k7542 in k7539 */
static void C_ccall f_7698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_7698,c,av);}
a=C_alloc(5);
t3=C_i_check_structure_2(t2,lf[12],lf[18]);
t4=C_slot(t2,C_fix(1));
t5=C_block_size(t4);
t6=C_fixnum_divide(t5,C_fix(4));
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_a_i_fixnum_difference(&a,2,t6,C_fix(2));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* chicken.irregex#irregex-match-names in k7542 in k7539 */
static void C_ccall f_7723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7723,c,av);}
t3=C_i_check_structure_2(t2,lf[12],lf[20]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fix(2));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k7767 in k7542 in k7539 */
static void C_ccall f_7769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(216,c,6)))){
C_save_and_reclaim((void *)f_7769,c,av);}
a=C_alloc(216);
t2=C_mutate((C_word*)lf[21]+1 /* (set! chicken.irregex#irregex-match-start-chunk ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7784,a[2]=((C_word)li10),tmp=(C_word)a,a+=3,tmp));
t3=C_mutate((C_word*)lf[24]+1 /* (set! chicken.irregex#irregex-match-start-index ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7809,a[2]=((C_word)li11),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[26]+1 /* (set! chicken.irregex#irregex-match-end-chunk ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7838,a[2]=((C_word)li12),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[28]+1 /* (set! chicken.irregex#irregex-match-end-index ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7867,a[2]=((C_word)li13),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate(&lf[22] /* (set! chicken.irregex#irregex-match-numeric-index ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7960,a[2]=((C_word)li15),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[36]+1 /* (set! chicken.irregex#irregex-match-valid-index? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8144,a[2]=((C_word)li16),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[40]+1 /* (set! chicken.irregex#irregex-match-substring ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8207,a[2]=((C_word)li17),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[42]+1 /* (set! chicken.irregex#irregex-match-subchunk ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8288,a[2]=((C_word)li18),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[45]+1 /* (set! chicken.irregex#make-irregex-chunker ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8378,a[2]=((C_word)li23),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate(&lf[50] /* (set! chicken.irregex#chunker-prev-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8646,a[2]=((C_word)li25),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate(&lf[51] /* (set! chicken.irregex#chunker-next-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8676,a[2]=((C_word)li26),tmp=(C_word)a,a+=3,tmp));
t13=C_a_i_list(&a,5,lf[52],C_make_character(0),C_make_character(55295),C_make_character(57344),C_make_character(1114111));
t14=C_mutate(&lf[53] /* (set! chicken.irregex#*all-chars* ...) */,t13);
t15=C_mutate(&lf[54] /* (set! chicken.irregex#string-scan-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8823,a[2]=((C_word)li28),tmp=(C_word)a,a+=3,tmp));
t16=C_mutate(&lf[47] /* (set! chicken.irregex#string-cat-reverse ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9114,a[2]=((C_word)li31),tmp=(C_word)a,a+=3,tmp));
t17=C_mutate(&lf[57] /* (set! chicken.irregex#zero-to ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9164,a[2]=((C_word)li33),tmp=(C_word)a,a+=3,tmp));
t18=C_mutate(&lf[58] /* (set! chicken.irregex#find ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9201,a[2]=((C_word)li35),tmp=(C_word)a,a+=3,tmp));
t19=C_mutate(&lf[59] /* (set! chicken.irregex#last ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9262,a[2]=((C_word)li37),tmp=(C_word)a,a+=3,tmp));
t20=C_mutate(&lf[61] /* (set! chicken.irregex#any ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9300,a[2]=((C_word)li39),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate(&lf[62] /* (set! chicken.irregex#every ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9343,a[2]=((C_word)li41),tmp=(C_word)a,a+=3,tmp));
t22=C_mutate(&lf[56] /* (set! chicken.irregex#fold ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9388,a[2]=((C_word)li43),tmp=(C_word)a,a+=3,tmp));
t23=C_mutate(&lf[63] /* (set! chicken.irregex#flag-join ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9718,a[2]=((C_word)li44),tmp=(C_word)a,a+=3,tmp));
t24=C_mutate(&lf[64] /* (set! chicken.irregex#flag-clear ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9727,a[2]=((C_word)li45),tmp=(C_word)a,a+=3,tmp));
t25=C_a_i_list1(&a,1,lf[65]);
t26=C_mutate(&lf[66] /* (set! chicken.irregex#close-token ...) */,t25);
t27=C_mutate(&lf[67] /* (set! chicken.irregex#with-read-from-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9745,a[2]=((C_word)li60),tmp=(C_word)a,a+=3,tmp));
t28=C_mutate(&lf[89] /* (set! chicken.irregex#symbol-list->flags ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10338,a[2]=((C_word)li62),tmp=(C_word)a,a+=3,tmp));
t29=C_mutate((C_word*)lf[101]+1 /* (set! chicken.irregex#maybe-string->sre ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10461,a[2]=((C_word)li63),tmp=(C_word)a,a+=3,tmp));
t30=C_mutate((C_word*)lf[102]+1 /* (set! chicken.irregex#string->sre ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10473,a[2]=((C_word)li90),tmp=(C_word)a,a+=3,tmp));
t31=C_a_i_cons(&a,2,C_make_character(110),C_make_character(10));
t32=C_a_i_cons(&a,2,C_make_character(114),C_make_character(13));
t33=C_a_i_cons(&a,2,C_make_character(116),C_make_character(9));
t34=C_a_i_cons(&a,2,C_make_character(97),C_make_character(7));
t35=C_a_i_cons(&a,2,C_make_character(101),C_make_character(27));
t36=C_a_i_cons(&a,2,C_make_character(102),C_make_character(12));
t37=C_a_i_list(&a,6,t31,t32,t33,t34,t35,t36);
t38=C_mutate(&lf[168] /* (set! chicken.irregex#posix-escape-sequences ...) */,t37);
t39=C_mutate(&lf[169] /* (set! chicken.irregex#string-parse-hex-escape ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13301,a[2]=((C_word)li92),tmp=(C_word)a,a+=3,tmp));
t40=C_mutate(&lf[204] /* (set! chicken.irregex#high-char? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14014,a[2]=((C_word)li93),tmp=(C_word)a,a+=3,tmp));
t41=C_mutate(&lf[106] /* (set! chicken.irregex#utf8-string-ref ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14035,a[2]=((C_word)li95),tmp=(C_word)a,a+=3,tmp));
t42=C_mutate(&lf[206] /* (set! chicken.irregex#utf8-lowest-digit-of-length ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14268,a[2]=((C_word)li96),tmp=(C_word)a,a+=3,tmp));
t43=C_mutate(&lf[208] /* (set! chicken.irregex#char->utf8-list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14344,a[2]=((C_word)li97),tmp=(C_word)a,a+=3,tmp));
t44=C_mutate(&lf[210] /* (set! chicken.irregex#unicode-range-helper ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14620,a[2]=((C_word)li100),tmp=(C_word)a,a+=3,tmp));
t45=C_mutate(&lf[212] /* (set! chicken.irregex#unicode-range-up-from ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14758,a[2]=((C_word)li103),tmp=(C_word)a,a+=3,tmp));
t46=C_mutate(&lf[213] /* (set! chicken.irregex#unicode-range-up-to ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14897,a[2]=((C_word)li106),tmp=(C_word)a,a+=3,tmp));
t47=C_mutate(&lf[214] /* (set! chicken.irregex#cset->utf8-pattern ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15475,a[2]=((C_word)li115),tmp=(C_word)a,a+=3,tmp));
t48=C_mutate((C_word*)lf[217]+1 /* (set! chicken.irregex#irregex ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16048,a[2]=((C_word)li116),tmp=(C_word)a,a+=3,tmp));
t49=C_mutate((C_word*)lf[219]+1 /* (set! chicken.irregex#string->irregex ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16176,a[2]=((C_word)li117),tmp=(C_word)a,a+=3,tmp));
t50=C_mutate((C_word*)lf[220]+1 /* (set! chicken.irregex#sre->irregex ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16186,a[2]=((C_word)li213),tmp=(C_word)a,a+=3,tmp));
t51=C_mutate(&lf[139] /* (set! chicken.irregex#sre-empty? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16319,a[2]=((C_word)li214),tmp=(C_word)a,a+=3,tmp));
t52=C_mutate(&lf[277] /* (set! chicken.irregex#sre-any? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16486,a[2]=((C_word)li215),tmp=(C_word)a,a+=3,tmp));
t53=C_mutate(&lf[136] /* (set! chicken.irregex#sre-repeater? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16587,a[2]=((C_word)li216),tmp=(C_word)a,a+=3,tmp));
t54=C_mutate(&lf[279] /* (set! chicken.irregex#sre-bos? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16632,a[2]=((C_word)li217),tmp=(C_word)a,a+=3,tmp));
t55=C_mutate(&lf[271] /* (set! chicken.irregex#sre-searcher? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16721,a[2]=((C_word)li218),tmp=(C_word)a,a+=3,tmp));
t56=C_mutate(&lf[253] /* (set! chicken.irregex#sre-consumer? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16838,a[2]=((C_word)li219),tmp=(C_word)a,a+=3,tmp));
t57=C_mutate(&lf[280] /* (set! chicken.irregex#sre-has-submatches? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16955,a[2]=((C_word)li220),tmp=(C_word)a,a+=3,tmp));
t58=C_mutate(&lf[224] /* (set! chicken.irregex#sre-count-submatches ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16994,a[2]=((C_word)li222),tmp=(C_word)a,a+=3,tmp));
t59=C_mutate(&lf[104] /* (set! chicken.irregex#sre-sequence ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18203,a[2]=((C_word)li223),tmp=(C_word)a,a+=3,tmp));
t60=C_mutate(&lf[107] /* (set! chicken.irregex#sre-alternate ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18226,a[2]=((C_word)li224),tmp=(C_word)a,a+=3,tmp));
t61=C_mutate(&lf[283] /* (set! chicken.irregex#sre-strip-submatches ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18249,a[2]=((C_word)li226),tmp=(C_word)a,a+=3,tmp));
t62=C_mutate(&lf[252] /* (set! chicken.irregex#sre-names ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18430,a[2]=((C_word)li227),tmp=(C_word)a,a+=3,tmp));
t63=C_mutate(&lf[284] /* (set! chicken.irregex#sre-sequence-names ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18716,a[2]=((C_word)li228),tmp=(C_word)a,a+=3,tmp));
t64=C_mutate(&lf[270] /* (set! chicken.irregex#sre-remove-initial-bos ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18748,a[2]=((C_word)li230),tmp=(C_word)a,a+=3,tmp));
t65=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18930,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t66=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30975,a[2]=((C_word)li387),tmp=(C_word)a,a+=3,tmp);
t67=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30978,a[2]=((C_word)li388),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:1964: make-irregex-chunker */
t68=*((C_word*)lf[45]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t68;
av2[1]=t65;
av2[2]=t66;
av2[3]=*((C_word*)lf[494]+1);
av2[4]=*((C_word*)lf[495]+1);
av2[5]=*((C_word*)lf[496]+1);
av2[6]=t67;
((C_proc)(void*)(*((C_word*)t68+1)))(7,av2);}}

/* k7780 in k8146 in chicken.irregex#irregex-match-valid-index? in k7767 in k7542 in k7539 */
static void C_ccall f_7782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7782,c,av);}
t2=C_i_assq(((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?C_SCHEME_TRUE:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.irregex#irregex-match-start-chunk in k7767 in k7542 in k7539 */
static void C_ccall f_7784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_7784,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7788,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:233: irregex-match-numeric-index */
f_7960(t4,lf[23],t2,t3);}

/* k7786 in chicken.irregex#irregex-match-start-chunk in k7767 in k7542 in k7539 */
static void C_ccall f_7788(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7788,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_slot(C_slot(((C_word*)t0)[3],C_fix(1)),C_fixnum_times(t1,C_fix(4))):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.irregex#irregex-match-start-index in k7767 in k7542 in k7539 */
static void C_ccall f_7809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_7809,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7813,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:236: irregex-match-numeric-index */
f_7960(t4,lf[25],t2,t3);}

/* k7811 in chicken.irregex#irregex-match-start-index in k7767 in k7542 in k7539 */
static void C_ccall f_7813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7813,c,av);}
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(t1,C_fix(4));
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fixnum_plus(C_fix(1),t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.irregex#irregex-match-end-chunk in k7767 in k7542 in k7539 */
static void C_ccall f_7838(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_7838,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7842,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:239: irregex-match-numeric-index */
f_7960(t4,lf[27],t2,t3);}

/* k7840 in chicken.irregex#irregex-match-end-chunk in k7767 in k7542 in k7539 */
static void C_ccall f_7842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7842,c,av);}
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(t1,C_fix(4));
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fixnum_plus(C_fix(2),t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.irregex#irregex-match-end-index in k7767 in k7542 in k7539 */
static void C_ccall f_7867(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_7867,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7871,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:242: irregex-match-numeric-index */
f_7960(t4,lf[29],t2,t3);}

/* k7869 in chicken.irregex#irregex-match-end-index in k7767 in k7542 in k7539 */
static void C_ccall f_7871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7871,c,av);}
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(t1,C_fix(4));
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fixnum_plus(C_fix(3),t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.irregex#irregex-match-numeric-index in k7767 in k7542 in k7539 */
static void C_fcall f_7960(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_7960,4,t1,t2,t3,t4);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8142,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:269: irregex-match-data? */
t6=*((C_word*)lf[16]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k8026 in k8140 in chicken.irregex#irregex-match-numeric-index in k7767 in k7542 in k7539 */
static void C_fcall f_8028(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_8028,2,t0,t1);}
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_fixnum_times(((C_word*)t0)[3],C_fix(4));
t4=C_fixnum_plus(C_fix(1),t3);
t5=C_slot(t2,t4);
t6=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t5)?((C_word*)t0)[3]:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* irregex-core.scm:280: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[6];
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=lf[33];
av2[4]=((C_word*)t0)[2];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* k8068 in k8140 in chicken.irregex#irregex-match-numeric-index in k7767 in k7542 in k7539 */
static void C_ccall f_8070(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_8070,c,av);}
a=C_alloc(9);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8072,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t3,a[6]=((C_word)li14),tmp=(C_word)a,a+=7,tmp));
t5=((C_word*)t3)[1];
f_8072(t5,((C_word*)t0)[5],t1,C_SCHEME_TRUE);}

/* lp in k8068 in k8140 in chicken.irregex#irregex-match-numeric-index in k7767 in k7542 in k7539 */
static void C_fcall f_8072(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_8072,4,t0,t1,t2,t3);}
if(C_truep(C_i_nullp(t2))){
if(C_truep(t3)){
/* irregex-core.scm:287: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[35];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=C_i_caar(t2);
t5=C_eqp(((C_word*)t0)[3],t4);
if(C_truep(t5)){
t6=C_u_i_car(t2);
t7=C_u_i_cdr(t6);
t8=C_slot(((C_word*)t0)[4],C_fix(1));
t9=C_fixnum_times(t7,C_fix(4));
if(C_truep(C_slot(t8,t9))){
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_i_cdar(t2);
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
/* irregex-core.scm:291: lp */
t11=t1;
t12=C_u_i_cdr(t2);
t13=C_SCHEME_FALSE;
t1=t11;
t2=t12;
t3=t13;
goto loop;}}
else{
/* irregex-core.scm:292: lp */
t11=t1;
t12=C_u_i_cdr(t2);
t13=t3;
t1=t11;
t2=t12;
t3=t13;
goto loop;}}}

/* k8140 in chicken.irregex#irregex-match-numeric-index in k7767 in k7542 in k7539 */
static void C_ccall f_8142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,6)))){
C_save_and_reclaim((void *)f_8142,c,av);}
a=C_alloc(11);
if(C_truep(C_i_not(t1))){
/* irregex-core.scm:270: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[31];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=C_i_pairp(((C_word*)t0)[5]);
if(C_truep(C_i_not(t2))){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_cdr(((C_word*)t0)[5]);
if(C_truep(C_i_pairp(t3))){{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[30]+1);
av2[3]=((C_word*)t0)[3];
av2[4]=lf[32];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
C_apply(7,av2);}}
else{
t4=C_u_i_car(((C_word*)t0)[5]);
if(C_truep(C_i_numberp(t4))){
t5=(C_truep(C_i_integerp(t4))?C_i_exactp(t4):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8028,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t7=C_slot(((C_word*)t0)[4],C_fix(1));
if(C_truep(C_fixnum_greater_or_equal_p(t4,C_fix(0)))){
t8=C_fixnum_times(t4,C_fix(4));
t9=C_block_size(t7);
t10=C_a_i_fixnum_difference(&a,2,t9,C_fix(4));
t11=t6;
f_8028(t11,C_fixnum_lessp(t8,t10));}
else{
t8=t6;
f_8028(t8,C_SCHEME_FALSE);}}
else{
/* irregex-core.scm:281: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[34];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8070,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:282: irregex-match-names */
t6=*((C_word*)lf[19]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}}}}

/* chicken.irregex#irregex-match-valid-index? in k7767 in k7542 in k7539 */
static void C_ccall f_8144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_8144,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8148,a[2]=t3,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8205,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:295: irregex-match-data? */
t6=*((C_word*)lf[16]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k8146 in chicken.irregex#irregex-match-valid-index? in k7767 in k7542 in k7539 */
static void C_ccall f_8148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_8148,c,av);}
a=C_alloc(5);
if(C_truep(C_i_integerp(((C_word*)t0)[2]))){
t2=C_i_exactp(((C_word*)t0)[2]);
if(C_truep(C_i_not(t2))){
/* irregex-core.scm:299: chicken.base#error */
t3=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[37];
av2[3]=lf[38];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=C_slot(((C_word*)t0)[4],C_fix(1));
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[2],C_fix(0)))){
t4=C_fixnum_times(((C_word*)t0)[2],C_fix(4));
t5=C_block_size(t3);
t6=C_a_i_fixnum_difference(&a,2,t5,C_fix(4));
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_fixnum_lessp(t4,t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7782,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:228: irregex-match-names */
t3=*((C_word*)lf[19]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k8203 in chicken.irregex#irregex-match-valid-index? in k7767 in k7542 in k7539 */
static void C_ccall f_8205(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8205,c,av);}
if(C_truep(C_i_not(t1))){
/* irregex-core.scm:296: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[37];
av2[3]=lf[39];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_8148(2,av2);}}}

/* chicken.irregex#irregex-match-substring in k7767 in k7542 in k7539 */
static void C_ccall f_8207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_8207,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8211,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:304: irregex-match-numeric-index */
f_7960(t4,lf[41],t2,t3);}

/* k8209 in chicken.irregex#irregex-match-substring in k7767 in k7542 in k7539 */
static void C_ccall f_8211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_8211,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(3));
if(C_truep(t1)){
t3=C_i_vector_ref(t2,C_fix(4));
t4=C_slot(((C_word*)t0)[2],C_fix(1));
t5=C_fixnum_times(t1,C_fix(4));
t6=C_slot(t4,t5);
t7=C_slot(((C_word*)t0)[2],C_fix(1));
t8=C_fixnum_times(t1,C_fix(4));
t9=C_fixnum_plus(C_fix(1),t8);
t10=C_slot(t7,t9);
t11=C_slot(((C_word*)t0)[2],C_fix(1));
t12=C_fixnum_times(t1,C_fix(4));
t13=C_fixnum_plus(C_fix(2),t12);
t14=C_slot(t11,t13);
t15=C_slot(((C_word*)t0)[2],C_fix(1));
t16=C_fixnum_times(t1,C_fix(4));
/* irregex-core.scm:306: g895 */
t17=t3;{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t17;
av2[1]=((C_word*)t0)[3];
av2[2]=t6;
av2[3]=t10;
av2[4]=t14;
av2[5]=C_slot(t15,C_fixnum_plus(C_fix(3),t16));
((C_proc)(void*)(*((C_word*)t17+1)))(6,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.irregex#irregex-match-subchunk in k7767 in k7542 in k7539 */
static void C_ccall f_8288(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_8288,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8292,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:314: irregex-match-numeric-index */
f_7960(t4,lf[44],t2,t3);}

/* k8290 in chicken.irregex#irregex-match-subchunk in k7767 in k7542 in k7539 */
static void C_ccall f_8292(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_8292,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(3));
t3=C_i_vector_ref(t2,C_fix(5));
if(C_truep(C_i_not(t3))){
/* irregex-core.scm:318: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[43];
av2[3]=((C_word*)t0)[2];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
if(C_truep(t1)){
t4=C_slot(((C_word*)t0)[2],C_fix(1));
t5=C_fixnum_times(t1,C_fix(4));
t6=C_slot(t4,t5);
t7=C_slot(((C_word*)t0)[2],C_fix(1));
t8=C_fixnum_times(t1,C_fix(4));
t9=C_fixnum_plus(C_fix(1),t8);
t10=C_slot(t7,t9);
t11=C_slot(((C_word*)t0)[2],C_fix(1));
t12=C_fixnum_times(t1,C_fix(4));
t13=C_fixnum_plus(C_fix(2),t12);
t14=C_slot(t11,t13);
t15=C_slot(((C_word*)t0)[2],C_fix(1));
t16=C_fixnum_times(t1,C_fix(4));
/* irregex-core.scm:319: get-subchunk */
t17=t3;{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t17;
av2[1]=((C_word*)t0)[3];
av2[2]=t6;
av2[3]=t10;
av2[4]=t14;
av2[5]=C_slot(t15,C_fixnum_plus(C_fix(3),t16));
((C_proc)(void*)(*((C_word*)t17+1)))(6,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* chicken.irregex#make-irregex-chunker in k7767 in k7542 in k7539 */
static void C_ccall f_8378(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +33,c,6)))){
C_save_and_reclaim((void*)f_8378,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+33);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
t5=C_i_pairp(t4);
t6=(C_truep(t5)?C_get_rest_arg(c,4,av,4,t0):C_SCHEME_FALSE);
t7=(C_truep(t6)?t6:(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8570,a[2]=((C_word)li19),tmp=(C_word)a,a+=3,tmp));
t8=C_i_pairp(t4);
t9=(C_truep(t8)?C_i_cdr(t4):t4);
t10=C_i_pairp(t9);
t11=(C_truep(t10)?C_u_i_car(t9):C_SCHEME_FALSE);
t12=(C_truep(t11)?t11:(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8553,a[2]=t3,a[3]=((C_word)li20),tmp=(C_word)a,a+=4,tmp));
t13=C_i_pairp(t9);
t14=(C_truep(t13)?C_u_i_cdr(t9):t9);
t15=C_i_pairp(t14);
t16=(C_truep(t15)?C_u_i_car(t14):C_SCHEME_FALSE);
t17=(C_truep(t16)?t16:(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8452,a[2]=t3,a[3]=t7,a[4]=t12,a[5]=t2,a[6]=((C_word)li22),tmp=(C_word)a,a+=7,tmp));
t18=C_i_pairp(t14);
t19=(C_truep(t18)?C_u_i_cdr(t14):t14);
t20=C_i_pairp(t19);
t21=(C_truep(t20)?C_u_i_car(t19):C_SCHEME_FALSE);
t22=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8412,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t7,a[6]=t12,a[7]=t17,a[8]=t21,tmp=(C_word)a,a+=9,tmp);
t23=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8418,a[2]=t22,a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t7,a[7]=t12,a[8]=t17,a[9]=t21,tmp=(C_word)a,a+=10,tmp);
if(C_truep(C_i_closurep(t2))){
if(C_truep(C_i_closurep(t3))){
t24=C_i_closurep(t7);
t25=t23;
f_8418(t25,(C_truep(t24)?C_i_not(C_i_closurep(t17)):C_SCHEME_TRUE));}
else{
t24=t23;
f_8418(t24,C_SCHEME_TRUE);}}
else{
t24=t23;
f_8418(t24,C_SCHEME_TRUE);}}

/* k8410 in chicken.irregex#make-irregex-chunker in k7767 in k7542 in k7539 */
static void C_ccall f_8412(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,1)))){
C_save_and_reclaim((void *)f_8412,c,av);}
a=C_alloc(7);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_vector6(&a,6,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8416 in chicken.irregex#make-irregex-chunker in k7767 in k7542 in k7539 */
static void C_fcall f_8418(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_8418,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* irregex-core.scm:357: chicken.base#error */
t2=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[48];
av2[3]=lf[49];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_a_i_vector6(&a,6,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* f_8452 in chicken.irregex#make-irregex-chunker in k7767 in k7542 in k7539 */
static void C_ccall f_8452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_8452,c,av);}
a=C_alloc(11);
t6=C_eqp(t2,t4);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8466,a[2]=t1,a[3]=t3,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:337: get-str */
t8=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8473,a[2]=t4,a[3]=t5,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=t1,a[9]=t3,a[10]=t2,tmp=(C_word)a,a+=11,tmp);
/* irregex-core.scm:338: get-next */
t8=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}

/* k8464 */
static void C_ccall f_8466(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8466,c,av);}
/* irregex-core.scm:337: scheme#substring */
t2=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k8471 */
static void C_ccall f_8473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_8473,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8536,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,tmp=(C_word)a,a+=10,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8540,a[2]=t2,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:339: get-str */
t4=((C_word*)t0)[5];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* loop in k8534 in k8471 */
static void C_fcall f_8479(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_8479,4,t0,t1,t2,t3);}
a=C_alloc(10);
t4=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8497,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8501,a[2]=t5,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:344: get-str */
t7=((C_word*)t0)[5];{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8512,a[2]=t3,a[3]=((C_word*)t0)[6],a[4]=t1,a[5]=((C_word*)t0)[7],a[6]=t2,a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* irregex-core.scm:348: get-next */
t6=((C_word*)t0)[8];{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k8495 in loop in k8534 in k8471 */
static void C_ccall f_8497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8497,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:343: string-cat-reverse */
f_9114(((C_word*)t0)[3],t2);}

/* k8499 in loop in k8534 in k8471 */
static void C_ccall f_8501(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8501,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8505,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:345: get-start */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8503 in k8499 in loop in k8534 in k8471 */
static void C_ccall f_8505(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8505,c,av);}
/* irregex-core.scm:344: scheme#substring */
t2=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k8510 in loop in k8534 in k8471 */
static void C_ccall f_8512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_8512,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8520,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8524,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:349: get-str */
t4=((C_word*)t0)[8];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8518 in k8510 in loop in k8534 in k8471 */
static void C_ccall f_8520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_8520,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* irregex-core.scm:348: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_8479(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k8522 in k8510 in loop in k8534 in k8471 */
static void C_ccall f_8524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_8524,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8528,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:350: get-start */
t3=((C_word*)t0)[5];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8526 in k8522 in k8510 in loop in k8534 in k8471 */
static void C_ccall f_8528(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8528,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8532,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:351: get-end */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8530 in k8526 in k8522 in k8510 in loop in k8534 in k8471 */
static void C_ccall f_8532(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8532,c,av);}
/* irregex-core.scm:349: scheme#substring */
t2=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k8534 in k8471 */
static void C_ccall f_8536(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_8536,c,av);}
a=C_alloc(15);
t2=C_a_i_list1(&a,1,t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8479,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t4,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word)li21),tmp=(C_word)a,a+=10,tmp));
t6=((C_word*)t4)[1];
f_8479(t6,((C_word*)t0)[8],((C_word*)t0)[9],t2);}

/* k8538 in k8471 */
static void C_ccall f_8540(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8540,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8544,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:341: get-end */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8542 in k8538 in k8471 */
static void C_ccall f_8544(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8544,c,av);}
/* irregex-core.scm:339: scheme#substring */
t2=*((C_word*)lf[46]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* f_8553 in chicken.irregex#make-irregex-chunker in k7767 in k7542 in k7539 */
static void C_ccall f_8553(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8553,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8561,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:331: get-str */
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8559 */
static void C_ccall f_8561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8561,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_string_length(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_8570 in chicken.irregex#make-irregex-chunker in k7767 in k7542 in k7539 */
static void C_ccall f_8570(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8570,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* lp in chicken.irregex#chunker-prev-char in k7767 in k7542 in k7539 */
static void C_fcall f_8628(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_8628,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8632,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:372: get-next */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8630 in lp in chicken.irregex#chunker-prev-char in k7767 in k7542 in k7539 */
static void C_ccall f_8632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8632,c,av);}
t2=C_eqp(t1,((C_word*)t0)[2]);
if(C_truep(t2)){
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(t1)){
/* irregex-core.scm:375: lp */
t3=((C_word*)((C_word*)t0)[5])[1];
f_8628(t3,((C_word*)t0)[3],t1);}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* chicken.irregex#chunker-prev-char in k7767 in k7542 in k7539 */
static void C_fcall f_8646(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_8646,4,t1,t2,t3,t4);}
a=C_alloc(12);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8650,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=C_eqp(t3,t4);
if(C_truep(t6)){
t7=t5;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
f_8650(2,av2);}}
else{
t7=C_i_vector_ref(t2,C_fix(0));
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8628,a[2]=t4,a[3]=t9,a[4]=t7,a[5]=((C_word)li24),tmp=(C_word)a,a+=6,tmp));
t11=((C_word*)t9)[1];
f_8628(t11,t5,t3);}}

/* k8648 in chicken.irregex#chunker-prev-char in k7767 in k7542 in k7539 */
static void C_ccall f_8650(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8650,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8663,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:380: g994 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k8661 in k8648 in chicken.irregex#chunker-prev-char in k7767 in k7542 in k7539 */
static void C_ccall f_8663(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8663,c,av);}
a=C_alloc(4);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8674,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:381: g996 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8672 in k8661 in k8648 in chicken.irregex#chunker-prev-char in k7767 in k7542 in k7539 */
static void C_ccall f_8674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8674,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_string_ref(((C_word*)t0)[3],C_fixnum_difference(t1,C_fix(1)));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.irregex#chunker-next-char in k7767 in k7542 in k7539 */
static void C_fcall f_8676(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_8676,3,t1,t2,t3);}
a=C_alloc(4);
t4=C_i_vector_ref(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8683,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:384: g1002 */
t6=t4;{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k8681 in chicken.irregex#chunker-next-char in k7767 in k7542 in k7539 */
static void C_ccall f_8683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8683,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8696,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:386: g1005 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k8694 in k8681 in chicken.irregex#chunker-next-char in k7767 in k7542 in k7539 */
static void C_ccall f_8696(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8696,c,av);}
a=C_alloc(4);
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8703,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:386: g1007 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8701 in k8694 in k8681 in chicken.irregex#chunker-next-char in k7767 in k7542 in k7539 */
static void C_ccall f_8703(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8703,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_string_ref(((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a8741 */
static void C_ccall f_8742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8742,c,av);}
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(C_i_not(t3))){
/* irregex-core.scm:401: g1024 */
t4=C_i_vector_ref(((C_word*)t0)[3],C_fix(0));{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* a8768 */
static void C_ccall f_8769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_8769,c,av);}
a=C_alloc(7);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
if(C_truep(t3)){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* irregex-core.scm:409: g1035 */
t4=C_i_vector_ref(((C_word*)t0)[4],C_fix(3));{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}
else{
t4=C_i_vector_ref(((C_word*)t0)[4],C_fix(0));
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8808,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:410: g1031 */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k8799 in k8806 in a8768 */
static void C_ccall f_8801(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8801,c,av);}
if(C_truep(C_i_not(t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* irregex-core.scm:409: g1035 */
t2=C_i_vector_ref(((C_word*)t0)[4],C_fix(3));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}}

/* k8806 in a8768 */
static void C_ccall f_8808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_8808,c,av);}
a=C_alloc(6);
if(C_truep(C_i_not(t1))){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(0));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8801,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:411: g1033 */
t4=t2;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* irregex-core.scm:409: g1035 */
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(3));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}}

/* chicken.irregex#string-scan-char in k7767 in k7542 in k7539 */
static void C_ccall f_8823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +9,c,3)))){
C_save_and_reclaim((void*)f_8823,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+9);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
t5=C_i_string_length(t2);
t6=C_i_pairp(t4);
t7=(C_truep(t6)?C_get_rest_arg(c,4,av,4,t0):C_fix(0));
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8836,a[2]=t5,a[3]=t2,a[4]=t3,a[5]=t9,a[6]=((C_word)li27),tmp=(C_word)a,a+=7,tmp));
t11=((C_word*)t9)[1];
f_8836(t11,t1,t7);}

/* scan in chicken.irregex#string-scan-char in k7767 in k7542 in k7539 */
static void C_fcall f_8836(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_8836,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_string_ref(((C_word*)t0)[3],t2);
t5=C_eqp(((C_word*)t0)[4],t4);
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:443: scan */
t8=t1;
t9=t6;
t1=t8;
t2=t9;
goto loop;}}}

/* scan in chicken.irregex#string-parse-hex-escape in k7767 in k7542 in k7539 */
static void C_fcall f_8879(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_8879,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_string_ref(((C_word*)t0)[3],t2);
t5=C_eqp(C_make_character(125),t4);
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:451: scan */
t8=t1;
t9=t6;
t1=t8;
t2=t9;
goto loop;}}}

/* scan in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_8936(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_8936,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_string_ref(((C_word*)t0)[3],t2);
t5=C_u_i_char_numericp(t4);
if(C_truep(C_i_not(t5))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:458: scan */
t8=t1;
t9=t6;
t1=t8;
t2=t9;
goto loop;}}}

/* lp in k12202 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_8974(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(23,0,4)))){
C_save_and_reclaim_args((void *)trf_8974,5,t0,t1,t2,t3,t4);}
a=C_alloc(23);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8977,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t2,a[6]=((C_word)li83),tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[3]))){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8998,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:464: collect */
t7=t5;
f_8977(t7,t6);}
else{
t6=C_i_string_ref(((C_word*)t0)[2],t2);
t7=C_eqp(C_make_character(44),t6);
if(C_truep(t7)){
t8=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t9=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9017,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t8,a[5]=t9,tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:465: collect */
t11=t5;
f_8977(t11,t10);}
else{
t8=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:466: lp */
t12=t1;
t13=t8;
t14=t3;
t15=t4;
t1=t12;
t2=t13;
t3=t14;
t4=t15;
goto loop;}}}

/* collect in lp in k12202 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_fcall f_8977(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_8977,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8985,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:463: scheme#substring */
t3=*((C_word*)lf[46]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8983 in collect in lp in k12202 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_8985(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_8985,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8996 in lp in k12202 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_8998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8998,c,av);}
/* irregex-core.scm:464: ##sys#fast-reverse */
t2=*((C_word*)lf[69]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k9015 in lp in k12202 in k12074 in k12058 in k12049 in lp in k10481 in k10475 in chicken.irregex#string->sre in k7767 in k7542 in k7539 */
static void C_ccall f_9017(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9017,c,av);}
/* irregex-core.scm:465: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8974(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* chicken.irregex#string-cat-reverse in k7767 in k7542 in k7539 */
static void C_fcall f_9114(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_9114,2,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9122,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9124,a[2]=((C_word)li30),tmp=(C_word)a,a+=3,tmp);
/* irregex-core.scm:490: fold */
f_9388(t3,t4,C_fix(0),t2);}

/* k9120 in chicken.irregex#string-cat-reverse in k7767 in k7542 in k7539 */
static void C_ccall f_9122(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9122,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9138,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:494: scheme#make-string */
t3=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* a9123 in chicken.irregex#string-cat-reverse in k7767 in k7542 in k7539 */
static void C_ccall f_9124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9124,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_plus(C_i_string_length(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k9136 in k9120 in chicken.irregex#string-cat-reverse in k7767 in k7542 in k7539 */
static void C_ccall f_9138(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9138,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9143,a[2]=t1,a[3]=((C_word)li29),tmp=(C_word)a,a+=4,tmp);
t3=(
  f_9143(t2,((C_word*)t0)[2],((C_word*)t0)[3])
);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* lp in k9136 in k9120 in chicken.irregex#string-cat-reverse in k7767 in k7542 in k7539 */
static C_word C_fcall f_9143(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_i_string_length(t3);
t5=C_fixnum_difference(t1,t4);
t6=C_substring_copy(t3,((C_word*)t0)[2],C_fix(0),t4,t5);
t8=t5;
t9=C_u_i_cdr(t2);
t1=t8;
t2=t9;
goto loop;}
else{
t3=C_SCHEME_UNDEFINED;
return(t3);}}

/* chicken.irregex#zero-to in k7767 in k7542 in k7539 */
static void C_fcall f_9164(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_9164,2,t1,t2);}
a=C_alloc(6);
if(C_truep(C_fixnum_less_or_equal_p(t2,C_fix(0)))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_fixnum_difference(t2,C_fix(1));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9180,a[2]=t5,a[3]=((C_word)li32),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_9180(t7,t1,t3,C_SCHEME_END_OF_LIST);}}

/* lp in chicken.irregex#zero-to in k7767 in k7542 in k7539 */
static void C_fcall f_9180(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_9180,4,t0,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_i_zerop(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,C_fix(0),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fixnum_difference(t2,C_fix(1));
t5=C_a_i_cons(&a,2,t2,t3);
/* irregex-core.scm:512: lp */
t7=t1;
t8=t4;
t9=t5;
t1=t7;
t2=t8;
t3=t9;
goto loop;}}

/* chicken.irregex#find in k7767 in k7542 in k7539 */
static void C_fcall f_9201(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_9201,3,t1,t2,t3);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9207,a[2]=t5,a[3]=t2,a[4]=((C_word)li34),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_9207(t7,t1,t3);}

/* lp in chicken.irregex#find in k7767 in k7542 in k7539 */
static void C_fcall f_9207(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9207,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9220,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:519: pred */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k9218 in lp in chicken.irregex#find in k7767 in k7542 in k7539 */
static void C_ccall f_9220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9220,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* irregex-core.scm:520: lp */
t2=((C_word*)((C_word*)t0)[4])[1];
f_9207(t2,((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[3]));}}

/* chicken.irregex#last in k7767 in k7542 in k7539 */
static void C_fcall f_9262(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_9262,2,t1,t2);}
a=C_alloc(3);
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
/* irregex-core.scm:530: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[60];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9277,a[2]=((C_word)li36),tmp=(C_word)a,a+=3,tmp);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(
  f_9277(t2)
);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* lp in chicken.irregex#last in k7767 in k7542 in k7539 */
static C_word C_fcall f_9277(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
t2=C_i_cdr(t1);
if(C_truep(C_i_pairp(t2))){
t4=C_u_i_cdr(t1);
t1=t4;
goto loop;}
else{
return(C_u_i_car(t1));}}

/* chicken.irregex#any in k7767 in k7542 in k7539 */
static void C_fcall f_9300(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_9300,3,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(C_i_pairp(t3))){
t4=C_u_i_car(t3);
t5=C_u_i_cdr(t3);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9316,a[2]=t2,a[3]=t7,a[4]=((C_word)li38),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_9316(t9,t1,t4,t5);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* lp in chicken.irregex#any in k7767 in k7542 in k7539 */
static void C_fcall f_9316(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9316,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t3))){
/* irregex-core.scm:540: pred */
t4=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9329,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:541: pred */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k9327 in lp in chicken.irregex#any in k7767 in k7542 in k7539 */
static void C_ccall f_9329(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9329,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* irregex-core.scm:541: lp */
t2=((C_word*)((C_word*)t0)[3])[1];
f_9316(t2,((C_word*)t0)[2],C_i_car(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[4]));}}

/* chicken.irregex#every in k7767 in k7542 in k7539 */
static void C_fcall f_9343(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_9343,3,t1,t2,t3);}
a=C_alloc(7);
t4=C_i_nullp(t3);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_car(t3);
t6=C_u_i_cdr(t3);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9361,a[2]=t2,a[3]=t8,a[4]=((C_word)li40),tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_9361(t10,t1,t5,t6);}}

/* lp in chicken.irregex#every in k7767 in k7542 in k7539 */
static void C_fcall f_9361(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9361,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t3))){
/* irregex-core.scm:547: pred */
t4=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9377,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:548: pred */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k9375 in lp in chicken.irregex#every in k7767 in k7542 in k7539 */
static void C_ccall f_9377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9377,c,av);}
if(C_truep(t1)){
/* irregex-core.scm:548: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9361(t2,((C_word*)t0)[3],C_i_car(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[4]));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.irregex#fold in k7767 in k7542 in k7539 */
static void C_fcall f_9388(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_9388,4,t1,t2,t3,t4);}
a=C_alloc(7);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9394,a[2]=t6,a[3]=t2,a[4]=((C_word)li42),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_9394(t8,t1,t4,t3);}

/* lp in chicken.irregex#fold in k7767 in k7542 in k7539 */
static void C_fcall f_9394(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_9394,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9412,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:554: kons */
t6=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_u_i_car(t2);
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* k9410 in lp in chicken.irregex#fold in k7767 in k7542 in k7539 */
static void C_ccall f_9412(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9412,c,av);}
/* irregex-core.scm:554: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9394(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.irregex#flag-join in k7767 in k7542 in k7539 */
static void C_ccall f_9718(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9718,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_fixnum_or(t2,t3):t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.irregex#flag-clear in k7767 in k7542 in k7539 */
static void C_ccall f_9727(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9727,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_and(t2,C_fixnum_not(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.irregex#with-read-from-string in k7767 in k7542 in k7539 */
static void C_fcall f_9745(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,4)))){
C_save_and_reclaim_args((void *)trf_9745,4,t1,t2,t3,t4);}
a=C_alloc(15);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_i_string_length(t2);
t10=C_set_block_item(t6,0,t9);
t11=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9752,a[2]=t6,a[3]=t2,a[4]=t8,a[5]=((C_word)li58),tmp=(C_word)a,a+=6,tmp));
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10317,a[2]=t2,a[3]=t4,a[4]=((C_word)li59),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:720: read */
t13=((C_word*)t8)[1];
f_9752(t13,t1,t3,t12);}

/* f_9752 in chicken.irregex#with-read-from-string in k7767 in k7542 in k7539 */
static void C_fcall f_9752(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,5)))){
C_save_and_reclaim_args((void *)trf_9752,4,t0,t1,t2,t3);}
a=C_alloc(19);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)((C_word*)t0)[2])[1]))){
/* irregex-core.scm:637: chicken.base#error */
t4=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[68];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t4=C_i_string_ref(((C_word*)t0)[3],t2);
switch(t4){
case C_make_character(40):
t5=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9779,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t7,a[6]=((C_word)li49),tmp=(C_word)a,a+=7,tmp));
t9=((C_word*)t7)[1];
f_9779(t9,t1,t5,C_SCHEME_END_OF_LIST);
case C_make_character(41):
t5=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:661: k */
t6=t3;{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[66];
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}
case C_make_character(59):
t5=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9893,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t3,a[6]=t7,a[7]=((C_word)li50),tmp=(C_word)a,a+=8,tmp));
t9=((C_word*)t7)[1];
f_9893(t9,t1,t5);
default:
t5=C_eqp(t4,C_make_character(39));
t6=(C_truep(t5)?t5:C_eqp(t4,C_make_character(96)));
if(C_truep(t6)){
t7=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9942,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=t3,a[5]=((C_word)li51),tmp=(C_word)a,a+=6,tmp);
/* irregex-core.scm:668: read */
t41=t1;
t42=t7;
t43=t8;
t1=t41;
t2=t42;
t3=t43;
goto loop;}
else{
switch(t4){
case C_make_character(44):
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9970,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t8=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
if(C_truep(C_fixnum_lessp(t8,((C_word*)((C_word*)t0)[2])[1]))){
t9=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t10=t7;
f_9970(t10,C_eqp(C_make_character(64),C_i_string_ref(((C_word*)t0)[3],t9)));}
else{
t9=t7;
f_9970(t9,C_SCHEME_FALSE);}
case C_make_character(34):
t7=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t8=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10027,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t10,a[6]=((C_word)li54),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_10027(t12,t1,t7,t8,C_SCHEME_END_OF_LIST);
case C_make_character(35):
t7=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t8=C_i_string_ref(((C_word*)t0)[3],t7);
switch(t8){
case C_make_character(59):
t9=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10128,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=((C_word)li55),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:690: read */
t41=t1;
t42=t9;
t43=t10;
t1=t41;
t2=t42;
t3=t43;
goto loop;
case C_make_character(92):
t9=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10146,a[2]=t3,a[3]=((C_word)li56),tmp=(C_word)a,a+=4,tmp);
/* irregex-core.scm:692: read */
t41=t1;
t42=t9;
t43=t10;
t1=t41;
t2=t42;
t3=t43;
goto loop;
default:
t9=C_eqp(t8,C_make_character(116));
t10=(C_truep(t9)?t9:C_eqp(t8,C_make_character(102)));
if(C_truep(t10)){
t11=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t12=C_i_string_ref(((C_word*)t0)[3],t11);
t13=C_eqp(C_make_character(116),t12);
t14=C_a_i_fixnum_plus(&a,2,t2,C_fix(2));
/* irregex-core.scm:703: k */
t15=t3;{
C_word av2[4];
av2[0]=t15;
av2[1]=t1;
av2[2]=t13;
av2[3]=t14;
((C_proc)(void*)(*((C_word*)t15+1)))(4,av2);}}
else{
/* irregex-core.scm:705: chicken.base#error */
t11=*((C_word*)lf[30]+1);{
C_word av2[4];
av2[0]=t11;
av2[1]=t1;
av2[2]=lf[83];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t11+1)))(4,av2);}}}
default:
if(C_truep(C_u_i_char_whitespacep(C_i_string_ref(((C_word*)t0)[3],t2)))){
t7=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
/* irregex-core.scm:709: read */
t41=t1;
t42=t7;
t43=t3;
t1=t41;
t2=t42;
t3=t43;
goto loop;}
else{
t7=C_a_i_fixnum_plus(&a,2,t2,C_fix(1));
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10246,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=t9,a[7]=((C_word)li57),tmp=(C_word)a,a+=8,tmp));
t11=((C_word*)t9)[1];
f_10246(t11,t1,t7);}}}}}}

/* lp */
static void C_fcall f_9779(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_9779,4,t0,t1,t2,t3);}
a=C_alloc(8);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9785,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word)li48),tmp=(C_word)a,a+=8,tmp);
/* irregex-core.scm:642: read */
t5=((C_word*)((C_word*)t0)[4])[1];
f_9752(t5,t1,t2,t4);}

/* a9784 in lp */
static void C_ccall f_9785(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_9785,c,av);}
a=C_alloc(7);
t4=C_eqp(t2,lf[66]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9799,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:647: ##sys#fast-reverse */
t6=*((C_word*)lf[69]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_eqp(t2,lf[70]);
if(C_truep(t5)){
if(C_truep(C_i_nullp(((C_word*)t0)[3]))){
/* irregex-core.scm:650: chicken.base#error */
t6=*((C_word*)lf[30]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[71];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9819,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word)li47),tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:651: read */
t7=((C_word*)((C_word*)t0)[5])[1];
f_9752(t7,t1,t3,t6);}}
else{
t6=C_a_i_cons(&a,2,t2,((C_word*)t0)[3]);
/* irregex-core.scm:659: lp */
t7=((C_word*)((C_word*)t0)[6])[1];
f_9779(t7,t1,t3,t6);}}}

/* k9797 in a9784 in lp */
static void C_ccall f_9799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9799,c,av);}
/* irregex-core.scm:647: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a9818 in a9784 in lp */
static void C_ccall f_9819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_9819,c,av);}
a=C_alloc(7);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=((C_word)li46),tmp=(C_word)a,a+=7,tmp);
/* irregex-core.scm:652: read */
t5=((C_word*)((C_word*)t0)[5])[1];
f_9752(t5,t1,t3,t4);}

/* a9824 in a9818 in a9784 in lp */
static void C_ccall f_9825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_9825,c,av);}
a=C_alloc(10);
t4=C_eqp(t2,lf[66]);
if(C_truep(C_i_not(t4))){
/* irregex-core.scm:654: chicken.base#error */
t5=*((C_word*)lf[30]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[72];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9842,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9846,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:655: ##sys#fast-reverse */
t7=*((C_word*)lf[69]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_cdr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k9840 in a9824 in a9818 in a9784 in lp */
static void C_ccall f_9842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9842,c,av);}
/* irregex-core.scm:655: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k9844 in a9824 in a9818 in a9784 in lp */
static void C_ccall f_9846(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9846,c,av);}
a=C_alloc(3);
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[3]);
/* irregex-core.scm:655: scheme#append */
t4=*((C_word*)lf[73]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* skip */
static void C_fcall f_9893(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_9893,3,t0,t1,t2);}
t3=C_fixnum_greater_or_equal_p(t2,((C_word*)((C_word*)t0)[2])[1]);
t4=(C_truep(t3)?t3:C_eqp(C_make_character(10),C_i_string_ref(((C_word*)t0)[3],t2)));
if(C_truep(t4)){
/* irregex-core.scm:665: read */
t5=((C_word*)((C_word*)t0)[4])[1];
f_9752(t5,t1,C_fixnum_plus(t2,C_fix(1)),((C_word*)t0)[5]);}
else{
/* irregex-core.scm:666: skip */
t6=t1;
t7=C_fixnum_plus(t2,C_fix(1));
t1=t6;
t2=t7;
goto loop;}}

/* a9941 */
static void C_ccall f_9942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9942,c,av);}
a=C_alloc(6);
t4=C_i_string_ref(((C_word*)t0)[2],((C_word*)t0)[3]);
t5=C_eqp(C_make_character(39),t4);
t6=(C_truep(t5)?lf[74]:lf[75]);
t7=C_a_i_list2(&a,2,t6,t2);
/* irregex-core.scm:671: k */
t8=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t8;
av2[1]=t1;
av2[2]=t7;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}

/* k9968 */
static void C_fcall f_9970(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_9970,2,t0,t1);}
a=C_alloc(10);
t2=(C_truep(t1)?lf[76]:lf[77]);
t3=(C_truep(t1)?C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(2)):C_a_i_fixnum_plus(&a,2,((C_word*)t0)[2],C_fix(1)));
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9981,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word)li52),tmp=(C_word)a,a+=5,tmp);
/* irregex-core.scm:676: read */
t5=((C_word*)((C_word*)t0)[4])[1];
f_9752(t5,((C_word*)t0)[5],t3,t4);}

/* a9980 in k9968 */
static void C_ccall f_9981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
C_check_for_interrupt;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_9981,c,av);}
a=C_alloc(6);
t4=C_a_i_list2(&a,2,((C_word*)t0)[2],t2);
/* irregex-core.scm:676: k */
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* toplevel */
static C_TLS int toplevel_initialized=0;

void C_ccall C_irregex_toplevel(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(toplevel_initialized) {C_kontinue(t1,C_SCHEME_UNDEFINED);}
else C_toplevel_entry(C_text("irregex"));
C_check_nursery_minimum(C_calculate_demand(19,c,2));
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void*)C_irregex_toplevel,c,av);}
toplevel_initialized=1;
if(C_unlikely(!C_demand_2(2387))){
C_save(t1);
C_rereclaim2(2387*sizeof(C_word),1);
t1=C_restore;}
a=C_alloc(19);
C_initialize_lf(lf,502);
lf[0]=C_h_intern(&lf[0],7, C_text("irregex"));
lf[1]=C_h_intern(&lf[1],16, C_text("chicken.irregex#"));
lf[3]=C_h_intern(&lf[3],25, C_text("chicken.base#vector-copy!"));
lf[4]=C_h_intern(&lf[4],18, C_text("scheme#make-vector"));
lf[5]=C_h_intern(&lf[5],24, C_text("chicken.irregex#irregex\077"));
lf[6]=C_h_intern(&lf[6],6, C_text("regexp"));
lf[7]=C_h_intern(&lf[7],38, C_text("chicken.irregex#irregex-num-submatches"));
lf[8]=C_h_intern(&lf[8],22, C_text("irregex-num-submatches"));
lf[9]=C_h_intern(&lf[9],29, C_text("chicken.irregex#irregex-names"));
lf[10]=C_h_intern(&lf[10],13, C_text("irregex-names"));
lf[12]=C_h_intern(&lf[12],12, C_text("regexp-match"));
lf[14]=C_h_intern(&lf[14],19, C_text("scheme#vector-fill!"));
lf[16]=C_h_intern(&lf[16],35, C_text("chicken.irregex#irregex-match-data\077"));
lf[17]=C_h_intern(&lf[17],44, C_text("chicken.irregex#irregex-match-num-submatches"));
lf[18]=C_h_intern(&lf[18],28, C_text("irregex-match-num-submatches"));
lf[19]=C_h_intern(&lf[19],35, C_text("chicken.irregex#irregex-match-names"));
lf[20]=C_h_intern(&lf[20],19, C_text("irregex-match-names"));
lf[21]=C_h_intern(&lf[21],41, C_text("chicken.irregex#irregex-match-start-chunk"));
lf[23]=C_h_intern(&lf[23],25, C_text("irregex-match-start-chunk"));
lf[24]=C_h_intern(&lf[24],41, C_text("chicken.irregex#irregex-match-start-index"));
lf[25]=C_h_intern(&lf[25],25, C_text("irregex-match-start-index"));
lf[26]=C_h_intern(&lf[26],39, C_text("chicken.irregex#irregex-match-end-chunk"));
lf[27]=C_h_intern(&lf[27],23, C_text("irregex-match-end-chunk"));
lf[28]=C_h_intern(&lf[28],39, C_text("chicken.irregex#irregex-match-end-index"));
lf[29]=C_h_intern(&lf[29],23, C_text("irregex-match-end-index"));
lf[30]=C_h_intern(&lf[30],18, C_text("chicken.base#error"));
lf[31]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016not match data"));
lf[32]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022too many arguments"));
lf[33]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021not a valid index"));
lf[34]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[35]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022unknown match name"));
lf[36]=C_h_intern(&lf[36],42, C_text("chicken.irregex#irregex-match-valid-index\077"));
lf[37]=C_h_intern(&lf[37],26, C_text("irregex-match-valid-index\077"));
lf[38]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[39]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016not match data"));
lf[40]=C_h_intern(&lf[40],39, C_text("chicken.irregex#irregex-match-substring"));
lf[41]=C_h_intern(&lf[41],23, C_text("irregex-match-substring"));
lf[42]=C_h_intern(&lf[42],38, C_text("chicken.irregex#irregex-match-subchunk"));
lf[43]=C_decode_literal(C_heaptop,C_text("\376B\000\0000this chunk type does not support match subchunks"));
lf[44]=C_h_intern(&lf[44],22, C_text("irregex-match-subchunk"));
lf[45]=C_h_intern(&lf[45],36, C_text("chicken.irregex#make-irregex-chunker"));
lf[46]=C_h_intern(&lf[46],16, C_text("scheme#substring"));
lf[48]=C_h_intern(&lf[48],20, C_text("make-irregex-chunker"));
lf[49]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023expected a procdure"));
lf[52]=C_h_intern(&lf[52],1, C_text("/"));
lf[55]=C_h_intern(&lf[55],18, C_text("scheme#make-string"));
lf[60]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035can\047t take last of empty list"));
lf[65]=C_h_intern(&lf[65],5, C_text("close"));
lf[68]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031unterminated embedded SRE"));
lf[69]=C_h_intern(&lf[69],18, C_text("##sys#fast-reverse"));
lf[70]=C_h_intern(&lf[70],1, C_text("."));
lf[71]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017bad dotted form"));
lf[72]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017bad dotted form"));
lf[73]=C_h_intern(&lf[73],13, C_text("scheme#append"));
lf[74]=C_h_intern(&lf[74],5, C_text("quote"));
lf[75]=C_h_intern(&lf[75],10, C_text("quasiquote"));
lf[76]=C_h_intern(&lf[76],15, C_text("uquote-splicing"));
lf[77]=C_h_intern(&lf[77],7, C_text("unquote"));
lf[78]=C_decode_literal(C_heaptop,C_text("\376B\000\000#unterminated string in embedded SRE"));
lf[79]=C_h_intern(&lf[79],5, C_text("space"));
lf[80]=C_h_intern(&lf[80],7, C_text("newline"));
lf[81]=C_h_intern(&lf[81],20, C_text("##sys#number->string"));
lf[82]=C_h_intern(&lf[82],21, C_text("scheme#symbol->string"));
lf[83]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad # syntax in simplified SRE"));
lf[84]=C_h_intern(&lf[84],21, C_text("scheme#string->symbol"));
lf[85]=C_h_intern(&lf[85],21, C_text("scheme#string->number"));
lf[86]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000;\376\003\000\000\002\376\377\012\000\000(\376\003\000\000\002\376\377\012\000\000)\376\003\000\000\002\376\377\012\000\000\042\376\003\000\000\002\376\377\012\000\000#\376\003\000\000\002\376\377\012\000\000\134\376\377\016"));
lf[87]=C_h_intern(&lf[87],11, C_text("close-token"));
lf[88]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025unexpected \047)\047 in SRE"));
lf[90]=C_h_intern(&lf[90],1, C_text("i"));
lf[91]=C_h_intern(&lf[91],1, C_text("m"));
lf[92]=C_h_intern(&lf[92],10, C_text("multi-line"));
lf[93]=C_h_intern(&lf[93],1, C_text("s"));
lf[94]=C_h_intern(&lf[94],11, C_text("single-line"));
lf[95]=C_h_intern(&lf[95],1, C_text("x"));
lf[96]=C_h_intern(&lf[96],12, C_text("ignore-space"));
lf[97]=C_h_intern(&lf[97],1, C_text("u"));
lf[98]=C_h_intern(&lf[98],4, C_text("utf8"));
lf[99]=C_h_intern(&lf[99],2, C_text("ci"));
lf[100]=C_h_intern(&lf[100],16, C_text("case-insensitive"));
lf[101]=C_h_intern(&lf[101],33, C_text("chicken.irregex#maybe-string->sre"));
lf[102]=C_h_intern(&lf[102],27, C_text("chicken.irregex#string->sre"));
lf[103]=C_h_intern(&lf[103],2, C_text("or"));
lf[105]=C_h_intern(&lf[105],18, C_text("##sys#string->list"));
lf[108]=C_h_intern(&lf[108],8, C_text("submatch"));
lf[109]=C_h_intern(&lf[109],2, C_text("if"));
lf[110]=C_h_intern(&lf[110],7, C_text("epsilon"));
lf[111]=C_h_intern(&lf[111],10, C_text("look-ahead"));
lf[112]=C_h_intern(&lf[112],14, C_text("neg-look-ahead"));
lf[113]=C_h_intern(&lf[113],11, C_text("look-behind"));
lf[114]=C_h_intern(&lf[114],15, C_text("neg-look-behind"));
lf[115]=C_h_intern(&lf[115],3, C_text("seq"));
lf[116]=C_h_intern(&lf[116],13, C_text("scheme#cddadr"));
lf[117]=C_h_intern(&lf[117],13, C_text("scheme#cadadr"));
lf[118]=C_h_intern(&lf[118],12, C_text("##sys#append"));
lf[119]=C_h_intern(&lf[119],2, C_text("=>"));
lf[120]=C_h_intern(&lf[120],14, C_text("submatch-named"));
lf[121]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\002\001=>\376\003\000\000\002\376\001\000\000\016\001submatch-named\376\377\016"));
lf[122]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001atomic\376\003\000\000\002\376\001\000\000\002\001if\376\003\000\000\002\376\001\000\000\012\001look-ahead\376\003\000\000\002\376\001\000\000\016\001neg-look-ahead\376\003\000\000"
"\002\376\001\000\000\013\001look-behind\376\003\000\000\002\376\001\000\000\017\001neg-look-behind\376\003\000\000\002\376\001\000\000\002\001=>\376\003\000\000\002\376\001\000\000\016\001submatch-nam"
"ed\376\003\000\000\002\376\001\000\000\006\001w/utf8\376\003\000\000\002\376\001\000\000\010\001w/noutf8\376\377\016"));
lf[123]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042unterminated parenthesis in regexp"));
lf[124]=C_h_intern(&lf[124],3, C_text("any"));
lf[125]=C_h_intern(&lf[125],4, C_text("nonl"));
lf[126]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034\077 can\047t follow empty pattern"));
lf[127]=C_h_intern(&lf[127],1, C_text("\052"));
lf[128]=C_h_intern(&lf[128],2, C_text("\052\077"));
lf[129]=C_h_intern(&lf[129],1, C_text("+"));
lf[130]=C_h_intern(&lf[130],3, C_text("\052\052\077"));
lf[131]=C_h_intern(&lf[131],1, C_text("\077"));
lf[132]=C_h_intern(&lf[132],2, C_text("\077\077"));
lf[133]=C_h_intern(&lf[133],2, C_text("\052\052"));
lf[134]=C_h_intern(&lf[134],1, C_text("="));
lf[135]=C_h_intern(&lf[135],2, C_text(">="));
lf[137]=C_decode_literal(C_heaptop,C_text("\376B\000\000)duplicate repetition (e.g. \052\052) in pattern"));
lf[138]=C_decode_literal(C_heaptop,C_text("\376B\000\000%can\047t repeat empty pattern (e.g. ()\052)"));
lf[140]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042unterminated parenthesis in regexp"));
lf[141]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000\077\376\003\000\000\002\376\377\012\000\000\052\376\377\016"));
lf[142]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042unterminated parenthesis in regexp"));
lf[143]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037unterminated (\052\047...) SRE escape"));
lf[144]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047bad regexp syntax: (\052FOO) not supported"));
lf[145]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\012\001look-ahead\376\377\016"));
lf[146]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\016\001neg-look-ahead\376\377\016"));
lf[147]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042unterminated parenthesis in regexp"));
lf[148]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\013\001look-behind\376\377\016"));
lf[149]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\017\001neg-look-behind\376\377\016"));
lf[150]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024invalid (\077< sequence"));
lf[151]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001atomic\376\377\016"));
lf[152]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042unterminated parenthesis in regexp"));
lf[153]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035invalid conditional reference"));
lf[154]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\002\001if\376\377\016"));
lf[155]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036unsupported Perl-style cluster"));
lf[156]=C_h_intern(&lf[156],6, C_text("w/utf8"));
lf[157]=C_h_intern(&lf[157],8, C_text("w/noutf8"));
lf[158]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022incomplete cluster"));
lf[159]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036unknown regex cluster modifier"));
lf[160]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026too many )\047s in regexp"));
lf[161]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023incomplete char set"));
lf[163]=C_h_intern(&lf[163],19, C_text("scheme#vector->list"));
lf[166]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014bad char-set"));
lf[167]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032inverted range in char-set"));
lf[170]=C_decode_literal(C_heaptop,C_text("\376\000\000\001\000\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000"
"\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376"
"\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000"
"\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001"
"\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001"
"\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000"
"\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377"
"\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000"
"\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376"
"\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000"
"\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001"
"\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001"
"\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000"
"\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377"
"\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000"
"\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376"
"\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\001\376\377\001\000\000\000\002\376\377\001\000"
"\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002"
"\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001"
"\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\002\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000"
"\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377\001\000\000\000\003\376\377"
"\001\000\000\000\003\376\377\001\000\000\000\004\376\377\001\000\000\000\004\376\377\001\000\000\000\004\376\377\001\000\000\000\004\376\377\001\000\000\000\004\376\377\001\000\000\000\004\376\377\001\000\000\000\004\376\377\001\000\000\000\004\376\377\001\000\000\000\005\376\377\001\000\000\000\005\376\377\001\000\000"
"\000\005\376\377\001\000\000\000\005\376\377\001\000\000\000\006\376\377\001\000\000\000\006\376\377\001\000\000\000\000\376\377\001\000\000\000\000"));
lf[171]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032incomplete character class"));
lf[173]=C_decode_literal(C_heaptop,C_text("\376B\000\000!collating sequences not supported"));
lf[174]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034{ can\047t follow empty pattern"));
lf[175]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035invalid {n} repetition syntax"));
lf[176]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[177]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032incomplete escape sequence"));
lf[178]=C_h_intern(&lf[178],7, C_text("numeric"));
lf[179]=C_h_intern(&lf[179],1, C_text("~"));
lf[180]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001_"));
lf[181]=C_h_intern(&lf[181],12, C_text("alphanumeric"));
lf[182]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001_"));
lf[183]=C_h_intern(&lf[183],3, C_text("bow"));
lf[184]=C_h_intern(&lf[184],3, C_text("eow"));
lf[185]=C_h_intern(&lf[185],3, C_text("nwb"));
lf[186]=C_h_intern(&lf[186],3, C_text("bos"));
lf[187]=C_h_intern(&lf[187],3, C_text("eos"));
lf[188]=C_h_intern(&lf[188],5, C_text("reset"));
lf[189]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000<\376\003\000\000\002\376\377\012\000\000{\376\003\000\000\002\376\377\012\000\000\047\376\377\016"));
lf[190]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad \134k usage, expected \134k<...>"));
lf[191]=C_h_intern(&lf[191],10, C_text("backref-ci"));
lf[192]=C_h_intern(&lf[192],7, C_text("backref"));
lf[193]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032unterminated named backref"));
lf[194]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027unknown escape sequence"));
lf[195]=C_h_intern(&lf[195],3, C_text("bol"));
lf[196]=C_h_intern(&lf[196],3, C_text("eol"));
lf[197]=C_h_intern(&lf[197],11, C_text("string->sre"));
lf[198]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021expected a string"));
lf[199]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025incomplete hex escape"));
lf[200]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033incomplete hex brace escape"));
lf[201]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024bad hex brace escape"));
lf[202]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025incomplete hex escape"));
lf[203]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016bad hex escape"));
lf[205]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023invalid utf8 length"));
lf[207]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023invalid utf8 length"));
lf[209]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037unicode codepoint out of range:"));
lf[211]=C_h_intern(&lf[211],3, C_text("map"));
lf[215]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023invalid utf8 length"));
lf[217]=C_h_intern(&lf[217],23, C_text("chicken.irregex#irregex"));
lf[218]=C_decode_literal(C_heaptop,C_text("\376\000\000\000\013\376\377\006\000\376\377\006\000\376\377\006\000\376\377\006\000\376\377\006\000\376\377\006\000\376\377\006\000\376\377\006\000\376\377\006\000\376\377\006\000\376\377\001\000\000\000\000"));
lf[219]=C_h_intern(&lf[219],31, C_text("chicken.irregex#string->irregex"));
lf[220]=C_h_intern(&lf[220],28, C_text("chicken.irregex#sre->irregex"));
lf[221]=C_h_intern(&lf[221],5, C_text("small"));
lf[222]=C_h_intern(&lf[222],4, C_text("fast"));
lf[225]=C_h_intern(&lf[225],6, C_text("w/case"));
lf[226]=C_h_intern(&lf[226],8, C_text("w/nocase"));
lf[227]=C_h_intern(&lf[227],1, C_text(":"));
lf[228]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024invalid sre: empty \052"));
lf[229]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025invalid sre: empty \052\077"));
lf[230]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024invalid sre: empty +"));
lf[231]=C_h_intern(&lf[231],4, C_text("word"));
lf[232]=C_h_intern(&lf[232],5, C_text("word+"));
lf[233]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001_"));
lf[234]=C_h_intern(&lf[234],1, C_text("&"));
lf[235]=C_h_intern(&lf[235],12, C_text("posix-string"));
lf[236]=C_h_intern(&lf[236],10, C_text("scheme#not"));
lf[237]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\003\000\000\002\376\001\000\000\003\001any\376\377\016"));
lf[238]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001eos\376\377\016"));
lf[239]=C_h_intern(&lf[239],6, C_text("atomic"));
lf[240]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037unknown named backref in SRE IF"));
lf[241]=C_h_intern(&lf[241],18, C_text("scheme#string-ci=\077"));
lf[242]=C_h_intern(&lf[242],15, C_text("scheme#string=\077"));
lf[243]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025unknown backreference"));
lf[244]=C_h_intern(&lf[244],3, C_text("dsm"));
lf[245]=C_h_intern(&lf[245],1, C_text("$"));
lf[246]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027unknown regexp operator"));
lf[247]=C_h_intern(&lf[247],1, C_text("-"));
lf[249]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016unknown regexp"));
lf[250]=C_h_intern(&lf[250],16, C_text("scheme#char-ci=\077"));
lf[251]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016unknown regexp"));
lf[254]=C_h_intern(&lf[254],10, C_text("scheme#max"));
lf[255]=C_h_intern(&lf[255],10, C_text("scheme#min"));
lf[256]=C_h_intern(&lf[256],10, C_text("sre-length"));
lf[257]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025invalid backreference"));
lf[258]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035invalid forward backreference"));
lf[259]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025unknown backreference"));
lf[260]=C_h_intern(&lf[260],3, C_text(">=\077"));
lf[261]=C_h_intern(&lf[261],17, C_text("sre-length-ranges"));
lf[262]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024unknown sre operator"));
lf[263]=C_h_intern(&lf[263],2, C_text("=\077"));
lf[264]=C_h_intern(&lf[264],6, C_text("commit"));
lf[265]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013unknown sre"));
lf[266]=C_h_intern(&lf[266],11, C_text("scheme#cons"));
lf[269]=C_h_intern(&lf[269],9, C_text("backtrack"));
lf[272]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\003\000\000\002\376\001\000\000\003\001any\376\377\016"));
lf[273]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\003\000\000\002\376\001\000\000\004\001nonl\376\377\016"));
lf[274]=C_h_intern(&lf[274],8, C_text("utf8-any"));
lf[275]=C_h_intern(&lf[275],9, C_text("utf8-nonl"));
lf[276]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\007\001epsilon\376\003\000\000\002\376\001\000\000\003\001bos\376\003\000\000\002\376\001\000\000\003\001eos\376\003\000\000\002\376\001\000\000\003\001bol\376\003\000\000\002\376\001\000\000\003\001eol\376\003\000\000\002\376"
"\001\000\000\003\001bow\376\003\000\000\002\376\001\000\000\003\001eow\376\003\000\000\002\376\001\000\000\006\001commit\376\377\016"));
lf[278]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\003\000\000\002\376\001\000\000\001\001+\376\377\016"));
lf[281]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001$\376\003\000\000\002\376\001\000\000\010\001submatch\376\003\000\000\002\376\001\000\000\002\001=>\376\003\000\000\002\376\001\000\000\016\001submatch-named\376\377\016"));
lf[282]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\002\001or\376\377\016"));
lf[286]=C_h_intern(&lf[286],30, C_text("chicken.irregex#irregex-search"));
lf[287]=C_h_intern(&lf[287],38, C_text("chicken.irregex#irregex-search/chunked"));
lf[288]=C_h_intern(&lf[288],14, C_text("irregex-search"));
lf[289]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[290]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[291]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014not a string"));
lf[293]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016not an integer"));
lf[294]=C_h_intern(&lf[294],11, C_text("irregex-dfa"));
lf[297]=C_h_intern(&lf[297],11, C_text("irregex-nfa"));
lf[298]=C_h_intern(&lf[298],29, C_text("chicken.irregex#irregex-match"));
lf[299]=C_h_intern(&lf[299],37, C_text("chicken.irregex#irregex-match/chunked"));
lf[300]=C_h_intern(&lf[300],13, C_text("irregex-match"));
lf[301]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[302]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[303]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014not a string"));
lf[304]=C_h_intern(&lf[304],30, C_text("chicken.irregex#irregex-match\077"));
lf[306]=C_h_intern(&lf[306],8, C_text("for-each"));
lf[307]=C_h_intern(&lf[307],10, C_text("alphabetic"));
lf[308]=C_h_intern(&lf[308],5, C_text("alpha"));
lf[309]=C_h_intern(&lf[309],8, C_text("alphanum"));
lf[310]=C_h_intern(&lf[310],5, C_text("alnum"));
lf[311]=C_h_intern(&lf[311],10, C_text("lower-case"));
lf[312]=C_h_intern(&lf[312],5, C_text("lower"));
lf[313]=C_h_intern(&lf[313],10, C_text("upper-case"));
lf[314]=C_h_intern(&lf[314],5, C_text("upper"));
lf[315]=C_h_intern(&lf[315],3, C_text("num"));
lf[316]=C_h_intern(&lf[316],5, C_text("digit"));
lf[317]=C_h_intern(&lf[317],11, C_text("punctuation"));
lf[318]=C_h_intern(&lf[318],5, C_text("punct"));
lf[319]=C_h_intern(&lf[319],7, C_text("graphic"));
lf[320]=C_h_intern(&lf[320],5, C_text("graph"));
lf[321]=C_h_intern(&lf[321],5, C_text("blank"));
lf[322]=C_h_intern(&lf[322],10, C_text("whitespace"));
lf[323]=C_h_intern(&lf[323],5, C_text("white"));
lf[324]=C_h_intern(&lf[324],8, C_text("printing"));
lf[325]=C_h_intern(&lf[325],5, C_text("print"));
lf[326]=C_h_intern(&lf[326],7, C_text("control"));
lf[327]=C_h_intern(&lf[327],5, C_text("cntrl"));
lf[328]=C_h_intern(&lf[328],9, C_text("hex-digit"));
lf[329]=C_h_intern(&lf[329],6, C_text("xdigit"));
lf[330]=C_h_intern(&lf[330],5, C_text("ascii"));
lf[331]=C_h_intern(&lf[331],10, C_text("ascii-nonl"));
lf[332]=C_h_intern(&lf[332],14, C_text("utf8-tail-char"));
lf[333]=C_h_intern(&lf[333],11, C_text("utf8-2-char"));
lf[334]=C_h_intern(&lf[334],11, C_text("utf8-3-char"));
lf[335]=C_h_intern(&lf[335],11, C_text("utf8-4-char"));
lf[336]=C_h_intern(&lf[336],7, C_text("integer"));
lf[337]=C_h_intern(&lf[337],4, C_text("real"));
lf[338]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016!$%&\052/:<=>\077^_~"));
lf[339]=C_h_intern(&lf[339],14, C_text("symbol-initial"));
lf[340]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004+-.@"));
lf[341]=C_h_intern(&lf[341],17, C_text("symbol-subsequent"));
lf[342]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002+-"));
lf[343]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001."));
lf[344]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002.."));
lf[345]=C_h_intern(&lf[345],6, C_text("symbol"));
lf[346]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001;"));
lf[347]=C_h_intern(&lf[347],10, C_text("sexp-space"));
lf[348]=C_h_intern(&lf[348],6, C_text("escape"));
lf[349]=C_h_intern(&lf[349],6, C_text("string"));
lf[350]=C_decode_literal(C_heaptop,C_text("\376B\000\000\00212"));
lf[351]=C_h_intern(&lf[351],10, C_text("ipv4-digit"));
lf[352]=C_h_intern(&lf[352],12, C_text("ipv4-address"));
lf[353]=C_h_intern(&lf[353],12, C_text("ipv6-address"));
lf[354]=C_h_intern(&lf[354],10, C_text("ip-address"));
lf[355]=C_h_intern(&lf[355],11, C_text("domain-atom"));
lf[356]=C_h_intern(&lf[356],6, C_text("domain"));
lf[357]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004arpa"));
lf[358]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003com"));
lf[359]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003gov"));
lf[360]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003mil"));
lf[361]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003net"));
lf[362]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003org"));
lf[363]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003edu"));
lf[364]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004aero"));
lf[365]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003biz"));
lf[366]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004coop"));
lf[367]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004info"));
lf[368]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006museum"));
lf[369]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004name"));
lf[370]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003pro"));
lf[371]=C_h_intern(&lf[371],16, C_text("top-level-domain"));
lf[372]=C_h_intern(&lf[372],13, C_text("domain/common"));
lf[373]=C_h_intern(&lf[373],16, C_text("email-local-part"));
lf[374]=C_h_intern(&lf[374],5, C_text("email"));
lf[375]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001%"));
lf[376]=C_h_intern(&lf[376],8, C_text("url-char"));
lf[377]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001%"));
lf[378]=C_h_intern(&lf[378],14, C_text("url-final-char"));
lf[379]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001s"));
lf[380]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001:"));
lf[381]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001/"));
lf[382]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\077"));
lf[383]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001#"));
lf[384]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001/"));
lf[385]=C_h_intern(&lf[385],8, C_text("http-url"));
lf[386]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004http"));
lf[387]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003://"));
lf[390]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[392]=C_h_intern(&lf[392],12, C_text("scheme#cadar"));
lf[393]=C_h_intern(&lf[393],12, C_text("scheme#cddar"));
lf[394]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\007\001epsilon\376\377\016"));
lf[395]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034non-procedure in op position"));
lf[401]=C_h_intern(&lf[401],13, C_text("scheme#caddar"));
lf[406]=C_decode_literal(C_heaptop,C_text("\376B\000\000!not a valid sre char-set operator"));
lf[407]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030not a valid sre char-set"));
lf[409]=C_h_intern(&lf[409],19, C_text("scheme#list->vector"));
lf[411]=C_h_intern(&lf[411],12, C_text("irregex-fold"));
lf[412]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[413]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024not an exact integer"));
lf[414]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014not a string"));
lf[415]=C_h_intern(&lf[415],28, C_text("chicken.irregex#irregex-fold"));
lf[416]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017not a procedure"));
lf[418]=C_h_intern(&lf[418],20, C_text("irregex-fold/chunked"));
lf[419]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016not an integer"));
lf[420]=C_h_intern(&lf[420],36, C_text("chicken.irregex#irregex-fold/chunked"));
lf[421]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017not a procedure"));
lf[422]=C_h_intern(&lf[422],31, C_text("chicken.irregex#irregex-replace"));
lf[424]=C_h_intern(&lf[424],15, C_text("irregex-replace"));
lf[425]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014not a string"));
lf[426]=C_h_intern(&lf[426],35, C_text("chicken.irregex#irregex-replace/all"));
lf[427]=C_h_intern(&lf[427],19, C_text("irregex-replace/all"));
lf[428]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014not a string"));
lf[429]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[430]=C_h_intern(&lf[430],3, C_text("pre"));
lf[431]=C_h_intern(&lf[431],4, C_text("post"));
lf[432]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031unknown match replacement"));
lf[433]=C_h_intern(&lf[433],31, C_text("chicken.irregex#irregex-extract"));
lf[434]=C_h_intern(&lf[434],15, C_text("irregex-extract"));
lf[435]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014not a string"));
lf[436]=C_h_intern(&lf[436],29, C_text("chicken.irregex#irregex-split"));
lf[437]=C_h_intern(&lf[437],20, C_text("scheme#string-append"));
lf[438]=C_h_intern(&lf[438],13, C_text("irregex-split"));
lf[439]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014not a string"));
lf[440]=C_h_intern(&lf[440],29, C_text("chicken.irregex#irregex-quote"));
lf[441]=C_h_intern(&lf[441],18, C_text("##sys#list->string"));
lf[442]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017\134|[](){}.\052+\077^$#"));
lf[443]=C_h_intern(&lf[443],27, C_text("chicken.irregex#irregex-opt"));
lf[444]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[445]=C_h_intern(&lf[445],12, C_text("scheme#char\077"));
lf[446]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376B\000\000\000\376\377\016"));
lf[448]=C_h_intern(&lf[448],30, C_text("chicken.base#get-output-string"));
lf[449]=C_h_intern(&lf[449],14, C_text("scheme#display"));
lf[450]=C_h_intern(&lf[450],21, C_text("##sys#write-char/port"));
lf[451]=C_h_intern(&lf[451],31, C_text("chicken.base#open-output-string"));
lf[452]=C_h_intern(&lf[452],27, C_text("chicken.irregex#sre->string"));
lf[453]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[454]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003(\077:"));
lf[455]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[456]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001("));
lf[457]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[458]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001>"));
lf[459]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003(\077<"));
lf[460]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001|"));
lf[461]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[462]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003(\077:"));
lf[463]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[464]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003(\077:"));
lf[465]=C_h_intern(&lf[465],3, C_text("not"));
lf[466]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001]"));
lf[467]=C_h_intern(&lf[467],12, C_text("scheme#cdadr"));
lf[468]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002[^"));
lf[469]=C_decode_literal(C_heaptop,C_text("\376B\000\000(can\047t represent general \047not\047 in strings"));
lf[470]=C_h_intern(&lf[470],4, C_text("cset"));
lf[471]=C_h_intern(&lf[471],12, C_text("scheme#caadr"));
lf[472]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001]"));
lf[473]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001["));
lf[474]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001]"));
lf[475]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002[^"));
lf[476]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[477]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001:"));
lf[478]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001-"));
lf[479]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002(\077"));
lf[480]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024unknown sre operator"));
lf[481]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001^"));
lf[482]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001$"));
lf[483]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001."));
lf[484]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022unknown sre symbol"));
lf[485]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023unknown sre pattern"));
lf[486]=C_h_intern(&lf[486],25, C_text("chicken.irregex#glob->sre"));
lf[487]=C_h_intern(&lf[487],9, C_text("glob->sre"));
lf[488]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003./\134"));
lf[489]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002/\134"));
lf[490]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003./\134"));
lf[491]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002/\134"));
lf[492]=C_decode_literal(C_heaptop,C_text("\376B\000\000!unexpected end of character class"));
lf[493]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000\134\376\003\000\000\002\376\377\012\000\000/\376\377\016"));
lf[494]=C_h_intern(&lf[494],10, C_text("scheme#car"));
lf[495]=C_h_intern(&lf[495],11, C_text("scheme#cadr"));
lf[496]=C_h_intern(&lf[496],12, C_text("scheme#caddr"));
lf[497]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002)>"));
lf[498]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002es"));
lf[499]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011 submatch"));
lf[500]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020#<regexp-match ("));
lf[501]=C_h_intern(&lf[501],32, C_text("chicken.base#set-record-printer!"));
C_register_lf2(lf,502,create_ptable());{}
t2=C_a_i_provide(&a,1,lf[0]);
t3=C_a_i_provide(&a,1,lf[1]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7541,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t4;
C_library_toplevel(2,av2);}}

#ifdef C_ENABLE_PTABLES
static C_PTABLE_ENTRY ptable[1212] = {
{C_text("f33662:irregex_2escm"),(void*)f33662},
{C_text("f33666:irregex_2escm"),(void*)f33666},
{C_text("f_10027:irregex_2escm"),(void*)f_10027},
{C_text("f_10030:irregex_2escm"),(void*)f_10030},
{C_text("f_10044:irregex_2escm"),(void*)f_10044},
{C_text("f_10069:irregex_2escm"),(void*)f_10069},
{C_text("f_10076:irregex_2escm"),(void*)f_10076},
{C_text("f_10095:irregex_2escm"),(void*)f_10095},
{C_text("f_10128:irregex_2escm"),(void*)f_10128},
{C_text("f_10146:irregex_2escm"),(void*)f_10146},
{C_text("f_10166:irregex_2escm"),(void*)f_10166},
{C_text("f_10246:irregex_2escm"),(void*)f_10246},
{C_text("f_10256:irregex_2escm"),(void*)f_10256},
{C_text("f_10259:irregex_2escm"),(void*)f_10259},
{C_text("f_10266:irregex_2escm"),(void*)f_10266},
{C_text("f_10269:irregex_2escm"),(void*)f_10269},
{C_text("f_10317:irregex_2escm"),(void*)f_10317},
{C_text("f_10338:irregex_2escm"),(void*)f_10338},
{C_text("f_10344:irregex_2escm"),(void*)f_10344},
{C_text("f_10362:irregex_2escm"),(void*)f_10362},
{C_text("f_10373:irregex_2escm"),(void*)f_10373},
{C_text("f_10461:irregex_2escm"),(void*)f_10461},
{C_text("f_10473:irregex_2escm"),(void*)f_10473},
{C_text("f_10477:irregex_2escm"),(void*)f_10477},
{C_text("f_10483:irregex_2escm"),(void*)f_10483},
{C_text("f_10488:irregex_2escm"),(void*)f_10488},
{C_text("f_10491:irregex_2escm"),(void*)f_10491},
{C_text("f_10513:irregex_2escm"),(void*)f_10513},
{C_text("f_10530:irregex_2escm"),(void*)f_10530},
{C_text("f_10533:irregex_2escm"),(void*)f_10533},
{C_text("f_10535:irregex_2escm"),(void*)f_10535},
{C_text("f_10569:irregex_2escm"),(void*)f_10569},
{C_text("f_10583:irregex_2escm"),(void*)f_10583},
{C_text("f_10587:irregex_2escm"),(void*)f_10587},
{C_text("f_10589:irregex_2escm"),(void*)f_10589},
{C_text("f_10596:irregex_2escm"),(void*)f_10596},
{C_text("f_10605:irregex_2escm"),(void*)f_10605},
{C_text("f_10625:irregex_2escm"),(void*)f_10625},
{C_text("f_10629:irregex_2escm"),(void*)f_10629},
{C_text("f_10633:irregex_2escm"),(void*)f_10633},
{C_text("f_10661:irregex_2escm"),(void*)f_10661},
{C_text("f_10665:irregex_2escm"),(void*)f_10665},
{C_text("f_10668:irregex_2escm"),(void*)f_10668},
{C_text("f_10671:irregex_2escm"),(void*)f_10671},
{C_text("f_10674:irregex_2escm"),(void*)f_10674},
{C_text("f_10679:irregex_2escm"),(void*)f_10679},
{C_text("f_10682:irregex_2escm"),(void*)f_10682},
{C_text("f_10752:irregex_2escm"),(void*)f_10752},
{C_text("f_10768:irregex_2escm"),(void*)f_10768},
{C_text("f_10844:irregex_2escm"),(void*)f_10844},
{C_text("f_10855:irregex_2escm"),(void*)f_10855},
{C_text("f_10869:irregex_2escm"),(void*)f_10869},
{C_text("f_10891:irregex_2escm"),(void*)f_10891},
{C_text("f_10894:irregex_2escm"),(void*)f_10894},
{C_text("f_10906:irregex_2escm"),(void*)f_10906},
{C_text("f_10966:irregex_2escm"),(void*)f_10966},
{C_text("f_10995:irregex_2escm"),(void*)f_10995},
{C_text("f_11126:irregex_2escm"),(void*)f_11126},
{C_text("f_11132:irregex_2escm"),(void*)f_11132},
{C_text("f_11147:irregex_2escm"),(void*)f_11147},
{C_text("f_11218:irregex_2escm"),(void*)f_11218},
{C_text("f_11248:irregex_2escm"),(void*)f_11248},
{C_text("f_11258:irregex_2escm"),(void*)f_11258},
{C_text("f_11280:irregex_2escm"),(void*)f_11280},
{C_text("f_11315:irregex_2escm"),(void*)f_11315},
{C_text("f_11330:irregex_2escm"),(void*)f_11330},
{C_text("f_11356:irregex_2escm"),(void*)f_11356},
{C_text("f_11379:irregex_2escm"),(void*)f_11379},
{C_text("f_11402:irregex_2escm"),(void*)f_11402},
{C_text("f_11444:irregex_2escm"),(void*)f_11444},
{C_text("f_11467:irregex_2escm"),(void*)f_11467},
{C_text("f_11470:irregex_2escm"),(void*)f_11470},
{C_text("f_11496:irregex_2escm"),(void*)f_11496},
{C_text("f_11500:irregex_2escm"),(void*)f_11500},
{C_text("f_11504:irregex_2escm"),(void*)f_11504},
{C_text("f_11556:irregex_2escm"),(void*)f_11556},
{C_text("f_11581:irregex_2escm"),(void*)f_11581},
{C_text("f_11584:irregex_2escm"),(void*)f_11584},
{C_text("f_11614:irregex_2escm"),(void*)f_11614},
{C_text("f_11618:irregex_2escm"),(void*)f_11618},
{C_text("f_11633:irregex_2escm"),(void*)f_11633},
{C_text("f_11636:irregex_2escm"),(void*)f_11636},
{C_text("f_11657:irregex_2escm"),(void*)f_11657},
{C_text("f_11661:irregex_2escm"),(void*)f_11661},
{C_text("f_11684:irregex_2escm"),(void*)f_11684},
{C_text("f_11715:irregex_2escm"),(void*)f_11715},
{C_text("f_11718:irregex_2escm"),(void*)f_11718},
{C_text("f_11727:irregex_2escm"),(void*)f_11727},
{C_text("f_11871:irregex_2escm"),(void*)f_11871},
{C_text("f_11902:irregex_2escm"),(void*)f_11902},
{C_text("f_11993:irregex_2escm"),(void*)f_11993},
{C_text("f_12008:irregex_2escm"),(void*)f_12008},
{C_text("f_12028:irregex_2escm"),(void*)f_12028},
{C_text("f_12032:irregex_2escm"),(void*)f_12032},
{C_text("f_12051:irregex_2escm"),(void*)f_12051},
{C_text("f_12060:irregex_2escm"),(void*)f_12060},
{C_text("f_12076:irregex_2escm"),(void*)f_12076},
{C_text("f_12079:irregex_2escm"),(void*)f_12079},
{C_text("f_12082:irregex_2escm"),(void*)f_12082},
{C_text("f_12085:irregex_2escm"),(void*)f_12085},
{C_text("f_12094:irregex_2escm"),(void*)f_12094},
{C_text("f_12204:irregex_2escm"),(void*)f_12204},
{C_text("f_12280:irregex_2escm"),(void*)f_12280},
{C_text("f_12307:irregex_2escm"),(void*)f_12307},
{C_text("f_12330:irregex_2escm"),(void*)f_12330},
{C_text("f_12357:irregex_2escm"),(void*)f_12357},
{C_text("f_12384:irregex_2escm"),(void*)f_12384},
{C_text("f_12415:irregex_2escm"),(void*)f_12415},
{C_text("f_12450:irregex_2escm"),(void*)f_12450},
{C_text("f_12473:irregex_2escm"),(void*)f_12473},
{C_text("f_12496:irregex_2escm"),(void*)f_12496},
{C_text("f_12527:irregex_2escm"),(void*)f_12527},
{C_text("f_12550:irregex_2escm"),(void*)f_12550},
{C_text("f_12573:irregex_2escm"),(void*)f_12573},
{C_text("f_12596:irregex_2escm"),(void*)f_12596},
{C_text("f_12619:irregex_2escm"),(void*)f_12619},
{C_text("f_12642:irregex_2escm"),(void*)f_12642},
{C_text("f_12653:irregex_2escm"),(void*)f_12653},
{C_text("f_12673:irregex_2escm"),(void*)f_12673},
{C_text("f_12677:irregex_2escm"),(void*)f_12677},
{C_text("f_12701:irregex_2escm"),(void*)f_12701},
{C_text("f_12704:irregex_2escm"),(void*)f_12704},
{C_text("f_12707:irregex_2escm"),(void*)f_12707},
{C_text("f_12742:irregex_2escm"),(void*)f_12742},
{C_text("f_12746:irregex_2escm"),(void*)f_12746},
{C_text("f_12773:irregex_2escm"),(void*)f_12773},
{C_text("f_12781:irregex_2escm"),(void*)f_12781},
{C_text("f_12841:irregex_2escm"),(void*)f_12841},
{C_text("f_12884:irregex_2escm"),(void*)f_12884},
{C_text("f_12896:irregex_2escm"),(void*)f_12896},
{C_text("f_12905:irregex_2escm"),(void*)f_12905},
{C_text("f_12925:irregex_2escm"),(void*)f_12925},
{C_text("f_12929:irregex_2escm"),(void*)f_12929},
{C_text("f_12933:irregex_2escm"),(void*)f_12933},
{C_text("f_12985:irregex_2escm"),(void*)f_12985},
{C_text("f_13001:irregex_2escm"),(void*)f_13001},
{C_text("f_13065:irregex_2escm"),(void*)f_13065},
{C_text("f_13091:irregex_2escm"),(void*)f_13091},
{C_text("f_13120:irregex_2escm"),(void*)f_13120},
{C_text("f_13148:irregex_2escm"),(void*)f_13148},
{C_text("f_13169:irregex_2escm"),(void*)f_13169},
{C_text("f_13187:irregex_2escm"),(void*)f_13187},
{C_text("f_13301:irregex_2escm"),(void*)f_13301},
{C_text("f_13320:irregex_2escm"),(void*)f_13320},
{C_text("f_13332:irregex_2escm"),(void*)f_13332},
{C_text("f_13335:irregex_2escm"),(void*)f_13335},
{C_text("f_13366:irregex_2escm"),(void*)f_13366},
{C_text("f_13369:irregex_2escm"),(void*)f_13369},
{C_text("f_13410:irregex_2escm"),(void*)f_13410},
{C_text("f_13445:irregex_2escm"),(void*)f_13445},
{C_text("f_13455:irregex_2escm"),(void*)f_13455},
{C_text("f_13462:irregex_2escm"),(void*)f_13462},
{C_text("f_13483:irregex_2escm"),(void*)f_13483},
{C_text("f_13493:irregex_2escm"),(void*)f_13493},
{C_text("f_13510:irregex_2escm"),(void*)f_13510},
{C_text("f_13527:irregex_2escm"),(void*)f_13527},
{C_text("f_13538:irregex_2escm"),(void*)f_13538},
{C_text("f_13539:irregex_2escm"),(void*)f_13539},
{C_text("f_13560:irregex_2escm"),(void*)f_13560},
{C_text("f_13572:irregex_2escm"),(void*)f_13572},
{C_text("f_13582:irregex_2escm"),(void*)f_13582},
{C_text("f_13685:irregex_2escm"),(void*)f_13685},
{C_text("f_13694:irregex_2escm"),(void*)f_13694},
{C_text("f_13700:irregex_2escm"),(void*)f_13700},
{C_text("f_13703:irregex_2escm"),(void*)f_13703},
{C_text("f_13713:irregex_2escm"),(void*)f_13713},
{C_text("f_13720:irregex_2escm"),(void*)f_13720},
{C_text("f_13724:irregex_2escm"),(void*)f_13724},
{C_text("f_13768:irregex_2escm"),(void*)f_13768},
{C_text("f_13807:irregex_2escm"),(void*)f_13807},
{C_text("f_13817:irregex_2escm"),(void*)f_13817},
{C_text("f_13821:irregex_2escm"),(void*)f_13821},
{C_text("f_13825:irregex_2escm"),(void*)f_13825},
{C_text("f_13840:irregex_2escm"),(void*)f_13840},
{C_text("f_13848:irregex_2escm"),(void*)f_13848},
{C_text("f_13852:irregex_2escm"),(void*)f_13852},
{C_text("f_13871:irregex_2escm"),(void*)f_13871},
{C_text("f_13924:irregex_2escm"),(void*)f_13924},
{C_text("f_13938:irregex_2escm"),(void*)f_13938},
{C_text("f_13942:irregex_2escm"),(void*)f_13942},
{C_text("f_13946:irregex_2escm"),(void*)f_13946},
{C_text("f_13956:irregex_2escm"),(void*)f_13956},
{C_text("f_14014:irregex_2escm"),(void*)f_14014},
{C_text("f_14035:irregex_2escm"),(void*)f_14035},
{C_text("f_14038:irregex_2escm"),(void*)f_14038},
{C_text("f_14230:irregex_2escm"),(void*)f_14230},
{C_text("f_14268:irregex_2escm"),(void*)f_14268},
{C_text("f_14344:irregex_2escm"),(void*)f_14344},
{C_text("f_14485:irregex_2escm"),(void*)f_14485},
{C_text("f_14488:irregex_2escm"),(void*)f_14488},
{C_text("f_14509:irregex_2escm"),(void*)f_14509},
{C_text("f_14514:irregex_2escm"),(void*)f_14514},
{C_text("f_14546:irregex_2escm"),(void*)f_14546},
{C_text("f_14571:irregex_2escm"),(void*)f_14571},
{C_text("f_14575:irregex_2escm"),(void*)f_14575},
{C_text("f_14586:irregex_2escm"),(void*)f_14586},
{C_text("f_14594:irregex_2escm"),(void*)f_14594},
{C_text("f_14620:irregex_2escm"),(void*)f_14620},
{C_text("f_14650:irregex_2escm"),(void*)f_14650},
{C_text("f_14660:irregex_2escm"),(void*)f_14660},
{C_text("f_14668:irregex_2escm"),(void*)f_14668},
{C_text("f_14684:irregex_2escm"),(void*)f_14684},
{C_text("f_14686:irregex_2escm"),(void*)f_14686},
{C_text("f_14722:irregex_2escm"),(void*)f_14722},
{C_text("f_14758:irregex_2escm"),(void*)f_14758},
{C_text("f_14778:irregex_2escm"),(void*)f_14778},
{C_text("f_14780:irregex_2escm"),(void*)f_14780},
{C_text("f_14812:irregex_2escm"),(void*)f_14812},
{C_text("f_14819:irregex_2escm"),(void*)f_14819},
{C_text("f_14825:irregex_2escm"),(void*)f_14825},
{C_text("f_14841:irregex_2escm"),(void*)f_14841},
{C_text("f_14843:irregex_2escm"),(void*)f_14843},
{C_text("f_14883:irregex_2escm"),(void*)f_14883},
{C_text("f_14889:irregex_2escm"),(void*)f_14889},
{C_text("f_14897:irregex_2escm"),(void*)f_14897},
{C_text("f_14917:irregex_2escm"),(void*)f_14917},
{C_text("f_14919:irregex_2escm"),(void*)f_14919},
{C_text("f_14951:irregex_2escm"),(void*)f_14951},
{C_text("f_14958:irregex_2escm"),(void*)f_14958},
{C_text("f_14964:irregex_2escm"),(void*)f_14964},
{C_text("f_14980:irregex_2escm"),(void*)f_14980},
{C_text("f_14982:irregex_2escm"),(void*)f_14982},
{C_text("f_15022:irregex_2escm"),(void*)f_15022},
{C_text("f_15028:irregex_2escm"),(void*)f_15028},
{C_text("f_15047:irregex_2escm"),(void*)f_15047},
{C_text("f_15056:irregex_2escm"),(void*)f_15056},
{C_text("f_15068:irregex_2escm"),(void*)f_15068},
{C_text("f_15080:irregex_2escm"),(void*)f_15080},
{C_text("f_15086:irregex_2escm"),(void*)f_15086},
{C_text("f_15088:irregex_2escm"),(void*)f_15088},
{C_text("f_15136:irregex_2escm"),(void*)f_15136},
{C_text("f_15144:irregex_2escm"),(void*)f_15144},
{C_text("f_15151:irregex_2escm"),(void*)f_15151},
{C_text("f_15157:irregex_2escm"),(void*)f_15157},
{C_text("f_15189:irregex_2escm"),(void*)f_15189},
{C_text("f_15191:irregex_2escm"),(void*)f_15191},
{C_text("f_15241:irregex_2escm"),(void*)f_15241},
{C_text("f_15259:irregex_2escm"),(void*)f_15259},
{C_text("f_15284:irregex_2escm"),(void*)f_15284},
{C_text("f_15327:irregex_2escm"),(void*)f_15327},
{C_text("f_15329:irregex_2escm"),(void*)f_15329},
{C_text("f_15418:irregex_2escm"),(void*)f_15418},
{C_text("f_15420:irregex_2escm"),(void*)f_15420},
{C_text("f_15475:irregex_2escm"),(void*)f_15475},
{C_text("f_15483:irregex_2escm"),(void*)f_15483},
{C_text("f_15485:irregex_2escm"),(void*)f_15485},
{C_text("f_15499:irregex_2escm"),(void*)f_15499},
{C_text("f_15503:irregex_2escm"),(void*)f_15503},
{C_text("f_15521:irregex_2escm"),(void*)f_15521},
{C_text("f_15530:irregex_2escm"),(void*)f_15530},
{C_text("f_15545:irregex_2escm"),(void*)f_15545},
{C_text("f_15597:irregex_2escm"),(void*)f_15597},
{C_text("f_15600:irregex_2escm"),(void*)f_15600},
{C_text("f_15657:irregex_2escm"),(void*)f_15657},
{C_text("f_15668:irregex_2escm"),(void*)f_15668},
{C_text("f_15670:irregex_2escm"),(void*)f_15670},
{C_text("f_15695:irregex_2escm"),(void*)f_15695},
{C_text("f_15718:irregex_2escm"),(void*)f_15718},
{C_text("f_15729:irregex_2escm"),(void*)f_15729},
{C_text("f_15731:irregex_2escm"),(void*)f_15731},
{C_text("f_15756:irregex_2escm"),(void*)f_15756},
{C_text("f_15772:irregex_2escm"),(void*)f_15772},
{C_text("f_15781:irregex_2escm"),(void*)f_15781},
{C_text("f_15787:irregex_2escm"),(void*)f_15787},
{C_text("f_15797:irregex_2escm"),(void*)f_15797},
{C_text("f_15804:irregex_2escm"),(void*)f_15804},
{C_text("f_15839:irregex_2escm"),(void*)f_15839},
{C_text("f_15841:irregex_2escm"),(void*)f_15841},
{C_text("f_15866:irregex_2escm"),(void*)f_15866},
{C_text("f_15895:irregex_2escm"),(void*)f_15895},
{C_text("f_15897:irregex_2escm"),(void*)f_15897},
{C_text("f_15922:irregex_2escm"),(void*)f_15922},
{C_text("f_15986:irregex_2escm"),(void*)f_15986},
{C_text("f_15996:irregex_2escm"),(void*)f_15996},
{C_text("f_15999:irregex_2escm"),(void*)f_15999},
{C_text("f_16001:irregex_2escm"),(void*)f_16001},
{C_text("f_16048:irregex_2escm"),(void*)f_16048},
{C_text("f_16055:irregex_2escm"),(void*)f_16055},
{C_text("f_16109:irregex_2escm"),(void*)f_16109},
{C_text("f_16176:irregex_2escm"),(void*)f_16176},
{C_text("f_16184:irregex_2escm"),(void*)f_16184},
{C_text("f_16186:irregex_2escm"),(void*)f_16186},
{C_text("f_16190:irregex_2escm"),(void*)f_16190},
{C_text("f_16193:irregex_2escm"),(void*)f_16193},
{C_text("f_16196:irregex_2escm"),(void*)f_16196},
{C_text("f_16199:irregex_2escm"),(void*)f_16199},
{C_text("f_16205:irregex_2escm"),(void*)f_16205},
{C_text("f_16208:irregex_2escm"),(void*)f_16208},
{C_text("f_16211:irregex_2escm"),(void*)f_16211},
{C_text("f_16214:irregex_2escm"),(void*)f_16214},
{C_text("f_16217:irregex_2escm"),(void*)f_16217},
{C_text("f_16232:irregex_2escm"),(void*)f_16232},
{C_text("f_16246:irregex_2escm"),(void*)f_16246},
{C_text("f_16251:irregex_2escm"),(void*)f_16251},
{C_text("f_16277:irregex_2escm"),(void*)f_16277},
{C_text("f_16281:irregex_2escm"),(void*)f_16281},
{C_text("f_16319:irregex_2escm"),(void*)f_16319},
{C_text("f_16336:irregex_2escm"),(void*)f_16336},
{C_text("f_16379:irregex_2escm"),(void*)f_16379},
{C_text("f_16486:irregex_2escm"),(void*)f_16486},
{C_text("f_16509:irregex_2escm"),(void*)f_16509},
{C_text("f_16587:irregex_2escm"),(void*)f_16587},
{C_text("f_16632:irregex_2escm"),(void*)f_16632},
{C_text("f_16649:irregex_2escm"),(void*)f_16649},
{C_text("f_16721:irregex_2escm"),(void*)f_16721},
{C_text("f_16725:irregex_2escm"),(void*)f_16725},
{C_text("f_16762:irregex_2escm"),(void*)f_16762},
{C_text("f_16838:irregex_2escm"),(void*)f_16838},
{C_text("f_16842:irregex_2escm"),(void*)f_16842},
{C_text("f_16879:irregex_2escm"),(void*)f_16879},
{C_text("f_16892:irregex_2escm"),(void*)f_16892},
{C_text("f_16955:irregex_2escm"),(void*)f_16955},
{C_text("f_16981:irregex_2escm"),(void*)f_16981},
{C_text("f_16994:irregex_2escm"),(void*)f_16994},
{C_text("f_17000:irregex_2escm"),(void*)f_17000},
{C_text("f_17021:irregex_2escm"),(void*)f_17021},
{C_text("f_17027:irregex_2escm"),(void*)f_17027},
{C_text("f_17057:irregex_2escm"),(void*)f_17057},
{C_text("f_17094:irregex_2escm"),(void*)f_17094},
{C_text("f_17097:irregex_2escm"),(void*)f_17097},
{C_text("f_17104:irregex_2escm"),(void*)f_17104},
{C_text("f_17106:irregex_2escm"),(void*)f_17106},
{C_text("f_17109:irregex_2escm"),(void*)f_17109},
{C_text("f_17149:irregex_2escm"),(void*)f_17149},
{C_text("f_17165:irregex_2escm"),(void*)f_17165},
{C_text("f_17178:irregex_2escm"),(void*)f_17178},
{C_text("f_17185:irregex_2escm"),(void*)f_17185},
{C_text("f_17218:irregex_2escm"),(void*)f_17218},
{C_text("f_17248:irregex_2escm"),(void*)f_17248},
{C_text("f_17263:irregex_2escm"),(void*)f_17263},
{C_text("f_17300:irregex_2escm"),(void*)f_17300},
{C_text("f_17316:irregex_2escm"),(void*)f_17316},
{C_text("f_17320:irregex_2escm"),(void*)f_17320},
{C_text("f_17333:irregex_2escm"),(void*)f_17333},
{C_text("f_17356:irregex_2escm"),(void*)f_17356},
{C_text("f_17359:irregex_2escm"),(void*)f_17359},
{C_text("f_17366:irregex_2escm"),(void*)f_17366},
{C_text("f_17368:irregex_2escm"),(void*)f_17368},
{C_text("f_17382:irregex_2escm"),(void*)f_17382},
{C_text("f_17396:irregex_2escm"),(void*)f_17396},
{C_text("f_17421:irregex_2escm"),(void*)f_17421},
{C_text("f_17425:irregex_2escm"),(void*)f_17425},
{C_text("f_17502:irregex_2escm"),(void*)f_17502},
{C_text("f_17515:irregex_2escm"),(void*)f_17515},
{C_text("f_17551:irregex_2escm"),(void*)f_17551},
{C_text("f_17560:irregex_2escm"),(void*)f_17560},
{C_text("f_17660:irregex_2escm"),(void*)f_17660},
{C_text("f_17669:irregex_2escm"),(void*)f_17669},
{C_text("f_17687:irregex_2escm"),(void*)f_17687},
{C_text("f_17690:irregex_2escm"),(void*)f_17690},
{C_text("f_17708:irregex_2escm"),(void*)f_17708},
{C_text("f_17755:irregex_2escm"),(void*)f_17755},
{C_text("f_17829:irregex_2escm"),(void*)f_17829},
{C_text("f_17857:irregex_2escm"),(void*)f_17857},
{C_text("f_17882:irregex_2escm"),(void*)f_17882},
{C_text("f_17901:irregex_2escm"),(void*)f_17901},
{C_text("f_17922:irregex_2escm"),(void*)f_17922},
{C_text("f_17932:irregex_2escm"),(void*)f_17932},
{C_text("f_17940:irregex_2escm"),(void*)f_17940},
{C_text("f_18171:irregex_2escm"),(void*)f_18171},
{C_text("f_18194:irregex_2escm"),(void*)f_18194},
{C_text("f_18203:irregex_2escm"),(void*)f_18203},
{C_text("f_18226:irregex_2escm"),(void*)f_18226},
{C_text("f_18249:irregex_2escm"),(void*)f_18249},
{C_text("f_18322:irregex_2escm"),(void*)f_18322},
{C_text("f_18347:irregex_2escm"),(void*)f_18347},
{C_text("f_18382:irregex_2escm"),(void*)f_18382},
{C_text("f_18405:irregex_2escm"),(void*)f_18405},
{C_text("f_18409:irregex_2escm"),(void*)f_18409},
{C_text("f_18430:irregex_2escm"),(void*)f_18430},
{C_text("f_18532:irregex_2escm"),(void*)f_18532},
{C_text("f_18716:irregex_2escm"),(void*)f_18716},
{C_text("f_18738:irregex_2escm"),(void*)f_18738},
{C_text("f_18744:irregex_2escm"),(void*)f_18744},
{C_text("f_18748:irregex_2escm"),(void*)f_18748},
{C_text("f_18765:irregex_2escm"),(void*)f_18765},
{C_text("f_18798:irregex_2escm"),(void*)f_18798},
{C_text("f_18835:irregex_2escm"),(void*)f_18835},
{C_text("f_18837:irregex_2escm"),(void*)f_18837},
{C_text("f_18862:irregex_2escm"),(void*)f_18862},
{C_text("f_18930:irregex_2escm"),(void*)f_18930},
{C_text("f_18932:irregex_2escm"),(void*)f_18932},
{C_text("f_18936:irregex_2escm"),(void*)f_18936},
{C_text("f_18945:irregex_2escm"),(void*)f_18945},
{C_text("f_18951:irregex_2escm"),(void*)f_18951},
{C_text("f_18954:irregex_2escm"),(void*)f_18954},
{C_text("f_19022:irregex_2escm"),(void*)f_19022},
{C_text("f_19026:irregex_2escm"),(void*)f_19026},
{C_text("f_19029:irregex_2escm"),(void*)f_19029},
{C_text("f_19032:irregex_2escm"),(void*)f_19032},
{C_text("f_19035:irregex_2escm"),(void*)f_19035},
{C_text("f_19065:irregex_2escm"),(void*)f_19065},
{C_text("f_19084:irregex_2escm"),(void*)f_19084},
{C_text("f_19109:irregex_2escm"),(void*)f_19109},
{C_text("f_19126:irregex_2escm"),(void*)f_19126},
{C_text("f_19130:irregex_2escm"),(void*)f_19130},
{C_text("f_19135:irregex_2escm"),(void*)f_19135},
{C_text("f_19142:irregex_2escm"),(void*)f_19142},
{C_text("f_19165:irregex_2escm"),(void*)f_19165},
{C_text("f_19175:irregex_2escm"),(void*)f_19175},
{C_text("f_19196:irregex_2escm"),(void*)f_19196},
{C_text("f_19214:irregex_2escm"),(void*)f_19214},
{C_text("f_19220:irregex_2escm"),(void*)f_19220},
{C_text("f_19234:irregex_2escm"),(void*)f_19234},
{C_text("f_19240:irregex_2escm"),(void*)f_19240},
{C_text("f_19247:irregex_2escm"),(void*)f_19247},
{C_text("f_19277:irregex_2escm"),(void*)f_19277},
{C_text("f_19290:irregex_2escm"),(void*)f_19290},
{C_text("f_19297:irregex_2escm"),(void*)f_19297},
{C_text("f_19304:irregex_2escm"),(void*)f_19304},
{C_text("f_19306:irregex_2escm"),(void*)f_19306},
{C_text("f_19314:irregex_2escm"),(void*)f_19314},
{C_text("f_19318:irregex_2escm"),(void*)f_19318},
{C_text("f_19327:irregex_2escm"),(void*)f_19327},
{C_text("f_19333:irregex_2escm"),(void*)f_19333},
{C_text("f_19336:irregex_2escm"),(void*)f_19336},
{C_text("f_19404:irregex_2escm"),(void*)f_19404},
{C_text("f_19408:irregex_2escm"),(void*)f_19408},
{C_text("f_19411:irregex_2escm"),(void*)f_19411},
{C_text("f_19426:irregex_2escm"),(void*)f_19426},
{C_text("f_19449:irregex_2escm"),(void*)f_19449},
{C_text("f_19460:irregex_2escm"),(void*)f_19460},
{C_text("f_19496:irregex_2escm"),(void*)f_19496},
{C_text("f_19506:irregex_2escm"),(void*)f_19506},
{C_text("f_19512:irregex_2escm"),(void*)f_19512},
{C_text("f_19518:irregex_2escm"),(void*)f_19518},
{C_text("f_19528:irregex_2escm"),(void*)f_19528},
{C_text("f_19530:irregex_2escm"),(void*)f_19530},
{C_text("f_19540:irregex_2escm"),(void*)f_19540},
{C_text("f_19559:irregex_2escm"),(void*)f_19559},
{C_text("f_19572:irregex_2escm"),(void*)f_19572},
{C_text("f_19604:irregex_2escm"),(void*)f_19604},
{C_text("f_19627:irregex_2escm"),(void*)f_19627},
{C_text("f_19632:irregex_2escm"),(void*)f_19632},
{C_text("f_19639:irregex_2escm"),(void*)f_19639},
{C_text("f_19690:irregex_2escm"),(void*)f_19690},
{C_text("f_19697:irregex_2escm"),(void*)f_19697},
{C_text("f_19700:irregex_2escm"),(void*)f_19700},
{C_text("f_19705:irregex_2escm"),(void*)f_19705},
{C_text("f_19757:irregex_2escm"),(void*)f_19757},
{C_text("f_19772:irregex_2escm"),(void*)f_19772},
{C_text("f_19808:irregex_2escm"),(void*)f_19808},
{C_text("f_19818:irregex_2escm"),(void*)f_19818},
{C_text("f_19828:irregex_2escm"),(void*)f_19828},
{C_text("f_19830:irregex_2escm"),(void*)f_19830},
{C_text("f_19888:irregex_2escm"),(void*)f_19888},
{C_text("f_19916:irregex_2escm"),(void*)f_19916},
{C_text("f_19920:irregex_2escm"),(void*)f_19920},
{C_text("f_19925:irregex_2escm"),(void*)f_19925},
{C_text("f_19945:irregex_2escm"),(void*)f_19945},
{C_text("f_19947:irregex_2escm"),(void*)f_19947},
{C_text("f_19972:irregex_2escm"),(void*)f_19972},
{C_text("f_19984:irregex_2escm"),(void*)f_19984},
{C_text("f_19987:irregex_2escm"),(void*)f_19987},
{C_text("f_20000:irregex_2escm"),(void*)f_20000},
{C_text("f_20004:irregex_2escm"),(void*)f_20004},
{C_text("f_20007:irregex_2escm"),(void*)f_20007},
{C_text("f_20012:irregex_2escm"),(void*)f_20012},
{C_text("f_20022:irregex_2escm"),(void*)f_20022},
{C_text("f_20025:irregex_2escm"),(void*)f_20025},
{C_text("f_20035:irregex_2escm"),(void*)f_20035},
{C_text("f_20070:irregex_2escm"),(void*)f_20070},
{C_text("f_20122:irregex_2escm"),(void*)f_20122},
{C_text("f_20134:irregex_2escm"),(void*)f_20134},
{C_text("f_20158:irregex_2escm"),(void*)f_20158},
{C_text("f_20159:irregex_2escm"),(void*)f_20159},
{C_text("f_20188:irregex_2escm"),(void*)f_20188},
{C_text("f_20197:irregex_2escm"),(void*)f_20197},
{C_text("f_20211:irregex_2escm"),(void*)f_20211},
{C_text("f_20230:irregex_2escm"),(void*)f_20230},
{C_text("f_20238:irregex_2escm"),(void*)f_20238},
{C_text("f_20248:irregex_2escm"),(void*)f_20248},
{C_text("f_20261:irregex_2escm"),(void*)f_20261},
{C_text("f_20286:irregex_2escm"),(void*)f_20286},
{C_text("f_20295:irregex_2escm"),(void*)f_20295},
{C_text("f_20331:irregex_2escm"),(void*)f_20331},
{C_text("f_20334:irregex_2escm"),(void*)f_20334},
{C_text("f_20373:irregex_2escm"),(void*)f_20373},
{C_text("f_20376:irregex_2escm"),(void*)f_20376},
{C_text("f_20401:irregex_2escm"),(void*)f_20401},
{C_text("f_20441:irregex_2escm"),(void*)f_20441},
{C_text("f_20469:irregex_2escm"),(void*)f_20469},
{C_text("f_20594:irregex_2escm"),(void*)f_20594},
{C_text("f_20628:irregex_2escm"),(void*)f_20628},
{C_text("f_20769:irregex_2escm"),(void*)f_20769},
{C_text("f_20773:irregex_2escm"),(void*)f_20773},
{C_text("f_20776:irregex_2escm"),(void*)f_20776},
{C_text("f_20778:irregex_2escm"),(void*)f_20778},
{C_text("f_20781:irregex_2escm"),(void*)f_20781},
{C_text("f_20791:irregex_2escm"),(void*)f_20791},
{C_text("f_20795:irregex_2escm"),(void*)f_20795},
{C_text("f_20804:irregex_2escm"),(void*)f_20804},
{C_text("f_20807:irregex_2escm"),(void*)f_20807},
{C_text("f_20816:irregex_2escm"),(void*)f_20816},
{C_text("f_20852:irregex_2escm"),(void*)f_20852},
{C_text("f_20863:irregex_2escm"),(void*)f_20863},
{C_text("f_20869:irregex_2escm"),(void*)f_20869},
{C_text("f_20886:irregex_2escm"),(void*)f_20886},
{C_text("f_20919:irregex_2escm"),(void*)f_20919},
{C_text("f_20925:irregex_2escm"),(void*)f_20925},
{C_text("f_20932:irregex_2escm"),(void*)f_20932},
{C_text("f_20943:irregex_2escm"),(void*)f_20943},
{C_text("f_20957:irregex_2escm"),(void*)f_20957},
{C_text("f_20975:irregex_2escm"),(void*)f_20975},
{C_text("f_21000:irregex_2escm"),(void*)f_21000},
{C_text("f_21027:irregex_2escm"),(void*)f_21027},
{C_text("f_21058:irregex_2escm"),(void*)f_21058},
{C_text("f_21065:irregex_2escm"),(void*)f_21065},
{C_text("f_21077:irregex_2escm"),(void*)f_21077},
{C_text("f_21107:irregex_2escm"),(void*)f_21107},
{C_text("f_21121:irregex_2escm"),(void*)f_21121},
{C_text("f_21124:irregex_2escm"),(void*)f_21124},
{C_text("f_21130:irregex_2escm"),(void*)f_21130},
{C_text("f_21144:irregex_2escm"),(void*)f_21144},
{C_text("f_21168:irregex_2escm"),(void*)f_21168},
{C_text("f_21171:irregex_2escm"),(void*)f_21171},
{C_text("f_21178:irregex_2escm"),(void*)f_21178},
{C_text("f_21195:irregex_2escm"),(void*)f_21195},
{C_text("f_21211:irregex_2escm"),(void*)f_21211},
{C_text("f_21214:irregex_2escm"),(void*)f_21214},
{C_text("f_21217:irregex_2escm"),(void*)f_21217},
{C_text("f_21223:irregex_2escm"),(void*)f_21223},
{C_text("f_21233:irregex_2escm"),(void*)f_21233},
{C_text("f_21237:irregex_2escm"),(void*)f_21237},
{C_text("f_21248:irregex_2escm"),(void*)f_21248},
{C_text("f_21252:irregex_2escm"),(void*)f_21252},
{C_text("f_21256:irregex_2escm"),(void*)f_21256},
{C_text("f_21264:irregex_2escm"),(void*)f_21264},
{C_text("f_21272:irregex_2escm"),(void*)f_21272},
{C_text("f_21287:irregex_2escm"),(void*)f_21287},
{C_text("f_21293:irregex_2escm"),(void*)f_21293},
{C_text("f_21307:irregex_2escm"),(void*)f_21307},
{C_text("f_21321:irregex_2escm"),(void*)f_21321},
{C_text("f_21327:irregex_2escm"),(void*)f_21327},
{C_text("f_21330:irregex_2escm"),(void*)f_21330},
{C_text("f_21357:irregex_2escm"),(void*)f_21357},
{C_text("f_21361:irregex_2escm"),(void*)f_21361},
{C_text("f_21381:irregex_2escm"),(void*)f_21381},
{C_text("f_21387:irregex_2escm"),(void*)f_21387},
{C_text("f_21390:irregex_2escm"),(void*)f_21390},
{C_text("f_21393:irregex_2escm"),(void*)f_21393},
{C_text("f_21409:irregex_2escm"),(void*)f_21409},
{C_text("f_21417:irregex_2escm"),(void*)f_21417},
{C_text("f_21429:irregex_2escm"),(void*)f_21429},
{C_text("f_21459:irregex_2escm"),(void*)f_21459},
{C_text("f_21465:irregex_2escm"),(void*)f_21465},
{C_text("f_21468:irregex_2escm"),(void*)f_21468},
{C_text("f_21471:irregex_2escm"),(void*)f_21471},
{C_text("f_21487:irregex_2escm"),(void*)f_21487},
{C_text("f_21495:irregex_2escm"),(void*)f_21495},
{C_text("f_21503:irregex_2escm"),(void*)f_21503},
{C_text("f_21507:irregex_2escm"),(void*)f_21507},
{C_text("f_21526:irregex_2escm"),(void*)f_21526},
{C_text("f_21544:irregex_2escm"),(void*)f_21544},
{C_text("f_21672:irregex_2escm"),(void*)f_21672},
{C_text("f_21678:irregex_2escm"),(void*)f_21678},
{C_text("f_21681:irregex_2escm"),(void*)f_21681},
{C_text("f_21689:irregex_2escm"),(void*)f_21689},
{C_text("f_21728:irregex_2escm"),(void*)f_21728},
{C_text("f_21763:irregex_2escm"),(void*)f_21763},
{C_text("f_21770:irregex_2escm"),(void*)f_21770},
{C_text("f_21796:irregex_2escm"),(void*)f_21796},
{C_text("f_21892:irregex_2escm"),(void*)f_21892},
{C_text("f_21896:irregex_2escm"),(void*)f_21896},
{C_text("f_21909:irregex_2escm"),(void*)f_21909},
{C_text("f_21921:irregex_2escm"),(void*)f_21921},
{C_text("f_21925:irregex_2escm"),(void*)f_21925},
{C_text("f_21932:irregex_2escm"),(void*)f_21932},
{C_text("f_21938:irregex_2escm"),(void*)f_21938},
{C_text("f_21942:irregex_2escm"),(void*)f_21942},
{C_text("f_21945:irregex_2escm"),(void*)f_21945},
{C_text("f_21947:irregex_2escm"),(void*)f_21947},
{C_text("f_21954:irregex_2escm"),(void*)f_21954},
{C_text("f_21961:irregex_2escm"),(void*)f_21961},
{C_text("f_21996:irregex_2escm"),(void*)f_21996},
{C_text("f_22009:irregex_2escm"),(void*)f_22009},
{C_text("f_22110:irregex_2escm"),(void*)f_22110},
{C_text("f_22116:irregex_2escm"),(void*)f_22116},
{C_text("f_22122:irregex_2escm"),(void*)f_22122},
{C_text("f_22175:irregex_2escm"),(void*)f_22175},
{C_text("f_22246:irregex_2escm"),(void*)f_22246},
{C_text("f_22299:irregex_2escm"),(void*)f_22299},
{C_text("f_22308:irregex_2escm"),(void*)f_22308},
{C_text("f_22328:irregex_2escm"),(void*)f_22328},
{C_text("f_22357:irregex_2escm"),(void*)f_22357},
{C_text("f_22381:irregex_2escm"),(void*)f_22381},
{C_text("f_22388:irregex_2escm"),(void*)f_22388},
{C_text("f_22391:irregex_2escm"),(void*)f_22391},
{C_text("f_22394:irregex_2escm"),(void*)f_22394},
{C_text("f_22397:irregex_2escm"),(void*)f_22397},
{C_text("f_22413:irregex_2escm"),(void*)f_22413},
{C_text("f_22430:irregex_2escm"),(void*)f_22430},
{C_text("f_22465:irregex_2escm"),(void*)f_22465},
{C_text("f_22469:irregex_2escm"),(void*)f_22469},
{C_text("f_22497:irregex_2escm"),(void*)f_22497},
{C_text("f_22500:irregex_2escm"),(void*)f_22500},
{C_text("f_22506:irregex_2escm"),(void*)f_22506},
{C_text("f_22592:irregex_2escm"),(void*)f_22592},
{C_text("f_22595:irregex_2escm"),(void*)f_22595},
{C_text("f_22600:irregex_2escm"),(void*)f_22600},
{C_text("f_22610:irregex_2escm"),(void*)f_22610},
{C_text("f_22613:irregex_2escm"),(void*)f_22613},
{C_text("f_22633:irregex_2escm"),(void*)f_22633},
{C_text("f_22641:irregex_2escm"),(void*)f_22641},
{C_text("f_22674:irregex_2escm"),(void*)f_22674},
{C_text("f_22676:irregex_2escm"),(void*)f_22676},
{C_text("f_22701:irregex_2escm"),(void*)f_22701},
{C_text("f_22714:irregex_2escm"),(void*)f_22714},
{C_text("f_22753:irregex_2escm"),(void*)f_22753},
{C_text("f_22768:irregex_2escm"),(void*)f_22768},
{C_text("f_22789:irregex_2escm"),(void*)f_22789},
{C_text("f_22807:irregex_2escm"),(void*)f_22807},
{C_text("f_22816:irregex_2escm"),(void*)f_22816},
{C_text("f_22830:irregex_2escm"),(void*)f_22830},
{C_text("f_22834:irregex_2escm"),(void*)f_22834},
{C_text("f_22837:irregex_2escm"),(void*)f_22837},
{C_text("f_22843:irregex_2escm"),(void*)f_22843},
{C_text("f_22846:irregex_2escm"),(void*)f_22846},
{C_text("f_22849:irregex_2escm"),(void*)f_22849},
{C_text("f_22866:irregex_2escm"),(void*)f_22866},
{C_text("f_22938:irregex_2escm"),(void*)f_22938},
{C_text("f_22942:irregex_2escm"),(void*)f_22942},
{C_text("f_22946:irregex_2escm"),(void*)f_22946},
{C_text("f_22948:irregex_2escm"),(void*)f_22948},
{C_text("f_22971:irregex_2escm"),(void*)f_22971},
{C_text("f_23000:irregex_2escm"),(void*)f_23000},
{C_text("f_23004:irregex_2escm"),(void*)f_23004},
{C_text("f_23028:irregex_2escm"),(void*)f_23028},
{C_text("f_23056:irregex_2escm"),(void*)f_23056},
{C_text("f_23066:irregex_2escm"),(void*)f_23066},
{C_text("f_23076:irregex_2escm"),(void*)f_23076},
{C_text("f_23081:irregex_2escm"),(void*)f_23081},
{C_text("f_23096:irregex_2escm"),(void*)f_23096},
{C_text("f_23116:irregex_2escm"),(void*)f_23116},
{C_text("f_23139:irregex_2escm"),(void*)f_23139},
{C_text("f_23171:irregex_2escm"),(void*)f_23171},
{C_text("f_23178:irregex_2escm"),(void*)f_23178},
{C_text("f_23180:irregex_2escm"),(void*)f_23180},
{C_text("f_23204:irregex_2escm"),(void*)f_23204},
{C_text("f_23248:irregex_2escm"),(void*)f_23248},
{C_text("f_23261:irregex_2escm"),(void*)f_23261},
{C_text("f_23275:irregex_2escm"),(void*)f_23275},
{C_text("f_23302:irregex_2escm"),(void*)f_23302},
{C_text("f_23383:irregex_2escm"),(void*)f_23383},
{C_text("f_23399:irregex_2escm"),(void*)f_23399},
{C_text("f_23409:irregex_2escm"),(void*)f_23409},
{C_text("f_23418:irregex_2escm"),(void*)f_23418},
{C_text("f_23458:irregex_2escm"),(void*)f_23458},
{C_text("f_23461:irregex_2escm"),(void*)f_23461},
{C_text("f_23484:irregex_2escm"),(void*)f_23484},
{C_text("f_23500:irregex_2escm"),(void*)f_23500},
{C_text("f_23507:irregex_2escm"),(void*)f_23507},
{C_text("f_23527:irregex_2escm"),(void*)f_23527},
{C_text("f_23547:irregex_2escm"),(void*)f_23547},
{C_text("f_23550:irregex_2escm"),(void*)f_23550},
{C_text("f_23551:irregex_2escm"),(void*)f_23551},
{C_text("f_23557:irregex_2escm"),(void*)f_23557},
{C_text("f_23573:irregex_2escm"),(void*)f_23573},
{C_text("f_23701:irregex_2escm"),(void*)f_23701},
{C_text("f_23720:irregex_2escm"),(void*)f_23720},
{C_text("f_23743:irregex_2escm"),(void*)f_23743},
{C_text("f_23744:irregex_2escm"),(void*)f_23744},
{C_text("f_23750:irregex_2escm"),(void*)f_23750},
{C_text("f_23769:irregex_2escm"),(void*)f_23769},
{C_text("f_23770:irregex_2escm"),(void*)f_23770},
{C_text("f_23776:irregex_2escm"),(void*)f_23776},
{C_text("f_23798:irregex_2escm"),(void*)f_23798},
{C_text("f_23804:irregex_2escm"),(void*)f_23804},
{C_text("f_23805:irregex_2escm"),(void*)f_23805},
{C_text("f_23811:irregex_2escm"),(void*)f_23811},
{C_text("f_23843:irregex_2escm"),(void*)f_23843},
{C_text("f_23849:irregex_2escm"),(void*)f_23849},
{C_text("f_23851:irregex_2escm"),(void*)f_23851},
{C_text("f_23857:irregex_2escm"),(void*)f_23857},
{C_text("f_23867:irregex_2escm"),(void*)f_23867},
{C_text("f_23873:irregex_2escm"),(void*)f_23873},
{C_text("f_23897:irregex_2escm"),(void*)f_23897},
{C_text("f_23903:irregex_2escm"),(void*)f_23903},
{C_text("f_23910:irregex_2escm"),(void*)f_23910},
{C_text("f_23916:irregex_2escm"),(void*)f_23916},
{C_text("f_23999:irregex_2escm"),(void*)f_23999},
{C_text("f_24002:irregex_2escm"),(void*)f_24002},
{C_text("f_24003:irregex_2escm"),(void*)f_24003},
{C_text("f_24016:irregex_2escm"),(void*)f_24016},
{C_text("f_24022:irregex_2escm"),(void*)f_24022},
{C_text("f_24035:irregex_2escm"),(void*)f_24035},
{C_text("f_24040:irregex_2escm"),(void*)f_24040},
{C_text("f_24071:irregex_2escm"),(void*)f_24071},
{C_text("f_24075:irregex_2escm"),(void*)f_24075},
{C_text("f_24080:irregex_2escm"),(void*)f_24080},
{C_text("f_24151:irregex_2escm"),(void*)f_24151},
{C_text("f_24154:irregex_2escm"),(void*)f_24154},
{C_text("f_24155:irregex_2escm"),(void*)f_24155},
{C_text("f_24168:irregex_2escm"),(void*)f_24168},
{C_text("f_24174:irregex_2escm"),(void*)f_24174},
{C_text("f_24184:irregex_2escm"),(void*)f_24184},
{C_text("f_24196:irregex_2escm"),(void*)f_24196},
{C_text("f_24209:irregex_2escm"),(void*)f_24209},
{C_text("f_24230:irregex_2escm"),(void*)f_24230},
{C_text("f_24240:irregex_2escm"),(void*)f_24240},
{C_text("f_24244:irregex_2escm"),(void*)f_24244},
{C_text("f_24250:irregex_2escm"),(void*)f_24250},
{C_text("f_24322:irregex_2escm"),(void*)f_24322},
{C_text("f_24372:irregex_2escm"),(void*)f_24372},
{C_text("f_24385:irregex_2escm"),(void*)f_24385},
{C_text("f_24386:irregex_2escm"),(void*)f_24386},
{C_text("f_24393:irregex_2escm"),(void*)f_24393},
{C_text("f_24401:irregex_2escm"),(void*)f_24401},
{C_text("f_24408:irregex_2escm"),(void*)f_24408},
{C_text("f_24420:irregex_2escm"),(void*)f_24420},
{C_text("f_24421:irregex_2escm"),(void*)f_24421},
{C_text("f_24428:irregex_2escm"),(void*)f_24428},
{C_text("f_24436:irregex_2escm"),(void*)f_24436},
{C_text("f_24443:irregex_2escm"),(void*)f_24443},
{C_text("f_24458:irregex_2escm"),(void*)f_24458},
{C_text("f_24459:irregex_2escm"),(void*)f_24459},
{C_text("f_24463:irregex_2escm"),(void*)f_24463},
{C_text("f_24469:irregex_2escm"),(void*)f_24469},
{C_text("f_24476:irregex_2escm"),(void*)f_24476},
{C_text("f_24485:irregex_2escm"),(void*)f_24485},
{C_text("f_24495:irregex_2escm"),(void*)f_24495},
{C_text("f_24499:irregex_2escm"),(void*)f_24499},
{C_text("f_24504:irregex_2escm"),(void*)f_24504},
{C_text("f_24521:irregex_2escm"),(void*)f_24521},
{C_text("f_24530:irregex_2escm"),(void*)f_24530},
{C_text("f_24541:irregex_2escm"),(void*)f_24541},
{C_text("f_24542:irregex_2escm"),(void*)f_24542},
{C_text("f_24546:irregex_2escm"),(void*)f_24546},
{C_text("f_24557:irregex_2escm"),(void*)f_24557},
{C_text("f_24564:irregex_2escm"),(void*)f_24564},
{C_text("f_24576:irregex_2escm"),(void*)f_24576},
{C_text("f_24579:irregex_2escm"),(void*)f_24579},
{C_text("f_24582:irregex_2escm"),(void*)f_24582},
{C_text("f_24591:irregex_2escm"),(void*)f_24591},
{C_text("f_24594:irregex_2escm"),(void*)f_24594},
{C_text("f_24595:irregex_2escm"),(void*)f_24595},
{C_text("f_24652:irregex_2escm"),(void*)f_24652},
{C_text("f_24653:irregex_2escm"),(void*)f_24653},
{C_text("f_24659:irregex_2escm"),(void*)f_24659},
{C_text("f_24695:irregex_2escm"),(void*)f_24695},
{C_text("f_24700:irregex_2escm"),(void*)f_24700},
{C_text("f_24732:irregex_2escm"),(void*)f_24732},
{C_text("f_24735:irregex_2escm"),(void*)f_24735},
{C_text("f_24736:irregex_2escm"),(void*)f_24736},
{C_text("f_24740:irregex_2escm"),(void*)f_24740},
{C_text("f_24758:irregex_2escm"),(void*)f_24758},
{C_text("f_24771:irregex_2escm"),(void*)f_24771},
{C_text("f_24785:irregex_2escm"),(void*)f_24785},
{C_text("f_24789:irregex_2escm"),(void*)f_24789},
{C_text("f_24803:irregex_2escm"),(void*)f_24803},
{C_text("f_24809:irregex_2escm"),(void*)f_24809},
{C_text("f_24822:irregex_2escm"),(void*)f_24822},
{C_text("f_24829:irregex_2escm"),(void*)f_24829},
{C_text("f_24836:irregex_2escm"),(void*)f_24836},
{C_text("f_24858:irregex_2escm"),(void*)f_24858},
{C_text("f_24862:irregex_2escm"),(void*)f_24862},
{C_text("f_24949:irregex_2escm"),(void*)f_24949},
{C_text("f_24950:irregex_2escm"),(void*)f_24950},
{C_text("f_24998:irregex_2escm"),(void*)f_24998},
{C_text("f_25058:irregex_2escm"),(void*)f_25058},
{C_text("f_25093:irregex_2escm"),(void*)f_25093},
{C_text("f_25293:irregex_2escm"),(void*)f_25293},
{C_text("f_25313:irregex_2escm"),(void*)f_25313},
{C_text("f_25322:irregex_2escm"),(void*)f_25322},
{C_text("f_25328:irregex_2escm"),(void*)f_25328},
{C_text("f_25334:irregex_2escm"),(void*)f_25334},
{C_text("f_25351:irregex_2escm"),(void*)f_25351},
{C_text("f_25388:irregex_2escm"),(void*)f_25388},
{C_text("f_25397:irregex_2escm"),(void*)f_25397},
{C_text("f_25403:irregex_2escm"),(void*)f_25403},
{C_text("f_25409:irregex_2escm"),(void*)f_25409},
{C_text("f_25443:irregex_2escm"),(void*)f_25443},
{C_text("f_25473:irregex_2escm"),(void*)f_25473},
{C_text("f_25480:irregex_2escm"),(void*)f_25480},
{C_text("f_25517:irregex_2escm"),(void*)f_25517},
{C_text("f_25524:irregex_2escm"),(void*)f_25524},
{C_text("f_25531:irregex_2escm"),(void*)f_25531},
{C_text("f_25540:irregex_2escm"),(void*)f_25540},
{C_text("f_25559:irregex_2escm"),(void*)f_25559},
{C_text("f_25576:irregex_2escm"),(void*)f_25576},
{C_text("f_25583:irregex_2escm"),(void*)f_25583},
{C_text("f_25604:irregex_2escm"),(void*)f_25604},
{C_text("f_25624:irregex_2escm"),(void*)f_25624},
{C_text("f_25631:irregex_2escm"),(void*)f_25631},
{C_text("f_25638:irregex_2escm"),(void*)f_25638},
{C_text("f_25657:irregex_2escm"),(void*)f_25657},
{C_text("f_25664:irregex_2escm"),(void*)f_25664},
{C_text("f_25671:irregex_2escm"),(void*)f_25671},
{C_text("f_25694:irregex_2escm"),(void*)f_25694},
{C_text("f_25715:irregex_2escm"),(void*)f_25715},
{C_text("f_25722:irregex_2escm"),(void*)f_25722},
{C_text("f_25729:irregex_2escm"),(void*)f_25729},
{C_text("f_25736:irregex_2escm"),(void*)f_25736},
{C_text("f_25745:irregex_2escm"),(void*)f_25745},
{C_text("f_25765:irregex_2escm"),(void*)f_25765},
{C_text("f_25781:irregex_2escm"),(void*)f_25781},
{C_text("f_25798:irregex_2escm"),(void*)f_25798},
{C_text("f_25818:irregex_2escm"),(void*)f_25818},
{C_text("f_25822:irregex_2escm"),(void*)f_25822},
{C_text("f_25825:irregex_2escm"),(void*)f_25825},
{C_text("f_25831:irregex_2escm"),(void*)f_25831},
{C_text("f_25876:irregex_2escm"),(void*)f_25876},
{C_text("f_25940:irregex_2escm"),(void*)f_25940},
{C_text("f_25957:irregex_2escm"),(void*)f_25957},
{C_text("f_25959:irregex_2escm"),(void*)f_25959},
{C_text("f_25969:irregex_2escm"),(void*)f_25969},
{C_text("f_25975:irregex_2escm"),(void*)f_25975},
{C_text("f_25981:irregex_2escm"),(void*)f_25981},
{C_text("f_25997:irregex_2escm"),(void*)f_25997},
{C_text("f_26003:irregex_2escm"),(void*)f_26003},
{C_text("f_26025:irregex_2escm"),(void*)f_26025},
{C_text("f_26039:irregex_2escm"),(void*)f_26039},
{C_text("f_26056:irregex_2escm"),(void*)f_26056},
{C_text("f_26058:irregex_2escm"),(void*)f_26058},
{C_text("f_26068:irregex_2escm"),(void*)f_26068},
{C_text("f_26074:irregex_2escm"),(void*)f_26074},
{C_text("f_26080:irregex_2escm"),(void*)f_26080},
{C_text("f_26096:irregex_2escm"),(void*)f_26096},
{C_text("f_26154:irregex_2escm"),(void*)f_26154},
{C_text("f_26180:irregex_2escm"),(void*)f_26180},
{C_text("f_26182:irregex_2escm"),(void*)f_26182},
{C_text("f_26195:irregex_2escm"),(void*)f_26195},
{C_text("f_26214:irregex_2escm"),(void*)f_26214},
{C_text("f_26223:irregex_2escm"),(void*)f_26223},
{C_text("f_26229:irregex_2escm"),(void*)f_26229},
{C_text("f_26235:irregex_2escm"),(void*)f_26235},
{C_text("f_26241:irregex_2escm"),(void*)f_26241},
{C_text("f_26393:irregex_2escm"),(void*)f_26393},
{C_text("f_26405:irregex_2escm"),(void*)f_26405},
{C_text("f_26455:irregex_2escm"),(void*)f_26455},
{C_text("f_26473:irregex_2escm"),(void*)f_26473},
{C_text("f_26484:irregex_2escm"),(void*)f_26484},
{C_text("f_26490:irregex_2escm"),(void*)f_26490},
{C_text("f_26502:irregex_2escm"),(void*)f_26502},
{C_text("f_26504:irregex_2escm"),(void*)f_26504},
{C_text("f_26514:irregex_2escm"),(void*)f_26514},
{C_text("f_26517:irregex_2escm"),(void*)f_26517},
{C_text("f_26543:irregex_2escm"),(void*)f_26543},
{C_text("f_26564:irregex_2escm"),(void*)f_26564},
{C_text("f_26568:irregex_2escm"),(void*)f_26568},
{C_text("f_26581:irregex_2escm"),(void*)f_26581},
{C_text("f_26583:irregex_2escm"),(void*)f_26583},
{C_text("f_26608:irregex_2escm"),(void*)f_26608},
{C_text("f_26632:irregex_2escm"),(void*)f_26632},
{C_text("f_26645:irregex_2escm"),(void*)f_26645},
{C_text("f_26647:irregex_2escm"),(void*)f_26647},
{C_text("f_26672:irregex_2escm"),(void*)f_26672},
{C_text("f_26694:irregex_2escm"),(void*)f_26694},
{C_text("f_26702:irregex_2escm"),(void*)f_26702},
{C_text("f_26715:irregex_2escm"),(void*)f_26715},
{C_text("f_26717:irregex_2escm"),(void*)f_26717},
{C_text("f_26742:irregex_2escm"),(void*)f_26742},
{C_text("f_26762:irregex_2escm"),(void*)f_26762},
{C_text("f_26772:irregex_2escm"),(void*)f_26772},
{C_text("f_26787:irregex_2escm"),(void*)f_26787},
{C_text("f_26800:irregex_2escm"),(void*)f_26800},
{C_text("f_26802:irregex_2escm"),(void*)f_26802},
{C_text("f_26827:irregex_2escm"),(void*)f_26827},
{C_text("f_26949:irregex_2escm"),(void*)f_26949},
{C_text("f_26951:irregex_2escm"),(void*)f_26951},
{C_text("f_26969:irregex_2escm"),(void*)f_26969},
{C_text("f_26971:irregex_2escm"),(void*)f_26971},
{C_text("f_27004:irregex_2escm"),(void*)f_27004},
{C_text("f_27056:irregex_2escm"),(void*)f_27056},
{C_text("f_27092:irregex_2escm"),(void*)f_27092},
{C_text("f_27100:irregex_2escm"),(void*)f_27100},
{C_text("f_27104:irregex_2escm"),(void*)f_27104},
{C_text("f_27106:irregex_2escm"),(void*)f_27106},
{C_text("f_27120:irregex_2escm"),(void*)f_27120},
{C_text("f_27124:irregex_2escm"),(void*)f_27124},
{C_text("f_27128:irregex_2escm"),(void*)f_27128},
{C_text("f_27141:irregex_2escm"),(void*)f_27141},
{C_text("f_27145:irregex_2escm"),(void*)f_27145},
{C_text("f_27149:irregex_2escm"),(void*)f_27149},
{C_text("f_27287:irregex_2escm"),(void*)f_27287},
{C_text("f_27295:irregex_2escm"),(void*)f_27295},
{C_text("f_27299:irregex_2escm"),(void*)f_27299},
{C_text("f_27301:irregex_2escm"),(void*)f_27301},
{C_text("f_27315:irregex_2escm"),(void*)f_27315},
{C_text("f_27328:irregex_2escm"),(void*)f_27328},
{C_text("f_27332:irregex_2escm"),(void*)f_27332},
{C_text("f_27378:irregex_2escm"),(void*)f_27378},
{C_text("f_27381:irregex_2escm"),(void*)f_27381},
{C_text("f_27388:irregex_2escm"),(void*)f_27388},
{C_text("f_27483:irregex_2escm"),(void*)f_27483},
{C_text("f_27491:irregex_2escm"),(void*)f_27491},
{C_text("f_27495:irregex_2escm"),(void*)f_27495},
{C_text("f_27497:irregex_2escm"),(void*)f_27497},
{C_text("f_27514:irregex_2escm"),(void*)f_27514},
{C_text("f_27609:irregex_2escm"),(void*)f_27609},
{C_text("f_27617:irregex_2escm"),(void*)f_27617},
{C_text("f_27619:irregex_2escm"),(void*)f_27619},
{C_text("f_27627:irregex_2escm"),(void*)f_27627},
{C_text("f_27629:irregex_2escm"),(void*)f_27629},
{C_text("f_27643:irregex_2escm"),(void*)f_27643},
{C_text("f_27649:irregex_2escm"),(void*)f_27649},
{C_text("f_27658:irregex_2escm"),(void*)f_27658},
{C_text("f_27662:irregex_2escm"),(void*)f_27662},
{C_text("f_27666:irregex_2escm"),(void*)f_27666},
{C_text("f_27670:irregex_2escm"),(void*)f_27670},
{C_text("f_27694:irregex_2escm"),(void*)f_27694},
{C_text("f_27704:irregex_2escm"),(void*)f_27704},
{C_text("f_27713:irregex_2escm"),(void*)f_27713},
{C_text("f_27717:irregex_2escm"),(void*)f_27717},
{C_text("f_27721:irregex_2escm"),(void*)f_27721},
{C_text("f_27725:irregex_2escm"),(void*)f_27725},
{C_text("f_27735:irregex_2escm"),(void*)f_27735},
{C_text("f_27750:irregex_2escm"),(void*)f_27750},
{C_text("f_27754:irregex_2escm"),(void*)f_27754},
{C_text("f_27757:irregex_2escm"),(void*)f_27757},
{C_text("f_27760:irregex_2escm"),(void*)f_27760},
{C_text("f_27769:irregex_2escm"),(void*)f_27769},
{C_text("f_27772:irregex_2escm"),(void*)f_27772},
{C_text("f_27781:irregex_2escm"),(void*)f_27781},
{C_text("f_27784:irregex_2escm"),(void*)f_27784},
{C_text("f_27792:irregex_2escm"),(void*)f_27792},
{C_text("f_27805:irregex_2escm"),(void*)f_27805},
{C_text("f_27840:irregex_2escm"),(void*)f_27840},
{C_text("f_27843:irregex_2escm"),(void*)f_27843},
{C_text("f_27951:irregex_2escm"),(void*)f_27951},
{C_text("f_27968:irregex_2escm"),(void*)f_27968},
{C_text("f_27972:irregex_2escm"),(void*)f_27972},
{C_text("f_27973:irregex_2escm"),(void*)f_27973},
{C_text("f_27981:irregex_2escm"),(void*)f_27981},
{C_text("f_27996:irregex_2escm"),(void*)f_27996},
{C_text("f_28000:irregex_2escm"),(void*)f_28000},
{C_text("f_28003:irregex_2escm"),(void*)f_28003},
{C_text("f_28012:irregex_2escm"),(void*)f_28012},
{C_text("f_28018:irregex_2escm"),(void*)f_28018},
{C_text("f_28026:irregex_2escm"),(void*)f_28026},
{C_text("f_28039:irregex_2escm"),(void*)f_28039},
{C_text("f_28089:irregex_2escm"),(void*)f_28089},
{C_text("f_28099:irregex_2escm"),(void*)f_28099},
{C_text("f_28113:irregex_2escm"),(void*)f_28113},
{C_text("f_28116:irregex_2escm"),(void*)f_28116},
{C_text("f_28119:irregex_2escm"),(void*)f_28119},
{C_text("f_28171:irregex_2escm"),(void*)f_28171},
{C_text("f_28178:irregex_2escm"),(void*)f_28178},
{C_text("f_28182:irregex_2escm"),(void*)f_28182},
{C_text("f_28183:irregex_2escm"),(void*)f_28183},
{C_text("f_28191:irregex_2escm"),(void*)f_28191},
{C_text("f_28206:irregex_2escm"),(void*)f_28206},
{C_text("f_28210:irregex_2escm"),(void*)f_28210},
{C_text("f_28213:irregex_2escm"),(void*)f_28213},
{C_text("f_28227:irregex_2escm"),(void*)f_28227},
{C_text("f_28231:irregex_2escm"),(void*)f_28231},
{C_text("f_28235:irregex_2escm"),(void*)f_28235},
{C_text("f_28243:irregex_2escm"),(void*)f_28243},
{C_text("f_28285:irregex_2escm"),(void*)f_28285},
{C_text("f_28289:irregex_2escm"),(void*)f_28289},
{C_text("f_28294:irregex_2escm"),(void*)f_28294},
{C_text("f_28328:irregex_2escm"),(void*)f_28328},
{C_text("f_28335:irregex_2escm"),(void*)f_28335},
{C_text("f_28343:irregex_2escm"),(void*)f_28343},
{C_text("f_28345:irregex_2escm"),(void*)f_28345},
{C_text("f_28366:irregex_2escm"),(void*)f_28366},
{C_text("f_28378:irregex_2escm"),(void*)f_28378},
{C_text("f_28384:irregex_2escm"),(void*)f_28384},
{C_text("f_28411:irregex_2escm"),(void*)f_28411},
{C_text("f_28436:irregex_2escm"),(void*)f_28436},
{C_text("f_28462:irregex_2escm"),(void*)f_28462},
{C_text("f_28526:irregex_2escm"),(void*)f_28526},
{C_text("f_28558:irregex_2escm"),(void*)f_28558},
{C_text("f_28588:irregex_2escm"),(void*)f_28588},
{C_text("f_28609:irregex_2escm"),(void*)f_28609},
{C_text("f_28613:irregex_2escm"),(void*)f_28613},
{C_text("f_28618:irregex_2escm"),(void*)f_28618},
{C_text("f_28626:irregex_2escm"),(void*)f_28626},
{C_text("f_28628:irregex_2escm"),(void*)f_28628},
{C_text("f_28644:irregex_2escm"),(void*)f_28644},
{C_text("f_28648:irregex_2escm"),(void*)f_28648},
{C_text("f_28654:irregex_2escm"),(void*)f_28654},
{C_text("f_28659:irregex_2escm"),(void*)f_28659},
{C_text("f_28673:irregex_2escm"),(void*)f_28673},
{C_text("f_28717:irregex_2escm"),(void*)f_28717},
{C_text("f_28725:irregex_2escm"),(void*)f_28725},
{C_text("f_28727:irregex_2escm"),(void*)f_28727},
{C_text("f_28768:irregex_2escm"),(void*)f_28768},
{C_text("f_28808:irregex_2escm"),(void*)f_28808},
{C_text("f_28842:irregex_2escm"),(void*)f_28842},
{C_text("f_28855:irregex_2escm"),(void*)f_28855},
{C_text("f_28885:irregex_2escm"),(void*)f_28885},
{C_text("f_28893:irregex_2escm"),(void*)f_28893},
{C_text("f_28897:irregex_2escm"),(void*)f_28897},
{C_text("f_28899:irregex_2escm"),(void*)f_28899},
{C_text("f_28918:irregex_2escm"),(void*)f_28918},
{C_text("f_28942:irregex_2escm"),(void*)f_28942},
{C_text("f_28959:irregex_2escm"),(void*)f_28959},
{C_text("f_28966:irregex_2escm"),(void*)f_28966},
{C_text("f_28989:irregex_2escm"),(void*)f_28989},
{C_text("f_29010:irregex_2escm"),(void*)f_29010},
{C_text("f_29012:irregex_2escm"),(void*)f_29012},
{C_text("f_29022:irregex_2escm"),(void*)f_29022},
{C_text("f_29049:irregex_2escm"),(void*)f_29049},
{C_text("f_29079:irregex_2escm"),(void*)f_29079},
{C_text("f_29084:irregex_2escm"),(void*)f_29084},
{C_text("f_29096:irregex_2escm"),(void*)f_29096},
{C_text("f_29116:irregex_2escm"),(void*)f_29116},
{C_text("f_29151:irregex_2escm"),(void*)f_29151},
{C_text("f_29159:irregex_2escm"),(void*)f_29159},
{C_text("f_29195:irregex_2escm"),(void*)f_29195},
{C_text("f_29209:irregex_2escm"),(void*)f_29209},
{C_text("f_29213:irregex_2escm"),(void*)f_29213},
{C_text("f_29216:irregex_2escm"),(void*)f_29216},
{C_text("f_29221:irregex_2escm"),(void*)f_29221},
{C_text("f_29231:irregex_2escm"),(void*)f_29231},
{C_text("f_29242:irregex_2escm"),(void*)f_29242},
{C_text("f_29245:irregex_2escm"),(void*)f_29245},
{C_text("f_29252:irregex_2escm"),(void*)f_29252},
{C_text("f_29264:irregex_2escm"),(void*)f_29264},
{C_text("f_29279:irregex_2escm"),(void*)f_29279},
{C_text("f_29289:irregex_2escm"),(void*)f_29289},
{C_text("f_29293:irregex_2escm"),(void*)f_29293},
{C_text("f_29296:irregex_2escm"),(void*)f_29296},
{C_text("f_29301:irregex_2escm"),(void*)f_29301},
{C_text("f_29324:irregex_2escm"),(void*)f_29324},
{C_text("f_29327:irregex_2escm"),(void*)f_29327},
{C_text("f_29334:irregex_2escm"),(void*)f_29334},
{C_text("f_29339:irregex_2escm"),(void*)f_29339},
{C_text("f_29349:irregex_2escm"),(void*)f_29349},
{C_text("f_29369:irregex_2escm"),(void*)f_29369},
{C_text("f_29379:irregex_2escm"),(void*)f_29379},
{C_text("f_29421:irregex_2escm"),(void*)f_29421},
{C_text("f_29428:irregex_2escm"),(void*)f_29428},
{C_text("f_29433:irregex_2escm"),(void*)f_29433},
{C_text("f_29443:irregex_2escm"),(void*)f_29443},
{C_text("f_29463:irregex_2escm"),(void*)f_29463},
{C_text("f_29466:irregex_2escm"),(void*)f_29466},
{C_text("f_29469:irregex_2escm"),(void*)f_29469},
{C_text("f_29478:irregex_2escm"),(void*)f_29478},
{C_text("f_29483:irregex_2escm"),(void*)f_29483},
{C_text("f_29493:irregex_2escm"),(void*)f_29493},
{C_text("f_29517:irregex_2escm"),(void*)f_29517},
{C_text("f_29520:irregex_2escm"),(void*)f_29520},
{C_text("f_29521:irregex_2escm"),(void*)f_29521},
{C_text("f_29525:irregex_2escm"),(void*)f_29525},
{C_text("f_29537:irregex_2escm"),(void*)f_29537},
{C_text("f_29542:irregex_2escm"),(void*)f_29542},
{C_text("f_29552:irregex_2escm"),(void*)f_29552},
{C_text("f_29576:irregex_2escm"),(void*)f_29576},
{C_text("f_29579:irregex_2escm"),(void*)f_29579},
{C_text("f_29590:irregex_2escm"),(void*)f_29590},
{C_text("f_29593:irregex_2escm"),(void*)f_29593},
{C_text("f_29600:irregex_2escm"),(void*)f_29600},
{C_text("f_29605:irregex_2escm"),(void*)f_29605},
{C_text("f_29615:irregex_2escm"),(void*)f_29615},
{C_text("f_29673:irregex_2escm"),(void*)f_29673},
{C_text("f_29676:irregex_2escm"),(void*)f_29676},
{C_text("f_29679:irregex_2escm"),(void*)f_29679},
{C_text("f_29686:irregex_2escm"),(void*)f_29686},
{C_text("f_29690:irregex_2escm"),(void*)f_29690},
{C_text("f_29703:irregex_2escm"),(void*)f_29703},
{C_text("f_29716:irregex_2escm"),(void*)f_29716},
{C_text("f_29719:irregex_2escm"),(void*)f_29719},
{C_text("f_29726:irregex_2escm"),(void*)f_29726},
{C_text("f_29737:irregex_2escm"),(void*)f_29737},
{C_text("f_29746:irregex_2escm"),(void*)f_29746},
{C_text("f_29749:irregex_2escm"),(void*)f_29749},
{C_text("f_29752:irregex_2escm"),(void*)f_29752},
{C_text("f_29759:irregex_2escm"),(void*)f_29759},
{C_text("f_29784:irregex_2escm"),(void*)f_29784},
{C_text("f_29822:irregex_2escm"),(void*)f_29822},
{C_text("f_29825:irregex_2escm"),(void*)f_29825},
{C_text("f_29828:irregex_2escm"),(void*)f_29828},
{C_text("f_29835:irregex_2escm"),(void*)f_29835},
{C_text("f_29840:irregex_2escm"),(void*)f_29840},
{C_text("f_29850:irregex_2escm"),(void*)f_29850},
{C_text("f_29886:irregex_2escm"),(void*)f_29886},
{C_text("f_30050:irregex_2escm"),(void*)f_30050},
{C_text("f_30063:irregex_2escm"),(void*)f_30063},
{C_text("f_30072:irregex_2escm"),(void*)f_30072},
{C_text("f_30083:irregex_2escm"),(void*)f_30083},
{C_text("f_30087:irregex_2escm"),(void*)f_30087},
{C_text("f_30089:irregex_2escm"),(void*)f_30089},
{C_text("f_30120:irregex_2escm"),(void*)f_30120},
{C_text("f_30167:irregex_2escm"),(void*)f_30167},
{C_text("f_30187:irregex_2escm"),(void*)f_30187},
{C_text("f_30197:irregex_2escm"),(void*)f_30197},
{C_text("f_30224:irregex_2escm"),(void*)f_30224},
{C_text("f_30246:irregex_2escm"),(void*)f_30246},
{C_text("f_30348:irregex_2escm"),(void*)f_30348},
{C_text("f_30813:irregex_2escm"),(void*)f_30813},
{C_text("f_30975:irregex_2escm"),(void*)f_30975},
{C_text("f_30978:irregex_2escm"),(void*)f_30978},
{C_text("f_31012:irregex_2escm"),(void*)f_31012},
{C_text("f_31016:irregex_2escm"),(void*)f_31016},
{C_text("f_31019:irregex_2escm"),(void*)f_31019},
{C_text("f_31022:irregex_2escm"),(void*)f_31022},
{C_text("f_31025:irregex_2escm"),(void*)f_31025},
{C_text("f_31028:irregex_2escm"),(void*)f_31028},
{C_text("f_7541:irregex_2escm"),(void*)f_7541},
{C_text("f_7544:irregex_2escm"),(void*)f_7544},
{C_text("f_7546:irregex_2escm"),(void*)f_7546},
{C_text("f_7550:irregex_2escm"),(void*)f_7550},
{C_text("f_7553:irregex_2escm"),(void*)f_7553},
{C_text("f_7559:irregex_2escm"),(void*)f_7559},
{C_text("f_7601:irregex_2escm"),(void*)f_7601},
{C_text("f_7619:irregex_2escm"),(void*)f_7619},
{C_text("f_7628:irregex_2escm"),(void*)f_7628},
{C_text("f_7636:irregex_2escm"),(void*)f_7636},
{C_text("f_7649:irregex_2escm"),(void*)f_7649},
{C_text("f_7651:irregex_2escm"),(void*)f_7651},
{C_text("f_7658:irregex_2escm"),(void*)f_7658},
{C_text("f_7660:irregex_2escm"),(void*)f_7660},
{C_text("f_7674:irregex_2escm"),(void*)f_7674},
{C_text("f_7692:irregex_2escm"),(void*)f_7692},
{C_text("f_7698:irregex_2escm"),(void*)f_7698},
{C_text("f_7723:irregex_2escm"),(void*)f_7723},
{C_text("f_7769:irregex_2escm"),(void*)f_7769},
{C_text("f_7782:irregex_2escm"),(void*)f_7782},
{C_text("f_7784:irregex_2escm"),(void*)f_7784},
{C_text("f_7788:irregex_2escm"),(void*)f_7788},
{C_text("f_7809:irregex_2escm"),(void*)f_7809},
{C_text("f_7813:irregex_2escm"),(void*)f_7813},
{C_text("f_7838:irregex_2escm"),(void*)f_7838},
{C_text("f_7842:irregex_2escm"),(void*)f_7842},
{C_text("f_7867:irregex_2escm"),(void*)f_7867},
{C_text("f_7871:irregex_2escm"),(void*)f_7871},
{C_text("f_7960:irregex_2escm"),(void*)f_7960},
{C_text("f_8028:irregex_2escm"),(void*)f_8028},
{C_text("f_8070:irregex_2escm"),(void*)f_8070},
{C_text("f_8072:irregex_2escm"),(void*)f_8072},
{C_text("f_8142:irregex_2escm"),(void*)f_8142},
{C_text("f_8144:irregex_2escm"),(void*)f_8144},
{C_text("f_8148:irregex_2escm"),(void*)f_8148},
{C_text("f_8205:irregex_2escm"),(void*)f_8205},
{C_text("f_8207:irregex_2escm"),(void*)f_8207},
{C_text("f_8211:irregex_2escm"),(void*)f_8211},
{C_text("f_8288:irregex_2escm"),(void*)f_8288},
{C_text("f_8292:irregex_2escm"),(void*)f_8292},
{C_text("f_8378:irregex_2escm"),(void*)f_8378},
{C_text("f_8412:irregex_2escm"),(void*)f_8412},
{C_text("f_8418:irregex_2escm"),(void*)f_8418},
{C_text("f_8452:irregex_2escm"),(void*)f_8452},
{C_text("f_8466:irregex_2escm"),(void*)f_8466},
{C_text("f_8473:irregex_2escm"),(void*)f_8473},
{C_text("f_8479:irregex_2escm"),(void*)f_8479},
{C_text("f_8497:irregex_2escm"),(void*)f_8497},
{C_text("f_8501:irregex_2escm"),(void*)f_8501},
{C_text("f_8505:irregex_2escm"),(void*)f_8505},
{C_text("f_8512:irregex_2escm"),(void*)f_8512},
{C_text("f_8520:irregex_2escm"),(void*)f_8520},
{C_text("f_8524:irregex_2escm"),(void*)f_8524},
{C_text("f_8528:irregex_2escm"),(void*)f_8528},
{C_text("f_8532:irregex_2escm"),(void*)f_8532},
{C_text("f_8536:irregex_2escm"),(void*)f_8536},
{C_text("f_8540:irregex_2escm"),(void*)f_8540},
{C_text("f_8544:irregex_2escm"),(void*)f_8544},
{C_text("f_8553:irregex_2escm"),(void*)f_8553},
{C_text("f_8561:irregex_2escm"),(void*)f_8561},
{C_text("f_8570:irregex_2escm"),(void*)f_8570},
{C_text("f_8628:irregex_2escm"),(void*)f_8628},
{C_text("f_8632:irregex_2escm"),(void*)f_8632},
{C_text("f_8646:irregex_2escm"),(void*)f_8646},
{C_text("f_8650:irregex_2escm"),(void*)f_8650},
{C_text("f_8663:irregex_2escm"),(void*)f_8663},
{C_text("f_8674:irregex_2escm"),(void*)f_8674},
{C_text("f_8676:irregex_2escm"),(void*)f_8676},
{C_text("f_8683:irregex_2escm"),(void*)f_8683},
{C_text("f_8696:irregex_2escm"),(void*)f_8696},
{C_text("f_8703:irregex_2escm"),(void*)f_8703},
{C_text("f_8742:irregex_2escm"),(void*)f_8742},
{C_text("f_8769:irregex_2escm"),(void*)f_8769},
{C_text("f_8801:irregex_2escm"),(void*)f_8801},
{C_text("f_8808:irregex_2escm"),(void*)f_8808},
{C_text("f_8823:irregex_2escm"),(void*)f_8823},
{C_text("f_8836:irregex_2escm"),(void*)f_8836},
{C_text("f_8879:irregex_2escm"),(void*)f_8879},
{C_text("f_8936:irregex_2escm"),(void*)f_8936},
{C_text("f_8974:irregex_2escm"),(void*)f_8974},
{C_text("f_8977:irregex_2escm"),(void*)f_8977},
{C_text("f_8985:irregex_2escm"),(void*)f_8985},
{C_text("f_8998:irregex_2escm"),(void*)f_8998},
{C_text("f_9017:irregex_2escm"),(void*)f_9017},
{C_text("f_9114:irregex_2escm"),(void*)f_9114},
{C_text("f_9122:irregex_2escm"),(void*)f_9122},
{C_text("f_9124:irregex_2escm"),(void*)f_9124},
{C_text("f_9138:irregex_2escm"),(void*)f_9138},
{C_text("f_9143:irregex_2escm"),(void*)f_9143},
{C_text("f_9164:irregex_2escm"),(void*)f_9164},
{C_text("f_9180:irregex_2escm"),(void*)f_9180},
{C_text("f_9201:irregex_2escm"),(void*)f_9201},
{C_text("f_9207:irregex_2escm"),(void*)f_9207},
{C_text("f_9220:irregex_2escm"),(void*)f_9220},
{C_text("f_9262:irregex_2escm"),(void*)f_9262},
{C_text("f_9277:irregex_2escm"),(void*)f_9277},
{C_text("f_9300:irregex_2escm"),(void*)f_9300},
{C_text("f_9316:irregex_2escm"),(void*)f_9316},
{C_text("f_9329:irregex_2escm"),(void*)f_9329},
{C_text("f_9343:irregex_2escm"),(void*)f_9343},
{C_text("f_9361:irregex_2escm"),(void*)f_9361},
{C_text("f_9377:irregex_2escm"),(void*)f_9377},
{C_text("f_9388:irregex_2escm"),(void*)f_9388},
{C_text("f_9394:irregex_2escm"),(void*)f_9394},
{C_text("f_9412:irregex_2escm"),(void*)f_9412},
{C_text("f_9718:irregex_2escm"),(void*)f_9718},
{C_text("f_9727:irregex_2escm"),(void*)f_9727},
{C_text("f_9745:irregex_2escm"),(void*)f_9745},
{C_text("f_9752:irregex_2escm"),(void*)f_9752},
{C_text("f_9779:irregex_2escm"),(void*)f_9779},
{C_text("f_9785:irregex_2escm"),(void*)f_9785},
{C_text("f_9799:irregex_2escm"),(void*)f_9799},
{C_text("f_9819:irregex_2escm"),(void*)f_9819},
{C_text("f_9825:irregex_2escm"),(void*)f_9825},
{C_text("f_9842:irregex_2escm"),(void*)f_9842},
{C_text("f_9846:irregex_2escm"),(void*)f_9846},
{C_text("f_9893:irregex_2escm"),(void*)f_9893},
{C_text("f_9942:irregex_2escm"),(void*)f_9942},
{C_text("f_9970:irregex_2escm"),(void*)f_9970},
{C_text("f_9981:irregex_2escm"),(void*)f_9981},
{C_text("toplevel:irregex_2escm"),(void*)C_irregex_toplevel},
{NULL,NULL}};
#endif

static C_PTABLE_ENTRY *create_ptable(void){
#ifdef C_ENABLE_PTABLES
return ptable;
#else
return NULL;
#endif
}

/*
o|hiding unexported module binding: chicken.irregex#d 
o|hiding unexported module binding: chicken.irregex#define-alias 
o|hiding unexported module binding: chicken.irregex#build-cache 
o|hiding unexported module binding: chicken.irregex#vector-copy 
o|hiding unexported module binding: chicken.irregex#irregex-dfa 
o|hiding unexported module binding: chicken.irregex#irregex-dfa/search 
o|hiding unexported module binding: chicken.irregex#irregex-nfa 
o|hiding unexported module binding: chicken.irregex#irregex-flags 
o|hiding unexported module binding: chicken.irregex#irregex-lengths 
o|hiding unexported module binding: chicken.irregex#irregex-new-matches 
o|hiding unexported module binding: chicken.irregex#irregex-reset-matches! 
o|hiding unexported module binding: chicken.irregex#irregex-copy-matches 
o|hiding unexported module binding: chicken.irregex#irregex-match-chunker 
o|hiding unexported module binding: chicken.irregex#irregex-match-chunker-set! 
o|hiding unexported module binding: chicken.irregex#%irregex-match-end-index 
o|hiding unexported module binding: chicken.irregex#%irregex-match-fail 
o|hiding unexported module binding: chicken.irregex#%irregex-match-fail-set! 
o|hiding unexported module binding: chicken.irregex#irregex-match-valid-named-index? 
o|hiding unexported module binding: chicken.irregex#irregex-match-start-chunk-set! 
o|hiding unexported module binding: chicken.irregex#irregex-match-start-index-set! 
o|hiding unexported module binding: chicken.irregex#irregex-match-end-chunk-set! 
o|hiding unexported module binding: chicken.irregex#irregex-match-end-index-set! 
o|hiding unexported module binding: chicken.irregex#irregex-match-chunk&index-from-tag-set! 
o|hiding unexported module binding: chicken.irregex#irregex-match-numeric-index 
o|hiding unexported module binding: chicken.irregex#chunker-get-next 
o|hiding unexported module binding: chicken.irregex#chunker-get-str 
o|hiding unexported module binding: chicken.irregex#chunker-get-start 
o|hiding unexported module binding: chicken.irregex#chunker-get-end 
o|hiding unexported module binding: chicken.irregex#chunker-get-substring 
o|hiding unexported module binding: chicken.irregex#chunker-get-subchunk 
o|hiding unexported module binding: chicken.irregex#chunker-prev-chunk 
o|hiding unexported module binding: chicken.irregex#chunker-prev-char 
o|hiding unexported module binding: chicken.irregex#chunker-next-char 
o|hiding unexported module binding: chicken.irregex#chunk-before? 
o|hiding unexported module binding: chicken.irregex#wrap-end-chunker 
o|hiding unexported module binding: chicken.irregex#*all-chars* 
o|hiding unexported module binding: chicken.irregex#*allow-utf8-mode?* 
o|hiding unexported module binding: chicken.irregex#string-scan-char 
o|hiding unexported module binding: chicken.irregex#string-scan-char-escape 
o|hiding unexported module binding: chicken.irregex#string-scan-pred 
o|hiding unexported module binding: chicken.irregex#string-split-char 
o|hiding unexported module binding: chicken.irregex#char-alphanumeric? 
o|hiding unexported module binding: chicken.irregex#%substring=? 
o|hiding unexported module binding: chicken.irregex#%%string-copy! 
o|hiding unexported module binding: chicken.irregex#string-cat-reverse 
o|hiding unexported module binding: chicken.irregex#string-cat-reverse/aux 
o|hiding unexported module binding: chicken.irregex#zero-to 
o|hiding unexported module binding: chicken.irregex#find 
o|hiding unexported module binding: chicken.irregex#find-tail 
o|hiding unexported module binding: chicken.irregex#last 
o|hiding unexported module binding: chicken.irregex#any 
o|hiding unexported module binding: chicken.irregex#every 
o|hiding unexported module binding: chicken.irregex#fold 
o|hiding unexported module binding: chicken.irregex#filter 
o|hiding unexported module binding: chicken.irregex#remove 
o|hiding unexported module binding: chicken.irregex#bit-shr 
o|hiding unexported module binding: chicken.irregex#bit-shl 
o|hiding unexported module binding: chicken.irregex#bit-not 
o|hiding unexported module binding: chicken.irregex#bit-ior 
o|hiding unexported module binding: chicken.irregex#bit-and 
o|hiding unexported module binding: chicken.irregex#integer-log 
o|hiding unexported module binding: chicken.irregex#flag-set? 
o|hiding unexported module binding: chicken.irregex#flag-join 
o|hiding unexported module binding: chicken.irregex#flag-clear 
o|hiding unexported module binding: chicken.irregex#~none 
o|hiding unexported module binding: chicken.irregex#~searcher? 
o|hiding unexported module binding: chicken.irregex#~consumer? 
o|hiding unexported module binding: chicken.irregex#close-token 
o|hiding unexported module binding: chicken.irregex#dot-token 
o|hiding unexported module binding: chicken.irregex#with-read-from-string 
o|hiding unexported module binding: chicken.irregex#~save? 
o|hiding unexported module binding: chicken.irregex#~case-insensitive? 
o|hiding unexported module binding: chicken.irregex#~multi-line? 
o|hiding unexported module binding: chicken.irregex#~single-line? 
o|hiding unexported module binding: chicken.irregex#~ignore-space? 
o|hiding unexported module binding: chicken.irregex#~utf8? 
o|hiding unexported module binding: chicken.irregex#symbol-list->flags 
o|hiding unexported module binding: chicken.irregex#posix-escape-sequences 
o|hiding unexported module binding: chicken.irregex#char-altcase 
o|hiding unexported module binding: chicken.irregex#char-mirror 
o|hiding unexported module binding: chicken.irregex#string-parse-hex-escape 
o|hiding unexported module binding: chicken.irregex#string-parse-cset 
o|hiding unexported module binding: chicken.irregex#high-char? 
o|hiding unexported module binding: chicken.irregex#utf8-start-char->length 
o|hiding unexported module binding: chicken.irregex#utf8-string-ref 
o|hiding unexported module binding: chicken.irregex#utf8-backup-to-initial-char 
o|hiding unexported module binding: chicken.irregex#utf8-lowest-digit-of-length 
o|hiding unexported module binding: chicken.irregex#utf8-highest-digit-of-length 
o|hiding unexported module binding: chicken.irregex#char->utf8-list 
o|hiding unexported module binding: chicken.irregex#unicode-range->utf8-pattern 
o|hiding unexported module binding: chicken.irregex#unicode-range-helper 
o|hiding unexported module binding: chicken.irregex#unicode-range-up-from 
o|hiding unexported module binding: chicken.irregex#unicode-range-up-to 
o|hiding unexported module binding: chicken.irregex#unicode-range-climb-digits 
o|hiding unexported module binding: chicken.irregex#unicode-range-middle 
o|hiding unexported module binding: chicken.irregex#cset->utf8-pattern 
o|hiding unexported module binding: chicken.irregex#sre-adjust-utf8 
o|hiding unexported module binding: chicken.irregex#cached 
o|hiding unexported module binding: chicken.irregex#sre-empty? 
o|hiding unexported module binding: chicken.irregex#sre-any? 
o|hiding unexported module binding: chicken.irregex#sre-repeater? 
o|hiding unexported module binding: chicken.irregex#sre-bos? 
o|hiding unexported module binding: chicken.irregex#sre-searcher? 
o|hiding unexported module binding: chicken.irregex#sre-consumer? 
o|hiding unexported module binding: chicken.irregex#sre-has-submatches? 
o|hiding unexported module binding: chicken.irregex#sre-count-submatches 
o|hiding unexported module binding: chicken.irregex#sre-length-ranges 
o|hiding unexported module binding: chicken.irregex#sre-sequence 
o|hiding unexported module binding: chicken.irregex#sre-alternate 
o|hiding unexported module binding: chicken.irregex#sre-strip-submatches 
o|hiding unexported module binding: chicken.irregex#sre-flatten-ranges 
o|hiding unexported module binding: chicken.irregex#sre-names 
o|hiding unexported module binding: chicken.irregex#sre-sequence-names 
o|hiding unexported module binding: chicken.irregex#sre-remove-initial-bos 
o|hiding unexported module binding: chicken.irregex#irregex-basic-string-chunker 
o|hiding unexported module binding: chicken.irregex#irregex-search/matches 
o|hiding unexported module binding: chicken.irregex#irregex-search/backtrack 
o|hiding unexported module binding: chicken.irregex#dfa-init-state 
o|hiding unexported module binding: chicken.irregex#dfa-next-state 
o|hiding unexported module binding: chicken.irregex#dfa-cell-commands 
o|hiding unexported module binding: chicken.irregex#dfa-finalizer 
o|hiding unexported module binding: chicken.irregex#dfa-match/shortest 
o|hiding unexported module binding: chicken.irregex#finalize! 
o|hiding unexported module binding: chicken.irregex#make-initial-memory 
o|hiding unexported module binding: chicken.irregex#dfa-match/longest 
o|hiding unexported module binding: chicken.irregex#sre-named-definitions 
o|hiding unexported module binding: chicken.irregex#*nfa-presize* 
o|hiding unexported module binding: chicken.irregex#*nfa-num-fields* 
o|hiding unexported module binding: chicken.irregex#nfa-num-states 
o|hiding unexported module binding: chicken.irregex#nfa-start-state 
o|hiding unexported module binding: chicken.irregex#nfa-num-tags 
o|hiding unexported module binding: chicken.irregex#nfa-highest-map-index 
o|hiding unexported module binding: chicken.irregex#nfa-set-highest-map-index! 
o|hiding unexported module binding: chicken.irregex#nfa-get-state-trans 
o|hiding unexported module binding: chicken.irregex#nfa-set-state-trans! 
o|hiding unexported module binding: chicken.irregex#nfa-get-epsilons 
o|hiding unexported module binding: chicken.irregex#nfa-set-epsilons! 
o|hiding unexported module binding: chicken.irregex#nfa-add-epsilon! 
o|hiding unexported module binding: chicken.irregex#nfa-get-reorder-commands 
o|hiding unexported module binding: chicken.irregex#nfa-set-reorder-commands! 
o|hiding unexported module binding: chicken.irregex#nfa-get-closure 
o|hiding unexported module binding: chicken.irregex#nfa-add-closure! 
o|hiding unexported module binding: chicken.irregex#sre->nfa 
o|hiding unexported module binding: chicken.irregex#*mst-first-state-index* 
o|hiding unexported module binding: chicken.irregex#mst-mappings-summary 
o|hiding unexported module binding: chicken.irregex#mst-num-states 
o|hiding unexported module binding: chicken.irregex#mst-num-states-set! 
o|hiding unexported module binding: chicken.irregex#mst-hash 
o|hiding unexported module binding: chicken.irregex#mst-hash-set! 
o|hiding unexported module binding: chicken.irregex#mst-state-mappings 
o|hiding unexported module binding: chicken.irregex#mst-state-mappings-set! 
o|hiding unexported module binding: chicken.irregex#make-mst 
o|hiding unexported module binding: chicken.irregex#mst-copy 
o|hiding unexported module binding: chicken.irregex#nfa-state->mst 
o|hiding unexported module binding: chicken.irregex#mst-add! 
o|hiding unexported module binding: chicken.irregex#mst-add/fast! 
o|hiding unexported module binding: chicken.irregex#mst-add-tagged! 
o|hiding unexported module binding: chicken.irregex#mst-same-states? 
o|hiding unexported module binding: chicken.irregex#mst-fold 
o|hiding unexported module binding: chicken.irregex#next-index-for-tag! 
o|hiding unexported module binding: chicken.irregex#nfa->dfa 
o|hiding unexported module binding: chicken.irregex#dfa-renumber 
o|hiding unexported module binding: chicken.irregex#get-distinct-transitions 
o|hiding unexported module binding: chicken.irregex#nfa-epsilon-closure-internal 
o|hiding unexported module binding: chicken.irregex#nfa-epsilon-closure 
o|hiding unexported module binding: chicken.irregex#tag-set-commands-for-closure 
o|hiding unexported module binding: chicken.irregex#find-reorder-commands-internal 
o|hiding unexported module binding: chicken.irregex#find-reorder-commands 
o|hiding unexported module binding: chicken.irregex#sre->procedure 
o|hiding unexported module binding: chicken.irregex#sre-cset->procedure 
o|hiding unexported module binding: chicken.irregex#make-cset 
o|hiding unexported module binding: chicken.irregex#range->cset 
o|hiding unexported module binding: chicken.irregex#char->cset 
o|hiding unexported module binding: chicken.irregex#cset-empty? 
o|hiding unexported module binding: chicken.irregex#maybe-cset->char 
o|hiding unexported module binding: chicken.irregex#cset=? 
o|hiding unexported module binding: chicken.irregex#cset-size 
o|hiding unexported module binding: chicken.irregex#cset->plist 
o|hiding unexported module binding: chicken.irregex#plist->cset 
o|hiding unexported module binding: chicken.irregex#string->cset 
o|hiding unexported module binding: chicken.irregex#sre->cset 
o|hiding unexported module binding: chicken.irregex#cset->sre 
o|hiding unexported module binding: chicken.irregex#cset-contains? 
o|hiding unexported module binding: chicken.irregex#char-ranges-union 
o|hiding unexported module binding: chicken.irregex#cset-union 
o|hiding unexported module binding: chicken.irregex#cset-adjoin 
o|hiding unexported module binding: chicken.irregex#next-char 
o|hiding unexported module binding: chicken.irregex#prev-char 
o|hiding unexported module binding: chicken.irregex#cset-difference 
o|hiding unexported module binding: chicken.irregex#min-char 
o|hiding unexported module binding: chicken.irregex#max-char 
o|hiding unexported module binding: chicken.irregex#cset-intersection 
o|hiding unexported module binding: chicken.irregex#cset-complement 
o|hiding unexported module binding: chicken.irregex#cset-case-insensitive 
o|hiding unexported module binding: chicken.irregex#irregex-fold/fast 
o|hiding unexported module binding: chicken.irregex#irregex-fold/chunked/fast 
o|hiding unexported module binding: chicken.irregex#irregex-apply-match 
o|hiding unexported module binding: chicken.irregex#rx-special-chars 
o|hiding unexported module binding: chicken.irregex#string-scan-char 
o|hiding unexported module binding: chicken.irregex#cset->string 
S|applied compiler syntax:
S|  irregex-match-chunk&index-from-tag-set!		1
S|  scheme#for-each		12
S|  irregex-match-end-index-set!		7
S|  irregex-match-end-chunk-set!		7
S|  irregex-match-start-index-set!		7
S|  irregex-match-start-chunk-set!		7
S|  make-irregex		2
S|  scheme#map		24
S|  bit-not		1
S|  bit-shr		10
S|  bit-shl		11
S|  bit-and		18
S|  bit-ior		11
S|  %%string-copy!		1
S|  scheme#reverse		35
S|  make-irregex-match		1
o|eliminated procedure checks: 537 
o|eliminated procedure checks: 1 
o|folded constant expression: (scheme#integer->char (quote 0)) 
o|folded constant expression: (scheme#integer->char (quote 55295)) 
o|folded constant expression: (scheme#integer->char (quote 57344)) 
o|folded constant expression: (scheme#integer->char (quote 1114111)) 
o|folded constant expression: (scheme#string->symbol (quote ".")) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#+ (quote 10) (quote 3)) 
o|folded constant expression: (scheme#integer->char (quote 13)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#- (quote 10) (quote 1)) 
o|folded constant expression: (scheme#integer->char (quote 9)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#- (quote 10) (quote 3)) 
o|folded constant expression: (scheme#integer->char (quote 7)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#+ (quote 10) (quote 17)) 
o|folded constant expression: (scheme#integer->char (quote 27)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#+ (quote 10) (quote 2)) 
o|folded constant expression: (scheme#integer->char (quote 12)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|eliminated procedure checks: 1 
o|eliminated procedure checks: 1 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|eliminated procedure checks: 1 
o|eliminated procedure checks: 1 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|eliminated procedure checks: 1 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|eliminated procedure checks: 1 
o|eliminated procedure checks: 1 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|eliminated procedure checks: 1 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#- (quote 32) (quote 23)) 
o|folded constant expression: (scheme#integer->char (quote 9)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#- (quote 32) (quote 32)) 
o|folded constant expression: (scheme#integer->char (quote 0)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#- (quote 32) (quote 1)) 
o|folded constant expression: (scheme#integer->char (quote 31)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#- (quote 32) (quote 32)) 
o|folded constant expression: (scheme#integer->char (quote 0)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 95)) 
o|folded constant expression: (scheme#integer->char (quote 127)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#- (quote 32) (quote 32)) 
o|folded constant expression: (scheme#integer->char (quote 0)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#- (quote 10) (quote 1)) 
o|folded constant expression: (scheme#integer->char (quote 9)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#+ (quote 10) (quote 1)) 
o|folded constant expression: (scheme#integer->char (quote 11)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 95)) 
o|folded constant expression: (scheme#integer->char (quote 127)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#+ (quote 10) (quote 3)) 
o|folded constant expression: (scheme#integer->char (quote 13)) 
o|folded constant expression: (scheme#char->integer (quote #\newline)) 
o|folded constant expression: (scheme#+ (quote 10) (quote 3)) 
o|folded constant expression: (scheme#integer->char (quote 13)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 96)) 
o|folded constant expression: (scheme#integer->char (quote 128)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 161)) 
o|folded constant expression: (scheme#integer->char (quote 193)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 162)) 
o|folded constant expression: (scheme#integer->char (quote 194)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 191)) 
o|folded constant expression: (scheme#integer->char (quote 223)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 192)) 
o|folded constant expression: (scheme#integer->char (quote 224)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 207)) 
o|folded constant expression: (scheme#integer->char (quote 239)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 208)) 
o|folded constant expression: (scheme#integer->char (quote 240)) 
o|folded constant expression: (scheme#char->integer (quote #\space)) 
o|folded constant expression: (scheme#+ (quote 32) (quote 215)) 
o|folded constant expression: (scheme#integer->char (quote 247)) 
o|eliminated procedure checks: 1 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#+ (quote 2) (quote 0)) 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|folded constant expression: (scheme#+ (quote 3) (quote 0)) 
o|eliminated procedure checks: 1 
o|eliminated procedure checks: 1 
o|specializations:
o|  1 (scheme#> fixnum fixnum)
o|  1 (scheme#> integer integer)
o|  1 (scheme#< integer integer)
o|  1 (scheme#char<? char char)
o|  2 (scheme#char<=? char char)
o|  2 (scheme#zero? integer)
o|  1 (scheme#eqv? * *)
o|  1 (scheme#set-car! pair *)
o|  1 (scheme#equal? (or eof null fixnum char boolean symbol keyword) *)
o|  1 (scheme#caar (pair pair *))
o|  1 (scheme#quotient fixnum fixnum)
o|  1 (chicken.irregex#irregex-nfa (struct regexp))
o|  1 (chicken.irregex#irregex-dfa/search (struct regexp))
o|  4 (chicken.irregex#irregex-dfa (struct regexp))
o|  4 (chicken.irregex#irregex-flags (struct regexp))
o|  2 (scheme#string-length string)
o|  3 (scheme#cdddr (pair * (pair * pair)))
o|  5 (scheme#caddr (pair * (pair * pair)))
o|  3 (scheme#vector-length vector)
o|  33 (scheme#cadr (pair * pair))
o|  2 (scheme#- integer integer)
o|  3 (scheme#= fixnum fixnum)
o|  2 (scheme#length list)
o|  1 (scheme#>= fixnum fixnum)
o|  1 (scheme#< fixnum fixnum)
o|  5 (scheme#<= fixnum fixnum)
o|  7 (scheme#>= integer integer)
o|  6 (scheme#cddr (pair * pair))
o|  17 (scheme#memq * list)
o|  4 (##sys#check-list (or pair list) *)
o|  3 (scheme#memv (or symbol keyword procedure eof null fixnum char boolean) list)
o|  3 (scheme#string-ref string fixnum)
o|  1 (scheme#number->string *)
o|  128 (scheme#eqv? (or eof null fixnum char boolean symbol keyword) *)
o|  6 (scheme#+ integer integer)
o|  7 (scheme#* fixnum fixnum)
o|  4 (scheme#odd? *)
o|  13 (scheme#zero? *)
o|  4 (scheme#char=? char char)
o|  264 (scheme#eqv? * (or eof null fixnum char boolean symbol keyword))
o|  215 (scheme#cdr pair)
o|  5 (scheme#cdar (pair pair *))
o|  12 (scheme#integer? *)
o|  159 (scheme#car pair)
o|  16 (scheme#- fixnum fixnum)
o|  1 (chicken.irregex#irregex-names (struct regexp))
o|  1 (scheme#* integer integer)
o|  215 (scheme#+ fixnum fixnum)
(o e)|safe calls: 3632 
(o e)|assignments to immediate values: 13 
o|safe globals: (chicken.irregex#%irregex-match-fail-set! chicken.irregex#%irregex-match-fail chicken.irregex#%irregex-match-end-index chicken.irregex#irregex-match-chunker-set! chicken.irregex#irregex-match-names chicken.irregex#irregex-match-chunker chicken.irregex#irregex-match-num-submatches chicken.irregex#irregex-match-data? chicken.irregex#irregex-copy-matches chicken.irregex#irregex-reset-matches! chicken.irregex#irregex-new-matches chicken.irregex#irregex-names chicken.irregex#irregex-lengths chicken.irregex#irregex-num-submatches chicken.irregex#irregex-flags chicken.irregex#irregex-nfa chicken.irregex#irregex-dfa/search chicken.irregex#irregex-dfa chicken.irregex#irregex? chicken.irregex#vector-copy) 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-dfa/search 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-flags 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-lengths 
o|substituted constant variable: a7645 
o|substituted constant variable: a7643 
o|inlining procedure: k7662 
o|inlining procedure: k7662 
o|substituted constant variable: a7707 
o|inlining procedure: k7789 
o|contracted procedure: "(irregex-core.scm:234) g794795" 
o|inlining procedure: k7789 
o|inlining procedure: k7814 
o|contracted procedure: "(irregex-core.scm:237) g803804" 
o|inlining procedure: k7814 
o|inlining procedure: k7843 
o|contracted procedure: "(irregex-core.scm:240) g812813" 
o|inlining procedure: k7843 
o|inlining procedure: k7872 
o|inlining procedure: k7872 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-match-start-chunk-set! 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-match-start-index-set! 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-match-end-chunk-set! 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-match-end-index-set! 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-match-chunk&index-from-tag-set! 
o|inlining procedure: k7962 
o|inlining procedure: k7962 
o|inlining procedure: k7977 
o|inlining procedure: k7977 
o|inlining procedure: k7993 
o|inlining procedure: k8029 
o|inlining procedure: k8029 
o|contracted procedure: "(irregex-core.scm:279) g860861" 
o|inlining procedure: k8037 
o|inlining procedure: k8037 
o|contracted procedure: "(irregex-core.scm:278) g853854" 
o|inlining procedure: k8007 
o|substituted constant variable: a8025 
o|inlining procedure: k8007 
o|inlining procedure: k7993 
o|inlining procedure: k8074 
o|inlining procedure: k8074 
o|inlining procedure: k8092 
o|inlining procedure: k8092 
o|contracted procedure: "(irregex-core.scm:289) g874875" 
o|inlining procedure: k8149 
o|contracted procedure: "(irregex-core.scm:300) g882883" 
o|inlining procedure: k8167 
o|substituted constant variable: a8185 
o|inlining procedure: k8167 
o|inlining procedure: k8149 
o|contracted procedure: "(irregex-core.scm:301) chicken.irregex#irregex-match-valid-named-index?" 
o|inlining procedure: k7773 
o|inlining procedure: k7773 
o|inlining procedure: k8215 
o|contracted procedure: "(irregex-core.scm:310) g905906" 
o|contracted procedure: "(irregex-core.scm:309) g901902" 
o|contracted procedure: "(irregex-core.scm:308) g897898" 
o|inlining procedure: "(irregex-core.scm:307) chicken.irregex#chunker-get-substring" 
o|inlining procedure: k8215 
o|inlining procedure: "(irregex-core.scm:305) chicken.irregex#irregex-match-chunker" 
o|inlining procedure: k8299 
o|inlining procedure: k8299 
o|contracted procedure: "(irregex-core.scm:322) g924925" 
o|contracted procedure: "(irregex-core.scm:321) g920921" 
o|contracted procedure: "(irregex-core.scm:320) g916917" 
o|inlining procedure: "(irregex-core.scm:316) chicken.irregex#chunker-get-subchunk" 
o|inlining procedure: "(irregex-core.scm:315) chicken.irregex#irregex-match-chunker" 
o|inlining procedure: k8423 
o|inlining procedure: k8435 
o|inlining procedure: k8435 
o|inlining procedure: k8423 
o|inlining procedure: k8454 
o|inlining procedure: k8454 
o|inlining procedure: k8481 
o|inlining procedure: k8481 
o|inlining procedure: k8651 
o|inlining procedure: "(irregex-core.scm:381) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:380) chicken.irregex#chunker-get-str" 
o|inlining procedure: k8651 
o|contracted procedure: "(irregex-core.scm:378) chicken.irregex#chunker-prev-chunk" 
o|inlining procedure: k8615 
o|inlining procedure: k8615 
o|inlining procedure: k8633 
o|inlining procedure: k8633 
o|inlining procedure: "(irregex-core.scm:370) chicken.irregex#chunker-get-next" 
o|inlining procedure: k8684 
o|inlining procedure: "(irregex-core.scm:387) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:386) chicken.irregex#chunker-get-str" 
o|inlining procedure: k8684 
o|inlining procedure: "(irregex-core.scm:384) chicken.irregex#chunker-get-next" 
o|inlining procedure: k8838 
o|inlining procedure: k8838 
o|substituted constant variable: a8855 
o|inlining procedure: k9035 
o|inlining procedure: k9035 
o|removed side-effect free assignment to unused variable: chicken.irregex#%substring=? 
o|removed side-effect free assignment to unused variable: chicken.irregex#%%string-copy! 
o|contracted procedure: "(irregex-core.scm:489) chicken.irregex#string-cat-reverse/aux" 
o|substituted constant variable: u11411146 
o|inlining procedure: k9145 
o|inlining procedure: k9145 
o|inlining procedure: k9166 
o|inlining procedure: k9166 
o|inlining procedure: k9182 
o|inlining procedure: k9182 
o|inlining procedure: k9209 
o|inlining procedure: k9209 
o|removed side-effect free assignment to unused variable: chicken.irregex#find-tail 
o|inlining procedure: k9264 
o|inlining procedure: k9264 
o|inlining procedure: k9279 
o|inlining procedure: k9279 
o|inlining procedure: k9302 
o|inlining procedure: k9318 
o|inlining procedure: k9318 
o|inlining procedure: k9302 
o|inlining procedure: k9348 
o|inlining procedure: k9348 
o|inlining procedure: k9363 
o|inlining procedure: k9363 
o|inlining procedure: k9396 
o|inlining procedure: k9396 
o|removed side-effect free assignment to unused variable: chicken.irregex#filter 
o|removed side-effect free assignment to unused variable: chicken.irregex#remove 
o|removed side-effect free assignment to unused variable: chicken.irregex#bit-shr 
o|removed side-effect free assignment to unused variable: chicken.irregex#bit-shl 
o|removed side-effect free assignment to unused variable: chicken.irregex#bit-not 
o|removed side-effect free assignment to unused variable: chicken.irregex#bit-ior 
o|removed side-effect free assignment to unused variable: chicken.irregex#bit-and 
o|removed side-effect free assignment to unused variable: chicken.irregex#integer-log 
o|inlining procedure: k9720 
o|inlining procedure: k9720 
o|inlining procedure: k9754 
o|inlining procedure: k9754 
o|substituted constant variable: a9777 
o|inlining procedure: k9787 
o|inlining procedure: k9787 
o|inlining procedure: k9806 
o|inlining procedure: k9806 
o|inlining procedure: k9827 
o|inlining procedure: k9827 
o|substituted constant variable: chicken.irregex#dot-token 
o|inlining procedure: k9868 
o|substituted constant variable: a9879 
o|inlining procedure: k9868 
o|substituted constant variable: a9891 
o|inlining procedure: k9895 
o|inlining procedure: k9895 
o|substituted constant variable: a9921 
o|inlining procedure: k9926 
o|substituted constant variable: a9940 
o|substituted constant variable: a9957 
o|inlining procedure: k9926 
o|substituted constant variable: a9991 
o|substituted constant variable: a9993 
o|substituted constant variable: a10000 
o|substituted constant variable: a10007 
o|substituted constant variable: a10010 
o|inlining procedure: k10011 
o|substituted constant variable: a10022 
o|substituted constant variable: a10025 
o|inlining procedure: k10032 
o|inlining procedure: k10032 
o|inlining procedure: k10045 
o|inlining procedure: k10045 
o|substituted constant variable: a10072 
o|inlining procedure: k10077 
o|substituted constant variable: a10088 
o|substituted constant variable: a10091 
o|inlining procedure: k10077 
o|substituted constant variable: a10101 
o|substituted constant variable: a10103 
o|substituted constant variable: a10105 
o|inlining procedure: k10011 
o|inlining procedure: k10115 
o|substituted constant variable: a10126 
o|inlining procedure: k10115 
o|substituted constant variable: a10144 
o|inlining procedure: k10152 
o|inlining procedure: k10152 
o|substituted constant variable: a10168 
o|inlining procedure: k10164 
o|inlining procedure: k10164 
o|substituted constant variable: a10180 
o|substituted constant variable: a10182 
o|inlining procedure: k10183 
o|substituted constant variable: a10201 
o|substituted constant variable: a10202 
o|substituted constant variable: a10209 
o|inlining procedure: k10183 
o|substituted constant variable: a10217 
o|substituted constant variable: a10219 
o|substituted constant variable: a10221 
o|substituted constant variable: a10223 
o|substituted constant variable: a10226 
o|inlining procedure: k10227 
o|substituted constant variable: a10238 
o|inlining procedure: k10227 
o|substituted constant variable: a10244 
o|inlining procedure: k10248 
o|inlining procedure: k10267 
o|inlining procedure: k10267 
o|inlining procedure: k10248 
o|inlining procedure: k10286 
o|inlining procedure: k10286 
o|substituted constant variable: a10290 
o|substituted constant variable: a10295 
o|substituted constant variable: a10297 
o|substituted constant variable: a10299 
o|substituted constant variable: a10304 
o|substituted constant variable: a10306 
o|substituted constant variable: a10308 
o|substituted constant variable: a10310 
o|substituted constant variable: a10312 
o|inlining procedure: k10319 
o|inlining procedure: k10319 
o|inlining procedure: k10346 
o|inlining procedure: k10346 
o|inlining procedure: k10365 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|propagated global variable: r1036631228 chicken.irregex#~case-insensitive? 
o|inlining procedure: k10365 
o|substituted constant variable: chicken.irregex#~multi-line? 
o|inlining procedure: k10383 
o|substituted constant variable: chicken.irregex#~single-line? 
o|propagated global variable: r1038431232 chicken.irregex#~single-line? 
o|inlining procedure: k10383 
o|substituted constant variable: chicken.irregex#~ignore-space? 
o|inlining procedure: k10401 
o|substituted constant variable: chicken.irregex#*allow-utf8-mode?* 
o|substituted constant variable: chicken.irregex#~utf8? 
o|substituted constant variable: chicken.irregex#~none 
o|inlining procedure: k10365 
o|inlining procedure: k10401 
o|substituted constant variable: a10417 
o|substituted constant variable: a10419 
o|substituted constant variable: a10424 
o|substituted constant variable: a10426 
o|substituted constant variable: a10431 
o|substituted constant variable: a10433 
o|substituted constant variable: a10438 
o|substituted constant variable: a10440 
o|inlining procedure: k10444 
o|inlining procedure: k10444 
o|substituted constant variable: a10451 
o|substituted constant variable: a10453 
o|substituted constant variable: a10455 
o|substituted constant variable: chicken.irregex#~none 
o|inlining procedure: k10463 
o|inlining procedure: k10463 
o|inlining procedure: k10493 
o|inlining procedure: k10493 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k10515 
o|inlining procedure: k10537 
o|inlining procedure: k10537 
o|inlining procedure: k10515 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k10571 
o|inlining procedure: k10571 
o|inlining procedure: k10597 
o|inlining procedure: k10597 
o|inlining procedure: k10631 
o|inlining procedure: k10631 
o|contracted procedure: "(irregex-core.scm:778) chicken.irregex#utf8-backup-to-initial-char" 
o|inlining procedure: k14232 
o|inlining procedure: k14232 
o|substituted constant variable: a14255 
o|substituted constant variable: a14260 
o|substituted constant variable: a14262 
o|substituted constant variable: chicken.irregex#~utf8? 
o|inlining procedure: k10691 
o|inlining procedure: k10706 
o|substituted constant variable: a10725 
o|inlining procedure: k10718 
o|inlining procedure: k10718 
o|inlining procedure: k10706 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k10691 
o|substituted constant variable: a10833 
o|inlining procedure: k10826 
o|inlining procedure: k10826 
o|inlining procedure: k10870 
o|inlining procedure: k10870 
o|substituted constant variable: a10884 
o|substituted constant variable: a10892 
o|inlining procedure: k10907 
o|inlining procedure: k10907 
o|substituted constant variable: a10939 
o|substituted constant variable: a10942 
o|substituted constant variable: chicken.irregex#~single-line? 
o|inlining procedure: k10958 
o|substituted constant variable: a10984 
o|substituted constant variable: a10987 
o|inlining procedure: k10993 
o|inlining procedure: k11013 
o|inlining procedure: k11013 
o|inlining procedure: k11043 
o|inlining procedure: k11043 
o|inlining procedure: k11073 
o|inlining procedure: k11073 
o|substituted constant variable: a11101 
o|substituted constant variable: a11103 
o|substituted constant variable: a11105 
o|substituted constant variable: a11107 
o|substituted constant variable: a11109 
o|substituted constant variable: a11111 
o|inlining procedure: k10993 
o|inlining procedure: k10958 
o|inlining procedure: k11133 
o|inlining procedure: k11133 
o|substituted constant variable: a11156 
o|substituted constant variable: a11159 
o|inlining procedure: k11180 
o|substituted constant variable: a11191 
o|inlining procedure: k11196 
o|substituted constant variable: a11207 
o|substituted constant variable: a11210 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k11196 
o|substituted constant variable: a11224 
o|inlining procedure: k11229 
o|substituted constant variable: a11246 
o|inlining procedure: k11250 
o|inlining procedure: k11250 
o|substituted constant variable: a11288 
o|substituted constant variable: a11296 
o|substituted constant variable: a11303 
o|inlining procedure: k11229 
o|substituted constant variable: a11333 
o|inlining procedure: k11334 
o|substituted constant variable: a11345 
o|substituted constant variable: a11348 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k11334 
o|substituted constant variable: a11368 
o|substituted constant variable: a11371 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k11380 
o|substituted constant variable: a11391 
o|substituted constant variable: a11394 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k11380 
o|substituted constant variable: a11414 
o|inlining procedure: k11409 
o|inlining procedure: k11409 
o|substituted constant variable: a11433 
o|substituted constant variable: a11436 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k11445 
o|substituted constant variable: a11456 
o|substituted constant variable: a11459 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k11445 
o|substituted constant variable: a11507 
o|substituted constant variable: chicken.irregex#~save? 
o|substituted constant variable: a11519 
o|substituted constant variable: a11526 
o|substituted constant variable: a11528 
o|substituted constant variable: a11530 
o|substituted constant variable: a11533 
o|inlining procedure: k11534 
o|substituted constant variable: a11545 
o|substituted constant variable: a11548 
o|substituted constant variable: chicken.irregex#~save? 
o|inlining procedure: k11534 
o|substituted constant variable: a11568 
o|inlining procedure: k11563 
o|inlining procedure: k11563 
o|inlining procedure: k11585 
o|inlining procedure: k11585 
o|substituted constant variable: a11599 
o|substituted constant variable: a11602 
o|substituted constant variable: chicken.irregex#~save? 
o|substituted constant variable: a11621 
o|substituted constant variable: a11624 
o|inlining procedure: k11625 
o|substituted constant variable: a11642 
o|substituted constant variable: a11645 
o|substituted constant variable: chicken.irregex#~save? 
o|substituted constant variable: a11664 
o|substituted constant variable: a11667 
o|inlining procedure: k11625 
o|substituted constant variable: a11673 
o|substituted constant variable: a11676 
o|substituted constant variable: chicken.irregex#~save? 
o|substituted constant variable: a11691 
o|substituted constant variable: a11698 
o|inlining procedure: k11699 
o|inlining procedure: k11699 
o|substituted constant variable: a11713 
o|inlining procedure: k11720 
o|propagated global variable: r1172131315 chicken.irregex#flag-clear 
o|inlining procedure: k11720 
o|propagated global variable: r1172131320 chicken.irregex#flag-join 
o|inlining procedure: k11735 
o|inlining procedure: k11735 
o|inlining procedure: k11745 
o|inlining procedure: k11745 
o|substituted constant variable: chicken.irregex#~utf8? 
o|substituted constant variable: chicken.irregex#~utf8? 
o|inlining procedure: k11748 
o|inlining procedure: k11748 
o|substituted constant variable: a11771 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k11776 
o|substituted constant variable: a11787 
o|substituted constant variable: chicken.irregex#~multi-line? 
o|inlining procedure: k11776 
o|substituted constant variable: a11803 
o|substituted constant variable: chicken.irregex#~ignore-space? 
o|inlining procedure: k11808 
o|substituted constant variable: chicken.irregex#*allow-utf8-mode?* 
o|substituted constant variable: a11822 
o|substituted constant variable: chicken.irregex#~utf8? 
o|substituted constant variable: a11832 
o|inlining procedure: k11808 
o|substituted constant variable: a11844 
o|inlining procedure: k11849 
o|substituted constant variable: a11860 
o|substituted constant variable: a11863 
o|inlining procedure: k11849 
o|substituted constant variable: a11883 
o|substituted constant variable: a11886 
o|substituted constant variable: a11907 
o|substituted constant variable: a11909 
o|substituted constant variable: a11911 
o|substituted constant variable: a11913 
o|substituted constant variable: a11915 
o|substituted constant variable: a11917 
o|substituted constant variable: a11919 
o|substituted constant variable: a11921 
o|substituted constant variable: a11923 
o|substituted constant variable: a11925 
o|substituted constant variable: a11927 
o|substituted constant variable: a11929 
o|substituted constant variable: a11931 
o|substituted constant variable: a11933 
o|substituted constant variable: a11935 
o|substituted constant variable: a11938 
o|substituted constant variable: a11943 
o|substituted constant variable: a11946 
o|substituted constant variable: a11952 
o|substituted constant variable: a11955 
o|inlining procedure: k11180 
o|inlining procedure: k11962 
o|inlining procedure: k11962 
o|substituted constant variable: a11976 
o|substituted constant variable: a11979 
o|inlining procedure: k11998 
o|substituted constant variable: a12035 
o|contracted procedure: "(irregex-core.scm:1020) chicken.irregex#string-parse-cset" 
o|inlining procedure: k13412 
o|inlining procedure: k13412 
o|inlining procedure: k13430 
o|substituted constant variable: a13441 
o|inlining procedure: k13430 
o|contracted procedure: "(irregex-core.scm:1240) chicken.irregex#cset->sre" 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k13469 
o|substituted constant variable: a13489 
o|inlining procedure: k13494 
o|inlining procedure: k13494 
o|inlining procedure: k13512 
o|inlining procedure: k13512 
o|inlining procedure: k13536 
o|inlining procedure: k13536 
o|substituted constant variable: a13566 
o|inlining procedure: k13567 
o|substituted constant variable: a13589 
o|inlining procedure: k13567 
o|substituted constant variable: a13595 
o|substituted constant variable: a13613 
o|substituted constant variable: a13616 
o|substituted constant variable: a13617 
o|substituted constant variable: a13625 
o|substituted constant variable: a13629 
o|inlining procedure: k13633 
o|inlining procedure: k13633 
o|substituted constant variable: a13639 
o|substituted constant variable: a13646 
o|substituted constant variable: a13653 
o|inlining procedure: k13469 
o|inlining procedure: k13677 
o|substituted constant variable: a13709 
o|consed rest parameter at call site: "(irregex-core.scm:1276) chicken.irregex#sre->cset" 2 
o|substituted constant variable: a13727 
o|substituted constant variable: a13735 
o|substituted constant variable: a13746 
o|inlining procedure: k13677 
o|substituted constant variable: a13764 
o|substituted constant variable: a13773 
o|substituted constant variable: a13775 
o|substituted constant variable: a13777 
o|substituted constant variable: a13779 
o|substituted constant variable: a13781 
o|substituted constant variable: a13782 
o|substituted constant variable: a13789 
o|inlining procedure: k13790 
o|substituted constant variable: a13813 
o|consed rest parameter at call site: "(irregex-core.scm:1291) chicken.irregex#sre->cset" 2 
o|inlining procedure: k13830 
o|substituted constant variable: a13855 
o|inlining procedure: k13830 
o|substituted constant variable: a13867 
o|substituted constant variable: a13876 
o|inlining procedure: k13880 
o|inlining procedure: k13880 
o|inlining procedure: k13892 
o|inlining procedure: k13892 
o|substituted constant variable: a13905 
o|substituted constant variable: a13907 
o|substituted constant variable: a13909 
o|substituted constant variable: a13911 
o|substituted constant variable: a13913 
o|substituted constant variable: a13915 
o|substituted constant variable: a13918 
o|inlining procedure: k13790 
o|substituted constant variable: a13952 
o|substituted constant variable: a13965 
o|substituted constant variable: a13967 
o|substituted constant variable: a13969 
o|substituted constant variable: a13971 
o|inlining procedure: k13972 
o|inlining procedure: k13983 
o|inlining procedure: k13983 
o|inlining procedure: "(irregex-core.scm:1313) chicken.irregex#make-cset" 
o|substituted constant variable: chicken.irregex#~multi-line? 
o|inlining procedure: k13972 
o|inlining procedure: "(irregex-core.scm:1314) chicken.irregex#make-cset" 
o|substituted constant variable: chicken.irregex#~utf8? 
o|substituted constant variable: a14008 
o|inlining procedure: k11998 
o|substituted constant variable: a12047 
o|inlining procedure: k12042 
o|substituted constant variable: a12057 
o|inlining procedure: k12042 
o|inlining procedure: k12086 
o|inlining procedure: k12086 
o|substituted constant variable: a12109 
o|substituted constant variable: a12112 
o|inlining procedure: k12121 
o|substituted constant variable: a12129 
o|substituted constant variable: a12132 
o|inlining procedure: k12121 
o|substituted constant variable: a12146 
o|substituted constant variable: a12149 
o|inlining procedure: k12160 
o|inlining procedure: k12160 
o|contracted procedure: "(irregex-core.scm:1036) chicken.irregex#string-split-char" 
o|inlining procedure: k8986 
o|inlining procedure: k8986 
o|substituted constant variable: a9010 
o|substituted constant variable: a9013 
o|substituted constant variable: a9023 
o|substituted constant variable: a12207 
o|substituted constant variable: a12210 
o|inlining procedure: k12218 
o|inlining procedure: k12218 
o|substituted constant variable: a12224 
o|substituted constant variable: a12231 
o|substituted constant variable: a12238 
o|inlining procedure: k12239 
o|substituted constant variable: a12250 
o|inlining procedure: k12258 
o|substituted constant variable: a12269 
o|substituted constant variable: a12272 
o|inlining procedure: k12258 
o|substituted constant variable: a12292 
o|substituted constant variable: a12295 
o|inlining procedure: k12308 
o|substituted constant variable: a12319 
o|substituted constant variable: a12322 
o|inlining procedure: k12308 
o|substituted constant variable: a12342 
o|substituted constant variable: a12345 
o|inlining procedure: k12358 
o|substituted constant variable: a12369 
o|substituted constant variable: a12372 
o|inlining procedure: k12358 
o|substituted constant variable: a12400 
o|substituted constant variable: a12403 
o|inlining procedure: k12424 
o|substituted constant variable: a12435 
o|substituted constant variable: a12438 
o|inlining procedure: k12424 
o|substituted constant variable: a12462 
o|substituted constant variable: a12465 
o|inlining procedure: k12474 
o|substituted constant variable: a12485 
o|substituted constant variable: a12488 
o|inlining procedure: k12474 
o|substituted constant variable: a12508 
o|substituted constant variable: a12511 
o|inlining procedure: k12528 
o|substituted constant variable: a12539 
o|substituted constant variable: a12542 
o|inlining procedure: k12528 
o|substituted constant variable: a12562 
o|substituted constant variable: a12565 
o|inlining procedure: k12574 
o|substituted constant variable: a12585 
o|substituted constant variable: a12588 
o|inlining procedure: k12574 
o|substituted constant variable: a12608 
o|substituted constant variable: a12611 
o|inlining procedure: k12620 
o|substituted constant variable: a12631 
o|substituted constant variable: a12634 
o|inlining procedure: k12620 
o|substituted constant variable: a12680 
o|inlining procedure: k12681 
o|inlining procedure: k12711 
o|inlining procedure: k12711 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|substituted constant variable: a12755 
o|substituted constant variable: a12758 
o|contracted procedure: "(irregex-core.scm:1105) chicken.irregex#char-mirror" 
o|inlining procedure: k13268 
o|inlining procedure: k13268 
o|inlining procedure: k13280 
o|inlining procedure: k13280 
o|substituted constant variable: a13293 
o|substituted constant variable: a13295 
o|substituted constant variable: a13297 
o|substituted constant variable: a13299 
o|substituted constant variable: a12761 
o|substituted constant variable: a12764 
o|inlining procedure: k12681 
o|substituted constant variable: a12779 
o|inlining procedure: k12783 
o|inlining procedure: k12783 
o|substituted constant variable: a12807 
o|inlining procedure: k12802 
o|substituted constant variable: a12814 
o|inlining procedure: k12802 
o|substituted constant variable: a12830 
o|substituted constant variable: a12833 
o|substituted constant variable: a12851 
o|substituted constant variable: a12852 
o|substituted constant variable: a12859 
o|substituted constant variable: a12865 
o|substituted constant variable: a12866 
o|inlining procedure: k12871 
o|substituted constant variable: a12882 
o|inlining procedure: k12871 
o|substituted constant variable: a12936 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|substituted constant variable: a12952 
o|contracted procedure: "(irregex-core.scm:1146) chicken.irregex#string-scan-pred" 
o|inlining procedure: k8938 
o|inlining procedure: k8938 
o|substituted constant variable: a8955 
o|inlining procedure: k12953 
o|substituted constant variable: a12970 
o|substituted constant variable: a12973 
o|inlining procedure: k12953 
o|substituted constant variable: a12994 
o|substituted constant variable: a12997 
o|substituted constant variable: a13003 
o|substituted constant variable: a13005 
o|substituted constant variable: a13007 
o|substituted constant variable: a13009 
o|substituted constant variable: a13011 
o|substituted constant variable: a13013 
o|substituted constant variable: a13015 
o|substituted constant variable: a13017 
o|substituted constant variable: a13019 
o|substituted constant variable: a13021 
o|substituted constant variable: a13023 
o|substituted constant variable: a13025 
o|substituted constant variable: a13027 
o|substituted constant variable: a13029 
o|substituted constant variable: a13031 
o|substituted constant variable: a13033 
o|substituted constant variable: a13035 
o|substituted constant variable: a13037 
o|substituted constant variable: a13039 
o|substituted constant variable: a13042 
o|inlining procedure: k12239 
o|substituted constant variable: a13054 
o|substituted constant variable: a13057 
o|inlining procedure: k13066 
o|substituted constant variable: a13080 
o|substituted constant variable: a13083 
o|substituted constant variable: chicken.irregex#~multi-line? 
o|inlining procedure: k13066 
o|substituted constant variable: a13109 
o|substituted constant variable: a13112 
o|substituted constant variable: chicken.irregex#~multi-line? 
o|inlining procedure: k13124 
o|substituted constant variable: a13141 
o|substituted constant variable: a13144 
o|substituted constant variable: a13154 
o|substituted constant variable: chicken.irregex#~ignore-space? 
o|inlining procedure: k13124 
o|inlining procedure: k13161 
o|substituted constant variable: a13189 
o|substituted constant variable: a13192 
o|inlining procedure: k13161 
o|substituted constant variable: a13198 
o|substituted constant variable: chicken.irregex#~ignore-space? 
o|substituted constant variable: a13204 
o|substituted constant variable: a13206 
o|substituted constant variable: a13208 
o|substituted constant variable: a13210 
o|substituted constant variable: a13212 
o|substituted constant variable: a13214 
o|substituted constant variable: a13216 
o|substituted constant variable: a13218 
o|substituted constant variable: a13220 
o|substituted constant variable: a13222 
o|substituted constant variable: a13224 
o|substituted constant variable: a13229 
o|substituted constant variable: a13231 
o|substituted constant variable: a13233 
o|substituted constant variable: a13235 
o|inlining procedure: k13253 
o|inlining procedure: k13253 
o|inlining procedure: k13303 
o|inlining procedure: k13303 
o|inlining procedure: k13321 
o|inlining procedure: k13321 
o|substituted constant variable: a13351 
o|substituted constant variable: a13354 
o|contracted procedure: "(irregex-core.scm:1208) chicken.irregex#string-scan-char-escape" 
o|inlining procedure: k8881 
o|inlining procedure: k8881 
o|inlining procedure: k8893 
o|substituted constant variable: a8904 
o|inlining procedure: k8893 
o|substituted constant variable: a8910 
o|substituted constant variable: a8912 
o|inlining procedure: k13355 
o|inlining procedure: k13355 
o|substituted constant variable: a13382 
o|substituted constant variable: a13388 
o|substituted constant variable: a13391 
o|substituted constant variable: a13392 
o|substituted constant variable: a14019 
o|substituted constant variable: table1944 
o|inlining procedure: k14047 
o|inlining procedure: k14047 
o|inlining procedure: k14090 
o|inlining procedure: k14090 
o|substituted constant variable: a14216 
o|substituted constant variable: a14218 
o|substituted constant variable: a14220 
o|substituted constant variable: a14222 
o|inlining procedure: k14270 
o|inlining procedure: k14270 
o|inlining procedure: k14282 
o|inlining procedure: k14282 
o|substituted constant variable: a14298 
o|substituted constant variable: a14300 
o|substituted constant variable: a14302 
o|substituted constant variable: a14304 
o|inlining procedure: k14349 
o|inlining procedure: k14349 
o|inlining procedure: k14383 
o|inlining procedure: k14383 
o|substituted constant variable: a14473 
o|substituted constant variable: a14475 
o|substituted constant variable: a14477 
o|substituted constant variable: a14479 
o|inlining procedure: k14622 
o|inlining procedure: k14622 
o|inlining procedure: k14688 
o|contracted procedure: "(irregex-core.scm:1452) g20832092" 
o|inlining procedure: k14688 
o|inlining procedure: k14724 
o|inlining procedure: k14724 
o|inlining procedure: k14845 
o|inlining procedure: k14845 
o|inlining procedure: k14984 
o|inlining procedure: k14984 
o|inlining procedure: k15487 
o|inlining procedure: k15505 
o|inlining procedure: k15505 
o|inlining procedure: k15487 
o|contracted procedure: "(irregex-core.scm:1540) chicken.irregex#unicode-range->utf8-pattern" 
o|inlining procedure: k14489 
o|contracted procedure: "(irregex-core.scm:1425) chicken.irregex#unicode-range-climb-digits" 
o|inlining procedure: k15090 
o|contracted procedure: "(irregex-core.scm:1507) g22432252" 
o|inlining procedure: k15090 
o|contracted procedure: "(irregex-core.scm:1506) chicken.irregex#utf8-highest-digit-of-length" 
o|inlining procedure: k14308 
o|inlining procedure: k14308 
o|inlining procedure: k14320 
o|inlining procedure: k14320 
o|substituted constant variable: a14336 
o|substituted constant variable: a14338 
o|substituted constant variable: a14340 
o|substituted constant variable: a14342 
o|inlining procedure: k15193 
o|contracted procedure: "(irregex-core.scm:1518) g22832292" 
o|inlining procedure: k15193 
o|inlining procedure: k15261 
o|inlining procedure: k15261 
o|substituted constant variable: a15299 
o|inlining procedure: k15331 
o|contracted procedure: "(irregex-core.scm:1498) g21902199" 
o|inlining procedure: k15331 
o|inlining procedure: k15371 
o|inlining procedure: k15371 
o|inlining procedure: k14489 
o|inlining procedure: k14516 
o|inlining procedure: k14534 
o|inlining procedure: k14534 
o|inlining procedure: k14516 
o|contracted procedure: "(irregex-core.scm:1439) chicken.irregex#unicode-range-middle" 
o|inlining procedure: k15422 
o|contracted procedure: "(irregex-core.scm:1527) g23212330" 
o|inlining procedure: k15422 
o|inlining procedure: k16050 
o|inlining procedure: k16050 
o|inlining procedure: k16062 
o|inlining procedure: k16062 
o|inlining procedure: k16080 
o|inlining procedure: k16080 
o|inlining procedure: k16098 
o|inlining procedure: k16098 
o|inlining procedure: k16163 
o|inlining procedure: k16163 
o|inlining procedure: k16224 
o|inlining procedure: k16224 
o|contracted procedure: "(irregex-core.scm:1645) chicken.irregex#sre->procedure" 
o|inlining procedure: "(irregex-core.scm:3142) chicken.irregex#%irregex-match-fail-set!" 
o|inlining procedure: k23466 
o|consed rest parameter at call site: "(irregex-core.scm:3150) chicken.irregex#sre->cset" 2 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k23492 
o|consed rest parameter at call site: "(irregex-core.scm:3155) chicken.irregex#sre->cset" 2 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k23492 
o|inlining procedure: k23521 
o|inlining procedure: k23521 
o|substituted constant variable: a23587 
o|substituted constant variable: a23589 
o|inlining procedure: k23592 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k23592 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k23630 
o|substituted constant variable: chicken.irregex#~utf8? 
o|inlining procedure: k23630 
o|substituted constant variable: chicken.irregex#~utf8? 
o|inlining procedure: k23668 
o|inlining procedure: k23686 
o|inlining procedure: k23686 
o|substituted constant variable: a23730 
o|substituted constant variable: a23732 
o|inlining procedure: k23668 
o|inlining procedure: k23761 
o|inlining procedure: k23761 
o|inlining procedure: k23793 
o|inlining procedure: k23793 
o|inlining procedure: k23832 
o|inlining procedure: k23832 
o|inlining procedure: k23892 
o|inlining procedure: k23892 
o|inlining procedure: k23929 
o|inlining procedure: k23929 
o|inlining procedure: k23988 
o|inlining procedure: k24024 
o|inlining procedure: k24024 
o|inlining procedure: k24042 
o|inlining procedure: k24042 
o|inlining procedure: k24065 
o|inlining procedure: k24065 
o|inlining procedure: k24082 
o|inlining procedure: k24082 
o|inlining procedure: k24093 
o|inlining procedure: k24093 
o|inlining procedure: k24101 
o|inlining procedure: k24101 
o|inlining procedure: k24116 
o|inlining procedure: k24116 
o|inlining procedure: k23988 
o|inlining procedure: k24146 
o|inlining procedure: k24176 
o|inlining procedure: k24176 
o|inlining procedure: k24198 
o|inlining procedure: k24198 
o|inlining procedure: k24146 
o|inlining procedure: k24232 
o|inlining procedure: k24232 
o|inlining procedure: k24255 
o|inlining procedure: k24255 
o|inlining procedure: k24263 
o|inlining procedure: k24263 
o|inlining procedure: k24278 
o|inlining procedure: k24278 
o|inlining procedure: k24302 
o|inlining procedure: k24302 
o|inlining procedure: k24360 
o|inlining procedure: k24360 
o|inlining procedure: k24388 
o|inlining procedure: k24388 
o|inlining procedure: k24412 
o|inlining procedure: k24423 
o|inlining procedure: k24423 
o|inlining procedure: k24412 
o|inlining procedure: k24477 
o|inlining procedure: k24477 
o|inlining procedure: "(irregex-core.scm:3361) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:3359) chicken.irregex#chunker-get-str" 
o|contracted procedure: "(irregex-core.scm:3358) chicken.irregex#wrap-end-chunker" 
o|inlining procedure: k8744 
o|inlining procedure: "(irregex-core.scm:401) chicken.irregex#chunker-get-next" 
o|inlining procedure: k8744 
o|inlining procedure: k8771 
o|inlining procedure: k8771 
o|inlining procedure: "(irregex-core.scm:413) chicken.irregex#chunker-get-end" 
o|inlining procedure: k8786 
o|inlining procedure: "(irregex-core.scm:411) chicken.irregex#chunker-get-next" 
o|inlining procedure: k8786 
o|inlining procedure: "(irregex-core.scm:410) chicken.irregex#chunker-get-next" 
o|inlining procedure: "(irregex-core.scm:415) chicken.irregex#chunker-get-subchunk" 
o|inlining procedure: "(irregex-core.scm:414) chicken.irregex#chunker-get-substring" 
o|inlining procedure: "(irregex-core.scm:403) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:402) chicken.irregex#chunker-get-str" 
o|inlining procedure: k24533 
o|inlining procedure: k24547 
o|inlining procedure: k24547 
o|inlining procedure: k24533 
o|inlining procedure: k24583 
o|inlining procedure: k24597 
o|inlining procedure: k24597 
o|contracted procedure: "(irregex-core.scm:3399) g48084809" 
o|inlining procedure: k24632 
o|inlining procedure: k24632 
o|inlining procedure: k24583 
o|inlining procedure: k24721 
o|inlining procedure: k24741 
o|inlining procedure: k24741 
o|inlining procedure: k24760 
o|inlining procedure: k24760 
o|inlining procedure: k24810 
o|inlining procedure: "(irregex-core.scm:3444) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:3443) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3442) chicken.irregex#chunker-get-str" 
o|inlining procedure: k24810 
o|inlining procedure: "(irregex-core.scm:3439) chicken.irregex#chunker-get-next" 
o|inlining procedure: k24878 
o|inlining procedure: k24878 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k24894 
o|inlining procedure: k24894 
o|inlining procedure: k24721 
o|inlining procedure: k24938 
o|contracted procedure: "(irregex-core.scm:3473) g49214922" 
o|contracted procedure: "(irregex-core.scm:3472) g49174918" 
o|contracted procedure: "(irregex-core.scm:3459) g48874888" 
o|inlining procedure: k24938 
o|substituted constant variable: a25181 
o|substituted constant variable: a25183 
o|substituted constant variable: a25188 
o|substituted constant variable: a25190 
o|substituted constant variable: a25192 
o|substituted constant variable: a25197 
o|substituted constant variable: a25199 
o|substituted constant variable: a25201 
o|substituted constant variable: a25203 
o|substituted constant variable: a25208 
o|substituted constant variable: a25210 
o|substituted constant variable: a25212 
o|substituted constant variable: a25214 
o|substituted constant variable: a25216 
o|substituted constant variable: a25218 
o|substituted constant variable: a25220 
o|substituted constant variable: a25222 
o|substituted constant variable: a25224 
o|substituted constant variable: a25226 
o|substituted constant variable: a25228 
o|substituted constant variable: a25230 
o|substituted constant variable: a25232 
o|substituted constant variable: a25234 
o|substituted constant variable: a25236 
o|substituted constant variable: a25238 
o|substituted constant variable: a25243 
o|substituted constant variable: a25245 
o|substituted constant variable: a25247 
o|substituted constant variable: a25249 
o|substituted constant variable: a25251 
o|substituted constant variable: a25253 
o|substituted constant variable: a25255 
o|inlining procedure: k25259 
o|inlining procedure: k25259 
o|substituted constant variable: a25272 
o|substituted constant variable: a25274 
o|substituted constant variable: a25276 
o|substituted constant variable: a25278 
o|inlining procedure: k23466 
o|inlining procedure: k25287 
o|inlining procedure: k25295 
o|inlining procedure: k25295 
o|inlining procedure: "(irregex-core.scm:3497) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:3496) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3495) chicken.irregex#chunker-get-str" 
o|inlining procedure: "(irregex-core.scm:3493) chicken.irregex#chunker-get-next" 
o|inlining procedure: k25287 
o|inlining procedure: k25353 
o|substituted constant variable: a25370 
o|substituted constant variable: a25378 
o|inlining procedure: k25353 
o|inlining procedure: k25410 
o|substituted constant variable: a25421 
o|inlining procedure: k25410 
o|substituted constant variable: a25429 
o|inlining procedure: "(irregex-core.scm:3510) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:3509) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3508) chicken.irregex#chunker-get-str" 
o|inlining procedure: "(irregex-core.scm:3506) chicken.irregex#chunker-get-next" 
o|inlining procedure: k25437 
o|inlining procedure: k25445 
o|inlining procedure: k25445 
o|inlining procedure: k25437 
o|inlining procedure: k25475 
o|inlining procedure: k25475 
o|substituted constant variable: a25496 
o|inlining procedure: "(irregex-core.scm:3522) chicken.irregex#chunker-get-start" 
o|inlining procedure: k25518 
o|inlining procedure: k25526 
o|inlining procedure: k25526 
o|inlining procedure: k25541 
o|inlining procedure: k25541 
o|inlining procedure: "(irregex-core.scm:3540) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3539) chicken.irregex#chunker-get-str" 
o|inlining procedure: "(irregex-core.scm:3536) chicken.irregex#chunker-get-next" 
o|inlining procedure: k25608 
o|inlining procedure: k25608 
o|inlining procedure: "(irregex-core.scm:3530) chicken.irregex#chunker-get-start" 
o|inlining procedure: k25518 
o|inlining procedure: k25633 
o|inlining procedure: k25633 
o|inlining procedure: "(irregex-core.scm:3545) chicken.irregex#chunker-get-next" 
o|inlining procedure: k25658 
o|inlining procedure: k25666 
o|inlining procedure: k25666 
o|substituted constant variable: a25684 
o|inlining procedure: k25695 
o|inlining procedure: k25695 
o|substituted constant variable: a25704 
o|inlining procedure: "(irregex-core.scm:3557) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3556) chicken.irregex#chunker-get-str" 
o|inlining procedure: "(irregex-core.scm:3552) chicken.irregex#chunker-get-next" 
o|inlining procedure: k25658 
o|inlining procedure: k25731 
o|inlining procedure: k25731 
o|inlining procedure: k25746 
o|inlining procedure: k25746 
o|inlining procedure: "(irregex-core.scm:3566) chicken.irregex#chunker-get-start" 
o|inlining procedure: k25802 
o|inlining procedure: k25802 
o|inlining procedure: k25812 
o|inlining procedure: k25826 
o|inlining procedure: k25826 
o|inlining procedure: k25838 
o|inlining procedure: k25838 
o|inlining procedure: "(irregex-core.scm:3577) chicken.irregex#chunker-get-start" 
o|inlining procedure: k25812 
o|inlining procedure: k25895 
o|inlining procedure: k25895 
o|substituted constant variable: a25909 
o|substituted constant variable: a25911 
o|substituted constant variable: a25913 
o|substituted constant variable: a25915 
o|substituted constant variable: a25917 
o|substituted constant variable: a25919 
o|substituted constant variable: a25921 
o|substituted constant variable: a25923 
o|substituted constant variable: a25925 
o|substituted constant variable: a25927 
o|inlining procedure: k25928 
o|inlining procedure: k25942 
o|inlining procedure: k25961 
o|inlining procedure: "(irregex-core.scm:3604) chicken.irregex#chunker-get-next" 
o|inlining procedure: k25998 
o|substituted constant variable: a26009 
o|inlining procedure: k25998 
o|inlining procedure: "(irregex-core.scm:3602) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:3601) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3600) chicken.irregex#chunker-get-str" 
o|inlining procedure: k25961 
o|inlining procedure: "(irregex-core.scm:3598) chicken.irregex#chunker-get-next" 
o|inlining procedure: k25942 
o|substituted constant variable: a26031 
o|inlining procedure: k26041 
o|inlining procedure: k26060 
o|inlining procedure: "(irregex-core.scm:3622) chicken.irregex#chunker-get-next" 
o|inlining procedure: k26097 
o|substituted constant variable: a26108 
o|inlining procedure: k26097 
o|inlining procedure: "(irregex-core.scm:3620) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:3619) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3618) chicken.irregex#chunker-get-str" 
o|inlining procedure: k26060 
o|inlining procedure: "(irregex-core.scm:3616) chicken.irregex#chunker-get-next" 
o|inlining procedure: k26041 
o|substituted constant variable: a26130 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k25928 
o|substituted constant variable: chicken.irregex#~none 
o|inlining procedure: k16241 
o|substituted constant variable: chicken.irregex#~consumer? 
o|propagated global variable: r1624231901 chicken.irregex#~consumer? 
o|inlining procedure: k16241 
o|substituted constant variable: chicken.irregex#~none 
o|inlining procedure: k16248 
o|substituted constant variable: chicken.irregex#~searcher? 
o|propagated global variable: r1624931905 chicken.irregex#~searcher? 
o|substituted constant variable: chicken.irregex#~none 
o|inlining procedure: k16248 
o|substituted constant variable: chicken.irregex#~none 
o|contracted procedure: "(irregex-core.scm:1637) chicken.irregex#sre-length-ranges" 
o|inlining procedure: k17119 
o|inlining procedure: k17119 
o|inlining procedure: k17125 
o|inlining procedure: k17141 
o|inlining procedure: k17141 
o|inlining procedure: k17170 
o|inlining procedure: k17187 
o|inlining procedure: k17201 
o|inlining procedure: k17201 
o|inlining procedure: k17187 
o|inlining procedure: k17236 
o|inlining procedure: k17236 
o|inlining procedure: k17170 
o|inlining procedure: k17265 
o|inlining procedure: k17279 
o|inlining procedure: k17279 
o|inlining procedure: k17289 
o|inlining procedure: k17289 
o|inlining procedure: k17265 
o|inlining procedure: k17318 
o|inlining procedure: k17318 
o|inlining procedure: k17336 
o|inlining procedure: k17406 
o|inlining procedure: k17412 
o|inlining procedure: k17412 
o|inlining procedure: k17406 
o|inlining procedure: k17439 
o|inlining procedure: k17439 
o|inlining procedure: k17336 
o|inlining procedure: k17494 
o|inlining procedure: k17528 
o|inlining procedure: k17528 
o|inlining procedure: k17494 
o|inlining procedure: k17552 
o|inlining procedure: k17552 
o|inlining procedure: k17587 
o|inlining procedure: k17587 
o|inlining procedure: k17630 
o|inlining procedure: k17630 
o|inlining procedure: k17649 
o|inlining procedure: k17649 
o|inlining procedure: k17682 
o|inlining procedure: k17682 
o|inlining procedure: k17718 
o|inlining procedure: k17718 
o|inlining procedure: k17776 
o|inlining procedure: k17776 
o|inlining procedure: k17791 
o|inlining procedure: k17791 
o|inlining procedure: k17815 
o|inlining procedure: k17815 
o|inlining procedure: k17863 
o|inlining procedure: k17863 
o|inlining procedure: k17874 
o|substituted constant variable: a17911 
o|inlining procedure: k17903 
o|inlining procedure: k17903 
o|inlining procedure: k17874 
o|inlining procedure: k17929 
o|inlining procedure: k17929 
o|inlining procedure: k17960 
o|inlining procedure: k17960 
o|substituted constant variable: a17973 
o|substituted constant variable: a17975 
o|substituted constant variable: a17977 
o|substituted constant variable: a17979 
o|inlining procedure: k17983 
o|inlining procedure: k17983 
o|substituted constant variable: a17996 
o|substituted constant variable: a17998 
o|substituted constant variable: a18000 
o|substituted constant variable: a18002 
o|substituted constant variable: a18007 
o|substituted constant variable: a18009 
o|substituted constant variable: a18011 
o|substituted constant variable: a18016 
o|substituted constant variable: a18018 
o|substituted constant variable: a18023 
o|substituted constant variable: a18025 
o|substituted constant variable: a18030 
o|substituted constant variable: a18032 
o|inlining procedure: k18036 
o|inlining procedure: k18036 
o|substituted constant variable: a18049 
o|substituted constant variable: a18051 
o|substituted constant variable: a18053 
o|substituted constant variable: a18055 
o|substituted constant variable: a18057 
o|substituted constant variable: a18059 
o|substituted constant variable: a18061 
o|inlining procedure: k18065 
o|inlining procedure: k18065 
o|inlining procedure: k18077 
o|inlining procedure: k18077 
o|substituted constant variable: a18084 
o|substituted constant variable: a18086 
o|substituted constant variable: a18088 
o|substituted constant variable: a18090 
o|substituted constant variable: a18092 
o|substituted constant variable: a18094 
o|inlining procedure: k18098 
o|inlining procedure: k18098 
o|substituted constant variable: a18111 
o|substituted constant variable: a18113 
o|substituted constant variable: a18115 
o|substituted constant variable: a18117 
o|inlining procedure: k17125 
o|inlining procedure: k18129 
o|inlining procedure: k18129 
o|substituted constant variable: a18147 
o|substituted constant variable: a18155 
o|inlining procedure: k18151 
o|inlining procedure: k18151 
o|inlining procedure: k18169 
o|inlining procedure: k18169 
o|consed rest parameter at call site: "(irregex-core.scm:1633) chicken.irregex#nfa->dfa" 2 
o|substituted constant variable: a16270 
o|inlining procedure: k16272 
o|inlining procedure: k16272 
o|consed rest parameter at call site: "(irregex-core.scm:1629) chicken.irregex#nfa->dfa" 2 
o|substituted constant variable: a16305 
o|substituted constant variable: a16310 
o|inlining procedure: k16307 
o|inlining procedure: k16307 
o|substituted constant variable: chicken.irregex#*allow-utf8-mode?* 
o|contracted procedure: "(irregex-core.scm:1616) chicken.irregex#sre-adjust-utf8" 
o|inlining procedure: k15605 
o|inlining procedure: k15627 
o|inlining procedure: k15627 
o|inlining procedure: k15672 
o|inlining procedure: k15672 
o|inlining procedure: k15703 
o|inlining procedure: k15733 
o|inlining procedure: k15733 
o|inlining procedure: k15703 
o|inlining procedure: k15773 
o|inlining procedure: k15773 
o|inlining procedure: k15788 
o|inlining procedure: k15788 
o|consed rest parameter at call site: "(irregex-core.scm:1561) chicken.irregex#sre->cset" 2 
o|inlining procedure: k15805 
o|inlining procedure: k15820 
o|inlining procedure: k15820 
o|inlining procedure: k15843 
o|inlining procedure: k15843 
o|substituted constant variable: a15875 
o|substituted constant variable: a15877 
o|inlining procedure: k15805 
o|inlining procedure: k15899 
o|inlining procedure: k15899 
o|substituted constant variable: a15931 
o|inlining procedure: k15935 
o|inlining procedure: k15935 
o|substituted constant variable: a15948 
o|substituted constant variable: a15950 
o|substituted constant variable: a15952 
o|substituted constant variable: a15954 
o|substituted constant variable: a15956 
o|substituted constant variable: a15958 
o|substituted constant variable: a15960 
o|substituted constant variable: a15962 
o|inlining procedure: k15605 
o|inlining procedure: k15969 
o|inlining procedure: k15969 
o|inlining procedure: k15972 
o|inlining procedure: k15972 
o|inlining procedure: k16003 
o|inlining procedure: k16003 
o|inlining procedure: k16034 
o|inlining procedure: k16034 
o|substituted constant variable: a16044 
o|substituted constant variable: a16046 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|substituted constant variable: chicken.irregex#~utf8? 
o|inlining procedure: k16321 
o|inlining procedure: k16337 
o|inlining procedure: k16337 
o|inlining procedure: k16371 
o|inlining procedure: k16371 
o|inlining procedure: k16388 
o|inlining procedure: k16388 
o|inlining procedure: k16400 
o|inlining procedure: k16400 
o|inlining procedure: k16412 
o|inlining procedure: k16412 
o|substituted constant variable: a16425 
o|substituted constant variable: a16427 
o|substituted constant variable: a16429 
o|substituted constant variable: a16431 
o|substituted constant variable: a16433 
o|substituted constant variable: a16435 
o|substituted constant variable: a16437 
o|substituted constant variable: a16439 
o|substituted constant variable: a16441 
o|substituted constant variable: a16443 
o|inlining procedure: k16447 
o|inlining procedure: k16447 
o|inlining procedure: k16459 
o|inlining procedure: k16459 
o|substituted constant variable: a16472 
o|substituted constant variable: a16474 
o|substituted constant variable: a16476 
o|substituted constant variable: a16478 
o|substituted constant variable: a16480 
o|substituted constant variable: a16482 
o|inlining procedure: k16321 
o|substituted constant variable: a16484 
o|inlining procedure: k16491 
o|inlining procedure: k16491 
o|inlining procedure: k16501 
o|inlining procedure: k16516 
o|inlining procedure: k16516 
o|inlining procedure: k16501 
o|substituted constant variable: a16546 
o|inlining procedure: k16550 
o|inlining procedure: k16550 
o|inlining procedure: k16562 
o|inlining procedure: k16562 
o|substituted constant variable: a16575 
o|substituted constant variable: a16577 
o|substituted constant variable: a16579 
o|substituted constant variable: a16581 
o|substituted constant variable: a16583 
o|substituted constant variable: a16585 
o|substituted constant variable: a16597 
o|inlining procedure: k16589 
o|substituted constant variable: a16606 
o|inlining procedure: k16601 
o|inlining procedure: k16613 
o|inlining procedure: k16613 
o|inlining procedure: k16601 
o|inlining procedure: k16589 
o|inlining procedure: k16634 
o|inlining procedure: k16650 
o|inlining procedure: k16650 
o|inlining procedure: k16665 
o|inlining procedure: k16665 
o|substituted constant variable: a16677 
o|inlining procedure: k16681 
o|inlining procedure: k16681 
o|inlining procedure: k16693 
o|inlining procedure: k16693 
o|substituted constant variable: a16706 
o|substituted constant variable: a16708 
o|substituted constant variable: a16710 
o|substituted constant variable: a16712 
o|substituted constant variable: a16714 
o|substituted constant variable: a16716 
o|inlining procedure: k16634 
o|inlining procedure: k16726 
o|inlining procedure: k16726 
o|inlining procedure: k16736 
o|inlining procedure: k16736 
o|inlining procedure: k16763 
o|inlining procedure: k16763 
o|inlining procedure: k16778 
o|inlining procedure: k16778 
o|substituted constant variable: a16790 
o|inlining procedure: k16794 
o|inlining procedure: k16794 
o|inlining procedure: k16806 
o|inlining procedure: k16806 
o|substituted constant variable: a16819 
o|substituted constant variable: a16821 
o|substituted constant variable: a16823 
o|substituted constant variable: a16825 
o|substituted constant variable: a16827 
o|substituted constant variable: a16829 
o|substituted constant variable: a16834 
o|substituted constant variable: a16836 
o|inlining procedure: k16843 
o|inlining procedure: k16843 
o|inlining procedure: k16853 
o|inlining procedure: k16853 
o|inlining procedure: k16880 
o|inlining procedure: k16880 
o|inlining procedure: k16895 
o|inlining procedure: k16895 
o|substituted constant variable: a16907 
o|inlining procedure: k16911 
o|inlining procedure: k16911 
o|inlining procedure: k16923 
o|inlining procedure: k16923 
o|substituted constant variable: a16936 
o|substituted constant variable: a16938 
o|substituted constant variable: a16940 
o|substituted constant variable: a16942 
o|substituted constant variable: a16944 
o|substituted constant variable: a16946 
o|substituted constant variable: a16951 
o|substituted constant variable: a16953 
o|substituted constant variable: a16965 
o|inlining procedure: k16957 
o|inlining procedure: k16969 
o|inlining procedure: k16969 
o|inlining procedure: k16957 
o|inlining procedure: k17002 
o|inlining procedure: k17019 
o|inlining procedure: k17019 
o|inlining procedure: k17045 
o|inlining procedure: k17045 
o|substituted constant variable: a17063 
o|substituted constant variable: a17065 
o|inlining procedure: k17069 
o|inlining procedure: k17069 
o|substituted constant variable: a17082 
o|substituted constant variable: a17084 
o|substituted constant variable: a17086 
o|substituted constant variable: a17088 
o|inlining procedure: k17002 
o|inlining procedure: k18205 
o|inlining procedure: k18205 
o|inlining procedure: k18228 
o|inlining procedure: k18228 
o|inlining procedure: k18251 
o|inlining procedure: k18251 
o|inlining procedure: k18278 
o|inlining procedure: k18278 
o|inlining procedure: k18324 
o|inlining procedure: k18324 
o|substituted constant variable: a18356 
o|substituted constant variable: a18361 
o|substituted constant variable: a18363 
o|substituted constant variable: a18368 
o|substituted constant variable: a18370 
o|inlining procedure: k18432 
o|inlining procedure: k18432 
o|inlining procedure: k18463 
o|inlining procedure: k18463 
o|inlining procedure: k18524 
o|inlining procedure: k18524 
o|inlining procedure: k18554 
o|inlining procedure: k18554 
o|substituted constant variable: a18574 
o|substituted constant variable: a18576 
o|substituted constant variable: a18581 
o|substituted constant variable: a18583 
o|inlining procedure: k18587 
o|inlining procedure: k18587 
o|inlining procedure: k18599 
o|inlining procedure: k18599 
o|inlining procedure: k18611 
o|inlining procedure: k18611 
o|inlining procedure: k18623 
o|inlining procedure: k18623 
o|inlining procedure: k18635 
o|inlining procedure: k18635 
o|inlining procedure: k18647 
o|inlining procedure: k18647 
o|inlining procedure: k18659 
o|inlining procedure: k18659 
o|substituted constant variable: a18666 
o|substituted constant variable: a18668 
o|substituted constant variable: a18670 
o|substituted constant variable: a18672 
o|substituted constant variable: a18674 
o|substituted constant variable: a18676 
o|substituted constant variable: a18678 
o|substituted constant variable: a18680 
o|substituted constant variable: a18682 
o|substituted constant variable: a18684 
o|substituted constant variable: a18686 
o|substituted constant variable: a18688 
o|substituted constant variable: a18690 
o|substituted constant variable: a18692 
o|substituted constant variable: a18694 
o|substituted constant variable: a18696 
o|substituted constant variable: a18701 
o|substituted constant variable: a18703 
o|substituted constant variable: a18708 
o|substituted constant variable: a18710 
o|inlining procedure: k18718 
o|inlining procedure: k18718 
o|inlining procedure: k18750 
o|inlining procedure: k18766 
o|inlining procedure: k18766 
o|inlining procedure: k18816 
o|inlining procedure: k18839 
o|inlining procedure: k18839 
o|inlining procedure: k18816 
o|substituted constant variable: a18871 
o|inlining procedure: k18875 
o|inlining procedure: k18875 
o|inlining procedure: k18887 
o|inlining procedure: k18887 
o|inlining procedure: k18899 
o|inlining procedure: k18899 
o|substituted constant variable: a18912 
o|substituted constant variable: a18914 
o|substituted constant variable: a18916 
o|substituted constant variable: a18918 
o|substituted constant variable: a18920 
o|substituted constant variable: a18922 
o|substituted constant variable: a18924 
o|substituted constant variable: a18926 
o|inlining procedure: k18750 
o|inlining procedure: k18969 
o|inlining procedure: k18969 
o|inlining procedure: k18983 
o|inlining procedure: k18983 
o|inlining procedure: k18996 
o|inlining procedure: k18996 
o|inlining procedure: "(irregex-core.scm:1989) chicken.irregex#irregex-match-chunker-set!" 
o|inlining procedure: "(irregex-core.scm:1987) chicken.irregex#chunker-get-start" 
o|inlining procedure: k19067 
o|inlining procedure: k19079 
o|inlining procedure: k19079 
o|inlining procedure: k19104 
o|inlining procedure: k19137 
o|inlining procedure: k19137 
o|inlining procedure: k19166 
o|inlining procedure: k19166 
o|inlining procedure: "(irregex-core.scm:2011) chicken.irregex#chunker-get-next" 
o|inlining procedure: "(irregex-core.scm:2010) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:2009) chicken.irregex#chunker-get-start" 
o|inlining procedure: k19104 
o|contracted procedure: "(irregex-core.scm:2006) chicken.irregex#dfa-match/shortest" 
o|inlining procedure: k19692 
o|inlining procedure: k19707 
o|inlining procedure: k19707 
o|inlining procedure: k19758 
o|substituted constant variable: a19766 
o|inlining procedure: k19758 
o|inlining procedure: k19777 
o|inlining procedure: k19777 
o|inlining procedure: k19809 
o|inlining procedure: k19809 
o|inlining procedure: "(irregex-core.scm:2140) chicken.irregex#dfa-finalizer" 
o|inlining procedure: k19692 
o|inlining procedure: "(irregex-core.scm:2132) chicken.irregex#dfa-init-state" 
o|inlining procedure: "(irregex-core.scm:2130) chicken.irregex#chunker-get-next" 
o|inlining procedure: "(irregex-core.scm:2129) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:2128) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:2127) chicken.irregex#chunker-get-str" 
o|substituted constant variable: chicken.irregex#~searcher? 
o|inlining procedure: k19067 
o|inlining procedure: "(irregex-core.scm:2029) chicken.irregex#%irregex-match-fail-set!" 
o|contracted procedure: "(irregex-core.scm:2028) chicken.irregex#irregex-search/backtrack" 
o|inlining procedure: k19224 
o|inlining procedure: k19224 
o|inlining procedure: k19242 
o|inlining procedure: k19242 
o|inlining procedure: k19278 
o|inlining procedure: "(irregex-core.scm:2056) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:2055) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:2054) chicken.irregex#chunker-get-str" 
o|inlining procedure: k19278 
o|substituted constant variable: chicken.irregex#~searcher? 
o|inlining procedure: "(irregex-core.scm:2036) chicken.irregex#chunker-get-next" 
o|inlining procedure: "(irregex-core.scm:2035) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:2034) chicken.irregex#chunker-get-str" 
o|contracted procedure: "(irregex-core.scm:2033) chicken.irregex#irregex-nfa" 
o|contracted procedure: "(irregex-core.scm:1996) chicken.irregex#irregex-dfa" 
o|inlining procedure: k19351 
o|inlining procedure: k19351 
o|inlining procedure: k19365 
o|inlining procedure: k19365 
o|inlining procedure: k19378 
o|inlining procedure: k19378 
o|inlining procedure: k19415 
o|inlining procedure: k19427 
o|inlining procedure: "(irregex-core.scm:2086) chicken.irregex#chunker-get-start" 
o|inlining procedure: k19427 
o|contracted procedure: "(irregex-core.scm:2080) g33953396" 
o|inlining procedure: "(irregex-core.scm:2080) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:2079) chicken.irregex#chunker-get-start" 
o|inlining procedure: k19415 
o|inlining procedure: k19532 
o|inlining procedure: "(irregex-core.scm:2102) chicken.irregex#%irregex-match-fail-set!" 
o|inlining procedure: k19544 
o|inlining procedure: "(irregex-core.scm:2105) chicken.irregex#%irregex-match-fail" 
o|inlining procedure: k19544 
o|inlining procedure: "(irregex-core.scm:2104) chicken.irregex#%irregex-match-fail" 
o|contracted procedure: "(irregex-core.scm:2100) g34353436" 
o|inlining procedure: "(irregex-core.scm:2099) chicken.irregex#chunker-get-end" 
o|contracted procedure: "(irregex-core.scm:2098) g34293430" 
o|inlining procedure: "(irregex-core.scm:2097) chicken.irregex#chunker-get-next" 
o|inlining procedure: k19532 
o|inlining procedure: "(irregex-core.scm:2092) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:2091) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:2090) chicken.irregex#chunker-get-str" 
o|inlining procedure: "(irregex-core.scm:2074) chicken.irregex#irregex-match-chunker-set!" 
o|inlining procedure: k19634 
o|inlining procedure: k19634 
o|removed unused formal parameters: (dfa3453) 
o|removed unused formal parameters: (dfa3456) 
o|substituted constant variable: a19855 
o|substituted constant variable: a19852 
o|inlining procedure: k19857 
o|inlining procedure: k19857 
o|substituted constant variable: a19871 
o|substituted constant variable: a19868 
o|inlining procedure: k19873 
o|inlining procedure: k19873 
o|inlining procedure: k19890 
o|inlining procedure: k19890 
o|inlining procedure: k20014 
o|inlining procedure: k20036 
o|inlining procedure: k20062 
o|inlining procedure: k20062 
o|contracted procedure: "(irregex-core.scm:2222) g36363637" 
o|inlining procedure: k20036 
o|inlining procedure: k20014 
o|inlining procedure: k20135 
o|substituted constant variable: a20143 
o|substituted constant variable: a20146 
o|inlining procedure: k20135 
o|substituted constant variable: a20152 
o|inlining procedure: k20240 
o|contracted procedure: "(irregex-core.scm:2252) g36793697" 
o|inlining procedure: k20240 
o|inlining procedure: k20263 
o|inlining procedure: k20263 
o|inlining procedure: k20297 
o|inlining procedure: k20297 
o|inlining procedure: "(irregex-core.scm:2238) chicken.irregex#dfa-cell-commands" 
o|inlining procedure: "(irregex-core.scm:2235) chicken.irregex#dfa-finalizer" 
o|inlining procedure: k20326 
o|inlining procedure: k20326 
o|inlining procedure: k20374 
o|inlining procedure: k20374 
o|contracted procedure: "(irregex-core.scm:2270) g37553756" 
o|inlining procedure: k20406 
o|inlining procedure: k20406 
o|inlining procedure: k20471 
o|inlining procedure: k20471 
o|inlining procedure: "(irregex-core.scm:2198) chicken.irregex#dfa-cell-commands" 
o|inlining procedure: "(irregex-core.scm:2189) chicken.irregex#dfa-finalizer" 
o|contracted procedure: "(irregex-core.scm:2186) chicken.irregex#make-initial-memory" 
o|substituted constant variable: a19917 
o|inlining procedure: k19927 
o|inlining procedure: k19927 
o|substituted constant variable: a19941 
o|inlining procedure: "(irregex-core.scm:2182) chicken.irregex#dfa-init-state" 
o|inlining procedure: "(irregex-core.scm:2181) chicken.irregex#chunker-get-next" 
o|inlining procedure: "(irregex-core.scm:2180) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:2179) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:2178) chicken.irregex#chunker-get-str" 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: k20596 
o|inlining procedure: k20596 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: k20633 
o|contracted procedure: "(irregex-core.scm:2430) chicken.irregex#nfa-set-epsilons!" 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: k20633 
o|contracted procedure: "(irregex-core.scm:2487) chicken.irregex#nfa-set-state-trans!" 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|substituted constant variable: a20814 
o|inlining procedure: k20818 
o|inlining procedure: k20818 
o|substituted constant variable: a20832 
o|substituted constant variable: a20838 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: k20854 
o|inlining procedure: k20854 
o|inlining procedure: k20874 
o|inlining procedure: k20874 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k20902 
o|inlining procedure: k20902 
o|inlining procedure: k20920 
o|inlining procedure: k20920 
o|inlining procedure: k20935 
o|substituted constant variable: a20955 
o|inlining procedure: k20959 
o|inlining procedure: k20959 
o|inlining procedure: k20935 
o|inlining procedure: k21005 
o|inlining procedure: k21025 
o|inlining procedure: k21025 
o|inlining procedure: k21005 
o|inlining procedure: k21050 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k21050 
o|inlining procedure: k21113 
o|substituted constant variable: a21152 
o|inlining procedure: k21146 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|propagated global variable: r2114732519 chicken.irregex#~case-insensitive? 
o|inlining procedure: k21146 
o|substituted constant variable: chicken.irregex#~utf8? 
o|propagated global variable: r2114732521 chicken.irregex#~utf8? 
o|substituted constant variable: a21157 
o|inlining procedure: k21113 
o|consed rest parameter at call site: "(irregex-core.scm:2554) chicken.irregex#sre->cset" 2 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k21187 
o|inlining procedure: k21199 
o|inlining procedure: k21199 
o|inlining procedure: k21187 
o|inlining procedure: k21288 
o|inlining procedure: k21288 
o|inlining procedure: k21310 
o|inlining procedure: k21331 
o|inlining procedure: k21331 
o|inlining procedure: k21310 
o|inlining procedure: k21382 
o|inlining procedure: k21382 
o|inlining procedure: k21442 
o|inlining procedure: k21472 
o|inlining procedure: k21472 
o|inlining procedure: k21442 
o|inlining procedure: k21528 
o|inlining procedure: k21528 
o|substituted constant variable: a21575 
o|substituted constant variable: a21577 
o|substituted constant variable: a21582 
o|substituted constant variable: a21584 
o|substituted constant variable: a21589 
o|substituted constant variable: a21591 
o|substituted constant variable: a21593 
o|substituted constant variable: a21595 
o|inlining procedure: k21599 
o|inlining procedure: k21599 
o|substituted constant variable: a21612 
o|substituted constant variable: a21614 
o|substituted constant variable: a21616 
o|substituted constant variable: a21618 
o|inlining procedure: k21622 
o|inlining procedure: k21622 
o|substituted constant variable: a21635 
o|substituted constant variable: a21637 
o|substituted constant variable: a21639 
o|substituted constant variable: a21641 
o|substituted constant variable: a21646 
o|substituted constant variable: a21648 
o|inlining procedure: k21673 
o|substituted constant variable: a21687 
o|inlining procedure: k21691 
o|inlining procedure: k21691 
o|substituted constant variable: a21705 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: k21673 
o|inlining procedure: k21730 
o|inlining procedure: k21730 
o|inlining procedure: k21755 
o|inlining procedure: k21755 
o|inlining procedure: k21804 
o|inlining procedure: k21804 
o|substituted constant variable: a21817 
o|substituted constant variable: a21819 
o|substituted constant variable: a21821 
o|substituted constant variable: a21823 
o|substituted constant variable: chicken.irregex#*nfa-presize* 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|substituted constant variable: chicken.irregex#*nfa-presize* 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|inlining procedure: "(irregex-core.scm:2745) chicken.irregex#nfa-num-tags" 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|inlining procedure: k21970 
o|inlining procedure: k21970 
o|inlining procedure: "(irregex-core.scm:2778) chicken.irregex#mst-hash-set!" 
o|inlining procedure: k22011 
o|inlining procedure: k22011 
o|inlining procedure: "(irregex-core.scm:2768) chicken.irregex#mst-mappings-summary" 
o|inlining procedure: "(irregex-core.scm:2766) chicken.irregex#mst-num-states-set!" 
o|inlining procedure: "(irregex-core.scm:2766) chicken.irregex#mst-num-states" 
o|inlining procedure: "(irregex-core.scm:2763) chicken.irregex#mst-hash" 
o|inlining procedure: k22310 
o|inlining procedure: k22310 
o|substituted constant variable: a22324 
o|inlining procedure: k22326 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|inlining procedure: k22326 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|merged explicitly consed rest parameter: o4198 
o|inlining procedure: k22415 
o|contracted procedure: "(irregex-core.scm:2896) chicken.irregex#dfa-renumber" 
o|inlining procedure: k22602 
o|inlining procedure: k22602 
o|substituted constant variable: a22622 
o|contracted procedure: "(irregex-core.scm:2948) chicken.irregex#maybe-cset->char" 
o|inlining procedure: k26297 
o|inlining procedure: k26297 
o|substituted constant variable: a26336 
o|inlining procedure: k22678 
o|inlining procedure: k22678 
o|inlining procedure: k22716 
o|inlining procedure: k22716 
o|inlining procedure: "(irregex-core.scm:2895) chicken.irregex#nfa-highest-map-index" 
o|inlining procedure: k22415 
o|inlining procedure: k22447 
o|inlining procedure: k22447 
o|inlining procedure: k22471 
o|inlining procedure: k22471 
o|contracted procedure: "(irregex-core.scm:2913) chicken.irregex#find-reorder-commands" 
o|inlining procedure: k23394 
o|inlining procedure: k23394 
o|contracted procedure: "(irregex-core.scm:3120) chicken.irregex#nfa-set-reorder-commands!" 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: "(irregex-core.scm:2437) chicken.irregex#mst-hash" 
o|contracted procedure: "(irregex-core.scm:3119) chicken.irregex#find-reorder-commands-internal" 
o|inlining procedure: k23250 
o|inlining procedure: k23250 
o|inlining procedure: k23277 
o|inlining procedure: k23277 
o|inlining procedure: k23304 
o|inlining procedure: k23304 
o|inlining procedure: k23355 
o|inlining procedure: k23355 
o|inlining procedure: "(irregex-core.scm:3098) chicken.irregex#mst-mappings-summary" 
o|contracted procedure: "(irregex-core.scm:3096) chicken.irregex#mst-same-states?" 
o|inlining procedure: k22227 
o|inlining procedure: k22251 
o|inlining procedure: k22251 
o|substituted constant variable: a22265 
o|substituted constant variable: chicken.irregex#*mst-first-state-index* 
o|inlining procedure: "(irregex-core.scm:2816) chicken.irregex#mst-num-states" 
o|inlining procedure: "(irregex-core.scm:2816) chicken.irregex#mst-num-states" 
o|inlining procedure: k22227 
o|inlining procedure: "(irregex-core.scm:2815) chicken.irregex#mst-hash" 
o|inlining procedure: "(irregex-core.scm:2815) chicken.irregex#mst-hash" 
o|inlining procedure: "(irregex-core.scm:3092) chicken.irregex#mst-mappings-summary" 
o|inlining procedure: "(irregex-core.scm:3091) chicken.irregex#nfa-num-tags" 
o|contracted procedure: "(irregex-core.scm:3118) chicken.irregex#nfa-get-reorder-commands" 
o|inlining procedure: k20660 
o|inlining procedure: k20660 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: "(irregex-core.scm:2433) chicken.irregex#mst-hash" 
o|contracted procedure: "(irregex-core.scm:2903) chicken.irregex#get-distinct-transitions" 
o|inlining procedure: k22773 
o|inlining procedure: k22773 
o|inlining procedure: k22791 
o|inlining procedure: k22791 
o|inlining procedure: k22850 
o|inlining procedure: k22850 
o|inlining procedure: k22827 
o|inlining procedure: k22827 
o|contracted procedure: "(irregex-core.scm:2981) csets-intersect?4286" 
o|inlining procedure: k22754 
o|inlining procedure: k22754 
o|contracted procedure: "(irregex-core.scm:2964) chicken.irregex#nfa-get-state-trans" 
o|inlining procedure: k20570 
o|inlining procedure: k20570 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|contracted procedure: "(irregex-core.scm:2880) chicken.irregex#nfa-start-state" 
o|substituted constant variable: a20548 
o|inlining procedure: k23071 
o|inlining procedure: k23071 
o|contracted procedure: "(irregex-core.scm:3047) chicken.irregex#nfa-add-closure!" 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: "(irregex-core.scm:2445) chicken.irregex#mst-hash" 
o|contracted procedure: "(irregex-core.scm:3046) chicken.irregex#nfa-epsilon-closure-internal" 
o|inlining procedure: k22950 
o|inlining procedure: k22950 
o|inlining procedure: k22973 
o|inlining procedure: k22973 
o|contracted procedure: "(irregex-core.scm:3035) chicken.irregex#mst-add-tagged!" 
o|inlining procedure: "(irregex-core.scm:2810) chicken.irregex#mst-hash-set!" 
o|inlining procedure: "(irregex-core.scm:2805) chicken.irregex#mst-num-states-set!" 
o|inlining procedure: "(irregex-core.scm:2805) chicken.irregex#mst-num-states" 
o|inlining procedure: "(irregex-core.scm:2802) chicken.irregex#mst-hash" 
o|inlining procedure: k22177 
o|inlining procedure: k22177 
o|inlining procedure: "(irregex-core.scm:2794) chicken.irregex#mst-mappings-summary" 
o|contracted procedure: "(irregex-core.scm:3033) chicken.irregex#next-index-for-tag!" 
o|inlining procedure: k22347 
o|contracted procedure: "(irregex-core.scm:2842) chicken.irregex#nfa-set-highest-map-index!" 
o|inlining procedure: k22347 
o|inlining procedure: k22359 
o|inlining procedure: k22359 
o|inlining procedure: "(irregex-core.scm:2838) chicken.irregex#mst-mappings-summary" 
o|inlining procedure: "(irregex-core.scm:2837) chicken.irregex#nfa-highest-map-index" 
o|inlining procedure: k22997 
o|inlining procedure: k22997 
o|contracted procedure: "(irregex-core.scm:3040) chicken.irregex#mst-add/fast!" 
o|inlining procedure: "(irregex-core.scm:2787) chicken.irregex#mst-num-states-set!" 
o|inlining procedure: "(irregex-core.scm:2787) chicken.irregex#mst-num-states" 
o|inlining procedure: "(irregex-core.scm:2784) chicken.irregex#mst-hash-set!" 
o|inlining procedure: "(irregex-core.scm:2785) chicken.irregex#mst-hash" 
o|contracted procedure: "(irregex-core.scm:3045) chicken.irregex#nfa-get-closure" 
o|inlining procedure: k20717 
o|inlining procedure: k20717 
o|substituted constant variable: chicken.irregex#*nfa-num-fields* 
o|inlining procedure: "(irregex-core.scm:2441) chicken.irregex#mst-hash" 
o|inlining procedure: k23098 
o|inlining procedure: k23098 
o|inlining procedure: k23118 
o|inlining procedure: k23118 
o|inlining procedure: k23160 
o|inlining procedure: k23182 
o|inlining procedure: k23182 
o|inlining procedure: k23206 
o|inlining procedure: k23206 
o|inlining procedure: k23160 
o|inlining procedure: "(irregex-core.scm:3055) chicken.irregex#mst-mappings-summary" 
o|inlining procedure: "(irregex-core.scm:3054) chicken.irregex#mst-mappings-summary" 
o|inlining procedure: "(irregex-core.scm:3053) chicken.irregex#nfa-num-tags" 
o|inlining procedure: k26184 
o|substituted constant variable: a26201 
o|inlining procedure: k26184 
o|inlining procedure: k26236 
o|substituted constant variable: a26247 
o|inlining procedure: k26236 
o|inlining procedure: "(irregex-core.scm:3664) chicken.irregex#chunker-get-end" 
o|inlining procedure: "(irregex-core.scm:3663) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3662) chicken.irregex#chunker-get-str" 
o|inlining procedure: "(irregex-core.scm:3660) chicken.irregex#chunker-get-next" 
o|removed side-effect free assignment to unused variable: chicken.irregex#cset-size 
o|substituted constant variable: a26403 
o|inlining procedure: k26407 
o|inlining procedure: k26407 
o|inlining procedure: "(irregex-core.scm:3709) chicken.irregex#make-cset" 
o|merged explicitly consed rest parameter: o5232 
o|inlining procedure: k26522 
o|inlining procedure: k26534 
o|inlining procedure: k26534 
o|inlining procedure: k26552 
o|inlining procedure: k26585 
o|inlining procedure: k26585 
o|inlining procedure: k26552 
o|inlining procedure: k26649 
o|inlining procedure: k26649 
o|inlining procedure: k26684 
o|inlining procedure: k26719 
o|inlining procedure: k26719 
o|inlining procedure: k26684 
o|inlining procedure: k26763 
o|inlining procedure: k26763 
o|contracted procedure: "(irregex-core.scm:3732) chicken.irregex#plist->cset" 
o|inlining procedure: k26457 
o|inlining procedure: k26457 
o|inlining procedure: "(irregex-core.scm:3701) chicken.irregex#make-cset" 
o|contracted procedure: "(irregex-core.scm:3732) chicken.irregex#sre-flatten-ranges" 
o|inlining procedure: k18384 
o|inlining procedure: k18384 
o|inlining procedure: k26775 
o|inlining procedure: k26804 
o|inlining procedure: k26804 
o|inlining procedure: k26775 
o|inlining procedure: k26854 
o|inlining procedure: k26854 
o|substituted constant variable: a26873 
o|substituted constant variable: a26875 
o|substituted constant variable: a26877 
o|substituted constant variable: a26879 
o|substituted constant variable: a26881 
o|substituted constant variable: a26883 
o|substituted constant variable: a26885 
o|inlining procedure: k26522 
o|inlining procedure: k26894 
o|inlining procedure: k26894 
o|inlining procedure: k26907 
o|inlining procedure: k26907 
o|inlining procedure: k26976 
o|inlining procedure: k26976 
o|inlining procedure: k26991 
o|inlining procedure: k26991 
o|substituted constant variable: a27019 
o|inlining procedure: k27012 
o|inlining procedure: k27012 
o|inlining procedure: k27035 
o|inlining procedure: k27035 
o|substituted constant variable: a27051 
o|substituted constant variable: a27053 
o|inlining procedure: k27066 
o|inlining procedure: k27066 
o|inlining procedure: k27108 
o|inlining procedure: k27108 
o|substituted constant variable: a27164 
o|inlining procedure: k27156 
o|inlining procedure: k27156 
o|substituted constant variable: a27190 
o|inlining procedure: k27200 
o|inlining procedure: k27200 
o|inlining procedure: k27303 
o|inlining procedure: k27303 
o|inlining procedure: k27339 
o|inlining procedure: k27339 
o|inlining procedure: k27365 
o|inlining procedure: k27365 
o|inlining procedure: k27390 
o|inlining procedure: k27390 
o|contracted procedure: "(irregex-core.scm:3838) chicken.irregex#next-char" 
o|substituted constant variable: a27273 
o|contracted procedure: "(irregex-core.scm:3836) chicken.irregex#prev-char" 
o|substituted constant variable: a27285 
o|inlining procedure: k27499 
o|inlining procedure: k27499 
o|inlining procedure: k27532 
o|inlining procedure: k27532 
o|contracted procedure: "(irregex-core.scm:3865) chicken.irregex#min-char" 
o|inlining procedure: k27467 
o|inlining procedure: k27467 
o|contracted procedure: "(irregex-core.scm:3864) chicken.irregex#max-char" 
o|inlining procedure: k27476 
o|inlining procedure: k27476 
o|consed rest parameter at call site: "(irregex-core.scm:3873) chicken.irregex#sre->cset" 2 
o|inlining procedure: k27631 
o|inlining procedure: k27631 
o|inlining procedure: k27794 
o|inlining procedure: k27794 
o|inlining procedure: k27844 
o|inlining procedure: k27844 
o|substituted constant variable: chicken.irregex#~consumer? 
o|contracted procedure: "(irregex-core.scm:3923) g55135514" 
o|inlining procedure: "(irregex-core.scm:3910) chicken.irregex#irregex-match-chunker-set!" 
o|propagated global variable: str74632918 chicken.irregex#irregex-basic-string-chunker 
o|inlining procedure: k27889 
o|inlining procedure: k27889 
o|inlining procedure: k27903 
o|inlining procedure: k27903 
o|inlining procedure: k27922 
o|inlining procedure: k27922 
o|inlining procedure: k28028 
o|inlining procedure: k28028 
o|inlining procedure: k28072 
o|inlining procedure: "(irregex-core.scm:3962) chicken.irregex#chunker-get-start" 
o|inlining procedure: "(irregex-core.scm:3961) chicken.irregex#chunker-get-next" 
o|inlining procedure: "(irregex-core.scm:3960) chicken.irregex#chunker-get-end" 
o|inlining procedure: k28072 
o|substituted constant variable: chicken.irregex#~consumer? 
o|contracted procedure: "(irregex-core.scm:3957) g55655566" 
o|inlining procedure: "(irregex-core.scm:3950) chicken.irregex#irregex-match-chunker-set!" 
o|inlining procedure: "(irregex-core.scm:3947) chicken.irregex#chunker-get-start" 
o|inlining procedure: k28214 
o|contracted procedure: "(irregex-core.scm:3982) g55975598" 
o|inlining procedure: k28214 
o|inlining procedure: k28316 
o|inlining procedure: k28316 
o|contracted procedure: "(irregex-core.scm:3991) g56105611" 
o|inlining procedure: k28354 
o|inlining procedure: k28354 
o|inlining procedure: k28386 
o|inlining procedure: k28386 
o|inlining procedure: k28412 
o|inlining procedure: k28412 
o|inlining procedure: k28417 
o|inlining procedure: k28417 
o|inlining procedure: k28444 
o|contracted procedure: "(irregex-core.scm:4020) g56435644" 
o|contracted procedure: "(irregex-core.scm:4018) g56395640" 
o|inlining procedure: k28444 
o|contracted procedure: "(irregex-core.scm:4023) g56485649" 
o|inlining procedure: k28555 
o|inlining procedure: k28555 
o|substituted constant variable: a28590 
o|substituted constant variable: a28592 
o|inlining procedure: k28661 
o|inlining procedure: k28661 
o|contracted procedure: "(irregex-core.scm:4059) g56905691" 
o|contracted procedure: "(irregex-core.scm:4056) g56865687" 
o|inlining procedure: k28729 
o|inlining procedure: k28729 
o|inlining procedure: k28747 
o|inlining procedure: k28747 
o|inlining procedure: k28857 
o|inlining procedure: k28857 
o|substituted constant variable: a28874 
o|inlining procedure: k28901 
o|inlining procedure: k28901 
o|substituted constant variable: chicken.irregex#rx-special-chars 
o|inlining procedure: k29064 
o|inlining procedure: k29064 
o|inlining procedure: k29086 
o|inlining procedure: k29098 
o|contracted procedure: "(irregex-utils.scm:47) make-alt5939" 
o|inlining procedure: k28947 
o|inlining procedure: k28947 
o|inlining procedure: k29098 
o|substituted constant variable: a29128 
o|inlining procedure: k29130 
o|inlining procedure: k29130 
o|contracted procedure: "(irregex-utils.scm:55) make-seq5940" 
o|inlining procedure: k28977 
o|inlining procedure: k28977 
o|inlining procedure: k29014 
o|contracted procedure: "(irregex-utils.scm:36) g59635972" 
o|inlining procedure: k28999 
o|inlining procedure: k28999 
o|inlining procedure: k29014 
o|inlining procedure: k29054 
o|inlining procedure: k29054 
o|inlining procedure: k29086 
o|substituted constant variable: a29202 
o|inlining procedure: k29223 
o|inlining procedure: k29223 
o|inlining procedure: k29303 
o|inlining procedure: k29319 
o|inlining procedure: k29341 
o|inlining procedure: k29341 
o|inlining procedure: k29319 
o|inlining procedure: k29371 
o|inlining procedure: k29371 
o|inlining procedure: k29394 
o|inlining procedure: k29394 
o|inlining procedure: k29413 
o|inlining procedure: k29435 
o|inlining procedure: k29435 
o|inlining procedure: k29413 
o|inlining procedure: k29485 
o|inlining procedure: k29485 
o|inlining procedure: k29509 
o|inlining procedure: k29544 
o|inlining procedure: k29544 
o|inlining procedure: k29509 
o|inlining procedure: k29607 
o|inlining procedure: k29607 
o|inlining procedure: k29634 
o|substituted constant variable: a29647 
o|inlining procedure: k29634 
o|inlining procedure: k29662 
o|inlining procedure: k29662 
o|inlining procedure: k29729 
o|inlining procedure: k29761 
o|inlining procedure: k29761 
o|substituted constant variable: a29771 
o|consed rest parameter at call site: "(irregex-utils.scm:130) chicken.irregex#sre->cset" 2 
o|inlining procedure: k29785 
o|inlining procedure: k29785 
o|substituted constant variable: a29808 
o|inlining procedure: k29729 
o|inlining procedure: k29842 
o|inlining procedure: k29842 
o|inlining procedure: k29870 
o|inlining procedure: k29870 
o|substituted constant variable: a29898 
o|substituted constant variable: a29900 
o|inlining procedure: k29904 
o|inlining procedure: k29904 
o|substituted constant variable: a29917 
o|substituted constant variable: a29919 
o|substituted constant variable: a29921 
o|substituted constant variable: a29923 
o|substituted constant variable: a29925 
o|substituted constant variable: a29927 
o|inlining procedure: k29931 
o|inlining procedure: k29931 
o|inlining procedure: k29943 
o|inlining procedure: k29943 
o|substituted constant variable: a29950 
o|substituted constant variable: a29952 
o|substituted constant variable: a29954 
o|substituted constant variable: a29956 
o|substituted constant variable: a29958 
o|substituted constant variable: a29960 
o|substituted constant variable: a29962 
o|substituted constant variable: a29964 
o|substituted constant variable: a29969 
o|substituted constant variable: a29971 
o|inlining procedure: k29303 
o|inlining procedure: k29978 
o|inlining procedure: k29978 
o|inlining procedure: k30002 
o|inlining procedure: k30002 
o|substituted constant variable: a30021 
o|substituted constant variable: a30023 
o|substituted constant variable: a30028 
o|substituted constant variable: a30030 
o|substituted constant variable: a30035 
o|substituted constant variable: a30037 
o|inlining procedure: k30038 
o|inlining procedure: k30038 
o|inlining procedure: k30091 
o|inlining procedure: k30091 
o|inlining procedure: k30107 
o|inlining procedure: k30107 
o|substituted constant variable: a30180 
o|inlining procedure: k30176 
o|inlining procedure: k30176 
o|substituted constant variable: a30192 
o|inlining procedure: k30199 
o|inlining procedure: k30199 
o|substituted constant variable: a30240 
o|inlining procedure: k30241 
o|inlining procedure: k30241 
o|inlining procedure: k30316 
o|inlining procedure: k30316 
o|substituted constant variable: a30351 
o|inlining procedure: k31026 
o|inlining procedure: k31026 
o|simplifications: ((if . 8)) 
o|replaced variables: 7216 
o|removed binding forms: 699 
o|removed conditional forms: 3 
o|substituted constant variable: r766331045 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-match-chunker 
o|removed side-effect free assignment to unused variable: chicken.irregex#irregex-match-chunker-set! 
o|removed side-effect free assignment to unused variable: chicken.irregex#%irregex-match-fail 
o|removed side-effect free assignment to unused variable: chicken.irregex#%irregex-match-fail-set! 
o|substituted constant variable: r779031047 
o|substituted constant variable: r781531049 
o|substituted constant variable: r784431051 
o|substituted constant variable: r787331053 
o|substituted constant variable: r803031060 
o|substituted constant variable: r803831061 
o|substituted constant variable: r803831062 
o|substituted constant variable: r800831064 
o|substituted constant variable: r816831072 
o|substituted constant variable: r777431074 
o|substituted constant variable: r777431075 
o|substituted constant variable: r821631082 
o|inlining procedure: k8423 
o|substituted constant variable: r843631103 
o|inlining procedure: k8423 
o|substituted constant variable: r842431104 
o|substituted constant variable: r842431104 
o|folded constant expression: (scheme#not (quote #f)) 
o|removed side-effect free assignment to unused variable: chicken.irregex#chunker-get-next 
o|removed side-effect free assignment to unused variable: chicken.irregex#chunker-get-str 
o|removed side-effect free assignment to unused variable: chicken.irregex#chunker-get-start 
o|removed side-effect free assignment to unused variable: chicken.irregex#chunker-get-end 
o|removed side-effect free assignment to unused variable: chicken.irregex#chunker-get-substring 
o|removed side-effect free assignment to unused variable: chicken.irregex#chunker-get-subchunk 
o|substituted constant variable: r865231121 
o|substituted constant variable: r861631122 
o|substituted constant variable: r868531142 
o|removed side-effect free assignment to unused variable: chicken.irregex#*allow-utf8-mode?* 
o|substituted constant variable: r883931148 
o|substituted constant variable: r916731154 
o|substituted constant variable: r921031158 
o|substituted constant variable: r930331167 
o|removed side-effect free assignment to unused variable: chicken.irregex#~none 
o|removed side-effect free assignment to unused variable: chicken.irregex#dot-token 
o|converted assignments to bindings: (collect1353) 
o|substituted constant variable: r1015331200 
o|substituted constant variable: r1015331200 
o|inlining procedure: k10152 
o|inlining procedure: k10152 
o|removed side-effect free assignment to unused variable: chicken.irregex#~save? 
o|removed side-effect free assignment to unused variable: chicken.irregex#~multi-line? 
o|removed side-effect free assignment to unused variable: chicken.irregex#~ignore-space? 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|inlining procedure: k10365 
o|inlining procedure: k10365 
o|substituted constant variable: chicken.irregex#~single-line? 
o|propagated global variable: r1036633147 chicken.irregex#~single-line? 
o|propagated global variable: r1036633147 chicken.irregex#~single-line? 
o|inlining procedure: k10365 
o|substituted constant variable: r1036631235 
o|substituted constant variable: r1036631235 
o|inlining procedure: k10365 
o|substituted constant variable: r1040231237 
o|substituted constant variable: r1423331256 
o|converted assignments to bindings: (shift1522) 
o|substituted constant variable: r1087131269 
o|substituted constant variable: r1174631327 
o|substituted constant variable: r1174631327 
o|substituted constant variable: r1174631329 
o|substituted constant variable: r1174631329 
o|substituted constant variable: r1216131393 
o|substituted constant variable: c1080 
o|converted assignments to bindings: (collect1090) 
o|substituted constant variable: r1326931420 
o|substituted constant variable: r1328131422 
o|substituted constant variable: r893931432 
o|substituted constant variable: r888231450 
o|substituted constant variable: c1056 
o|folded constant expression: (scheme#eq? (quote #\}) (quote #\\)) 
o|substituted constant variable: c1056 
o|converted assignments to bindings: (byte1955) 
o|substituted constant variable: r1427131460 
o|substituted constant variable: r1428331462 
o|substituted constant variable: r1550631479 
o|substituted constant variable: r1550631479 
o|substituted constant variable: r1430931487 
o|substituted constant variable: r1432131489 
o|substituted constant variable: r1537231497 
o|substituted constant variable: r1537231497 
o|folded constant expression: (scheme#integer->char (quote 127)) 
o|substituted constant variable: r1537231499 
o|substituted constant variable: r1537231499 
o|folded constant expression: (scheme#integer->char (quote 255)) 
o|substituted constant variable: r1453531503 
o|substituted constant variable: r1453531503 
o|substituted constant variable: r2409431563 
o|substituted constant variable: r2410231565 
o|substituted constant variable: r2411731567 
o|substituted constant variable: r2425631578 
o|substituted constant variable: r2426431580 
o|substituted constant variable: r2427931582 
o|substituted constant variable: r874531611 
o|substituted constant variable: r878731625 
o|substituted constant variable: r2569631795 
o|substituted constant variable: r2583931828 
o|converted assignments to bindings: (rec4438) 
o|substituted constant variable: chicken.irregex#~consumer? 
o|substituted constant variable: chicken.irregex#~consumer? 
o|substituted constant variable: r1624231903 
o|substituted constant variable: r1624231903 
o|substituted constant variable: chicken.irregex#~searcher? 
o|substituted constant variable: chicken.irregex#~searcher? 
o|substituted constant variable: r1624931907 
o|substituted constant variable: r1624931907 
o|substituted constant variable: r1712031912 
o|substituted constant variable: r1712031912 
o|inlining procedure: k17201 
o|substituted constant variable: r1720231921 
o|substituted constant variable: r1720231921 
o|inlining procedure: k17236 
o|substituted constant variable: r1723731926 
o|substituted constant variable: r1723731926 
o|inlining procedure: k17279 
o|substituted constant variable: r1728031932 
o|substituted constant variable: r1728031932 
o|substituted constant variable: r1729031936 
o|substituted constant variable: r1729031936 
o|inlining procedure: k17318 
o|substituted constant variable: r1731931941 
o|substituted constant variable: r1731931941 
o|inlining procedure: k17406 
o|substituted constant variable: r1741331947 
o|substituted constant variable: r1740731948 
o|substituted constant variable: r1740731948 
o|inlining procedure: k17587 
o|substituted constant variable: r1758831967 
o|substituted constant variable: r1758831967 
o|inlining procedure: k17718 
o|substituted constant variable: r1771931977 
o|substituted constant variable: r1771931977 
o|substituted constant variable: r1777731980 
o|substituted constant variable: r1779231982 
o|inlining procedure: k17863 
o|substituted constant variable: r1786431987 
o|substituted constant variable: r1786431987 
o|substituted constant variable: r1790431990 
o|substituted constant variable: r1790431990 
o|converted assignments to bindings: (grow2855) 
o|substituted constant variable: r1627332027 
o|substituted constant variable: r1630832029 
o|substituted constant variable: r1630832030 
o|substituted constant variable: r1582132045 
o|substituted constant variable: r1597032055 
o|substituted constant variable: r1597032056 
o|substituted constant variable: r1603532062 
o|converted assignments to bindings: (rec2364) 
o|substituted constant variable: r1637232067 
o|substituted constant variable: r1651732083 
o|substituted constant variable: r1661432092 
o|substituted constant variable: r1660232093 
o|substituted constant variable: r1659032095 
o|substituted constant variable: r1665132098 
o|substituted constant variable: r1666632100 
o|substituted constant variable: r1676432111 
o|substituted constant variable: r1677932113 
o|substituted constant variable: r1688132123 
o|substituted constant variable: r1689632125 
o|substituted constant variable: r1695832133 
o|substituted constant variable: r1702032135 
o|substituted constant variable: r1702032135 
o|inlining procedure: k17019 
o|substituted constant variable: r1704632140 
o|substituted constant variable: r1820632144 
o|substituted constant variable: r1822932146 
o|substituted constant variable: r1897032194 
o|substituted constant variable: r1897032194 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r1898432198 
o|substituted constant variable: r1898432198 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r1899732201 
o|substituted constant variable: r1908032215 
o|substituted constant variable: r1916732220 
o|substituted constant variable: r1910532236 
o|substituted constant variable: r1970832238 
o|substituted constant variable: index3464 
o|substituted constant variable: index3464 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: index3464 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|inlining procedure: k19713 
o|inlining procedure: k19731 
o|inlining procedure: k19743 
o|substituted constant variable: r1975932241 
o|substituted constant variable: r1981032245 
o|substituted constant variable: r1969332252 
o|substituted constant variable: x75432281 
o|inlining procedure: k19197 
o|substituted constant variable: r1927932305 
o|substituted constant variable: r1935232323 
o|substituted constant variable: r1935232323 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r1936632327 
o|substituted constant variable: r1936632327 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r1937932330 
o|substituted constant variable: r1942832338 
o|substituted constant variable: n3398 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: x75432353 
o|substituted constant variable: r1954532363 
o|substituted constant variable: n3438 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: n3432 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: r1953332379 
o|substituted constant variable: r1963532401 
o|substituted constant variable: r1963532402 
o|removed side-effect free assignment to unused variable: chicken.irregex#dfa-init-state 
o|removed side-effect free assignment to unused variable: chicken.irregex#dfa-cell-commands 
o|removed side-effect free assignment to unused variable: chicken.irregex#dfa-finalizer 
o|substituted constant variable: r1985832405 
o|substituted constant variable: r1985832405 
o|substituted constant variable: r1987432409 
o|substituted constant variable: r1987432409 
o|substituted constant variable: r2006332415 
o|substituted constant variable: r2006332416 
o|inlining procedure: k20068 
o|substituted constant variable: r2003732417 
o|substituted constant variable: r2032732439 
o|inlining procedure: k20332 
o|removed side-effect free assignment to unused variable: chicken.irregex#*nfa-presize* 
o|removed side-effect free assignment to unused variable: chicken.irregex#*nfa-num-fields* 
o|removed side-effect free assignment to unused variable: chicken.irregex#nfa-num-tags 
o|removed side-effect free assignment to unused variable: chicken.irregex#nfa-highest-map-index 
o|substituted constant variable: r2059732488 
o|substituted constant variable: r2085532495 
o|substituted constant variable: r2092132501 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|substituted constant variable: chicken.irregex#~case-insensitive? 
o|substituted constant variable: chicken.irregex#~utf8? 
o|substituted constant variable: chicken.irregex#~utf8? 
o|inlining procedure: k21294 
o|substituted constant variable: r2128932531 
o|inlining procedure: k21394 
o|substituted constant variable: r2138332539 
o|substituted constant variable: r2167432555 
o|removed side-effect free assignment to unused variable: chicken.irregex#*mst-first-state-index* 
o|removed side-effect free assignment to unused variable: chicken.irregex#mst-mappings-summary 
o|removed side-effect free assignment to unused variable: chicken.irregex#mst-num-states 
o|removed side-effect free assignment to unused variable: chicken.irregex#mst-num-states-set! 
o|removed side-effect free assignment to unused variable: chicken.irregex#mst-hash 
o|removed side-effect free assignment to unused variable: chicken.irregex#mst-hash-set! 
o|substituted constant variable: r2325132630 
o|substituted constant variable: r2222832658 
o|substituted constant variable: r2066132680 
o|substituted constant variable: r2275532695 
o|substituted constant variable: r2057132696 
o|substituted constant variable: r2071832779 
o|substituted constant variable: r2318332791 
o|substituted constant variable: r2320732793 
o|substituted constant variable: r2316132794 
o|removed side-effect free assignment to unused variable: chicken.irregex#make-cset 
o|removed side-effect free assignment to unused variable: chicken.irregex#cset=? 
o|converted assignments to bindings: (rec5240) 
o|substituted constant variable: r2697732874 
o|substituted constant variable: r2699232877 
o|substituted constant variable: r2703632881 
o|substituted constant variable: n5516 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: r2789032924 
o|substituted constant variable: r2789032924 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r2790432928 
o|substituted constant variable: r2790432928 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r2792332931 
o|substituted constant variable: n5568 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: n5600 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: n5613 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: r2841332974 
o|substituted constant variable: r2841332974 
o|substituted constant variable: n5646 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: n5642 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: n5651 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: n5693 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|substituted constant variable: n5689 
o|folded constant expression: (scheme#* (quote 0) (quote 4)) 
o|removed side-effect free assignment to unused variable: chicken.irregex#rx-special-chars 
o|substituted constant variable: r2885832990 
o|substituted constant variable: r2906532994 
o|substituted constant variable: r2939533024 
o|substituted constant variable: r2963533038 
o|substituted constant variable: r2978633047 
o|substituted constant variable: r3009233066 
o|substituted constant variable: r3031733077 
o|simplifications: ((let . 8)) 
o|replaced variables: 1046 
o|removed binding forms: 6520 
o|removed conditional forms: 1 
o|inlining procedure: k8051 
o|inlining procedure: k8051 
o|inlining procedure: k8410 
o|substituted constant variable: r842433092 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r842433094 
o|folded constant expression: (scheme#not (quote #f)) 
o|removed side-effect free assignment to unused variable: chicken.irregex#~searcher? 
o|removed side-effect free assignment to unused variable: chicken.irregex#~consumer? 
o|substituted constant variable: r1015333139 
o|removed side-effect free assignment to unused variable: chicken.irregex#~case-insensitive? 
o|removed side-effect free assignment to unused variable: chicken.irregex#~utf8? 
o|inlining procedure: "(irregex-core.scm:740) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:740) chicken.irregex#flag-join" 
o|substituted constant variable: r1036633145 
o|substituted constant variable: chicken.irregex#~single-line? 
o|inlining procedure: "(irregex-core.scm:740) chicken.irregex#flag-join" 
o|substituted constant variable: chicken.irregex#~single-line? 
o|propagated global variable: b128733608 chicken.irregex#~single-line? 
o|propagated global variable: b128733608 chicken.irregex#~single-line? 
o|inlining procedure: "(irregex-core.scm:740) chicken.irregex#flag-join" 
o|substituted constant variable: r1036633149 
o|inlining procedure: "(irregex-core.scm:740) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:740) chicken.irregex#flag-join" 
o|substituted constant variable: r1036633151 
o|inlining procedure: "(irregex-core.scm:762) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:767) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:776) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:820) chicken.irregex#flag-set?" 
o|inlining procedure: k10948 
o|inlining procedure: k10948 
o|inlining procedure: "(irregex-core.scm:855) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:897) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:914) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:916) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:919) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:928) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:931) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:938) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:944) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:959) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:964) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:967) chicken.irregex#flag-clear" 
o|inlining procedure: chicken.irregex#flag-clear 
o|inlining procedure: chicken.irregex#flag-join 
o|inlining procedure: "(irregex-core.scm:978) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:977) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1236) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1237) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1235) chicken.irregex#cset-empty?" 
o|inlining procedure: "(irregex-core.scm:1247) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1256) chicken.irregex#range->cset" 
o|inlining procedure: "(irregex-core.scm:1264) chicken.irregex#utf8-start-char->length" 
o|inlining procedure: "(irregex-core.scm:1284) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1295) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1300) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1306) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1303) chicken.irregex#utf8-start-char->length" 
o|inlining procedure: "(irregex-core.scm:1307) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1312) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:1311) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1228) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1109) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1152) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:457) a12940" 
o|inlining procedure: "(irregex-core.scm:1170) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1173) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1176) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1180) chicken.irregex#flag-set?" 
o|contracted procedure: k8896 
o|removed call to pure procedure with unused result: "(irregex-core.scm:1452) ##sys#slot" 
o|removed call to pure procedure with unused result: "(irregex-core.scm:1507) ##sys#slot" 
o|inlining procedure: k15134 
o|inlining procedure: k15134 
o|inlining procedure: k15134 
o|inlining procedure: k15134 
o|removed call to pure procedure with unused result: "(irregex-core.scm:1518) ##sys#slot" 
o|inlining procedure: "(irregex-core.scm:1515) chicken.irregex#utf8-start-char->length" 
o|removed call to pure procedure with unused result: "(irregex-core.scm:1498) ##sys#slot" 
o|inlining procedure: k15367 
o|inlining procedure: k15367 
o|removed call to pure procedure with unused result: "(irregex-core.scm:1527) ##sys#slot" 
o|inlining procedure: "(irregex-core.scm:1538) chicken.irregex#high-char?" 
o|inlining procedure: "(irregex-core.scm:1538) chicken.irregex#high-char?" 
o|inlining procedure: "(irregex-core.scm:3150) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:3155) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:3174) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:3179) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:3182) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:3184) chicken.irregex#flag-clear" 
o|inlining procedure: "(irregex-core.scm:3413) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:3594) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1638) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:1638) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:1639) chicken.irregex#flag-join" 
o|inlining procedure: "(irregex-core.scm:1639) chicken.irregex#flag-join" 
o|substituted constant variable: r1720233241 
o|substituted constant variable: r1723733243 
o|substituted constant variable: r1728033247 
o|substituted constant variable: r1731933249 
o|substituted constant variable: r1740733253 
o|substituted constant variable: r1758833255 
o|substituted constant variable: r1771933257 
o|substituted constant variable: r1786433259 
o|inlining procedure: "(irregex-core.scm:1633) chicken.irregex#nfa-num-states" 
o|inlining procedure: "(irregex-core.scm:1629) chicken.irregex#nfa-num-states" 
o|inlining procedure: "(irregex-core.scm:1580) chicken.irregex#high-char?" 
o|inlining procedure: "(irregex-core.scm:1547) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:1546) chicken.irregex#flag-set?" 
o|substituted constant variable: r1702033279 
o|inlining procedure: k18962 
o|inlining procedure: k18976 
o|substituted constant variable: r1973233307 
o|folded constant expression: (scheme#+ (quote 3) (quote 0)) 
o|substituted constant variable: r1974433309 
o|folded constant expression: (scheme#+ (quote 2) (quote 0)) 
o|inlining procedure: "(irregex-core.scm:2153) chicken.irregex#dfa-next-state" 
o|inlining procedure: "(irregex-core.scm:2132) chicken.irregex#dfa-next-state" 
o|inlining procedure: "(irregex-core.scm:1998) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:2037) chicken.irregex#flag-set?" 
o|inlining procedure: k19344 
o|inlining procedure: k19358 
o|contracted procedure: k19480 
o|contracted procedure: k19592 
o|contracted procedure: k19620 
o|substituted constant variable: r200633241533338 
o|substituted constant variable: r200633241633339 
o|inlining procedure: k20317 
o|inlining procedure: "(irregex-core.scm:2234) chicken.irregex#dfa-next-state" 
o|substituted constant variable: r203273243933349 
o|inlining procedure: "(irregex-core.scm:2188) chicken.irregex#dfa-next-state" 
o|inlining procedure: "(irregex-core.scm:2495) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:2495) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:2496) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:2494) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:2533) chicken.irregex#flag-set?" 
o|inlining procedure: "(irregex-core.scm:2555) chicken.irregex#flag-set?" 
o|inlining procedure: k21334 
o|inlining procedure: "(irregex-core.scm:2744) chicken.irregex#nfa-num-states" 
o|inlining procedure: "(irregex-core.scm:2778) chicken.irregex#nfa-num-states" 
o|inlining procedure: "(irregex-core.scm:2764) chicken.irregex#mst-state-mappings" 
o|inlining procedure: "(irregex-core.scm:2907) chicken.irregex#mst-state-mappings" 
o|inlining procedure: k23381 
o|inlining procedure: k23381 
o|inlining procedure: "(irregex-core.scm:2997) chicken.irregex#cset-empty?" 
o|inlining procedure: "(irregex-core.scm:2987) chicken.irregex#cset-empty?" 
o|inlining procedure: "(irregex-core.scm:2960) chicken.irregex#cset-empty?" 
o|inlining procedure: k22580 
o|inlining procedure: "(irregex-core.scm:2409) chicken.irregex#nfa-num-states" 
o|inlining procedure: "(irregex-core.scm:2810) chicken.irregex#nfa-num-states" 
o|inlining procedure: "(irregex-core.scm:2803) chicken.irregex#mst-state-mappings" 
o|inlining procedure: "(irregex-core.scm:2786) chicken.irregex#nfa-num-states" 
o|inlining procedure: k22056 
o|inlining procedure: "(irregex-core.scm:2783) chicken.irregex#mst-state-mappings" 
o|inlining procedure: "(irregex-core.scm:3014) chicken.irregex#nfa-num-states" 
o|inlining procedure: "(irregex-core.scm:3708) chicken.irregex#cset-adjoin" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: "(irregex-core.scm:3704) chicken.irregex#range->cset" 
o|inlining procedure: "(irregex-core.scm:3745) chicken.irregex#range->cset" 
o|inlining procedure: "(irregex-core.scm:3746) chicken.irregex#range->cset" 
o|inlining procedure: "(irregex-core.scm:3809) chicken.irregex#char->cset" 
o|inlining procedure: k27582 
o|inlining procedure: k27582 
o|inlining procedure: "(irregex-core.scm:3886) chicken.irregex#range->cset" 
o|inlining procedure: "(irregex-core.scm:3928) chicken.irregex#flag-set?" 
o|contracted procedure: k27829 
o|inlining procedure: k27882 
o|inlining procedure: k27896 
o|inlining procedure: k27910 
o|inlining procedure: k27910 
o|inlining procedure: k27937 
o|inlining procedure: "(irregex-core.scm:3966) chicken.irregex#flag-set?" 
o|contracted procedure: k28063 
o|contracted procedure: k28259 
o|contracted procedure: k28310 
o|contracted procedure: k28482 
o|contracted procedure: k28499 
o|contracted procedure: k28546 
o|contracted procedure: k28689 
o|contracted procedure: k28710 
o|inlining procedure: k28809 
o|inlining procedure: k29104 
o|inlining procedure: k29149 
o|inlining procedure: k29035 
o|replaced variables: 4 
o|removed binding forms: 1107 
o|substituted constant variable: r805233561 
o|substituted constant variable: r805233564 
o|removed side-effect free assignment to unused variable: chicken.irregex#flag-set? 
o|substituted constant variable: b128733600 
o|substituted constant variable: b128733600 
o|substituted constant variable: b128733604 
o|substituted constant variable: b128733604 
o|substituted constant variable: chicken.irregex#~single-line? 
o|substituted constant variable: chicken.irregex#~single-line? 
o|substituted constant variable: b128733612 
o|substituted constant variable: b128733612 
o|substituted constant variable: b128733616 
o|substituted constant variable: b128733616 
o|substituted constant variable: b128733620 
o|substituted constant variable: b128733620 
o|inlining procedure: k10360 
o|substituted constant variable: i128333626 
o|substituted constant variable: i128333626 
o|substituted constant variable: i128333634 
o|substituted constant variable: i128333634 
o|substituted constant variable: i128333648 
o|substituted constant variable: i128333648 
o|substituted constant variable: i128333654 
o|substituted constant variable: i128333654 
o|substituted constant variable: r1094933660 
o|substituted constant variable: r1094933664 
o|substituted constant variable: i128333670 
o|substituted constant variable: i128333670 
o|substituted constant variable: b128733676 
o|substituted constant variable: b128733676 
o|substituted constant variable: b129133680 
o|substituted constant variable: b129133686 
o|substituted constant variable: b129133692 
o|substituted constant variable: b129133698 
o|substituted constant variable: b129133704 
o|substituted constant variable: b129133710 
o|substituted constant variable: b129133716 
o|substituted constant variable: b129133722 
o|substituted constant variable: b129133728 
o|substituted constant variable: b129133734 
o|substituted constant variable: i128333750 
o|substituted constant variable: i128333750 
o|substituted constant variable: i128333756 
o|substituted constant variable: i128333756 
o|substituted constant variable: ch541533764 
o|substituted constant variable: ch541533764 
o|substituted constant variable: ch541533764 
o|substituted constant variable: i128333775 
o|substituted constant variable: i128333775 
o|substituted constant variable: ch541533808 
o|substituted constant variable: ch541533808 
o|substituted constant variable: ch541533808 
o|substituted constant variable: ch520033867 
o|substituted constant variable: ch520033867 
o|substituted constant variable: i128333873 
o|substituted constant variable: i128333873 
o|substituted constant variable: i128333881 
o|substituted constant variable: i128333881 
o|substituted constant variable: i128333889 
o|substituted constant variable: i128333889 
o|substituted constant variable: i128333897 
o|substituted constant variable: i128333897 
o|substituted constant variable: i128333910 
o|substituted constant variable: i128333910 
o|substituted constant variable: i128333916 
o|substituted constant variable: i128333916 
o|substituted constant variable: i128333922 
o|substituted constant variable: i128333922 
o|substituted constant variable: i128333928 
o|substituted constant variable: i128333928 
o|substituted constant variable: r8897 
o|removed side-effect free assignment to unused variable: chicken.irregex#utf8-start-char->length 
o|contracted procedure: k14713 
o|contracted procedure: k15115 
o|substituted constant variable: r1513533946 
o|folded constant expression: (scheme#integer->char (quote 127)) 
o|substituted constant variable: r1513533947 
o|folded constant expression: (scheme#integer->char (quote 223)) 
o|substituted constant variable: r1513533948 
o|folded constant expression: (scheme#integer->char (quote 239)) 
o|substituted constant variable: r1513533949 
o|folded constant expression: (scheme#integer->char (quote 247)) 
o|contracted procedure: k15218 
o|contracted procedure: k15356 
o|substituted constant variable: r1536833961 
o|substituted constant variable: r1536833962 
o|contracted procedure: k15447 
o|contracted procedure: k16218 
o|substituted constant variable: i128333981 
o|substituted constant variable: i128333981 
o|substituted constant variable: i128333987 
o|substituted constant variable: i128333987 
o|substituted constant variable: b129133993 
o|substituted constant variable: b128733999 
o|substituted constant variable: b128733999 
o|substituted constant variable: b128734003 
o|substituted constant variable: b128734003 
o|substituted constant variable: b129134007 
o|substituted constant variable: i128334015 
o|substituted constant variable: i128334015 
o|substituted constant variable: i128334025 
o|substituted constant variable: i128334025 
o|substituted constant variable: b128734033 
o|substituted constant variable: b128734033 
o|substituted constant variable: b128734037 
o|substituted constant variable: b128734037 
o|substituted constant variable: b128734041 
o|substituted constant variable: a128634040 
o|substituted constant variable: b128734041 
o|substituted constant variable: a128634040 
o|substituted constant variable: b128734045 
o|substituted constant variable: a128634044 
o|substituted constant variable: b128734045 
o|substituted constant variable: a128634044 
o|substituted constant variable: i128334082 
o|substituted constant variable: i128334082 
o|substituted constant variable: i128334088 
o|substituted constant variable: i128334088 
o|substituted constant variable: r1896334098 
o|substituted constant variable: r1897734099 
o|contracted procedure: k19727 
o|contracted procedure: k19739 
o|substituted constant variable: i128334122 
o|substituted constant variable: i128334122 
o|substituted constant variable: i128334130 
o|substituted constant variable: i128334130 
o|substituted constant variable: r1934534134 
o|substituted constant variable: r1935934135 
o|substituted constant variable: r19481 
o|folded constant expression: (scheme#+ (quote 2) (quote 0)) 
o|substituted constant variable: r19593 
o|folded constant expression: (scheme#+ (quote 2) (quote 0)) 
o|substituted constant variable: r19621 
o|folded constant expression: (scheme#+ (quote 2) (quote 0)) 
o|removed side-effect free assignment to unused variable: chicken.irregex#dfa-next-state 
o|substituted constant variable: r2031834146 
o|removed side-effect free assignment to unused variable: chicken.irregex#nfa-num-states 
o|substituted constant variable: i128334186 
o|substituted constant variable: i128334186 
o|substituted constant variable: i128334194 
o|substituted constant variable: i128334194 
o|substituted constant variable: i128334200 
o|substituted constant variable: i128334200 
o|removed side-effect free assignment to unused variable: chicken.irregex#mst-state-mappings 
o|substituted constant variable: state405134239 
o|folded constant expression: (scheme#+ (quote 0) (quote 3)) 
o|substituted constant variable: r2338234249 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r2338234250 
o|folded constant expression: (scheme#not (quote #f)) 
o|contracted procedure: k23005 
o|removed side-effect free assignment to unused variable: chicken.irregex#range->cset 
o|removed side-effect free assignment to unused variable: chicken.irregex#char->cset 
o|removed side-effect free assignment to unused variable: chicken.irregex#cset-empty? 
o|removed side-effect free assignment to unused variable: chicken.irregex#cset-adjoin 
o|substituted constant variable: i128334394 
o|substituted constant variable: i128334394 
o|substituted constant variable: r27830 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|substituted constant variable: r2788334400 
o|substituted constant variable: r2789734401 
o|substituted constant variable: r2791134402 
o|substituted constant variable: r2791134403 
o|substituted constant variable: r2793834404 
o|substituted constant variable: i128334407 
o|substituted constant variable: i128334407 
o|substituted constant variable: r28064 
o|folded constant expression: (scheme#+ (quote 2) (quote 0)) 
o|substituted constant variable: r28260 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|substituted constant variable: r28311 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|substituted constant variable: r28483 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|substituted constant variable: r28500 
o|substituted constant variable: r28547 
o|substituted constant variable: r28690 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|substituted constant variable: r28711 
o|folded constant expression: (scheme#+ (quote 1) (quote 0)) 
o|substituted constant variable: r2881034417 
o|replaced variables: 273 
o|removed binding forms: 66 
o|removed conditional forms: 27 
o|removed side-effect free assignment to unused variable: chicken.irregex#~single-line? 
o|inlining procedure: k15130 
o|inlining procedure: k15130 
o|inlining procedure: k15130 
o|inlining procedure: k15130 
o|inlining procedure: k16261 
o|inlining procedure: k16291 
o|substituted constant variable: r19728 
o|substituted constant variable: r19740 
o|contracted procedure: k19476 
o|contracted procedure: k19588 
o|contracted procedure: k19616 
o|inlining procedure: k21916 
o|inlining procedure: k22005 
o|contracted procedure: k2187834242 
o|inlining procedure: k20545 
o|inlining procedure: k22131 
o|inlining procedure: k22088 
o|inlining procedure: k23052 
o|contracted procedure: k27825 
o|contracted procedure: k28059 
o|contracted procedure: k28255 
o|contracted procedure: k28306 
o|contracted procedure: k28478 
o|contracted procedure: k28685 
o|contracted procedure: k28706 
o|replaced variables: 4 
o|removed binding forms: 358 
o|substituted constant variable: r1513134762 
o|substituted constant variable: r1513134763 
o|substituted constant variable: r1513134764 
o|substituted constant variable: r1513134765 
o|substituted constant variable: r19477 
o|substituted constant variable: r19589 
o|substituted constant variable: r19617 
o|substituted constant variable: r2187934240 
o|substituted constant variable: r27826 
o|substituted constant variable: r28060 
o|substituted constant variable: r28256 
o|substituted constant variable: r28307 
o|substituted constant variable: r28479 
o|substituted constant variable: r28686 
o|substituted constant variable: r28707 
o|removed binding forms: 14 
o|removed binding forms: 15 
o|simplifications: ((let . 236) (if . 174) (##core#call . 2983)) 
o|  call simplifications:
o|    ##sys#check-string
o|    chicken.fixnum#fx>	2
o|    scheme#write-char
o|    scheme#list->string	2
o|    scheme#char>?	5
o|    scheme#char<=?	2
o|    scheme#char>=?	3
o|    scheme#quotient
o|    scheme#assoc	4
o|    scheme#modulo	3
o|    scheme#memv	4
o|    scheme#char?	11
o|    scheme#char=?	7
o|    scheme#cdddr	9
o|    scheme#cadddr	2
o|    scheme#symbol?	7
o|    scheme#caddr	14
o|    scheme#vector-set!	63
o|    chicken.fixnum#fx+	2
o|    chicken.fixnum#fxmod
o|    ##sys#setislot
o|    scheme#length	6
o|    ##sys#check-list	32
o|    chicken.fixnum#fxshr	6
o|    chicken.fixnum#fxshl	6
o|    chicken.fixnum#fx<=	8
o|    scheme#integer->char	27
o|    scheme#char-upper-case?
o|    scheme#char-upcase
o|    scheme#char-downcase
o|    scheme#equal?	9
o|    scheme#assv	4
o|    scheme#char<?	7
o|    scheme#string	10
o|    ##sys#cons	117
o|    scheme#cddr	31
o|    scheme#cadr	64
o|    scheme#>	11
o|    scheme#char->integer	19
o|    chicken.fixnum#fx<
o|    chicken.fixnum#fx>=
o|    scheme#string->list	7
o|    ##sys#setslot	34
o|    ##sys#list	179
o|    scheme#string?	24
o|    scheme#char-whitespace?	2
o|    chicken.fixnum#fxnot	14
o|    chicken.fixnum#fxand	58
o|    chicken.fixnum#fxior	21
o|    scheme#car	78
o|    scheme#<=	5
o|    scheme#char-alphabetic?	7
o|    scheme#char-numeric?	5
o|    scheme#=	66
o|    scheme#-	20
o|    scheme#string-ref	68
o|    scheme#string-length	25
o|    scheme#list	49
o|    scheme#cons	223
o|    scheme#procedure?	10
o|    scheme#vector	26
o|    scheme#vector-ref	170
o|    scheme#assq	13
o|    scheme#not	101
o|    scheme#cdr	60
o|    scheme#pair?	124
o|    scheme#number?	13
o|    scheme#null?	65
o|    scheme#caar	26
o|    scheme#eq?	434
o|    scheme#cdar	15
o|    scheme#exact?	8
o|    scheme#>=	27
o|    scheme#<	21
o|    scheme#apply	16
o|    scheme#*	52
o|    scheme#+	148
o|    ##sys#size	8
o|    chicken.fixnum#fx/
o|    ##sys#make-structure	4
o|    ##sys#check-structure	6
o|    ##sys#slot	220
o|    ##sys#structure?	3
o|    scheme#vector-length	20
o|contracted procedure: k7555 
o|contracted procedure: k7603 
o|contracted procedure: k7621 
o|contracted procedure: k7638 
o|contracted procedure: k7653 
o|contracted procedure: k7665 
o|contracted procedure: k7676 
o|contracted procedure: k7680 
o|contracted procedure: k7684 
o|contracted procedure: k7688 
o|contracted procedure: k7700 
o|contracted procedure: k7713 
o|contracted procedure: k7709 
o|contracted procedure: k7704 
o|contracted procedure: k7725 
o|contracted procedure: k7744 
o|contracted procedure: k7752 
o|contracted procedure: k7748 
o|contracted procedure: k7798 
o|contracted procedure: k7802 
o|contracted procedure: k7823 
o|contracted procedure: k7831 
o|contracted procedure: k7827 
o|contracted procedure: k7852 
o|contracted procedure: k7860 
o|contracted procedure: k7856 
o|contracted procedure: k7965 
o|contracted procedure: k8136 
o|contracted procedure: k7974 
o|contracted procedure: k8132 
o|contracted procedure: k7980 
o|contracted procedure: k7990 
o|contracted procedure: k7996 
o|contracted procedure: k8034 
o|contracted procedure: k8048 
o|contracted procedure: k8044 
o|contracted procedure: k8040 
o|contracted procedure: k8004 
o|contracted procedure: k8010 
o|substituted constant variable: g35701 
o|contracted procedure: k8017 
o|contracted procedure: k8022 
o|contracted procedure: k8077 
o|contracted procedure: k8128 
o|contracted procedure: k8089 
o|contracted procedure: k8101 
o|contracted procedure: k8105 
o|contracted procedure: k8108 
o|contracted procedure: k8190 
o|contracted procedure: k8156 
o|contracted procedure: k8164 
o|contracted procedure: k8170 
o|substituted constant variable: g35707 
o|contracted procedure: k8177 
o|contracted procedure: k8182 
o|contracted procedure: k7776 
o|contracted procedure: k8196 
o|contracted procedure: k8212 
o|contracted procedure: k8218 
o|contracted procedure: k8231 
o|contracted procedure: k8235 
o|contracted procedure: k8238 
o|contracted procedure: k8248 
o|contracted procedure: k8256 
o|contracted procedure: k8252 
o|contracted procedure: k8259 
o|contracted procedure: k8269 
o|contracted procedure: k8277 
o|contracted procedure: k8273 
o|contracted procedure: k8280 
o|contracted procedure: k8293 
o|contracted procedure: k8296 
o|contracted procedure: k8302 
o|contracted procedure: k8321 
o|contracted procedure: k8325 
o|contracted procedure: k8328 
o|contracted procedure: k8338 
o|contracted procedure: k8346 
o|contracted procedure: k8342 
o|contracted procedure: k8349 
o|contracted procedure: k8359 
o|contracted procedure: k8367 
o|contracted procedure: k8363 
o|contracted procedure: k8370 
o|contracted procedure: k8572 
o|contracted procedure: k8380 
o|contracted procedure: k8383 
o|contracted procedure: k8566 
o|contracted procedure: k8386 
o|contracted procedure: k8562 
o|contracted procedure: k8389 
o|contracted procedure: k8392 
o|contracted procedure: k8549 
o|contracted procedure: k8395 
o|contracted procedure: k8545 
o|contracted procedure: k8398 
o|contracted procedure: k8401 
o|contracted procedure: k8457 
o|contracted procedure: k8475 
o|contracted procedure: k8484 
o|contracted procedure: k8491 
o|contracted procedure: k8514 
o|contracted procedure: k8448 
o|contracted procedure: k8404 
o|contracted procedure: k8444 
o|contracted procedure: k8407 
o|contracted procedure: k8426 
o|contracted procedure: k8432 
o|contracted procedure: k8438 
o|contracted procedure: k8423 
o|contracted procedure: k8658 
o|contracted procedure: k8669 
o|contracted procedure: k8665 
o|contracted procedure: k8618 
o|contracted procedure: k8621 
o|contracted procedure: k8636 
o|contracted procedure: k8678 
o|contracted procedure: k8691 
o|contracted procedure: k8698 
o|contracted procedure: k8818 
o|contracted procedure: k8825 
o|contracted procedure: k8861 
o|contracted procedure: k8832 
o|contracted procedure: k8841 
o|contracted procedure: k8858 
o|contracted procedure: k8847 
o|contracted procedure: k9032 
o|contracted procedure: k9148 
o|contracted procedure: k9152 
o|contracted procedure: k9155 
o|contracted procedure: k9130 
o|contracted procedure: k9169 
o|substituted constant variable: g35721 
o|contracted procedure: k9176 
o|contracted procedure: k9193 
o|contracted procedure: k9197 
o|contracted procedure: k9212 
o|contracted procedure: k9228 
o|contracted procedure: k9296 
o|contracted procedure: k9267 
o|contracted procedure: k9292 
o|contracted procedure: k9282 
o|contracted procedure: k9305 
o|contracted procedure: k9321 
o|contracted procedure: k9337 
o|contracted procedure: k9345 
o|contracted procedure: k9355 
o|contracted procedure: k9366 
o|contracted procedure: k9382 
o|contracted procedure: k9399 
o|contracted procedure: k9406 
o|contracted procedure: k9733 
o|contracted procedure: k9740 
o|contracted procedure: k9748 
o|contracted procedure: k9757 
o|contracted procedure: k9763 
o|contracted procedure: k9769 
o|contracted procedure: k9790 
o|contracted procedure: k9803 
o|contracted procedure: k9809 
o|contracted procedure: k9858 
o|contracted procedure: k9830 
o|contracted procedure: k9848 
o|contracted procedure: k9854 
o|contracted procedure: k9865 
o|contracted procedure: k9871 
o|contracted procedure: k9883 
o|contracted procedure: k9898 
o|contracted procedure: k9908 
o|contracted procedure: k9915 
o|contracted procedure: k9923 
o|contracted procedure: k9929 
o|contracted procedure: k9932 
o|contracted procedure: k9959 
o|contracted procedure: k9954 
o|contracted procedure: k9944 
o|contracted procedure: k9951 
o|contracted procedure: k9965 
o|contracted procedure: k9971 
o|contracted procedure: k9974 
o|contracted procedure: k9987 
o|contracted procedure: k9994 
o|contracted procedure: k10002 
o|contracted procedure: k10014 
o|contracted procedure: k10035 
o|contracted procedure: k10048 
o|contracted procedure: k10054 
o|contracted procedure: k10060 
o|contracted procedure: k10080 
o|contracted procedure: k10109 
o|contracted procedure: k10112 
o|contracted procedure: k10118 
o|contracted procedure: k10136 
o|contracted procedure: k10155 
o|contracted procedure: k10161 
o|contracted procedure: k10169 
o|contracted procedure: k10186 
o|contracted procedure: k10189 
o|contracted procedure: k10204 
o|contracted procedure: k10196 
o|contracted procedure: k10230 
o|contracted procedure: k10251 
o|contracted procedure: k10277 
o|contracted procedure: k10280 
o|contracted procedure: k10283 
o|contracted procedure: k10322 
o|contracted procedure: k10457 
o|contracted procedure: k10349 
o|contracted procedure: k10356 
o|contracted procedure: k10368 
o|inlining procedure: k10360 
o|contracted procedure: k10377 
o|contracted procedure: k10380 
o|inlining procedure: k10360 
o|contracted procedure: k10386 
o|contracted procedure: k10389 
o|contracted procedure: k10395 
o|contracted procedure: k10398 
o|contracted procedure: k10404 
o|contracted procedure: k10407 
o|contracted procedure: k10441 
o|contracted procedure: k10466 
o|contracted procedure: k10478 
o|contracted procedure: k971433629 
o|contracted procedure: k10506 
o|substituted constant variable: g35754 
o|contracted procedure: k10496 
o|contracted procedure: k971433637 
o|contracted procedure: k10518 
o|substituted constant variable: g35758 
o|contracted procedure: k10525 
o|contracted procedure: k10540 
o|contracted procedure: k10543 
o|contracted procedure: k10546 
o|contracted procedure: k10554 
o|contracted procedure: k10562 
o|contracted procedure: k10574 
o|contracted procedure: k971433651 
o|contracted procedure: k10591 
o|substituted constant variable: g35772 
o|contracted procedure: k10600 
o|contracted procedure: k10609 
o|contracted procedure: k10619 
o|contracted procedure: k10638 
o|inlining procedure: k10631 
o|contracted procedure: k10651 
o|contracted procedure: k14235 
o|substituted constant variable: g35767 
o|contracted procedure: k14264 
o|contracted procedure: k14238 
o|contracted procedure: k14244 
o|contracted procedure: k14247 
o|substituted constant variable: g35771 
o|contracted procedure: k10694 
o|contracted procedure: k971433657 
o|contracted procedure: k10786 
o|substituted constant variable: g35774 
o|contracted procedure: k10700 
o|contracted procedure: k10783 
o|contracted procedure: k10709 
o|contracted procedure: k10772 
o|contracted procedure: k10715 
o|contracted procedure: k10722 
o|contracted procedure: k10729 
o|contracted procedure: k10736 
o|contracted procedure: k10762 
o|contracted procedure: k10779 
o|contracted procedure: k10823 
o|contracted procedure: k10799 
o|contracted procedure: k10817 
o|contracted procedure: k10830 
o|contracted procedure: k10838 
o|contracted procedure: k10849 
o|contracted procedure: k10863 
o|contracted procedure: k10877 
o|contracted procedure: k10881 
o|contracted procedure: k10885 
o|contracted procedure: k10900 
o|contracted procedure: k10910 
o|contracted procedure: k10916 
o|contracted procedure: k10925 
o|contracted procedure: k10931 
o|contracted procedure: k971433673 
o|contracted procedure: k10955 
o|substituted constant variable: g35778 
o|inlining procedure: k10944 
o|inlining procedure: k10944 
o|contracted procedure: k10961 
o|contracted procedure: k10970 
o|contracted procedure: k10976 
o|contracted procedure: k10989 
o|contracted procedure: k10998 
o|contracted procedure: k11005 
o|contracted procedure: k11016 
o|contracted procedure: k11027 
o|contracted procedure: k11023 
o|contracted procedure: k11035 
o|contracted procedure: k11046 
o|contracted procedure: k11057 
o|contracted procedure: k11068 
o|contracted procedure: k11064 
o|contracted procedure: k11076 
o|contracted procedure: k11087 
o|contracted procedure: k11091 
o|contracted procedure: k11083 
o|contracted procedure: k11118 
o|contracted procedure: k11121 
o|contracted procedure: k11176 
o|contracted procedure: k11127 
o|contracted procedure: k11165 
o|contracted procedure: k11169 
o|contracted procedure: k11161 
o|contracted procedure: k11173 
o|contracted procedure: k11183 
o|contracted procedure: k11949 
o|contracted procedure: k11199 
o|contracted procedure: k11212 
o|contracted procedure: k11940 
o|contracted procedure: k11232 
o|contracted procedure: k11298 
o|contracted procedure: k11238 
o|contracted procedure: k11253 
o|contracted procedure: k11266 
o|contracted procedure: k11270 
o|contracted procedure: k11274 
o|contracted procedure: k11290 
o|contracted procedure: k11285 
o|contracted procedure: k11304 
o|contracted procedure: k11310 
o|contracted procedure: k11320 
o|contracted procedure: k11324 
o|contracted procedure: k11337 
o|contracted procedure: k973333683 
o|contracted procedure: k11350 
o|contracted procedure: k11360 
o|contracted procedure: k973333689 
o|contracted procedure: k11373 
o|contracted procedure: k11383 
o|contracted procedure: k973333695 
o|contracted procedure: k11396 
o|contracted procedure: k11406 
o|contracted procedure: k11419 
o|contracted procedure: k11425 
o|contracted procedure: k973333701 
o|contracted procedure: k11438 
o|contracted procedure: k11448 
o|contracted procedure: k973333707 
o|contracted procedure: k11461 
o|contracted procedure: k11478 
o|contracted procedure: k11482 
o|contracted procedure: k973333713 
o|contracted procedure: k11486 
o|contracted procedure: k11490 
o|contracted procedure: k11521 
o|contracted procedure: k11511 
o|contracted procedure: k11537 
o|contracted procedure: k973333719 
o|contracted procedure: k11550 
o|contracted procedure: k11560 
o|contracted procedure: k11693 
o|contracted procedure: k11576 
o|contracted procedure: k11588 
o|contracted procedure: k973333725 
o|contracted procedure: k11604 
o|contracted procedure: k11608 
o|contracted procedure: k11686 
o|contracted procedure: k11628 
o|contracted procedure: k973333731 
o|contracted procedure: k11647 
o|contracted procedure: k11651 
o|contracted procedure: k973333737 
o|contracted procedure: k11678 
o|contracted procedure: k11702 
o|contracted procedure: k973333743 
o|contracted procedure: k971433759 
o|contracted procedure: k11729 
o|substituted constant variable: g35784 
o|contracted procedure: k971433753 
o|contracted procedure: k11732 
o|substituted constant variable: g35782 
o|contracted procedure: k11738 
o|contracted procedure: k11751 
o|contracted procedure: k11757 
o|contracted procedure: k11763 
o|contracted procedure: k11779 
o|contracted procedure: k11795 
o|contracted procedure: k11811 
o|contracted procedure: k11836 
o|contracted procedure: k11846 
o|contracted procedure: k11852 
o|contracted procedure: k11875 
o|contracted procedure: k11896 
o|contracted procedure: k11892 
o|contracted procedure: k11959 
o|contracted procedure: k11965 
o|contracted procedure: k11981 
o|contracted procedure: k11995 
o|contracted procedure: k11985 
o|contracted procedure: k12001 
o|contracted procedure: k12014 
o|contracted procedure: k12018 
o|contracted procedure: k12022 
o|contracted procedure: k13400 
o|contracted procedure: k971433884 
o|contracted procedure: k13406 
o|substituted constant variable: g35808 
o|contracted procedure: k13415 
o|contracted procedure: k13421 
o|contracted procedure: k13427 
o|contracted procedure: k2629133783 
o|contracted procedure: k13433 
o|contracted procedure: k2628133772 
o|contracted procedure: k2725933767 
o|contracted procedure: k971433778 
o|contracted procedure: k13446 
o|substituted constant variable: g35790 
o|contracted procedure: k13456 
o|contracted procedure: k26957 
o|contracted procedure: k26961 
o|contracted procedure: k13472 
o|contracted procedure: k13478 
o|contracted procedure: k2628133794 
o|contracted procedure: k2725933789 
o|contracted procedure: k13497 
o|contracted procedure: k13503 
o|contracted procedure: k13515 
o|contracted procedure: k2627133800 
o|contracted procedure: k13529 
o|contracted procedure: k13619 
o|contracted procedure: k13533 
o|contracted procedure: k13545 
o|contracted procedure: k13549 
o|contracted procedure: k1403133805 
o|contracted procedure: k13573 
o|contracted procedure: k13584 
o|inlining procedure: k13536 
o|inlining procedure: k13536 
o|contracted procedure: k13600 
o|substituted constant variable: g35792 
o|substituted constant variable: g35794 
o|contracted procedure: k13603 
o|contracted procedure: k13610 
o|contracted procedure: k13641 
o|contracted procedure: k13659 
o|contracted procedure: k13647 
o|contracted procedure: k13655 
o|contracted procedure: k13665 
o|contracted procedure: k13784 
o|contracted procedure: k13668 
o|contracted procedure: k13671 
o|contracted procedure: k13674 
o|contracted procedure: k13680 
o|contracted procedure: k13689 
o|contracted procedure: k13741 
o|contracted procedure: k13737 
o|contracted procedure: k13732 
o|contracted procedure: k13750 
o|contracted procedure: k13753 
o|contracted procedure: k2628133816 
o|contracted procedure: k2725933811 
o|contracted procedure: k13793 
o|contracted procedure: k13796 
o|contracted procedure: k13802 
o|contracted procedure: k13827 
o|contracted procedure: k13833 
o|contracted procedure: k2628133827 
o|contracted procedure: k2725933822 
o|contracted procedure: k13856 
o|contracted procedure: k13859 
o|contracted procedure: k2628133838 
o|contracted procedure: k2725933833 
o|contracted procedure: k13877 
o|contracted procedure: k13883 
o|contracted procedure: k13889 
o|contracted procedure: k13895 
o|contracted procedure: k1403133854 
o|contracted procedure: k13925 
o|contracted procedure: k13932 
o|contracted procedure: k2628133849 
o|contracted procedure: k2725933844 
o|contracted procedure: k2628133865 
o|contracted procedure: k2725933860 
o|contracted procedure: k13961 
o|substituted constant variable: g35799 
o|substituted constant variable: g35801 
o|contracted procedure: k13979 
o|contracted procedure: k971433876 
o|contracted procedure: k13986 
o|substituted constant variable: g35804 
o|contracted procedure: k2628133870 
o|inlining procedure: k13983 
o|inlining procedure: k13983 
o|contracted procedure: k13999 
o|contracted procedure: k14002 
o|contracted procedure: k14010 
o|contracted procedure: k12039 
o|contracted procedure: k12064 
o|contracted procedure: k12070 
o|contracted procedure: k12089 
o|contracted procedure: k12101 
o|contracted procedure: k12118 
o|contracted procedure: k12114 
o|contracted procedure: k12138 
o|contracted procedure: k12134 
o|contracted procedure: k12155 
o|contracted procedure: k12151 
o|contracted procedure: k12163 
o|contracted procedure: k12180 
o|contracted procedure: k12176 
o|contracted procedure: k12169 
o|contracted procedure: k12185 
o|contracted procedure: k12192 
o|contracted procedure: k12198 
o|contracted procedure: k8967 
o|contracted procedure: k8989 
o|contracted procedure: k9026 
o|contracted procedure: k9002 
o|contracted procedure: k12233 
o|contracted procedure: k12215 
o|contracted procedure: k12226 
o|contracted procedure: k12218 
o|contracted procedure: k12242 
o|contracted procedure: k12255 
o|contracted procedure: k12261 
o|contracted procedure: k12274 
o|contracted procedure: k12284 
o|contracted procedure: k12301 
o|contracted procedure: k12297 
o|contracted procedure: k12311 
o|contracted procedure: k12324 
o|contracted procedure: k12334 
o|contracted procedure: k12351 
o|contracted procedure: k12347 
o|contracted procedure: k12361 
o|contracted procedure: k12386 
o|contracted procedure: k12378 
o|contracted procedure: k12374 
o|contracted procedure: k12392 
o|contracted procedure: k12421 
o|contracted procedure: k12417 
o|contracted procedure: k12409 
o|contracted procedure: k12405 
o|contracted procedure: k12427 
o|contracted procedure: k12444 
o|contracted procedure: k12440 
o|contracted procedure: k12454 
o|contracted procedure: k12467 
o|contracted procedure: k12477 
o|contracted procedure: k12490 
o|contracted procedure: k12500 
o|contracted procedure: k12517 
o|contracted procedure: k12521 
o|contracted procedure: k12513 
o|contracted procedure: k12531 
o|contracted procedure: k12544 
o|contracted procedure: k12554 
o|contracted procedure: k12567 
o|contracted procedure: k12577 
o|contracted procedure: k12590 
o|contracted procedure: k12600 
o|contracted procedure: k12613 
o|contracted procedure: k12623 
o|contracted procedure: k12636 
o|contracted procedure: k12646 
o|contracted procedure: k12659 
o|contracted procedure: k12663 
o|contracted procedure: k12667 
o|contracted procedure: k12684 
o|contracted procedure: k12687 
o|contracted procedure: k12693 
o|contracted procedure: k971433892 
o|contracted procedure: k12747 
o|substituted constant variable: g35816 
o|contracted procedure: k12708 
o|contracted procedure: k12714 
o|contracted procedure: k12724 
o|contracted procedure: k12728 
o|contracted procedure: k12736 
o|contracted procedure: k12732 
o|contracted procedure: k13271 
o|contracted procedure: k13277 
o|contracted procedure: k13283 
o|contracted procedure: k13289 
o|contracted procedure: k12768 
o|contracted procedure: k12786 
o|contracted procedure: k12793 
o|contracted procedure: k12868 
o|contracted procedure: k12799 
o|contracted procedure: k12816 
o|contracted procedure: k12854 
o|contracted procedure: k12822 
o|contracted procedure: k12835 
o|contracted procedure: k12843 
o|contracted procedure: k12874 
o|contracted procedure: k12890 
o|contracted procedure: k12900 
o|contracted procedure: k12906 
o|contracted procedure: k971433900 
o|contracted procedure: k12937 
o|substituted constant variable: g35822 
o|contracted procedure: k12909 
o|contracted procedure: k12919 
o|contracted procedure: k12912 
o|contracted procedure: k8925 
o|contracted procedure: k8960 
o|contracted procedure: k8932 
o|contracted procedure: k8941 
o|contracted procedure: k8957 
o|contracted procedure: k1294733905 
o|contracted procedure: k8947 
o|contracted procedure: k12956 
o|contracted procedure: k12959 
o|contracted procedure: k12979 
o|contracted procedure: k12975 
o|contracted procedure: k13046 
o|contracted procedure: k13059 
o|contracted procedure: k13069 
o|contracted procedure: k971433913 
o|contracted procedure: k13092 
o|substituted constant variable: g35828 
o|contracted procedure: k13072 
o|contracted procedure: k13085 
o|contracted procedure: k13098 
o|contracted procedure: k971433919 
o|contracted procedure: k13121 
o|substituted constant variable: g35830 
o|contracted procedure: k13101 
o|contracted procedure: k13114 
o|contracted procedure: k13127 
o|contracted procedure: k971433925 
o|contracted procedure: k13133 
o|substituted constant variable: g35832 
o|contracted procedure: k13158 
o|contracted procedure: k971433931 
o|contracted procedure: k13164 
o|substituted constant variable: g35834 
o|contracted procedure: k13170 
o|contracted procedure: k13177 
o|contracted procedure: k13181 
o|contracted procedure: k13243 
o|contracted procedure: k13236 
o|contracted procedure: k30988 
o|contracted procedure: k30992 
o|contracted procedure: k30996 
o|contracted procedure: k31000 
o|contracted procedure: k31004 
o|contracted procedure: k31008 
o|contracted procedure: k13247 
o|contracted procedure: k13256 
o|contracted procedure: k13306 
o|contracted procedure: k13394 
o|contracted procedure: k13315 
o|contracted procedure: k13324 
o|contracted procedure: k13343 
o|contracted procedure: k8868 
o|contracted procedure: k8918 
o|contracted procedure: k8875 
o|contracted procedure: k8884 
o|contracted procedure: k8915 
o|contracted procedure: k8890 
o|contracted procedure: k13358 
o|contracted procedure: k13377 
o|contracted procedure: k14021 
o|contracted procedure: k14044 
o|contracted procedure: k14050 
o|contracted procedure: k14059 
o|contracted procedure: k14083 
o|contracted procedure: k14067 
o|contracted procedure: k14071 
o|contracted procedure: k14079 
o|contracted procedure: k14093 
o|contracted procedure: k14136 
o|contracted procedure: k14104 
o|contracted procedure: k14124 
o|contracted procedure: k14108 
o|contracted procedure: k14112 
o|contracted procedure: k14100 
o|contracted procedure: k14120 
o|contracted procedure: k14132 
o|contracted procedure: k14146 
o|contracted procedure: k14205 
o|contracted procedure: k14157 
o|contracted procedure: k14193 
o|contracted procedure: k14161 
o|contracted procedure: k14181 
o|contracted procedure: k14165 
o|contracted procedure: k14169 
o|contracted procedure: k14153 
o|contracted procedure: k14177 
o|contracted procedure: k14189 
o|contracted procedure: k14201 
o|contracted procedure: k14273 
o|contracted procedure: k14279 
o|contracted procedure: k14285 
o|contracted procedure: k14291 
o|contracted procedure: k14346 
o|contracted procedure: k14352 
o|contracted procedure: k14361 
o|contracted procedure: k14380 
o|contracted procedure: k14368 
o|contracted procedure: k14376 
o|contracted procedure: k14372 
o|contracted procedure: k14386 
o|contracted procedure: k14417 
o|contracted procedure: k14393 
o|contracted procedure: k14413 
o|contracted procedure: k14409 
o|contracted procedure: k14397 
o|contracted procedure: k14405 
o|contracted procedure: k14401 
o|contracted procedure: k14423 
o|contracted procedure: k14466 
o|contracted procedure: k14430 
o|contracted procedure: k14462 
o|contracted procedure: k14458 
o|contracted procedure: k14434 
o|contracted procedure: k14454 
o|contracted procedure: k14450 
o|contracted procedure: k14438 
o|contracted procedure: k14446 
o|contracted procedure: k14442 
o|contracted procedure: k14625 
o|contracted procedure: k14632 
o|contracted procedure: k14636 
o|contracted procedure: k14640 
o|contracted procedure: k14652 
o|contracted procedure: k14655 
o|contracted procedure: k14670 
o|contracted procedure: k14679 
o|contracted procedure: k14662 
o|contracted procedure: k14691 
o|contracted procedure: k14709 
o|contracted procedure: k14694 
o|contracted procedure: k14697 
o|contracted procedure: k14705 
o|contracted procedure: k14727 
o|contracted procedure: k14749 
o|contracted procedure: k14745 
o|contracted procedure: k14730 
o|contracted procedure: k14733 
o|contracted procedure: k14741 
o|contracted procedure: k14893 
o|contracted procedure: k14768 
o|contracted procedure: k14764 
o|contracted procedure: k14794 
o|contracted procedure: k14790 
o|contracted procedure: k14786 
o|contracted procedure: k14798 
o|contracted procedure: k14802 
o|contracted procedure: k14814 
o|contracted procedure: k14820 
o|contracted procedure: k14835 
o|contracted procedure: k14831 
o|contracted procedure: k14827 
o|contracted procedure: k14848 
o|contracted procedure: k14870 
o|contracted procedure: k14866 
o|contracted procedure: k14851 
o|contracted procedure: k14854 
o|contracted procedure: k14862 
o|contracted procedure: k14877 
o|contracted procedure: k15032 
o|contracted procedure: k14907 
o|contracted procedure: k14903 
o|contracted procedure: k14933 
o|contracted procedure: k14929 
o|contracted procedure: k14925 
o|contracted procedure: k14937 
o|contracted procedure: k14941 
o|contracted procedure: k14953 
o|contracted procedure: k14959 
o|contracted procedure: k14974 
o|contracted procedure: k14970 
o|contracted procedure: k14966 
o|contracted procedure: k14987 
o|contracted procedure: k15009 
o|contracted procedure: k15005 
o|contracted procedure: k14990 
o|contracted procedure: k14993 
o|contracted procedure: k15001 
o|contracted procedure: k15016 
o|contracted procedure: k15490 
o|contracted procedure: k15508 
o|contracted procedure: k15515 
o|contracted procedure: k15505 
o|contracted procedure: k15579 
o|contracted procedure: k1402133976 
o|contracted procedure: k15525 
o|contracted procedure: k15535 
o|contracted procedure: k15539 
o|contracted procedure: k14612 
o|contracted procedure: k14492 
o|contracted procedure: k14499 
o|contracted procedure: k15038 
o|contracted procedure: k15049 
o|contracted procedure: k15053 
o|contracted procedure: k15070 
o|contracted procedure: k15081 
o|contracted procedure: k15062 
o|contracted procedure: k15093 
o|contracted procedure: k15111 
o|contracted procedure: k15096 
o|contracted procedure: k15099 
o|contracted procedure: k15107 
o|contracted procedure: k15122 
o|contracted procedure: k15126 
o|contracted procedure: k15130 
o|contracted procedure: k15138 
o|contracted procedure: k14311 
o|contracted procedure: k14317 
o|contracted procedure: k14323 
o|contracted procedure: k14329 
o|contracted procedure: k15146 
o|contracted procedure: k15152 
o|contracted procedure: k15159 
o|contracted procedure: k15225 
o|contracted procedure: k15233 
o|contracted procedure: k15229 
o|contracted procedure: k15171 
o|contracted procedure: k15175 
o|contracted procedure: k15184 
o|contracted procedure: k15167 
o|contracted procedure: k15196 
o|contracted procedure: k15214 
o|contracted procedure: k15199 
o|contracted procedure: k15202 
o|contracted procedure: k15210 
o|contracted procedure: k15255 
o|contracted procedure: k15251 
o|contracted procedure: k15247 
o|contracted procedure: k1403133956 
o|contracted procedure: k15243 
o|contracted procedure: k15264 
o|contracted procedure: k15267 
o|contracted procedure: k15270 
o|contracted procedure: k15278 
o|contracted procedure: k15286 
o|contracted procedure: k15294 
o|contracted procedure: k15380 
o|contracted procedure: k15363 
o|contracted procedure: k15374 
o|substituted constant variable: g35865 
o|contracted procedure: k15309 
o|contracted procedure: k15313 
o|contracted procedure: k15322 
o|contracted procedure: k15305 
o|contracted procedure: k15334 
o|contracted procedure: k15352 
o|contracted procedure: k15337 
o|contracted procedure: k15340 
o|contracted procedure: k15348 
o|contracted procedure: k14604 
o|contracted procedure: k14608 
o|contracted procedure: k14519 
o|contracted procedure: k14530 
o|contracted procedure: k14537 
o|inlining procedure: k14526 
o|contracted procedure: k14534 
o|inlining procedure: k14526 
o|contracted procedure: k14596 
o|contracted procedure: k14558 
o|contracted procedure: k14565 
o|contracted procedure: k14580 
o|contracted procedure: k15471 
o|contracted procedure: k15467 
o|contracted procedure: k15386 
o|contracted procedure: k15463 
o|contracted procedure: k15459 
o|contracted procedure: k15389 
o|contracted procedure: k15400 
o|contracted procedure: k15404 
o|contracted procedure: k15413 
o|contracted procedure: k15396 
o|contracted procedure: k15425 
o|contracted procedure: k15443 
o|contracted procedure: k15428 
o|contracted procedure: k15431 
o|contracted procedure: k15439 
o|contracted procedure: k15555 
o|contracted procedure: k15566 
o|contracted procedure: k15559 
o|contracted procedure: k15575 
o|contracted procedure: k1402133971 
o|contracted procedure: k16059 
o|contracted procedure: k16160 
o|contracted procedure: k16065 
o|contracted procedure: k16156 
o|contracted procedure: k16074 
o|contracted procedure: k16152 
o|contracted procedure: k16083 
o|contracted procedure: k16148 
o|contracted procedure: k16092 
o|contracted procedure: k16144 
o|contracted procedure: k16101 
o|contracted procedure: k16110 
o|contracted procedure: k16113 
o|contracted procedure: k16131 
o|contracted procedure: k16116 
o|contracted procedure: k16127 
o|contracted procedure: k16123 
o|contracted procedure: k16119 
o|contracted procedure: k16134 
o|contracted procedure: k16166 
o|contracted procedure: k16200 
o|contracted procedure: k17098 
o|contracted procedure: k16237 
o|contracted procedure: k16221 
o|contracted procedure: k26158 
o|contracted procedure: k23414 
o|contracted procedure: k23450 
o|contracted procedure: k23454 
o|contracted procedure: k23420 
o|contracted procedure: k23444 
o|contracted procedure: k23423 
o|contracted procedure: k23440 
o|contracted procedure: k23426 
o|contracted procedure: k23436 
o|contracted procedure: k23429 
o|contracted procedure: k23432 
o|contracted procedure: k23469 
o|contracted procedure: k23475 
o|contracted procedure: k971433984 
o|contracted procedure: k23488 
o|substituted constant variable: g35876 
o|contracted procedure: k23495 
o|contracted procedure: k971433990 
o|contracted procedure: k23509 
o|substituted constant variable: g35878 
o|contracted procedure: k23515 
o|contracted procedure: k23518 
o|contracted procedure: k23524 
o|contracted procedure: k23535 
o|contracted procedure: k23542 
o|contracted procedure: k23567 
o|contracted procedure: k23575 
o|contracted procedure: k23579 
o|contracted procedure: k23583 
o|contracted procedure: k23595 
o|contracted procedure: k973333996 
o|contracted procedure: k23606 
o|contracted procedure: k23614 
o|contracted procedure: k23625 
o|contracted procedure: k23633 
o|contracted procedure: k23644 
o|contracted procedure: k23652 
o|contracted procedure: k973334010 
o|contracted procedure: k23663 
o|contracted procedure: k23671 
o|contracted procedure: k23674 
o|contracted procedure: k23677 
o|contracted procedure: k23683 
o|contracted procedure: k23689 
o|contracted procedure: k23696 
o|contracted procedure: k23706 
o|contracted procedure: k23714 
o|contracted procedure: k23722 
o|contracted procedure: k23726 
o|contracted procedure: k23738 
o|contracted procedure: k23764 
o|contracted procedure: k23790 
o|contracted procedure: k23817 
o|contracted procedure: k23835 
o|contracted procedure: k23889 
o|contracted procedure: k23932 
o|contracted procedure: k23947 
o|contracted procedure: k23951 
o|contracted procedure: k23943 
o|contracted procedure: k23939 
o|contracted procedure: k23963 
o|contracted procedure: k23978 
o|contracted procedure: k23982 
o|contracted procedure: k23974 
o|contracted procedure: k23970 
o|contracted procedure: k23991 
o|contracted procedure: k24010 
o|contracted procedure: k24045 
o|contracted procedure: k24055 
o|contracted procedure: k24104 
o|contracted procedure: k24137 
o|contracted procedure: k24113 
o|contracted procedure: k24133 
o|contracted procedure: k24119 
o|contracted procedure: k24143 
o|contracted procedure: k24162 
o|contracted procedure: k24179 
o|contracted procedure: k24189 
o|contracted procedure: k24214 
o|contracted procedure: k24266 
o|contracted procedure: k24299 
o|contracted procedure: k24275 
o|contracted procedure: k24295 
o|contracted procedure: k24281 
o|contracted procedure: k24305 
o|contracted procedure: k24316 
o|contracted procedure: k24312 
o|contracted procedure: k24326 
o|contracted procedure: k24332 
o|contracted procedure: k24351 
o|contracted procedure: k24355 
o|contracted procedure: k24347 
o|contracted procedure: k24343 
o|contracted procedure: k24339 
o|contracted procedure: k24363 
o|contracted procedure: k24374 
o|contracted procedure: k24380 
o|contracted procedure: k24415 
o|contracted procedure: k24450 
o|contracted procedure: k24453 
o|contracted procedure: k24464 
o|contracted procedure: k24471 
o|contracted procedure: k24507 
o|contracted procedure: k24501 
o|contracted procedure: k24480 
o|contracted procedure: k24513 
o|contracted procedure: k8757 
o|contracted procedure: k8747 
o|contracted procedure: k8750 
o|contracted procedure: k8761 
o|contracted procedure: k8765 
o|contracted procedure: k8774 
o|contracted procedure: k8780 
o|contracted procedure: k8803 
o|contracted procedure: k8789 
o|contracted procedure: k8796 
o|contracted procedure: k8810 
o|contracted procedure: k8814 
o|contracted procedure: k24524 
o|contracted procedure: k24536 
o|contracted procedure: k24571 
o|contracted procedure: k24675 
o|contracted procedure: k24586 
o|contracted procedure: k24606 
o|contracted procedure: k24614 
o|contracted procedure: k24610 
o|contracted procedure: k24617 
o|contracted procedure: k24626 
o|contracted procedure: k24629 
o|contracted procedure: k24665 
o|contracted procedure: k24706 
o|contracted procedure: k24678 
o|contracted procedure: k24685 
o|contracted procedure: k24689 
o|contracted procedure: k24710 
o|contracted procedure: k24714 
o|contracted procedure: k24718 
o|contracted procedure: k24724 
o|contracted procedure: k24727 
o|contracted procedure: k24744 
o|contracted procedure: k24754 
o|contracted procedure: k24872 
o|contracted procedure: k24763 
o|contracted procedure: k24776 
o|contracted procedure: k24791 
o|contracted procedure: k24795 
o|contracted procedure: k24804 
o|contracted procedure: k24817 
o|contracted procedure: k24824 
o|contracted procedure: k24831 
o|contracted procedure: k24843 
o|contracted procedure: k24868 
o|contracted procedure: k24864 
o|contracted procedure: k24875 
o|contracted procedure: k971434018 
o|contracted procedure: k24878 
o|substituted constant variable: g35896 
o|contracted procedure: k24910 
o|contracted procedure: k24886 
o|contracted procedure: k24891 
o|contracted procedure: k24916 
o|contracted procedure: k24931 
o|contracted procedure: k24927 
o|contracted procedure: k24935 
o|contracted procedure: k24941 
o|contracted procedure: k24944 
o|contracted procedure: k24958 
o|contracted procedure: k24962 
o|contracted procedure: k24965 
o|contracted procedure: k24974 
o|contracted procedure: k24982 
o|contracted procedure: k24978 
o|contracted procedure: k24985 
o|contracted procedure: k25042 
o|contracted procedure: k25046 
o|contracted procedure: k24988 
o|contracted procedure: k25030 
o|contracted procedure: k25038 
o|contracted procedure: k25034 
o|contracted procedure: k24991 
o|contracted procedure: k25022 
o|contracted procedure: k25026 
o|contracted procedure: k25000 
o|contracted procedure: k25010 
o|contracted procedure: k25018 
o|contracted procedure: k25014 
o|contracted procedure: k25003 
o|contracted procedure: k25054 
o|contracted procedure: k25066 
o|contracted procedure: k25074 
o|contracted procedure: k25070 
o|contracted procedure: k25077 
o|contracted procedure: k25141 
o|contracted procedure: k25149 
o|contracted procedure: k25145 
o|contracted procedure: k25083 
o|contracted procedure: k25129 
o|contracted procedure: k25137 
o|contracted procedure: k25133 
o|contracted procedure: k25086 
o|contracted procedure: k25117 
o|contracted procedure: k25125 
o|contracted procedure: k25121 
o|contracted procedure: k25095 
o|contracted procedure: k25105 
o|contracted procedure: k25113 
o|contracted procedure: k25109 
o|contracted procedure: k25098 
o|contracted procedure: k25157 
o|contracted procedure: k25160 
o|contracted procedure: k25171 
o|contracted procedure: k25167 
o|contracted procedure: k25256 
o|contracted procedure: k25262 
o|contracted procedure: k25284 
o|contracted procedure: k25290 
o|contracted procedure: k25298 
o|contracted procedure: k25305 
o|contracted procedure: k25308 
o|contracted procedure: k25317 
o|contracted procedure: k25323 
o|contracted procedure: k25329 
o|contracted procedure: k25339 
o|contracted procedure: k25348 
o|contracted procedure: k25356 
o|contracted procedure: k25380 
o|contracted procedure: k25375 
o|contracted procedure: k25362 
o|contracted procedure: k25383 
o|contracted procedure: k25392 
o|contracted procedure: k25398 
o|contracted procedure: k25404 
o|contracted procedure: k25431 
o|contracted procedure: k25426 
o|contracted procedure: k25413 
o|contracted procedure: k25440 
o|contracted procedure: k25464 
o|contracted procedure: k25457 
o|contracted procedure: k25448 
o|contracted procedure: k25470 
o|contracted procedure: k25481 
o|contracted procedure: k25484 
o|contracted procedure: k25512 
o|contracted procedure: k25498 
o|contracted procedure: k25505 
o|contracted procedure: k25521 
o|contracted procedure: k25544 
o|contracted procedure: k25551 
o|contracted procedure: k25554 
o|contracted procedure: k25571 
o|contracted procedure: k25578 
o|contracted procedure: k25567 
o|contracted procedure: k25619 
o|contracted procedure: k25584 
o|contracted procedure: k25599 
o|contracted procedure: k25595 
o|contracted procedure: k25605 
o|contracted procedure: k25628 
o|contracted procedure: k25645 
o|contracted procedure: k25652 
o|contracted procedure: k25661 
o|contracted procedure: k25678 
o|contracted procedure: k25686 
o|contracted procedure: k25689 
o|contracted procedure: k25698 
o|contracted procedure: k25710 
o|contracted procedure: k25717 
o|contracted procedure: k25706 
o|contracted procedure: k25726 
o|contracted procedure: k25776 
o|contracted procedure: k25749 
o|contracted procedure: k25760 
o|contracted procedure: k25756 
o|contracted procedure: k25766 
o|contracted procedure: k25782 
o|contracted procedure: k25793 
o|contracted procedure: k25799 
o|contracted procedure: k25815 
o|contracted procedure: k25871 
o|contracted procedure: k25857 
o|contracted procedure: k25864 
o|contracted procedure: k25877 
o|contracted procedure: k25889 
o|contracted procedure: k25892 
o|contracted procedure: k25902 
o|contracted procedure: k25931 
o|contracted procedure: k971434028 
o|contracted procedure: k25937 
o|substituted constant variable: g35932 
o|contracted procedure: k25945 
o|contracted procedure: k25952 
o|contracted procedure: k25964 
o|contracted procedure: k25970 
o|contracted procedure: k25976 
o|contracted procedure: k25985 
o|contracted procedure: k25992 
o|contracted procedure: k26014 
o|contracted procedure: k26036 
o|contracted procedure: k26044 
o|contracted procedure: k26051 
o|contracted procedure: k26063 
o|contracted procedure: k26069 
o|contracted procedure: k26075 
o|contracted procedure: k26084 
o|contracted procedure: k26091 
o|contracted procedure: k26113 
o|contracted procedure: k26100 
o|contracted procedure: k26135 
o|contracted procedure: k26122 
o|contracted procedure: k26141 
o|contracted procedure: k26171 
o|contracted procedure: k26162 
o|contracted procedure: k17115 
o|contracted procedure: k17119 
o|contracted procedure: k17128 
o|contracted procedure: k17134 
o|contracted procedure: k17144 
o|contracted procedure: k17156 
o|contracted procedure: k17167 
o|contracted procedure: k17173 
o|contracted procedure: k17190 
o|contracted procedure: k17197 
o|contracted procedure: k17201 
o|contracted procedure: k17214 
o|contracted procedure: k17224 
o|contracted procedure: k17228 
o|contracted procedure: k17232 
o|contracted procedure: k17236 
o|contracted procedure: k17254 
o|contracted procedure: k17268 
o|contracted procedure: k17275 
o|contracted procedure: k17279 
o|contracted procedure: k17296 
o|contracted procedure: k17306 
o|contracted procedure: k17310 
o|contracted procedure: k17339 
o|contracted procedure: k17345 
o|contracted procedure: k17374 
o|contracted procedure: k17378 
o|contracted procedure: k17433 
o|contracted procedure: k17426 
o|contracted procedure: k17388 
o|contracted procedure: k17392 
o|contracted procedure: k17402 
o|inlining procedure: k17406 
o|inlining procedure: k17406 
o|contracted procedure: k17451 
o|contracted procedure: k17436 
o|contracted procedure: k17439 
o|contracted procedure: k17455 
o|contracted procedure: k17464 
o|contracted procedure: k17472 
o|contracted procedure: k17487 
o|contracted procedure: k17483 
o|contracted procedure: k17491 
o|contracted procedure: k17497 
o|contracted procedure: k17511 
o|contracted procedure: k17524 
o|contracted procedure: k17517 
o|contracted procedure: k17531 
o|contracted procedure: k17528 
o|contracted procedure: k17543 
o|contracted procedure: k17546 
o|contracted procedure: k17555 
o|contracted procedure: k17605 
o|contracted procedure: k17567 
o|contracted procedure: k17601 
o|contracted procedure: k17573 
o|contracted procedure: k17597 
o|contracted procedure: k17576 
o|contracted procedure: k17583 
o|contracted procedure: k17587 
o|contracted procedure: k17616 
o|contracted procedure: k17612 
o|substituted constant variable: g35940 
o|contracted procedure: k17646 
o|contracted procedure: k17622 
o|contracted procedure: k17627 
o|contracted procedure: k17652 
o|contracted procedure: k17655 
o|contracted procedure: k17676 
o|contracted procedure: k17679 
o|contracted procedure: k17697 
o|contracted procedure: k17740 
o|contracted procedure: k17736 
o|contracted procedure: k17714 
o|contracted procedure: k17732 
o|contracted procedure: k17728 
o|contracted procedure: k17718 
o|contracted procedure: k17769 
o|contracted procedure: k17765 
o|contracted procedure: k17761 
o|contracted procedure: k17773 
o|contracted procedure: k17779 
o|contracted procedure: k17812 
o|contracted procedure: k17788 
o|contracted procedure: k17808 
o|contracted procedure: k17794 
o|contracted procedure: k17818 
o|contracted procedure: k17835 
o|contracted procedure: k17843 
o|contracted procedure: k17846 
o|contracted procedure: k17863 
o|contracted procedure: k17877 
o|contracted procedure: k17895 
o|contracted procedure: k17891 
o|contracted procedure: k17887 
o|contracted procedure: k17917 
o|contracted procedure: k17926 
o|contracted procedure: k17942 
o|contracted procedure: k17946 
o|contracted procedure: k17957 
o|contracted procedure: k17963 
o|contracted procedure: k17980 
o|contracted procedure: k17986 
o|contracted procedure: k18033 
o|contracted procedure: k18039 
o|contracted procedure: k18062 
o|contracted procedure: k18068 
o|contracted procedure: k18074 
o|contracted procedure: k18095 
o|contracted procedure: k18101 
o|contracted procedure: k18123 
o|contracted procedure: k18132 
o|contracted procedure: k18139 
o|contracted procedure: k18159 
o|contracted procedure: k18181 
o|contracted procedure: k18172 
o|contracted procedure: k18188 
o|contracted procedure: k18195 
o|contracted procedure: k2053734057 
o|contracted procedure: k16257 
o|contracted procedure: k2053734062 
o|contracted procedure: k16287 
o|contracted procedure: k16302 
o|contracted procedure: k16298 
o|contracted procedure: k971434091 
o|contracted procedure: k15589 
o|substituted constant variable: g35961 
o|contracted procedure: k971434085 
o|contracted procedure: k15593 
o|substituted constant variable: g35959 
o|contracted procedure: k15608 
o|contracted procedure: k15615 
o|contracted procedure: k15630 
o|contracted procedure: k15645 
o|contracted procedure: k15654 
o|contracted procedure: k15663 
o|contracted procedure: k15675 
o|contracted procedure: k15678 
o|contracted procedure: k15681 
o|contracted procedure: k15689 
o|contracted procedure: k15697 
o|contracted procedure: k15706 
o|contracted procedure: k15715 
o|contracted procedure: k15724 
o|contracted procedure: k15736 
o|contracted procedure: k15739 
o|contracted procedure: k15742 
o|contracted procedure: k15750 
o|contracted procedure: k15758 
o|contracted procedure: k15767 
o|contracted procedure: k15776 
o|contracted procedure: k15808 
o|contracted procedure: k15817 
o|contracted procedure: k15823 
o|contracted procedure: k15830 
o|contracted procedure: k15834 
o|contracted procedure: k15846 
o|contracted procedure: k15849 
o|contracted procedure: k15852 
o|contracted procedure: k15860 
o|contracted procedure: k15868 
o|contracted procedure: k15886 
o|contracted procedure: k15890 
o|contracted procedure: k15902 
o|contracted procedure: k15905 
o|contracted procedure: k15908 
o|contracted procedure: k15916 
o|contracted procedure: k15924 
o|contracted procedure: k15932 
o|contracted procedure: k15938 
o|contracted procedure: k15966 
o|contracted procedure: k15975 
o|contracted procedure: k15991 
o|contracted procedure: k16006 
o|contracted procedure: k16028 
o|contracted procedure: k16024 
o|contracted procedure: k16009 
o|contracted procedure: k16012 
o|contracted procedure: k16020 
o|contracted procedure: k16037 
o|contracted procedure: k1402134077 
o|contracted procedure: k16324 
o|contracted procedure: k16331 
o|contracted procedure: k16340 
o|contracted procedure: k16357 
o|contracted procedure: k16353 
o|contracted procedure: k16343 
o|contracted procedure: k16363 
o|contracted procedure: k16374 
o|inlining procedure: k16377 
o|contracted procedure: k16385 
o|inlining procedure: k16377 
o|contracted procedure: k16391 
o|contracted procedure: k16397 
o|contracted procedure: k16403 
o|contracted procedure: k16409 
o|contracted procedure: k16415 
o|contracted procedure: k16444 
o|contracted procedure: k16450 
o|contracted procedure: k16456 
o|contracted procedure: k16462 
o|contracted procedure: k16488 
o|contracted procedure: k16497 
o|contracted procedure: k16504 
o|contracted procedure: k16513 
o|contracted procedure: k16529 
o|contracted procedure: k16519 
o|contracted procedure: k16537 
o|contracted procedure: k16547 
o|contracted procedure: k16553 
o|contracted procedure: k16559 
o|contracted procedure: k16565 
o|contracted procedure: k16592 
o|contracted procedure: k16610 
o|contracted procedure: k16626 
o|contracted procedure: k16616 
o|contracted procedure: k16637 
o|contracted procedure: k16644 
o|contracted procedure: k16653 
o|contracted procedure: k16660 
o|contracted procedure: k16668 
o|contracted procedure: k16678 
o|contracted procedure: k16684 
o|contracted procedure: k16690 
o|contracted procedure: k16696 
o|contracted procedure: k16732 
o|contracted procedure: k16739 
o|contracted procedure: k16742 
o|contracted procedure: k16757 
o|contracted procedure: k16766 
o|contracted procedure: k16773 
o|contracted procedure: k16781 
o|contracted procedure: k16791 
o|contracted procedure: k16797 
o|contracted procedure: k16803 
o|contracted procedure: k16809 
o|contracted procedure: k16849 
o|contracted procedure: k16856 
o|contracted procedure: k16859 
o|contracted procedure: k16874 
o|contracted procedure: k16883 
o|contracted procedure: k16898 
o|contracted procedure: k16908 
o|contracted procedure: k16914 
o|contracted procedure: k16920 
o|contracted procedure: k16926 
o|contracted procedure: k16960 
o|contracted procedure: k16972 
o|contracted procedure: k16983 
o|contracted procedure: k17005 
o|inlining procedure: k17012 
o|contracted procedure: k17022 
o|inlining procedure: k17012 
o|contracted procedure: k17031 
o|contracted procedure: k17038 
o|contracted procedure: k17042 
o|contracted procedure: k17048 
o|contracted procedure: k17059 
o|inlining procedure: k17012 
o|contracted procedure: k17066 
o|contracted procedure: k17072 
o|contracted procedure: k18208 
o|contracted procedure: k18222 
o|contracted procedure: k18214 
o|contracted procedure: k18231 
o|contracted procedure: k18245 
o|contracted procedure: k18237 
o|contracted procedure: k18372 
o|contracted procedure: k18254 
o|contracted procedure: k18257 
o|contracted procedure: k18263 
o|contracted procedure: k18266 
o|contracted procedure: k18281 
o|contracted procedure: k18284 
o|contracted procedure: k18295 
o|contracted procedure: k18301 
o|contracted procedure: k18312 
o|contracted procedure: k18315 
o|contracted procedure: k18327 
o|contracted procedure: k18330 
o|contracted procedure: k18333 
o|contracted procedure: k18341 
o|contracted procedure: k18349 
o|contracted procedure: k18712 
o|contracted procedure: k18435 
o|contracted procedure: k18438 
o|contracted procedure: k18444 
o|contracted procedure: k18447 
o|contracted procedure: k18458 
o|contracted procedure: k18466 
o|contracted procedure: k18469 
o|contracted procedure: k18480 
o|contracted procedure: k18492 
o|contracted procedure: k18488 
o|contracted procedure: k18484 
o|contracted procedure: k18496 
o|contracted procedure: k18502 
o|contracted procedure: k18517 
o|contracted procedure: k18513 
o|contracted procedure: k18521 
o|contracted procedure: k18527 
o|contracted procedure: k18541 
o|contracted procedure: k18544 
o|contracted procedure: k18551 
o|contracted procedure: k18557 
o|contracted procedure: k18560 
o|contracted procedure: k18567 
o|contracted procedure: k18584 
o|contracted procedure: k18590 
o|contracted procedure: k18596 
o|contracted procedure: k18602 
o|contracted procedure: k18608 
o|contracted procedure: k18614 
o|contracted procedure: k18620 
o|contracted procedure: k18626 
o|contracted procedure: k18632 
o|contracted procedure: k18638 
o|contracted procedure: k18644 
o|contracted procedure: k18650 
o|contracted procedure: k18656 
o|contracted procedure: k18721 
o|contracted procedure: k18728 
o|contracted procedure: k18732 
o|contracted procedure: k18753 
o|contracted procedure: k18760 
o|contracted procedure: k18811 
o|contracted procedure: k18769 
o|contracted procedure: k18807 
o|contracted procedure: k18775 
o|contracted procedure: k18800 
o|contracted procedure: k18792 
o|contracted procedure: k18819 
o|contracted procedure: k18826 
o|contracted procedure: k18830 
o|contracted procedure: k18842 
o|contracted procedure: k18845 
o|contracted procedure: k18848 
o|contracted procedure: k18856 
o|contracted procedure: k18864 
o|contracted procedure: k18872 
o|contracted procedure: k18878 
o|contracted procedure: k18884 
o|contracted procedure: k18890 
o|contracted procedure: k18896 
o|contracted procedure: k18902 
o|contracted procedure: k19007 
o|contracted procedure: k18937 
o|contracted procedure: k18940 
o|contracted procedure: k18946 
o|contracted procedure: k18959 
o|contracted procedure: k18969 
o|contracted procedure: k18962 
o|contracted procedure: k18983 
o|contracted procedure: k18976 
o|contracted procedure: k18993 
o|contracted procedure: k18999 
o|contracted procedure: k19018 
o|contracted procedure: k19011 
o|contracted procedure: k19036 
o|contracted procedure: k19043 
o|contracted procedure: k19046 
o|contracted procedure: k19054 
o|contracted procedure: k19058 
o|contracted procedure: k7567 
o|contracted procedure: k19070 
o|contracted procedure: k19190 
o|contracted procedure: k971434125 
o|contracted procedure: k19076 
o|substituted constant variable: g35981 
o|contracted procedure: k19096 
o|contracted procedure: k19085 
o|contracted procedure: k19092 
o|contracted procedure: k19088 
o|contracted procedure: k19100 
o|contracted procedure: k19110 
o|contracted procedure: k19113 
o|contracted procedure: k19116 
o|contracted procedure: k19119 
o|contracted procedure: k19154 
o|contracted procedure: k19143 
o|contracted procedure: k19150 
o|contracted procedure: k19146 
o|contracted procedure: k19160 
o|contracted procedure: k19180 
o|contracted procedure: k19185 
o|contracted procedure: k19671 
o|contracted procedure: k19674 
o|contracted procedure: k19677 
o|contracted procedure: k19680 
o|contracted procedure: k19824 
o|contracted procedure: k19820 
o|contracted procedure: k1965334119 
o|contracted procedure: k19683 
o|contracted procedure: k19710 
o|contracted procedure: k19735 
o|contracted procedure: k19716 
o|contracted procedure: k19723 
o|contracted procedure: k19713 
o|contracted procedure: k19749 
o|contracted procedure: k19752 
o|contracted procedure: k1965334109 
o|contracted procedure: k19768 
o|contracted procedure: k19799 
o|contracted procedure: k19774 
o|contracted procedure: k19792 
o|contracted procedure: k19783 
o|contracted procedure: k19803 
o|contracted procedure: k19197 
o|contracted procedure: k7585 
o|contracted procedure: k19206 
o|contracted procedure: k19209 
o|contracted procedure: k19215 
o|contracted procedure: k19221 
o|contracted procedure: k19309 
o|contracted procedure: k971434133 
o|contracted procedure: k19227 
o|substituted constant variable: g35987 
o|contracted procedure: k19259 
o|contracted procedure: k19248 
o|contracted procedure: k19255 
o|contracted procedure: k19251 
o|contracted procedure: k19265 
o|contracted procedure: k19272 
o|contracted procedure: k19285 
o|contracted procedure: k19292 
o|contracted procedure: k19299 
o|contracted procedure: k19389 
o|contracted procedure: k19319 
o|contracted procedure: k19322 
o|contracted procedure: k19328 
o|contracted procedure: k19341 
o|contracted procedure: k19351 
o|contracted procedure: k19344 
o|contracted procedure: k19365 
o|contracted procedure: k19358 
o|contracted procedure: k19375 
o|contracted procedure: k19381 
o|contracted procedure: k19400 
o|contracted procedure: k19393 
o|contracted procedure: k19412 
o|contracted procedure: k19418 
o|contracted procedure: k19455 
o|contracted procedure: k19430 
o|contracted procedure: k19451 
o|contracted procedure: k19433 
o|contracted procedure: k19440 
o|contracted procedure: k19444 
o|contracted procedure: k19436 
o|contracted procedure: k19472 
o|contracted procedure: k19483 
o|contracted procedure: k19487 
o|contracted procedure: k19491 
o|contracted procedure: k19498 
o|contracted procedure: k19501 
o|contracted procedure: k19507 
o|contracted procedure: k19513 
o|contracted procedure: k19519 
o|contracted procedure: k19541 
o|contracted procedure: k19547 
o|contracted procedure: k19554 
o|contracted procedure: k19599 
o|contracted procedure: k19560 
o|contracted procedure: k19567 
o|contracted procedure: k19584 
o|contracted procedure: k19595 
o|contracted procedure: k19612 
o|contracted procedure: k19623 
o|contracted procedure: k19832 
o|contracted procedure: k19835 
o|contracted procedure: k19838 
o|contracted procedure: k19848 
o|contracted procedure: k19857 
o|contracted procedure: k19864 
o|contracted procedure: k19873 
o|contracted procedure: k19881 
o|contracted procedure: k19893 
o|contracted procedure: k19903 
o|contracted procedure: k19907 
o|contracted procedure: k19949 
o|contracted procedure: k19952 
o|contracted procedure: k19955 
o|contracted procedure: k19958 
o|contracted procedure: k19961 
o|contracted procedure: k19964 
o|contracted procedure: k19967 
o|contracted procedure: k19973 
o|contracted procedure: k1965334164 
o|contracted procedure: k19976 
o|contracted procedure: k19979 
o|contracted procedure: k19992 
o|contracted procedure: k19996 
o|contracted procedure: k20017 
o|contracted procedure: k20048 
o|contracted procedure: k20056 
o|contracted procedure: k20052 
o|contracted procedure: k20059 
o|contracted procedure: k20065 
o|contracted procedure: k20081 
o|contracted procedure: k20074 
o|contracted procedure: k20084 
o|contracted procedure: k20106 
o|contracted procedure: k20114 
o|contracted procedure: k20110 
o|contracted procedure: k20087 
o|contracted procedure: k20094 
o|contracted procedure: k20102 
o|contracted procedure: k20098 
o|contracted procedure: k20117 
o|contracted procedure: k1965334152 
o|contracted procedure: k20126 
o|contracted procedure: k20129 
o|contracted procedure: k20153 
o|contracted procedure: k20177 
o|contracted procedure: k20161 
o|contracted procedure: k20173 
o|contracted procedure: k20164 
o|contracted procedure: k20180 
o|contracted procedure: k20183 
o|contracted procedure: k20194 
o|contracted procedure: k20199 
o|contracted procedure: k20221 
o|contracted procedure: k20202 
o|contracted procedure: k20217 
o|contracted procedure: k20205 
o|contracted procedure: k20208 
o|contracted procedure: k20225 
o|contracted procedure: k20231 
o|contracted procedure: k20243 
o|contracted procedure: k20253 
o|contracted procedure: k20257 
o|contracted procedure: k20266 
o|contracted procedure: k20269 
o|contracted procedure: k20272 
o|contracted procedure: k20280 
o|contracted procedure: k20288 
o|contracted procedure: k20300 
o|contracted procedure: k20310 
o|contracted procedure: k20314 
o|contracted procedure: k20317 
o|contracted procedure: k20357 
o|contracted procedure: k20365 
o|contracted procedure: k20361 
o|contracted procedure: k20338 
o|contracted procedure: k20345 
o|contracted procedure: k20353 
o|contracted procedure: k20349 
o|contracted procedure: k20386 
o|contracted procedure: k20394 
o|contracted procedure: k20390 
o|contracted procedure: k20428 
o|contracted procedure: k20403 
o|contracted procedure: k20421 
o|contracted procedure: k20412 
o|contracted procedure: k20432 
o|contracted procedure: k20435 
o|contracted procedure: k20456 
o|contracted procedure: k20443 
o|contracted procedure: k20452 
o|contracted procedure: k20492 
o|contracted procedure: k20459 
o|contracted procedure: k20462 
o|contracted procedure: k20474 
o|contracted procedure: k20484 
o|contracted procedure: k20488 
o|contracted procedure: k20514 
o|contracted procedure: k20522 
o|contracted procedure: k20518 
o|contracted procedure: k20495 
o|contracted procedure: k20502 
o|contracted procedure: k20510 
o|contracted procedure: k20506 
o|contracted procedure: k19930 
o|contracted procedure: k19933 
o|contracted procedure: k30353 
o|contracted procedure: k30971 
o|contracted procedure: k30967 
o|contracted procedure: k30361 
o|contracted procedure: k30369 
o|contracted procedure: k30377 
o|contracted procedure: k30385 
o|contracted procedure: k30393 
o|contracted procedure: k30401 
o|contracted procedure: k30409 
o|contracted procedure: k30417 
o|contracted procedure: k30425 
o|contracted procedure: k30433 
o|contracted procedure: k30441 
o|contracted procedure: k30449 
o|contracted procedure: k30457 
o|contracted procedure: k30465 
o|contracted procedure: k30473 
o|contracted procedure: k30481 
o|contracted procedure: k30489 
o|contracted procedure: k30497 
o|contracted procedure: k30505 
o|contracted procedure: k30513 
o|contracted procedure: k30521 
o|contracted procedure: k30529 
o|contracted procedure: k30537 
o|contracted procedure: k30545 
o|contracted procedure: k30553 
o|contracted procedure: k30963 
o|contracted procedure: k30561 
o|contracted procedure: k30569 
o|contracted procedure: k30577 
o|contracted procedure: k30581 
o|contracted procedure: k30955 
o|contracted procedure: k30959 
o|contracted procedure: k30585 
o|contracted procedure: k30951 
o|contracted procedure: k30947 
o|contracted procedure: k30589 
o|contracted procedure: k30593 
o|contracted procedure: k30943 
o|contracted procedure: k30597 
o|contracted procedure: k30939 
o|contracted procedure: k30601 
o|contracted procedure: k30935 
o|contracted procedure: k30605 
o|contracted procedure: k30609 
o|contracted procedure: k30613 
o|contracted procedure: k30931 
o|contracted procedure: k30923 
o|contracted procedure: k30927 
o|contracted procedure: k30617 
o|contracted procedure: k30919 
o|contracted procedure: k30895 
o|contracted procedure: k30899 
o|contracted procedure: k30915 
o|contracted procedure: k30903 
o|contracted procedure: k30911 
o|contracted procedure: k30907 
o|contracted procedure: k30621 
o|contracted procedure: k30891 
o|contracted procedure: k30625 
o|contracted procedure: k30887 
o|contracted procedure: k30629 
o|contracted procedure: k30883 
o|contracted procedure: k30855 
o|contracted procedure: k30871 
o|contracted procedure: k30879 
o|contracted procedure: k30875 
o|contracted procedure: k30859 
o|contracted procedure: k30867 
o|contracted procedure: k30863 
o|contracted procedure: k30633 
o|contracted procedure: k30847 
o|contracted procedure: k30851 
o|contracted procedure: k30839 
o|contracted procedure: k30843 
o|contracted procedure: k30637 
o|contracted procedure: k30835 
o|contracted procedure: k30641 
o|contracted procedure: k30831 
o|contracted procedure: k30823 
o|contracted procedure: k30827 
o|contracted procedure: k30819 
o|contracted procedure: k30645 
o|contracted procedure: k30809 
o|contracted procedure: k30801 
o|contracted procedure: k30805 
o|contracted procedure: k30649 
o|contracted procedure: k30797 
o|contracted procedure: k30653 
o|contracted procedure: k30781 
o|contracted procedure: k30789 
o|contracted procedure: k30793 
o|contracted procedure: k30785 
o|contracted procedure: k30657 
o|contracted procedure: k30661 
o|contracted procedure: k30777 
o|contracted procedure: k30665 
o|contracted procedure: k30773 
o|contracted procedure: k30669 
o|contracted procedure: k30769 
o|contracted procedure: k30765 
o|contracted procedure: k30673 
o|contracted procedure: k30761 
o|contracted procedure: k30677 
o|contracted procedure: k30757 
o|contracted procedure: k30681 
o|contracted procedure: k30685 
o|contracted procedure: k30753 
o|contracted procedure: k30689 
o|contracted procedure: k30749 
o|contracted procedure: k30693 
o|contracted procedure: k30701 
o|contracted procedure: k30705 
o|contracted procedure: k30745 
o|contracted procedure: k30709 
o|contracted procedure: k30741 
o|contracted procedure: k30717 
o|contracted procedure: k30737 
o|contracted procedure: k30721 
o|contracted procedure: k30733 
o|contracted procedure: k30729 
o|contracted procedure: k30725 
o|contracted procedure: k30713 
o|contracted procedure: k30697 
o|contracted procedure: k30573 
o|contracted procedure: k30565 
o|contracted procedure: k30557 
o|contracted procedure: k30549 
o|contracted procedure: k30541 
o|contracted procedure: k30533 
o|contracted procedure: k30525 
o|contracted procedure: k30517 
o|contracted procedure: k30509 
o|contracted procedure: k30501 
o|contracted procedure: k30493 
o|contracted procedure: k30485 
o|contracted procedure: k30477 
o|contracted procedure: k30469 
o|contracted procedure: k30461 
o|contracted procedure: k30453 
o|contracted procedure: k30445 
o|contracted procedure: k30437 
o|contracted procedure: k30429 
o|contracted procedure: k30421 
o|contracted procedure: k30413 
o|contracted procedure: k30405 
o|contracted procedure: k30397 
o|contracted procedure: k30389 
o|contracted procedure: k30381 
o|contracted procedure: k30373 
o|contracted procedure: k30365 
o|contracted procedure: k30357 
o|contracted procedure: k20528 
o|contracted procedure: k20599 
o|substituted constant variable: g36016 
o|contracted procedure: k20610 
o|contracted procedure: k20606 
o|contracted procedure: k20651 
o|contracted procedure: k20636 
o|contracted procedure: k20647 
o|contracted procedure: k20643 
o|contracted procedure: k20624 
o|contracted procedure: k20620 
o|contracted procedure: k20787 
o|contracted procedure: k20590 
o|contracted procedure: k20796 
o|contracted procedure: k20844 
o|contracted procedure: k20848 
o|contracted procedure: k20799 
o|contracted procedure: k20811 
o|contracted procedure: k20821 
o|substituted constant variable: g36018 
o|contracted procedure: k20834 
o|contracted procedure: k20824 
o|contracted procedure: k20840 
o|contracted procedure: k20865 
o|contracted procedure: k971434189 
o|contracted procedure: k20877 
o|substituted constant variable: g36023 
o|contracted procedure: k2628134178 
o|contracted procedure: k20888 
o|contracted procedure: k2628134173 
o|contracted procedure: k20892 
o|contracted procedure: k2628134183 
o|contracted procedure: k20899 
o|contracted procedure: k20905 
o|contracted procedure: k21667 
o|contracted procedure: k20911 
o|contracted procedure: k20914 
o|contracted procedure: k20938 
o|contracted procedure: k20952 
o|contracted procedure: k20962 
o|substituted constant variable: g36026 
o|contracted procedure: k20969 
o|contracted procedure: k20981 
o|contracted procedure: k20977 
o|contracted procedure: k20991 
o|contracted procedure: k21008 
o|contracted procedure: k21011 
o|inlining procedure: k21021 
o|contracted procedure: k21039 
o|contracted procedure: k21030 
o|inlining procedure: k21021 
o|contracted procedure: k21047 
o|contracted procedure: k21650 
o|contracted procedure: k21053 
o|contracted procedure: k971434197 
o|contracted procedure: k21068 
o|substituted constant variable: g36029 
o|contracted procedure: k21079 
o|contracted procedure: k21086 
o|contracted procedure: k21089 
o|contracted procedure: k21095 
o|contracted procedure: k21098 
o|contracted procedure: k21116 
o|contracted procedure: k21154 
o|contracted procedure: k21125 
o|contracted procedure: k21138 
o|contracted procedure: k21163 
o|contracted procedure: k971434203 
o|contracted procedure: k21184 
o|substituted constant variable: g36031 
o|contracted procedure: k21190 
o|contracted procedure: k21274 
o|contracted procedure: k21202 
o|contracted procedure: k21242 
o|contracted procedure: k21258 
o|contracted procedure: k21282 
o|contracted procedure: k21301 
o|contracted procedure: k21313 
o|contracted procedure: k21316 
o|contracted procedure: k21347 
o|contracted procedure: k21340 
o|contracted procedure: k21351 
o|contracted procedure: k21367 
o|contracted procedure: k21370 
o|contracted procedure: k21437 
o|contracted procedure: k21433 
o|contracted procedure: k21373 
o|contracted procedure: k21376 
o|contracted procedure: k21411 
o|contracted procedure: k21423 
o|contracted procedure: k21445 
o|contracted procedure: k21448 
o|contracted procedure: k21515 
o|contracted procedure: k21511 
o|contracted procedure: k21451 
o|contracted procedure: k21454 
o|contracted procedure: k21489 
o|contracted procedure: k21568 
o|contracted procedure: k21520 
o|contracted procedure: k21561 
o|contracted procedure: k21531 
o|contracted procedure: k21538 
o|contracted procedure: k21550 
o|contracted procedure: k21557 
o|contracted procedure: k21596 
o|contracted procedure: k21602 
o|contracted procedure: k21619 
o|contracted procedure: k21625 
o|contracted procedure: k21684 
o|contracted procedure: k21694 
o|substituted constant variable: g36034 
o|contracted procedure: k21707 
o|contracted procedure: k21697 
o|contracted procedure: k21716 
o|contracted procedure: k21712 
o|contracted procedure: k21720 
o|contracted procedure: k21724 
o|contracted procedure: k21834 
o|contracted procedure: k21733 
o|contracted procedure: k21743 
o|contracted procedure: k21736 
o|contracted procedure: k21739 
o|contracted procedure: k21830 
o|contracted procedure: k21749 
o|contracted procedure: k21752 
o|contracted procedure: k21758 
o|contracted procedure: k21772 
o|contracted procedure: k21780 
o|contracted procedure: k21776 
o|contracted procedure: k21801 
o|contracted procedure: k21807 
o|contracted procedure: k21888 
o|contracted procedure: k21897 
o|contracted procedure: k21900 
o|contracted procedure: k21903 
o|contracted procedure: k21911 
o|contracted procedure: k2053734215 
o|contracted procedure: k21926 
o|contracted procedure: k21934 
o|contracted procedure: k21949 
o|contracted procedure: k21958 
o|contracted procedure: k21963 
o|contracted procedure: k21967 
o|contracted procedure: k21988 
o|contracted procedure: k21973 
o|contracted procedure: k21977 
o|contracted procedure: k21984 
o|contracted procedure: k21991 
o|contracted procedure: k2053734220 
o|contracted procedure: k22001 
o|contracted procedure: k22014 
o|contracted procedure: k22024 
o|contracted procedure: k22028 
o|contracted procedure: k2187834228 
o|contracted procedure: k22050 
o|contracted procedure: k22031 
o|contracted procedure: k22035 
o|contracted procedure: k22046 
o|contracted procedure: k22042 
o|contracted procedure: k22301 
o|contracted procedure: k22313 
o|contracted procedure: k22316 
o|contracted procedure: k22583 
o|contracted procedure: k22383 
o|contracted procedure: k22576 
o|contracted procedure: k22572 
o|contracted procedure: k22568 
o|contracted procedure: k22564 
o|contracted procedure: k22398 
o|contracted procedure: k22405 
o|contracted procedure: k22409 
o|contracted procedure: k22418 
o|contracted procedure: k22438 
o|contracted procedure: k22434 
o|contracted procedure: k22421 
o|contracted procedure: k22605 
o|contracted procedure: k22630 
o|contracted procedure: k22655 
o|contracted procedure: k22647 
o|contracted procedure: k22651 
o|contracted procedure: k22643 
o|contracted procedure: k22660 
o|contracted procedure: k26307 
o|contracted procedure: k26333 
o|contracted procedure: k26310 
o|contracted procedure: k26329 
o|contracted procedure: k26317 
o|contracted procedure: k26325 
o|contracted procedure: k26321 
o|contracted procedure: k22669 
o|contracted procedure: k22626 
o|contracted procedure: k22614 
o|contracted procedure: k22681 
o|contracted procedure: k22684 
o|contracted procedure: k22687 
o|contracted procedure: k22695 
o|contracted procedure: k22703 
o|contracted procedure: k22710 
o|contracted procedure: k22719 
o|contracted procedure: k22726 
o|contracted procedure: k22730 
o|contracted procedure: k22742 
o|contracted procedure: k22738 
o|contracted procedure: k22734 
o|contracted procedure: k22557 
o|contracted procedure: k22450 
o|contracted procedure: k22474 
o|contracted procedure: k22477 
o|contracted procedure: k22492 
o|contracted procedure: k22484 
o|contracted procedure: k22488 
o|contracted procedure: k22501 
o|contracted procedure: k22507 
o|contracted procedure: k22516 
o|contracted procedure: k22532 
o|contracted procedure: k22536 
o|contracted procedure: k22528 
o|contracted procedure: k22524 
o|contracted procedure: k22520 
o|contracted procedure: k22546 
o|contracted procedure: k20679 
o|contracted procedure: k20675 
o|contracted procedure: k20671 
o|contracted procedure: k20667 
o|contracted procedure: k20657 
o|contracted procedure: k23391 
o|contracted procedure: k20708 
o|contracted procedure: k20704 
o|contracted procedure: k20685 
o|contracted procedure: k20696 
o|contracted procedure: k20700 
o|contracted procedure: k20692 
o|contracted procedure: k23400 
o|contracted procedure: k23238 
o|contracted procedure: k23241 
o|contracted procedure: k23253 
o|contracted procedure: k23377 
o|contracted procedure: k23271 
o|contracted procedure: k23280 
o|contracted procedure: k23287 
o|contracted procedure: k23294 
o|contracted procedure: k23298 
o|contracted procedure: k23307 
o|contracted procedure: k23313 
o|contracted procedure: k23320 
o|contracted procedure: k23327 
o|contracted procedure: k23333 
o|contracted procedure: k23340 
o|contracted procedure: k23347 
o|contracted procedure: k23351 
o|contracted procedure: k23358 
o|contracted procedure: k23365 
o|contracted procedure: k23355 
o|contracted procedure: k23385 
o|contracted procedure: k22291 
o|contracted procedure: k22295 
o|contracted procedure: k22230 
o|contracted procedure: k22283 
o|contracted procedure: k22287 
o|contracted procedure: k22236 
o|contracted procedure: k22239 
o|contracted procedure: k22248 
o|contracted procedure: k22279 
o|contracted procedure: k22267 
o|contracted procedure: k22275 
o|contracted procedure: k22271 
o|contracted procedure: k22257 
o|contracted procedure: k22553 
o|contracted procedure: k22776 
o|contracted procedure: k22783 
o|contracted procedure: k22794 
o|contracted procedure: k22801 
o|contracted procedure: k22926 
o|contracted procedure: k22811 
o|contracted procedure: k22821 
o|contracted procedure: k22922 
o|contracted procedure: k2629134269 
o|contracted procedure: k22761 
o|contracted procedure: k22757 
o|contracted procedure: k22824 
o|contracted procedure: k22838 
o|contracted procedure: k2629134259 
o|contracted procedure: k22853 
o|contracted procedure: k22860 
o|contracted procedure: k22879 
o|contracted procedure: k22875 
o|contracted procedure: k22886 
o|contracted procedure: k2629134264 
o|contracted procedure: k22896 
o|contracted procedure: k22889 
o|contracted procedure: k22900 
o|contracted procedure: k22904 
o|contracted procedure: k22916 
o|contracted procedure: k20573 
o|substituted constant variable: g36076 
o|contracted procedure: k20580 
o|contracted procedure: k2053734279 
o|contracted procedure: k20736 
o|contracted procedure: k20732 
o|contracted procedure: k20728 
o|contracted procedure: k20724 
o|contracted procedure: k20714 
o|contracted procedure: k23068 
o|contracted procedure: k20765 
o|contracted procedure: k20761 
o|contracted procedure: k20742 
o|contracted procedure: k20753 
o|contracted procedure: k20757 
o|contracted procedure: k20749 
o|contracted procedure: k23077 
o|contracted procedure: k22953 
o|contracted procedure: k22956 
o|contracted procedure: k22976 
o|contracted procedure: k22982 
o|contracted procedure: k23048 
o|contracted procedure: k22988 
o|contracted procedure: k22991 
o|contracted procedure: k22994 
o|contracted procedure: k22102 
o|contracted procedure: k22105 
o|contracted procedure: k22111 
o|contracted procedure: k2053734284 
o|contracted procedure: k22127 
o|contracted procedure: k22123 
o|contracted procedure: k23012 
o|contracted procedure: k23020 
o|contracted procedure: k23016 
o|contracted procedure: k22149 
o|contracted procedure: k22134 
o|contracted procedure: k22138 
o|contracted procedure: k22145 
o|contracted procedure: k2187834290 
o|contracted procedure: k22171 
o|contracted procedure: k22152 
o|contracted procedure: k22156 
o|contracted procedure: k22167 
o|contracted procedure: k22163 
o|contracted procedure: k22180 
o|contracted procedure: k22187 
o|contracted procedure: k22221 
o|contracted procedure: k22193 
o|contracted procedure: k22204 
o|contracted procedure: k22200 
o|contracted procedure: k22215 
o|contracted procedure: k22338 
o|contracted procedure: k22377 
o|contracted procedure: k22341 
o|contracted procedure: k22350 
o|contracted procedure: k22347 
o|contracted procedure: k22373 
o|contracted procedure: k22362 
o|contracted procedure: k22369 
o|contracted procedure: k23039 
o|contracted procedure: k23035 
o|contracted procedure: k2187834306 
o|contracted procedure: k22096 
o|contracted procedure: k22062 
o|contracted procedure: k22092 
o|contracted procedure: k22084 
o|contracted procedure: k2053734299 
o|contracted procedure: k22080 
o|contracted procedure: k22065 
o|contracted procedure: k22076 
o|contracted procedure: k22072 
o|contracted procedure: k22056 
o|contracted procedure: k2053734315 
o|contracted procedure: k23062 
o|contracted procedure: k23083 
o|contracted procedure: k23086 
o|contracted procedure: k23089 
o|contracted procedure: k23101 
o|contracted procedure: k23108 
o|contracted procedure: k23112 
o|contracted procedure: k23121 
o|contracted procedure: k23128 
o|contracted procedure: k23232 
o|contracted procedure: k23134 
o|contracted procedure: k23155 
o|contracted procedure: k23151 
o|contracted procedure: k23228 
o|contracted procedure: k23163 
o|contracted procedure: k23200 
o|contracted procedure: k23185 
o|contracted procedure: k23192 
o|contracted procedure: k23196 
o|contracted procedure: k23224 
o|contracted procedure: k23209 
o|contracted procedure: k23216 
o|contracted procedure: k23220 
o|contracted procedure: k26187 
o|contracted procedure: k26206 
o|contracted procedure: k26209 
o|contracted procedure: k26218 
o|contracted procedure: k26224 
o|contracted procedure: k26230 
o|contracted procedure: k26252 
o|contracted procedure: k26400 
o|contracted procedure: k26410 
o|substituted constant variable: g36112 
o|contracted procedure: k26417 
o|contracted procedure: k26441 
o|contracted procedure: k26425 
o|contracted procedure: k26437 
o|contracted procedure: k26433 
o|contracted procedure: k26429 
o|contracted procedure: k26421 
o|contracted procedure: k2628134332 
o|contracted procedure: k2725934327 
o|contracted procedure: k26496 
o|contracted procedure: k26936 
o|contracted procedure: k26510 
o|contracted procedure: k26525 
o|contracted procedure: k26531 
o|contracted procedure: k26555 
o|contracted procedure: k26570 
o|contracted procedure: k26573 
o|contracted procedure: k26576 
o|contracted procedure: k26588 
o|contracted procedure: k26591 
o|contracted procedure: k26594 
o|contracted procedure: k26602 
o|contracted procedure: k26610 
o|contracted procedure: k26617 
o|contracted procedure: k26623 
o|contracted procedure: k26634 
o|contracted procedure: k26637 
o|contracted procedure: k26640 
o|contracted procedure: k26652 
o|contracted procedure: k26655 
o|contracted procedure: k26658 
o|contracted procedure: k26666 
o|contracted procedure: k26674 
o|contracted procedure: k26681 
o|contracted procedure: k26687 
o|contracted procedure: k26704 
o|contracted procedure: k26707 
o|contracted procedure: k26710 
o|contracted procedure: k26722 
o|contracted procedure: k26725 
o|contracted procedure: k26728 
o|contracted procedure: k26736 
o|contracted procedure: k26744 
o|contracted procedure: k26751 
o|contracted procedure: k26757 
o|contracted procedure: k26451 
o|contracted procedure: k26460 
o|contracted procedure: k26467 
o|contracted procedure: k2627134344 
o|contracted procedure: k26475 
o|contracted procedure: k18387 
o|contracted procedure: k18426 
o|contracted procedure: k18396 
o|contracted procedure: k18420 
o|contracted procedure: k26778 
o|contracted procedure: k26789 
o|contracted procedure: k26792 
o|contracted procedure: k26795 
o|contracted procedure: k26807 
o|contracted procedure: k26810 
o|contracted procedure: k26813 
o|contracted procedure: k26821 
o|contracted procedure: k26829 
o|contracted procedure: k26836 
o|contracted procedure: k26842 
o|contracted procedure: k26857 
o|contracted procedure: k26891 
o|contracted procedure: k2627134360 
o|contracted procedure: k26901 
o|contracted procedure: k2627134366 
o|contracted procedure: k26910 
o|contracted procedure: k26917 
o|contracted procedure: k26920 
o|contracted procedure: k26930 
o|contracted procedure: k26973 
o|contracted procedure: k26979 
o|contracted procedure: k26985 
o|contracted procedure: k26988 
o|contracted procedure: k27047 
o|contracted procedure: k27006 
o|contracted procedure: k27009 
o|contracted procedure: k27023 
o|contracted procedure: k27032 
o|contracted procedure: k27038 
o|contracted procedure: k27084 
o|contracted procedure: k27088 
o|contracted procedure: k27078 
o|contracted procedure: k27062 
o|contracted procedure: k27069 
o|contracted procedure: k27111 
o|contracted procedure: k27132 
o|contracted procedure: k27150 
o|contracted procedure: k27153 
o|contracted procedure: k27249 
o|contracted procedure: k27161 
o|contracted procedure: k27245 
o|contracted procedure: k27166 
o|contracted procedure: k27175 
o|contracted procedure: k27182 
o|contracted procedure: k27187 
o|contracted procedure: k27197 
o|contracted procedure: k27203 
o|contracted procedure: k27210 
o|contracted procedure: k27227 
o|contracted procedure: k27306 
o|contracted procedure: k27319 
o|contracted procedure: k27333 
o|contracted procedure: k27336 
o|contracted procedure: k27457 
o|contracted procedure: k27461 
o|contracted procedure: k27342 
o|contracted procedure: k27351 
o|contracted procedure: k27357 
o|contracted procedure: k27438 
o|contracted procedure: k27368 
o|contracted procedure: k27390 
o|contracted procedure: k27402 
o|contracted procedure: k27270 
o|contracted procedure: k27409 
o|contracted procedure: k27420 
o|contracted procedure: k27282 
o|contracted procedure: k27429 
o|contracted procedure: k27502 
o|contracted procedure: k27505 
o|contracted procedure: k27515 
o|contracted procedure: k27518 
o|contracted procedure: k27598 
o|contracted procedure: k27602 
o|contracted procedure: k27524 
o|contracted procedure: k27535 
o|contracted procedure: k27479 
o|contracted procedure: k27578 
o|contracted procedure: k27470 
o|contracted procedure: k27543 
o|contracted procedure: k27569 
o|contracted procedure: k27550 
o|contracted procedure: k27561 
o|contracted procedure: k27554 
o|contracted procedure: k27558 
o|contracted procedure: k27634 
o|contracted procedure: k2627134389 
o|contracted procedure: k27672 
o|contracted procedure: k27684 
o|contracted procedure: k27688 
o|contracted procedure: k27696 
o|contracted procedure: k27727 
o|contracted procedure: k27746 
o|contracted procedure: k27736 
o|contracted procedure: k27953 
o|contracted procedure: k27761 
o|contracted procedure: k27764 
o|contracted procedure: k27773 
o|contracted procedure: k27776 
o|contracted procedure: k27785 
o|contracted procedure: k27797 
o|contracted procedure: k27809 
o|contracted procedure: k27821 
o|contracted procedure: k27832 
o|contracted procedure: k27878 
o|contracted procedure: k971434397 
o|contracted procedure: k27847 
o|substituted constant variable: g36145 
o|contracted procedure: k27856 
o|contracted procedure: k27863 
o|contracted procedure: k27867 
o|contracted procedure: k27874 
o|contracted procedure: k27889 
o|contracted procedure: k27882 
o|contracted procedure: k27903 
o|contracted procedure: k27896 
o|contracted procedure: k27919 
o|contracted procedure: k27925 
o|contracted procedure: k27932 
o|contracted procedure: k27910 
o|contracted procedure: k27943 
o|contracted procedure: k27937 
o|contracted procedure: k27964 
o|contracted procedure: k27957 
o|contracted procedure: k27992 
o|contracted procedure: k27985 
o|contracted procedure: k28173 
o|contracted procedure: k28004 
o|contracted procedure: k28007 
o|contracted procedure: k28013 
o|contracted procedure: k28019 
o|contracted procedure: k28031 
o|contracted procedure: k28043 
o|contracted procedure: k28055 
o|contracted procedure: k28066 
o|contracted procedure: k28108 
o|contracted procedure: k28081 
o|contracted procedure: k28084 
o|contracted procedure: k28094 
o|contracted procedure: k28104 
o|contracted procedure: k28133 
o|contracted procedure: k971434410 
o|contracted procedure: k28123 
o|substituted constant variable: g36153 
o|contracted procedure: k28137 
o|contracted procedure: k28143 
o|contracted procedure: k28163 
o|contracted procedure: k28151 
o|contracted procedure: k28157 
o|contracted procedure: k28202 
o|contracted procedure: k28195 
o|contracted procedure: k28221 
o|contracted procedure: k28237 
o|contracted procedure: k28251 
o|contracted procedure: k28262 
o|contracted procedure: k28270 
o|contracted procedure: k28281 
o|contracted procedure: k28274 
o|contracted procedure: k28302 
o|contracted procedure: k28313 
o|contracted procedure: k28319 
o|contracted procedure: k28337 
o|contracted procedure: k28347 
o|contracted procedure: k28357 
o|contracted procedure: k28354 
o|contracted procedure: k28374 
o|contracted procedure: k28367 
o|contracted procedure: k28389 
o|contracted procedure: k28396 
o|contracted procedure: k28405 
o|contracted procedure: k28420 
o|contracted procedure: k28429 
o|contracted procedure: k28440 
o|contracted procedure: k28447 
o|contracted procedure: k28456 
o|contracted procedure: k28495 
o|contracted procedure: k28502 
o|contracted procedure: k28464 
o|contracted procedure: k28474 
o|contracted procedure: k28485 
o|contracted procedure: k28508 
o|contracted procedure: k28542 
o|contracted procedure: k28549 
o|contracted procedure: k28511 
o|contracted procedure: k28520 
o|contracted procedure: k28532 
o|contracted procedure: k28552 
o|contracted procedure: k28568 
o|contracted procedure: k28572 
o|contracted procedure: k28564 
o|contracted procedure: k28599 
o|contracted procedure: k28640 
o|contracted procedure: k28633 
o|contracted procedure: k28826 
o|contracted procedure: k28649 
o|contracted procedure: k28702 
o|contracted procedure: k28713 
o|contracted procedure: k28664 
o|contracted procedure: k28681 
o|contracted procedure: k28692 
o|contracted procedure: k28732 
o|contracted procedure: k28796 
o|contracted procedure: k28738 
o|contracted procedure: k28750 
o|contracted procedure: k28757 
o|inlining procedure: k28747 
o|inlining procedure: k28747 
o|contracted procedure: k28772 
o|contracted procedure: k28776 
o|contracted procedure: k28790 
o|contracted procedure: k28799 
o|contracted procedure: k28818 
o|contracted procedure: k28809 
o|contracted procedure: k28837 
o|contracted procedure: k28830 
o|contracted procedure: k28844 
o|contracted procedure: k28880 
o|contracted procedure: k28851 
o|contracted procedure: k28860 
o|contracted procedure: k28877 
o|contracted procedure: k28866 
o|contracted procedure: k28904 
o|contracted procedure: k28910 
o|contracted procedure: k28929 
o|contracted procedure: k28925 
o|contracted procedure: k28938 
o|contracted procedure: k29067 
o|contracted procedure: k29205 
o|contracted procedure: k29073 
o|contracted procedure: k29089 
o|contracted procedure: k29101 
o|substituted constant variable: g36180 
o|contracted procedure: k28971 
o|contracted procedure: k28950 
o|inlining procedure: k29104 
o|inlining procedure: k29104 
o|contracted procedure: k29117 
o|contracted procedure: k29120 
o|contracted procedure: k29133 
o|contracted procedure: k29139 
o|inlining procedure: k29130 
o|inlining procedure: k29130 
o|contracted procedure: k29153 
o|contracted procedure: k29061 
o|contracted procedure: k28980 
o|inlining procedure: k29130 
o|contracted procedure: k28994 
o|contracted procedure: k29017 
o|contracted procedure: k29023 
o|contracted procedure: k29031 
o|contracted procedure: k29039 
o|contracted procedure: k29002 
o|contracted procedure: k29035 
o|contracted procedure: k29051 
o|contracted procedure: k29160 
o|contracted procedure: k29163 
o|contracted procedure: k29169 
o|contracted procedure: k29177 
o|contracted procedure: k29197 
o|contracted procedure: k29189 
o|contracted procedure: k29180 
o|contracted procedure: k29226 
o|contracted procedure: k29237 
o|contracted procedure: k29258 
o|contracted procedure: k29254 
o|contracted procedure: k29270 
o|contracted procedure: k29266 
o|contracted procedure: k29281 
o|contracted procedure: k29306 
o|contracted procedure: k29313 
o|contracted procedure: k29316 
o|contracted procedure: k29329 
o|contracted procedure: k29344 
o|contracted procedure: k29354 
o|contracted procedure: k29358 
o|contracted procedure: k29362 
o|contracted procedure: k29374 
o|contracted procedure: k29384 
o|contracted procedure: k29388 
o|contracted procedure: k29391 
o|contracted procedure: k29408 
o|contracted procedure: k29397 
o|contracted procedure: k29404 
o|contracted procedure: k29416 
o|contracted procedure: k29423 
o|contracted procedure: k29438 
o|contracted procedure: k29448 
o|contracted procedure: k29452 
o|contracted procedure: k29458 
o|contracted procedure: k29470 
o|contracted procedure: k29473 
o|contracted procedure: k29488 
o|contracted procedure: k29498 
o|contracted procedure: k29502 
o|contracted procedure: k29506 
o|contracted procedure: k29512 
o|contracted procedure: k29529 
o|contracted procedure: k29532 
o|contracted procedure: k29547 
o|contracted procedure: k29557 
o|contracted procedure: k29561 
o|contracted procedure: k29565 
o|contracted procedure: k29571 
o|contracted procedure: k29659 
o|contracted procedure: k29585 
o|contracted procedure: k29595 
o|contracted procedure: k29610 
o|contracted procedure: k29620 
o|contracted procedure: k29624 
o|contracted procedure: k29631 
o|contracted procedure: k29637 
o|contracted procedure: k29649 
o|contracted procedure: k29644 
o|contracted procedure: k29665 
o|contracted procedure: k29705 
o|contracted procedure: k29694 
o|contracted procedure: k29711 
o|contracted procedure: k29732 
o|contracted procedure: k29741 
o|contracted procedure: k29764 
o|contracted procedure: k29761 
o|contracted procedure: k29778 
o|contracted procedure: k29788 
o|contracted procedure: k29794 
o|contracted procedure: k29801 
o|contracted procedure: k29814 
o|contracted procedure: k29817 
o|contracted procedure: k29830 
o|contracted procedure: k29845 
o|contracted procedure: k29855 
o|contracted procedure: k29859 
o|contracted procedure: k29862 
o|contracted procedure: k29873 
o|contracted procedure: k29880 
o|contracted procedure: k29901 
o|contracted procedure: k29907 
o|contracted procedure: k29928 
o|contracted procedure: k29934 
o|contracted procedure: k29940 
o|contracted procedure: k29975 
o|contracted procedure: k29981 
o|contracted procedure: k29984 
o|contracted procedure: k29993 
o|contracted procedure: k29996 
o|contracted procedure: k30005 
o|contracted procedure: k30008 
o|contracted procedure: k30041 
o|contracted procedure: k30054 
o|contracted procedure: k30065 
o|contracted procedure: k30074 
o|contracted procedure: k30094 
o|contracted procedure: k30097 
o|contracted procedure: k30104 
o|contracted procedure: k30154 
o|contracted procedure: k30138 
o|contracted procedure: k30150 
o|contracted procedure: k30146 
o|contracted procedure: k30142 
o|contracted procedure: k30122 
o|contracted procedure: k30134 
o|contracted procedure: k30130 
o|contracted procedure: k30126 
o|contracted procedure: k30114 
o|contracted procedure: k30173 
o|contracted procedure: k30169 
o|contracted procedure: k30161 
o|contracted procedure: k30339 
o|contracted procedure: k30202 
o|contracted procedure: k30335 
o|contracted procedure: k30211 
o|contracted procedure: k30237 
o|contracted procedure: k30227 
o|contracted procedure: k30218 
o|contracted procedure: k30251 
o|contracted procedure: k30259 
o|contracted procedure: k30255 
o|contracted procedure: k30303 
o|contracted procedure: k30271 
o|contracted procedure: k30278 
o|contracted procedure: k30286 
o|contracted procedure: k30282 
o|contracted procedure: k30298 
o|contracted procedure: k30313 
o|contracted procedure: k30329 
o|contracted procedure: k30319 
o|contracted procedure: k30984 
o|contracted procedure: k31032 
o|contracted procedure: k31035 
o|simplifications: ((if . 14) (let . 674)) 
o|replaced variables: 210 
o|removed binding forms: 2714 
o|inlining procedure: "(irregex-core.scm:243) chicken.irregex#%irregex-match-end-index" 
o|inlining procedure: "(irregex-core.scm:311) chicken.irregex#%irregex-match-end-index" 
o|inlining procedure: "(irregex-core.scm:323) chicken.irregex#%irregex-match-end-index" 
(o x)|known list op on rest arg sublist: ##core#rest-car o931 0 
(o x)|known list op on rest arg sublist: ##core#rest-cdr o931 0 
(o x)|known list op on rest arg sublist: ##core#rest-car o1045 0 
o|contracted procedure: k9901 
o|inlining procedure: "(irregex-core.scm:764) chicken.irregex#char-altcase" 
o|contracted procedure: k10856 
o|contracted procedure: k13403 
o|contracted procedure: k13630 
o|inlining procedure: k8777 
o|inlining procedure: k8777 
o|inlining procedure: k8777 
o|inlining procedure: "(irregex-core.scm:3461) chicken.irregex#%irregex-match-end-index" 
o|inlining procedure: "(irregex-core.scm:3535) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3538) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3531) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3533) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3567) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3569) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3563) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3565) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3582) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3583) chicken.irregex#char-alphanumeric?" 
o|inlining procedure: "(irregex-core.scm:3581) chicken.irregex#char-alphanumeric?" 
o|contracted procedure: k17348 
o|substituted constant variable: r1740736306 
o|inlining procedure: k17019 
o|inlining procedure: k19334 
o|inlining procedure: "(irregex-core.scm:2081) chicken.irregex#%irregex-match-end-index" 
o|inlining procedure: "(irregex-core.scm:2101) chicken.irregex#%irregex-match-end-index" 
o|contracted procedure: k19841 
o|inlining procedure: "(irregex-core.scm:2493) chicken.irregex#char-altcase" 
o|inlining procedure: "(irregex-core.scm:2767) chicken.irregex#mst-state-mappings-set!" 
o|inlining procedure: k26300 
o|inlining procedure: k26300 
o|contracted procedure: k22770 
o|inlining procedure: "(irregex-core.scm:2806) chicken.irregex#mst-state-mappings-set!" 
o|inlining procedure: "(irregex-core.scm:2788) chicken.irregex#mst-state-mappings-set!" 
o|inlining procedure: "(irregex-core.scm:2788) chicken.irregex#mst-state-mappings-set!" 
o|inlining procedure: "(irregex-core.scm:3887) chicken.irregex#char-altcase" 
o|inlining procedure: "(irregex-core.scm:3886) chicken.irregex#char-altcase" 
o|inlining procedure: "(irregex-core.scm:3924) chicken.irregex#%irregex-match-end-index" 
o|inlining procedure: "(irregex-core.scm:3958) chicken.irregex#%irregex-match-end-index" 
o|inlining procedure: "(irregex-core.scm:3980) chicken.irregex#%irregex-match-end-index" 
o|inlining procedure: "(irregex-core.scm:4026) chicken.irregex#%irregex-match-end-index" 
(o x)|known list op on rest arg sublist: ##core#rest-car o5917 0 
o|inlining procedure: k29149 
o|simplifications: ((if . 3) (let . 6)) 
o|replaced variables: 7 
o|removed binding forms: 270 
o|removed side-effect free assignment to unused variable: chicken.irregex#%irregex-match-end-index 
o|removed side-effect free assignment to unused variable: chicken.irregex#char-alphanumeric? 
o|contracted procedure: k10644 
o|removed side-effect free assignment to unused variable: chicken.irregex#char-altcase 
o|substituted constant variable: r877836576 
o|substituted constant variable: n74936663 
o|substituted constant variable: n74936668 
o|removed side-effect free assignment to unused variable: chicken.irregex#mst-state-mappings-set! 
o|substituted constant variable: r2630136711 
o|contracted procedure: k22444 
o|substituted constant variable: n74936790 
o|contracted procedure: k28075 
o|substituted constant variable: n74936797 
o|substituted constant variable: n74936804 
o|substituted constant variable: n74936809 
o|simplifications: ((if . 2) (let . 9)) 
o|replaced variables: 74 
o|removed binding forms: 14 
o|removed conditional forms: 1 
o|inlining procedure: k8284 
o|inlining procedure: k8374 
o|inlining procedure: k10503 
o|inlining procedure: k25591 
o|inlining procedure: k25615 
o|inlining procedure: k25789 
o|inlining procedure: k25809 
o|inlining procedure: k25854 
o|inlining procedure: k19574 
o|inlining procedure: k27680 
o|inlining procedure: k28266 
o|inlining procedure: k28528 
o|removed binding forms: 76 
o|contracted procedure: k25080 
o|contracted procedure: k25844 
o|contracted procedure: k19462 
o|contracted procedure: k20871 
o|contracted procedure: k21955 
o|contracted procedure: k22117 
o|contracted procedure: k27676 
o|contracted procedure: k27835 
o|contracted procedure: k28069 
o|simplifications: ((let . 5)) 
o|removed binding forms: 21 
o|direct leaf routine/allocation: lp1131 0 
o|direct leaf routine/allocation: lp1179 0 
o|direct leaf routine/allocation: cased-char1457 9 
o|direct leaf routine/allocation: join1643 0 
o|direct leaf routine/allocation: new-res1644 6 
o|direct leaf routine/allocation: g18841885 6 
o|direct leaf routine/allocation: byte1955 0 
o|direct leaf routine/allocation: chicken.irregex#sre-repeater? 0 
o|direct leaf routine/allocation: chicken.irregex#sre-sequence 3 
o|direct leaf routine/allocation: chicken.irregex#sre-alternate 3 
o|direct leaf routine/allocation: g35143521 20 
o|direct leaf routine/allocation: g36693687 3 
o|direct leaf routine/allocation: g35853592 3 
o|direct leaf routine/allocation: chicken.irregex#nfa-get-epsilons 0 
o|direct leaf routine/allocation: g40874094 3 
o|direct leaf routine/allocation: doloop41874188 0 
o|direct leaf routine/allocation: chicken.irregex#char-ranges-union 6 
o|contracted procedure: k9139 
o|converted assignments to bindings: (lp1131) 
o|converted assignments to bindings: (lp1179) 
o|contracted procedure: "(irregex-core.scm:768) k10558" 
o|contracted procedure: "(irregex-core.scm:816) k10688" 
o|contracted procedure: "(irregex-core.scm:819) k10697" 
o|contracted procedure: "(irregex-core.scm:834) k10740" 
o|contracted procedure: "(irregex-core.scm:837) k10754" 
o|contracted procedure: "(irregex-core.scm:838) k10758" 
o|contracted procedure: "(irregex-core.scm:884) k11136" 
o|contracted procedure: "(irregex-core.scm:988) k11773" 
o|contracted procedure: "(irregex-core.scm:990) k11789" 
o|contracted procedure: "(irregex-core.scm:992) k11805" 
o|contracted procedure: "(irregex-core.scm:995) k11824" 
o|contracted procedure: "(irregex-core.scm:1000) k11865" 
o|contracted procedure: "(irregex-core.scm:1003) k11888" 
o|inlining procedure: "(irregex-core.scm:1257) k13536" 
o|contracted procedure: "(irregex-core.scm:1368) k14087" 
o|contracted procedure: "(irregex-core.scm:1369) k14075" 
o|contracted procedure: "(irregex-core.scm:1372) k14140" 
o|contracted procedure: "(irregex-core.scm:1373) k14128" 
o|contracted procedure: "(irregex-core.scm:1374) k14116" 
o|contracted procedure: "(irregex-core.scm:1377) k14209" 
o|contracted procedure: "(irregex-core.scm:1378) k14197" 
o|contracted procedure: "(irregex-core.scm:1379) k14185" 
o|contracted procedure: "(irregex-core.scm:1380) k14173" 
o|contracted procedure: "(irregex-core.scm:1449) k14644" 
o|contracted procedure: "(irregex-core.scm:1461) k14772" 
o|contracted procedure: "(irregex-core.scm:1468) k14806" 
o|contracted procedure: "(irregex-core.scm:1477) k14911" 
o|contracted procedure: "(irregex-core.scm:1484) k14945" 
o|contracted procedure: "(irregex-core.scm:1492) k14503" 
o|inlining procedure: "(irregex-core.scm:1425) k15543" 
o|contracted procedure: "(irregex-core.scm:1495) k15301" 
o|contracted procedure: "(irregex-core.scm:1512) k15163" 
o|contracted procedure: "(irregex-core.scm:1525) k14588" 
o|contracted procedure: "(irregex-core.scm:3163) k23563" 
o|contracted procedure: "(irregex-core.scm:3172) k23602" 
o|contracted procedure: "(irregex-core.scm:3177) k23621" 
o|contracted procedure: "(irregex-core.scm:3182) k23640" 
o|contracted procedure: "(irregex-core.scm:3184) k23659" 
o|contracted procedure: "(irregex-core.scm:3190) k23710" 
o|contracted procedure: "(irregex-core.scm:3196) k23756" 
o|contracted procedure: "(irregex-core.scm:3201) k23782" 
o|contracted procedure: "(irregex-core.scm:3210) k23821" 
o|contracted procedure: "(irregex-core.scm:3207) k23827" 
o|contracted procedure: "(irregex-core.scm:3222) k23863" 
o|contracted procedure: "(irregex-core.scm:3217) k23881" 
o|contracted procedure: "(irregex-core.scm:3241) k23906" 
o|contracted procedure: "(irregex-core.scm:3236) k23924" 
o|contracted procedure: "(irregex-core.scm:3265) k24013" 
o|contracted procedure: "(irregex-core.scm:3299) k24165" 
o|contracted procedure: "(irregex-core.scm:3332) k24404" 
o|contracted procedure: "(irregex-core.scm:3342) k24439" 
o|contracted procedure: "(irregex-core.scm:3352) k24517" 
o|contracted procedure: "(irregex-core.scm:3369) k24560" 
o|contracted procedure: "(irregex-core.scm:3451) k24923" 
o|contracted procedure: "(irregex-core.scm:3454) k25050" 
o|contracted procedure: "(irregex-core.scm:3633) k26148" 
o|contracted procedure: "(irregex-core.scm:1792) k17479" 
o|contracted procedure: "(irregex-core.scm:1816) k17665" 
o|contracted procedure: "(irregex-core.scm:1827) k17704" 
o|contracted procedure: "(irregex-core.scm:1831) k17751" 
o|contracted procedure: "(irregex-core.scm:1835) k17825" 
o|contracted procedure: "(irregex-core.scm:1839) k17853" 
o|contracted procedure: "(irregex-core.scm:1552) k15622" 
o|contracted procedure: "(irregex-core.scm:1553) k15637" 
o|contracted procedure: "(irregex-core.scm:1568) k15811" 
o|contracted procedure: "(irregex-core.scm:1694) k16749" 
o|contracted procedure: "(irregex-core.scm:1705) k16866" 
o|contracted procedure: "(irregex-core.scm:1894) k18273" 
o|contracted procedure: "(irregex-core.scm:1895) k18291" 
o|contracted procedure: "(irregex-core.scm:1896) k18308" 
o|contracted procedure: "(irregex-core.scm:1916) k18454" 
o|contracted procedure: "(irregex-core.scm:1918) k18476" 
o|contracted procedure: "(irregex-core.scm:1922) k18509" 
o|contracted procedure: "(irregex-core.scm:2159) k19896" 
o|contracted procedure: "(irregex-core.scm:2243) k20303" 
o|contracted procedure: "(irregex-core.scm:2195) k20477" 
o|contracted procedure: "(irregex-core.scm:2428) k20630" 
o|contracted procedure: "(irregex-core.scm:2567) k21266" 
o|contracted procedure: "(irregex-core.scm:2640) k21419" 
o|contracted procedure: "(irregex-core.scm:2653) k21497" 
o|contracted procedure: "(irregex-core.scm:2769) k22017" 
o|contracted procedure: "(irregex-core.scm:3020) k22965" 
o|contracted procedure: k22344 
o|converted assignments to bindings: (doloop41874188) 
o|contracted procedure: "(irregex-core.scm:3739) k26849" 
o|contracted procedure: "(irregex-core.scm:3741) k26864" 
o|contracted procedure: "(irregex-core.scm:3802) k27216" 
o|contracted procedure: "(irregex-core.scm:3806) k27231" 
o|simplifications: ((if . 1) (let . 3)) 
o|removed binding forms: 86 
o|contracted procedure: "(irregex-core.scm:1794) k17507" 
o|replaced variables: 10 
o|removed binding forms: 1 
o|simplifications: ((if . 6)) 
o|removed binding forms: 10 
o|contracted procedure: k24027 
o|contracted procedure: k24068 
o|contracted procedure: k24201 
o|contracted procedure: k24227 
o|removed binding forms: 4 
o|direct leaf routine/allocation: shift1522 6 
o|direct leaf routine/allocation: chicken.irregex#nfa-add-epsilon! 6 
o|contracted procedure: "(irregex-core.scm:819) k10793" 
o|contracted procedure: "(irregex-core.scm:841) k10808" 
o|contracted procedure: "(irregex-core.scm:2505) k20926" 
o|contracted procedure: "(irregex-core.scm:2579) k21224" 
o|contracted procedure: "(irregex-core.scm:2580) k21227" 
o|contracted procedure: "(irregex-core.scm:2589) k21294" 
o|contracted procedure: "(irregex-core.scm:2604) k21334" 
o|inlining procedure: "(irregex-core.scm:2606) k21331" 
o|contracted procedure: "(irregex-core.scm:2644) k21397" 
o|contracted procedure: "(irregex-core.scm:2645) k21394" 
o|contracted procedure: "(irregex-core.scm:2657) k21475" 
o|contracted procedure: "(irregex-core.scm:2658) k21472" 
o|removed binding forms: 11 
o|contracted procedure: "(irregex-core.scm:2606) k21331" 
o|removed binding forms: 1 
o|customizable procedures: (k30244 loop26293 loop6278 k29574 k29735 for-each-loop62306240 k29744 k29671 chicken.irregex#cset->string k29588 for-each-loop61756185 g61346141 for-each-loop61336145 for-each-loop61126122 for-each-loop60936103 k29322 for-each-loop60766086 lp6034 for-each-loop60576067 lp6016 lp15983 k29020 map-loop59575975 lp25986 loop5928 scan5919 k28652 k28723 lp5696 g56585659 lp5621 chicken.irregex#irregex-apply-match lp5558 chicken.irregex#irregex-copy-matches k27767 k27770 chicken.irregex#irregex-reset-matches! lp5504 k27647 lp5471 intersect5452 k27376 k27379 k27386 diff5423 union-range5398 lp5379 map-loop53315348 lp3090 lp5222 map-loop53045321 map-loop52765293 rec5240 map-loop52505267 lp5233 lp5216 k23137 lp24373 lp4370 k23026 g43424343 k23002 lp4134 k22114 k22120 lp24328 lp4322 chicken.irregex#mst-fold g43074308 chicken.irregex#cset-difference chicken.irregex#mst-copy k22844 lp4295 chicken.irregex#nfa-state->mst chicken.irregex#nfa-epsilon-closure lp4163 k23259 lp34404 lp24400 lp4398 k22498 chicken.irregex#tag-set-commands-for-closure lp24220 lp4209 lp4239 g42584267 map-loop42524274 doloop42444245 k22639 lp4175 k21952 for-each-loop40864105 chicken.irregex#make-mst chicken.irregex#mst-add! k21761 lp3844 doloop40294030 k21119 k21166 g40194020 chicken.irregex#string->cset add-char-state!3878 lp23910 lp3870 extend-state!3877 new-state-number3875 add-state!3876 doloop38833884 k20793 doloop35443545 k19982 for-each-loop35843596 k20371 k20329 for-each-loop36683692 g37083717 map-loop37023724 for-each-loop36783731 lp23610 k20020 chicken.irregex#finalize! lp13601 for-each-loop35133534 k19538 lp3419 k19325 lp3335 lp13470 chicken.irregex#find chicken.irregex#cset-contains? lp23477 lp23301 lp13297 chicken.irregex#dfa-match/longest chicken.irregex#irregex-new-matches chicken.irregex#irregex-search/matches k18943 k18763 map-loop32053222 k18530 chicken.irregex#sre-sequence-names map-loop30643081 k17025 k16877 k16760 k16647 k16507 k16334 k16377 chicken.irregex#every k15984 map-loop25042521 k15770 map-loop24702487 rec2364 map-loop24442461 chicken.irregex#any chicken.irregex#cset->utf8-pattern g24072416 map-loop24012419 g23802389 map-loop23742392 adjust2356 g26142615 chicken.irregex#sre->nfa g26252626 chicken.irregex#nfa->dfa k17147 k17176 k17500 k17880 k17920 g30273028 k17899 k17685 k17688 k17558 k17364 lp22897 lp22885 lp2845 grow2855 chicken.irregex#sre-names lp5129 lp5105 k25829 chicken.irregex#chunker-next-char k25743 k25734 k25669 k25636 k25538 k25529 chicken.irregex#chunker-prev-char k23498 k24733 lp4844 k24589 k24149 k24152 k23997 k24000 chicken.irregex#sre-count-submatches rec4438 chicken.irregex#sre-cset->procedure lp4429 chicken.irregex#cset->plist k15528 chicken.irregex#char->utf8-list map-loop23152336 chicken.irregex#unicode-range-up-from lp2033 map-loop21842205 g22202229 map-loop22142265 map-loop22772298 chicken.irregex#utf8-lowest-digit-of-length k15066 chicken.irregex#zero-to map-loop22372258 chicken.irregex#unicode-range-up-to lp2345 map-loop21482165 map-loop21132130 map-loop20512068 map-loop20772098 chicken.irregex#unicode-range-helper scan1059 chicken.irregex#symbol-list->flags scan1071 lp21773 k12699 k12049 lp1082 collect1090 k12092 k13922 k13805 k13692 chicken.irregex#sre->cset k13481 k13558 k13570 chicken.irregex#string-parse-hex-escape chicken.irregex#cset-case-insensitive chicken.irregex#cset-complement go1850 lp21635 chicken.irregex#with-read-from-string k11256 save1462 collect/single1460 k10993 lp1451 collect/terms1461 collect1459 chicken.irregex#last k10666 k10669 lp1514 lp1977 chicken.irregex#utf8-string-ref k10603 cased-string1458 map-loop14711488 k10371 k10360 lp1416 k10254 scan1386 scan1349 collect1353 k9968 skip1331 lp1317 read1304 lp1208 lp1199 lp1186 lp1160 lp1153 chicken.irregex#fold scan1047 lp983 k8416 loop955 chicken.irregex#string-cat-reverse lp866 k8026 chicken.irregex#irregex-match-numeric-index chicken.irregex#vector-copy) 
o|calls to known targets: 1144 
o|identified direct recursive calls: f_8072 2 
o|identified direct recursive calls: f_8836 1 
o|identified direct recursive calls: f_9143 1 
o|identified direct recursive calls: f_9180 1 
o|identified direct recursive calls: f_9277 1 
o|identified direct recursive calls: f_9893 1 
o|identified direct recursive calls: f_10027 1 
o|identified direct recursive calls: f_9752 4 
o|identified direct recursive calls: f_10535 1 
o|identified direct recursive calls: f_14230 1 
o|identified direct recursive calls: f_10679 2 
o|identified direct recursive calls: f_11715 5 
o|identified direct recursive calls: f_8974 1 
o|identified direct recursive calls: f_12781 2 
o|identified direct recursive calls: f_8936 1 
o|identified direct recursive calls: f_10488 3 
o|identified direct recursive calls: f_8879 1 
o|identified direct recursive calls: f_14686 1 
o|identified direct recursive calls: f_14722 1 
o|identified direct recursive calls: f_14843 1 
o|identified direct recursive calls: f_14982 1 
o|identified direct recursive calls: f_15088 1 
o|identified direct recursive calls: f_15191 1 
o|identified direct recursive calls: f_15329 1 
o|identified direct recursive calls: f_15420 1 
o|identified direct recursive calls: f_14514 1 
o|identified direct recursive calls: f_17106 1 
o|identified direct recursive calls: f_16001 1 
o|identified direct recursive calls: f_15597 2 
o|identified direct recursive calls: f_16587 1 
o|identified direct recursive calls: f_18249 3 
o|identified direct recursive calls: f_18430 3 
o|identified direct recursive calls: f_19888 1 
o|identified direct recursive calls: f_20295 1 
o|identified direct recursive calls: f_20469 1 
o|identified direct recursive calls: f_20816 1 
o|identified direct recursive calls: f_20778 4 
o|identified direct recursive calls: f_21689 1 
o|identified direct recursive calls: f_21728 1 
o|identified direct recursive calls: f_22009 1 
o|identified direct recursive calls: f_22308 1 
o|identified direct recursive calls: f_22714 1 
o|identified direct recursive calls: f_23302 2 
o|identified direct recursive calls: f_22246 1 
o|identified direct recursive calls: f_22413 1 
o|identified direct recursive calls: f_22175 1 
o|identified direct recursive calls: f_22357 1 
o|identified direct recursive calls: f_22971 1 
o|identified direct recursive calls: f_26405 1 
o|identified direct recursive calls: f_18382 1 
o|identified direct recursive calls: f_26514 2 
o|identified direct recursive calls: f_27004 2 
o|identified direct recursive calls: f_27106 4 
o|identified direct recursive calls: f_27301 3 
o|identified direct recursive calls: f_27497 3 
o|identified direct recursive calls: f_28384 1 
o|identified direct recursive calls: f_28727 2 
o|identified direct recursive calls: f_28855 1 
o|identified direct recursive calls: f_29096 2 
o|identified direct recursive calls: f_29084 1 
o|identified direct recursive calls: f_30089 4 
o|fast box initializations: 141 
o|fast global references: 362 
o|fast global assignments: 77 
o|dropping unused closure argument: f_10338 
o|dropping unused closure argument: f_13301 
o|dropping unused closure argument: f_14035 
o|dropping unused closure argument: f_14268 
o|dropping unused closure argument: f_14344 
o|dropping unused closure argument: f_14620 
o|dropping unused closure argument: f_14758 
o|dropping unused closure argument: f_14897 
o|dropping unused closure argument: f_15475 
o|dropping unused closure argument: f_16587 
o|dropping unused closure argument: f_16994 
o|dropping unused closure argument: f_18203 
o|dropping unused closure argument: f_18226 
o|dropping unused closure argument: f_18430 
o|dropping unused closure argument: f_18716 
o|dropping unused closure argument: f_19065 
o|dropping unused closure argument: f_19828 
o|dropping unused closure argument: f_19947 
o|dropping unused closure argument: f_20594 
o|dropping unused closure argument: f_20628 
o|dropping unused closure argument: f_20769 
o|dropping unused closure argument: f_21892 
o|dropping unused closure argument: f_21921 
o|dropping unused closure argument: f_21938 
o|dropping unused closure argument: f_21947 
o|dropping unused closure argument: f_22299 
o|dropping unused closure argument: f_22381 
o|dropping unused closure argument: f_23066 
o|dropping unused closure argument: f_23081 
o|dropping unused closure argument: f_26180 
o|dropping unused closure argument: f_26393 
o|dropping unused closure argument: f_26484 
o|dropping unused closure argument: f_26504 
o|dropping unused closure argument: f_26971 
o|dropping unused closure argument: f_27056 
o|dropping unused closure argument: f_27287 
o|dropping unused closure argument: f_27609 
o|dropping unused closure argument: f_27619 
o|dropping unused closure argument: f_28378 
o|dropping unused closure argument: f_29209 
o|dropping unused closure argument: f_7546 
o|dropping unused closure argument: f_7628 
o|dropping unused closure argument: f_7651 
o|dropping unused closure argument: f_7660 
o|dropping unused closure argument: f_7960 
o|dropping unused closure argument: f_8646 
o|dropping unused closure argument: f_8676 
o|dropping unused closure argument: f_9114 
o|dropping unused closure argument: f_9164 
o|dropping unused closure argument: f_9201 
o|dropping unused closure argument: f_9262 
o|dropping unused closure argument: f_9277 
o|dropping unused closure argument: f_9300 
o|dropping unused closure argument: f_9343 
o|dropping unused closure argument: f_9388 
o|dropping unused closure argument: f_9745 
*/
/* end of file */
