/* Generated from scrutinizer.scm by the CHICKEN compiler
   http://www.call-cc.org
   Version 5.4.0rc1 (prerelease) (rev bc191a47)
   linux-unix-gnu-x86-64 [ 64bit dload ptables ]
   command line: scrutinizer.scm -optimize-level 2 -include-path . -include-path ./ -inline -ignore-repository -feature chicken-bootstrap -no-warnings -specialize -consult-types-file ./types.db -no-lambda-info -no-trace -emit-import-library chicken.compiler.scrutinizer -output-file scrutinizer.c
   unit: scrutinizer
   uses: eval expand port data-structures pathname internal extras support library
*/
#include "chicken.h"

static C_PTABLE_ENTRY *create_ptable(void);
C_noret_decl(C_eval_toplevel)
C_externimport void C_ccall C_eval_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_expand_toplevel)
C_externimport void C_ccall C_expand_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_port_toplevel)
C_externimport void C_ccall C_port_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_data_2dstructures_toplevel)
C_externimport void C_ccall C_data_2dstructures_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_pathname_toplevel)
C_externimport void C_ccall C_pathname_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_internal_toplevel)
C_externimport void C_ccall C_internal_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_extras_toplevel)
C_externimport void C_ccall C_extras_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_support_toplevel)
C_externimport void C_ccall C_support_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_library_toplevel)
C_externimport void C_ccall C_library_toplevel(C_word c,C_word *av) C_noret;

static C_TLS C_word lf[661];
static double C_possibly_force_alignment;


C_noret_decl(f26096)
static void C_ccall f26096(C_word c,C_word *av) C_noret;
C_noret_decl(f26203)
static void C_ccall f26203(C_word c,C_word *av) C_noret;
C_noret_decl(f26218)
static void C_ccall f26218(C_word c,C_word *av) C_noret;
C_noret_decl(f26225)
static void C_ccall f26225(C_word c,C_word *av) C_noret;
C_noret_decl(f26473)
static void C_ccall f26473(C_word c,C_word *av) C_noret;
C_noret_decl(f26621)
static void C_ccall f26621(C_word c,C_word *av) C_noret;
C_noret_decl(f26686)
static void C_ccall f26686(C_word c,C_word *av) C_noret;
C_noret_decl(f26693)
static void C_ccall f26693(C_word c,C_word *av) C_noret;
C_noret_decl(f26845)
static void C_ccall f26845(C_word c,C_word *av) C_noret;
C_noret_decl(f26850)
static void C_ccall f26850(C_word c,C_word *av) C_noret;
C_noret_decl(f26859)
static void C_ccall f26859(C_word c,C_word *av) C_noret;
C_noret_decl(f26866)
static void C_ccall f26866(C_word c,C_word *av) C_noret;
C_noret_decl(f26905)
static void C_ccall f26905(C_word c,C_word *av) C_noret;
C_noret_decl(f26910)
static void C_ccall f26910(C_word c,C_word *av) C_noret;
C_noret_decl(f26915)
static void C_ccall f26915(C_word c,C_word *av) C_noret;
C_noret_decl(f26922)
static void C_ccall f26922(C_word c,C_word *av) C_noret;
C_noret_decl(f26929)
static void C_ccall f26929(C_word c,C_word *av) C_noret;
C_noret_decl(f26936)
static void C_ccall f26936(C_word c,C_word *av) C_noret;
C_noret_decl(f26943)
static void C_ccall f26943(C_word c,C_word *av) C_noret;
C_noret_decl(f28250)
static void C_ccall f28250(C_word c,C_word *av) C_noret;
C_noret_decl(f28255)
static void C_ccall f28255(C_word c,C_word *av) C_noret;
C_noret_decl(f28274)
static void C_ccall f28274(C_word c,C_word *av) C_noret;
C_noret_decl(f28508)
static void C_ccall f28508(C_word c,C_word *av) C_noret;
C_noret_decl(f28513)
static void C_ccall f28513(C_word c,C_word *av) C_noret;
C_noret_decl(f28518)
static void C_ccall f28518(C_word c,C_word *av) C_noret;
C_noret_decl(f_10005)
static void C_fcall f_10005(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_10023)
static void C_ccall f_10023(C_word c,C_word *av) C_noret;
C_noret_decl(f_10032)
static void C_ccall f_10032(C_word c,C_word *av) C_noret;
C_noret_decl(f_10035)
static void C_fcall f_10035(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10051)
static void C_fcall f_10051(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10060)
static void C_ccall f_10060(C_word c,C_word *av) C_noret;
C_noret_decl(f_10068)
static void C_ccall f_10068(C_word c,C_word *av) C_noret;
C_noret_decl(f_10078)
static void C_ccall f_10078(C_word c,C_word *av) C_noret;
C_noret_decl(f_10082)
static void C_ccall f_10082(C_word c,C_word *av) C_noret;
C_noret_decl(f_10086)
static void C_ccall f_10086(C_word c,C_word *av) C_noret;
C_noret_decl(f_10088)
static void C_ccall f_10088(C_word c,C_word *av) C_noret;
C_noret_decl(f_10110)
static void C_ccall f_10110(C_word c,C_word *av) C_noret;
C_noret_decl(f_10117)
static void C_ccall f_10117(C_word c,C_word *av) C_noret;
C_noret_decl(f_10120)
static void C_ccall f_10120(C_word c,C_word *av) C_noret;
C_noret_decl(f_10123)
static void C_ccall f_10123(C_word c,C_word *av) C_noret;
C_noret_decl(f_10131)
static void C_ccall f_10131(C_word c,C_word *av) C_noret;
C_noret_decl(f_10140)
static void C_ccall f_10140(C_word c,C_word *av) C_noret;
C_noret_decl(f_10147)
static void C_ccall f_10147(C_word c,C_word *av) C_noret;
C_noret_decl(f_10154)
static void C_ccall f_10154(C_word c,C_word *av) C_noret;
C_noret_decl(f_10162)
static void C_ccall f_10162(C_word c,C_word *av) C_noret;
C_noret_decl(f_10164)
static void C_fcall f_10164(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_10172)
static void C_fcall f_10172(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10176)
static void C_fcall f_10176(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10188)
static void C_ccall f_10188(C_word c,C_word *av) C_noret;
C_noret_decl(f_10223)
static void C_ccall f_10223(C_word c,C_word *av) C_noret;
C_noret_decl(f_10245)
static void C_ccall f_10245(C_word c,C_word *av) C_noret;
C_noret_decl(f_10257)
static void C_fcall f_10257(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10270)
static void C_ccall f_10270(C_word c,C_word *av) C_noret;
C_noret_decl(f_10292)
static void C_ccall f_10292(C_word c,C_word *av) C_noret;
C_noret_decl(f_10301)
static void C_ccall f_10301(C_word c,C_word *av) C_noret;
C_noret_decl(f_10303)
static void C_fcall f_10303(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10374)
static void C_ccall f_10374(C_word c,C_word *av) C_noret;
C_noret_decl(f_10377)
static void C_ccall f_10377(C_word c,C_word *av) C_noret;
C_noret_decl(f_10380)
static void C_ccall f_10380(C_word c,C_word *av) C_noret;
C_noret_decl(f_10386)
static void C_ccall f_10386(C_word c,C_word *av) C_noret;
C_noret_decl(f_10389)
static void C_ccall f_10389(C_word c,C_word *av) C_noret;
C_noret_decl(f_10392)
static void C_ccall f_10392(C_word c,C_word *av) C_noret;
C_noret_decl(f_10398)
static void C_ccall f_10398(C_word c,C_word *av) C_noret;
C_noret_decl(f_10412)
static void C_fcall f_10412(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10420)
static void C_fcall f_10420(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10454)
static void C_ccall f_10454(C_word c,C_word *av) C_noret;
C_noret_decl(f_10503)
static void C_ccall f_10503(C_word c,C_word *av) C_noret;
C_noret_decl(f_10518)
static void C_fcall f_10518(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10521)
static void C_ccall f_10521(C_word c,C_word *av) C_noret;
C_noret_decl(f_10524)
static void C_ccall f_10524(C_word c,C_word *av) C_noret;
C_noret_decl(f_10533)
static void C_fcall f_10533(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10539)
static void C_ccall f_10539(C_word c,C_word *av) C_noret;
C_noret_decl(f_10545)
static void C_ccall f_10545(C_word c,C_word *av) C_noret;
C_noret_decl(f_10548)
static void C_ccall f_10548(C_word c,C_word *av) C_noret;
C_noret_decl(f_10555)
static void C_ccall f_10555(C_word c,C_word *av) C_noret;
C_noret_decl(f_10561)
static void C_ccall f_10561(C_word c,C_word *av) C_noret;
C_noret_decl(f_10564)
static void C_ccall f_10564(C_word c,C_word *av) C_noret;
C_noret_decl(f_10567)
static void C_ccall f_10567(C_word c,C_word *av) C_noret;
C_noret_decl(f_10570)
static void C_ccall f_10570(C_word c,C_word *av) C_noret;
C_noret_decl(f_10573)
static void C_ccall f_10573(C_word c,C_word *av) C_noret;
C_noret_decl(f_10576)
static void C_ccall f_10576(C_word c,C_word *av) C_noret;
C_noret_decl(f_10584)
static void C_ccall f_10584(C_word c,C_word *av) C_noret;
C_noret_decl(f_10604)
static void C_ccall f_10604(C_word c,C_word *av) C_noret;
C_noret_decl(f_10608)
static void C_ccall f_10608(C_word c,C_word *av) C_noret;
C_noret_decl(f_10637)
static void C_ccall f_10637(C_word c,C_word *av) C_noret;
C_noret_decl(f_10644)
static void C_fcall f_10644(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10647)
static void C_fcall f_10647(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10667)
static void C_fcall f_10667(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10674)
static void C_ccall f_10674(C_word c,C_word *av) C_noret;
C_noret_decl(f_10696)
static void C_ccall f_10696(C_word c,C_word *av) C_noret;
C_noret_decl(f_10700)
static void C_ccall f_10700(C_word c,C_word *av) C_noret;
C_noret_decl(f_10707)
static void C_ccall f_10707(C_word c,C_word *av) C_noret;
C_noret_decl(f_10709)
static void C_ccall f_10709(C_word c,C_word *av) C_noret;
C_noret_decl(f_10736)
static void C_ccall f_10736(C_word c,C_word *av) C_noret;
C_noret_decl(f_10743)
static void C_fcall f_10743(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10759)
static void C_ccall f_10759(C_word c,C_word *av) C_noret;
C_noret_decl(f_10763)
static void C_ccall f_10763(C_word c,C_word *av) C_noret;
C_noret_decl(f_10765)
static void C_ccall f_10765(C_word c,C_word *av) C_noret;
C_noret_decl(f_10772)
static void C_ccall f_10772(C_word c,C_word *av) C_noret;
C_noret_decl(f_10778)
static void C_ccall f_10778(C_word c,C_word *av) C_noret;
C_noret_decl(f_10784)
static void C_ccall f_10784(C_word c,C_word *av) C_noret;
C_noret_decl(f_10787)
static void C_ccall f_10787(C_word c,C_word *av) C_noret;
C_noret_decl(f_10790)
static void C_ccall f_10790(C_word c,C_word *av) C_noret;
C_noret_decl(f_10793)
static void C_ccall f_10793(C_word c,C_word *av) C_noret;
C_noret_decl(f_10798)
static void C_ccall f_10798(C_word c,C_word *av) C_noret;
C_noret_decl(f_10804)
static void C_ccall f_10804(C_word c,C_word *av) C_noret;
C_noret_decl(f_10807)
static void C_fcall f_10807(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10814)
static void C_fcall f_10814(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10817)
static void C_ccall f_10817(C_word c,C_word *av) C_noret;
C_noret_decl(f_10842)
static void C_ccall f_10842(C_word c,C_word *av) C_noret;
C_noret_decl(f_10846)
static void C_ccall f_10846(C_word c,C_word *av) C_noret;
C_noret_decl(f_10852)
static void C_ccall f_10852(C_word c,C_word *av) C_noret;
C_noret_decl(f_10855)
static void C_ccall f_10855(C_word c,C_word *av) C_noret;
C_noret_decl(f_10865)
static void C_fcall f_10865(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10877)
static void C_fcall f_10877(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10902)
static void C_ccall f_10902(C_word c,C_word *av) C_noret;
C_noret_decl(f_10919)
static void C_fcall f_10919(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10932)
static void C_ccall f_10932(C_word c,C_word *av) C_noret;
C_noret_decl(f_10935)
static void C_ccall f_10935(C_word c,C_word *av) C_noret;
C_noret_decl(f_10938)
static void C_ccall f_10938(C_word c,C_word *av) C_noret;
C_noret_decl(f_10944)
static void C_fcall f_10944(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10950)
static void C_ccall f_10950(C_word c,C_word *av) C_noret;
C_noret_decl(f_10956)
static void C_ccall f_10956(C_word c,C_word *av) C_noret;
C_noret_decl(f_10962)
static void C_ccall f_10962(C_word c,C_word *av) C_noret;
C_noret_decl(f_10985)
static void C_ccall f_10985(C_word c,C_word *av) C_noret;
C_noret_decl(f_11000)
static void C_ccall f_11000(C_word c,C_word *av) C_noret;
C_noret_decl(f_11006)
static void C_ccall f_11006(C_word c,C_word *av) C_noret;
C_noret_decl(f_11012)
static void C_ccall f_11012(C_word c,C_word *av) C_noret;
C_noret_decl(f_11028)
static void C_ccall f_11028(C_word c,C_word *av) C_noret;
C_noret_decl(f_11034)
static void C_ccall f_11034(C_word c,C_word *av) C_noret;
C_noret_decl(f_11038)
static void C_fcall f_11038(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11046)
static void C_ccall f_11046(C_word c,C_word *av) C_noret;
C_noret_decl(f_11068)
static void C_ccall f_11068(C_word c,C_word *av) C_noret;
C_noret_decl(f_11079)
static void C_ccall f_11079(C_word c,C_word *av) C_noret;
C_noret_decl(f_11083)
static void C_ccall f_11083(C_word c,C_word *av) C_noret;
C_noret_decl(f_11092)
static void C_ccall f_11092(C_word c,C_word *av) C_noret;
C_noret_decl(f_11095)
static void C_ccall f_11095(C_word c,C_word *av) C_noret;
C_noret_decl(f_11105)
static void C_fcall f_11105(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11117)
static void C_fcall f_11117(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11142)
static void C_ccall f_11142(C_word c,C_word *av) C_noret;
C_noret_decl(f_11151)
static void C_fcall f_11151(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11161)
static void C_ccall f_11161(C_word c,C_word *av) C_noret;
C_noret_decl(f_11190)
static void C_ccall f_11190(C_word c,C_word *av) C_noret;
C_noret_decl(f_11192)
static void C_ccall f_11192(C_word c,C_word *av) C_noret;
C_noret_decl(f_11200)
static void C_ccall f_11200(C_word c,C_word *av) C_noret;
C_noret_decl(f_11208)
static void C_ccall f_11208(C_word c,C_word *av) C_noret;
C_noret_decl(f_11225)
static void C_ccall f_11225(C_word c,C_word *av) C_noret;
C_noret_decl(f_11227)
static void C_fcall f_11227(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11265)
static void C_fcall f_11265(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11294)
static void C_ccall f_11294(C_word c,C_word *av) C_noret;
C_noret_decl(f_11323)
static void C_ccall f_11323(C_word c,C_word *av) C_noret;
C_noret_decl(f_11329)
static void C_ccall f_11329(C_word c,C_word *av) C_noret;
C_noret_decl(f_11348)
static void C_ccall f_11348(C_word c,C_word *av) C_noret;
C_noret_decl(f_11354)
static void C_fcall f_11354(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11357)
static void C_fcall f_11357(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11379)
static void C_ccall f_11379(C_word c,C_word *av) C_noret;
C_noret_decl(f_11411)
static void C_ccall f_11411(C_word c,C_word *av) C_noret;
C_noret_decl(f_11414)
static void C_ccall f_11414(C_word c,C_word *av) C_noret;
C_noret_decl(f_11427)
static void C_fcall f_11427(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11448)
static void C_ccall f_11448(C_word c,C_word *av) C_noret;
C_noret_decl(f_11454)
static void C_ccall f_11454(C_word c,C_word *av) C_noret;
C_noret_decl(f_11457)
static void C_ccall f_11457(C_word c,C_word *av) C_noret;
C_noret_decl(f_11467)
static void C_ccall f_11467(C_word c,C_word *av) C_noret;
C_noret_decl(f_11486)
static void C_ccall f_11486(C_word c,C_word *av) C_noret;
C_noret_decl(f_11511)
static void C_fcall f_11511(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11521)
static void C_ccall f_11521(C_word c,C_word *av) C_noret;
C_noret_decl(f_11523)
static void C_fcall f_11523(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11533)
static void C_ccall f_11533(C_word c,C_word *av) C_noret;
C_noret_decl(f_11594)
static void C_ccall f_11594(C_word c,C_word *av) C_noret;
C_noret_decl(f_11597)
static void C_ccall f_11597(C_word c,C_word *av) C_noret;
C_noret_decl(f_11600)
static void C_ccall f_11600(C_word c,C_word *av) C_noret;
C_noret_decl(f_11603)
static void C_ccall f_11603(C_word c,C_word *av) C_noret;
C_noret_decl(f_11606)
static void C_ccall f_11606(C_word c,C_word *av) C_noret;
C_noret_decl(f_11612)
static void C_ccall f_11612(C_word c,C_word *av) C_noret;
C_noret_decl(f_11635)
static void C_ccall f_11635(C_word c,C_word *av) C_noret;
C_noret_decl(f_11639)
static void C_ccall f_11639(C_word c,C_word *av) C_noret;
C_noret_decl(f_11647)
static void C_ccall f_11647(C_word c,C_word *av) C_noret;
C_noret_decl(f_11650)
static void C_ccall f_11650(C_word c,C_word *av) C_noret;
C_noret_decl(f_11653)
static void C_ccall f_11653(C_word c,C_word *av) C_noret;
C_noret_decl(f_11656)
static void C_ccall f_11656(C_word c,C_word *av) C_noret;
C_noret_decl(f_11673)
static void C_fcall f_11673(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11683)
static void C_ccall f_11683(C_word c,C_word *av) C_noret;
C_noret_decl(f_11710)
static void C_ccall f_11710(C_word c,C_word *av) C_noret;
C_noret_decl(f_11712)
static void C_fcall f_11712(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11718)
static void C_fcall f_11718(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11728)
static void C_ccall f_11728(C_word c,C_word *av) C_noret;
C_noret_decl(f_11740)
static void C_ccall f_11740(C_word c,C_word *av) C_noret;
C_noret_decl(f_11748)
static void C_fcall f_11748(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11768)
static void C_ccall f_11768(C_word c,C_word *av) C_noret;
C_noret_decl(f_11781)
static void C_ccall f_11781(C_word c,C_word *av) C_noret;
C_noret_decl(f_11793)
static void C_ccall f_11793(C_word c,C_word *av) C_noret;
C_noret_decl(f_11800)
static void C_ccall f_11800(C_word c,C_word *av) C_noret;
C_noret_decl(f_11802)
static void C_fcall f_11802(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11827)
static void C_ccall f_11827(C_word c,C_word *av) C_noret;
C_noret_decl(f_11849)
static void C_ccall f_11849(C_word c,C_word *av) C_noret;
C_noret_decl(f_11862)
static void C_ccall f_11862(C_word c,C_word *av) C_noret;
C_noret_decl(f_11883)
static void C_ccall f_11883(C_word c,C_word *av) C_noret;
C_noret_decl(f_11908)
static void C_ccall f_11908(C_word c,C_word *av) C_noret;
C_noret_decl(f_11912)
static void C_ccall f_11912(C_word c,C_word *av) C_noret;
C_noret_decl(f_11923)
static void C_fcall f_11923(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11932)
static void C_fcall f_11932(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_12029)
static void C_ccall f_12029(C_word c,C_word *av) C_noret;
C_noret_decl(f_12054)
static void C_fcall f_12054(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12060)
static void C_ccall f_12060(C_word c,C_word *av) C_noret;
C_noret_decl(f_12076)
static void C_ccall f_12076(C_word c,C_word *av) C_noret;
C_noret_decl(f_12083)
static void C_ccall f_12083(C_word c,C_word *av) C_noret;
C_noret_decl(f_12100)
static void C_ccall f_12100(C_word c,C_word *av) C_noret;
C_noret_decl(f_12117)
static void C_fcall f_12117(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12160)
static void C_ccall f_12160(C_word c,C_word *av) C_noret;
C_noret_decl(f_12185)
static void C_fcall f_12185(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12191)
static void C_ccall f_12191(C_word c,C_word *av) C_noret;
C_noret_decl(f_12196)
static void C_ccall f_12196(C_word c,C_word *av) C_noret;
C_noret_decl(f_12202)
static void C_ccall f_12202(C_word c,C_word *av) C_noret;
C_noret_decl(f_12207)
static void C_fcall f_12207(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12213)
static void C_fcall f_12213(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12226)
static void C_ccall f_12226(C_word c,C_word *av) C_noret;
C_noret_decl(f_12243)
static void C_fcall f_12243(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12260)
static void C_fcall f_12260(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12273)
static void C_ccall f_12273(C_word c,C_word *av) C_noret;
C_noret_decl(f_12301)
static void C_fcall f_12301(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12314)
static void C_ccall f_12314(C_word c,C_word *av) C_noret;
C_noret_decl(f_12351)
static void C_ccall f_12351(C_word c,C_word *av) C_noret;
C_noret_decl(f_12392)
static void C_fcall f_12392(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12405)
static void C_ccall f_12405(C_word c,C_word *av) C_noret;
C_noret_decl(f_12435)
static void C_ccall f_12435(C_word c,C_word *av) C_noret;
C_noret_decl(f_12505)
static void C_ccall f_12505(C_word c,C_word *av) C_noret;
C_noret_decl(f_12509)
static void C_fcall f_12509(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12519)
static void C_ccall f_12519(C_word c,C_word *av) C_noret;
C_noret_decl(f_12523)
static void C_fcall f_12523(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12544)
static void C_ccall f_12544(C_word c,C_word *av) C_noret;
C_noret_decl(f_12549)
static void C_ccall f_12549(C_word c,C_word *av) C_noret;
C_noret_decl(f_12553)
static void C_ccall f_12553(C_word c,C_word *av) C_noret;
C_noret_decl(f_12556)
static void C_ccall f_12556(C_word c,C_word *av) C_noret;
C_noret_decl(f_12565)
static void C_ccall f_12565(C_word c,C_word *av) C_noret;
C_noret_decl(f_12585)
static void C_ccall f_12585(C_word c,C_word *av) C_noret;
C_noret_decl(f_12590)
static void C_ccall f_12590(C_word c,C_word *av) C_noret;
C_noret_decl(f_12594)
static void C_ccall f_12594(C_word c,C_word *av) C_noret;
C_noret_decl(f_12597)
static void C_ccall f_12597(C_word c,C_word *av) C_noret;
C_noret_decl(f_12606)
static void C_ccall f_12606(C_word c,C_word *av) C_noret;
C_noret_decl(f_12624)
static void C_ccall f_12624(C_word c,C_word *av) C_noret;
C_noret_decl(f_12643)
static void C_ccall f_12643(C_word c,C_word *av) C_noret;
C_noret_decl(f_12759)
static void C_fcall f_12759(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12771)
static void C_ccall f_12771(C_word c,C_word *av) C_noret;
C_noret_decl(f_12774)
static void C_ccall f_12774(C_word c,C_word *av) C_noret;
C_noret_decl(f_12777)
static void C_ccall f_12777(C_word c,C_word *av) C_noret;
C_noret_decl(f_12780)
static void C_ccall f_12780(C_word c,C_word *av) C_noret;
C_noret_decl(f_12786)
static void C_ccall f_12786(C_word c,C_word *av) C_noret;
C_noret_decl(f_12879)
static void C_ccall f_12879(C_word c,C_word *av) C_noret;
C_noret_decl(f_12989)
static void C_ccall f_12989(C_word c,C_word *av) C_noret;
C_noret_decl(f_13022)
static void C_ccall f_13022(C_word c,C_word *av) C_noret;
C_noret_decl(f_13091)
static void C_ccall f_13091(C_word c,C_word *av) C_noret;
C_noret_decl(f_13124)
static void C_ccall f_13124(C_word c,C_word *av) C_noret;
C_noret_decl(f_13198)
static void C_ccall f_13198(C_word c,C_word *av) C_noret;
C_noret_decl(f_13232)
static void C_ccall f_13232(C_word c,C_word *av) C_noret;
C_noret_decl(f_13274)
static void C_ccall f_13274(C_word c,C_word *av) C_noret;
C_noret_decl(f_13308)
static void C_ccall f_13308(C_word c,C_word *av) C_noret;
C_noret_decl(f_13496)
static void C_fcall f_13496(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13502)
static void C_fcall f_13502(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13535)
static void C_ccall f_13535(C_word c,C_word *av) C_noret;
C_noret_decl(f_13549)
static void C_ccall f_13549(C_word c,C_word *av) C_noret;
C_noret_decl(f_13568)
static void C_fcall f_13568(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13571)
static void C_fcall f_13571(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13577)
static void C_ccall f_13577(C_word c,C_word *av) C_noret;
C_noret_decl(f_13598)
static void C_ccall f_13598(C_word c,C_word *av) C_noret;
C_noret_decl(f_13602)
static void C_ccall f_13602(C_word c,C_word *av) C_noret;
C_noret_decl(f_13613)
static void C_ccall f_13613(C_word c,C_word *av) C_noret;
C_noret_decl(f_13615)
static void C_ccall f_13615(C_word c,C_word *av) C_noret;
C_noret_decl(f_13650)
static void C_ccall f_13650(C_word c,C_word *av) C_noret;
C_noret_decl(f_13652)
static void C_fcall f_13652(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13693)
static void C_ccall f_13693(C_word c,C_word *av) C_noret;
C_noret_decl(f_13721)
static void C_ccall f_13721(C_word c,C_word *av) C_noret;
C_noret_decl(f_13727)
static void C_ccall f_13727(C_word c,C_word *av) C_noret;
C_noret_decl(f_13739)
static void C_fcall f_13739(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13759)
static void C_ccall f_13759(C_word c,C_word *av) C_noret;
C_noret_decl(f_13762)
static void C_ccall f_13762(C_word c,C_word *av) C_noret;
C_noret_decl(f_13765)
static void C_ccall f_13765(C_word c,C_word *av) C_noret;
C_noret_decl(f_13768)
static void C_ccall f_13768(C_word c,C_word *av) C_noret;
C_noret_decl(f_13771)
static void C_ccall f_13771(C_word c,C_word *av) C_noret;
C_noret_decl(f_13774)
static void C_ccall f_13774(C_word c,C_word *av) C_noret;
C_noret_decl(f_13781)
static void C_fcall f_13781(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13789)
static void C_ccall f_13789(C_word c,C_word *av) C_noret;
C_noret_decl(f_13793)
static void C_ccall f_13793(C_word c,C_word *av) C_noret;
C_noret_decl(f_13808)
static void C_ccall f_13808(C_word c,C_word *av) C_noret;
C_noret_decl(f_13814)
static void C_ccall f_13814(C_word c,C_word *av) C_noret;
C_noret_decl(f_13824)
static void C_ccall f_13824(C_word c,C_word *av) C_noret;
C_noret_decl(f_13830)
static void C_ccall f_13830(C_word c,C_word *av) C_noret;
C_noret_decl(f_13836)
static void C_ccall f_13836(C_word c,C_word *av) C_noret;
C_noret_decl(f_13839)
static void C_ccall f_13839(C_word c,C_word *av) C_noret;
C_noret_decl(f_13842)
static void C_ccall f_13842(C_word c,C_word *av) C_noret;
C_noret_decl(f_13859)
static void C_fcall f_13859(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13884)
static void C_ccall f_13884(C_word c,C_word *av) C_noret;
C_noret_decl(f_13895)
static void C_ccall f_13895(C_word c,C_word *av) C_noret;
C_noret_decl(f_13913)
static void C_ccall f_13913(C_word c,C_word *av) C_noret;
C_noret_decl(f_13923)
static void C_ccall f_13923(C_word c,C_word *av) C_noret;
C_noret_decl(f_13939)
static void C_ccall f_13939(C_word c,C_word *av) C_noret;
C_noret_decl(f_13943)
static void C_ccall f_13943(C_word c,C_word *av) C_noret;
C_noret_decl(f_14001)
static void C_ccall f_14001(C_word c,C_word *av) C_noret;
C_noret_decl(f_14003)
static void C_fcall f_14003(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14028)
static void C_ccall f_14028(C_word c,C_word *av) C_noret;
C_noret_decl(f_14047)
static void C_ccall f_14047(C_word c,C_word *av) C_noret;
C_noret_decl(f_14066)
static void C_ccall f_14066(C_word c,C_word *av) C_noret;
C_noret_decl(f_14081)
static void C_ccall f_14081(C_word c,C_word *av) C_noret;
C_noret_decl(f_14094)
static void C_ccall f_14094(C_word c,C_word *av) C_noret;
C_noret_decl(f_14097)
static void C_ccall f_14097(C_word c,C_word *av) C_noret;
C_noret_decl(f_14133)
static void C_ccall f_14133(C_word c,C_word *av) C_noret;
C_noret_decl(f_14157)
static void C_ccall f_14157(C_word c,C_word *av) C_noret;
C_noret_decl(f_14198)
static void C_ccall f_14198(C_word c,C_word *av) C_noret;
C_noret_decl(f_14200)
static void C_fcall f_14200(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14225)
static void C_ccall f_14225(C_word c,C_word *av) C_noret;
C_noret_decl(f_14254)
static void C_ccall f_14254(C_word c,C_word *av) C_noret;
C_noret_decl(f_14256)
static void C_fcall f_14256(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14281)
static void C_ccall f_14281(C_word c,C_word *av) C_noret;
C_noret_decl(f_14315)
static void C_ccall f_14315(C_word c,C_word *av) C_noret;
C_noret_decl(f_14329)
static void C_fcall f_14329(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14354)
static void C_ccall f_14354(C_word c,C_word *av) C_noret;
C_noret_decl(f_14374)
static void C_ccall f_14374(C_word c,C_word *av) C_noret;
C_noret_decl(f_14376)
static void C_fcall f_14376(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14401)
static void C_ccall f_14401(C_word c,C_word *av) C_noret;
C_noret_decl(f_14454)
static void C_fcall f_14454(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14459)
static void C_ccall f_14459(C_word c,C_word *av) C_noret;
C_noret_decl(f_14468)
static void C_ccall f_14468(C_word c,C_word *av) C_noret;
C_noret_decl(f_14485)
static void C_ccall f_14485(C_word c,C_word *av) C_noret;
C_noret_decl(f_14487)
static void C_ccall f_14487(C_word c,C_word *av) C_noret;
C_noret_decl(f_14502)
static void C_fcall f_14502(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14510)
static void C_ccall f_14510(C_word c,C_word *av) C_noret;
C_noret_decl(f_14537)
static void C_fcall f_14537(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14583)
static void C_ccall f_14583(C_word c,C_word *av) C_noret;
C_noret_decl(f_14632)
static void C_ccall f_14632(C_word c,C_word *av) C_noret;
C_noret_decl(f_14636)
static void C_ccall f_14636(C_word c,C_word *av) C_noret;
C_noret_decl(f_14682)
static void C_ccall f_14682(C_word c,C_word *av) C_noret;
C_noret_decl(f_14686)
static void C_ccall f_14686(C_word c,C_word *av) C_noret;
C_noret_decl(f_14712)
static void C_ccall f_14712(C_word c,C_word *av) C_noret;
C_noret_decl(f_14718)
static void C_fcall f_14718(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_14744)
static void C_ccall f_14744(C_word c,C_word *av) C_noret;
C_noret_decl(f_14748)
static void C_ccall f_14748(C_word c,C_word *av) C_noret;
C_noret_decl(f_14775)
static void C_fcall f_14775(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_14779)
static void C_ccall f_14779(C_word c,C_word *av) C_noret;
C_noret_decl(f_14782)
static void C_ccall f_14782(C_word c,C_word *av) C_noret;
C_noret_decl(f_14807)
static void C_ccall f_14807(C_word c,C_word *av) C_noret;
C_noret_decl(f_14813)
static void C_ccall f_14813(C_word c,C_word *av) C_noret;
C_noret_decl(f_14819)
static void C_ccall f_14819(C_word c,C_word *av) C_noret;
C_noret_decl(f_14834)
static void C_ccall f_14834(C_word c,C_word *av) C_noret;
C_noret_decl(f_14838)
static void C_ccall f_14838(C_word c,C_word *av) C_noret;
C_noret_decl(f_14843)
static void C_fcall f_14843(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14862)
static void C_ccall f_14862(C_word c,C_word *av) C_noret;
C_noret_decl(f_14871)
static void C_fcall f_14871(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_14875)
static void C_ccall f_14875(C_word c,C_word *av) C_noret;
C_noret_decl(f_14879)
static void C_fcall f_14879(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14889)
static void C_ccall f_14889(C_word c,C_word *av) C_noret;
C_noret_decl(f_14893)
static void C_fcall f_14893(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14909)
static void C_ccall f_14909(C_word c,C_word *av) C_noret;
C_noret_decl(f_14936)
static void C_ccall f_14936(C_word c,C_word *av) C_noret;
C_noret_decl(f_14960)
static void C_fcall f_14960(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14969)
static void C_ccall f_14969(C_word c,C_word *av) C_noret;
C_noret_decl(f_14980)
static void C_ccall f_14980(C_word c,C_word *av) C_noret;
C_noret_decl(f_14994)
static void C_fcall f_14994(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15012)
static void C_ccall f_15012(C_word c,C_word *av) C_noret;
C_noret_decl(f_15018)
static void C_ccall f_15018(C_word c,C_word *av) C_noret;
C_noret_decl(f_15025)
static void C_fcall f_15025(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15054)
static void C_ccall f_15054(C_word c,C_word *av) C_noret;
C_noret_decl(f_15133)
static void C_ccall f_15133(C_word c,C_word *av) C_noret;
C_noret_decl(f_15163)
static void C_ccall f_15163(C_word c,C_word *av) C_noret;
C_noret_decl(f_15166)
static void C_ccall f_15166(C_word c,C_word *av) C_noret;
C_noret_decl(f_15184)
static void C_ccall f_15184(C_word c,C_word *av) C_noret;
C_noret_decl(f_15236)
static void C_fcall f_15236(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15287)
static void C_fcall f_15287(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15344)
static void C_fcall f_15344(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15401)
static void C_fcall f_15401(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_15410)
static void C_fcall f_15410(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15420)
static void C_ccall f_15420(C_word c,C_word *av) C_noret;
C_noret_decl(f_15427)
static void C_fcall f_15427(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15429)
static void C_fcall f_15429(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_15508)
static void C_ccall f_15508(C_word c,C_word *av) C_noret;
C_noret_decl(f_15564)
static void C_fcall f_15564(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15597)
static void C_ccall f_15597(C_word c,C_word *av) C_noret;
C_noret_decl(f_15624)
static void C_fcall f_15624(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15635)
static void C_fcall f_15635(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15657)
static void C_ccall f_15657(C_word c,C_word *av) C_noret;
C_noret_decl(f_15665)
static void C_fcall f_15665(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15667)
static void C_fcall f_15667(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15693)
static void C_ccall f_15693(C_word c,C_word *av) C_noret;
C_noret_decl(f_15752)
static C_word C_fcall f_15752(C_word t0);
C_noret_decl(f_15805)
static C_word C_fcall f_15805(C_word t0);
C_noret_decl(f_15825)
static C_word C_fcall f_15825(C_word t0);
C_noret_decl(f_15884)
static void C_ccall f_15884(C_word c,C_word *av) C_noret;
C_noret_decl(f_15928)
static C_word C_fcall f_15928(C_word t0);
C_noret_decl(f_15967)
static void C_ccall f_15967(C_word c,C_word *av) C_noret;
C_noret_decl(f_15970)
static void C_ccall f_15970(C_word c,C_word *av) C_noret;
C_noret_decl(f_15975)
static void C_ccall f_15975(C_word c,C_word *av) C_noret;
C_noret_decl(f_15979)
static void C_ccall f_15979(C_word c,C_word *av) C_noret;
C_noret_decl(f_15981)
static void C_fcall f_15981(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16026)
static void C_ccall f_16026(C_word c,C_word *av) C_noret;
C_noret_decl(f_16043)
static void C_fcall f_16043(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16053)
static void C_ccall f_16053(C_word c,C_word *av) C_noret;
C_noret_decl(f_16070)
static void C_fcall f_16070(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16080)
static void C_ccall f_16080(C_word c,C_word *av) C_noret;
C_noret_decl(f_16100)
static void C_ccall f_16100(C_word c,C_word *av) C_noret;
C_noret_decl(f_16116)
static void C_fcall f_16116(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16126)
static void C_ccall f_16126(C_word c,C_word *av) C_noret;
C_noret_decl(f_16143)
static void C_fcall f_16143(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16153)
static void C_ccall f_16153(C_word c,C_word *av) C_noret;
C_noret_decl(f_16185)
static void C_ccall f_16185(C_word c,C_word *av) C_noret;
C_noret_decl(f_16227)
static void C_ccall f_16227(C_word c,C_word *av) C_noret;
C_noret_decl(f_16229)
static void C_fcall f_16229(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16254)
static void C_fcall f_16254(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16276)
static void C_fcall f_16276(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16286)
static void C_ccall f_16286(C_word c,C_word *av) C_noret;
C_noret_decl(f_16307)
static void C_fcall f_16307(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16313)
static C_word C_fcall f_16313(C_word t0,C_word t1);
C_noret_decl(f_16345)
static void C_ccall f_16345(C_word c,C_word *av) C_noret;
C_noret_decl(f_16348)
static void C_ccall f_16348(C_word c,C_word *av) C_noret;
C_noret_decl(f_16350)
static void C_ccall f_16350(C_word c,C_word *av) C_noret;
C_noret_decl(f_16358)
static void C_ccall f_16358(C_word c,C_word *av) C_noret;
C_noret_decl(f_16360)
static void C_fcall f_16360(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_16368)
static void C_fcall f_16368(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16449)
static void C_fcall f_16449(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16460)
static void C_ccall f_16460(C_word c,C_word *av) C_noret;
C_noret_decl(f_16462)
static void C_fcall f_16462(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16487)
static void C_ccall f_16487(C_word c,C_word *av) C_noret;
C_noret_decl(f_16507)
static void C_ccall f_16507(C_word c,C_word *av) C_noret;
C_noret_decl(f_16533)
static void C_ccall f_16533(C_word c,C_word *av) C_noret;
C_noret_decl(f_16546)
static void C_fcall f_16546(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16556)
static void C_fcall f_16556(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16567)
static void C_ccall f_16567(C_word c,C_word *av) C_noret;
C_noret_decl(f_16569)
static void C_fcall f_16569(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16594)
static void C_ccall f_16594(C_word c,C_word *av) C_noret;
C_noret_decl(f_16610)
static void C_ccall f_16610(C_word c,C_word *av) C_noret;
C_noret_decl(f_16613)
static void C_ccall f_16613(C_word c,C_word *av) C_noret;
C_noret_decl(f_16616)
static void C_ccall f_16616(C_word c,C_word *av) C_noret;
C_noret_decl(f_16623)
static void C_ccall f_16623(C_word c,C_word *av) C_noret;
C_noret_decl(f_16635)
static void C_ccall f_16635(C_word c,C_word *av) C_noret;
C_noret_decl(f_16639)
static void C_ccall f_16639(C_word c,C_word *av) C_noret;
C_noret_decl(f_16646)
static void C_fcall f_16646(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16658)
static void C_fcall f_16658(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16683)
static void C_ccall f_16683(C_word c,C_word *av) C_noret;
C_noret_decl(f_16692)
static void C_fcall f_16692(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16720)
static void C_ccall f_16720(C_word c,C_word *av) C_noret;
C_noret_decl(f_16739)
static void C_ccall f_16739(C_word c,C_word *av) C_noret;
C_noret_decl(f_16748)
static void C_ccall f_16748(C_word c,C_word *av) C_noret;
C_noret_decl(f_16752)
static void C_ccall f_16752(C_word c,C_word *av) C_noret;
C_noret_decl(f_16815)
static void C_ccall f_16815(C_word c,C_word *av) C_noret;
C_noret_decl(f_16819)
static void C_ccall f_16819(C_word c,C_word *av) C_noret;
C_noret_decl(f_16822)
static void C_ccall f_16822(C_word c,C_word *av) C_noret;
C_noret_decl(f_16828)
static void C_ccall f_16828(C_word c,C_word *av) C_noret;
C_noret_decl(f_16833)
static void C_ccall f_16833(C_word c,C_word *av) C_noret;
C_noret_decl(f_16838)
static void C_ccall f_16838(C_word c,C_word *av) C_noret;
C_noret_decl(f_16847)
static void C_ccall f_16847(C_word c,C_word *av) C_noret;
C_noret_decl(f_16853)
static void C_ccall f_16853(C_word c,C_word *av) C_noret;
C_noret_decl(f_16858)
static void C_ccall f_16858(C_word c,C_word *av) C_noret;
C_noret_decl(f_16864)
static void C_ccall f_16864(C_word c,C_word *av) C_noret;
C_noret_decl(f_16868)
static void C_ccall f_16868(C_word c,C_word *av) C_noret;
C_noret_decl(f_16871)
static void C_ccall f_16871(C_word c,C_word *av) C_noret;
C_noret_decl(f_16874)
static void C_ccall f_16874(C_word c,C_word *av) C_noret;
C_noret_decl(f_16877)
static void C_ccall f_16877(C_word c,C_word *av) C_noret;
C_noret_decl(f_16886)
static void C_fcall f_16886(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16893)
static void C_ccall f_16893(C_word c,C_word *av) C_noret;
C_noret_decl(f_16897)
static void C_ccall f_16897(C_word c,C_word *av) C_noret;
C_noret_decl(f_16901)
static void C_ccall f_16901(C_word c,C_word *av) C_noret;
C_noret_decl(f_16905)
static void C_ccall f_16905(C_word c,C_word *av) C_noret;
C_noret_decl(f_16912)
static void C_ccall f_16912(C_word c,C_word *av) C_noret;
C_noret_decl(f_16919)
static void C_ccall f_16919(C_word c,C_word *av) C_noret;
C_noret_decl(f_16925)
static void C_ccall f_16925(C_word c,C_word *av) C_noret;
C_noret_decl(f_16928)
static void C_ccall f_16928(C_word c,C_word *av) C_noret;
C_noret_decl(f_16931)
static void C_ccall f_16931(C_word c,C_word *av) C_noret;
C_noret_decl(f_16934)
static void C_ccall f_16934(C_word c,C_word *av) C_noret;
C_noret_decl(f_16937)
static void C_ccall f_16937(C_word c,C_word *av) C_noret;
C_noret_decl(f_16940)
static void C_ccall f_16940(C_word c,C_word *av) C_noret;
C_noret_decl(f_16943)
static void C_ccall f_16943(C_word c,C_word *av) C_noret;
C_noret_decl(f_16947)
static void C_ccall f_16947(C_word c,C_word *av) C_noret;
C_noret_decl(f_16952)
static void C_fcall f_16952(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16968)
static void C_ccall f_16968(C_word c,C_word *av) C_noret;
C_noret_decl(f_16979)
static void C_fcall f_16979(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16998)
static void C_ccall f_16998(C_word c,C_word *av) C_noret;
C_noret_decl(f_17012)
static void C_ccall f_17012(C_word c,C_word *av) C_noret;
C_noret_decl(f_17026)
static void C_ccall f_17026(C_word c,C_word *av) C_noret;
C_noret_decl(f_17040)
static void C_ccall f_17040(C_word c,C_word *av) C_noret;
C_noret_decl(f_17054)
static void C_ccall f_17054(C_word c,C_word *av) C_noret;
C_noret_decl(f_17084)
static void C_ccall f_17084(C_word c,C_word *av) C_noret;
C_noret_decl(f_17103)
static void C_ccall f_17103(C_word c,C_word *av) C_noret;
C_noret_decl(f_17135)
static void C_ccall f_17135(C_word c,C_word *av) C_noret;
C_noret_decl(f_17141)
static void C_ccall f_17141(C_word c,C_word *av) C_noret;
C_noret_decl(f_17143)
static void C_fcall f_17143(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17153)
static void C_ccall f_17153(C_word c,C_word *av) C_noret;
C_noret_decl(f_17166)
static void C_ccall f_17166(C_word c,C_word *av) C_noret;
C_noret_decl(f_17173)
static void C_ccall f_17173(C_word c,C_word *av) C_noret;
C_noret_decl(f_17179)
static void C_ccall f_17179(C_word c,C_word *av) C_noret;
C_noret_decl(f_17182)
static void C_ccall f_17182(C_word c,C_word *av) C_noret;
C_noret_decl(f_17185)
static void C_ccall f_17185(C_word c,C_word *av) C_noret;
C_noret_decl(f_17188)
static void C_ccall f_17188(C_word c,C_word *av) C_noret;
C_noret_decl(f_17191)
static void C_ccall f_17191(C_word c,C_word *av) C_noret;
C_noret_decl(f_17200)
static void C_ccall f_17200(C_word c,C_word *av) C_noret;
C_noret_decl(f_17223)
static void C_fcall f_17223(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_17239)
static void C_fcall f_17239(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_17283)
static void C_ccall f_17283(C_word c,C_word *av) C_noret;
C_noret_decl(f_17287)
static void C_ccall f_17287(C_word c,C_word *av) C_noret;
C_noret_decl(f_17289)
static void C_ccall f_17289(C_word c,C_word *av) C_noret;
C_noret_decl(f_17295)
static void C_ccall f_17295(C_word c,C_word *av) C_noret;
C_noret_decl(f_17299)
static void C_ccall f_17299(C_word c,C_word *av) C_noret;
C_noret_decl(f_17300)
static void C_fcall f_17300(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17311)
static void C_fcall f_17311(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17314)
static void C_ccall f_17314(C_word c,C_word *av) C_noret;
C_noret_decl(f_17320)
static void C_ccall f_17320(C_word c,C_word *av) C_noret;
C_noret_decl(f_17323)
static void C_ccall f_17323(C_word c,C_word *av) C_noret;
C_noret_decl(f_17326)
static void C_ccall f_17326(C_word c,C_word *av) C_noret;
C_noret_decl(f_17329)
static void C_ccall f_17329(C_word c,C_word *av) C_noret;
C_noret_decl(f_17332)
static void C_ccall f_17332(C_word c,C_word *av) C_noret;
C_noret_decl(f_17335)
static void C_ccall f_17335(C_word c,C_word *av) C_noret;
C_noret_decl(f_17338)
static void C_ccall f_17338(C_word c,C_word *av) C_noret;
C_noret_decl(f_17345)
static void C_ccall f_17345(C_word c,C_word *av) C_noret;
C_noret_decl(f_17349)
static void C_ccall f_17349(C_word c,C_word *av) C_noret;
C_noret_decl(f_17351)
static void C_fcall f_17351(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17372)
static void C_ccall f_17372(C_word c,C_word *av) C_noret;
C_noret_decl(f_17382)
static void C_ccall f_17382(C_word c,C_word *av) C_noret;
C_noret_decl(f_17390)
static void C_ccall f_17390(C_word c,C_word *av) C_noret;
C_noret_decl(f_17398)
static void C_ccall f_17398(C_word c,C_word *av) C_noret;
C_noret_decl(f_17406)
static void C_ccall f_17406(C_word c,C_word *av) C_noret;
C_noret_decl(f_17434)
static void C_ccall f_17434(C_word c,C_word *av) C_noret;
C_noret_decl(f_17445)
static void C_ccall f_17445(C_word c,C_word *av) C_noret;
C_noret_decl(f_17449)
static void C_ccall f_17449(C_word c,C_word *av) C_noret;
C_noret_decl(f_17453)
static void C_ccall f_17453(C_word c,C_word *av) C_noret;
C_noret_decl(f_17459)
static void C_ccall f_17459(C_word c,C_word *av) C_noret;
C_noret_decl(f_17464)
static void C_fcall f_17464(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17474)
static void C_ccall f_17474(C_word c,C_word *av) C_noret;
C_noret_decl(f_17489)
static void C_ccall f_17489(C_word c,C_word *av) C_noret;
C_noret_decl(f_17491)
static void C_ccall f_17491(C_word c,C_word *av) C_noret;
C_noret_decl(f_17507)
static void C_ccall f_17507(C_word c,C_word *av) C_noret;
C_noret_decl(f_17510)
static void C_fcall f_17510(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17515)
static void C_ccall f_17515(C_word c,C_word *av) C_noret;
C_noret_decl(f_17522)
static void C_ccall f_17522(C_word c,C_word *av) C_noret;
C_noret_decl(f_17526)
static void C_ccall f_17526(C_word c,C_word *av) C_noret;
C_noret_decl(f_17528)
static void C_fcall f_17528(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17535)
static void C_ccall f_17535(C_word c,C_word *av) C_noret;
C_noret_decl(f_17555)
static void C_ccall f_17555(C_word c,C_word *av) C_noret;
C_noret_decl(f_17561)
static void C_ccall f_17561(C_word c,C_word *av) C_noret;
C_noret_decl(f_17569)
static void C_ccall f_17569(C_word c,C_word *av) C_noret;
C_noret_decl(f_17573)
static void C_ccall f_17573(C_word c,C_word *av) C_noret;
C_noret_decl(f_17580)
static void C_ccall f_17580(C_word c,C_word *av) C_noret;
C_noret_decl(f_17586)
static void C_ccall f_17586(C_word c,C_word *av) C_noret;
C_noret_decl(f_17588)
static void C_fcall f_17588(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17613)
static void C_ccall f_17613(C_word c,C_word *av) C_noret;
C_noret_decl(f_17630)
static void C_ccall f_17630(C_word c,C_word *av) C_noret;
C_noret_decl(f_17636)
static void C_ccall f_17636(C_word c,C_word *av) C_noret;
C_noret_decl(f_17645)
static void C_ccall f_17645(C_word c,C_word *av) C_noret;
C_noret_decl(f_17684)
static void C_ccall f_17684(C_word c,C_word *av) C_noret;
C_noret_decl(f_17690)
static void C_fcall f_17690(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_17693)
static void C_fcall f_17693(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17740)
static void C_ccall f_17740(C_word c,C_word *av) C_noret;
C_noret_decl(f_17750)
static void C_fcall f_17750(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17777)
static void C_ccall f_17777(C_word c,C_word *av) C_noret;
C_noret_decl(f_17781)
static void C_ccall f_17781(C_word c,C_word *av) C_noret;
C_noret_decl(f_17841)
static void C_ccall f_17841(C_word c,C_word *av) C_noret;
C_noret_decl(f_17843)
static void C_ccall f_17843(C_word c,C_word *av) C_noret;
C_noret_decl(f_17852)
static void C_fcall f_17852(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17870)
static void C_ccall f_17870(C_word c,C_word *av) C_noret;
C_noret_decl(f_17874)
static void C_fcall f_17874(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17880)
static C_word C_fcall f_17880(C_word t0,C_word t1);
C_noret_decl(f_17908)
static void C_fcall f_17908(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17939)
static void C_ccall f_17939(C_word c,C_word *av) C_noret;
C_noret_decl(f_17971)
static void C_ccall f_17971(C_word c,C_word *av) C_noret;
C_noret_decl(f_17998)
static void C_ccall f_17998(C_word c,C_word *av) C_noret;
C_noret_decl(f_18001)
static void C_ccall f_18001(C_word c,C_word *av) C_noret;
C_noret_decl(f_18038)
static void C_fcall f_18038(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_18096)
static void C_ccall f_18096(C_word c,C_word *av) C_noret;
C_noret_decl(f_18130)
static void C_ccall f_18130(C_word c,C_word *av) C_noret;
C_noret_decl(f_18162)
static void C_ccall f_18162(C_word c,C_word *av) C_noret;
C_noret_decl(f_18167)
static void C_ccall f_18167(C_word c,C_word *av) C_noret;
C_noret_decl(f_18171)
static void C_ccall f_18171(C_word c,C_word *av) C_noret;
C_noret_decl(f_18182)
static void C_ccall f_18182(C_word c,C_word *av) C_noret;
C_noret_decl(f_18184)
static void C_ccall f_18184(C_word c,C_word *av) C_noret;
C_noret_decl(f_18200)
static void C_ccall f_18200(C_word c,C_word *av) C_noret;
C_noret_decl(f_18203)
static void C_ccall f_18203(C_word c,C_word *av) C_noret;
C_noret_decl(f_18219)
static void C_fcall f_18219(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18266)
static void C_ccall f_18266(C_word c,C_word *av) C_noret;
C_noret_decl(f_18268)
static void C_fcall f_18268(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18293)
static void C_ccall f_18293(C_word c,C_word *av) C_noret;
C_noret_decl(f_18312)
static void C_fcall f_18312(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18316)
static C_word C_fcall f_18316(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_18360)
static void C_ccall f_18360(C_word c,C_word *av) C_noret;
C_noret_decl(f_18366)
static void C_ccall f_18366(C_word c,C_word *av) C_noret;
C_noret_decl(f_18371)
static void C_fcall f_18371(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18396)
static void C_ccall f_18396(C_word c,C_word *av) C_noret;
C_noret_decl(f_18480)
static void C_ccall f_18480(C_word c,C_word *av) C_noret;
C_noret_decl(f_18510)
static void C_fcall f_18510(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18522)
static void C_ccall f_18522(C_word c,C_word *av) C_noret;
C_noret_decl(f_18549)
static void C_ccall f_18549(C_word c,C_word *av) C_noret;
C_noret_decl(f_18552)
static void C_ccall f_18552(C_word c,C_word *av) C_noret;
C_noret_decl(f_18556)
static void C_fcall f_18556(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18569)
static void C_fcall f_18569(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18572)
static void C_ccall f_18572(C_word c,C_word *av) C_noret;
C_noret_decl(f_18596)
static void C_ccall f_18596(C_word c,C_word *av) C_noret;
C_noret_decl(f_18604)
static void C_fcall f_18604(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18608)
static void C_ccall f_18608(C_word c,C_word *av) C_noret;
C_noret_decl(f_18619)
static void C_ccall f_18619(C_word c,C_word *av) C_noret;
C_noret_decl(f_18698)
static void C_ccall f_18698(C_word c,C_word *av) C_noret;
C_noret_decl(f_18740)
static void C_fcall f_18740(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_18758)
static void C_ccall f_18758(C_word c,C_word *av) C_noret;
C_noret_decl(f_18761)
static void C_ccall f_18761(C_word c,C_word *av) C_noret;
C_noret_decl(f_18765)
static void C_fcall f_18765(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18808)
static void C_ccall f_18808(C_word c,C_word *av) C_noret;
C_noret_decl(f_18814)
static void C_ccall f_18814(C_word c,C_word *av) C_noret;
C_noret_decl(f_18819)
static void C_fcall f_18819(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18844)
static void C_ccall f_18844(C_word c,C_word *av) C_noret;
C_noret_decl(f_18889)
static void C_ccall f_18889(C_word c,C_word *av) C_noret;
C_noret_decl(f_18898)
static void C_ccall f_18898(C_word c,C_word *av) C_noret;
C_noret_decl(f_18902)
static void C_fcall f_18902(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18912)
static void C_ccall f_18912(C_word c,C_word *av) C_noret;
C_noret_decl(f_18944)
static void C_ccall f_18944(C_word c,C_word *av) C_noret;
C_noret_decl(f_18950)
static void C_ccall f_18950(C_word c,C_word *av) C_noret;
C_noret_decl(f_18952)
static void C_fcall f_18952(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18977)
static void C_ccall f_18977(C_word c,C_word *av) C_noret;
C_noret_decl(f_19109)
static void C_ccall f_19109(C_word c,C_word *av) C_noret;
C_noret_decl(f_19113)
static void C_fcall f_19113(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19117)
static void C_fcall f_19117(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19120)
static void C_ccall f_19120(C_word c,C_word *av) C_noret;
C_noret_decl(f_19152)
static void C_fcall f_19152(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19156)
static void C_ccall f_19156(C_word c,C_word *av) C_noret;
C_noret_decl(f_19169)
static void C_ccall f_19169(C_word c,C_word *av) C_noret;
C_noret_decl(f_19173)
static void C_ccall f_19173(C_word c,C_word *av) C_noret;
C_noret_decl(f_19176)
static void C_ccall f_19176(C_word c,C_word *av) C_noret;
C_noret_decl(f_19182)
static void C_ccall f_19182(C_word c,C_word *av) C_noret;
C_noret_decl(f_19184)
static void C_fcall f_19184(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19209)
static void C_ccall f_19209(C_word c,C_word *av) C_noret;
C_noret_decl(f_19224)
static void C_ccall f_19224(C_word c,C_word *av) C_noret;
C_noret_decl(f_19233)
static void C_ccall f_19233(C_word c,C_word *av) C_noret;
C_noret_decl(f_19241)
static void C_ccall f_19241(C_word c,C_word *av) C_noret;
C_noret_decl(f_19243)
static void C_ccall f_19243(C_word c,C_word *av) C_noret;
C_noret_decl(f_19258)
static void C_ccall f_19258(C_word c,C_word *av) C_noret;
C_noret_decl(f_19261)
static void C_fcall f_19261(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19273)
static void C_fcall f_19273(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19284)
static void C_fcall f_19284(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19290)
static void C_ccall f_19290(C_word c,C_word *av) C_noret;
C_noret_decl(f_19296)
static void C_ccall f_19296(C_word c,C_word *av) C_noret;
C_noret_decl(f_19312)
static void C_ccall f_19312(C_word c,C_word *av) C_noret;
C_noret_decl(f_19315)
static void C_ccall f_19315(C_word c,C_word *av) C_noret;
C_noret_decl(f_19325)
static void C_ccall f_19325(C_word c,C_word *av) C_noret;
C_noret_decl(f_19351)
static void C_fcall f_19351(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19357)
static void C_ccall f_19357(C_word c,C_word *av) C_noret;
C_noret_decl(f_19363)
static void C_ccall f_19363(C_word c,C_word *av) C_noret;
C_noret_decl(f_19379)
static void C_ccall f_19379(C_word c,C_word *av) C_noret;
C_noret_decl(f_19385)
static void C_fcall f_19385(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19410)
static void C_ccall f_19410(C_word c,C_word *av) C_noret;
C_noret_decl(f_19448)
static void C_ccall f_19448(C_word c,C_word *av) C_noret;
C_noret_decl(f_19450)
static void C_fcall f_19450(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19475)
static void C_ccall f_19475(C_word c,C_word *av) C_noret;
C_noret_decl(f_19501)
static void C_ccall f_19501(C_word c,C_word *av) C_noret;
C_noret_decl(f_19503)
static void C_fcall f_19503(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19528)
static void C_ccall f_19528(C_word c,C_word *av) C_noret;
C_noret_decl(f_19537)
static void C_fcall f_19537(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19565)
static void C_fcall f_19565(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_19579)
static void C_ccall f_19579(C_word c,C_word *av) C_noret;
C_noret_decl(f_19613)
static void C_ccall f_19613(C_word c,C_word *av) C_noret;
C_noret_decl(f_19617)
static void C_ccall f_19617(C_word c,C_word *av) C_noret;
C_noret_decl(f_19651)
static void C_fcall f_19651(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19655)
static void C_ccall f_19655(C_word c,C_word *av) C_noret;
C_noret_decl(f_19663)
static void C_fcall f_19663(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19683)
static void C_ccall f_19683(C_word c,C_word *av) C_noret;
C_noret_decl(f_19699)
static void C_ccall f_19699(C_word c,C_word *av) C_noret;
C_noret_decl(f_19701)
static void C_fcall f_19701(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_19705)
static void C_ccall f_19705(C_word c,C_word *av) C_noret;
C_noret_decl(f_19768)
static void C_ccall f_19768(C_word c,C_word *av) C_noret;
C_noret_decl(f_19780)
static void C_ccall f_19780(C_word c,C_word *av) C_noret;
C_noret_decl(f_19784)
static void C_ccall f_19784(C_word c,C_word *av) C_noret;
C_noret_decl(f_19800)
static void C_ccall f_19800(C_word c,C_word *av) C_noret;
C_noret_decl(f_19804)
static void C_ccall f_19804(C_word c,C_word *av) C_noret;
C_noret_decl(f_19825)
static void C_ccall f_19825(C_word c,C_word *av) C_noret;
C_noret_decl(f_19848)
static void C_ccall f_19848(C_word c,C_word *av) C_noret;
C_noret_decl(f_19855)
static void C_ccall f_19855(C_word c,C_word *av) C_noret;
C_noret_decl(f_19858)
static void C_ccall f_19858(C_word c,C_word *av) C_noret;
C_noret_decl(f_19861)
static void C_ccall f_19861(C_word c,C_word *av) C_noret;
C_noret_decl(f_19914)
static void C_ccall f_19914(C_word c,C_word *av) C_noret;
C_noret_decl(f_19924)
static void C_ccall f_19924(C_word c,C_word *av) C_noret;
C_noret_decl(f_19951)
static void C_fcall f_19951(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_19969)
static void C_ccall f_19969(C_word c,C_word *av) C_noret;
C_noret_decl(f_20046)
static void C_fcall f_20046(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20048)
static void C_ccall f_20048(C_word c,C_word *av) C_noret;
C_noret_decl(f_20052)
static void C_ccall f_20052(C_word c,C_word *av) C_noret;
C_noret_decl(f_20055)
static void C_ccall f_20055(C_word c,C_word *av) C_noret;
C_noret_decl(f_20101)
static void C_ccall f_20101(C_word c,C_word *av) C_noret;
C_noret_decl(f_20104)
static void C_ccall f_20104(C_word c,C_word *av) C_noret;
C_noret_decl(f_20110)
static void C_fcall f_20110(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20114)
static void C_fcall f_20114(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20118)
static void C_ccall f_20118(C_word c,C_word *av) C_noret;
C_noret_decl(f_20125)
static void C_ccall f_20125(C_word c,C_word *av) C_noret;
C_noret_decl(f_20129)
static void C_ccall f_20129(C_word c,C_word *av) C_noret;
C_noret_decl(f_20141)
static void C_ccall f_20141(C_word c,C_word *av) C_noret;
C_noret_decl(f_20144)
static void C_ccall f_20144(C_word c,C_word *av) C_noret;
C_noret_decl(f_20147)
static void C_ccall f_20147(C_word c,C_word *av) C_noret;
C_noret_decl(f_20150)
static void C_ccall f_20150(C_word c,C_word *av) C_noret;
C_noret_decl(f_20153)
static void C_ccall f_20153(C_word c,C_word *av) C_noret;
C_noret_decl(f_20156)
static void C_ccall f_20156(C_word c,C_word *av) C_noret;
C_noret_decl(f_20159)
static void C_ccall f_20159(C_word c,C_word *av) C_noret;
C_noret_decl(f_20161)
static void C_ccall f_20161(C_word c,C_word *av) C_noret;
C_noret_decl(f_20170)
static void C_fcall f_20170(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20180)
static void C_fcall f_20180(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20202)
static void C_ccall f_20202(C_word c,C_word *av) C_noret;
C_noret_decl(f_20212)
static void C_ccall f_20212(C_word c,C_word *av) C_noret;
C_noret_decl(f_20215)
static void C_ccall f_20215(C_word c,C_word *av) C_noret;
C_noret_decl(f_20217)
static void C_fcall f_20217(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20261)
static void C_ccall f_20261(C_word c,C_word *av) C_noret;
C_noret_decl(f_20278)
static void C_ccall f_20278(C_word c,C_word *av) C_noret;
C_noret_decl(f_20284)
static void C_ccall f_20284(C_word c,C_word *av) C_noret;
C_noret_decl(f_20291)
static void C_ccall f_20291(C_word c,C_word *av) C_noret;
C_noret_decl(f_20315)
static void C_ccall f_20315(C_word c,C_word *av) C_noret;
C_noret_decl(f_20324)
static void C_ccall f_20324(C_word c,C_word *av) C_noret;
C_noret_decl(f_20327)
static void C_ccall f_20327(C_word c,C_word *av) C_noret;
C_noret_decl(f_20331)
static void C_ccall f_20331(C_word c,C_word *av) C_noret;
C_noret_decl(f_20335)
static void C_ccall f_20335(C_word c,C_word *av) C_noret;
C_noret_decl(f_20347)
static void C_fcall f_20347(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20377)
static void C_ccall f_20377(C_word c,C_word *av) C_noret;
C_noret_decl(f_20391)
static void C_ccall f_20391(C_word c,C_word *av) C_noret;
C_noret_decl(f_20395)
static void C_ccall f_20395(C_word c,C_word *av) C_noret;
C_noret_decl(f_20399)
static void C_ccall f_20399(C_word c,C_word *av) C_noret;
C_noret_decl(f_20422)
static void C_ccall f_20422(C_word c,C_word *av) C_noret;
C_noret_decl(f_20424)
static void C_fcall f_20424(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_20427)
static void C_fcall f_20427(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20436)
static void C_fcall f_20436(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20487)
static void C_ccall f_20487(C_word c,C_word *av) C_noret;
C_noret_decl(f_20491)
static void C_fcall f_20491(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20495)
static void C_ccall f_20495(C_word c,C_word *av) C_noret;
C_noret_decl(f_20499)
static void C_fcall f_20499(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20507)
static void C_ccall f_20507(C_word c,C_word *av) C_noret;
C_noret_decl(f_20509)
static void C_ccall f_20509(C_word c,C_word *av) C_noret;
C_noret_decl(f_20533)
static void C_fcall f_20533(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20558)
static void C_ccall f_20558(C_word c,C_word *av) C_noret;
C_noret_decl(f_20569)
static void C_ccall f_20569(C_word c,C_word *av) C_noret;
C_noret_decl(f_20579)
static void C_ccall f_20579(C_word c,C_word *av) C_noret;
C_noret_decl(f_20581)
static void C_fcall f_20581(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20606)
static void C_ccall f_20606(C_word c,C_word *av) C_noret;
C_noret_decl(f_20623)
static void C_ccall f_20623(C_word c,C_word *av) C_noret;
C_noret_decl(f_20625)
static void C_fcall f_20625(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20639)
static void C_fcall f_20639(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20655)
static void C_ccall f_20655(C_word c,C_word *av) C_noret;
C_noret_decl(f_20674)
static void C_ccall f_20674(C_word c,C_word *av) C_noret;
C_noret_decl(f_20680)
static void C_ccall f_20680(C_word c,C_word *av) C_noret;
C_noret_decl(f_20682)
static void C_fcall f_20682(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20692)
static void C_ccall f_20692(C_word c,C_word *av) C_noret;
C_noret_decl(f_20712)
static void C_ccall f_20712(C_word c,C_word *av) C_noret;
C_noret_decl(f_20715)
static void C_ccall f_20715(C_word c,C_word *av) C_noret;
C_noret_decl(f_20726)
static void C_ccall f_20726(C_word c,C_word *av) C_noret;
C_noret_decl(f_20729)
static void C_ccall f_20729(C_word c,C_word *av) C_noret;
C_noret_decl(f_20749)
static void C_fcall f_20749(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20756)
static void C_ccall f_20756(C_word c,C_word *av) C_noret;
C_noret_decl(f_20759)
static void C_ccall f_20759(C_word c,C_word *av) C_noret;
C_noret_decl(f_20785)
static void C_fcall f_20785(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20798)
static void C_ccall f_20798(C_word c,C_word *av) C_noret;
C_noret_decl(f_20800)
static void C_fcall f_20800(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20825)
static void C_ccall f_20825(C_word c,C_word *av) C_noret;
C_noret_decl(f_20840)
static void C_fcall f_20840(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20847)
static void C_ccall f_20847(C_word c,C_word *av) C_noret;
C_noret_decl(f_20850)
static void C_ccall f_20850(C_word c,C_word *av) C_noret;
C_noret_decl(f_20857)
static void C_ccall f_20857(C_word c,C_word *av) C_noret;
C_noret_decl(f_20866)
static void C_fcall f_20866(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20872)
static void C_fcall f_20872(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20885)
static void C_ccall f_20885(C_word c,C_word *av) C_noret;
C_noret_decl(f_20901)
static void C_ccall f_20901(C_word c,C_word *av) C_noret;
C_noret_decl(f_20907)
static void C_ccall f_20907(C_word c,C_word *av) C_noret;
C_noret_decl(f_20910)
static void C_ccall f_20910(C_word c,C_word *av) C_noret;
C_noret_decl(f_20913)
static void C_ccall f_20913(C_word c,C_word *av) C_noret;
C_noret_decl(f_20916)
static void C_ccall f_20916(C_word c,C_word *av) C_noret;
C_noret_decl(f_20924)
static void C_ccall f_20924(C_word c,C_word *av) C_noret;
C_noret_decl(f_20937)
static void C_ccall f_20937(C_word c,C_word *av) C_noret;
C_noret_decl(f_20939)
static void C_fcall f_20939(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20964)
static void C_ccall f_20964(C_word c,C_word *av) C_noret;
C_noret_decl(f_20980)
static void C_ccall f_20980(C_word c,C_word *av) C_noret;
C_noret_decl(f_20992)
static void C_fcall f_20992(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21001)
static void C_ccall f_21001(C_word c,C_word *av) C_noret;
C_noret_decl(f_21010)
static void C_fcall f_21010(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21069)
static void C_ccall f_21069(C_word c,C_word *av) C_noret;
C_noret_decl(f_21071)
static void C_fcall f_21071(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21096)
static void C_ccall f_21096(C_word c,C_word *av) C_noret;
C_noret_decl(f_21121)
static void C_ccall f_21121(C_word c,C_word *av) C_noret;
C_noret_decl(f_21127)
static void C_ccall f_21127(C_word c,C_word *av) C_noret;
C_noret_decl(f_21130)
static void C_ccall f_21130(C_word c,C_word *av) C_noret;
C_noret_decl(f_21133)
static void C_ccall f_21133(C_word c,C_word *av) C_noret;
C_noret_decl(f_21164)
static void C_ccall f_21164(C_word c,C_word *av) C_noret;
C_noret_decl(f_21167)
static void C_fcall f_21167(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21170)
static void C_ccall f_21170(C_word c,C_word *av) C_noret;
C_noret_decl(f_21187)
static void C_fcall f_21187(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21212)
static void C_ccall f_21212(C_word c,C_word *av) C_noret;
C_noret_decl(f_21221)
static void C_fcall f_21221(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21246)
static void C_ccall f_21246(C_word c,C_word *av) C_noret;
C_noret_decl(f_21283)
static void C_ccall f_21283(C_word c,C_word *av) C_noret;
C_noret_decl(f_21290)
static void C_ccall f_21290(C_word c,C_word *av) C_noret;
C_noret_decl(f_21294)
static void C_ccall f_21294(C_word c,C_word *av) C_noret;
C_noret_decl(f_21296)
static void C_ccall f_21296(C_word c,C_word *av) C_noret;
C_noret_decl(f_21304)
static void C_ccall f_21304(C_word c,C_word *av) C_noret;
C_noret_decl(f_21306)
static void C_fcall f_21306(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21310)
static void C_ccall f_21310(C_word c,C_word *av) C_noret;
C_noret_decl(f_21315)
static void C_fcall f_21315(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21341)
static void C_ccall f_21341(C_word c,C_word *av) C_noret;
C_noret_decl(f_21346)
static void C_fcall f_21346(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21358)
static void C_fcall f_21358(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21383)
static void C_ccall f_21383(C_word c,C_word *av) C_noret;
C_noret_decl(f_21400)
static void C_ccall f_21400(C_word c,C_word *av) C_noret;
C_noret_decl(f_21409)
static void C_ccall f_21409(C_word c,C_word *av) C_noret;
C_noret_decl(f_21411)
static void C_fcall f_21411(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21419)
static void C_ccall f_21419(C_word c,C_word *av) C_noret;
C_noret_decl(f_21423)
static void C_ccall f_21423(C_word c,C_word *av) C_noret;
C_noret_decl(f_21425)
static void C_ccall f_21425(C_word c,C_word *av) C_noret;
C_noret_decl(f_21433)
static void C_ccall f_21433(C_word c,C_word *av) C_noret;
C_noret_decl(f_21435)
static void C_fcall f_21435(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21439)
static void C_ccall f_21439(C_word c,C_word *av) C_noret;
C_noret_decl(f_21448)
static void C_ccall f_21448(C_word c,C_word *av) C_noret;
C_noret_decl(f_21454)
static void C_ccall f_21454(C_word c,C_word *av) C_noret;
C_noret_decl(f_21457)
static void C_ccall f_21457(C_word c,C_word *av) C_noret;
C_noret_decl(f_21460)
static void C_ccall f_21460(C_word c,C_word *av) C_noret;
C_noret_decl(f_21465)
static void C_fcall f_21465(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21478)
static void C_ccall f_21478(C_word c,C_word *av) C_noret;
C_noret_decl(f_21484)
static void C_ccall f_21484(C_word c,C_word *av) C_noret;
C_noret_decl(f_21487)
static void C_ccall f_21487(C_word c,C_word *av) C_noret;
C_noret_decl(f_21490)
static void C_ccall f_21490(C_word c,C_word *av) C_noret;
C_noret_decl(f_21497)
static void C_ccall f_21497(C_word c,C_word *av) C_noret;
C_noret_decl(f_21515)
static void C_fcall f_21515(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21529)
static void C_fcall f_21529(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21533)
static void C_ccall f_21533(C_word c,C_word *av) C_noret;
C_noret_decl(f_21537)
static void C_ccall f_21537(C_word c,C_word *av) C_noret;
C_noret_decl(f_21543)
static void C_ccall f_21543(C_word c,C_word *av) C_noret;
C_noret_decl(f_21551)
static void C_ccall f_21551(C_word c,C_word *av) C_noret;
C_noret_decl(f_21557)
static void C_ccall f_21557(C_word c,C_word *av) C_noret;
C_noret_decl(f_21565)
static void C_ccall f_21565(C_word c,C_word *av) C_noret;
C_noret_decl(f_21569)
static void C_ccall f_21569(C_word c,C_word *av) C_noret;
C_noret_decl(f_21575)
static void C_ccall f_21575(C_word c,C_word *av) C_noret;
C_noret_decl(f_21578)
static void C_ccall f_21578(C_word c,C_word *av) C_noret;
C_noret_decl(f_21581)
static void C_ccall f_21581(C_word c,C_word *av) C_noret;
C_noret_decl(f_21584)
static void C_ccall f_21584(C_word c,C_word *av) C_noret;
C_noret_decl(f_21587)
static void C_ccall f_21587(C_word c,C_word *av) C_noret;
C_noret_decl(f_21593)
static void C_ccall f_21593(C_word c,C_word *av) C_noret;
C_noret_decl(f_21596)
static void C_ccall f_21596(C_word c,C_word *av) C_noret;
C_noret_decl(f_21599)
static void C_ccall f_21599(C_word c,C_word *av) C_noret;
C_noret_decl(f_21602)
static void C_ccall f_21602(C_word c,C_word *av) C_noret;
C_noret_decl(f_21605)
static void C_ccall f_21605(C_word c,C_word *av) C_noret;
C_noret_decl(f_21621)
static void C_ccall f_21621(C_word c,C_word *av) C_noret;
C_noret_decl(f_21635)
static void C_fcall f_21635(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21639)
static void C_ccall f_21639(C_word c,C_word *av) C_noret;
C_noret_decl(f_21642)
static void C_ccall f_21642(C_word c,C_word *av) C_noret;
C_noret_decl(f_21655)
static void C_ccall f_21655(C_word c,C_word *av) C_noret;
C_noret_decl(f_21659)
static void C_ccall f_21659(C_word c,C_word *av) C_noret;
C_noret_decl(f_21674)
static void C_ccall f_21674(C_word c,C_word *av) C_noret;
C_noret_decl(f_21686)
static void C_fcall f_21686(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21692)
static void C_ccall f_21692(C_word c,C_word *av) C_noret;
C_noret_decl(f_21698)
static void C_ccall f_21698(C_word c,C_word *av) C_noret;
C_noret_decl(f_21705)
static void C_ccall f_21705(C_word c,C_word *av) C_noret;
C_noret_decl(f_21711)
static void C_ccall f_21711(C_word c,C_word *av) C_noret;
C_noret_decl(f_21714)
static void C_ccall f_21714(C_word c,C_word *av) C_noret;
C_noret_decl(f_21717)
static void C_ccall f_21717(C_word c,C_word *av) C_noret;
C_noret_decl(f_21720)
static void C_ccall f_21720(C_word c,C_word *av) C_noret;
C_noret_decl(f_21723)
static void C_ccall f_21723(C_word c,C_word *av) C_noret;
C_noret_decl(f_21729)
static void C_ccall f_21729(C_word c,C_word *av) C_noret;
C_noret_decl(f_21735)
static void C_ccall f_21735(C_word c,C_word *av) C_noret;
C_noret_decl(f_21738)
static void C_ccall f_21738(C_word c,C_word *av) C_noret;
C_noret_decl(f_21741)
static void C_ccall f_21741(C_word c,C_word *av) C_noret;
C_noret_decl(f_21746)
static void C_fcall f_21746(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21749)
static void C_fcall f_21749(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21757)
static void C_ccall f_21757(C_word c,C_word *av) C_noret;
C_noret_decl(f_21761)
static void C_ccall f_21761(C_word c,C_word *av) C_noret;
C_noret_decl(f_21763)
static void C_fcall f_21763(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21767)
static void C_ccall f_21767(C_word c,C_word *av) C_noret;
C_noret_decl(f_21787)
static void C_ccall f_21787(C_word c,C_word *av) C_noret;
C_noret_decl(f_21794)
static void C_ccall f_21794(C_word c,C_word *av) C_noret;
C_noret_decl(f_21815)
static void C_ccall f_21815(C_word c,C_word *av) C_noret;
C_noret_decl(f_21825)
static void C_ccall f_21825(C_word c,C_word *av) C_noret;
C_noret_decl(f_21829)
static void C_ccall f_21829(C_word c,C_word *av) C_noret;
C_noret_decl(f_21833)
static void C_ccall f_21833(C_word c,C_word *av) C_noret;
C_noret_decl(f_21837)
static void C_ccall f_21837(C_word c,C_word *av) C_noret;
C_noret_decl(f_21841)
static void C_ccall f_21841(C_word c,C_word *av) C_noret;
C_noret_decl(f_21845)
static void C_ccall f_21845(C_word c,C_word *av) C_noret;
C_noret_decl(f_21849)
static void C_ccall f_21849(C_word c,C_word *av) C_noret;
C_noret_decl(f_21853)
static void C_ccall f_21853(C_word c,C_word *av) C_noret;
C_noret_decl(f_21860)
static void C_ccall f_21860(C_word c,C_word *av) C_noret;
C_noret_decl(f_21876)
static void C_ccall f_21876(C_word c,C_word *av) C_noret;
C_noret_decl(f_21879)
static void C_fcall f_21879(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21885)
static void C_ccall f_21885(C_word c,C_word *av) C_noret;
C_noret_decl(f_21901)
static void C_ccall f_21901(C_word c,C_word *av) C_noret;
C_noret_decl(f_21907)
static void C_ccall f_21907(C_word c,C_word *av) C_noret;
C_noret_decl(f_21914)
static void C_ccall f_21914(C_word c,C_word *av) C_noret;
C_noret_decl(f_21918)
static void C_ccall f_21918(C_word c,C_word *av) C_noret;
C_noret_decl(f_21922)
static void C_ccall f_21922(C_word c,C_word *av) C_noret;
C_noret_decl(f_21926)
static void C_ccall f_21926(C_word c,C_word *av) C_noret;
C_noret_decl(f_21929)
static void C_ccall f_21929(C_word c,C_word *av) C_noret;
C_noret_decl(f_21933)
static void C_ccall f_21933(C_word c,C_word *av) C_noret;
C_noret_decl(f_21937)
static void C_ccall f_21937(C_word c,C_word *av) C_noret;
C_noret_decl(f_21943)
static void C_ccall f_21943(C_word c,C_word *av) C_noret;
C_noret_decl(f_21946)
static void C_ccall f_21946(C_word c,C_word *av) C_noret;
C_noret_decl(f_21960)
static void C_fcall f_21960(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21978)
static void C_ccall f_21978(C_word c,C_word *av) C_noret;
C_noret_decl(f_21991)
static void C_ccall f_21991(C_word c,C_word *av) C_noret;
C_noret_decl(f_21995)
static void C_ccall f_21995(C_word c,C_word *av) C_noret;
C_noret_decl(f_21999)
static void C_ccall f_21999(C_word c,C_word *av) C_noret;
C_noret_decl(f_22005)
static void C_ccall f_22005(C_word c,C_word *av) C_noret;
C_noret_decl(f_22016)
static void C_ccall f_22016(C_word c,C_word *av) C_noret;
C_noret_decl(f_22020)
static void C_ccall f_22020(C_word c,C_word *av) C_noret;
C_noret_decl(f_22024)
static void C_ccall f_22024(C_word c,C_word *av) C_noret;
C_noret_decl(f_22028)
static void C_ccall f_22028(C_word c,C_word *av) C_noret;
C_noret_decl(f_22032)
static void C_ccall f_22032(C_word c,C_word *av) C_noret;
C_noret_decl(f_22043)
static void C_ccall f_22043(C_word c,C_word *av) C_noret;
C_noret_decl(f_22047)
static void C_ccall f_22047(C_word c,C_word *av) C_noret;
C_noret_decl(f_22051)
static void C_ccall f_22051(C_word c,C_word *av) C_noret;
C_noret_decl(f_22055)
static void C_ccall f_22055(C_word c,C_word *av) C_noret;
C_noret_decl(f_22059)
static void C_ccall f_22059(C_word c,C_word *av) C_noret;
C_noret_decl(f_22066)
static void C_ccall f_22066(C_word c,C_word *av) C_noret;
C_noret_decl(f_22077)
static void C_ccall f_22077(C_word c,C_word *av) C_noret;
C_noret_decl(f_22081)
static void C_ccall f_22081(C_word c,C_word *av) C_noret;
C_noret_decl(f_22085)
static void C_ccall f_22085(C_word c,C_word *av) C_noret;
C_noret_decl(f_22101)
static void C_ccall f_22101(C_word c,C_word *av) C_noret;
C_noret_decl(f_22105)
static void C_ccall f_22105(C_word c,C_word *av) C_noret;
C_noret_decl(f_22110)
static void C_fcall f_22110(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7) C_noret;
C_noret_decl(f_22115)
static void C_ccall f_22115(C_word c,C_word *av) C_noret;
C_noret_decl(f_22126)
static void C_ccall f_22126(C_word c,C_word *av) C_noret;
C_noret_decl(f_22130)
static void C_ccall f_22130(C_word c,C_word *av) C_noret;
C_noret_decl(f_22134)
static void C_ccall f_22134(C_word c,C_word *av) C_noret;
C_noret_decl(f_22138)
static void C_ccall f_22138(C_word c,C_word *av) C_noret;
C_noret_decl(f_22142)
static void C_ccall f_22142(C_word c,C_word *av) C_noret;
C_noret_decl(f_22146)
static void C_ccall f_22146(C_word c,C_word *av) C_noret;
C_noret_decl(f_22150)
static void C_ccall f_22150(C_word c,C_word *av) C_noret;
C_noret_decl(f_22154)
static void C_ccall f_22154(C_word c,C_word *av) C_noret;
C_noret_decl(f_22156)
static void C_ccall f_22156(C_word c,C_word *av) C_noret;
C_noret_decl(f_22161)
static void C_ccall f_22161(C_word c,C_word *av) C_noret;
C_noret_decl(f_22163)
static void C_ccall f_22163(C_word c,C_word *av) C_noret;
C_noret_decl(f_22175)
static void C_ccall f_22175(C_word c,C_word *av) C_noret;
C_noret_decl(f_22179)
static void C_ccall f_22179(C_word c,C_word *av) C_noret;
C_noret_decl(f_22183)
static void C_ccall f_22183(C_word c,C_word *av) C_noret;
C_noret_decl(f_22187)
static void C_ccall f_22187(C_word c,C_word *av) C_noret;
C_noret_decl(f_22191)
static void C_ccall f_22191(C_word c,C_word *av) C_noret;
C_noret_decl(f_22197)
static void C_ccall f_22197(C_word c,C_word *av) C_noret;
C_noret_decl(f_22200)
static void C_ccall f_22200(C_word c,C_word *av) C_noret;
C_noret_decl(f_22203)
static void C_ccall f_22203(C_word c,C_word *av) C_noret;
C_noret_decl(f_22210)
static void C_ccall f_22210(C_word c,C_word *av) C_noret;
C_noret_decl(f_22226)
static void C_ccall f_22226(C_word c,C_word *av) C_noret;
C_noret_decl(f_22232)
static void C_ccall f_22232(C_word c,C_word *av) C_noret;
C_noret_decl(f_22235)
static void C_ccall f_22235(C_word c,C_word *av) C_noret;
C_noret_decl(f_22238)
static void C_ccall f_22238(C_word c,C_word *av) C_noret;
C_noret_decl(f_22241)
static void C_ccall f_22241(C_word c,C_word *av) C_noret;
C_noret_decl(f_22249)
static void C_fcall f_22249(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_22254)
static void C_ccall f_22254(C_word c,C_word *av) C_noret;
C_noret_decl(f_22261)
static void C_ccall f_22261(C_word c,C_word *av) C_noret;
C_noret_decl(f_22269)
static void C_ccall f_22269(C_word c,C_word *av) C_noret;
C_noret_decl(f_22273)
static void C_ccall f_22273(C_word c,C_word *av) C_noret;
C_noret_decl(f_22277)
static void C_ccall f_22277(C_word c,C_word *av) C_noret;
C_noret_decl(f_22281)
static void C_ccall f_22281(C_word c,C_word *av) C_noret;
C_noret_decl(f_22285)
static void C_ccall f_22285(C_word c,C_word *av) C_noret;
C_noret_decl(f_22291)
static void C_ccall f_22291(C_word c,C_word *av) C_noret;
C_noret_decl(f_22294)
static void C_ccall f_22294(C_word c,C_word *av) C_noret;
C_noret_decl(f_22297)
static void C_ccall f_22297(C_word c,C_word *av) C_noret;
C_noret_decl(f_22303)
static void C_ccall f_22303(C_word c,C_word *av) C_noret;
C_noret_decl(f_22309)
static void C_ccall f_22309(C_word c,C_word *av) C_noret;
C_noret_decl(f_22312)
static void C_ccall f_22312(C_word c,C_word *av) C_noret;
C_noret_decl(f_22315)
static void C_ccall f_22315(C_word c,C_word *av) C_noret;
C_noret_decl(f_22318)
static void C_ccall f_22318(C_word c,C_word *av) C_noret;
C_noret_decl(f_22321)
static void C_ccall f_22321(C_word c,C_word *av) C_noret;
C_noret_decl(f_22324)
static void C_ccall f_22324(C_word c,C_word *av) C_noret;
C_noret_decl(f_22327)
static void C_ccall f_22327(C_word c,C_word *av) C_noret;
C_noret_decl(f_22334)
static void C_ccall f_22334(C_word c,C_word *av) C_noret;
C_noret_decl(f_22340)
static void C_ccall f_22340(C_word c,C_word *av) C_noret;
C_noret_decl(f_22343)
static void C_ccall f_22343(C_word c,C_word *av) C_noret;
C_noret_decl(f_22346)
static void C_ccall f_22346(C_word c,C_word *av) C_noret;
C_noret_decl(f_22352)
static void C_ccall f_22352(C_word c,C_word *av) C_noret;
C_noret_decl(f_22358)
static void C_ccall f_22358(C_word c,C_word *av) C_noret;
C_noret_decl(f_22361)
static void C_ccall f_22361(C_word c,C_word *av) C_noret;
C_noret_decl(f_22364)
static void C_ccall f_22364(C_word c,C_word *av) C_noret;
C_noret_decl(f_22371)
static void C_ccall f_22371(C_word c,C_word *av) C_noret;
C_noret_decl(f_22381)
static void C_ccall f_22381(C_word c,C_word *av) C_noret;
C_noret_decl(f_22384)
static void C_fcall f_22384(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22396)
static void C_ccall f_22396(C_word c,C_word *av) C_noret;
C_noret_decl(f_22400)
static void C_ccall f_22400(C_word c,C_word *av) C_noret;
C_noret_decl(f_22404)
static void C_ccall f_22404(C_word c,C_word *av) C_noret;
C_noret_decl(f_22420)
static void C_ccall f_22420(C_word c,C_word *av) C_noret;
C_noret_decl(f_22426)
static void C_ccall f_22426(C_word c,C_word *av) C_noret;
C_noret_decl(f_22429)
static void C_ccall f_22429(C_word c,C_word *av) C_noret;
C_noret_decl(f_22432)
static void C_ccall f_22432(C_word c,C_word *av) C_noret;
C_noret_decl(f_22435)
static void C_ccall f_22435(C_word c,C_word *av) C_noret;
C_noret_decl(f_22443)
static void C_ccall f_22443(C_word c,C_word *av) C_noret;
C_noret_decl(f_22446)
static void C_fcall f_22446(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22458)
static void C_ccall f_22458(C_word c,C_word *av) C_noret;
C_noret_decl(f_22462)
static void C_ccall f_22462(C_word c,C_word *av) C_noret;
C_noret_decl(f_22466)
static void C_ccall f_22466(C_word c,C_word *av) C_noret;
C_noret_decl(f_22470)
static void C_ccall f_22470(C_word c,C_word *av) C_noret;
C_noret_decl(f_22483)
static void C_ccall f_22483(C_word c,C_word *av) C_noret;
C_noret_decl(f_22489)
static void C_ccall f_22489(C_word c,C_word *av) C_noret;
C_noret_decl(f_22492)
static void C_ccall f_22492(C_word c,C_word *av) C_noret;
C_noret_decl(f_22495)
static void C_ccall f_22495(C_word c,C_word *av) C_noret;
C_noret_decl(f_22498)
static void C_ccall f_22498(C_word c,C_word *av) C_noret;
C_noret_decl(f_22502)
static void C_ccall f_22502(C_word c,C_word *av) C_noret;
C_noret_decl(f_22509)
static void C_ccall f_22509(C_word c,C_word *av) C_noret;
C_noret_decl(f_22515)
static void C_ccall f_22515(C_word c,C_word *av) C_noret;
C_noret_decl(f_22518)
static void C_ccall f_22518(C_word c,C_word *av) C_noret;
C_noret_decl(f_22521)
static void C_ccall f_22521(C_word c,C_word *av) C_noret;
C_noret_decl(f_22524)
static void C_ccall f_22524(C_word c,C_word *av) C_noret;
C_noret_decl(f_22527)
static void C_ccall f_22527(C_word c,C_word *av) C_noret;
C_noret_decl(f_22530)
static void C_ccall f_22530(C_word c,C_word *av) C_noret;
C_noret_decl(f_22534)
static void C_ccall f_22534(C_word c,C_word *av) C_noret;
C_noret_decl(f_22540)
static void C_ccall f_22540(C_word c,C_word *av) C_noret;
C_noret_decl(f_22543)
static void C_ccall f_22543(C_word c,C_word *av) C_noret;
C_noret_decl(f_22546)
static void C_ccall f_22546(C_word c,C_word *av) C_noret;
C_noret_decl(f_22549)
static void C_ccall f_22549(C_word c,C_word *av) C_noret;
C_noret_decl(f_22557)
static void C_ccall f_22557(C_word c,C_word *av) C_noret;
C_noret_decl(f_22563)
static void C_ccall f_22563(C_word c,C_word *av) C_noret;
C_noret_decl(f_22566)
static void C_fcall f_22566(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22578)
static void C_ccall f_22578(C_word c,C_word *av) C_noret;
C_noret_decl(f_22582)
static void C_ccall f_22582(C_word c,C_word *av) C_noret;
C_noret_decl(f_22586)
static void C_ccall f_22586(C_word c,C_word *av) C_noret;
C_noret_decl(f_22590)
static void C_ccall f_22590(C_word c,C_word *av) C_noret;
C_noret_decl(f_22603)
static void C_ccall f_22603(C_word c,C_word *av) C_noret;
C_noret_decl(f_22609)
static void C_ccall f_22609(C_word c,C_word *av) C_noret;
C_noret_decl(f_22612)
static void C_ccall f_22612(C_word c,C_word *av) C_noret;
C_noret_decl(f_22615)
static void C_ccall f_22615(C_word c,C_word *av) C_noret;
C_noret_decl(f_22618)
static void C_ccall f_22618(C_word c,C_word *av) C_noret;
C_noret_decl(f_22622)
static void C_ccall f_22622(C_word c,C_word *av) C_noret;
C_noret_decl(f_22629)
static void C_ccall f_22629(C_word c,C_word *av) C_noret;
C_noret_decl(f_22635)
static void C_ccall f_22635(C_word c,C_word *av) C_noret;
C_noret_decl(f_22638)
static void C_ccall f_22638(C_word c,C_word *av) C_noret;
C_noret_decl(f_22641)
static void C_ccall f_22641(C_word c,C_word *av) C_noret;
C_noret_decl(f_22644)
static void C_ccall f_22644(C_word c,C_word *av) C_noret;
C_noret_decl(f_22647)
static void C_ccall f_22647(C_word c,C_word *av) C_noret;
C_noret_decl(f_22650)
static void C_ccall f_22650(C_word c,C_word *av) C_noret;
C_noret_decl(f_22654)
static void C_ccall f_22654(C_word c,C_word *av) C_noret;
C_noret_decl(f_22660)
static void C_ccall f_22660(C_word c,C_word *av) C_noret;
C_noret_decl(f_22663)
static void C_ccall f_22663(C_word c,C_word *av) C_noret;
C_noret_decl(f_22666)
static void C_ccall f_22666(C_word c,C_word *av) C_noret;
C_noret_decl(f_22669)
static void C_ccall f_22669(C_word c,C_word *av) C_noret;
C_noret_decl(f_22677)
static void C_ccall f_22677(C_word c,C_word *av) C_noret;
C_noret_decl(f_22688)
static void C_ccall f_22688(C_word c,C_word *av) C_noret;
C_noret_decl(f_22699)
static void C_ccall f_22699(C_word c,C_word *av) C_noret;
C_noret_decl(f_22703)
static void C_ccall f_22703(C_word c,C_word *av) C_noret;
C_noret_decl(f_22707)
static void C_ccall f_22707(C_word c,C_word *av) C_noret;
C_noret_decl(f_22711)
static void C_ccall f_22711(C_word c,C_word *av) C_noret;
C_noret_decl(f_22715)
static void C_ccall f_22715(C_word c,C_word *av) C_noret;
C_noret_decl(f_22722)
static void C_ccall f_22722(C_word c,C_word *av) C_noret;
C_noret_decl(f_22733)
static void C_ccall f_22733(C_word c,C_word *av) C_noret;
C_noret_decl(f_22737)
static void C_ccall f_22737(C_word c,C_word *av) C_noret;
C_noret_decl(f_22741)
static void C_ccall f_22741(C_word c,C_word *av) C_noret;
C_noret_decl(f_22745)
static void C_ccall f_22745(C_word c,C_word *av) C_noret;
C_noret_decl(f_22749)
static void C_ccall f_22749(C_word c,C_word *av) C_noret;
C_noret_decl(f_22763)
static void C_ccall f_22763(C_word c,C_word *av) C_noret;
C_noret_decl(f_22767)
static void C_ccall f_22767(C_word c,C_word *av) C_noret;
C_noret_decl(f_22771)
static void C_ccall f_22771(C_word c,C_word *av) C_noret;
C_noret_decl(f_22785)
static void C_ccall f_22785(C_word c,C_word *av) C_noret;
C_noret_decl(f_22789)
static void C_ccall f_22789(C_word c,C_word *av) C_noret;
C_noret_decl(f_22803)
static void C_ccall f_22803(C_word c,C_word *av) C_noret;
C_noret_decl(f_22807)
static void C_ccall f_22807(C_word c,C_word *av) C_noret;
C_noret_decl(f_22811)
static void C_ccall f_22811(C_word c,C_word *av) C_noret;
C_noret_decl(f_22825)
static void C_ccall f_22825(C_word c,C_word *av) C_noret;
C_noret_decl(f_22829)
static void C_ccall f_22829(C_word c,C_word *av) C_noret;
C_noret_decl(f_22837)
static void C_ccall f_22837(C_word c,C_word *av) C_noret;
C_noret_decl(f_22851)
static void C_ccall f_22851(C_word c,C_word *av) C_noret;
C_noret_decl(f_22855)
static void C_ccall f_22855(C_word c,C_word *av) C_noret;
C_noret_decl(f_22859)
static void C_ccall f_22859(C_word c,C_word *av) C_noret;
C_noret_decl(f_22863)
static void C_ccall f_22863(C_word c,C_word *av) C_noret;
C_noret_decl(f_22883)
static void C_ccall f_22883(C_word c,C_word *av) C_noret;
C_noret_decl(f_22887)
static void C_ccall f_22887(C_word c,C_word *av) C_noret;
C_noret_decl(f_22891)
static void C_ccall f_22891(C_word c,C_word *av) C_noret;
C_noret_decl(f_22895)
static void C_ccall f_22895(C_word c,C_word *av) C_noret;
C_noret_decl(f_22899)
static void C_ccall f_22899(C_word c,C_word *av) C_noret;
C_noret_decl(f_22903)
static void C_ccall f_22903(C_word c,C_word *av) C_noret;
C_noret_decl(f_22913)
static void C_ccall f_22913(C_word c,C_word *av) C_noret;
C_noret_decl(f_22915)
static void C_fcall f_22915(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22940)
static void C_ccall f_22940(C_word c,C_word *av) C_noret;
C_noret_decl(f_22952)
static void C_ccall f_22952(C_word c,C_word *av) C_noret;
C_noret_decl(f_22959)
static void C_ccall f_22959(C_word c,C_word *av) C_noret;
C_noret_decl(f_22973)
static void C_ccall f_22973(C_word c,C_word *av) C_noret;
C_noret_decl(f_22977)
static void C_ccall f_22977(C_word c,C_word *av) C_noret;
C_noret_decl(f_22989)
static void C_ccall f_22989(C_word c,C_word *av) C_noret;
C_noret_decl(f_23001)
static void C_ccall f_23001(C_word c,C_word *av) C_noret;
C_noret_decl(f_23019)
static void C_ccall f_23019(C_word c,C_word *av) C_noret;
C_noret_decl(f_23023)
static void C_ccall f_23023(C_word c,C_word *av) C_noret;
C_noret_decl(f_23027)
static void C_ccall f_23027(C_word c,C_word *av) C_noret;
C_noret_decl(f_23031)
static void C_ccall f_23031(C_word c,C_word *av) C_noret;
C_noret_decl(f_23035)
static void C_ccall f_23035(C_word c,C_word *av) C_noret;
C_noret_decl(f_23039)
static void C_ccall f_23039(C_word c,C_word *av) C_noret;
C_noret_decl(f_23043)
static void C_ccall f_23043(C_word c,C_word *av) C_noret;
C_noret_decl(f_23046)
static void C_ccall f_23046(C_word c,C_word *av) C_noret;
C_noret_decl(f_23054)
static void C_fcall f_23054(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_23065)
static void C_ccall f_23065(C_word c,C_word *av) C_noret;
C_noret_decl(f_23071)
static void C_ccall f_23071(C_word c,C_word *av) C_noret;
C_noret_decl(f_23074)
static void C_ccall f_23074(C_word c,C_word *av) C_noret;
C_noret_decl(f_23077)
static void C_ccall f_23077(C_word c,C_word *av) C_noret;
C_noret_decl(f_23080)
static void C_ccall f_23080(C_word c,C_word *av) C_noret;
C_noret_decl(f_23088)
static void C_ccall f_23088(C_word c,C_word *av) C_noret;
C_noret_decl(f_23092)
static void C_ccall f_23092(C_word c,C_word *av) C_noret;
C_noret_decl(f_23096)
static void C_ccall f_23096(C_word c,C_word *av) C_noret;
C_noret_decl(f_23100)
static void C_ccall f_23100(C_word c,C_word *av) C_noret;
C_noret_decl(f_23103)
static void C_ccall f_23103(C_word c,C_word *av) C_noret;
C_noret_decl(f_23109)
static void C_ccall f_23109(C_word c,C_word *av) C_noret;
C_noret_decl(f_23112)
static void C_ccall f_23112(C_word c,C_word *av) C_noret;
C_noret_decl(f_23115)
static void C_ccall f_23115(C_word c,C_word *av) C_noret;
C_noret_decl(f_23118)
static void C_ccall f_23118(C_word c,C_word *av) C_noret;
C_noret_decl(f_23121)
static void C_ccall f_23121(C_word c,C_word *av) C_noret;
C_noret_decl(f_23128)
static void C_ccall f_23128(C_word c,C_word *av) C_noret;
C_noret_decl(f_23132)
static void C_ccall f_23132(C_word c,C_word *av) C_noret;
C_noret_decl(f_23144)
static void C_ccall f_23144(C_word c,C_word *av) C_noret;
C_noret_decl(f_23148)
static void C_ccall f_23148(C_word c,C_word *av) C_noret;
C_noret_decl(f_23189)
static void C_ccall f_23189(C_word c,C_word *av) C_noret;
C_noret_decl(f_23206)
static void C_ccall f_23206(C_word c,C_word *av) C_noret;
C_noret_decl(f_23227)
static void C_ccall f_23227(C_word c,C_word *av) C_noret;
C_noret_decl(f_23229)
static void C_fcall f_23229(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23263)
static void C_ccall f_23263(C_word c,C_word *av) C_noret;
C_noret_decl(f_23284)
static void C_ccall f_23284(C_word c,C_word *av) C_noret;
C_noret_decl(f_23286)
static void C_fcall f_23286(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23320)
static void C_ccall f_23320(C_word c,C_word *av) C_noret;
C_noret_decl(f_23345)
static void C_ccall f_23345(C_word c,C_word *av) C_noret;
C_noret_decl(f_23347)
static void C_fcall f_23347(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23385)
static void C_ccall f_23385(C_word c,C_word *av) C_noret;
C_noret_decl(f_23410)
static void C_ccall f_23410(C_word c,C_word *av) C_noret;
C_noret_decl(f_23412)
static void C_fcall f_23412(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23452)
static void C_ccall f_23452(C_word c,C_word *av) C_noret;
C_noret_decl(f_23454)
static void C_ccall f_23454(C_word c,C_word *av) C_noret;
C_noret_decl(f_23462)
static void C_ccall f_23462(C_word c,C_word *av) C_noret;
C_noret_decl(f_23464)
static void C_ccall f_23464(C_word c,C_word *av) C_noret;
C_noret_decl(f_23480)
static void C_ccall f_23480(C_word c,C_word *av) C_noret;
C_noret_decl(f_23484)
static void C_ccall f_23484(C_word c,C_word *av) C_noret;
C_noret_decl(f_23493)
static void C_ccall f_23493(C_word c,C_word *av) C_noret;
C_noret_decl(f_23520)
static void C_ccall f_23520(C_word c,C_word *av) C_noret;
C_noret_decl(f_23531)
static void C_ccall f_23531(C_word c,C_word *av) C_noret;
C_noret_decl(f_23537)
static void C_ccall f_23537(C_word c,C_word *av) C_noret;
C_noret_decl(f_23541)
static void C_ccall f_23541(C_word c,C_word *av) C_noret;
C_noret_decl(f_23594)
static void C_ccall f_23594(C_word c,C_word *av) C_noret;
C_noret_decl(f_23598)
static void C_ccall f_23598(C_word c,C_word *av) C_noret;
C_noret_decl(f_23602)
static void C_ccall f_23602(C_word c,C_word *av) C_noret;
C_noret_decl(f_6792)
static void C_ccall f_6792(C_word c,C_word *av) C_noret;
C_noret_decl(f_6795)
static void C_ccall f_6795(C_word c,C_word *av) C_noret;
C_noret_decl(f_6798)
static void C_ccall f_6798(C_word c,C_word *av) C_noret;
C_noret_decl(f_6801)
static void C_ccall f_6801(C_word c,C_word *av) C_noret;
C_noret_decl(f_6804)
static void C_ccall f_6804(C_word c,C_word *av) C_noret;
C_noret_decl(f_6807)
static void C_ccall f_6807(C_word c,C_word *av) C_noret;
C_noret_decl(f_6810)
static void C_ccall f_6810(C_word c,C_word *av) C_noret;
C_noret_decl(f_6813)
static void C_ccall f_6813(C_word c,C_word *av) C_noret;
C_noret_decl(f_6816)
static void C_ccall f_6816(C_word c,C_word *av) C_noret;
C_noret_decl(f_6882)
static void C_fcall f_6882(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6896)
static void C_ccall f_6896(C_word c,C_word *av) C_noret;
C_noret_decl(f_6920)
static void C_ccall f_6920(C_word c,C_word *av) C_noret;
C_noret_decl(f_6926)
static void C_fcall f_6926(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6944)
static void C_ccall f_6944(C_word c,C_word *av) C_noret;
C_noret_decl(f_6984)
static void C_fcall f_6984(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_6998)
static void C_ccall f_6998(C_word c,C_word *av) C_noret;
C_noret_decl(f_7017)
static void C_fcall f_7017(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7032)
static void C_fcall f_7032(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7040)
static void C_fcall f_7040(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7048)
static void C_ccall f_7048(C_word c,C_word *av) C_noret;
C_noret_decl(f_7059)
static void C_ccall f_7059(C_word c,C_word *av) C_noret;
C_noret_decl(f_7072)
static void C_fcall f_7072(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7079)
static void C_ccall f_7079(C_word c,C_word *av) C_noret;
C_noret_decl(f_7086)
static void C_ccall f_7086(C_word c,C_word *av) C_noret;
C_noret_decl(f_7090)
static void C_ccall f_7090(C_word c,C_word *av) C_noret;
C_noret_decl(f_7102)
static void C_ccall f_7102(C_word c,C_word *av) C_noret;
C_noret_decl(f_7104)
static void C_fcall f_7104(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7151)
static void C_ccall f_7151(C_word c,C_word *av) C_noret;
C_noret_decl(f_7153)
static void C_fcall f_7153(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7187)
static void C_fcall f_7187(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7193)
static void C_fcall f_7193(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7215)
static void C_ccall f_7215(C_word c,C_word *av) C_noret;
C_noret_decl(f_7221)
static void C_fcall f_7221(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7227)
static void C_fcall f_7227(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7237)
static void C_ccall f_7237(C_word c,C_word *av) C_noret;
C_noret_decl(f_7257)
static void C_fcall f_7257(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7271)
static void C_ccall f_7271(C_word c,C_word *av) C_noret;
C_noret_decl(f_7285)
static void C_fcall f_7285(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7303)
static void C_ccall f_7303(C_word c,C_word *av) C_noret;
C_noret_decl(f_7313)
static void C_fcall f_7313(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7326)
static void C_ccall f_7326(C_word c,C_word *av) C_noret;
C_noret_decl(f_7340)
static void C_ccall f_7340(C_word c,C_word *av) C_noret;
C_noret_decl(f_7382)
static void C_fcall f_7382(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7388)
static void C_fcall f_7388(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7402)
static void C_ccall f_7402(C_word c,C_word *av) C_noret;
C_noret_decl(f_7415)
static void C_ccall f_7415(C_word c,C_word *av) C_noret;
C_noret_decl(f_7471)
static void C_fcall f_7471(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7480)
static void C_fcall f_7480(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7488)
static void C_fcall f_7488(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7492)
static void C_ccall f_7492(C_word c,C_word *av) C_noret;
C_noret_decl(f_7496)
static C_word C_fcall f_7496(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_7514)
static void C_ccall f_7514(C_word c,C_word *av) C_noret;
C_noret_decl(f_7536)
static void C_ccall f_7536(C_word c,C_word *av) C_noret;
C_noret_decl(f_7553)
static void C_fcall f_7553(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7652)
static void C_fcall f_7652(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7738)
static void C_fcall f_7738(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7763)
static void C_fcall f_7763(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7786)
static void C_ccall f_7786(C_word c,C_word *av) C_noret;
C_noret_decl(f_7791)
static void C_ccall f_7791(C_word c,C_word *av) C_noret;
C_noret_decl(f_7805)
static void C_ccall f_7805(C_word c,C_word *av) C_noret;
C_noret_decl(f_7829)
static void C_fcall f_7829(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7835)
static void C_fcall f_7835(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7849)
static void C_ccall f_7849(C_word c,C_word *av) C_noret;
C_noret_decl(f_7853)
static void C_ccall f_7853(C_word c,C_word *av) C_noret;
C_noret_decl(f_7865)
static void C_ccall f_7865(C_word c,C_word *av) C_noret;
C_noret_decl(f_7871)
static void C_fcall f_7871(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7883)
static void C_ccall f_7883(C_word c,C_word *av) C_noret;
C_noret_decl(f_7948)
static C_word C_fcall f_7948(C_word t0,C_word t1);
C_noret_decl(f_8009)
static void C_ccall f_8009(C_word c,C_word *av) C_noret;
C_noret_decl(f_8012)
static void C_fcall f_8012(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8021)
static void C_ccall f_8021(C_word c,C_word *av) C_noret;
C_noret_decl(f_8141)
static void C_ccall f_8141(C_word c,C_word *av) C_noret;
C_noret_decl(f_8149)
static void C_ccall f_8149(C_word c,C_word *av) C_noret;
C_noret_decl(f_8151)
static void C_ccall f_8151(C_word c,C_word *av) C_noret;
C_noret_decl(f_8194)
static void C_ccall f_8194(C_word c,C_word *av) C_noret;
C_noret_decl(f_8231)
static void C_fcall f_8231(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8244)
static void C_ccall f_8244(C_word c,C_word *av) C_noret;
C_noret_decl(f_8256)
static void C_ccall f_8256(C_word c,C_word *av) C_noret;
C_noret_decl(f_8259)
static void C_ccall f_8259(C_word c,C_word *av) C_noret;
C_noret_decl(f_8320)
static void C_ccall f_8320(C_word c,C_word *av) C_noret;
C_noret_decl(f_8322)
static void C_fcall f_8322(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8347)
static void C_ccall f_8347(C_word c,C_word *av) C_noret;
C_noret_decl(f_8371)
static void C_ccall f_8371(C_word c,C_word *av) C_noret;
C_noret_decl(f_8375)
static void C_ccall f_8375(C_word c,C_word *av) C_noret;
C_noret_decl(f_8408)
static void C_ccall f_8408(C_word c,C_word *av) C_noret;
C_noret_decl(f_8411)
static void C_ccall f_8411(C_word c,C_word *av) C_noret;
C_noret_decl(f_8413)
static void C_fcall f_8413(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8438)
static void C_ccall f_8438(C_word c,C_word *av) C_noret;
C_noret_decl(f_8483)
static void C_ccall f_8483(C_word c,C_word *av) C_noret;
C_noret_decl(f_8487)
static void C_fcall f_8487(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8497)
static void C_ccall f_8497(C_word c,C_word *av) C_noret;
C_noret_decl(f_8506)
static void C_ccall f_8506(C_word c,C_word *av) C_noret;
C_noret_decl(f_8526)
static void C_fcall f_8526(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8538)
static C_word C_fcall f_8538(C_word t0,C_word t1);
C_noret_decl(f_8557)
static void C_fcall f_8557(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_8561)
static void C_ccall f_8561(C_word c,C_word *av) C_noret;
C_noret_decl(f_8573)
static void C_fcall f_8573(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8611)
static void C_ccall f_8611(C_word c,C_word *av) C_noret;
C_noret_decl(f_8618)
static void C_ccall f_8618(C_word c,C_word *av) C_noret;
C_noret_decl(f_8620)
static void C_ccall f_8620(C_word c,C_word *av) C_noret;
C_noret_decl(f_8652)
static void C_ccall f_8652(C_word c,C_word *av) C_noret;
C_noret_decl(f_8682)
static void C_fcall f_8682(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_8686)
static void C_ccall f_8686(C_word c,C_word *av) C_noret;
C_noret_decl(f_8692)
static void C_ccall f_8692(C_word c,C_word *av) C_noret;
C_noret_decl(f_8704)
static void C_ccall f_8704(C_word c,C_word *av) C_noret;
C_noret_decl(f_8706)
static void C_fcall f_8706(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8734)
static void C_ccall f_8734(C_word c,C_word *av) C_noret;
C_noret_decl(f_8737)
static void C_ccall f_8737(C_word c,C_word *av) C_noret;
C_noret_decl(f_8750)
static void C_ccall f_8750(C_word c,C_word *av) C_noret;
C_noret_decl(f_8753)
static void C_ccall f_8753(C_word c,C_word *av) C_noret;
C_noret_decl(f_8756)
static void C_ccall f_8756(C_word c,C_word *av) C_noret;
C_noret_decl(f_8772)
static void C_fcall f_8772(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_8782)
static void C_ccall f_8782(C_word c,C_word *av) C_noret;
C_noret_decl(f_8788)
static void C_ccall f_8788(C_word c,C_word *av) C_noret;
C_noret_decl(f_8798)
static void C_ccall f_8798(C_word c,C_word *av) C_noret;
C_noret_decl(f_8807)
static void C_fcall f_8807(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8810)
static void C_ccall f_8810(C_word c,C_word *av) C_noret;
C_noret_decl(f_8817)
static void C_ccall f_8817(C_word c,C_word *av) C_noret;
C_noret_decl(f_8823)
static void C_ccall f_8823(C_word c,C_word *av) C_noret;
C_noret_decl(f_8828)
static void C_ccall f_8828(C_word c,C_word *av) C_noret;
C_noret_decl(f_8834)
static void C_ccall f_8834(C_word c,C_word *av) C_noret;
C_noret_decl(f_8838)
static void C_ccall f_8838(C_word c,C_word *av) C_noret;
C_noret_decl(f_8841)
static void C_ccall f_8841(C_word c,C_word *av) C_noret;
C_noret_decl(f_8844)
static void C_fcall f_8844(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8847)
static void C_ccall f_8847(C_word c,C_word *av) C_noret;
C_noret_decl(f_8850)
static void C_ccall f_8850(C_word c,C_word *av) C_noret;
C_noret_decl(f_8853)
static void C_fcall f_8853(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8856)
static void C_fcall f_8856(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8859)
static void C_ccall f_8859(C_word c,C_word *av) C_noret;
C_noret_decl(f_8872)
static void C_fcall f_8872(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8884)
static void C_fcall f_8884(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8909)
static void C_ccall f_8909(C_word c,C_word *av) C_noret;
C_noret_decl(f_8919)
static void C_fcall f_8919(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8928)
static void C_ccall f_8928(C_word c,C_word *av) C_noret;
C_noret_decl(f_8940)
static void C_ccall f_8940(C_word c,C_word *av) C_noret;
C_noret_decl(f_8947)
static void C_ccall f_8947(C_word c,C_word *av) C_noret;
C_noret_decl(f_8950)
static void C_ccall f_8950(C_word c,C_word *av) C_noret;
C_noret_decl(f_8953)
static void C_ccall f_8953(C_word c,C_word *av) C_noret;
C_noret_decl(f_8987)
static void C_fcall f_8987(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8994)
static void C_ccall f_8994(C_word c,C_word *av) C_noret;
C_noret_decl(f_8997)
static void C_ccall f_8997(C_word c,C_word *av) C_noret;
C_noret_decl(f_9003)
static void C_ccall f_9003(C_word c,C_word *av) C_noret;
C_noret_decl(f_9032)
static void C_ccall f_9032(C_word c,C_word *av) C_noret;
C_noret_decl(f_9036)
static void C_ccall f_9036(C_word c,C_word *av) C_noret;
C_noret_decl(f_9054)
static void C_ccall f_9054(C_word c,C_word *av) C_noret;
C_noret_decl(f_9057)
static void C_ccall f_9057(C_word c,C_word *av) C_noret;
C_noret_decl(f_9060)
static void C_ccall f_9060(C_word c,C_word *av) C_noret;
C_noret_decl(f_9066)
static void C_ccall f_9066(C_word c,C_word *av) C_noret;
C_noret_decl(f_9099)
static void C_ccall f_9099(C_word c,C_word *av) C_noret;
C_noret_decl(f_9103)
static void C_ccall f_9103(C_word c,C_word *av) C_noret;
C_noret_decl(f_9142)
static void C_ccall f_9142(C_word c,C_word *av) C_noret;
C_noret_decl(f_9146)
static void C_fcall f_9146(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9165)
static void C_fcall f_9165(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9169)
static void C_fcall f_9169(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9175)
static void C_fcall f_9175(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9189)
static void C_ccall f_9189(C_word c,C_word *av) C_noret;
C_noret_decl(f_9195)
static void C_ccall f_9195(C_word c,C_word *av) C_noret;
C_noret_decl(f_9209)
static void C_ccall f_9209(C_word c,C_word *av) C_noret;
C_noret_decl(f_9240)
static void C_ccall f_9240(C_word c,C_word *av) C_noret;
C_noret_decl(f_9253)
static void C_ccall f_9253(C_word c,C_word *av) C_noret;
C_noret_decl(f_9263)
static void C_ccall f_9263(C_word c,C_word *av) C_noret;
C_noret_decl(f_9265)
static void C_ccall f_9265(C_word c,C_word *av) C_noret;
C_noret_decl(f_9294)
static void C_fcall f_9294(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_9307)
static void C_ccall f_9307(C_word c,C_word *av) C_noret;
C_noret_decl(f_9323)
static void C_ccall f_9323(C_word c,C_word *av) C_noret;
C_noret_decl(f_9334)
static void C_ccall f_9334(C_word c,C_word *av) C_noret;
C_noret_decl(f_9338)
static void C_ccall f_9338(C_word c,C_word *av) C_noret;
C_noret_decl(f_9366)
static void C_ccall f_9366(C_word c,C_word *av) C_noret;
C_noret_decl(f_9370)
static void C_ccall f_9370(C_word c,C_word *av) C_noret;
C_noret_decl(f_9372)
static void C_fcall f_9372(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9406)
static C_word C_fcall f_9406(C_word *a,C_word t0);
C_noret_decl(f_9411)
static void C_fcall f_9411(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_9417)
static void C_fcall f_9417(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9422)
static void C_ccall f_9422(C_word c,C_word *av) C_noret;
C_noret_decl(f_9444)
static void C_fcall f_9444(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9451)
static void C_ccall f_9451(C_word c,C_word *av) C_noret;
C_noret_decl(f_9454)
static void C_ccall f_9454(C_word c,C_word *av) C_noret;
C_noret_decl(f_9457)
static void C_ccall f_9457(C_word c,C_word *av) C_noret;
C_noret_decl(f_9463)
static void C_ccall f_9463(C_word c,C_word *av) C_noret;
C_noret_decl(f_9467)
static void C_fcall f_9467(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9474)
static void C_ccall f_9474(C_word c,C_word *av) C_noret;
C_noret_decl(f_9482)
static void C_fcall f_9482(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9507)
static void C_ccall f_9507(C_word c,C_word *av) C_noret;
C_noret_decl(f_9516)
static void C_ccall f_9516(C_word c,C_word *av) C_noret;
C_noret_decl(f_9522)
static void C_ccall f_9522(C_word c,C_word *av) C_noret;
C_noret_decl(f_9540)
static void C_fcall f_9540(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7) C_noret;
C_noret_decl(f_9544)
static void C_ccall f_9544(C_word c,C_word *av) C_noret;
C_noret_decl(f_9547)
static void C_ccall f_9547(C_word c,C_word *av) C_noret;
C_noret_decl(f_9550)
static void C_ccall f_9550(C_word c,C_word *av) C_noret;
C_noret_decl(f_9558)
static void C_ccall f_9558(C_word c,C_word *av) C_noret;
C_noret_decl(f_9586)
static void C_ccall f_9586(C_word c,C_word *av) C_noret;
C_noret_decl(f_9628)
static void C_ccall f_9628(C_word c,C_word *av) C_noret;
C_noret_decl(f_9645)
static void C_ccall f_9645(C_word c,C_word *av) C_noret;
C_noret_decl(f_9665)
static void C_ccall f_9665(C_word c,C_word *av) C_noret;
C_noret_decl(f_9682)
static void C_ccall f_9682(C_word c,C_word *av) C_noret;
C_noret_decl(f_9701)
static void C_ccall f_9701(C_word c,C_word *av) C_noret;
C_noret_decl(f_9707)
static void C_fcall f_9707(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9712)
static void C_ccall f_9712(C_word c,C_word *av) C_noret;
C_noret_decl(f_9731)
static void C_ccall f_9731(C_word c,C_word *av) C_noret;
C_noret_decl(f_9734)
static void C_ccall f_9734(C_word c,C_word *av) C_noret;
C_noret_decl(f_9738)
static void C_ccall f_9738(C_word c,C_word *av) C_noret;
C_noret_decl(f_9745)
static void C_ccall f_9745(C_word c,C_word *av) C_noret;
C_noret_decl(f_9757)
static void C_fcall f_9757(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9760)
static void C_ccall f_9760(C_word c,C_word *av) C_noret;
C_noret_decl(f_9792)
static void C_fcall f_9792(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9821)
static void C_ccall f_9821(C_word c,C_word *av) C_noret;
C_noret_decl(f_9886)
static void C_fcall f_9886(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9920)
static void C_fcall f_9920(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9930)
static void C_ccall f_9930(C_word c,C_word *av) C_noret;
C_noret_decl(f_9976)
static void C_ccall f_9976(C_word c,C_word *av) C_noret;
C_noret_decl(f_9980)
static void C_ccall f_9980(C_word c,C_word *av) C_noret;
C_noret_decl(f_9982)
static void C_ccall f_9982(C_word c,C_word *av) C_noret;
C_noret_decl(C_scrutinizer_toplevel)
C_externexport void C_ccall C_scrutinizer_toplevel(C_word c,C_word *av) C_noret;

C_noret_decl(trf_10005)
static void C_ccall trf_10005(C_word c,C_word *av) C_noret;
static void C_ccall trf_10005(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_10005(t0,t1,t2,t3,t4);}

C_noret_decl(trf_10035)
static void C_ccall trf_10035(C_word c,C_word *av) C_noret;
static void C_ccall trf_10035(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10035(t0,t1);}

C_noret_decl(trf_10051)
static void C_ccall trf_10051(C_word c,C_word *av) C_noret;
static void C_ccall trf_10051(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10051(t0,t1);}

C_noret_decl(trf_10164)
static void C_ccall trf_10164(C_word c,C_word *av) C_noret;
static void C_ccall trf_10164(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_10164(t0,t1,t2,t3,t4);}

C_noret_decl(trf_10172)
static void C_ccall trf_10172(C_word c,C_word *av) C_noret;
static void C_ccall trf_10172(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10172(t0,t1);}

C_noret_decl(trf_10176)
static void C_ccall trf_10176(C_word c,C_word *av) C_noret;
static void C_ccall trf_10176(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10176(t0,t1,t2);}

C_noret_decl(trf_10257)
static void C_ccall trf_10257(C_word c,C_word *av) C_noret;
static void C_ccall trf_10257(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10257(t0,t1);}

C_noret_decl(trf_10303)
static void C_ccall trf_10303(C_word c,C_word *av) C_noret;
static void C_ccall trf_10303(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10303(t0,t1,t2,t3);}

C_noret_decl(trf_10412)
static void C_ccall trf_10412(C_word c,C_word *av) C_noret;
static void C_ccall trf_10412(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10412(t0,t1);}

C_noret_decl(trf_10420)
static void C_ccall trf_10420(C_word c,C_word *av) C_noret;
static void C_ccall trf_10420(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10420(t0,t1,t2,t3);}

C_noret_decl(trf_10518)
static void C_ccall trf_10518(C_word c,C_word *av) C_noret;
static void C_ccall trf_10518(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10518(t0,t1);}

C_noret_decl(trf_10533)
static void C_ccall trf_10533(C_word c,C_word *av) C_noret;
static void C_ccall trf_10533(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10533(t0,t1);}

C_noret_decl(trf_10644)
static void C_ccall trf_10644(C_word c,C_word *av) C_noret;
static void C_ccall trf_10644(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10644(t0,t1);}

C_noret_decl(trf_10647)
static void C_ccall trf_10647(C_word c,C_word *av) C_noret;
static void C_ccall trf_10647(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10647(t0,t1);}

C_noret_decl(trf_10667)
static void C_ccall trf_10667(C_word c,C_word *av) C_noret;
static void C_ccall trf_10667(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10667(t0,t1);}

C_noret_decl(trf_10743)
static void C_ccall trf_10743(C_word c,C_word *av) C_noret;
static void C_ccall trf_10743(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10743(t0,t1,t2,t3);}

C_noret_decl(trf_10807)
static void C_ccall trf_10807(C_word c,C_word *av) C_noret;
static void C_ccall trf_10807(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10807(t0,t1);}

C_noret_decl(trf_10814)
static void C_ccall trf_10814(C_word c,C_word *av) C_noret;
static void C_ccall trf_10814(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10814(t0,t1);}

C_noret_decl(trf_10865)
static void C_ccall trf_10865(C_word c,C_word *av) C_noret;
static void C_ccall trf_10865(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10865(t0,t1,t2);}

C_noret_decl(trf_10877)
static void C_ccall trf_10877(C_word c,C_word *av) C_noret;
static void C_ccall trf_10877(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10877(t0,t1,t2);}

C_noret_decl(trf_10919)
static void C_ccall trf_10919(C_word c,C_word *av) C_noret;
static void C_ccall trf_10919(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10919(t0,t1,t2,t3);}

C_noret_decl(trf_10944)
static void C_ccall trf_10944(C_word c,C_word *av) C_noret;
static void C_ccall trf_10944(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10944(t0,t1);}

C_noret_decl(trf_11038)
static void C_ccall trf_11038(C_word c,C_word *av) C_noret;
static void C_ccall trf_11038(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11038(t0,t1,t2);}

C_noret_decl(trf_11105)
static void C_ccall trf_11105(C_word c,C_word *av) C_noret;
static void C_ccall trf_11105(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11105(t0,t1,t2);}

C_noret_decl(trf_11117)
static void C_ccall trf_11117(C_word c,C_word *av) C_noret;
static void C_ccall trf_11117(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11117(t0,t1,t2);}

C_noret_decl(trf_11151)
static void C_ccall trf_11151(C_word c,C_word *av) C_noret;
static void C_ccall trf_11151(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11151(t0,t1,t2,t3);}

C_noret_decl(trf_11227)
static void C_ccall trf_11227(C_word c,C_word *av) C_noret;
static void C_ccall trf_11227(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11227(t0,t1,t2);}

C_noret_decl(trf_11265)
static void C_ccall trf_11265(C_word c,C_word *av) C_noret;
static void C_ccall trf_11265(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11265(t0,t1,t2,t3);}

C_noret_decl(trf_11354)
static void C_ccall trf_11354(C_word c,C_word *av) C_noret;
static void C_ccall trf_11354(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11354(t0,t1);}

C_noret_decl(trf_11357)
static void C_ccall trf_11357(C_word c,C_word *av) C_noret;
static void C_ccall trf_11357(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11357(t0,t1);}

C_noret_decl(trf_11427)
static void C_ccall trf_11427(C_word c,C_word *av) C_noret;
static void C_ccall trf_11427(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11427(t0,t1,t2,t3);}

C_noret_decl(trf_11511)
static void C_ccall trf_11511(C_word c,C_word *av) C_noret;
static void C_ccall trf_11511(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11511(t0,t1,t2);}

C_noret_decl(trf_11523)
static void C_ccall trf_11523(C_word c,C_word *av) C_noret;
static void C_ccall trf_11523(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11523(t0,t1,t2);}

C_noret_decl(trf_11673)
static void C_ccall trf_11673(C_word c,C_word *av) C_noret;
static void C_ccall trf_11673(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11673(t0,t1,t2);}

C_noret_decl(trf_11712)
static void C_ccall trf_11712(C_word c,C_word *av) C_noret;
static void C_ccall trf_11712(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11712(t0,t1);}

C_noret_decl(trf_11718)
static void C_ccall trf_11718(C_word c,C_word *av) C_noret;
static void C_ccall trf_11718(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11718(t0,t1,t2);}

C_noret_decl(trf_11748)
static void C_ccall trf_11748(C_word c,C_word *av) C_noret;
static void C_ccall trf_11748(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11748(t0,t1,t2,t3);}

C_noret_decl(trf_11802)
static void C_ccall trf_11802(C_word c,C_word *av) C_noret;
static void C_ccall trf_11802(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11802(t0,t1,t2);}

C_noret_decl(trf_11923)
static void C_ccall trf_11923(C_word c,C_word *av) C_noret;
static void C_ccall trf_11923(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11923(t0,t1,t2,t3);}

C_noret_decl(trf_11932)
static void C_ccall trf_11932(C_word c,C_word *av) C_noret;
static void C_ccall trf_11932(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_11932(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_12054)
static void C_ccall trf_12054(C_word c,C_word *av) C_noret;
static void C_ccall trf_12054(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12054(t0,t1,t2,t3);}

C_noret_decl(trf_12117)
static void C_ccall trf_12117(C_word c,C_word *av) C_noret;
static void C_ccall trf_12117(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12117(t0,t1,t2,t3);}

C_noret_decl(trf_12185)
static void C_ccall trf_12185(C_word c,C_word *av) C_noret;
static void C_ccall trf_12185(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12185(t0,t1,t2,t3);}

C_noret_decl(trf_12207)
static void C_ccall trf_12207(C_word c,C_word *av) C_noret;
static void C_ccall trf_12207(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12207(t0,t1,t2,t3);}

C_noret_decl(trf_12213)
static void C_ccall trf_12213(C_word c,C_word *av) C_noret;
static void C_ccall trf_12213(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12213(t0,t1,t2,t3);}

C_noret_decl(trf_12243)
static void C_ccall trf_12243(C_word c,C_word *av) C_noret;
static void C_ccall trf_12243(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12243(t0,t1,t2,t3);}

C_noret_decl(trf_12260)
static void C_ccall trf_12260(C_word c,C_word *av) C_noret;
static void C_ccall trf_12260(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12260(t0,t1,t2);}

C_noret_decl(trf_12301)
static void C_ccall trf_12301(C_word c,C_word *av) C_noret;
static void C_ccall trf_12301(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12301(t0,t1,t2);}

C_noret_decl(trf_12392)
static void C_ccall trf_12392(C_word c,C_word *av) C_noret;
static void C_ccall trf_12392(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12392(t0,t1,t2);}

C_noret_decl(trf_12509)
static void C_ccall trf_12509(C_word c,C_word *av) C_noret;
static void C_ccall trf_12509(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12509(t0,t1,t2);}

C_noret_decl(trf_12523)
static void C_ccall trf_12523(C_word c,C_word *av) C_noret;
static void C_ccall trf_12523(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12523(t0,t1,t2);}

C_noret_decl(trf_12759)
static void C_ccall trf_12759(C_word c,C_word *av) C_noret;
static void C_ccall trf_12759(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12759(t0,t1);}

C_noret_decl(trf_13496)
static void C_ccall trf_13496(C_word c,C_word *av) C_noret;
static void C_ccall trf_13496(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13496(t0,t1,t2,t3);}

C_noret_decl(trf_13502)
static void C_ccall trf_13502(C_word c,C_word *av) C_noret;
static void C_ccall trf_13502(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13502(t0,t1,t2,t3);}

C_noret_decl(trf_13568)
static void C_ccall trf_13568(C_word c,C_word *av) C_noret;
static void C_ccall trf_13568(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13568(t0,t1);}

C_noret_decl(trf_13571)
static void C_ccall trf_13571(C_word c,C_word *av) C_noret;
static void C_ccall trf_13571(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13571(t0,t1,t2);}

C_noret_decl(trf_13652)
static void C_ccall trf_13652(C_word c,C_word *av) C_noret;
static void C_ccall trf_13652(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13652(t0,t1,t2);}

C_noret_decl(trf_13739)
static void C_ccall trf_13739(C_word c,C_word *av) C_noret;
static void C_ccall trf_13739(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13739(t0,t1,t2,t3);}

C_noret_decl(trf_13781)
static void C_ccall trf_13781(C_word c,C_word *av) C_noret;
static void C_ccall trf_13781(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13781(t0,t1);}

C_noret_decl(trf_13859)
static void C_ccall trf_13859(C_word c,C_word *av) C_noret;
static void C_ccall trf_13859(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13859(t0,t1,t2,t3);}

C_noret_decl(trf_14003)
static void C_ccall trf_14003(C_word c,C_word *av) C_noret;
static void C_ccall trf_14003(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14003(t0,t1,t2);}

C_noret_decl(trf_14200)
static void C_ccall trf_14200(C_word c,C_word *av) C_noret;
static void C_ccall trf_14200(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14200(t0,t1,t2);}

C_noret_decl(trf_14256)
static void C_ccall trf_14256(C_word c,C_word *av) C_noret;
static void C_ccall trf_14256(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14256(t0,t1,t2);}

C_noret_decl(trf_14329)
static void C_ccall trf_14329(C_word c,C_word *av) C_noret;
static void C_ccall trf_14329(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14329(t0,t1,t2);}

C_noret_decl(trf_14376)
static void C_ccall trf_14376(C_word c,C_word *av) C_noret;
static void C_ccall trf_14376(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14376(t0,t1,t2);}

C_noret_decl(trf_14454)
static void C_ccall trf_14454(C_word c,C_word *av) C_noret;
static void C_ccall trf_14454(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14454(t0,t1,t2);}

C_noret_decl(trf_14502)
static void C_ccall trf_14502(C_word c,C_word *av) C_noret;
static void C_ccall trf_14502(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14502(t0,t1,t2);}

C_noret_decl(trf_14537)
static void C_ccall trf_14537(C_word c,C_word *av) C_noret;
static void C_ccall trf_14537(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14537(t0,t1,t2);}

C_noret_decl(trf_14718)
static void C_ccall trf_14718(C_word c,C_word *av) C_noret;
static void C_ccall trf_14718(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_14718(t0,t1,t2,t3);}

C_noret_decl(trf_14775)
static void C_ccall trf_14775(C_word c,C_word *av) C_noret;
static void C_ccall trf_14775(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_14775(t0,t1,t2,t3);}

C_noret_decl(trf_14843)
static void C_ccall trf_14843(C_word c,C_word *av) C_noret;
static void C_ccall trf_14843(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14843(t0,t1);}

C_noret_decl(trf_14871)
static void C_ccall trf_14871(C_word c,C_word *av) C_noret;
static void C_ccall trf_14871(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_14871(t0,t1,t2,t3);}

C_noret_decl(trf_14879)
static void C_ccall trf_14879(C_word c,C_word *av) C_noret;
static void C_ccall trf_14879(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14879(t0,t1,t2);}

C_noret_decl(trf_14893)
static void C_ccall trf_14893(C_word c,C_word *av) C_noret;
static void C_ccall trf_14893(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14893(t0,t1,t2);}

C_noret_decl(trf_14960)
static void C_ccall trf_14960(C_word c,C_word *av) C_noret;
static void C_ccall trf_14960(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14960(t0,t1);}

C_noret_decl(trf_14994)
static void C_ccall trf_14994(C_word c,C_word *av) C_noret;
static void C_ccall trf_14994(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14994(t0,t1);}

C_noret_decl(trf_15025)
static void C_ccall trf_15025(C_word c,C_word *av) C_noret;
static void C_ccall trf_15025(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15025(t0,t1,t2,t3);}

C_noret_decl(trf_15236)
static void C_ccall trf_15236(C_word c,C_word *av) C_noret;
static void C_ccall trf_15236(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15236(t0,t1);}

C_noret_decl(trf_15287)
static void C_ccall trf_15287(C_word c,C_word *av) C_noret;
static void C_ccall trf_15287(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15287(t0,t1);}

C_noret_decl(trf_15344)
static void C_ccall trf_15344(C_word c,C_word *av) C_noret;
static void C_ccall trf_15344(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15344(t0,t1);}

C_noret_decl(trf_15401)
static void C_ccall trf_15401(C_word c,C_word *av) C_noret;
static void C_ccall trf_15401(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_15401(t0,t1,t2,t3,t4);}

C_noret_decl(trf_15410)
static void C_ccall trf_15410(C_word c,C_word *av) C_noret;
static void C_ccall trf_15410(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15410(t0,t1,t2,t3);}

C_noret_decl(trf_15427)
static void C_ccall trf_15427(C_word c,C_word *av) C_noret;
static void C_ccall trf_15427(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15427(t0,t1);}

C_noret_decl(trf_15429)
static void C_ccall trf_15429(C_word c,C_word *av) C_noret;
static void C_ccall trf_15429(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_15429(t0,t1,t2,t3,t4);}

C_noret_decl(trf_15564)
static void C_ccall trf_15564(C_word c,C_word *av) C_noret;
static void C_ccall trf_15564(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15564(t0,t1,t2);}

C_noret_decl(trf_15624)
static void C_ccall trf_15624(C_word c,C_word *av) C_noret;
static void C_ccall trf_15624(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15624(t0,t1,t2);}

C_noret_decl(trf_15635)
static void C_ccall trf_15635(C_word c,C_word *av) C_noret;
static void C_ccall trf_15635(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15635(t0,t1,t2);}

C_noret_decl(trf_15665)
static void C_ccall trf_15665(C_word c,C_word *av) C_noret;
static void C_ccall trf_15665(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15665(t0,t1);}

C_noret_decl(trf_15667)
static void C_ccall trf_15667(C_word c,C_word *av) C_noret;
static void C_ccall trf_15667(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15667(t0,t1,t2);}

C_noret_decl(trf_15981)
static void C_ccall trf_15981(C_word c,C_word *av) C_noret;
static void C_ccall trf_15981(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15981(t0,t1,t2);}

C_noret_decl(trf_16043)
static void C_ccall trf_16043(C_word c,C_word *av) C_noret;
static void C_ccall trf_16043(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16043(t0,t1,t2);}

C_noret_decl(trf_16070)
static void C_ccall trf_16070(C_word c,C_word *av) C_noret;
static void C_ccall trf_16070(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16070(t0,t1,t2);}

C_noret_decl(trf_16116)
static void C_ccall trf_16116(C_word c,C_word *av) C_noret;
static void C_ccall trf_16116(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16116(t0,t1,t2);}

C_noret_decl(trf_16143)
static void C_ccall trf_16143(C_word c,C_word *av) C_noret;
static void C_ccall trf_16143(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16143(t0,t1,t2);}

C_noret_decl(trf_16229)
static void C_ccall trf_16229(C_word c,C_word *av) C_noret;
static void C_ccall trf_16229(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16229(t0,t1,t2);}

C_noret_decl(trf_16254)
static void C_ccall trf_16254(C_word c,C_word *av) C_noret;
static void C_ccall trf_16254(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16254(t0,t1);}

C_noret_decl(trf_16276)
static void C_ccall trf_16276(C_word c,C_word *av) C_noret;
static void C_ccall trf_16276(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16276(t0,t1,t2);}

C_noret_decl(trf_16307)
static void C_ccall trf_16307(C_word c,C_word *av) C_noret;
static void C_ccall trf_16307(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16307(t0,t1,t2);}

C_noret_decl(trf_16360)
static void C_ccall trf_16360(C_word c,C_word *av) C_noret;
static void C_ccall trf_16360(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_16360(t0,t1,t2,t3);}

C_noret_decl(trf_16368)
static void C_ccall trf_16368(C_word c,C_word *av) C_noret;
static void C_ccall trf_16368(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16368(t0,t1,t2);}

C_noret_decl(trf_16449)
static void C_ccall trf_16449(C_word c,C_word *av) C_noret;
static void C_ccall trf_16449(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16449(t0,t1,t2);}

C_noret_decl(trf_16462)
static void C_ccall trf_16462(C_word c,C_word *av) C_noret;
static void C_ccall trf_16462(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16462(t0,t1,t2);}

C_noret_decl(trf_16546)
static void C_ccall trf_16546(C_word c,C_word *av) C_noret;
static void C_ccall trf_16546(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16546(t0,t1);}

C_noret_decl(trf_16556)
static void C_ccall trf_16556(C_word c,C_word *av) C_noret;
static void C_ccall trf_16556(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16556(t0,t1,t2);}

C_noret_decl(trf_16569)
static void C_ccall trf_16569(C_word c,C_word *av) C_noret;
static void C_ccall trf_16569(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16569(t0,t1,t2);}

C_noret_decl(trf_16646)
static void C_ccall trf_16646(C_word c,C_word *av) C_noret;
static void C_ccall trf_16646(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16646(t0,t1,t2);}

C_noret_decl(trf_16658)
static void C_ccall trf_16658(C_word c,C_word *av) C_noret;
static void C_ccall trf_16658(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16658(t0,t1,t2);}

C_noret_decl(trf_16692)
static void C_ccall trf_16692(C_word c,C_word *av) C_noret;
static void C_ccall trf_16692(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16692(t0,t1,t2);}

C_noret_decl(trf_16886)
static void C_ccall trf_16886(C_word c,C_word *av) C_noret;
static void C_ccall trf_16886(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16886(t0,t1);}

C_noret_decl(trf_16952)
static void C_ccall trf_16952(C_word c,C_word *av) C_noret;
static void C_ccall trf_16952(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16952(t0,t1,t2);}

C_noret_decl(trf_16979)
static void C_ccall trf_16979(C_word c,C_word *av) C_noret;
static void C_ccall trf_16979(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16979(t0,t1,t2);}

C_noret_decl(trf_17143)
static void C_ccall trf_17143(C_word c,C_word *av) C_noret;
static void C_ccall trf_17143(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17143(t0,t1,t2);}

C_noret_decl(trf_17223)
static void C_ccall trf_17223(C_word c,C_word *av) C_noret;
static void C_ccall trf_17223(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_17223(t0,t1,t2,t3);}

C_noret_decl(trf_17239)
static void C_ccall trf_17239(C_word c,C_word *av) C_noret;
static void C_ccall trf_17239(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_17239(t0,t1,t2,t3);}

C_noret_decl(trf_17300)
static void C_ccall trf_17300(C_word c,C_word *av) C_noret;
static void C_ccall trf_17300(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17300(t0,t1,t2);}

C_noret_decl(trf_17311)
static void C_ccall trf_17311(C_word c,C_word *av) C_noret;
static void C_ccall trf_17311(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17311(t0,t1);}

C_noret_decl(trf_17351)
static void C_ccall trf_17351(C_word c,C_word *av) C_noret;
static void C_ccall trf_17351(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17351(t0,t1,t2);}

C_noret_decl(trf_17464)
static void C_ccall trf_17464(C_word c,C_word *av) C_noret;
static void C_ccall trf_17464(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17464(t0,t1,t2);}

C_noret_decl(trf_17510)
static void C_ccall trf_17510(C_word c,C_word *av) C_noret;
static void C_ccall trf_17510(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17510(t0,t1,t2);}

C_noret_decl(trf_17528)
static void C_ccall trf_17528(C_word c,C_word *av) C_noret;
static void C_ccall trf_17528(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17528(t0,t1,t2);}

C_noret_decl(trf_17588)
static void C_ccall trf_17588(C_word c,C_word *av) C_noret;
static void C_ccall trf_17588(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17588(t0,t1,t2);}

C_noret_decl(trf_17690)
static void C_ccall trf_17690(C_word c,C_word *av) C_noret;
static void C_ccall trf_17690(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_17690(t0,t1,t2,t3);}

C_noret_decl(trf_17693)
static void C_ccall trf_17693(C_word c,C_word *av) C_noret;
static void C_ccall trf_17693(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17693(t0,t1,t2);}

C_noret_decl(trf_17750)
static void C_ccall trf_17750(C_word c,C_word *av) C_noret;
static void C_ccall trf_17750(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17750(t0,t1);}

C_noret_decl(trf_17852)
static void C_ccall trf_17852(C_word c,C_word *av) C_noret;
static void C_ccall trf_17852(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17852(t0,t1,t2);}

C_noret_decl(trf_17874)
static void C_ccall trf_17874(C_word c,C_word *av) C_noret;
static void C_ccall trf_17874(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17874(t0,t1,t2);}

C_noret_decl(trf_17908)
static void C_ccall trf_17908(C_word c,C_word *av) C_noret;
static void C_ccall trf_17908(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17908(t0,t1,t2);}

C_noret_decl(trf_18038)
static void C_ccall trf_18038(C_word c,C_word *av) C_noret;
static void C_ccall trf_18038(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_18038(t0,t1,t2,t3);}

C_noret_decl(trf_18219)
static void C_ccall trf_18219(C_word c,C_word *av) C_noret;
static void C_ccall trf_18219(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18219(t0,t1,t2);}

C_noret_decl(trf_18268)
static void C_ccall trf_18268(C_word c,C_word *av) C_noret;
static void C_ccall trf_18268(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18268(t0,t1,t2);}

C_noret_decl(trf_18312)
static void C_ccall trf_18312(C_word c,C_word *av) C_noret;
static void C_ccall trf_18312(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18312(t0,t1);}

C_noret_decl(trf_18371)
static void C_ccall trf_18371(C_word c,C_word *av) C_noret;
static void C_ccall trf_18371(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18371(t0,t1,t2);}

C_noret_decl(trf_18510)
static void C_ccall trf_18510(C_word c,C_word *av) C_noret;
static void C_ccall trf_18510(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18510(t0,t1);}

C_noret_decl(trf_18556)
static void C_ccall trf_18556(C_word c,C_word *av) C_noret;
static void C_ccall trf_18556(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18556(t0,t1,t2);}

C_noret_decl(trf_18569)
static void C_ccall trf_18569(C_word c,C_word *av) C_noret;
static void C_ccall trf_18569(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18569(t0,t1);}

C_noret_decl(trf_18604)
static void C_ccall trf_18604(C_word c,C_word *av) C_noret;
static void C_ccall trf_18604(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18604(t0,t1);}

C_noret_decl(trf_18740)
static void C_ccall trf_18740(C_word c,C_word *av) C_noret;
static void C_ccall trf_18740(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_18740(t0,t1,t2,t3);}

C_noret_decl(trf_18765)
static void C_ccall trf_18765(C_word c,C_word *av) C_noret;
static void C_ccall trf_18765(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18765(t0,t1,t2);}

C_noret_decl(trf_18819)
static void C_ccall trf_18819(C_word c,C_word *av) C_noret;
static void C_ccall trf_18819(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18819(t0,t1,t2);}

C_noret_decl(trf_18902)
static void C_ccall trf_18902(C_word c,C_word *av) C_noret;
static void C_ccall trf_18902(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18902(t0,t1);}

C_noret_decl(trf_18952)
static void C_ccall trf_18952(C_word c,C_word *av) C_noret;
static void C_ccall trf_18952(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18952(t0,t1,t2);}

C_noret_decl(trf_19113)
static void C_ccall trf_19113(C_word c,C_word *av) C_noret;
static void C_ccall trf_19113(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19113(t0,t1,t2);}

C_noret_decl(trf_19117)
static void C_ccall trf_19117(C_word c,C_word *av) C_noret;
static void C_ccall trf_19117(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19117(t0,t1);}

C_noret_decl(trf_19152)
static void C_ccall trf_19152(C_word c,C_word *av) C_noret;
static void C_ccall trf_19152(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19152(t0,t1,t2);}

C_noret_decl(trf_19184)
static void C_ccall trf_19184(C_word c,C_word *av) C_noret;
static void C_ccall trf_19184(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19184(t0,t1,t2);}

C_noret_decl(trf_19261)
static void C_ccall trf_19261(C_word c,C_word *av) C_noret;
static void C_ccall trf_19261(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19261(t0,t1,t2);}

C_noret_decl(trf_19273)
static void C_ccall trf_19273(C_word c,C_word *av) C_noret;
static void C_ccall trf_19273(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19273(t0,t1,t2);}

C_noret_decl(trf_19284)
static void C_ccall trf_19284(C_word c,C_word *av) C_noret;
static void C_ccall trf_19284(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19284(t0,t1,t2);}

C_noret_decl(trf_19351)
static void C_ccall trf_19351(C_word c,C_word *av) C_noret;
static void C_ccall trf_19351(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19351(t0,t1,t2);}

C_noret_decl(trf_19385)
static void C_ccall trf_19385(C_word c,C_word *av) C_noret;
static void C_ccall trf_19385(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19385(t0,t1,t2);}

C_noret_decl(trf_19450)
static void C_ccall trf_19450(C_word c,C_word *av) C_noret;
static void C_ccall trf_19450(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19450(t0,t1,t2);}

C_noret_decl(trf_19503)
static void C_ccall trf_19503(C_word c,C_word *av) C_noret;
static void C_ccall trf_19503(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19503(t0,t1,t2);}

C_noret_decl(trf_19537)
static void C_ccall trf_19537(C_word c,C_word *av) C_noret;
static void C_ccall trf_19537(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19537(t0,t1);}

C_noret_decl(trf_19565)
static void C_ccall trf_19565(C_word c,C_word *av) C_noret;
static void C_ccall trf_19565(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_19565(t0,t1,t2,t3);}

C_noret_decl(trf_19651)
static void C_ccall trf_19651(C_word c,C_word *av) C_noret;
static void C_ccall trf_19651(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19651(t0,t1);}

C_noret_decl(trf_19663)
static void C_ccall trf_19663(C_word c,C_word *av) C_noret;
static void C_ccall trf_19663(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19663(t0,t1,t2);}

C_noret_decl(trf_19701)
static void C_ccall trf_19701(C_word c,C_word *av) C_noret;
static void C_ccall trf_19701(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_19701(t0,t1,t2,t3,t4);}

C_noret_decl(trf_19951)
static void C_ccall trf_19951(C_word c,C_word *av) C_noret;
static void C_ccall trf_19951(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_19951(t0,t1,t2,t3,t4);}

C_noret_decl(trf_20046)
static void C_ccall trf_20046(C_word c,C_word *av) C_noret;
static void C_ccall trf_20046(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20046(t0,t1);}

C_noret_decl(trf_20110)
static void C_ccall trf_20110(C_word c,C_word *av) C_noret;
static void C_ccall trf_20110(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20110(t0,t1);}

C_noret_decl(trf_20114)
static void C_ccall trf_20114(C_word c,C_word *av) C_noret;
static void C_ccall trf_20114(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20114(t0,t1,t2);}

C_noret_decl(trf_20170)
static void C_ccall trf_20170(C_word c,C_word *av) C_noret;
static void C_ccall trf_20170(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20170(t0,t1);}

C_noret_decl(trf_20180)
static void C_ccall trf_20180(C_word c,C_word *av) C_noret;
static void C_ccall trf_20180(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20180(t0,t1,t2,t3);}

C_noret_decl(trf_20217)
static void C_ccall trf_20217(C_word c,C_word *av) C_noret;
static void C_ccall trf_20217(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20217(t0,t1,t2,t3);}

C_noret_decl(trf_20347)
static void C_ccall trf_20347(C_word c,C_word *av) C_noret;
static void C_ccall trf_20347(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20347(t0,t1);}

C_noret_decl(trf_20424)
static void C_ccall trf_20424(C_word c,C_word *av) C_noret;
static void C_ccall trf_20424(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_20424(t0,t1,t2,t3,t4);}

C_noret_decl(trf_20427)
static void C_ccall trf_20427(C_word c,C_word *av) C_noret;
static void C_ccall trf_20427(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20427(t0,t1);}

C_noret_decl(trf_20436)
static void C_ccall trf_20436(C_word c,C_word *av) C_noret;
static void C_ccall trf_20436(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20436(t0,t1,t2);}

C_noret_decl(trf_20491)
static void C_ccall trf_20491(C_word c,C_word *av) C_noret;
static void C_ccall trf_20491(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20491(t0,t1);}

C_noret_decl(trf_20499)
static void C_ccall trf_20499(C_word c,C_word *av) C_noret;
static void C_ccall trf_20499(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20499(t0,t1,t2);}

C_noret_decl(trf_20533)
static void C_ccall trf_20533(C_word c,C_word *av) C_noret;
static void C_ccall trf_20533(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20533(t0,t1,t2);}

C_noret_decl(trf_20581)
static void C_ccall trf_20581(C_word c,C_word *av) C_noret;
static void C_ccall trf_20581(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20581(t0,t1,t2);}

C_noret_decl(trf_20625)
static void C_ccall trf_20625(C_word c,C_word *av) C_noret;
static void C_ccall trf_20625(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20625(t0,t1,t2,t3);}

C_noret_decl(trf_20639)
static void C_ccall trf_20639(C_word c,C_word *av) C_noret;
static void C_ccall trf_20639(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20639(t0,t1,t2);}

C_noret_decl(trf_20682)
static void C_ccall trf_20682(C_word c,C_word *av) C_noret;
static void C_ccall trf_20682(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20682(t0,t1,t2);}

C_noret_decl(trf_20749)
static void C_ccall trf_20749(C_word c,C_word *av) C_noret;
static void C_ccall trf_20749(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20749(t0,t1,t2);}

C_noret_decl(trf_20785)
static void C_ccall trf_20785(C_word c,C_word *av) C_noret;
static void C_ccall trf_20785(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20785(t0,t1,t2);}

C_noret_decl(trf_20800)
static void C_ccall trf_20800(C_word c,C_word *av) C_noret;
static void C_ccall trf_20800(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20800(t0,t1,t2);}

C_noret_decl(trf_20840)
static void C_ccall trf_20840(C_word c,C_word *av) C_noret;
static void C_ccall trf_20840(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20840(t0,t1);}

C_noret_decl(trf_20866)
static void C_ccall trf_20866(C_word c,C_word *av) C_noret;
static void C_ccall trf_20866(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20866(t0,t1,t2,t3);}

C_noret_decl(trf_20872)
static void C_ccall trf_20872(C_word c,C_word *av) C_noret;
static void C_ccall trf_20872(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20872(t0,t1,t2);}

C_noret_decl(trf_20939)
static void C_ccall trf_20939(C_word c,C_word *av) C_noret;
static void C_ccall trf_20939(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20939(t0,t1,t2);}

C_noret_decl(trf_20992)
static void C_ccall trf_20992(C_word c,C_word *av) C_noret;
static void C_ccall trf_20992(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20992(t0,t1);}

C_noret_decl(trf_21010)
static void C_ccall trf_21010(C_word c,C_word *av) C_noret;
static void C_ccall trf_21010(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21010(t0,t1,t2);}

C_noret_decl(trf_21071)
static void C_ccall trf_21071(C_word c,C_word *av) C_noret;
static void C_ccall trf_21071(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21071(t0,t1,t2);}

C_noret_decl(trf_21167)
static void C_ccall trf_21167(C_word c,C_word *av) C_noret;
static void C_ccall trf_21167(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21167(t0,t1);}

C_noret_decl(trf_21187)
static void C_ccall trf_21187(C_word c,C_word *av) C_noret;
static void C_ccall trf_21187(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21187(t0,t1,t2);}

C_noret_decl(trf_21221)
static void C_ccall trf_21221(C_word c,C_word *av) C_noret;
static void C_ccall trf_21221(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21221(t0,t1,t2);}

C_noret_decl(trf_21306)
static void C_ccall trf_21306(C_word c,C_word *av) C_noret;
static void C_ccall trf_21306(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21306(t0,t1);}

C_noret_decl(trf_21315)
static void C_ccall trf_21315(C_word c,C_word *av) C_noret;
static void C_ccall trf_21315(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21315(t0,t1,t2,t3);}

C_noret_decl(trf_21346)
static void C_ccall trf_21346(C_word c,C_word *av) C_noret;
static void C_ccall trf_21346(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21346(t0,t1,t2);}

C_noret_decl(trf_21358)
static void C_ccall trf_21358(C_word c,C_word *av) C_noret;
static void C_ccall trf_21358(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21358(t0,t1,t2);}

C_noret_decl(trf_21411)
static void C_ccall trf_21411(C_word c,C_word *av) C_noret;
static void C_ccall trf_21411(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21411(t0,t1);}

C_noret_decl(trf_21435)
static void C_ccall trf_21435(C_word c,C_word *av) C_noret;
static void C_ccall trf_21435(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21435(t0,t1);}

C_noret_decl(trf_21465)
static void C_ccall trf_21465(C_word c,C_word *av) C_noret;
static void C_ccall trf_21465(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21465(t0,t1,t2);}

C_noret_decl(trf_21515)
static void C_ccall trf_21515(C_word c,C_word *av) C_noret;
static void C_ccall trf_21515(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21515(t0,t1,t2,t3);}

C_noret_decl(trf_21529)
static void C_ccall trf_21529(C_word c,C_word *av) C_noret;
static void C_ccall trf_21529(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21529(t0,t1);}

C_noret_decl(trf_21635)
static void C_ccall trf_21635(C_word c,C_word *av) C_noret;
static void C_ccall trf_21635(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21635(t0,t1);}

C_noret_decl(trf_21686)
static void C_ccall trf_21686(C_word c,C_word *av) C_noret;
static void C_ccall trf_21686(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21686(t0,t1);}

C_noret_decl(trf_21746)
static void C_ccall trf_21746(C_word c,C_word *av) C_noret;
static void C_ccall trf_21746(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21746(t0,t1);}

C_noret_decl(trf_21749)
static void C_ccall trf_21749(C_word c,C_word *av) C_noret;
static void C_ccall trf_21749(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21749(t0,t1);}

C_noret_decl(trf_21763)
static void C_ccall trf_21763(C_word c,C_word *av) C_noret;
static void C_ccall trf_21763(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21763(t0,t1,t2);}

C_noret_decl(trf_21879)
static void C_ccall trf_21879(C_word c,C_word *av) C_noret;
static void C_ccall trf_21879(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21879(t0,t1);}

C_noret_decl(trf_21960)
static void C_ccall trf_21960(C_word c,C_word *av) C_noret;
static void C_ccall trf_21960(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21960(t0,t1,t2);}

C_noret_decl(trf_22110)
static void C_ccall trf_22110(C_word c,C_word *av) C_noret;
static void C_ccall trf_22110(C_word c,C_word *av){
C_word t0=av[7];
C_word t1=av[6];
C_word t2=av[5];
C_word t3=av[4];
C_word t4=av[3];
C_word t5=av[2];
C_word t6=av[1];
C_word t7=av[0];
f_22110(t0,t1,t2,t3,t4,t5,t6,t7);}

C_noret_decl(trf_22249)
static void C_ccall trf_22249(C_word c,C_word *av) C_noret;
static void C_ccall trf_22249(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_22249(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_22384)
static void C_ccall trf_22384(C_word c,C_word *av) C_noret;
static void C_ccall trf_22384(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22384(t0,t1,t2,t3);}

C_noret_decl(trf_22446)
static void C_ccall trf_22446(C_word c,C_word *av) C_noret;
static void C_ccall trf_22446(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22446(t0,t1,t2,t3);}

C_noret_decl(trf_22566)
static void C_ccall trf_22566(C_word c,C_word *av) C_noret;
static void C_ccall trf_22566(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22566(t0,t1,t2,t3);}

C_noret_decl(trf_22915)
static void C_ccall trf_22915(C_word c,C_word *av) C_noret;
static void C_ccall trf_22915(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22915(t0,t1,t2);}

C_noret_decl(trf_23054)
static void C_ccall trf_23054(C_word c,C_word *av) C_noret;
static void C_ccall trf_23054(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_23054(t0,t1,t2,t3,t4);}

C_noret_decl(trf_23229)
static void C_ccall trf_23229(C_word c,C_word *av) C_noret;
static void C_ccall trf_23229(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23229(t0,t1,t2);}

C_noret_decl(trf_23286)
static void C_ccall trf_23286(C_word c,C_word *av) C_noret;
static void C_ccall trf_23286(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23286(t0,t1,t2);}

C_noret_decl(trf_23347)
static void C_ccall trf_23347(C_word c,C_word *av) C_noret;
static void C_ccall trf_23347(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23347(t0,t1,t2);}

C_noret_decl(trf_23412)
static void C_ccall trf_23412(C_word c,C_word *av) C_noret;
static void C_ccall trf_23412(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23412(t0,t1,t2);}

C_noret_decl(trf_6882)
static void C_ccall trf_6882(C_word c,C_word *av) C_noret;
static void C_ccall trf_6882(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6882(t0,t1,t2,t3);}

C_noret_decl(trf_6926)
static void C_ccall trf_6926(C_word c,C_word *av) C_noret;
static void C_ccall trf_6926(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6926(t0,t1,t2);}

C_noret_decl(trf_6984)
static void C_ccall trf_6984(C_word c,C_word *av) C_noret;
static void C_ccall trf_6984(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_6984(t0,t1,t2,t3,t4);}

C_noret_decl(trf_7017)
static void C_ccall trf_7017(C_word c,C_word *av) C_noret;
static void C_ccall trf_7017(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7017(t0,t1,t2,t3);}

C_noret_decl(trf_7032)
static void C_ccall trf_7032(C_word c,C_word *av) C_noret;
static void C_ccall trf_7032(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7032(t0,t1,t2);}

C_noret_decl(trf_7040)
static void C_ccall trf_7040(C_word c,C_word *av) C_noret;
static void C_ccall trf_7040(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7040(t0,t1,t2,t3);}

C_noret_decl(trf_7072)
static void C_ccall trf_7072(C_word c,C_word *av) C_noret;
static void C_ccall trf_7072(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7072(t0,t1,t2);}

C_noret_decl(trf_7104)
static void C_ccall trf_7104(C_word c,C_word *av) C_noret;
static void C_ccall trf_7104(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7104(t0,t1,t2);}

C_noret_decl(trf_7153)
static void C_ccall trf_7153(C_word c,C_word *av) C_noret;
static void C_ccall trf_7153(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7153(t0,t1,t2);}

C_noret_decl(trf_7187)
static void C_ccall trf_7187(C_word c,C_word *av) C_noret;
static void C_ccall trf_7187(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7187(t0,t1,t2);}

C_noret_decl(trf_7193)
static void C_ccall trf_7193(C_word c,C_word *av) C_noret;
static void C_ccall trf_7193(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7193(t0,t1,t2);}

C_noret_decl(trf_7221)
static void C_ccall trf_7221(C_word c,C_word *av) C_noret;
static void C_ccall trf_7221(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7221(t0,t1,t2);}

C_noret_decl(trf_7227)
static void C_ccall trf_7227(C_word c,C_word *av) C_noret;
static void C_ccall trf_7227(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7227(t0,t1,t2);}

C_noret_decl(trf_7257)
static void C_ccall trf_7257(C_word c,C_word *av) C_noret;
static void C_ccall trf_7257(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7257(t0,t1,t2,t3);}

C_noret_decl(trf_7285)
static void C_ccall trf_7285(C_word c,C_word *av) C_noret;
static void C_ccall trf_7285(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7285(t0,t1,t2);}

C_noret_decl(trf_7313)
static void C_ccall trf_7313(C_word c,C_word *av) C_noret;
static void C_ccall trf_7313(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7313(t0,t1,t2);}

C_noret_decl(trf_7382)
static void C_ccall trf_7382(C_word c,C_word *av) C_noret;
static void C_ccall trf_7382(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7382(t0,t1,t2);}

C_noret_decl(trf_7388)
static void C_ccall trf_7388(C_word c,C_word *av) C_noret;
static void C_ccall trf_7388(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7388(t0,t1,t2);}

C_noret_decl(trf_7471)
static void C_ccall trf_7471(C_word c,C_word *av) C_noret;
static void C_ccall trf_7471(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7471(t0,t1,t2);}

C_noret_decl(trf_7480)
static void C_ccall trf_7480(C_word c,C_word *av) C_noret;
static void C_ccall trf_7480(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7480(t0,t1,t2);}

C_noret_decl(trf_7488)
static void C_ccall trf_7488(C_word c,C_word *av) C_noret;
static void C_ccall trf_7488(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7488(t0,t1,t2,t3);}

C_noret_decl(trf_7553)
static void C_ccall trf_7553(C_word c,C_word *av) C_noret;
static void C_ccall trf_7553(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7553(t0,t1,t2);}

C_noret_decl(trf_7652)
static void C_ccall trf_7652(C_word c,C_word *av) C_noret;
static void C_ccall trf_7652(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7652(t0,t1,t2,t3);}

C_noret_decl(trf_7738)
static void C_ccall trf_7738(C_word c,C_word *av) C_noret;
static void C_ccall trf_7738(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7738(t0,t1,t2,t3);}

C_noret_decl(trf_7763)
static void C_ccall trf_7763(C_word c,C_word *av) C_noret;
static void C_ccall trf_7763(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7763(t0,t1,t2,t3);}

C_noret_decl(trf_7829)
static void C_ccall trf_7829(C_word c,C_word *av) C_noret;
static void C_ccall trf_7829(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7829(t0,t1,t2);}

C_noret_decl(trf_7835)
static void C_ccall trf_7835(C_word c,C_word *av) C_noret;
static void C_ccall trf_7835(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7835(t0,t1,t2);}

C_noret_decl(trf_7871)
static void C_ccall trf_7871(C_word c,C_word *av) C_noret;
static void C_ccall trf_7871(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7871(t0,t1,t2);}

C_noret_decl(trf_8012)
static void C_ccall trf_8012(C_word c,C_word *av) C_noret;
static void C_ccall trf_8012(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8012(t0,t1,t2);}

C_noret_decl(trf_8231)
static void C_ccall trf_8231(C_word c,C_word *av) C_noret;
static void C_ccall trf_8231(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8231(t0,t1,t2);}

C_noret_decl(trf_8322)
static void C_ccall trf_8322(C_word c,C_word *av) C_noret;
static void C_ccall trf_8322(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8322(t0,t1,t2);}

C_noret_decl(trf_8413)
static void C_ccall trf_8413(C_word c,C_word *av) C_noret;
static void C_ccall trf_8413(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8413(t0,t1,t2);}

C_noret_decl(trf_8487)
static void C_ccall trf_8487(C_word c,C_word *av) C_noret;
static void C_ccall trf_8487(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8487(t0,t1,t2);}

C_noret_decl(trf_8526)
static void C_ccall trf_8526(C_word c,C_word *av) C_noret;
static void C_ccall trf_8526(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8526(t0,t1,t2,t3);}

C_noret_decl(trf_8557)
static void C_ccall trf_8557(C_word c,C_word *av) C_noret;
static void C_ccall trf_8557(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_8557(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_8573)
static void C_ccall trf_8573(C_word c,C_word *av) C_noret;
static void C_ccall trf_8573(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8573(t0,t1);}

C_noret_decl(trf_8682)
static void C_ccall trf_8682(C_word c,C_word *av) C_noret;
static void C_ccall trf_8682(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_8682(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_8706)
static void C_ccall trf_8706(C_word c,C_word *av) C_noret;
static void C_ccall trf_8706(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8706(t0,t1,t2);}

C_noret_decl(trf_8772)
static void C_ccall trf_8772(C_word c,C_word *av) C_noret;
static void C_ccall trf_8772(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_8772(t0,t1,t2,t3,t4);}

C_noret_decl(trf_8807)
static void C_ccall trf_8807(C_word c,C_word *av) C_noret;
static void C_ccall trf_8807(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8807(t0,t1);}

C_noret_decl(trf_8844)
static void C_ccall trf_8844(C_word c,C_word *av) C_noret;
static void C_ccall trf_8844(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8844(t0,t1);}

C_noret_decl(trf_8853)
static void C_ccall trf_8853(C_word c,C_word *av) C_noret;
static void C_ccall trf_8853(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8853(t0,t1);}

C_noret_decl(trf_8856)
static void C_ccall trf_8856(C_word c,C_word *av) C_noret;
static void C_ccall trf_8856(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8856(t0,t1);}

C_noret_decl(trf_8872)
static void C_ccall trf_8872(C_word c,C_word *av) C_noret;
static void C_ccall trf_8872(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8872(t0,t1,t2);}

C_noret_decl(trf_8884)
static void C_ccall trf_8884(C_word c,C_word *av) C_noret;
static void C_ccall trf_8884(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8884(t0,t1,t2);}

C_noret_decl(trf_8919)
static void C_ccall trf_8919(C_word c,C_word *av) C_noret;
static void C_ccall trf_8919(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8919(t0,t1);}

C_noret_decl(trf_8987)
static void C_ccall trf_8987(C_word c,C_word *av) C_noret;
static void C_ccall trf_8987(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8987(t0,t1,t2);}

C_noret_decl(trf_9146)
static void C_ccall trf_9146(C_word c,C_word *av) C_noret;
static void C_ccall trf_9146(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9146(t0,t1,t2);}

C_noret_decl(trf_9165)
static void C_ccall trf_9165(C_word c,C_word *av) C_noret;
static void C_ccall trf_9165(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9165(t0,t1);}

C_noret_decl(trf_9169)
static void C_ccall trf_9169(C_word c,C_word *av) C_noret;
static void C_ccall trf_9169(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9169(t0,t1,t2);}

C_noret_decl(trf_9175)
static void C_ccall trf_9175(C_word c,C_word *av) C_noret;
static void C_ccall trf_9175(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9175(t0,t1,t2);}

C_noret_decl(trf_9294)
static void C_ccall trf_9294(C_word c,C_word *av) C_noret;
static void C_ccall trf_9294(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_9294(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_9372)
static void C_ccall trf_9372(C_word c,C_word *av) C_noret;
static void C_ccall trf_9372(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9372(t0,t1,t2);}

C_noret_decl(trf_9411)
static void C_ccall trf_9411(C_word c,C_word *av) C_noret;
static void C_ccall trf_9411(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_9411(t0,t1,t2,t3,t4);}

C_noret_decl(trf_9417)
static void C_ccall trf_9417(C_word c,C_word *av) C_noret;
static void C_ccall trf_9417(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9417(t0,t1,t2);}

C_noret_decl(trf_9444)
static void C_ccall trf_9444(C_word c,C_word *av) C_noret;
static void C_ccall trf_9444(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9444(t0,t1,t2,t3);}

C_noret_decl(trf_9467)
static void C_ccall trf_9467(C_word c,C_word *av) C_noret;
static void C_ccall trf_9467(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9467(t0,t1,t2);}

C_noret_decl(trf_9482)
static void C_ccall trf_9482(C_word c,C_word *av) C_noret;
static void C_ccall trf_9482(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9482(t0,t1,t2);}

C_noret_decl(trf_9540)
static void C_ccall trf_9540(C_word c,C_word *av) C_noret;
static void C_ccall trf_9540(C_word c,C_word *av){
C_word t0=av[7];
C_word t1=av[6];
C_word t2=av[5];
C_word t3=av[4];
C_word t4=av[3];
C_word t5=av[2];
C_word t6=av[1];
C_word t7=av[0];
f_9540(t0,t1,t2,t3,t4,t5,t6,t7);}

C_noret_decl(trf_9707)
static void C_ccall trf_9707(C_word c,C_word *av) C_noret;
static void C_ccall trf_9707(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9707(t0,t1);}

C_noret_decl(trf_9757)
static void C_ccall trf_9757(C_word c,C_word *av) C_noret;
static void C_ccall trf_9757(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9757(t0,t1);}

C_noret_decl(trf_9792)
static void C_ccall trf_9792(C_word c,C_word *av) C_noret;
static void C_ccall trf_9792(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9792(t0,t1,t2,t3);}

C_noret_decl(trf_9886)
static void C_ccall trf_9886(C_word c,C_word *av) C_noret;
static void C_ccall trf_9886(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9886(t0,t1,t2);}

C_noret_decl(trf_9920)
static void C_ccall trf_9920(C_word c,C_word *av) C_noret;
static void C_ccall trf_9920(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9920(t0,t1,t2);}

/* f26096 in chicken.compiler.scrutinizer#make-list in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f26096,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f26203 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f26203,c,av);}
/* scrutinizer.scm:584: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_SCHEME_END_OF_LIST;
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* f26218 in map-loop5660 in k22897 in k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f26218(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f26218,c,av);}
a=C_alloc(3);
/* scrutinizer.scm:2934: string-add-indent */
f_20749(((C_word*)t0)[2],t1,C_a_i_list(&a,1,lf[317]));}

/* f26225 in k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f26225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f26225,c,av);}
a=C_alloc(3);
/* scrutinizer.scm:2934: string-add-indent */
f_20749(((C_word*)t0)[2],t1,C_a_i_list(&a,1,lf[317]));}

/* f26473 in k20845 in map-loop5021 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f26473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f26473,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];
f_20992(t2,C_a_i_list2(&a,2,lf[124],t1));}

/* f26621 in map-loop994 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26621(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f26621,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t6=((C_word*)((C_word*)t0)[3])[1];
f_9372(t6,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* f26686 in map-loop1646 in k10782 */
static void C_ccall f26686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f26686,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t6=((C_word*)((C_word*)t0)[3])[1];
f_11227(t6,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* f26693 in k10776 in k10770 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f26693,c,av);}
a=C_alloc(20);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_10784,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=t2,a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],tmp=(C_word)a,a+=20,tmp);
/* scrutinizer.scm:681: procedure-name */
f_15236(t3,t2);}

/* f26845 in k19703 in known-length-vector-index in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26845(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f26845,c,av);}
a=C_alloc(7);
t2=C_i_car(t1);
if(C_truep(t2)){
if(C_truep(C_i_pairp(t2))){
t3=C_i_car(t2);
t4=C_eqp(lf[51],t3);
if(C_truep(t4)){
t5=C_i_caddr(((C_word*)t0)[2]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19784,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t5,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2121: chicken.compiler.support#node-class */
t7=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* f26850 in k19802 in vector-ref-result-type in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f26850,c,av);}
a=C_alloc(7);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19848,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2136: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* f26859 in k20050 */
static void C_ccall f26859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f26859,c,av);}
a=C_alloc(10);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=C_i_caddr(((C_word*)t0)[2]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_20129,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t2,a[8]=((C_word*)t0)[8],a[9]=t3,tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2207: chicken.compiler.support#node-class */
t5=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* f26866 in lp in derive-result-type in append-special-case in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f26866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,4)))){
C_save_and_reclaim((void *)f26866,c,av);}
a=C_alloc(33);
t2=C_i_car(t1);
t3=C_i_pairp(t2);
t4=(C_truep(t3)?C_eqp(C_u_i_car(t2),lf[48]):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20202,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t6=C_u_i_cdr(((C_word*)t0)[3]);
t7=C_s_a_i_plus(&a,2,((C_word*)t0)[4],C_fix(1));
/* scrutinizer.scm:2276: lp */
t8=((C_word*)((C_word*)t0)[5])[1];
f_20180(t8,t5,t6,t7);}
else{
t5=C_i_pairp(t2);
t6=(C_truep(t5)?C_eqp(C_u_i_car(t2),lf[362]):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20261,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t8=C_u_i_cdr(((C_word*)t0)[3]);
t9=C_s_a_i_plus(&a,2,((C_word*)t0)[4],C_fix(1));
/* scrutinizer.scm:2284: lp */
t10=((C_word*)((C_word*)t0)[5])[1];
f_20180(t10,t7,t8,t9);}
else{
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20278,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t8=C_i_nullp(C_u_i_cdr(((C_word*)t0)[3]));
t9=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20284,a[2]=((C_word*)t0)[2],a[3]=t7,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[8],a[8]=t2,tmp=(C_word)a,a+=9,tmp);
if(C_truep(t8)){
t10=t9;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t8;
f_20284(2,av2);}}
else{
/* scrutinizer.scm:2265: match-types */
t10=*((C_word*)lf[171]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t10;
av2[1]=t9;
av2[2]=t2;
av2[3]=lf[48];
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}}}}

/* f26905 in k20333 */
static void C_ccall f26905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f26905,c,av);}
t2=((C_word*)t0)[2];
f_20347(t2,C_i_car(t1));}

/* f26910 in k23146 in a23143 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f26910(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f26910,c,av);}
a=C_alloc(4);
t2=C_i_car(t1);
if(C_truep(t2)){
if(C_truep(C_i_pairp(t2))){
t3=C_i_car(t2);
t4=C_eqp(t3,lf[48]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23189,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2260: scheme#reverse */
t6=*((C_word*)lf[368]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_u_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* f26915 in map-loop4623 in a23205 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26915(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f26915,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t6=((C_word*)((C_word*)t0)[3])[1];
f_23229(t6,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* f26922 in map-loop4589 in a23262 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26922(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f26922,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t6=((C_word*)((C_word*)t0)[3])[1];
f_23286(t6,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* f26929 in map-loop4555 in a23319 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f26929,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t6=((C_word*)((C_word*)t0)[3])[1];
f_23347(t6,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* f26936 in map-loop4521 in a23384 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26936(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f26936,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t6=((C_word*)((C_word*)t0)[3])[1];
f_23412(t6,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* f26943 in k23491 in k23482 in a23479 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f26943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f26943,c,av);}
a=C_alloc(8);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23531,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2151: type-always-immediate? */
t4=lf[27];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
f_8151(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* f28250 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f28250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f28250,c,av);}
/* scrutinizer.scm:2543: fragment */
f_21306(((C_word*)t0)[2],C_i_car(t1));}

/* f28255 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f28255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f28255,c,av);}
/* scrutinizer.scm:2543: fragment */
f_21306(((C_word*)t0)[2],C_i_car(t1));}

/* f28274 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f28274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f28274,c,av);}
/* scrutinizer.scm:2543: fragment */
f_21306(((C_word*)t0)[2],C_i_car(t1));}

/* f28508 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f28508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f28508,c,av);}
/* scrutinizer.scm:2543: fragment */
f_21306(((C_word*)t0)[2],C_i_car(t1));}

/* f28513 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f28513(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f28513,c,av);}
/* scrutinizer.scm:2543: fragment */
f_21306(((C_word*)t0)[2],C_i_car(t1));}

/* f28518 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f28518(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f28518,c,av);}
/* scrutinizer.scm:2543: fragment */
f_21306(((C_word*)t0)[2],C_i_car(t1));}

/* loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10005(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,7)))){
C_save_and_reclaim_args((void *)trf_10005,5,t0,t1,t2,t3,t4);}
a=C_alloc(19);
if(C_truep(C_i_nullp(t2))){
t5=C_i_car(t3);
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10023,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t5,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:513: scheme#append */
t7=*((C_word*)lf[5]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t5=C_i_car(t2);
t6=C_i_car(t3);
t7=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10032,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=((C_word*)t0)[8],a[6]=t1,a[7]=((C_word*)t0)[9],a[8]=t5,a[9]=((C_word*)t0)[10],a[10]=t6,tmp=(C_word)a,a+=11,tmp);
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10086,a[2]=((C_word*)t0)[3],a[3]=t5,a[4]=((C_word*)t0)[11],a[5]=t6,a[6]=((C_word*)t0)[12],a[7]=t7,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:516: walk */
t9=((C_word*)((C_word*)t0)[2])[1];
f_9540(t9,t8,t6,((C_word*)t0)[7],((C_word*)t0)[3],t5,((C_word*)t0)[5],C_SCHEME_FALSE);}}

/* k10021 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10023(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_10023,c,av);}
/* scrutinizer.scm:513: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9540(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k10030 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10032(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_10032,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10035,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10051,a[2]=t2,a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[10],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10082,a[2]=t3,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:518: chicken.compiler.support#node-class */
t5=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k10033 in k10030 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10035(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_10035,2,t0,t1);}
a=C_alloc(6);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_u_i_cdr(((C_word*)t0)[3]);
t4=C_u_i_car(((C_word*)t0)[2]);
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[4]);
t6=C_a_i_cons(&a,2,t5,((C_word*)t0)[5]);
/* scrutinizer.scm:523: loop */
t7=((C_word*)((C_word*)t0)[6])[1];
f_10005(t7,((C_word*)t0)[7],t2,t3,t6);}

/* k10049 in k10030 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10051(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_10051,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10068,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:520: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];
f_10035(t2,C_SCHEME_UNDEFINED);}}

/* k10058 in k10066 in k10049 in k10030 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10060(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10060,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[2];
f_10035(t3,t2);}
else{
t2=((C_word*)((C_word*)t0)[3])[1];
t3=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,t4);
t6=((C_word*)t0)[2];
f_10035(t6,t5);}}

/* k10066 in k10049 in k10030 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10068(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10068,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10060,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:521: chicken.compiler.support#db-get */
t4=*((C_word*)lf[68]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=t2;
av2[4]=lf[69];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k10076 in k10080 in k10030 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10078(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10078,c,av);}
t2=((C_word*)t0)[2];
f_10051(t2,C_i_not(t1));}

/* k10080 in k10030 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10082(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_10082,c,av);}
a=C_alloc(3);
t2=C_eqp(t1,lf[88]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10078,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:519: chicken.compiler.support#db-get */
t4=*((C_word*)lf[68]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[69];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=((C_word*)t0)[2];
f_10051(t3,C_SCHEME_FALSE);}}

/* k10084 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10086(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_10086,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10088,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:516: single */
f_8706(((C_word*)t0)[7],t1,t2);}

/* a10087 in k10084 in loop in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10088(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_10088,c,av);}
t3=lf[221];
/* scrutinizer.scm:517: g1396 */
t4=lf[221];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=t2;
f_22443(7,av2);}}

/* a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10110(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_10110,c,av);}
a=C_alloc(20);
t5=(C_truep(((C_word*)t0)[2])?C_a_i_list1(&a,1,((C_word*)t0)[2]):C_SCHEME_END_OF_LIST);
t6=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_10117,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t5,a[8]=((C_word*)t0)[7],a[9]=t3,a[10]=t2,a[11]=((C_word*)t0)[8],a[12]=((C_word*)t0)[9],a[13]=((C_word*)t0)[10],a[14]=t4,a[15]=t1,a[16]=((C_word*)t0)[11],tmp=(C_word)a,a+=17,tmp);
/* scrutinizer.scm:529: initial-argument-types */
t7=((C_word*)((C_word*)t0)[12])[1];
f_9444(t7,t6,((C_word*)t0)[2],t3);}

/* k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10117(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_10117,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10120,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=t1,a[17]=((C_word*)t0)[16],tmp=(C_word)a,a+=18,tmp);
if(C_truep(((C_word*)t0)[14])){
/* scrutinizer.scm:530: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=lf[227];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* scrutinizer.scm:530: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10120(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_10120,c,av);}
a=C_alloc(29);
t2=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_10123,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],tmp=(C_word)a,a+=17,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10292,a[2]=((C_word*)t0)[16],a[3]=t2,a[4]=((C_word*)t0)[17],a[5]=t5,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[14])){
/* scrutinizer.scm:532: chicken.base#butlast */
t8=*((C_word*)lf[226]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t8=t7;{
C_word *av2=av;
av2[0]=t8;
av2[1]=((C_word*)t0)[10];
f_10292(2,av2);}}}

/* k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10123(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(49,c,4)))){
C_save_and_reclaim((void *)f_10123,c,av);}
a=C_alloc(49);
t2=(C_truep(((C_word*)t0)[2])?C_SCHEME_UNDEFINED:C_SCHEME_UNDEFINED);
t3=C_SCHEME_END_OF_LIST;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_FALSE;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_END_OF_LIST;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_FALSE;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_FALSE;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_SCHEME_FALSE;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10131,a[2]=t10,a[3]=((C_word*)t0)[3],a[4]=t12,a[5]=((C_word*)t0)[4],a[6]=t14,a[7]=((C_word*)t0)[5],a[8]=t4,a[9]=t6,a[10]=t8,tmp=(C_word)a,a+=11,tmp);
t16=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_10140,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[2],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=((C_word*)t0)[15],a[14]=t1,tmp=(C_word)a,a+=15,tmp);
t17=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10270,a[2]=t4,a[3]=((C_word*)t0)[3],a[4]=t6,a[5]=((C_word*)t0)[4],a[6]=t8,a[7]=((C_word*)t0)[5],a[8]=t10,a[9]=t12,a[10]=t14,tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:537: ##sys#dynamic-wind */
t18=*((C_word*)lf[225]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t18;
av2[1]=((C_word*)t0)[16];
av2[2]=t15;
av2[3]=t16;
av2[4]=t17;
((C_proc)(void*)(*((C_word*)t18+1)))(5,av2);}}

/* a10130 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10131(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10131,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)((C_word*)t0)[5])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[6])+1,((C_word*)((C_word*)t0)[7])[1]);
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[8])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[5])+1,((C_word*)((C_word*)t0)[9])[1]);
t7=C_mutate(((C_word *)((C_word*)t0)[7])+1,((C_word*)((C_word*)t0)[10])[1]);
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}

/* a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10140(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(53,c,2)))){
C_save_and_reclaim((void *)f_10140,c,av);}
a=C_alloc(53);
t2=(
/* scrutinizer.scm:540: tag */
  f_9406(C_a_i(&a,29),((C_word*)((C_word*)t0)[2])[1])
);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10147,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t4=C_i_car(((C_word*)t0)[9]);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10257,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[11],a[4]=t2,a[5]=((C_word*)t0)[12],a[6]=t3,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)t0)[13])){
t6=C_a_i_cons(&a,2,((C_word*)t0)[13],lf[48]);
t7=t5;
f_10257(t7,C_a_i_cons(&a,2,t6,((C_word*)t0)[14]));}
else{
t6=t5;
f_10257(t6,((C_word*)t0)[14]);}}

/* k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10147(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,5)))){
C_save_and_reclaim((void *)f_10147,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10154,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10162,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10164,a[2]=t5,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_10164(t7,t3,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k10152 in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10154(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10154,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list1(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10160 in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10162(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_10162,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* scrutinizer.scm:556: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[224];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* loop in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10164(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,4)))){
C_save_and_reclaim_args((void *)trf_10164,5,t0,t1,t2,t3,t4);}
a=C_alloc(13);
if(C_truep(C_i_zerop(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10172,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t4,a[6]=t1,tmp=(C_word)a,a+=7,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10245,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t5,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:562: chicken.compiler.support#db-get */
t7=*((C_word*)lf[68]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[5];
av2[3]=C_i_car(t3);
av2[4]=lf[69];
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}}

/* k10170 in loop in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_fcall f_10172(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,0,4)))){
C_save_and_reclaim_args((void *)trf_10172,2,t0,t1);}
a=C_alloc(33);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10176,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:561: g1483 */
t3=t2;
f_10176(t3,((C_word*)t0)[6],t1);}
else{
t2=C_i_car(((C_word*)t0)[5]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10223,a[2]=((C_word*)t0)[6],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(1));
/* scrutinizer.scm:576: loop */
t5=((C_word*)((C_word*)t0)[3])[1];
f_10164(t5,t3,t4,C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}}

/* g1483 in k10170 in loop in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_fcall f_10176(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,0,4)))){
C_save_and_reclaim_args((void *)trf_10176,3,t0,t1,t2);}
a=C_alloc(33);
t3=C_i_cdr(t2);
t4=C_eqp(t3,lf[54]);
t5=(C_truep(t4)?lf[54]:C_u_i_cdr(t2));
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10188,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(1));
/* scrutinizer.scm:572: loop */
t8=((C_word*)((C_word*)t0)[3])[1];
f_10164(t8,t6,t7,C_i_cdr(((C_word*)t0)[4]),C_i_cdr(((C_word*)t0)[5]));}

/* k10186 in g1483 in k10170 in loop in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_10188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10188,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10221 in k10170 in loop in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_10223(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10223,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10243 in loop in k10145 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_10245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10245,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[3]);
t4=((C_word*)t0)[4];
f_10172(t4,C_i_assoc(t3,((C_word*)((C_word*)t0)[5])[1]));}
else{
t2=((C_word*)t0)[4];
f_10172(t2,C_SCHEME_FALSE);}}

/* k10255 in a10139 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10257(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,7)))){
C_save_and_reclaim_args((void *)trf_10257,2,t0,t1);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_a_i_list1(&a,1,((C_word*)t0)[4]);
/* scrutinizer.scm:541: walk */
t4=((C_word*)((C_word*)t0)[5])[1];
f_9540(t4,((C_word*)t0)[6],((C_word*)t0)[7],t1,t2,C_SCHEME_FALSE,t3,C_SCHEME_FALSE);}

/* a10269 in k10121 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10270(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10270,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)((C_word*)t0)[5])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[6])+1,((C_word*)((C_word*)t0)[7])[1]);
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[8])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[5])+1,((C_word*)((C_word*)t0)[9])[1]);
t7=C_mutate(((C_word *)((C_word*)t0)[7])+1,((C_word*)((C_word*)t0)[10])[1]);
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}

/* k10290 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10292(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_10292,c,av);}
a=C_alloc(11);
t2=C_i_check_list_2(t1,lf[6]);
t3=C_i_check_list_2(((C_word*)t0)[2],lf[6]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10301,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10303,a[2]=((C_word*)t0)[5],a[3]=t6,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_10303(t8,t4,t1,((C_word*)t0)[2]);}

/* k10299 in k10290 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10301(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10301,c,av);}
/* scrutinizer.scm:531: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop1414 in k10290 in k10118 in k10115 in a10109 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10303(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_10303,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=C_slot(t2,C_fix(0));
t7=C_slot(t3,C_fix(0));
t8=C_a_i_cons(&a,2,t6,t7);
t9=C_a_i_cons(&a,2,t8,C_SCHEME_END_OF_LIST);
t10=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t9);
t11=C_mutate(((C_word *)((C_word*)t0)[2])+1,t9);
t13=t1;
t14=C_slot(t2,C_fix(1));
t15=C_slot(t3,C_fix(1));
t1=t13;
t2=t14;
t3=t15;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,7)))){
C_save_and_reclaim((void *)f_10374,c,av);}
a=C_alloc(25);
t2=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_10377,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=t1,a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],tmp=(C_word)a,a+=17,tmp);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10707,a[2]=((C_word*)t0)[14],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[16],a[7]=t2,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:581: walk */
t4=((C_word*)((C_word*)t0)[17])[1];
f_9540(t4,t3,C_i_car(((C_word*)t0)[11]),((C_word*)t0)[3],((C_word*)t0)[14],((C_word*)t0)[2],((C_word*)t0)[7],C_SCHEME_FALSE);}

/* k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,2)))){
C_save_and_reclaim((void *)f_10377,c,av);}
a=C_alloc(25);
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10380,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],tmp=(C_word)a,a+=18,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10696,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[13])){
/* scrutinizer.scm:585: type-typeenv */
t4=lf[162];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[13];
f_15975(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f26203,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:586: type-typeenv */
t5=lf[162];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t1;
f_15975(3,av2);}}}

/* k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,2)))){
C_save_and_reclaim((void *)f_10380,c,av);}
a=C_alloc(32);
t2=C_i_assq(((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_10386,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=t2,a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],tmp=(C_word)a,a+=15,tmp);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10644,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[15],a[4]=t3,a[5]=((C_word*)t0)[16],a[6]=((C_word*)t0)[14],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[17],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)t0)[14])){
if(C_truep(C_i_not(t2))){
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10667,a[2]=t4,a[3]=((C_word*)t0)[14],a[4]=((C_word*)t0)[7],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t6=C_eqp(((C_word*)t0)[14],lf[60]);
if(C_truep(t6)){
t7=t5;
f_10667(t7,C_i_not(t6));}
else{
t7=C_i_pairp(((C_word*)t0)[14]);
t8=t5;
f_10667(t8,(C_truep(t7)?C_i_not(C_eqp(C_u_i_car(((C_word*)t0)[14]),lf[60])):C_SCHEME_TRUE));}}
else{
t5=t4;
f_10644(t5,C_SCHEME_FALSE);}}
else{
t5=t4;
f_10644(t5,C_SCHEME_FALSE);}}

/* k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,4)))){
C_save_and_reclaim((void *)f_10386,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10389,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10518,a[2]=t2,a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[12],a[6]=((C_word*)t0)[13],a[7]=((C_word*)t0)[11],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_not(((C_word*)t0)[14]))){
if(C_truep(C_i_not(((C_word*)t0)[6]))){
t4=C_eqp(lf[54],((C_word*)t0)[5]);
if(C_truep(C_i_not(t4))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10637,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:598: chicken.compiler.support#db-get */
t6=*((C_word*)lf[68]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[11];
av2[3]=((C_word*)t0)[8];
av2[4]=lf[251];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=t3;
f_10518(t5,C_SCHEME_FALSE);}}
else{
t4=t3;
f_10518(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_10518(t4,C_SCHEME_FALSE);}}

/* k10387 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_10389,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10392,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
t3=C_i_cdr(((C_word*)t0)[6]);
t4=C_eqp(lf[36],t3);
t5=(C_truep(t4)?C_i_setslot(((C_word*)t0)[6],C_fix(1),((C_word*)t0)[5]):C_SCHEME_UNDEFINED);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10412,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[9],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[10])){
t7=t6;
f_10412(t7,(C_truep(((C_word*)t0)[10])?((C_word*)t0)[5]:lf[54]));}
else{
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10503,a[2]=t6,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:626: chicken.compiler.support#db-get */
t8=*((C_word*)lf[68]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[11];
av2[3]=((C_word*)t0)[8];
av2[4]=lf[233];
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_10392(2,av2);}}}

/* k10390 in k10387 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10392(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10392,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10398,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:660: type-always-immediate? */
t3=lf[27];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
f_8151(3,av2);}}

/* k10396 in k10390 in k10387 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,1)))){
C_save_and_reclaim((void *)f_10398,c,av);}
a=C_alloc(58);
if(C_truep(t1)){
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t2,C_fix(1)));
t4=C_i_set_cdr(((C_word*)t0)[3],lf[231]);
t5=lf[16];
t6=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t7=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t7;
av2[1]=lf[232];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t2=lf[16];
t3=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[232];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k10410 in k10387 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10412(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_10412,2,t0,t1);}
a=C_alloc(9);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10420,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=t4,tmp=(C_word)a,a+=7,tmp));
t6=((C_word*)t4)[1];
f_10420(t6,((C_word*)t0)[5],((C_word*)((C_word*)t0)[4])[1],C_SCHEME_FALSE);}

/* loop in k10410 in k10387 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10420(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(17,0,3)))){
C_save_and_reclaim_args((void *)trf_10420,4,t0,t1,t2,t3);}
a=C_alloc(17);
if(C_truep(C_i_nullp(t2))){
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t5=((C_word*)((C_word*)t0)[4])[1];
t6=C_a_i_cons(&a,2,t4,((C_word*)t0)[5]);
t7=C_a_i_cons(&a,2,t6,t5);
t8=C_mutate(((C_word *)((C_word*)t0)[4])+1,t7);
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t4=C_i_car(t2);
t5=C_i_caar(t4);
t6=C_eqp(((C_word*)t0)[2],t5);
if(C_truep(t6)){
t7=C_u_i_car(t2);
t8=C_i_cdr(t7);
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10454,a[2]=t7,a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
t10=C_a_i_list(&a,3,lf[28],((C_word*)t0)[5],t8);
/* scrutinizer.scm:653: simplify-type */
f_13568(t9,t10);}
else{
/* scrutinizer.scm:658: loop */
t12=t1;
t13=C_u_i_cdr(t2);
t14=t3;
t1=t12;
t2=t13;
t3=t14;
goto loop;}}}

/* k10452 in loop in k10410 in k10387 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_10454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10454,c,av);}
t2=C_i_set_cdr(((C_word*)t0)[2],t1);
t3=C_u_i_cdr(((C_word*)t0)[3]);
if(C_truep(((C_word*)t0)[4])){
/* scrutinizer.scm:657: loop */
t4=((C_word*)((C_word*)t0)[5])[1];
f_10420(t4,((C_word*)t0)[6],t3,((C_word*)t0)[4]);}
else{
t4=C_i_cdar(((C_word*)t0)[2]);
/* scrutinizer.scm:657: loop */
t5=((C_word*)((C_word*)t0)[5])[1];
f_10420(t5,((C_word*)t0)[6],t3,C_eqp(((C_word*)t0)[7],t4));}}

/* k10501 in k10387 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10503(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10503,c,av);}
t2=C_i_not(t1);
t3=((C_word*)t0)[2];
f_10412(t3,(C_truep(t2)?((C_word*)t0)[3]:lf[54]));}

/* k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10518(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_10518,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10521,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:599: chicken.compiler.support#db-get */
t3=*((C_word*)lf[68]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[250];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_10389(2,av2);}}}

/* k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_10521,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10524,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t1)){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
f_10524(2,av2);}}
else{
/* scrutinizer.scm:600: chicken.compiler.support#db-get */
t3=*((C_word*)lf[68]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[249];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_10524,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10533,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_i_car(((C_word*)t0)[5]);
t4=C_eqp(t1,t3);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10608,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:602: chicken.compiler.support#variable-visible? */
t6=*((C_word*)lf[248]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t5=t2;
f_10533(t5,C_SCHEME_FALSE);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_10389(2,av2);}}}

/* k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_fcall f_10533(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_10533,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10584,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:605: chicken.compiler.support#tree-copy */
t3=*((C_word*)lf[245]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_10389(2,av2);}}}

/* k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_10539(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_10539,c,av);}
a=C_alloc(10);
t2=C_i_cdar(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10545,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10555,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:608: chicken.base#open-output-string */
t5=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k10543 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_10545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_10545,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10548,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:612: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[234]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[67];
av2[4]=lf[235];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10546 in k10543 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_10548(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10548,c,av);}
/* scrutinizer.scm:613: chicken.compiler.support#mark-variable */
t2=*((C_word*)lf[234]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[66];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k10553 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_10555(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10555,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10561,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:608: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[242];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k10559 in k10553 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_10561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_10561,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10564,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:608: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10562 in k10559 in k10553 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_10564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_10564,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10567,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:608: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(32);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k10565 in k10562 in k10559 in k10553 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f_10567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_10567,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10570,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:608: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10568 in k10565 in k10562 in k10559 in k10553 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in ... */
static void C_ccall f_10570(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_10570,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10573,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:608: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(41);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k10571 in k10568 in k10565 in k10562 in k10559 in k10553 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in ... */
static void C_ccall f_10573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10573,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10576,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:608: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10574 in k10571 in k10568 in k10565 in k10562 in k10559 in k10553 in k10537 in k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in ... */
static void C_ccall f_10576(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10576,c,av);}
/* scrutinizer.scm:608: chicken.compiler.support#debugging */
t2=*((C_word*)lf[237]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[238];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k10582 in k10531 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_10584(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_10584,c,av);}
a=C_alloc(11);
t2=C_a_i_cons(&a,2,C_SCHEME_FALSE,t1);
t3=C_a_i_list1(&a,1,t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10539,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:606: smash-component-types! */
f_11712(t4,t3);}

/* k10602 in k10606 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_10604(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10604,c,av);}
t2=((C_word*)t0)[2];
f_10533(t2,C_i_not(C_eqp(t1,lf[246])));}

/* k10606 in k10522 in k10519 in k10516 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_10608(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_10608,c,av);}
a=C_alloc(3);
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];
f_10533(t3,t2);}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10604,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:603: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[247];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k10635 in k10384 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10637(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10637,c,av);}
t2=((C_word*)t0)[2];
f_10518(t2,C_i_not(t1));}

/* k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10644(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_10644,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10647,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)t0)[9])){
t3=C_set_block_item(((C_word*)t0)[10],0,C_SCHEME_TRUE);
t4=t2;
f_10647(t4,t3);}
else{
t3=t2;
f_10647(t3,C_SCHEME_UNDEFINED);}}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_10386(2,av2);}}}

/* k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10647(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,14)))){
C_save_and_reclaim_args((void *)trf_10647,2,t0,t1);}
a=C_alloc(15);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_a_i_list2(&a,2,((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_23019,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2994: scheme#string-append */
t5=*((C_word*)lf[77]+1);{
C_word av2[15];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[255];
av2[3]=lf[256];
av2[4]=lf[257];
av2[5]=lf[258];
av2[6]=lf[259];
av2[7]=lf[260];
av2[8]=lf[261];
av2[9]=lf[262];
av2[10]=lf[263];
av2[11]=lf[264];
av2[12]=lf[265];
av2[13]=lf[266];
av2[14]=lf[267];
((C_proc)(void*)(*((C_word*)t5+1)))(15,av2);}}

/* k10665 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10667(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_10667,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10674,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:592: match-types */
t3=*((C_word*)lf[171]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];
f_10644(t2,C_SCHEME_FALSE);}}

/* k10672 in k10665 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10674,c,av);}
t2=((C_word*)t0)[2];
f_10644(t2,C_i_not(t1));}

/* k10694 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10696(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_10696,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10700,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:586: type-typeenv */
t3=lf[162];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
f_15975(3,av2);}}

/* k10698 in k10694 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10700(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10700,c,av);}
/* scrutinizer.scm:584: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k10705 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_10707,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10709,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:581: single */
f_8706(((C_word*)t0)[7],t1,t2);}

/* a10708 in k10705 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10709(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_10709,c,av);}
t3=lf[268];
/* scrutinizer.scm:582: g1512 */
t4=lf[268];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=C_i_car(((C_word*)t0)[5]);
av2[6]=t2;
f_22563(7,av2);}}

/* k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,4)))){
C_save_and_reclaim((void *)f_10736,c,av);}
a=C_alloc(36);
t2=C_i_length(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10743,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t8=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_10772,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[2],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[15],a[15]=((C_word*)t0)[16],a[16]=t2,a[17]=((C_word*)t0)[17],a[18]=t5,a[19]=t7,a[20]=t6,tmp=(C_word)a,a+=21,tmp);
t9=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8009,tmp=(C_word)a,a+=2,tmp);
/* mini-srfi-1.scm:225: list-tabulate */
f_7829(t8,t2,t9);}

/* g1605 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_10743(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,7)))){
C_save_and_reclaim_args((void *)trf_10743,4,t0,t1,t2,t3);}
a=C_alloc(12);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10759,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10763,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=t4,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:675: walk */
t6=((C_word*)((C_word*)t0)[5])[1];
f_9540(t6,t5,t2,((C_word*)t0)[6],((C_word*)t0)[2],C_SCHEME_FALSE,((C_word*)t0)[7],C_SCHEME_FALSE);}

/* k10757 in g1605 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10759,c,av);}
a=C_alloc(6);
t2=C_a_i_list1(&a,1,t1);
t3=C_a_i_list1(&a,1,((C_word*)t0)[2]);
/* scrutinizer.scm:671: chicken.compiler.support#make-node */
t4=*((C_word*)lf[270]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[86];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k10761 in g1605 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_10763,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10765,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:674: single */
f_8706(((C_word*)t0)[7],t1,t2);}

/* a10764 in k10761 in g1605 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10765(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_10765,c,av);}
t3=lf[271];
/* scrutinizer.scm:676: g1626 */
t4=lf[271];{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=t2;
f_22156(7,av2);}}

/* k10770 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,4)))){
C_save_and_reclaim((void *)f_10772,c,av);}
a=C_alloc(26);
t2=C_i_check_list_2(t1,lf[6]);
t3=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10778,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],tmp=(C_word)a,a+=18,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11265,a[2]=((C_word*)t0)[18],a[3]=t5,a[4]=((C_word*)t0)[19],a[5]=((C_word*)t0)[20],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_11265(t7,t3,((C_word*)t0)[12],t1);}

/* k10776 in k10770 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_10778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_10778,c,av);}
a=C_alloc(19);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f26693,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k10782 */
static void C_ccall f_10784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,3)))){
C_save_and_reclaim((void *)f_10784,c,av);}
a=C_alloc(36);
t2=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_10787,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],tmp=(C_word)a,a+=21,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=lf[25];
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11225,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11227,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_11227(t12,t8,((C_word*)t0)[4]);}

/* k10785 in k10782 */
static void C_ccall f_10787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_10787,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_10790,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
if(C_truep(((C_word*)t0)[9])){
/* scrutinizer.scm:685: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=lf[277];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_10790(2,av2);}}}

/* k10788 in k10785 in k10782 */
static void C_ccall f_10790(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_10790,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|22,a[1]=(C_word)f_10793,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=t1,a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],tmp=(C_word)a,a+=23,tmp);
if(C_truep(((C_word*)t0)[9])){
/* scrutinizer.scm:686: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=lf[166];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_10793(2,av2);}}}

/* k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10793(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,4)))){
C_save_and_reclaim((void *)f_10793,c,av);}
a=C_alloc(28);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10798,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_10804,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=((C_word*)t0)[15],a[14]=((C_word*)t0)[16],a[15]=t1,a[16]=((C_word*)t0)[17],a[17]=((C_word*)t0)[18],a[18]=((C_word*)t0)[4],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],tmp=(C_word)a,a+=22,tmp);
/* scrutinizer.scm:687: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[22];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a10797 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10798,c,av);}
/* scrutinizer.scm:688: call-result */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8772(t2,t1,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,7)))){
C_save_and_reclaim((void *)f_10804,c,av);}
a=C_alloc(30);
t4=t2;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10807,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t3)){
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10852,a[2]=t5,a[3]=t1,a[4]=((C_word*)t0)[6],a[5]=t6,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:698: walk */
t8=((C_word*)((C_word*)t0)[7])[1];
f_9540(t8,t7,((C_word*)t0)[8],((C_word*)t0)[3],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[12]);}
else{
t7=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_11208,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[13],a[11]=((C_word*)t0)[14],a[12]=((C_word*)t0)[15],a[13]=((C_word*)t0)[6],a[14]=((C_word*)t0)[16],a[15]=((C_word*)t0)[17],a[16]=t5,a[17]=((C_word*)t0)[18],a[18]=((C_word*)t0)[19],a[19]=((C_word*)t0)[20],a[20]=t6,a[21]=((C_word*)t0)[21],tmp=(C_word)a,a+=22,tmp);
/* scrutinizer.scm:705: chicken.compiler.support#node-class */
t8=*((C_word*)lf[89]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}

/* smash in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_10807(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_10807,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10814,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_not(((C_word*)t0)[4]))){
t3=C_i_not(((C_word*)t0)[5]);
if(C_truep(t3)){
t4=t2;
f_10814(t4,t3);}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10846,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:693: chicken.compiler.support#variable-mark */
t5=*((C_word*)lf[65]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[273];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}
else{
t3=t2;
f_10814(t3,C_SCHEME_FALSE);}}

/* k10812 in smash in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_10814(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_10814,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10817,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:695: smash-component-types! */
f_11712(t2,((C_word*)t0)[4]);}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10815 in k10812 in smash in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10817(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10817,c,av);}
/* scrutinizer.scm:696: smash-component-types! */
f_11712(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);}

/* k10840 in k10844 in smash in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10842,c,av);}
t2=((C_word*)t0)[2];
f_10814(t2,C_i_not(t1));}

/* k10844 in smash in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10846(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_10846,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10842,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:694: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[272];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_10814(t2,C_SCHEME_FALSE);}}

/* k10850 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10852,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10855,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:699: smash */
t3=((C_word*)t0)[5];
f_10807(t3,t2);}

/* k10853 in k10850 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_10855,c,av);}
a=C_alloc(16);
t2=C_eqp(lf[54],((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(t2)){
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10865,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t8=((C_word*)((C_word*)t0)[2])[1];
t9=C_i_check_list_2(t8,lf[6]);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10877,a[2]=t5,a[3]=t11,a[4]=t7,a[5]=t6,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_10877(t13,((C_word*)t0)[3],t8);}}

/* g1701 in k10853 in k10850 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_10865(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_10865,3,t0,t1,t2);}
t3=lf[119];
/* scrutinizer.scm:704: g1718 */
t4=lf[119];{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
av2[3]=((C_word*)t0)[2];
f_16350(4,av2);}}

/* map-loop1695 in k10853 in k10850 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_10877(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_10877,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10902,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:704: g1701 */
t4=((C_word*)t0)[4];
f_10865(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10900 in map-loop1695 in k10853 in k10850 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10902(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10902,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_10877(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_10919(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,2)))){
C_save_and_reclaim_args((void *)trf_10919,4,t0,t1,t2,t3);}
a=C_alloc(19);
t4=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_11083,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],a[14]=((C_word*)t0)[12],a[15]=((C_word*)t0)[13],a[16]=t3,a[17]=((C_word*)t0)[14],a[18]=((C_word*)t0)[15],tmp=(C_word)a,a+=19,tmp);
/* scrutinizer.scm:710: chicken.compiler.support#node-class */
t5=*((C_word*)lf[89]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_10932,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10935,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],tmp=(C_word)a,a+=18,tmp);
if(C_truep(t1)){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
f_10935(2,av2);}}
else{
/* scrutinizer.scm:712: chicken.base#alist-ref */
t3=*((C_word*)lf[276]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[18];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10935(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_10935,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10938,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],tmp=(C_word)a,a+=18,tmp);
/* scrutinizer.scm:713: resolve */
t3=lf[119];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[17];
av2[3]=((C_word*)t0)[9];
f_16350(4,av2);}}

/* k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_10938,c,av);}
a=C_alloc(22);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_eqp(((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10944,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[12],a[11]=t1,a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[15],a[15]=((C_word*)t0)[16],a[16]=((C_word*)t0)[17],a[17]=t3,tmp=(C_word)a,a+=18,tmp);
if(C_truep(((C_word*)t0)[9])){
if(C_truep(((C_word*)t0)[8])){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11068,a[2]=t4,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:717: chicken.compiler.support#db-get */
t6=*((C_word*)lf[68]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[13];
av2[3]=((C_word*)t0)[7];
av2[4]=lf[69];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=t4;
f_10944(t5,C_SCHEME_FALSE);}}
else{
t5=t4;
f_10944(t5,C_SCHEME_FALSE);}}

/* k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_10944(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_10944,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10950,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:722: resolve */
t3=lf[119];{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[8];
f_16350(4,av2);}}
else{
if(C_truep(((C_word*)t0)[2])){
if(C_truep(((C_word*)t0)[9])){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11000,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[10],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11028,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[11],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:740: chicken.compiler.support#db-get */
t4=*((C_word*)lf[68]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[12];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[69];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11034,a[2]=((C_word*)t0)[13],a[3]=((C_word*)t0)[14],a[4]=((C_word*)t0)[15],a[5]=((C_word*)t0)[16],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[17])){
/* scrutinizer.scm:750: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[275];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_11034(2,av2);}}}}}

/* k10948 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10950(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_10950,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10956,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t3=C_i_car(((C_word*)t0)[6]);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10985,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[5],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_not(((C_word*)t0)[2]))){
/* scrutinizer.scm:725: add-to-blist */
t5=((C_word*)((C_word*)t0)[3])[1];
f_9411(t5,t2,((C_word*)t0)[5],t3,t1);}
else{
/* scrutinizer.scm:727: refine-types */
t5=*((C_word*)lf[274]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[2];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k10954 in k10948 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10956(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_10956,c,av);}
a=C_alloc(12);
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10962,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t3=C_a_i_list(&a,2,lf[70],((C_word*)t0)[7]);
/* scrutinizer.scm:733: refine-types */
t4=*((C_word*)lf[274]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10960 in k10954 in k10948 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10962(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10962,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:737: add-to-blist */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9411(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_u_i_cdr(((C_word*)t0)[5]),t1);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k10983 in k10948 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_10985(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10985,c,av);}
/* scrutinizer.scm:725: add-to-blist */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9411(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* k10998 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11000(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_11000,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11006,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:745: add-to-blist */
t3=((C_word*)((C_word*)t0)[3])[1];
f_9411(t3,t2,((C_word*)t0)[5],C_i_car(((C_word*)t0)[6]),t1);}

/* k11004 in k10998 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11006(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_11006,c,av);}
a=C_alloc(7);
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11012,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:747: add-to-blist */
t3=((C_word*)((C_word*)t0)[3])[1];
f_9411(t3,t2,((C_word*)t0)[5],C_i_car(((C_word*)t0)[2]),((C_word*)t0)[6]);}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11010 in k11004 in k10998 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11012,c,av);}
/* scrutinizer.scm:748: add-to-blist */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9411(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6]);}

/* k11026 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11028(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11028,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[54];
f_11000(2,av2);}}
else{
/* scrutinizer.scm:742: refine-types */
t2=*((C_word*)lf[274]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k11032 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11034(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_11034,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11038,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:719: g1778 */
t3=t2;
f_11038(t3,((C_word*)t0)[6],t1);}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g1778 in k11032 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_11038(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,5)))){
C_save_and_reclaim_args((void *)trf_11038,3,t0,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11046,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:755: srt */
t4=t2;{
C_word av2[6];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k11044 in g1778 in k11032 in k10942 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11046(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11046,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11066 in k10936 in k10933 in k10930 in k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11068(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11068,c,av);}
t2=C_i_not(t1);
t3=((C_word*)t0)[2];
f_10944(t3,(C_truep(t2)?C_i_not(((C_word*)t0)[3]):C_SCHEME_FALSE));}

/* k11077 in k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_11079,c,av);}
a=C_alloc(19);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_10932,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
/* scrutinizer.scm:712: blist-type */
t4=((C_word*)((C_word*)t0)[18])[1];
f_8526(t4,t3,t2,((C_word*)t0)[10]);}

/* k11081 in g1732 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11083(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_11083,c,av);}
a=C_alloc(19);
t2=C_eqp(lf[88],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_11079,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],tmp=(C_word)a,a+=19,tmp);
/* scrutinizer.scm:711: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k11090 in k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11092,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11095,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:762: smash */
t3=((C_word*)t0)[5];
f_10807(t3,t2);}

/* k11093 in k11090 in k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11095(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_11095,c,av);}
a=C_alloc(16);
t2=C_eqp(lf[54],((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(t2)){
t3=((C_word*)((C_word*)t0)[2])[1];
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11105,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t8=((C_word*)((C_word*)t0)[2])[1];
t9=C_i_check_list_2(t8,lf[6]);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11117,a[2]=t5,a[3]=t11,a[4]=t7,a[5]=t6,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_11117(t13,((C_word*)t0)[3],t8);}}

/* g1802 in k11093 in k11090 in k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_11105(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_11105,3,t0,t1,t2);}
t3=lf[119];
/* scrutinizer.scm:765: g1819 */
t4=lf[119];{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
av2[3]=((C_word*)t0)[2];
f_16350(4,av2);}}

/* map-loop1796 in k11093 in k11090 in k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_11117(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11117,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11142,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:765: g1802 */
t4=((C_word*)t0)[4];
f_11105(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11140 in map-loop1796 in k11093 in k11090 in k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11142,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11117(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* for-each-loop1731 in k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_fcall f_11151(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_11151,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11161,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:708: g1732 */
t7=((C_word*)t0)[3];
f_10919(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k11159 in for-each-loop1731 in k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11161,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_11151(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11188 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11190(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_11190,c,av);}
a=C_alloc(15);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_i_check_list_2(((C_word*)t0)[3],lf[213]);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11092,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11151,a[2]=t6,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_11151(t8,t4,((C_word*)t0)[3],t2);}

/* a11191 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11192(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_11192,c,av);}
a=C_alloc(5);
t2=C_a_i_fixnum_difference(&a,2,((C_word*)t0)[2],C_fix(1));
/* scrutinizer.scm:761: procedure-argument-types */
f_15401(t1,((C_word*)t0)[3],t2,((C_word*)t0)[4],C_SCHEME_END_OF_LIST);}

/* a11199 in k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11200,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_list_ref(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11206 in a10803 in k10791 in k10788 in k10785 in k10782 */
static void C_ccall f_11208(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,7)))){
C_save_and_reclaim((void *)f_11208,c,av);}
a=C_alloc(32);
t2=C_eqp(lf[124],t1);
if(C_truep(t2)){
/* scrutinizer.scm:706: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_9540(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}
else{
t3=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_10919,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[12],a[6]=((C_word*)t0)[13],a[7]=((C_word*)t0)[14],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[15],a[10]=((C_word*)t0)[16],a[11]=((C_word*)t0)[4],a[12]=((C_word*)t0)[17],a[13]=((C_word*)t0)[6],a[14]=((C_word*)t0)[5],a[15]=((C_word*)t0)[18],tmp=(C_word)a,a+=16,tmp);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11190,a[2]=((C_word*)t0)[19],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[16],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[13],a[7]=((C_word*)t0)[20],a[8]=t3,tmp=(C_word)a,a+=9,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11192,a[2]=((C_word*)t0)[21],a[3]=((C_word*)t0)[19],a[4]=((C_word*)t0)[13],tmp=(C_word)a,a+=5,tmp);
t6=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11200,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:759: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t4;
av2[2]=t5;
av2[3]=t6;
C_call_with_values(4,av2);}}}

/* k11223 in k10782 */
static void C_ccall f_11225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11225,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[28],t1);
/* scrutinizer.scm:682: type-typeenv */
t3=lf[162];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
f_15975(3,av2);}}

/* map-loop1646 in k10782 */
static void C_fcall f_11227(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11227,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26686,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* map-loop1599 in k10770 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11265(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_11265,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11294,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:670: g1605 */
t7=((C_word*)t0)[4];
f_10743(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k11292 in map-loop1599 in k10770 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_11294,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11265(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)),C_slot(((C_word*)t0)[6],C_fix(1)));}

/* k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,10)))){
C_save_and_reclaim((void *)f_11323,c,av);}
a=C_alloc(36);
t2=C_eqp(t1,lf[54]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11329,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t2)){
t4=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t5=lf[16];
t6=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
if(C_truep(C_i_nullp(t1))){
t4=C_i_car(((C_word*)t0)[4]);
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22803,a[2]=t3,a[3]=t5,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=t4,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2878: scheme#string-append */
t7=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[280];
av2[3]=lf[281];
av2[4]=lf[282];
av2[5]=lf[283];
av2[6]=lf[284];
av2[7]=lf[285];
av2[8]=lf[286];
((C_proc)(void*)(*((C_word*)t7+1)))(9,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11348,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t3,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[3],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
t5=C_i_length(t1);
if(C_truep(C_fixnum_greaterp(t5,C_fix(1)))){
t6=C_i_car(((C_word*)t0)[4]);
t7=C_a_i_list1(&a,1,t6);
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22825,a[2]=t1,a[3]=t4,a[4]=t7,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=t6,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2895: scheme#string-append */
t9=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[303];
av2[3]=lf[304];
av2[4]=lf[305];
av2[5]=lf[306];
av2[6]=lf[307];
av2[7]=lf[308];
av2[8]=lf[309];
av2[9]=lf[310];
av2[10]=lf[311];
((C_proc)(void*)(*((C_word*)t9+1)))(11,av2);}}
else{
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_11348(2,av2);}}}}}

/* k11327 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11329(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_11329,c,av);}
a=C_alloc(32);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=lf[16];
t4=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11348(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_11348,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11354,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(C_i_cadr(((C_word*)t0)[10]))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11379,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:775: compatible-types? */
f_14775(t3,((C_word*)t0)[6],C_i_car(((C_word*)t0)[3]),C_SCHEME_END_OF_LIST);}
else{
t3=t2;
f_11354(t3,C_SCHEME_FALSE);}}

/* k11352 in k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11354(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,0,2)))){
C_save_and_reclaim_args((void *)trf_11354,2,t0,t1);}
a=C_alloc(32);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11357,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[7])){
t3=C_set_block_item(((C_word*)t0)[8],0,C_SCHEME_TRUE);
t4=t2;
f_11357(t4,t3);}
else{
t3=t2;
f_11357(t3,C_SCHEME_UNDEFINED);}}
else{
t2=C_a_i_list1(&a,1,((C_word*)t0)[6]);
t3=lf[16];
t4=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t5=((C_word*)t0)[9];{
C_word av2[2];
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k11355 in k11352 in k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11357(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,14)))){
C_save_and_reclaim_args((void *)trf_11357,2,t0,t1);}
a=C_alloc(11);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_car(((C_word*)t0)[3]);
t4=C_a_i_list1(&a,1,t2);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22851,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=((C_word*)t0)[5],a[5]=t3,a[6]=((C_word*)t0)[6],a[7]=t2,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2915: scheme#string-append */
t6=*((C_word*)lf[77]+1);{
C_word av2[15];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[288];
av2[3]=lf[289];
av2[4]=lf[290];
av2[5]=lf[291];
av2[6]=lf[292];
av2[7]=lf[293];
av2[8]=lf[294];
av2[9]=lf[295];
av2[10]=lf[296];
av2[11]=lf[297];
av2[12]=lf[298];
av2[13]=lf[299];
av2[14]=lf[300];
((C_proc)(void*)(*((C_word*)t6+1)))(15,av2);}}

/* k11377 in k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11379,c,av);}
t2=((C_word*)t0)[2];
f_11354(t2,C_i_not(t1));}

/* k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11411(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_11411,c,av);}
a=C_alloc(14);
t2=lf[24];
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_11414,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=t2,a[13]=((C_word*)t0)[11],tmp=(C_word)a,a+=14,tmp);
/* scrutinizer.scm:782: type-typeenv */
t4=lf[162];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(t1);
f_15975(3,av2);}}

/* k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11414(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_11414,c,av);}
a=C_alloc(16);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_i_cdr(((C_word*)t0)[3]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_11427,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=t5,a[12]=((C_word*)t0)[12],a[13]=t1,tmp=(C_word)a,a+=14,tmp));
t7=((C_word*)t5)[1];
f_11427(t7,((C_word*)t0)[13],t2,t3);}

/* loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11427(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,18)))){
C_save_and_reclaim_args((void *)trf_11427,4,t0,t1,t2,t3);}
a=C_alloc(19);
if(C_truep(C_i_nullp(t2))){
t4=C_i_car(((C_word*)t0)[2]);
t5=C_i_cdr(((C_word*)t0)[3]);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22883,a[2]=t1,a[3]=t5,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2936: scheme#string-append */
t7=*((C_word*)lf[77]+1);{
C_word av2[19];
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[325];
av2[3]=lf[326];
av2[4]=lf[327];
av2[5]=lf[328];
av2[6]=lf[329];
av2[7]=lf[330];
av2[8]=lf[331];
av2[9]=lf[332];
av2[10]=lf[333];
av2[11]=lf[334];
av2[12]=lf[335];
av2[13]=lf[336];
av2[14]=lf[337];
av2[15]=lf[338];
av2[16]=lf[339];
av2[17]=lf[340];
av2[18]=lf[341];
((C_proc)(void*)(*((C_word*)t7+1)))(19,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_11448,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=t3,a[11]=((C_word*)t0)[11],a[12]=t2,a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[2],tmp=(C_word)a,a+=15,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11486,a[2]=t4,a[3]=((C_word*)t0)[13],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:787: type-typeenv */
t6=lf[162];{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_i_car(t2);
f_15975(3,av2);}}}

/* k11446 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11448(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,5)))){
C_save_and_reclaim((void *)f_11448,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_11454,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=t1,tmp=(C_word)a,a+=15,tmp);
/* scrutinizer.scm:788: match-types */
t3=*((C_word*)lf[171]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_car(((C_word*)t0)[12]);
av2[3]=C_i_car(((C_word*)t0)[14]);
av2[4]=t1;
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k11452 in k11446 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_11454,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11457,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:790: mutate-node! */
f_17510(t2,((C_word*)t0)[4],C_i_car(((C_word*)t0)[10]));}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11467,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:793: trail-restore */
f_16307(t2,((C_word*)t0)[13],((C_word*)t0)[14]);}}

/* k11455 in k11452 in k11446 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_11457,c,av);}
/* scrutinizer.scm:791: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9540(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k11465 in k11452 in k11446 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11467(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11467,c,av);}
/* scrutinizer.scm:794: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_11427(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_i_cdr(((C_word*)t0)[5]));}

/* k11484 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11486(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11486,c,av);}
/* scrutinizer.scm:787: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* g1860 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11511(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,7)))){
C_save_and_reclaim_args((void *)trf_11511,3,t0,t1,t2);}
/* scrutinizer.scm:798: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_9540(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_FALSE,((C_word*)t0)[5],C_SCHEME_FALSE);}

/* k11519 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_11521,c,av);}
a=C_alloc(29);
t2=lf[16];
t3=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* for-each-loop1859 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11523(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_11523,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11533,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:798: g1860 */
t4=((C_word*)t0)[3];
f_11511(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k11531 in for-each-loop1859 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11533,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_11523(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_11594,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11597,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_pairp(lf[23]))){
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11635,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:806: chicken.compiler.support#with-debugging-output */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[359];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_11597(2,av2);}}}

/* k11595 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11597(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_11597,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11600,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=((C_word*)((C_word*)t0)[7])[1];
if(C_truep(C_i_positivep(t3))){
/* scrutinizer.scm:815: chicken.compiler.support#debugging */
t4=*((C_word*)lf[237]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[351];
av2[3]=lf[352];
av2[4]=((C_word*)((C_word*)t0)[7])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_11600(2,av2);}}}

/* k11598 in k11595 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11600(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_11600,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11603,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=((C_word*)((C_word*)t0)[6])[1];
if(C_truep(C_i_positivep(t3))){
/* scrutinizer.scm:817: chicken.compiler.support#debugging */
t4=*((C_word*)lf[237]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[349];
av2[3]=lf[350];
av2[4]=((C_word*)((C_word*)t0)[6])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_11603(2,av2);}}}

/* k11601 in k11598 in k11595 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11603(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_11603,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11606,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)((C_word*)t0)[5])[1];
if(C_truep(C_i_positivep(t3))){
/* scrutinizer.scm:819: chicken.compiler.support#debugging */
t4=*((C_word*)lf[237]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[347];
av2[3]=lf[348];
av2[4]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_11606(2,av2);}}}

/* k11604 in k11601 in k11598 in k11595 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_11606,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11612,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)((C_word*)t0)[4])[1])){
/* scrutinizer.scm:822: chicken.compiler.support#quit-compiling */
t3=*((C_word*)lf[313]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[346];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11610 in k11604 in k11601 in k11598 in k11595 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11612(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11612,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11635,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11639,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:809: chicken.base#print */
t3=*((C_word*)lf[356]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[357];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11637 in a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11639,c,av);}
a=C_alloc(5);
t2=lf[23];
t3=C_i_check_list_2(lf[23],lf[213]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11673,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_11673(t7,((C_word*)t0)[2],lf[23]);}

/* k11645 in for-each-loop1885 in k11637 in a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11647(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_11647,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11650,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:812: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cdr(((C_word*)t0)[4]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11648 in k11645 in for-each-loop1885 in k11637 in a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11650(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11650,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11653,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:812: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(32);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11651 in k11648 in k11645 in for-each-loop1885 in k11637 in a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11653(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11653,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11656,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:812: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_car(((C_word*)t0)[4]);
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11654 in k11651 in k11648 in k11645 in for-each-loop1885 in k11637 in a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11656,c,av);}
/* scrutinizer.scm:812: ##sys#write-char-0 */
t2=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(10);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop1885 in k11637 in a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11673(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_11673,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11683,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[353]+1);
t6=*((C_word*)lf[353]+1);
t7=C_i_check_port_2(*((C_word*)lf[353]+1),C_fix(2),C_SCHEME_TRUE,lf[354]);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11647,a[2]=t3,a[3]=t5,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:812: ##sys#print */
t9=*((C_word*)lf[241]+1);{
C_word av2[5];
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[355];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[353]+1);
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k11681 in for-each-loop1885 in k11637 in a11634 in k11592 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11683,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_11673(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k11708 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11710(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,7)))){
C_save_and_reclaim((void *)f_11710,c,av);}
a=C_alloc(32);
t2=C_i_car(t1);
t3=(
/* scrutinizer.scm:804: tag */
  f_9406(C_a_i(&a,29),((C_word*)((C_word*)t0)[2])[1])
);
t4=C_a_i_list1(&a,1,t3);
/* scrutinizer.scm:804: walk */
t5=((C_word*)((C_word*)t0)[3])[1];
f_9540(t5,((C_word*)t0)[4],t2,C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE,t4,C_SCHEME_FALSE);}

/* chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11712(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_11712,2,t1,t2);}
a=C_alloc(5);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11718,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_11718(t6,t1,t2);}

/* doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11718(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,4)))){
C_save_and_reclaim_args((void *)trf_11718,3,t0,t1,t2);}
a=C_alloc(13);
if(C_truep(C_i_nullp(t2))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11728,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_i_cdar(t2);
t5=C_u_i_car(t2);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11740,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11748,a[2]=t8,tmp=(C_word)a,a+=3,tmp));
t10=((C_word*)t8)[1];
f_11748(t10,t3,t4,t6);}}

/* k11726 in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11728(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11728,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_11718(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* a11738 in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11740,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_setslot(((C_word*)t0)[2],C_fix(1),t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11748(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(16,0,3)))){
C_save_and_reclaim_args((void *)trf_11748,4,t0,t1,t2,t3);}
a=C_alloc(16);
if(C_truep(C_i_pairp(t2))){
t4=C_u_i_car(t2);
t5=C_eqp(t4,lf[360]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11768,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:840: change! */
t7=t3;{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[51];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t6=C_eqp(t4,lf[51]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11781,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t8=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t9=t8;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=((C_word*)t10)[1];
t12=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11793,a[2]=t2,a[3]=t3,a[4]=t7,a[5]=t10,a[6]=t11,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:845: chicken.base#constantly */
t13=*((C_word*)lf[361]+1);{
C_word av2[3];
av2[0]=t13;
av2[1]=t12;
av2[2]=lf[54];
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t7=C_eqp(t4,lf[362]);
t8=(C_truep(t7)?t7:C_eqp(t4,lf[48]));
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11849,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:849: change! */
t10=t3;{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=lf[363];
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}
else{
t9=C_eqp(t4,lf[49]);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11862,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:853: change! */
t11=t3;{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=C_u_i_car(t2);
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=C_eqp(t4,lf[29]);
if(C_truep(t10)){
t11=C_i_caddr(t2);
t12=C_i_cddr(t2);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11883,a[2]=t12,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:856: loop */
t15=t1;
t16=t11;
t17=t13;
t1=t15;
t2=t16;
t3=t17;
goto loop;}
else{
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}}}}
else{
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k11766 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11768,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k11779 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11781,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k11791 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11793(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_11793,c,av);}
a=C_alloc(12);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_check_list_2(t2,lf[6]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11800,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11802,a[2]=((C_word*)t0)[5],a[3]=t6,a[4]=t1,a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp));
t8=((C_word*)t6)[1];
f_11802(t8,t4,t2);}

/* k11798 in k11791 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11800,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[51],t1);
/* scrutinizer.scm:845: change! */
t3=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* map-loop1956 in k11791 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11802(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11802,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11827,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:845: g1962 */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11825 in map-loop1956 in k11791 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11827,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11802(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11847 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11849,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k11860 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11862,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a11879 in loop in doloop1938 in chicken.compiler.scrutinizer#smash-component-types! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11883(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11883,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_set_car(((C_word*)t0)[2],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11908(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +15,c,2)))){
C_save_and_reclaim((void*)f_11908,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+15);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11912,a[2]=t4,a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_nullp(t4))){
t6=C_a_i_list(&a,3,lf[28],t2,t3);
/* scrutinizer.scm:874: type-typeenv */
t7=lf[162];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t5;
av2[2]=t6;
f_15975(3,av2);}}
else{
t6=t5;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_i_car(t4);
f_11912(2,av2);}}}

/* k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_11912(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(42,c,4)))){
C_save_and_reclaim((void *)f_11912,c,av);}
a=C_alloc(42);
t2=C_i_nullp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_SCHEME_END_OF_LIST:C_i_cdr(((C_word*)t0)[2]));
t4=C_i_nullp(t3);
t5=(C_truep(t4)?C_SCHEME_FALSE:C_i_car(t3));
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_i_nullp(t3);
t9=(C_truep(t8)?C_SCHEME_END_OF_LIST:C_i_cdr(t3));
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_SCHEME_UNDEFINED;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_SCHEME_UNDEFINED;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11923,a[2]=t13,a[3]=t21,tmp=(C_word)a,a+=4,tmp));
t23=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12054,a[2]=t21,tmp=(C_word)a,a+=3,tmp));
t24=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12117,a[2]=t7,a[3]=t15,a[4]=t21,tmp=(C_word)a,a+=5,tmp));
t25=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12185,a[2]=t7,a[3]=t21,tmp=(C_word)a,a+=4,tmp));
t26=C_set_block_item(t19,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12207,a[2]=t21,tmp=(C_word)a,a+=3,tmp));
t27=C_set_block_item(t21,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12243,a[2]=t1,a[3]=t17,a[4]=t21,a[5]=t7,a[6]=t15,a[7]=t11,a[8]=t19,tmp=(C_word)a,a+=9,tmp));
/* scrutinizer.scm:1109: match1 */
t28=((C_word*)t21)[1];
f_12243(t28,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* match-args in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11923(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,6)))){
C_save_and_reclaim_args((void *)trf_11923,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11932,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_11932(t7,t1,t2,t3,C_SCHEME_FALSE,C_SCHEME_FALSE);}

/* loop in match-args in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_11932(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,5)))){
C_save_and_reclaim_args((void *)trf_11932,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_i_nullp(t3);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=(C_truep(t6)?t6:C_u_i_memq(C_i_car(t3),lf[364]));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
if(C_truep(C_i_nullp(t3))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t4)?t4:C_u_i_memq(C_i_car(t2),lf[364]));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_i_car(t2);
t7=C_eqp(lf[365],t6);
if(C_truep(t7)){
/* scrutinizer.scm:887: loop */
t14=t1;
t15=C_u_i_cdr(t2);
t16=t3;
t17=C_SCHEME_TRUE;
t18=t5;
t1=t14;
t2=t15;
t3=t16;
t4=t17;
t5=t18;
goto loop;}
else{
t8=C_i_car(t3);
t9=C_eqp(lf[365],t8);
if(C_truep(t9)){
/* scrutinizer.scm:889: loop */
t14=t1;
t15=t2;
t16=C_u_i_cdr(t3);
t17=t4;
t18=C_SCHEME_TRUE;
t1=t14;
t2=t15;
t3=t16;
t4=t17;
t5=t18;
goto loop;}
else{
t10=C_eqp(lf[366],C_u_i_car(t2));
if(C_truep(t10)){
t11=(
/* scrutinizer.scm:891: rest-type */
  f_15805(C_u_i_cdr(t2))
);
/* scrutinizer.scm:891: match-rest */
t12=((C_word*)((C_word*)t0)[3])[1];
f_12054(t12,t1,t11,t3);}
else{
t11=C_eqp(lf[366],C_u_i_car(t3));
if(C_truep(t11)){
t12=(
/* scrutinizer.scm:893: rest-type */
  f_15805(C_u_i_cdr(t3))
);
/* scrutinizer.scm:893: match-rest */
t13=((C_word*)((C_word*)t0)[3])[1];
f_12054(t13,t1,t12,t2);}
else{
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12029,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:894: match1 */
t13=((C_word*)((C_word*)t0)[4])[1];
f_12243(t13,t12,C_u_i_car(t2),C_u_i_car(t3));}}}}}}}

/* k12027 in loop in match-args in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12029(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_12029,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:895: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_11932(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7]);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12054(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_12054,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12060,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12076,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:899: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=t1;
av2[2]=t4;
av2[3]=t5;
C_call_with_values(4,av2);}}

/* a12059 in match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12060(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12060,c,av);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6882,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_6882(t5,t1,((C_word*)t0)[2],C_SCHEME_END_OF_LIST);}

/* a12075 in match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_12076,c,av);}
a=C_alloc(10);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12083,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12100,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:900: every */
f_7187(t4,t5,t2);}

/* k12081 in a12075 in match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12083(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12083,c,av);}
if(C_truep(t1)){
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t2=(
/* scrutinizer.scm:905: rest-type */
  f_15805(C_u_i_cdr(((C_word*)t0)[2]))
);
/* scrutinizer.scm:905: match1 */
t3=((C_word*)((C_word*)t0)[3])[1];
f_12243(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}
else{
/* scrutinizer.scm:905: match1 */
t2=((C_word*)((C_word*)t0)[3])[1];
f_12243(t2,((C_word*)t0)[4],((C_word*)t0)[5],lf[54]);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a12099 in a12075 in match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12100(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12100,c,av);}
t3=C_eqp(lf[365],t2);
if(C_truep(t3)){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* scrutinizer.scm:903: match1 */
t4=((C_word*)((C_word*)t0)[2])[1];
f_12243(t4,t1,((C_word*)t0)[3],t2);}}

/* match-results in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12117(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_12117,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_eqp(lf[54],t2);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(lf[54],t3);
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_i_not(((C_word*)((C_word*)t0)[2])[1]);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
if(C_truep(C_i_nullp(t2))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_i_nullp(t3);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
if(C_truep(C_i_nullp(t3))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_i_car(t2);
t7=(C_truep((C_truep(C_eqp(t6,lf[36]))?C_SCHEME_TRUE:(C_truep(C_eqp(t6,lf[71]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))?C_u_i_memq(C_i_car(t3),lf[369]):C_SCHEME_FALSE);
if(C_truep(t7)){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12160,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:917: match1 */
t9=((C_word*)((C_word*)t0)[4])[1];
f_12243(t9,t8,C_u_i_car(t2),C_i_car(t3));}}}}}}

/* k12158 in match-results in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12160(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12160,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:918: match-results */
t2=((C_word*)((C_word*)t0)[2])[1];
f_12117(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* rawmatch1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12185(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,4)))){
C_save_and_reclaim_args((void *)trf_12185,4,t0,t1,t2,t3);}
a=C_alloc(19);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_FALSE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12191,a[2]=t7,a[3]=((C_word*)t0)[2],a[4]=t5,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12196,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12202,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t7,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:922: ##sys#dynamic-wind */
t11=*((C_word*)lf[225]+1);{
C_word av2[5];
av2[0]=t11;
av2[1]=t1;
av2[2]=t8;
av2[3]=t9;
av2[4]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}

/* a12190 in rawmatch1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12191,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a12195 in rawmatch1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12196(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12196,c,av);}
/* scrutinizer.scm:923: match1 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_12243(t2,t1,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* a12201 in rawmatch1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12202(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12202,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* every-match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12207(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_12207,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12213,a[2]=t5,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_12213(t7,t1,t2,t3);}

/* loop in every-match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12213(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_12213,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_nullp(t2);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12226,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:928: match1 */
t6=((C_word*)((C_word*)t0)[3])[1];
f_12243(t6,t5,C_i_car(t2),C_i_car(t3));}}

/* k12224 in loop in every-match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12226,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:928: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_12213(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12243(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_12243,4,t0,t1,t2,t3);}
a=C_alloc(11);
t4=C_eqp(t2,t3);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_symbolp(t2);
t6=(C_truep(t5)?C_i_assq(t2,((C_word*)t0)[2]):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12260,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:934: g2143 */
t8=t7;
f_12260(t8,t1,t6);}
else{
t7=C_i_symbolp(t3);
t8=(C_truep(t7)?C_i_assq(t3,((C_word*)t0)[2]):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12392,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:934: g2176 */
t10=t9;
f_12392(t10,t1,t8);}
else{
t9=C_eqp(t2,lf[54]);
if(C_truep(t9)){
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t10=C_eqp(t3,lf[54]);
if(C_truep(t10)){
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=C_i_not(((C_word*)((C_word*)t0)[5])[1]);
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t11=C_eqp(t2,lf[36]);
if(C_truep(t11)){
t12=t1;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t12=C_eqp(t3,lf[36]);
if(C_truep(t12)){
t13=t1;{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t13=C_eqp(t2,lf[71]);
if(C_truep(t13)){
t14=t1;{
C_word av2[2];
av2[0]=t14;
av2[1]=t13;
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t14=C_eqp(t3,lf[71]);
if(C_truep(t14)){
t15=t1;{
C_word av2[2];
av2[0]=t15;
av2[1]=t14;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t15=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12505,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=t1,a[5]=t2,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_symbolp(t2))){
/* scrutinizer.scm:1275: chicken.base#alist-ref */
t16=*((C_word*)lf[276]+1);{
C_word av2[5];
av2[0]=t16;
av2[1]=t15;
av2[2]=t2;
av2[3]=lf[374];
av2[4]=*((C_word*)lf[375]+1);
((C_proc)(void*)(*((C_word*)t16+1)))(5,av2);}}
else{
t16=t15;{
C_word av2[2];
av2[0]=t16;
av2[1]=C_SCHEME_FALSE;
f_12505(2,av2);}}}}}}}}}}}}

/* g2143 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12260(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_12260,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_cadr(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12273,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:939: match1 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_12243(t4,t3,C_i_cadr(t2),((C_word*)t0)[3]);}
else{
t3=C_i_symbolp(((C_word*)t0)[3]);
t4=(C_truep(t3)?C_i_assq(((C_word*)t0)[3],((C_word*)t0)[5]):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12301,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:938: g2157 */
t6=t5;
f_12301(t6,t1,t4);}
else{
t5=C_i_caddr(t2);
t6=C_i_not(t5);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12351,a[2]=((C_word*)t0)[6],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
if(C_truep(t6)){
t8=t7;{
C_word av2[2];
av2[0]=t8;
av2[1]=t6;
f_12351(2,av2);}}
else{
/* scrutinizer.scm:953: rawmatch1 */
t8=((C_word*)((C_word*)t0)[2])[1];
f_12185(t8,t7,C_i_caddr(t2),((C_word*)t0)[3]);}}}}

/* k12271 in g2143 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12273,c,av);}
if(C_truep(t1)){
t2=C_i_caddr(((C_word*)t0)[2]);
t3=C_i_not(t2);
if(C_truep(t3)){
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* scrutinizer.scm:941: rawmatch1 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_12185(t4,((C_word*)t0)[3],C_i_caddr(((C_word*)t0)[2]),((C_word*)t0)[5]);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g2157 in g2143 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12301(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_12301,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_i_cadr(t2);
t4=C_i_not(t3);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12314,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:949: match1 */
t6=((C_word*)((C_word*)t0)[4])[1];
f_12243(t6,t5,((C_word*)t0)[3],C_i_cadr(t2));}}

/* k12312 in g2157 in g2143 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12314,c,av);}
if(C_truep(t1)){
t2=C_i_caddr(((C_word*)t0)[2]);
t3=C_i_not(t2);
if(C_truep(t3)){
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* scrutinizer.scm:951: rawmatch1 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_12185(t4,((C_word*)t0)[3],((C_word*)t0)[5],C_i_caddr(((C_word*)t0)[2]));}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k12349 in g2143 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12351(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_12351,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],lf[24]);
t3=C_mutate(&lf[24] /* (set! chicken.compiler.scrutinizer#trail ...) */,t2);
t4=C_i_cdr(((C_word*)t0)[3]);
t5=C_i_set_car(t4,((C_word*)t0)[4]);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g2176 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12392(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_12392,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_cadr(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12405,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:962: match1 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_12243(t4,t3,((C_word*)t0)[3],C_i_cadr(t2));}
else{
t3=C_i_caddr(t2);
t4=C_i_not(t3);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12435,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
if(C_truep(t4)){
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=t4;
f_12435(2,av2);}}
else{
/* scrutinizer.scm:966: rawmatch1 */
t6=((C_word*)((C_word*)t0)[2])[1];
f_12185(t6,t5,((C_word*)t0)[3],C_i_caddr(t2));}}}

/* k12403 in g2176 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12405(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12405,c,av);}
if(C_truep(t1)){
t2=C_i_caddr(((C_word*)t0)[2]);
t3=C_i_not(t2);
if(C_truep(t3)){
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* scrutinizer.scm:964: rawmatch1 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_12185(t4,((C_word*)t0)[3],((C_word*)t0)[5],C_i_caddr(((C_word*)t0)[2]));}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k12433 in g2176 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12435(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_12435,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],lf[24]);
t3=C_mutate(&lf[24] /* (set! chicken.compiler.scrutinizer#trail ...) */,t2);
t4=C_i_cdr(((C_word*)t0)[3]);
t5=C_i_set_car(t4,((C_word*)t0)[4]);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12505(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_12505,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12509,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:934: g2204 */
t3=t2;
f_12509(t3,((C_word*)t0)[4],t1);}
else{
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12519,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_symbolp(((C_word*)t0)[3]))){
/* scrutinizer.scm:1275: chicken.base#alist-ref */
t3=*((C_word*)lf[276]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[374];
av2[4]=*((C_word*)lf[375]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_12519(2,av2);}}}}

/* g2204 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12509(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_12509,3,t0,t1,t2);}
/* scrutinizer.scm:978: g2212 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,t2,((C_word*)t0)[3]);}

/* k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12519(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,5)))){
C_save_and_reclaim((void *)f_12519,c,av);}
a=C_alloc(20);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12523,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:934: g2215 */
t3=t2;
f_12523(t3,((C_word*)t0)[4],t1);}
else{
t2=C_i_pairp(((C_word*)t0)[3]);
t3=(C_truep(t2)?C_eqp(lf[70],C_u_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_i_not(((C_word*)((C_word*)t0)[5])[1]);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_FALSE;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12544,a[2]=t8,a[3]=((C_word*)t0)[5],a[4]=t6,tmp=(C_word)a,a+=5,tmp);
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12549,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12565,a[2]=t6,a[3]=((C_word*)t0)[5],a[4]=t8,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:981: ##sys#dynamic-wind */
t12=*((C_word*)lf[225]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t12;
av2[1]=((C_word*)t0)[4];
av2[2]=t9;
av2[3]=t10;
av2[4]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(5,av2);}}
else{
t4=C_i_pairp(((C_word*)t0)[7]);
t5=(C_truep(t4)?C_eqp(lf[70],C_u_i_car(((C_word*)t0)[7])):C_SCHEME_FALSE);
if(C_truep(t5)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[5])[1]))){
t6=C_SCHEME_TRUE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_FALSE;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12585,a[2]=t9,a[3]=((C_word*)t0)[5],a[4]=t7,tmp=(C_word)a,a+=5,tmp);
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12590,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12606,a[2]=t7,a[3]=((C_word*)t0)[5],a[4]=t9,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:988: ##sys#dynamic-wind */
t13=*((C_word*)lf[225]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t13;
av2[1]=((C_word*)t0)[4];
av2[2]=t10;
av2[3]=t11;
av2[4]=t12;
((C_proc)(void*)(*((C_word*)t13+1)))(5,av2);}}
else{
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t6=C_i_pairp(((C_word*)t0)[7]);
t7=(C_truep(t6)?C_eqp(lf[28],C_u_i_car(((C_word*)t0)[7])):C_SCHEME_FALSE);
if(C_truep(t7)){
t8=C_i_cdr(((C_word*)t0)[7]);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12624,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:996: over-all-instantiations */
f_20424(((C_word*)t0)[4],t8,((C_word*)t0)[6],((C_word*)((C_word*)t0)[5])[1],t9);}
else{
t8=C_i_pairp(((C_word*)t0)[3]);
t9=(C_truep(t8)?C_eqp(lf[28],C_u_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
if(C_truep(t9)){
t10=C_i_cdr(((C_word*)t0)[3]);
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12643,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1003: over-all-instantiations */
f_20424(((C_word*)t0)[4],t10,((C_word*)t0)[6],C_SCHEME_FALSE,t11);}
else{
t10=C_i_pairp(((C_word*)t0)[3]);
t11=(C_truep(t10)?C_eqp(lf[29],C_u_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
if(C_truep(t11)){
/* scrutinizer.scm:1009: match1 */
t12=((C_word*)((C_word*)t0)[2])[1];
f_12243(t12,((C_word*)t0)[4],C_i_caddr(((C_word*)t0)[3]),((C_word*)t0)[7]);}
else{
t12=C_i_pairp(((C_word*)t0)[7]);
t13=(C_truep(t12)?C_eqp(lf[29],C_u_i_car(((C_word*)t0)[7])):C_SCHEME_FALSE);
if(C_truep(t13)){
/* scrutinizer.scm:1011: match1 */
t14=((C_word*)((C_word*)t0)[2])[1];
f_12243(t14,((C_word*)t0)[4],((C_word*)t0)[3],C_i_caddr(((C_word*)t0)[7]));}
else{
t14=C_eqp(lf[85],((C_word*)t0)[3]);
if(C_truep(t14)){
t15=C_i_pairp(((C_word*)t0)[7]);
t16=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t16;
av2[1]=(C_truep(t15)?C_eqp(lf[85],C_u_i_car(((C_word*)t0)[7])):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}
else{
t15=C_eqp(lf[85],((C_word*)t0)[7]);
if(C_truep(t15)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[5])[1]))){
t16=C_i_pairp(((C_word*)t0)[3]);
t17=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t17;
av2[1]=(C_truep(t16)?C_eqp(lf[85],C_u_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}
else{
t16=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t16;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}}
else{
t16=C_eqp(((C_word*)t0)[3],lf[32]);
if(C_truep(t16)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[5])[1]))){
t17=C_i_pairp(((C_word*)t0)[7]);
t18=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t18;
av2[1]=(C_truep(t17)?C_eqp(lf[362],C_u_i_car(((C_word*)t0)[7])):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}
else{
t17=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t17;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}}
else{
t17=C_eqp(((C_word*)t0)[7],lf[32]);
if(C_truep(t17)){
t18=C_i_pairp(((C_word*)t0)[3]);
t19=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t19;
av2[1]=(C_truep(t18)?C_eqp(lf[362],C_u_i_car(((C_word*)t0)[3])):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}
else{
t18=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12759,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[6],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t19=C_i_pairp(((C_word*)t0)[7]);
t20=t18;
f_12759(t20,(C_truep(t19)?C_eqp(C_u_i_car(((C_word*)t0)[3]),C_u_i_car(((C_word*)t0)[7])):C_SCHEME_FALSE));}
else{
t19=t18;
f_12759(t19,C_SCHEME_FALSE);}}}}}}}}}}}}}

/* g2215 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12523(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_12523,3,t0,t1,t2);}
/* scrutinizer.scm:979: g2223 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,((C_word*)t0)[3],t2);}

/* a12543 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12544(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12544,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a12548 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12549,c,av);}
a=C_alloc(5);
t2=lf[24];
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12553,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:983: match1 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_12243(t4,t3,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k12551 in a12548 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12553(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12553,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12556,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:984: trail-restore */
f_16307(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k12554 in k12551 in a12548 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12556(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12556,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_not(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a12564 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12565(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12565,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a12584 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12585(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12585,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a12589 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12590,c,av);}
a=C_alloc(5);
t2=lf[24];
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12594,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:990: match1 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_12243(t4,t3,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* k12592 in a12589 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12594,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12597,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:991: trail-restore */
f_16307(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k12595 in k12592 in a12589 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12597(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12597,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_not(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a12605 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12606,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a12623 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12624,c,av);}
/* scrutinizer.scm:1000: match1 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,((C_word*)t0)[3],t2);}

/* a12642 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12643,c,av);}
/* scrutinizer.scm:1007: match1 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,t2,((C_word*)t0)[3]);}

/* k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_12759(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,5)))){
C_save_and_reclaim_args((void *)trf_12759,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_eqp(t2,lf[85]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12771,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1025: procedure-arguments */
f_15287(t4,((C_word*)t0)[2]);}
else{
t4=C_eqp(t2,lf[53]);
if(C_truep(t4)){
t5=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t5;
av2[1]=C_i_equalp(((C_word*)t0)[2],((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_eqp(t2,lf[49]);
if(C_truep(t5)){
/* scrutinizer.scm:1032: every-match1 */
t6=((C_word*)((C_word*)t0)[7])[1];
f_12207(t6,((C_word*)t0)[4],C_u_i_cdr(((C_word*)t0)[2]),C_i_cdr(((C_word*)t0)[6]));}
else{
t6=C_eqp(t2,lf[362]);
t7=(C_truep(t6)?t6:C_eqp(t2,lf[360]));
if(C_truep(t7)){
/* scrutinizer.scm:1033: match1 */
t8=((C_word*)((C_word*)t0)[8])[1];
f_12243(t8,((C_word*)t0)[4],C_i_cadr(((C_word*)t0)[2]),C_i_cadr(((C_word*)t0)[6]));}
else{
t8=C_eqp(t2,lf[48]);
t9=(C_truep(t8)?t8:C_eqp(t2,lf[51]));
if(C_truep(t9)){
t10=C_i_length(((C_word*)t0)[2]);
t11=C_i_length(((C_word*)t0)[6]);
t12=C_eqp(t10,t11);
if(C_truep(t12)){
/* scrutinizer.scm:1036: every-match1 */
t13=((C_word*)((C_word*)t0)[7])[1];
f_12207(t13,((C_word*)t0)[4],C_i_cdr(((C_word*)t0)[2]),C_i_cdr(((C_word*)t0)[6]));}
else{
t13=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}}
else{
t10=C_eqp(t2,lf[373]);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12879,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1038: match1 */
t12=((C_word*)((C_word*)t0)[8])[1];
f_12243(t12,t11,C_i_caddr(((C_word*)t0)[2]),C_i_caddr(((C_word*)t0)[6]));}
else{
t11=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}}}}}
else{
t2=C_i_pairp(((C_word*)t0)[2]);
t3=(C_truep(t2)?C_eqp(lf[373],C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t3)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[9])[1]))){
/* scrutinizer.scm:1043: match1 */
t4=((C_word*)((C_word*)t0)[8])[1];
f_12243(t4,((C_word*)t0)[4],C_i_caddr(((C_word*)t0)[2]),((C_word*)t0)[6]);}
else{
t4=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=C_i_pairp(((C_word*)t0)[6]);
t5=(C_truep(t4)?C_eqp(lf[373],C_u_i_car(((C_word*)t0)[6])):C_SCHEME_FALSE);
if(C_truep(t5)){
/* scrutinizer.scm:1045: match1 */
t6=((C_word*)((C_word*)t0)[8])[1];
f_12243(t6,((C_word*)t0)[4],((C_word*)t0)[2],C_i_caddr(((C_word*)t0)[6]));}
else{
t6=C_i_pairp(((C_word*)t0)[2]);
t7=(C_truep(t6)?C_eqp(lf[49],C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t7)){
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
t8=C_u_i_car(((C_word*)t0)[6]);
t9=C_eqp(t8,lf[362]);
if(C_truep(t9)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[9])[1]))){
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12989,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1051: match1 */
t11=((C_word*)((C_word*)t0)[8])[1];
f_12243(t11,t10,C_i_cadr(((C_word*)t0)[2]),C_i_cadr(((C_word*)t0)[6]));}
else{
t10=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}
else{
t10=C_eqp(t8,lf[48]);
if(C_truep(t10)){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[6])))){
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13022,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1055: match1 */
t12=((C_word*)((C_word*)t0)[8])[1];
f_12243(t12,t11,C_i_cadr(((C_word*)t0)[2]),C_i_cadr(((C_word*)t0)[6]));}
else{
t11=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}
else{
t11=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}
else{
t8=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}
else{
t8=C_i_pairp(((C_word*)t0)[6]);
t9=(C_truep(t8)?C_eqp(lf[49],C_u_i_car(((C_word*)t0)[6])):C_SCHEME_FALSE);
if(C_truep(t9)){
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t10=C_u_i_car(((C_word*)t0)[2]);
t11=C_eqp(t10,lf[362]);
if(C_truep(t11)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[9])[1]))){
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13091,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1066: match1 */
t13=((C_word*)((C_word*)t0)[8])[1];
f_12243(t13,t12,C_i_cadr(((C_word*)t0)[2]),C_i_cadr(((C_word*)t0)[6]));}
else{
t12=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}
else{
t12=C_eqp(t10,lf[48]);
if(C_truep(t12)){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[2])))){
t13=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13124,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1070: match1 */
t14=((C_word*)((C_word*)t0)[8])[1];
f_12243(t14,t13,C_i_cadr(((C_word*)t0)[2]),C_i_cadr(((C_word*)t0)[6]));}
else{
t13=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}}
else{
t13=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}}}
else{
t10=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}
else{
t10=C_i_pairp(((C_word*)t0)[2]);
t11=(C_truep(t10)?C_eqp(lf[48],C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t11)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[9])[1]))){
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
t12=C_eqp(lf[362],C_u_i_car(((C_word*)t0)[6]));
if(C_truep(t12)){
t13=C_i_cdr(((C_word*)t0)[2]);
t14=C_i_cadr(((C_word*)t0)[6]);
t15=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13198,a[2]=((C_word*)t0)[8],a[3]=t14,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1079: over-all-instantiations */
f_20424(((C_word*)t0)[4],t13,((C_word*)t0)[10],C_SCHEME_TRUE,t15);}
else{
t13=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}}
else{
t12=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}
else{
t12=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}
else{
t12=C_i_pairp(((C_word*)t0)[2]);
t13=(C_truep(t12)?C_eqp(lf[362],C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t13)){
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
t14=C_eqp(lf[48],C_u_i_car(((C_word*)t0)[6]));
if(C_truep(t14)){
t15=C_u_i_cdr(((C_word*)t0)[6]);
t16=C_i_cadr(((C_word*)t0)[2]);
t17=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13232,a[2]=((C_word*)t0)[8],a[3]=t16,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1086: over-all-instantiations */
f_20424(((C_word*)t0)[4],t15,((C_word*)t0)[10],C_SCHEME_TRUE,t17);}
else{
t15=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t15;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}}
else{
t14=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t14;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}}
else{
t14=C_i_pairp(((C_word*)t0)[2]);
t15=(C_truep(t14)?C_eqp(lf[51],C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t15)){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[9])[1]))){
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
t16=C_eqp(lf[360],C_u_i_car(((C_word*)t0)[6]));
if(C_truep(t16)){
t17=C_i_cdr(((C_word*)t0)[2]);
t18=C_i_cadr(((C_word*)t0)[6]);
t19=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13274,a[2]=((C_word*)t0)[8],a[3]=t18,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1094: over-all-instantiations */
f_20424(((C_word*)t0)[4],t17,((C_word*)t0)[10],C_SCHEME_TRUE,t19);}
else{
t17=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t17;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}}
else{
t16=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t16;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}}
else{
t16=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t16;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}}
else{
t16=C_i_pairp(((C_word*)t0)[2]);
t17=(C_truep(t16)?C_eqp(lf[360],C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE);
if(C_truep(t17)){
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
t18=C_eqp(lf[51],C_u_i_car(((C_word*)t0)[6]));
if(C_truep(t18)){
t19=C_u_i_cdr(((C_word*)t0)[6]);
t20=C_i_cadr(((C_word*)t0)[2]);
t21=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13308,a[2]=((C_word*)t0)[8],a[3]=t20,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1101: over-all-instantiations */
f_20424(((C_word*)t0)[4],t19,((C_word*)t0)[10],C_SCHEME_TRUE,t21);}
else{
t19=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t19;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}}
else{
t18=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t18;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}}
else{
t18=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t18;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}}}}}}}}}}

/* k12769 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_12771,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12774,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1026: procedure-arguments */
f_15287(t2,((C_word*)t0)[5]);}

/* k12772 in k12769 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12774(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_12774,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12777,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1027: procedure-results */
f_15344(t2,((C_word*)t0)[7]);}

/* k12775 in k12772 in k12769 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12777(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_12777,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12780,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1028: procedure-results */
f_15344(t2,((C_word*)t0)[7]);}

/* k12778 in k12775 in k12772 in k12769 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_12780,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12786,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1029: match-args */
t3=((C_word*)((C_word*)t0)[5])[1];
f_11923(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k12784 in k12778 in k12775 in k12772 in k12769 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12786(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12786,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:1030: match-results */
t2=((C_word*)((C_word*)t0)[2])[1];
f_12117(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k12877 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12879(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_12879,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_i_not(((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(t2)){
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_cadr(((C_word*)t0)[4]);
t4=C_i_cadr(((C_word*)t0)[5]);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7865,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:193: every */
f_7187(((C_word*)t0)[3],t5,t3);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k12987 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_12989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12989,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:1052: match1 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_12243(t2,((C_word*)t0)[3],C_i_caddr(((C_word*)t0)[4]),((C_word*)t0)[5]);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k13020 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_13022,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_i_caddr(((C_word*)t0)[2]);
t3=C_i_cddr(((C_word*)t0)[3]);
if(C_truep(C_i_nullp(t3))){
/* scrutinizer.scm:1056: match1 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_12243(t4,((C_word*)t0)[5],t2,lf[32]);}
else{
t4=C_u_i_cdr(((C_word*)t0)[3]);
t5=C_u_i_cdr(t4);
t6=C_a_i_cons(&a,2,lf[48],t5);
/* scrutinizer.scm:1056: match1 */
t7=((C_word*)((C_word*)t0)[4])[1];
f_12243(t7,((C_word*)t0)[5],t2,t6);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k13089 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13091,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:1067: match1 */
t2=((C_word*)((C_word*)t0)[2])[1];
f_12243(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_i_caddr(((C_word*)t0)[5]));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k13122 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_13124,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_nullp(t2))){
/* scrutinizer.scm:1071: match1 */
t3=((C_word*)((C_word*)t0)[3])[1];
f_12243(t3,((C_word*)t0)[4],lf[32],C_i_caddr(((C_word*)t0)[5]));}
else{
t3=C_u_i_cdr(((C_word*)t0)[2]);
t4=C_u_i_cdr(t3);
t5=C_a_i_cons(&a,2,lf[48],t4);
/* scrutinizer.scm:1071: match1 */
t6=((C_word*)((C_word*)t0)[3])[1];
f_12243(t6,((C_word*)t0)[4],t5,C_i_caddr(((C_word*)t0)[5]));}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a13194 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13198(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13198,c,av);}
/* scrutinizer.scm:1083: g23302331 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,t2,((C_word*)t0)[3]);}

/* a13228 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13232(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13232,c,av);}
/* scrutinizer.scm:1090: g23452346 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,((C_word*)t0)[3],t2);}

/* a13270 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13274,c,av);}
/* scrutinizer.scm:1098: g23612362 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,t2,((C_word*)t0)[3]);}

/* a13304 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13308(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13308,c,av);}
/* scrutinizer.scm:1105: g23762377 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_12243(t3,t1,((C_word*)t0)[3],t2);}

/* chicken.compiler.scrutinizer#match-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_13496(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_13496,4,t1,t2,t3,t4);}
a=C_alloc(6);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13502,a[2]=t4,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_13502(t8,t1,t2,t3);}

/* loop in chicken.compiler.scrutinizer#match-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_13502(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_13502,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_i_nullp(t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_equalp(lf[376],t2);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_car(t2);
t6=C_eqp(t5,lf[366]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13535,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1122: every */
f_7187(t1,t7,t3);}
else{
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13549,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1126: match-types */
t8=*((C_word*)lf[171]+1);{
C_word av2[6];
av2[0]=t8;
av2[1]=t7;
av2[2]=C_u_i_car(t2);
av2[3]=C_i_car(t3);
av2[4]=((C_word*)t0)[2];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t8+1)))(6,av2);}}}}}}

/* a13534 in loop in chicken.compiler.scrutinizer#match-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_13535,c,av);}
/* scrutinizer.scm:1124: match-types */
t3=*((C_word*)lf[171]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
av2[3]=t2;
av2[4]=((C_word*)t0)[3];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k13547 in loop in chicken.compiler.scrutinizer#match-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13549,c,av);}
if(C_truep(t1)){
/* scrutinizer.scm:1127: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13502(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_13568(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,3)))){
C_save_and_reclaim_args((void *)trf_13568,2,t1,t2);}
a=C_alloc(21);
t3=C_SCHEME_END_OF_LIST;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_END_OF_LIST;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_END_OF_LIST;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13571,a[2]=t4,a[3]=t6,a[4]=t10,a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t12=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14468,a[2]=t8,a[3]=t1,a[4]=t6,a[5]=t10,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1257: simplify */
t13=((C_word*)t10)[1];
f_13571(t13,t12,t2);}

/* simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_13571(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_13571,3,t0,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13577,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1142: chicken.base#call/cc */
t4=*((C_word*)lf[168]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13577(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_13577,c,av);}
a=C_alloc(24);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t3=C_u_i_car(((C_word*)t0)[2]);
t4=C_eqp(t3,lf[29]);
if(C_truep(t4)){
t5=C_i_cadr(((C_word*)t0)[2]);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13598,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t1,a[6]=((C_word*)t0)[2],a[7]=t5,tmp=(C_word)a,a+=8,tmp);
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=C_i_check_list_2(t5,lf[6]);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13650,a[2]=t6,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13652,a[2]=t9,a[3]=t14,a[4]=t10,tmp=(C_word)a,a+=5,tmp));
t16=((C_word*)t14)[1];
f_13652(t16,t12,t5);}
else{
t5=C_eqp(t3,lf[28]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13693,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=C_u_i_cdr(((C_word*)t0)[2]);
t12=C_i_check_list_2(t11,lf[6]);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14001,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14003,a[2]=t9,a[3]=t15,a[4]=((C_word*)t0)[5],a[5]=t10,tmp=(C_word)a,a+=6,tmp));
t17=((C_word*)t15)[1];
f_14003(t17,t13,t11);}
else{
t6=C_eqp(t3,lf[373]);
if(C_truep(t6)){
t7=C_i_cadr(((C_word*)t0)[2]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14047,a[2]=t7,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1212: simplify */
t9=((C_word*)((C_word*)t0)[5])[1];
f_13571(t9,t8,C_i_caddr(((C_word*)t0)[2]));}
else{
t7=C_eqp(t3,lf[49]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14094,a[2]=t1,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1219: simplify */
t9=((C_word*)((C_word*)t0)[5])[1];
f_13571(t9,t8,C_i_cadr(((C_word*)t0)[2]));}
else{
t8=C_eqp(t3,lf[360]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14133,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1226: simplify */
t10=((C_word*)((C_word*)t0)[5])[1];
f_13571(t10,t9,C_i_cadr(((C_word*)t0)[2]));}
else{
t9=C_eqp(t3,lf[362]);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14157,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1231: simplify */
t11=((C_word*)((C_word*)t0)[5])[1];
f_13571(t11,t10,C_i_cadr(((C_word*)t0)[2]));}
else{
t10=C_eqp(t3,lf[48]);
if(C_truep(t10)){
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[2])))){
t11=t1;{
C_word *av2=av;
av2[0]=t11;
av2[1]=lf[32];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t11=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t12=t11;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=((C_word*)t13)[1];
t15=C_u_i_cdr(((C_word*)t0)[2]);
t16=C_i_check_list_2(t15,lf[6]);
t17=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14198,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t18=C_SCHEME_UNDEFINED;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_set_block_item(t19,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14200,a[2]=t13,a[3]=t19,a[4]=((C_word*)t0)[5],a[5]=t14,tmp=(C_word)a,a+=6,tmp));
t21=((C_word*)t19)[1];
f_14200(t21,t17,t15);}}
else{
t11=C_eqp(t3,lf[51]);
if(C_truep(t11)){
t12=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t13=t12;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=((C_word*)t14)[1];
t16=C_u_i_cdr(((C_word*)t0)[2]);
t17=C_i_check_list_2(t16,lf[6]);
t18=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14254,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t19=C_SCHEME_UNDEFINED;
t20=(*a=C_VECTOR_TYPE|1,a[1]=t19,tmp=(C_word)a,a+=2,tmp);
t21=C_set_block_item(t20,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14256,a[2]=t14,a[3]=t20,a[4]=((C_word*)t0)[5],a[5]=t15,tmp=(C_word)a,a+=6,tmp));
t22=((C_word*)t20)[1];
f_14256(t22,t18,t16);}
else{
t12=C_eqp(t3,lf[85]);
if(C_truep(t12)){
t13=(
/* scrutinizer.scm:1242: named? */
  f_15752(((C_word*)t0)[2])
);
t14=(C_truep(t13)?C_i_cadr(((C_word*)t0)[2]):C_SCHEME_FALSE);
t15=(C_truep(t14)?C_i_cdddr(((C_word*)t0)[2]):C_i_cddr(((C_word*)t0)[2]));
t16=(C_truep(t14)?C_a_i_list1(&a,1,t14):C_SCHEME_END_OF_LIST);
t17=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t18=t17;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=((C_word*)t19)[1];
t21=(C_truep(t14)?C_i_caddr(((C_word*)t0)[2]):C_i_cadr(((C_word*)t0)[2]));
t22=C_i_check_list_2(t21,lf[6]);
t23=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14374,a[2]=t1,a[3]=t16,a[4]=t15,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t24=C_SCHEME_UNDEFINED;
t25=(*a=C_VECTOR_TYPE|1,a[1]=t24,tmp=(C_word)a,a+=2,tmp);
t26=C_set_block_item(t25,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14376,a[2]=t19,a[3]=t25,a[4]=((C_word*)t0)[5],a[5]=t20,tmp=(C_word)a,a+=6,tmp));
t27=((C_word*)t25)[1];
f_14376(t27,t23,t21);}
else{
t13=t1;{
C_word *av2=av;
av2[0]=t13;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}}}}}}}}}}
else{
t3=C_i_assq(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14454,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1144: g2702 */
t5=t4;
f_14454(t5,t1,t3);}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* k13596 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13598(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_13598,c,av);}
a=C_alloc(12);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13602,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13613,a[2]=t3,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13615,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:1155: filter-map */
f_7471(t4,t5,((C_word*)t0)[7]);}

/* k13600 in k13596 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13602,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
/* scrutinizer.scm:1160: simplify */
t3=((C_word*)((C_word*)t0)[3])[1];
f_13571(t3,((C_word*)t0)[4],C_i_caddr(((C_word*)t0)[5]));}

/* k13611 in k13596 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13613,c,av);}
/* scrutinizer.scm:1155: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a13614 in k13596 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13615(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13615,c,av);}
t3=C_i_pairp(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?t2:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k13648 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13650(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13650,c,av);}
/* scrutinizer.scm:1149: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop2435 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_13652(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_13652,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_symbolp(t3);
t5=(C_truep(t4)?t3:C_i_car(t3));
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15967,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1523: chicken.plist#get */
t7=*((C_word*)lf[378]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=t5;
av2[3]=lf[377];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13693,c,av);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_i_cdr(t1);
if(C_truep(C_i_nullp(t2))){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_car(t1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_length(t1);
if(C_truep(C_fixnum_greaterp(t3,C_fix(20)))){
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13721,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1168: every */
f_7187(t4,lf[122],t1);}}}}

/* k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13721,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13727,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13814,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:1169: any */
f_7221(t2,t3,((C_word*)t0)[3]);}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13824,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1186: lset=/eq? */
f_7871(t2,lf[386],((C_word*)t0)[3]);}}

/* k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13727(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_13727,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[85];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_i_car(((C_word*)t0)[3]);
t3=C_u_i_cdr(((C_word*)t0)[3]);
t4=C_i_check_list_2(t3,lf[379]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13739,a[2]=t6,tmp=(C_word)a,a+=3,tmp));
t8=((C_word*)t6)[1];
f_13739(t8,((C_word*)t0)[2],t3,t2);}}

/* foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_13739(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_13739,4,t0,t1,t2,t3);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13808,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=C_slot(t2,C_fix(0));
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13759,a[2]=t5,a[3]=t3,a[4]=t6,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1173: procedure-name */
f_15236(t7,t6);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_13759,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13762,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1174: procedure-arguments */
f_15287(t2,((C_word*)t0)[4]);}

/* k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_13762,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13765,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1175: procedure-results */
f_15344(t2,((C_word*)t0)[5]);}

/* k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13765(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_13765,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13768,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1176: procedure-name */
f_15236(t2,((C_word*)t0)[5]);}

/* k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13768,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13771,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1177: procedure-arguments */
f_15287(t2,((C_word*)t0)[6]);}

/* k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13771,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13774,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1178: procedure-results */
f_15344(t2,((C_word*)t0)[7]);}

/* k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_13774(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_13774,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13781,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[6])){
if(C_truep(((C_word*)t0)[7])){
t3=C_eqp(((C_word*)t0)[6],((C_word*)t0)[7]);
t4=t2;
f_13781(t4,(C_truep(t3)?C_a_i_list1(&a,1,((C_word*)t0)[6]):C_SCHEME_END_OF_LIST));}
else{
t3=t2;
f_13781(t3,C_SCHEME_END_OF_LIST);}}
else{
t3=t2;
f_13781(t3,C_SCHEME_END_OF_LIST);}}

/* k13779 in k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_fcall f_13781(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_13781,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13793,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1182: merge-argument-types */
f_14537(t2,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k13787 in k13791 in k13779 in k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_13789(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_13789,c,av);}
/* scrutinizer.scm:1179: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[380];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k13791 in k13779 in k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_13793(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_13793,c,av);}
a=C_alloc(12);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13789,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14712,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1306: chicken.base#call/cc */
t5=*((C_word*)lf[168]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k13806 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13808,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_13739(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* a13813 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13814,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_eqp(lf[85],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13824(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13824,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[35];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13830,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1187: lset=/eq? */
f_7871(t2,lf[385],((C_word*)t0)[6]);}}

/* k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13830(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13830,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[41];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13836,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1188: lset=/eq? */
f_7871(t2,lf[384],((C_word*)t0)[6]);}}

/* k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13836(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_13836,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[382];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13839,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13939,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1190: append-map */
f_7017(t2,t3,((C_word*)t0)[6],C_SCHEME_END_OF_LIST);}}

/* k13837 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13839(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_13839,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13842,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13859,a[2]=((C_word*)t0)[5],a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_13859(t6,t2,t1,C_SCHEME_END_OF_LIST);}

/* k13840 in k13837 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_13842,c,av);}
a=C_alloc(3);
if(C_truep(C_i_equalp(t1,C_u_i_cdr(((C_word*)t0)[2])))){
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_a_i_cons(&a,2,lf[28],t1);
/* scrutinizer.scm:1209: simplify */
t3=((C_word*)((C_word*)t0)[4])[1];
f_13571(t3,((C_word*)t0)[3],t2);}}

/* loop in k13837 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_13859(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_13859,4,t0,t1,t2,t3);}
a=C_alloc(9);
if(C_truep(C_i_nullp(t2))){
/* scrutinizer.scm:1200: scheme#reverse */
t4=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=C_i_car(t2);
t5=C_eqp(lf[54],t4);
if(C_truep(t5)){
/* scrutinizer.scm:1201: return */
t6=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[54];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13884,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13923,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1202: any */
f_7221(t6,t7,C_u_i_cdr(t2));}}}

/* k13882 in loop in k13837 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13884(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_13884,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
/* scrutinizer.scm:1203: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13859(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),((C_word*)t0)[5]);}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13895,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13913,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1204: any */
f_7221(t2,t3,((C_word*)t0)[5]);}}

/* k13893 in k13882 in loop in k13837 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_13895,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
/* scrutinizer.scm:1205: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13859(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),((C_word*)t0)[5]);}
else{
t2=C_u_i_cdr(((C_word*)t0)[4]);
t3=C_u_i_car(((C_word*)t0)[4]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[5]);
/* scrutinizer.scm:1206: loop */
t5=((C_word*)((C_word*)t0)[2])[1];
f_13859(t5,((C_word*)t0)[3],t2,t4);}}

/* a13912 in k13882 in loop in k13837 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13913,c,av);}
t3=*((C_word*)lf[383]+1);
/* scrutinizer.scm:1204: g2562 */
t4=*((C_word*)lf[383]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=C_i_car(((C_word*)t0)[2]);
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* a13922 in loop in k13837 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13923,c,av);}
t3=*((C_word*)lf[383]+1);
/* scrutinizer.scm:1202: g2554 */
t4=*((C_word*)lf[383]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=C_i_car(((C_word*)t0)[2]);
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* a13938 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13939(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13939,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13943,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1192: simplify */
t4=((C_word*)((C_word*)t0)[3])[1];
f_13571(t4,t3,t2);}

/* k13941 in a13938 in k13834 in k13828 in k13822 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_13943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_13943,c,av);}
a=C_alloc(3);
t2=C_i_pairp(t1);
t3=(C_truep(t2)?C_eqp(lf[28],C_u_i_car(t1)):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cdr(t1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_eqp(t1,lf[36]);
if(C_truep(t4)){
/* scrutinizer.scm:1195: return */
t5=((C_word*)t0)[3];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[36];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t5=C_eqp(t1,lf[71]);
if(C_truep(t5)){
/* scrutinizer.scm:1196: return */
t6=((C_word*)t0)[3];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[54];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_list1(&a,1,t1);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}

/* k13999 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14001,c,av);}
/* scrutinizer.scm:1162: delete-duplicates */
f_7382(((C_word*)t0)[2],t1,*((C_word*)lf[375]+1));}

/* map-loop2468 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14003(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_14003,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14028,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1162: g2474 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_13571(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k14026 in map-loop2468 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14028(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_14028,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_14003(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_14047,c,av);}
a=C_alloc(12);
if(C_truep(C_i_nullp(((C_word*)t0)[2]))){
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(
/* scrutinizer.scm:1214: refinement-type? */
  f_15928(t1)
);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14066,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_i_cadr(t1);
t5=C_a_i_list(&a,1,((C_word*)t0)[2]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7738,a[2]=t7,tmp=(C_word)a,a+=3,tmp));
t9=((C_word*)t7)[1];
f_7738(t9,t3,t5,t4);}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14081,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1217: delete-duplicates */
f_7382(t3,((C_word*)t0)[2],*((C_word*)lf[375]+1));}}}

/* k14064 in k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14066(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14066,c,av);}
a=C_alloc(9);
t2=C_i_caddr(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list3(&a,3,lf[373],t1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14079 in k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14081(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14081,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list3(&a,3,lf[373],t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k14092 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14094(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14094,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14097,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1220: simplify */
t3=((C_word*)((C_word*)t0)[3])[1];
f_13571(t3,t2,C_i_caddr(((C_word*)t0)[4]));}

/* k14095 in k14092 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14097(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_14097,c,av);}
a=C_alloc(9);
t2=C_eqp(lf[54],((C_word*)t0)[2]);
t3=(C_truep(t2)?C_eqp(lf[54],t1):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[49];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_a_i_list(&a,3,lf[49],((C_word*)t0)[2],t1);
/* scrutinizer.scm:1223: canonicalize-list-type */
f_19537(((C_word*)t0)[3],t4);}}

/* k14131 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_14133,c,av);}
a=C_alloc(6);
t2=C_eqp(t1,lf[54]);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[51];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_u_i_car(((C_word*)t0)[3]);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list(&a,2,t3,t1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14155 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_14157,c,av);}
a=C_alloc(6);
t2=C_eqp(t1,lf[54]);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[48];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_u_i_car(((C_word*)t0)[3]);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list(&a,2,t3,t1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14196 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14198(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_14198,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[48],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop2593 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14200(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_14200,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14225,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1238: g2599 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_13571(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k14223 in map-loop2593 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_14225,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_14200(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k14252 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14254(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_14254,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[51],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop2622 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14256(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_14256,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14281,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1240: g2628 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_13571(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k14279 in map-loop2622 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14281(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_14281,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_14256(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k14313 in k14372 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_14315,c,av);}
/* scrutinizer.scm:1244: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[390];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* map-loop2677 in k14372 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14329(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_14329,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14354,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1250: g2683 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_13571(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k14352 in map-loop2677 in k14372 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_14354,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_14329(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k14372 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,5)))){
C_save_and_reclaim((void *)f_14374,c,av);}
a=C_alloc(21);
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14315,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_eqp(lf[54],((C_word*)t0)[4]);
if(C_truep(t4)){
/* scrutinizer.scm:1244: scheme#append */
t5=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[390];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
av2[5]=lf[54];
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}
else{
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=C_i_check_list_2(((C_word*)t0)[4],lf[6]);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14329,a[2]=t7,a[3]=t11,a[4]=((C_word*)t0)[5],a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_14329(t13,t3,((C_word*)t0)[4]);}}

/* map-loop2651 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14376(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_14376,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14401,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1247: g2657 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_13571(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k14399 in map-loop2651 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_14401,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_14376(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* g2702 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14454(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,4)))){
C_save_and_reclaim_args((void *)trf_14454,3,t0,t1,t2);}
a=C_alloc(13);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14459,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=((C_word*)((C_word*)t0)[2])[1];
t5=C_a_i_list(&a,1,((C_word*)t0)[3]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7652,a[2]=t7,tmp=(C_word)a,a+=3,tmp));
t9=((C_word*)t7)[1];
f_7652(t9,t3,t5,t4);}

/* k14457 in g2702 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14459,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14466 in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_14468,c,av);}
a=C_alloc(11);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[2])[1]))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14485,a[2]=t3,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14487,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1260: filter-map */
f_7471(t4,t5,((C_word*)((C_word*)t0)[6])[1]);}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t3)[1];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14483 in k14466 in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14485,c,av);}
a=C_alloc(9);
t2=C_a_i_list(&a,3,lf[29],t1,((C_word*)((C_word*)t0)[2])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a14486 in k14466 in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_14487,c,av);}
a=C_alloc(4);
t3=C_i_car(t2);
if(C_truep(C_i_memq(t3,((C_word*)((C_word*)t0)[2])[1]))){
t4=C_u_i_cdr(t2);
t5=C_i_assq(C_u_i_car(t2),((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14502,a[2]=t4,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1264: g2720 */
t7=t6;
f_14502(t7,t1,t5);}
else{
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* g2720 in a14486 in k14466 in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14502(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_14502,3,t0,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14510,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1266: simplify */
t4=((C_word*)((C_word*)t0)[3])[1];
f_13571(t4,t3,C_i_cadr(t2));}

/* k14508 in g2720 in a14486 in k14466 in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14510(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_14510,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list2(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#merge-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14537(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(14,0,3)))){
C_save_and_reclaim_args((void *)trf_14537,3,t1,t2,t3);}
a=C_alloc(14);
if(C_truep(C_i_nullp(t2))){
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep((C_truep(C_eqp(t4,lf[366]))?C_SCHEME_TRUE:(C_truep(C_eqp(t4,lf[365]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))?t3:lf[391]);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=lf[392];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=C_eqp(lf[366],t4);
if(C_truep(t5)){
t6=C_i_pairp(t3);
t7=(C_truep(t6)?C_eqp(lf[366],C_u_i_car(t3)):C_SCHEME_FALSE);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14583,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t9=(
/* scrutinizer.scm:1291: rest-type */
  f_15805(C_u_i_cdr(t2))
);
t10=(
/* scrutinizer.scm:1292: rest-type */
  f_15805(C_i_cdr(t3))
);
t11=C_a_i_list(&a,3,lf[28],t9,t10);
/* scrutinizer.scm:1290: simplify-type */
f_13568(t8,t11);}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=lf[393];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}
else{
t6=C_eqp(lf[365],C_u_i_car(t2));
if(C_truep(t6)){
t7=C_i_pairp(t3);
t8=(C_truep(t7)?C_eqp(lf[365],C_u_i_car(t3)):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14632,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t10=C_i_cadr(t2);
t11=C_i_cadr(t3);
t12=C_a_i_list(&a,3,lf[28],t10,t11);
/* scrutinizer.scm:1297: simplify-type */
f_13568(t9,t12);}
else{
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=lf[394];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t7=C_i_car(t3);
if(C_truep((C_truep(C_eqp(t7,lf[366]))?C_SCHEME_TRUE:(C_truep(C_eqp(t7,lf[365]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
/* scrutinizer.scm:1301: merge-argument-types */
t14=t1;
t15=t3;
t16=t2;
t1=t14;
t2=t15;
t3=t16;
goto loop;}
else{
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14682,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t9=C_u_i_car(t2);
t10=C_u_i_car(t3);
t11=C_a_i_list(&a,3,lf[28],t9,t10);
/* scrutinizer.scm:1302: simplify-type */
f_13568(t8,t11);}}}}}}

/* k14581 in chicken.compiler.scrutinizer#merge-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14583(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_14583,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,2,lf[366],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k14630 in chicken.compiler.scrutinizer#merge-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_14632,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14636,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1298: merge-argument-types */
f_14537(t2,C_i_cddr(((C_word*)t0)[3]),C_i_cddr(((C_word*)t0)[4]));}

/* k14634 in k14630 in chicken.compiler.scrutinizer#merge-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_14636,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[365],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14680 in chicken.compiler.scrutinizer#merge-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_14682,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14686,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1303: merge-argument-types */
f_14537(t2,C_u_i_cdr(((C_word*)t0)[3]),C_u_i_cdr(((C_word*)t0)[4]));}

/* k14684 in k14680 in chicken.compiler.scrutinizer#merge-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_14686,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a14711 in k13791 in k13779 in k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_14712(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_14712,c,av);}
a=C_alloc(6);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14718,a[2]=t2,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_14718(t6,t1,((C_word*)t0)[2],((C_word*)t0)[3]);}

/* loop in a14711 in k13791 in k13779 in k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_14718(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,2)))){
C_save_and_reclaim_args((void *)trf_14718,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=C_i_nullp(t2);
t5=(C_truep(t4)?C_i_nullp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_i_not_pair_p(t2);
t7=(C_truep(t6)?t6:C_i_not_pair_p(t3));
if(C_truep(t7)){
/* scrutinizer.scm:1310: return */
t8=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t8;
av2[1]=t1;
av2[2]=lf[54];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14744,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t9=C_i_car(t2);
t10=C_i_car(t3);
t11=C_a_i_list(&a,3,lf[28],t9,t10);
/* scrutinizer.scm:1311: simplify-type */
f_13568(t8,t11);}}}

/* k14742 in loop in a14711 in k13791 in k13779 in k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_14744(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_14744,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14748,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1312: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_14718(t3,t2,C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}

/* k14746 in k14742 in loop in a14711 in k13791 in k13779 in k13772 in k13769 in k13766 in k13763 in k13760 in k13757 in foldl2511 in k13725 in k13719 in k13691 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in ... */
static void C_ccall f_14748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_14748,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#compatible-types? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14775(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_14775,4,t1,t2,t3,t4);}
a=C_alloc(14);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14779,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_nullp(t4))){
t6=C_a_i_list(&a,3,lf[28],t2,t3);
/* scrutinizer.scm:1315: type-typeenv */
t7=lf[162];{
C_word av2[3];
av2[0]=t7;
av2[1]=t5;
av2[2]=t6;
f_15975(3,av2);}}
else{
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_i_car(t4);
f_14779(2,av2);}}}

/* k14777 in chicken.compiler.scrutinizer#compatible-types? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14779(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_14779,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14782,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1316: type<=? */
t3=*((C_word*)lf[383]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k14780 in k14777 in chicken.compiler.scrutinizer#compatible-types? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_14782,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* scrutinizer.scm:1317: type<=? */
t2=*((C_word*)lf[383]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k14805 in k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_14807,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14813,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1320: type<=? */
t3=*((C_word*)lf[383]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k14811 in k14805 in k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_14813,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14819,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1321: type<=? */
t3=*((C_word*)lf[383]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k14817 in k14811 in k14805 in k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14819,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?((C_word*)t0)[3]:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#type<=? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14834(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_14834,c,av);}
a=C_alloc(14);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14838,a[2]=t3,a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_rest_nullp(c,4))){
t5=C_a_i_list(&a,3,lf[28],t2,t3);
/* scrutinizer.scm:1324: type-typeenv */
t6=lf[162];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
f_15975(3,av2);}}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_get_rest_arg(c,4,av,4,t0);
f_14838(2,av2);}}}

/* k14836 in chicken.compiler.scrutinizer#type<=? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14838(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_14838,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14843,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=lf[24];
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16345,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1565: thunk */
t5=t2;
f_14843(t5,t4);}

/* a14842 in k14836 in chicken.compiler.scrutinizer#type<=? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14843(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_14843,2,t0,t1);}
/* scrutinizer.scm:1328: match-types */
t2=*((C_word*)lf[171]+1);{
C_word av2[6];
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_14862,c,av);}
a=C_alloc(14);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15163,a[2]=t3,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=C_a_i_list(&a,3,lf[28],t2,t3);
/* scrutinizer.scm:1367: type-typeenv */
t6=lf[162];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
f_15975(3,av2);}}

/* loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14871(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_14871,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14875,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t1,a[5]=t2,a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_symbolp(t2))){
/* scrutinizer.scm:1275: chicken.base#alist-ref */
t5=*((C_word*)lf[276]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[374];
av2[4]=*((C_word*)lf[375]+1);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_14875(2,av2);}}}

/* k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14875(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_14875,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14879,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1340: g2855 */
t3=t2;
f_14879(t3,((C_word*)t0)[4],t1);}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14889,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_symbolp(((C_word*)t0)[3]))){
/* scrutinizer.scm:1275: chicken.base#alist-ref */
t3=*((C_word*)lf[276]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[374];
av2[4]=*((C_word*)lf[375]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_14889(2,av2);}}}}

/* g2855 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14879(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_14879,3,t0,t1,t2);}
/* scrutinizer.scm:1341: g2863 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_14871(t3,t1,t2,((C_word*)t0)[3]);}

/* k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_14889,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14893,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1340: g2866 */
t3=t2;
f_14893(t3,((C_word*)t0)[4],t1);}
else{
t2=C_i_pairp(((C_word*)t0)[3]);
t3=(C_truep(t2)?C_u_i_memq(C_u_i_car(((C_word*)t0)[3]),lf[395]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14909,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1344: loop */
t5=((C_word*)((C_word*)t0)[2])[1];
f_14871(t5,t4,C_i_caddr(((C_word*)t0)[3]),((C_word*)t0)[5]);}
else{
t4=C_i_pairp(((C_word*)t0)[5]);
t5=(C_truep(t4)?C_u_i_memq(C_u_i_car(((C_word*)t0)[5]),lf[396]):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14936,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1347: loop */
t7=((C_word*)((C_word*)t0)[2])[1];
f_14871(t7,t6,((C_word*)t0)[3],C_i_caddr(((C_word*)t0)[5]));}
else{
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14960,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t7=C_eqp(C_u_i_car(((C_word*)t0)[3]),lf[28]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15133,a[2]=((C_word*)t0)[5],a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1351: lset=/eq? */
f_7871(t8,lf[398],C_u_i_cdr(((C_word*)t0)[3]));}
else{
t8=t6;
f_14960(t8,C_SCHEME_FALSE);}}
else{
t7=t6;
f_14960(t7,C_SCHEME_FALSE);}}}}}

/* g2866 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14893(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_14893,3,t0,t1,t2);}
/* scrutinizer.scm:1342: g2874 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_14871(t3,t1,((C_word*)t0)[3],t2);}

/* k14907 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14909(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14909,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_cadr(((C_word*)t0)[2]);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list3(&a,3,t2,t3,t1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k14934 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14936(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_14936,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_cadr(((C_word*)t0)[2]);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list3(&a,3,t2,t3,t1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14960(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_14960,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_i_pairp(((C_word*)t0)[4]);
t3=(C_truep(t2)?C_eqp(C_u_i_car(((C_word*)t0)[4]),lf[28]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14969,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14980,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1355: filter-map */
f_7471(t4,t5,C_i_cdr(((C_word*)t0)[4]));}
else{
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14994,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[4]))){
t5=C_u_i_car(((C_word*)t0)[4]);
if(C_truep((C_truep(C_eqp(t5,lf[49]))?C_SCHEME_TRUE:(C_truep(C_eqp(t5,lf[48]))?C_SCHEME_TRUE:(C_truep(C_eqp(t5,lf[51]))?C_SCHEME_TRUE:(C_truep(C_eqp(t5,lf[360]))?C_SCHEME_TRUE:(C_truep(C_eqp(t5,lf[362]))?C_SCHEME_TRUE:C_SCHEME_FALSE))))))){
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t6=C_eqp(C_u_i_car(((C_word*)t0)[4]),C_u_i_car(((C_word*)t0)[3]));
t7=t4;
f_14994(t7,(C_truep(t6)?C_eqp(C_i_length(((C_word*)t0)[4]),C_i_length(((C_word*)t0)[3])):C_SCHEME_FALSE));}
else{
t6=t4;
f_14994(t6,C_SCHEME_FALSE);}}
else{
t6=t4;
f_14994(t6,C_SCHEME_FALSE);}}
else{
t5=t4;
f_14994(t5,C_SCHEME_FALSE);}}}}

/* k14967 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_14969,c,av);}
a=C_alloc(3);
t2=C_i_pairp(t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?C_a_i_cons(&a,2,lf[28],t1):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a14979 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_14980(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14980,c,av);}
/* scrutinizer.scm:1355: loop */
t3=((C_word*)((C_word*)t0)[2])[1];
f_14871(t3,t1,t2,((C_word*)t0)[3]);}

/* k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_14994(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,0,4)))){
C_save_and_reclaim_args((void *)trf_14994,2,t0,t1);}
a=C_alloc(17);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_cdr(((C_word*)t0)[2]);
t7=C_i_cdr(((C_word*)t0)[3]);
t8=C_i_check_list_2(t6,lf[6]);
t9=C_i_check_list_2(t7,lf[6]);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15012,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15025,a[2]=t4,a[3]=t12,a[4]=((C_word*)t0)[5],a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_15025(t14,t10,t6,t7);}
else{
t2=C_a_i_list(&a,1,((C_word*)t0)[6]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14807,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_nullp(t2))){
t4=C_a_i_list(&a,3,lf[28],((C_word*)t0)[2],((C_word*)t0)[3]);
/* scrutinizer.scm:1319: type-typeenv */
t5=lf[162];{
C_word av2[3];
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
f_15975(3,av2);}}
else{
t4=t3;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_i_car(t2);
f_14807(2,av2);}}}}

/* k15010 in k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15012,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15018,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1363: every */
f_7187(t2,*((C_word*)lf[397]+1),t1);}

/* k15016 in k15010 in k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15018(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15018,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_u_i_car(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* map-loop2897 in k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15025(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_15025,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15054,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1362: g2903 */
t7=((C_word*)((C_word*)t0)[4])[1];
f_14871(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k15052 in map-loop2897 in k14992 in k14958 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15054(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_15054,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15025(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)),C_slot(((C_word*)t0)[6],C_fix(1)));}

/* k15131 in k14887 in k14873 in loop in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15133,c,av);}
if(C_truep(t1)){
t2=C_i_pairp(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];
f_14960(t3,(C_truep(t2)?C_eqp(lf[362],C_u_i_car(((C_word*)t0)[2])):C_SCHEME_FALSE));}
else{
t2=((C_word*)t0)[3];
f_14960(t2,C_SCHEME_FALSE);}}

/* k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15163(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_15163,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15166,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14871,a[2]=t4,a[3]=t1,tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_14871(t6,t2,((C_word*)t0)[4],((C_word*)t0)[2]);}

/* k15164 in k15161 in chicken.compiler.scrutinizer#refine-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15166(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15166,c,av);}
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* scrutinizer.scm:1371: simplify-type */
f_13568(((C_word*)t0)[3],t2);}}

/* chicken.compiler.scrutinizer#procedure-type? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15184(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
av[0]=t0;
av[1]=t1;
av[2]=t2;
C_save_and_reclaim((void *)f_15184,c,av);}
t3=C_eqp(lf[85],t2);
if(C_truep(t3)){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t2))){
t4=C_u_i_car(t2);
t5=C_eqp(t4,lf[29]);
if(C_truep(t5)){
/* scrutinizer.scm:1379: procedure-type? */
t9=t1;
t10=C_i_caddr(t2);
t1=t9;
t2=t10;
c=3;
goto loop;}
else{
t6=C_eqp(t4,lf[85]);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(t4,lf[28]);
if(C_truep(t7)){
/* scrutinizer.scm:1381: every */
f_7187(t1,lf[122],C_u_i_cdr(t2));}
else{
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* chicken.compiler.scrutinizer#procedure-name in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15236(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,0,2)))){
C_save_and_reclaim_args((void *)trf_15236,2,t1,t2);}
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[29]);
if(C_truep(t4)){
/* scrutinizer.scm:1387: procedure-name */
t9=t1;
t10=C_i_caddr(t2);
t1=t9;
t2=t10;
goto loop;}
else{
t5=C_eqp(t3,lf[85]);
if(C_truep(t5)){
t6=C_i_cadr(t2);
if(C_truep(C_i_stringp(t6))){
/* scrutinizer.scm:1390: scheme#string->symbol */
t7=*((C_word*)lf[253]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t7=C_i_symbolp(t6);
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=(C_truep(t7)?t6:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.compiler.scrutinizer#procedure-arguments in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15287(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_15287,2,t1,t2);}
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[29]);
if(C_truep(t4)){
/* scrutinizer.scm:1398: procedure-arguments */
t10=t1;
t11=C_i_caddr(t2);
t1=t10;
t2=t11;
goto loop;}
else{
t5=C_eqp(t3,lf[85]);
if(C_truep(t5)){
t6=C_i_cadr(t2);
t7=C_i_stringp(t6);
if(C_truep(t7)){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=(C_truep(t7)?C_i_caddr(t2):C_i_cadr(t2));
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_i_symbolp(t6);
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=(C_truep(t8)?C_i_caddr(t2):C_i_cadr(t2));
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
/* scrutinizer.scm:1404: chicken.compiler.support#bomb */
t6=*((C_word*)lf[344]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[399];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.compiler.scrutinizer#procedure-results in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15344(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_15344,2,t1,t2);}
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[29]);
if(C_truep(t4)){
/* scrutinizer.scm:1409: procedure-results */
t10=t1;
t11=C_i_caddr(t2);
t1=t10;
t2=t11;
goto loop;}
else{
t5=C_eqp(t3,lf[85]);
if(C_truep(t5)){
t6=C_i_cadr(t2);
t7=C_i_stringp(t6);
if(C_truep(t7)){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=(C_truep(t7)?C_i_cdddr(t2):C_i_cddr(t2));
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_i_symbolp(t6);
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=(C_truep(t8)?C_i_cdddr(t2):C_i_cddr(t2));
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
/* scrutinizer.scm:1415: chicken.compiler.support#bomb */
t6=*((C_word*)lf[344]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[400];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15401(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_15401,5,t1,t2,t3,t4,t5);}
a=C_alloc(8);
t6=C_i_nullp(t5);
t7=(C_truep(t6)?C_SCHEME_FALSE:C_i_car(t5));
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15410,a[2]=t7,a[3]=t3,a[4]=t9,a[5]=t4,tmp=(C_word)a,a+=6,tmp));
t11=((C_word*)t9)[1];
f_15410(t11,t1,t2,C_SCHEME_END_OF_LIST);}

/* loop1 in chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15410(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(20,0,3)))){
C_save_and_reclaim_args((void *)trf_15410,4,t0,t1,t2,t3);}
a=C_alloc(20);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_eqp(lf[85],C_u_i_car(t2)):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=C_SCHEME_FALSE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_TRUE;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_fix(0);
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15420,a[2]=t1,a[3]=t7,a[4]=t9,a[5]=t11,tmp=(C_word)a,a+=6,tmp);
t13=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15427,a[2]=t9,a[3]=((C_word*)t0)[2],a[4]=t7,a[5]=t11,a[6]=t12,a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
t14=C_i_cadr(t2);
t15=C_i_stringp(t14);
if(C_truep(t15)){
t16=t13;
f_15427(t16,(C_truep(t15)?C_i_caddr(t2):C_i_cadr(t2)));}
else{
t16=C_i_cadr(t2);
t17=C_i_symbolp(t16);
t18=t13;
f_15427(t18,(C_truep(t17)?C_i_caddr(t2):C_i_cadr(t2)));}}
else{
t6=C_i_pairp(t2);
t7=(C_truep(t6)?C_eqp(lf[29],C_u_i_car(t2)):C_SCHEME_FALSE);
if(C_truep(t7)){
/* scrutinizer.scm:1450: loop1 */
t19=t1;
t20=C_i_caddr(t2);
t21=t3;
t1=t19;
t2=t20;
t3=t21;
goto loop;}
else{
t8=C_i_assq(t2,((C_word*)t0)[5]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15564,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1419: g3042 */
t10=t9;
f_15564(t10,t1,t8);}
else{
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15597,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1457: make-list */
f_8012(t9,((C_word*)t0)[3],C_a_i_list(&a,1,lf[54]));}}}}

/* k15418 in loop1 in chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15420(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_15420,c,av);}
/* scrutinizer.scm:1448: scheme#values */{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
av2[4]=((C_word*)((C_word*)t0)[4])[1];
av2[5]=((C_word*)((C_word*)t0)[5])[1];
C_values(6,av2);}}

/* k15425 in loop1 in chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15427(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_15427,2,t0,t1);}
a=C_alloc(9);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15429,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp));
t5=((C_word*)t3)[1];
f_15429(t5,((C_word*)t0)[6],t1,((C_word*)t0)[7],C_SCHEME_FALSE);}

/* loop in k15425 in loop1 in chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15429(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(62,0,4)))){
C_save_and_reclaim_args((void *)trf_15429,5,t0,t1,t2,t3,t4);}
a=C_alloc(62);
if(C_truep(C_i_nullp(t2))){
if(C_truep(t4)){
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=C_i_zerop(t3);
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
t5=C_i_car(t2);
t6=C_eqp(lf[365],t5);
if(C_truep(t6)){
if(C_truep(((C_word*)t0)[3])){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* scrutinizer.scm:1437: loop */
t17=t1;
t18=C_u_i_cdr(t2);
t19=t3;
t20=C_SCHEME_TRUE;
t1=t17;
t2=t18;
t3=t19;
t4=t20;
goto loop;}}
else{
t7=C_eqp(lf[366],C_u_i_car(t2));
if(C_truep(t7)){
if(C_truep(((C_word*)t0)[3])){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_i_pairp(C_u_i_cdr(t2));
t9=(C_truep(t8)?C_eqp(lf[401],C_i_cadr(t2)):C_SCHEME_FALSE);
t10=C_set_block_item(((C_word*)t0)[5],0,t9);
t11=(
/* scrutinizer.scm:1442: rest-type */
  f_15805(C_u_i_cdr(t2))
);
/* scrutinizer.scm:1442: make-list */
f_8012(t1,t3,C_a_i_list(&a,1,t11));}}
else{
t8=(C_truep(t4)?C_i_less_or_equalp(t3,C_fix(0)):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_set_block_item(((C_word*)t0)[2],0,C_i_positivep(t3));
t10=((C_word*)((C_word*)t0)[6])[1];
t11=C_mutate(((C_word *)((C_word*)t0)[6])+1,C_s_a_i_plus(&a,2,t10,C_fix(1)));
t12=C_u_i_car(t2);
t13=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15508,a[2]=t1,a[3]=t12,tmp=(C_word)a,a+=4,tmp);
t14=C_u_i_cdr(t2);
t15=C_s_a_i_minus(&a,2,t3,C_fix(1));
/* scrutinizer.scm:1447: loop */
t17=t13;
t18=t14;
t19=t15;
t20=t4;
t1=t17;
t2=t18;
t3=t19;
t4=t20;
goto loop;}}}}}

/* k15506 in loop in k15425 in loop1 in chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15508,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* g3042 in loop1 in chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15564(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_15564,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_i_cadr(t2);
t4=(C_truep(t3)?C_i_memq(t3,((C_word*)t0)[2]):C_SCHEME_FALSE);
if(C_truep(t4)){
/* scrutinizer.scm:1455: loop1 */
t5=((C_word*)((C_word*)t0)[3])[1];
f_15410(t5,t1,lf[54],((C_word*)t0)[2]);}
else{
t5=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[2]);
/* scrutinizer.scm:1456: loop1 */
t6=((C_word*)((C_word*)t0)[3])[1];
f_15410(t6,t1,t3,t5);}}

/* k15595 in loop1 in chicken.compiler.scrutinizer#procedure-argument-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15597(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_15597,c,av);}
/* scrutinizer.scm:1457: scheme#values */{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
av2[5]=((C_word*)t0)[3];
C_values(6,av2);}}

/* loop1 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15624(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_15624,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(((C_word*)t0)[2])){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_assq(t2,((C_word*)t0)[4]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15635,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1461: g3061 */
t5=t4;
f_15635(t5,t1,t3);}
else{
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_eqp(lf[85],C_u_i_car(t2)):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15657,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1464: chicken.base#call/cc */
t7=*((C_word*)lf[168]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t1;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t6=C_i_pairp(t2);
t7=(C_truep(t6)?C_eqp(lf[29],C_u_i_car(t2)):C_SCHEME_FALSE);
if(C_truep(t7)){
/* scrutinizer.scm:1473: loop1 */
t9=t1;
t10=C_i_caddr(t2);
t1=t9;
t2=t10;
goto loop;}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}}}

/* g3061 in loop1 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_fcall f_15635(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,2)))){
C_save_and_reclaim_args((void *)trf_15635,3,t0,t1,t2);}
/* scrutinizer.scm:1462: loop1 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_15624(t3,t1,C_i_cadr(t2));}

/* a15656 in loop1 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_15657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_15657,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15665,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=C_i_cadr(((C_word*)t0)[2]);
t5=C_i_stringp(t4);
if(C_truep(t5)){
t6=t3;
f_15665(t6,(C_truep(t5)?C_i_cdddr(((C_word*)t0)[2]):C_i_cddr(((C_word*)t0)[2])));}
else{
t6=C_i_cadr(((C_word*)t0)[2]);
t7=C_i_symbolp(t6);
t8=t3;
f_15665(t8,(C_truep(t7)?C_i_cdddr(((C_word*)t0)[2]):C_i_cddr(((C_word*)t0)[2])));}}

/* k15663 in a15656 in loop1 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_fcall f_15665(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_15665,2,t0,t1);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15667,a[2]=((C_word*)t0)[2],a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_15667(t5,((C_word*)t0)[3],t1);}

/* loop in k15663 in a15656 in loop1 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_15667(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_15667,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep((C_truep(C_eqp(t2,lf[54]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[71]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
/* scrutinizer.scm:1470: return */
t3=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[54];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15693,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1471: loop */
t6=t4;
t7=C_u_i_cdr(t2);
t1=t6;
t2=t7;
goto loop;}}}

/* k15691 in loop in k15663 in a15656 in loop1 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_15693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_15693,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#named? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_15752(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_u_i_car(t1);
t3=C_eqp(t2,lf[85]);
if(C_truep(t3)){
t4=C_i_cadr(t1);
t5=C_i_nullp(t4);
if(C_truep(t5)){
return(C_i_not(t5));}
else{
t6=C_u_i_cdr(t1);
return(C_i_not(C_i_pairp(C_u_i_car(t6))));}}
else{
t4=C_eqp(t2,lf[29]);
if(C_truep(t4)){
t8=C_i_caddr(t1);
t1=t8;
goto loop;}
else{
return(C_SCHEME_FALSE);}}}
else{
return(C_SCHEME_FALSE);}}

/* chicken.compiler.scrutinizer#rest-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_15805(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;{}
if(C_truep(C_i_nullp(t1))){
return(lf[54]);}
else{
t2=C_i_car(t1);
t3=C_eqp(lf[401],t2);
return((C_truep(t3)?lf[54]:C_u_i_car(t1)));}}

/* chicken.compiler.scrutinizer#noreturn-procedure-type? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_15825(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_u_i_car(t1);
t3=C_eqp(t2,lf[85]);
if(C_truep(t3)){
if(C_truep(C_i_listp(t1))){
t4=C_i_cadr(t1);
t5=C_i_pairp(t4);
t6=(C_truep(t5)?C_i_cddr(t1):C_i_cdddr(t1));
return(C_i_equalp(lf[402],t6));}
else{
return(C_SCHEME_FALSE);}}
else{
t4=C_eqp(t2,lf[29]);
if(C_truep(t4)){
t8=C_i_caddr(t1);
t1=t8;
goto loop;}
else{
return(C_SCHEME_FALSE);}}}
else{
return(C_SCHEME_FALSE);}}

/* chicken.compiler.scrutinizer#noreturn-type? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15884(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
av[0]=t0;
av[1]=t1;
av[2]=t2;
C_save_and_reclaim((void *)f_15884,c,av);}
t3=C_eqp(lf[71],t2);
if(C_truep(t3)){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t2))){
t4=C_u_i_car(t2);
t5=C_eqp(t4,lf[28]);
if(C_truep(t5)){
/* scrutinizer.scm:1507: any */
f_7221(t1,lf[403],C_u_i_cdr(t2));}
else{
t6=C_eqp(t4,lf[29]);
if(C_truep(t6)){
/* scrutinizer.scm:1508: noreturn-type? */
t8=t1;
t9=C_i_caddr(t2);
t1=t8;
t2=t9;
c=3;
goto loop;}
else{
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* chicken.compiler.scrutinizer#refinement-type? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_15928(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_i_car(t1);
t3=C_eqp(t2,lf[373]);
if(C_truep(t3)){
return(C_SCHEME_TRUE);}
else{
t4=C_eqp(t2,lf[29]);
if(C_truep(t4)){
t6=C_i_caddr(t1);
t1=t6;
goto loop;}
else{
return(C_SCHEME_FALSE);}}}
else{
return(C_SCHEME_FALSE);}}

/* k15965 in map-loop2435 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15967(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_15967,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15970,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1525: chicken.base#gensym */
t3=*((C_word*)lf[198]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15968 in k15965 in map-loop2435 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15970(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_15970,c,av);}
a=C_alloc(14);
t2=C_a_i_putprop(&a,3,t1,lf[377],((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[4])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[4])+1,t4);
t7=((C_word*)((C_word*)t0)[5])[1];
f_13652(t7,((C_word*)t0)[6],C_slot(((C_word*)t0)[7],C_fix(1)));}

/* chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15975(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_15975,c,av);}
a=C_alloc(12);
t3=C_SCHEME_END_OF_LIST;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15979,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15981,a[2]=t7,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_15981(t9,t5,t2);}

/* k15977 in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_15979(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15979,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_15981(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(22,0,3)))){
C_save_and_reclaim_args((void *)trf_15981,3,t0,t1,t2);}
a=C_alloc(22);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[373]);
if(C_truep(t4)){
/* scrutinizer.scm:1535: loop */
t19=t1;
t20=C_i_caddr(t2);
t1=t19;
t2=t20;
goto loop;}
else{
t5=C_eqp(t3,lf[85]);
if(C_truep(t5)){
t6=C_i_cadr(t2);
t7=C_i_stringp(t6);
t8=(C_truep(t7)?t7:C_i_symbolp(C_i_cadr(t2)));
if(C_truep(t8)){
t9=C_i_caddr(t2);
t10=C_i_check_list_2(t9,lf[213]);
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16026,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16070,a[2]=t13,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp));
t15=((C_word*)t13)[1];
f_16070(t15,t11,t9);}
else{
t9=C_i_cadr(t2);
t10=C_i_check_list_2(t9,lf[213]);
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16100,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16143,a[2]=t13,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp));
t15=((C_word*)t13)[1];
f_16143(t15,t11,t9);}}
else{
t6=C_eqp(t3,lf[29]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16185,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t8=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t9=t8;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=((C_word*)t10)[1];
t12=C_i_cadr(t2);
t13=C_i_check_list_2(t12,lf[6]);
t14=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16227,a[2]=t7,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16229,a[2]=t10,a[3]=t16,a[4]=t11,tmp=(C_word)a,a+=5,tmp));
t18=((C_word*)t16)[1];
f_16229(t18,t14,t12);}
else{
t7=C_eqp(t3,lf[28]);
if(C_truep(t7)){
t8=C_u_i_cdr(t2);
t9=C_i_check_list_2(t8,lf[213]);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16276,a[2]=t11,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp));
t13=((C_word*)t11)[1];
f_16276(t13,t1,t8);}
else{
t8=C_SCHEME_UNDEFINED;
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}}}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k16024 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16026(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_16026,c,av);}
a=C_alloc(6);
t2=C_i_cdddr(((C_word*)t0)[2]);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_cdr(((C_word*)t0)[2]);
t4=C_u_i_cdr(t3);
t5=C_u_i_cdr(t4);
t6=C_i_check_list_2(t5,lf[213]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16043,a[2]=t8,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_16043(t10,((C_word*)t0)[4],t5);}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* for-each-loop3169 in k16024 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16043(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_16043,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16053,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1540: g3170 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_15981(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k16051 in for-each-loop3169 in k16024 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16053(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16053,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_16043(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop3152 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16070(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_16070,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16080,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1538: g3153 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_15981(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k16078 in for-each-loop3152 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16080,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_16070(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k16098 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16100(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_16100,c,av);}
a=C_alloc(6);
t2=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_cdr(((C_word*)t0)[2]);
t4=C_u_i_cdr(t3);
t5=C_i_check_list_2(t4,lf[213]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16116,a[2]=t7,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_16116(t9,((C_word*)t0)[4],t4);}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* for-each-loop3204 in k16098 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16116(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_16116,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16126,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1544: g3205 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_15981(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k16124 in for-each-loop3204 in k16098 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16126,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_16116(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop3187 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16143(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_16143,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16153,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1542: g3188 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_15981(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k16151 in for-each-loop3187 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16153(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16153,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_16143(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k16183 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16185(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16185,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
/* scrutinizer.scm:1552: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_15981(t3,((C_word*)t0)[4],C_i_caddr(((C_word*)t0)[5]));}

/* k16225 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_16227,c,av);}
/* scrutinizer.scm:1546: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop3222 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16229(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,2)))){
C_save_and_reclaim_args((void *)trf_16229,3,t0,t1,t2);}
a=C_alloc(15);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16254,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
if(C_truep(C_i_symbolp(t4))){
t5=t3;
f_16254(t5,C_a_i_list3(&a,3,t4,C_SCHEME_FALSE,C_SCHEME_FALSE));}
else{
t5=C_i_car(t4);
t6=C_i_cadr(t4);
t7=t3;
f_16254(t7,C_a_i_list3(&a,3,t5,C_SCHEME_FALSE,t6));}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16252 in map-loop3222 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16254(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16254,2,t0,t1);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_16229(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* for-each-loop3250 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16276(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_16276,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16286,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1554: g3251 */
t4=((C_word*)((C_word*)t0)[3])[1];
f_15981(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k16284 in for-each-loop3250 in loop in chicken.compiler.scrutinizer#type-typeenv in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16286,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_16276(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.compiler.scrutinizer#trail-restore in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16307(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_16307,3,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16313,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(
  f_16313(t4,lf[24])
);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* doloop3270 in chicken.compiler.scrutinizer#trail-restore in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_16313(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;
loop:{}
t2=C_eqp(t1,((C_word*)t0)[2]);
if(C_truep(t2)){
t3=C_SCHEME_UNDEFINED;
return(t3);}
else{
t3=C_i_car(t1);
t4=C_i_assq(t3,((C_word*)t0)[3]);
t5=C_i_cdr(t4);
t6=C_i_set_car(t5,C_SCHEME_FALSE);
t8=C_u_i_cdr(t1);
t1=t8;
goto loop;}}

/* k16343 in k14836 in chicken.compiler.scrutinizer#type<=? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16345(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_16345,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16348,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1566: trail-restore */
f_16307(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k16346 in k16343 in k14836 in chicken.compiler.scrutinizer#type<=? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16348(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_16348,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16350(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_16350,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16358,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16360,a[2]=t3,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_16360(t8,t4,t2,C_SCHEME_END_OF_LIST);}

/* k16356 in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16358(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16358,c,av);}
/* scrutinizer.scm:1570: simplify-type */
f_13568(((C_word*)t0)[2],t1);}

/* resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16360(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(20,0,3)))){
C_save_and_reclaim_args((void *)trf_16360,4,t0,t1,t2,t3);}
a=C_alloc(20);
t4=C_i_assq(t2,((C_word*)t0)[2]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16368,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1572: g3294 */
t6=t5;
f_16368(t6,t1,t4);}
else{
t5=C_i_pairp(t2);
if(C_truep(C_i_not(t5))){
t6=C_i_memq(t2,lf[19]);
if(C_truep(t6)){
if(C_truep(t6)){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* scrutinizer.scm:1584: chicken.compiler.support#bomb */
t7=*((C_word*)lf[344]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[404];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
if(C_truep(C_i_memq(t2,lf[21]))){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* scrutinizer.scm:1584: chicken.compiler.support#bomb */
t7=*((C_word*)lf[344]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[404];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}}
else{
t6=C_i_car(t2);
t7=C_eqp(t6,lf[28]);
if(C_truep(t7)){
t8=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t9=t8;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=((C_word*)t10)[1];
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16449,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t13=C_u_i_cdr(t2);
t14=C_i_check_list_2(t13,lf[6]);
t15=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16460,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16462,a[2]=t10,a[3]=t17,a[4]=t12,a[5]=t11,tmp=(C_word)a,a+=6,tmp));
t19=((C_word*)t17)[1];
f_16462(t19,t15,t13);}
else{
t8=C_eqp(t6,lf[70]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16507,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1588: resolve */
t20=t9;
t21=C_i_cadr(t2);
t22=t3;
t1=t20;
t2=t21;
t3=t22;
goto loop;}
else{
t9=C_eqp(t6,lf[29]);
t10=(C_truep(t9)?t9:C_eqp(t6,lf[373]));
if(C_truep(t10)){
t11=C_u_i_car(t2);
t12=C_i_cadr(t2);
t13=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16533,a[2]=t1,a[3]=t11,a[4]=t12,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1590: resolve */
t20=t13;
t21=C_i_caddr(t2);
t22=t3;
t1=t20;
t2=t21;
t3=t22;
goto loop;}
else{
t11=C_eqp(t6,lf[49]);
t12=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16546,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=t1,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t11)){
t13=t12;
f_16546(t13,t11);}
else{
t13=C_eqp(t6,lf[48]);
if(C_truep(t13)){
t14=t12;
f_16546(t14,t13);}
else{
t14=C_eqp(t6,lf[51]);
if(C_truep(t14)){
t15=t12;
f_16546(t15,t14);}
else{
t15=C_eqp(t6,lf[360]);
t16=t12;
f_16546(t16,(C_truep(t15)?t15:C_eqp(t6,lf[362])));}}}}}}}}}

/* g3294 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16368(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_16368,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_i_cadr(t2);
t4=C_i_not(t3);
t5=(C_truep(t4)?t4:C_i_memq(t3,((C_word*)t0)[2]));
if(C_truep(t5)){
if(C_truep(C_i_caddr(t2))){
t6=C_i_caddr(t2);
t7=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[2]);
/* scrutinizer.scm:1578: resolve */
t8=((C_word*)((C_word*)t0)[4])[1];
f_16360(t8,t1,t6,t7);}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t6=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[2]);
/* scrutinizer.scm:1580: resolve */
t7=((C_word*)((C_word*)t0)[4])[1];
f_16360(t7,t1,t3,t6);}}

/* g3321 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16449(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_16449,3,t0,t1,t2);}
/* scrutinizer.scm:1587: g3338 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_16360(t3,t1,t2,((C_word*)t0)[3]);}

/* k16458 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16460,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[28],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop3315 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16462(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_16462,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16487,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1587: g3321 */
t4=((C_word*)t0)[4];
f_16449(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16485 in map-loop3315 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_16487,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_16462(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k16505 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16507(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_16507,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,2,lf[70],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k16531 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_16533,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list3(&a,3,((C_word*)t0)[3],((C_word*)t0)[4],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16546(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,3)))){
C_save_and_reclaim_args((void *)trf_16546,2,t0,t1);}
a=C_alloc(21);
if(C_truep(t1)){
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16556,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t8=C_u_i_cdr(((C_word*)t0)[2]);
t9=C_i_check_list_2(t8,lf[6]);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16567,a[2]=((C_word*)t0)[5],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16569,a[2]=t5,a[3]=t12,a[4]=t7,a[5]=t6,tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_16569(t14,t10,t8);}
else{
t2=C_eqp(((C_word*)t0)[6],lf[85]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16610,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1594: procedure-name */
f_15236(t3,((C_word*)t0)[2]);}
else{
t3=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* g3373 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16556(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_16556,3,t0,t1,t2);}
/* scrutinizer.scm:1592: g3390 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_16360(t3,t1,t2,((C_word*)t0)[3]);}

/* k16565 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16567,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop3367 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16569(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_16569,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16594,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1592: g3373 */
t4=((C_word*)t0)[4];
f_16556(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16592 in map-loop3367 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_16594,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_16569(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16610(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_16610,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16613,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1595: procedure-arguments */
f_15287(t2,((C_word*)t0)[5]);}

/* k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_16613,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16616,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1596: procedure-results */
f_15344(t2,((C_word*)t0)[6]);}

/* k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16616(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_16616,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16623,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(C_truep(((C_word*)t0)[3])?C_a_i_list1(&a,1,((C_word*)t0)[3]):C_SCHEME_END_OF_LIST);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16635,a[2]=t2,a[3]=t3,a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16692,a[2]=t6,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_16692(t8,t4,((C_word*)t0)[6]);}

/* k16621 in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16623(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16623,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[85],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k16633 in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_16635,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16639,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_eqp(lf[54],((C_word*)t0)[4]);
if(C_truep(t3)){
t4=C_a_i_cons(&a,2,t1,lf[54]);
/* scrutinizer.scm:1597: ##sys#append */
t5=*((C_word*)lf[405]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16646,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t9=C_i_check_list_2(((C_word*)t0)[4],lf[6]);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16658,a[2]=t6,a[3]=t11,a[4]=t8,a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_16658(t13,t2,((C_word*)t0)[4]);}}

/* k16637 in k16633 in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_16639,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* scrutinizer.scm:1597: ##sys#append */
t3=*((C_word*)lf[405]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* g3420 in k16633 in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16646(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_16646,3,t0,t1,t2);}
/* scrutinizer.scm:1610: g3437 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_16360(t3,t1,t2,((C_word*)t0)[3]);}

/* map-loop3414 in k16633 in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16658(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_16658,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16683,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1610: g3420 */
t4=((C_word*)t0)[4];
f_16646(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16681 in map-loop3414 in k16633 in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_16683,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_16658(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* loop in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16692(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_16692,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=C_eqp(lf[366],t3);
if(C_truep(t4)){
if(C_truep(C_i_equalp(lf[406],C_u_i_cdr(t2)))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_u_i_car(t2);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16720,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1604: loop */
t9=t6;
t10=C_u_i_cdr(t2);
t1=t9;
t2=t10;
goto loop;}}
else{
t5=C_eqp(lf[365],C_u_i_car(t2));
if(C_truep(t5)){
t6=C_u_i_car(t2);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16739,a[2]=t1,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1606: loop */
t9=t7;
t10=C_u_i_cdr(t2);
t1=t9;
t2=t10;
goto loop;}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16748,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1607: resolve */
t7=((C_word*)((C_word*)t0)[3])[1];
f_16360(t7,t6,C_u_i_car(t2),((C_word*)t0)[4]);}}}}

/* k16718 in loop in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16720,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k16737 in loop in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16739(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16739,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k16746 in loop in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_16748,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16752,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1607: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_16692(t3,t2,C_u_i_cdr(((C_word*)t0)[4]));}

/* k16750 in k16746 in loop in k16614 in k16611 in k16608 in k16544 in resolve in chicken.compiler.scrutinizer#resolve in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16752(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16752,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16815(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_16815,c,av);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16819,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_rest_nullp(c,4))){
/* scrutinizer.scm:1617: chicken.platform#repository-path */
t5=*((C_word*)lf[432]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_get_rest_arg(c,4,av,4,t0);
f_16819(2,av2);}}}

/* k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_16819,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16822,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_not(t1))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17200,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1619: ##sys#file-exists? */
t4=*((C_word*)lf[430]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
av2[5]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
/* scrutinizer.scm:1620: chicken.load#find-file */
t3=*((C_word*)lf[431]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_16822,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16828,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17173,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1621: chicken.base#open-output-string */
t4=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_16828,c,av);}
a=C_alloc(15);
t2=C_SCHEME_FALSE;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16833,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16838,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17166,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1622: ##sys#dynamic-wind */
t9=*((C_word*)lf[225]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a16832 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16833(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_16833,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,lf[17]);
t3=C_mutate(&lf[17] /* (set! chicken.compiler.scrutinizer#scrutiny-debug ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16838(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_16838,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17135,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1683: scheme#call-with-input-file */
t3=*((C_word*)lf[425]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=*((C_word*)lf[426]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_16847,c,av);}
a=C_alloc(12);
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_i_pairp(t2);
t4=(C_truep(t3)?C_u_i_cdr(C_u_i_cdr(((C_word*)t0)[2])):C_SCHEME_FALSE);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16853,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t6=C_u_i_cdr(((C_word*)t0)[2]);
t7=C_u_i_car(t6);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16952,a[2]=((C_word*)t0)[3],a[3]=t9,tmp=(C_word)a,a+=4,tmp));
t11=((C_word*)t9)[1];
f_16952(t11,t5,t7);}

/* k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,5)))){
C_save_and_reclaim((void *)f_16853,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16858,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16864,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1662: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a16857 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_16858,c,av);}
/* scrutinizer.scm:1662: validate-type */
t2=*((C_word*)lf[408]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16864(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_16864,c,av);}
a=C_alloc(13);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16868,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t2)){
t6=t5;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_16868(2,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16919,a[2]=t5,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1665: chicken.base#open-output-string */
t7=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16868(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_16868,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16871,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16886,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16912,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1668: compatible-types? */
f_14775(t4,((C_word*)t0)[6],((C_word*)t0)[5],C_SCHEME_END_OF_LIST);}
else{
t4=t3;
f_16886(t4,C_SCHEME_FALSE);}}

/* k16869 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_16871,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16874,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1679: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[234]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[66];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16872 in k16869 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_16874(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_16874,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16877,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1680: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[234]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[67];
av2[4]=lf[410];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16875 in k16872 in k16869 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_16877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_16877,c,av);}
if(C_truep(((C_word*)t0)[2])){
/* scrutinizer.scm:1682: install-specializations */
t2=*((C_word*)lf[409]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16884 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16886(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_16886,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16893,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16897,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1671: scheme#string-append */
t4=*((C_word*)lf[77]+1);{
C_word av2[6];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[412];
av2[3]=lf[413];
av2[4]=lf[414];
av2[5]=lf[415];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_16871(2,av2);}}}

/* k16891 in k16884 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_16893(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16893,c,av);}
/* scrutinizer.scm:1669: chicken.base#warning */
t2=*((C_word*)lf[91]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k16895 in k16884 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_16897(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_16897,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16901,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1677: type->pp-string */
f_20840(t2,((C_word*)t0)[5]);}

/* k16899 in k16895 in k16884 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_16901(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_16901,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16905,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1678: type->pp-string */
f_20840(t2,((C_word*)t0)[5]);}

/* k16903 in k16899 in k16895 in k16884 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_16905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_16905,c,av);}
/* scrutinizer.scm:1670: chicken.format#sprintf */
t2=*((C_word*)lf[411]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k16910 in k16866 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16912(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_16912,c,av);}
t2=((C_word*)t0)[2];
f_16886(t2,C_i_not(t1));}

/* k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_16919,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16925,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1665: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[417];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_16925,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16928,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1665: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16926 in k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_16928(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_16928,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16931,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1665: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[416];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16929 in k16926 in k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_16931(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_16931,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16934,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1665: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k16932 in k16929 in k16926 in k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_16934(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_16934,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16937,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1665: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k16935 in k16932 in k16929 in k16926 in k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_16937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_16937,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16940,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16947,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1667: type->pp-string */
f_20840(t3,((C_word*)t0)[4]);}

/* k16938 in k16935 in k16932 in k16929 in k16926 in k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_16940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_16940,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16943,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1665: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k16941 in k16938 in k16935 in k16932 in k16929 in k16926 in k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_16943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16943,c,av);}
/* scrutinizer.scm:1664: chicken.base#warning */
t2=*((C_word*)lf[91]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k16945 in k16935 in k16932 in k16929 in k16926 in k16923 in k16917 in a16863 in k16851 in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_16947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_16947,c,av);}
/* scrutinizer.scm:1665: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16952(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_16952,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=C_i_vectorp(C_u_i_car(t2));
t4=(C_truep(t3)?C_eqp(lf[85],C_i_vector_ref(C_u_i_car(t2),C_fix(0))):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16968,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17084,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1633: scheme#vector->list */
t7=*((C_word*)lf[52]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_u_i_car(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=C_eqp(lf[29],C_u_i_car(t2));
if(C_truep(t5)){
t6=C_i_cadr(t2);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17103,a[2]=t1,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1657: adjust */
t9=t7;
t10=C_i_caddr(t2);
t1=t9;
t2=t10;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16966 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16968(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16968,c,av);}
a=C_alloc(3);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[85],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* loop in k17082 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_16979(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_16979,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=C_eqp(t3,lf[418]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16998,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1637: chicken.compiler.support#mark-variable */
t6=*((C_word*)lf[234]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[273];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=C_eqp(t3,lf[419]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17012,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1640: chicken.compiler.support#mark-variable */
t7=*((C_word*)lf[234]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[272];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t6=C_eqp(t3,lf[420]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17026,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1643: chicken.compiler.support#mark-variable */
t8=*((C_word*)lf[234]+1);{
C_word av2[5];
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[277];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
t7=C_eqp(t3,lf[421]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17040,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1646: chicken.compiler.support#mark-variable */
t9=*((C_word*)lf[234]+1);{
C_word av2[5];
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[422];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t8=C_eqp(t3,lf[423]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17054,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1649: chicken.compiler.support#mark-variable */
t10=*((C_word*)lf[234]+1);{
C_word av2[5];
av2[0]=t10;
av2[1]=t9;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[166];
av2[4]=C_i_cadr(t2);
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
/* scrutinizer.scm:1652: chicken.compiler.support#bomb */
t9=*((C_word*)lf[344]+1);{
C_word av2[5];
av2[0]=t9;
av2[1]=t1;
av2[2]=lf[424];
av2[3]=C_u_i_car(t2);
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}}}}}}}

/* k16996 in loop in k17082 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_16998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16998,c,av);}
/* scrutinizer.scm:1638: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16979(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* k17010 in loop in k17082 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17012,c,av);}
/* scrutinizer.scm:1641: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16979(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* k17024 in loop in k17082 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17026(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17026,c,av);}
/* scrutinizer.scm:1644: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16979(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* k17038 in loop in k17082 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17040,c,av);}
/* scrutinizer.scm:1647: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16979(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* k17052 in loop in k17082 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17054(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17054,c,av);}
/* scrutinizer.scm:1650: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16979(t2,((C_word*)t0)[3],C_i_cddr(((C_word*)t0)[4]));}

/* k17082 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17084(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_17084,c,av);}
a=C_alloc(7);
t2=C_i_cdr(t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16979,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_16979(t6,((C_word*)t0)[4],t2);}

/* k17101 in adjust in k16845 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17103(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_17103,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[29],((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17135(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_17135,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[213]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17141,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17143,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_17143(t7,t3,t1);}

/* k17139 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17141,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17143(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_17143,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17153,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=C_i_car(t4);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16847,a[2]=t4,a[3]=t5,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1626: chicken.compiler.support#variable-mark */
t7=*((C_word*)lf[65]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=t5;
av2[3]=lf[66];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k17151 in for-each-loop3485 in k17133 in a16837 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17153(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17153,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_17143(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* a17165 in k16826 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17166(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17166,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,lf[17]);
t3=C_mutate(&lf[17] /* (set! chicken.compiler.scrutinizer#scrutiny-debug ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k17171 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17173(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_17173,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17179,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1621: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[429];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k17177 in k17171 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17179(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_17179,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17182,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1621: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k17180 in k17177 in k17171 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_17182,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17185,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1621: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[428];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k17183 in k17180 in k17177 in k17171 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17185(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_17185,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17188,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1621: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k17186 in k17183 in k17180 in k17177 in k17171 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_17188,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17191,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1621: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17189 in k17186 in k17183 in k17180 in k17177 in k17171 in k16820 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17191,c,av);}
/* scrutinizer.scm:1621: chicken.compiler.support#debugging */
t2=*((C_word*)lf[237]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[427];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17198 in k16817 in chicken.compiler.scrutinizer#load-type-database in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17200,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?((C_word*)t0)[3]:C_SCHEME_FALSE);
f_16822(2,av2);}}

/* loop1 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17223(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_17223,4,t0,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(C_i_greater_or_equalp(t2,((C_word*)t0)[2]))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_vector_ref(((C_word*)t0)[3],t2);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17239,a[2]=t2,a[3]=((C_word*)t0)[4],a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_17239(t8,t1,t4,t3);}}

/* loop2 in loop1 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17239(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(29,0,3)))){
C_save_and_reclaim_args((void *)trf_17239,4,t0,t1,t2,t3);}
a=C_alloc(29);
if(C_truep(C_i_nullp(t2))){
t4=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
/* scrutinizer.scm:1694: loop1 */
t5=((C_word*)((C_word*)t0)[3])[1];
f_17223(t5,t1,t4,t3);}
else{
t4=C_i_cdr(t2);
t5=C_i_caar(t2);
t6=C_u_i_car(t2);
t7=C_u_i_cdr(t6);
t8=C_a_i_cons(&a,2,t5,t7);
t9=C_a_i_cons(&a,2,t8,t3);
/* scrutinizer.scm:1695: loop2 */
t11=t1;
t12=t4;
t13=t9;
t1=t11;
t2=t12;
t3=t13;
goto loop;}}

/* k17281 in a17490 in k17487 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17283(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17283,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17287,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1700: scheme#symbol->string */
t3=*((C_word*)lf[443]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17285 in k17281 in a17490 in k17487 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17287(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17287,c,av);}
/* scrutinizer.scm:1699: scheme#string<? */
t2=*((C_word*)lf[442]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17289(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_17289,c,av);}
a=C_alloc(5);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17295,a[2]=t5,a[3]=t4,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1703: scheme#with-output-to-file */
t7=*((C_word*)lf[449]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t1;
av2[2]=t3;
av2[3]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_17295,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17299,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17507,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1705: chicken.platform#chicken-version */
t4=*((C_word*)lf[448]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17299(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_17299,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17300,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17453,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17489,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=C_i_vector_length(((C_word*)t0)[4]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17223,a[2]=t5,a[3]=((C_word*)t0)[4],a[4]=t7,tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_17223(t9,t4,C_fix(0),C_SCHEME_END_OF_LIST);}

/* g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17300(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_17300,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17311,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17445,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1711: chicken.compiler.support#variable-visible? */
t7=*((C_word*)lf[248]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17311(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_17311,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17314,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1713: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[163];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_17314,c,av);}
a=C_alloc(5);
t2=(C_truep(t1)?t1:C_SCHEME_END_OF_LIST);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17320,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1714: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[66];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17320(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_17320,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17323,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1715: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[166];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_17323,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17326,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1716: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[273];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17326(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_17326,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17329,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1717: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[272];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17329(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_17329,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17332,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:1718: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[277];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17332(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_17332,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17335,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:1719: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[422];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_17335,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17338,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17345,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17349,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17351,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=t1,a[7]=t6,tmp=(C_word)a,a+=8,tmp));
t8=((C_word*)t6)[1];
f_17351(t8,t4,((C_word*)t0)[9]);}

/* k17336 in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_17338(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17338,c,av);}
/* scrutinizer.scm:1737: scheme#newline */
t2=*((C_word*)lf[434]+1);{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k17343 in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_17345(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17345,c,av);}
/* scrutinizer.scm:1720: chicken.pretty-print#pp */
t2=*((C_word*)lf[435]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k17347 in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_17349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_17349,c,av);}
a=C_alloc(11);
t2=C_a_i_list(&a,2,t1,((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7257,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_7257(t6,((C_word*)t0)[3],((C_word*)t0)[4],t2);}

/* wrap in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_fcall f_17351(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(25,0,3)))){
C_save_and_reclaim_args((void *)trf_17351,3,t0,t1,t2);}
a=C_alloc(25);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[85]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17372,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17382,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t7=(C_truep(((C_word*)t0)[2])?lf[436]:C_SCHEME_END_OF_LIST);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17390,a[2]=t6,a[3]=t7,tmp=(C_word)a,a+=4,tmp);
t9=(C_truep(((C_word*)t0)[3])?C_a_i_list(&a,2,lf[423],((C_word*)t0)[3]):C_SCHEME_END_OF_LIST);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17398,a[2]=t8,a[3]=t9,tmp=(C_word)a,a+=4,tmp);
t11=(C_truep(((C_word*)t0)[4])?lf[437]:C_SCHEME_END_OF_LIST);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17406,a[2]=t10,a[3]=t11,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[5])){
t13=lf[438];
if(C_truep(((C_word*)t0)[6])){
/* scrutinizer.scm:1725: ##sys#append */
t14=*((C_word*)lf[405]+1);{
C_word av2[4];
av2[0]=t14;
av2[1]=t12;
av2[2]=t13;
av2[3]=lf[439];
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}
else{
/* scrutinizer.scm:1725: ##sys#append */
t14=*((C_word*)lf[405]+1);{
C_word av2[4];
av2[0]=t14;
av2[1]=t12;
av2[2]=t13;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}}
else{
t13=C_SCHEME_END_OF_LIST;
if(C_truep(((C_word*)t0)[6])){
/* scrutinizer.scm:1725: ##sys#append */
t14=*((C_word*)lf[405]+1);{
C_word av2[4];
av2[0]=t14;
av2[1]=t12;
av2[2]=t13;
av2[3]=lf[439];
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}
else{
/* scrutinizer.scm:1725: ##sys#append */
t14=*((C_word*)lf[405]+1);{
C_word av2[4];
av2[0]=t14;
av2[1]=t12;
av2[2]=t13;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}}}
else{
t5=C_eqp(t3,lf[29]);
if(C_truep(t5)){
t6=C_i_cadr(t2);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17434,a[2]=t1,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1733: wrap */
t15=t7;
t16=C_i_caddr(t2);
t1=t15;
t2=t16;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k17370 in wrap in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_17372(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_17372,c,av);}
a=C_alloc(3);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k17380 in wrap in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_17382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_17382,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[85],t1);
/* scrutinizer.scm:1725: ##sys#list->vector */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17388 in wrap in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_17390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17390,c,av);}
/* scrutinizer.scm:1725: ##sys#append */
t2=*((C_word*)lf[405]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17396 in wrap in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_17398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17398,c,av);}
/* scrutinizer.scm:1725: ##sys#append */
t2=*((C_word*)lf[405]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17404 in wrap in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_17406(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17406,c,av);}
/* scrutinizer.scm:1725: ##sys#append */
t2=*((C_word*)lf[405]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17432 in wrap in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_17434(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_17434,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[29],((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k17443 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17445(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_17445,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17449,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1712: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[67];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_17311(t2,C_SCHEME_FALSE);}}

/* k17447 in k17443 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17449(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17449,c,av);}
t2=((C_word*)t0)[2];
f_17311(t2,C_u_i_memq(t1,lf[440]));}

/* k17451 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17453(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_17453,c,av);}
a=C_alloc(9);
t2=C_i_check_list_2(t1,lf[213]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17459,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17464,a[2]=t5,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_17464(t7,t3,t1);}

/* k17457 in k17451 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17459,c,av);}
/* scrutinizer.scm:1740: chicken.base#print */
t2=*((C_word*)lf[356]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[441];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* for-each-loop3595 in k17451 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17464(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_17464,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17474,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1707: g3596 */
t4=((C_word*)t0)[3];
f_17300(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k17472 in for-each-loop3595 in k17451 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17474(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17474,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_17464(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k17487 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17489(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(2,c,4)))){
C_save_and_reclaim((void *)f_17489,c,av);}
a=C_alloc(2);
t2=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17491,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:1738: chicken.sort#sort */
t3=*((C_word*)lf[444]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a17490 in k17487 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17491(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17491,c,av);}
a=C_alloc(4);
t4=C_i_car(t2);
t5=C_i_car(t3);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17283,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1699: scheme#symbol->string */
t7=*((C_word*)lf[443]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k17505 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17507(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17507,c,av);}
/* scrutinizer.scm:1705: chicken.base#print */
t2=*((C_word*)lf[356]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[445];
av2[3]=t1;
av2[4]=lf[446];
av2[5]=((C_word*)t0)[3];
av2[6]=lf[447];
((C_proc)(void*)(*((C_word*)t2+1)))(7,av2);}}

/* chicken.compiler.scrutinizer#mutate-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17510(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_17510,3,t1,t2,t3);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17515,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17526,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1755: chicken.compiler.support#copy-node */
t6=*((C_word*)lf[453]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k17513 in chicken.compiler.scrutinizer#mutate-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17515(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17515,c,av);}
a=C_alloc(4);
t2=C_mutate(&lf[450] /* (set! chicken.compiler.scrutinizer#node-mutations ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17522,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1756: chicken.compiler.support#build-node-graph */
t4=*((C_word*)lf[452]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k17520 in k17513 in chicken.compiler.scrutinizer#mutate-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17522(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17522,c,av);}
/* scrutinizer.scm:1756: chicken.compiler.support#copy-node! */
t2=*((C_word*)lf[451]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17524 in chicken.compiler.scrutinizer#mutate-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_17526,c,av);}
/* scrutinizer.scm:1755: chicken.base#alist-update! */
t2=*((C_word*)lf[187]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=lf[450];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.compiler.scrutinizer#source-node in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17528(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_17528,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_i_nullp(t3);
t5=(C_truep(t4)?*((C_word*)lf[455]+1):C_i_car(t3));
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17535,a[2]=t5,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1759: chicken.base#alist-ref */
t7=*((C_word*)lf[276]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
av2[3]=lf[450];
av2[4]=*((C_word*)lf[375]+1);
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}

/* k17533 in chicken.compiler.scrutinizer#source-node in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_17535,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
/* scrutinizer.scm:1760: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
/* scrutinizer.scm:1760: source-node */
f_17528(((C_word*)t0)[3],t1,C_a_i_list(&a,1,((C_word*)t0)[2]));}}

/* chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17555(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_17555,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17561,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:1763: source-node */
f_17528(t1,t2,C_a_i_list(&a,1,t3));}

/* a17560 in chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17561,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17569,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1766: chicken.compiler.support#node-class */
t4=*((C_word*)lf[89]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k17567 in a17560 in chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_17569,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17573,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1767: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17571 in k17567 in a17560 in chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_17573,c,av);}
a=C_alloc(12);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=lf[456];
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17580,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t4,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1768: chicken.compiler.support#node-subexpressions */
t8=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}

/* k17578 in k17571 in k17567 in a17560 in chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17580(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_17580,c,av);}
a=C_alloc(12);
t2=C_i_check_list_2(t1,lf[6]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17586,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17588,a[2]=((C_word*)t0)[5],a[3]=t5,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_17588(t7,t3,t1);}

/* k17584 in k17578 in k17571 in k17567 in a17560 in chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_17586,c,av);}
/* scrutinizer.scm:1766: chicken.compiler.support#make-node */
t2=*((C_word*)lf[270]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop3670 in k17578 in k17571 in k17567 in a17560 in chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17588(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_17588,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17613,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1768: g3676 */
t4=lf[456];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_17555(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k17611 in map-loop3670 in k17578 in k17571 in k17567 in a17560 in chicken.compiler.scrutinizer#source-node-tree in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_17613,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_17588(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k17628 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_17630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17630,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17636,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1774: chicken.compiler.support#node-class */
t3=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17634 in k17628 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_17636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_17636,c,av);}
a=C_alloc(3);
t2=C_eqp(t1,lf[121]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17645,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1776: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_eqp(t1,lf[312]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17684,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1781: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_21439(2,av2);}}}}

/* k17643 in k17634 in k17628 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_17645(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17645,c,av);}
t2=C_i_cdr(t1);
if(C_truep(C_i_pairp(t2))){
t3=C_i_cadr(t1);
if(C_truep(C_i_pairp(t3))){
t4=C_u_i_cdr(t1);
/* scrutinizer.scm:1779: chicken.compiler.support#source-info->line */
t5=*((C_word*)lf[512]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=C_u_i_car(t4);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_21439(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_21439(2,av2);}}}

/* k17682 in k17634 in k17628 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_17684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17684,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_car(t1);
f_21439(2,av2);}}

/* chicken.compiler.scrutinizer#specialize-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17690(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_17690,4,t1,t2,t3,t4);}
a=C_alloc(13);
t5=C_SCHEME_END_OF_LIST;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17693,a[2]=t3,a[3]=t6,a[4]=t8,tmp=(C_word)a,a+=5,tmp));
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17841,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1810: subst */
t11=((C_word*)t8)[1];
f_17693(t11,t10,t4);}

/* subst in chicken.compiler.scrutinizer#specialize-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17693(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(58,0,2)))){
C_save_and_reclaim_args((void *)trf_17693,3,t0,t1,t2);}
a=C_alloc(58);
t3=C_i_vectorp(t2);
t4=(C_truep(t3)?C_eqp(C_fix(1),C_block_size(t2)):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_i_vector_ref(t2,C_fix(0));
if(C_truep(C_i_integerp(t5))){
if(C_truep(C_i_negativep(t5))){
t6=C_s_a_i_negate(&a,1,t5);
t7=C_s_a_i_minus(&a,2,t6,C_fix(1));
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_i_list_tail(((C_word*)t0)[2],t7);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t6=C_s_a_i_minus(&a,2,t5,C_fix(1));
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_i_list_ref(((C_word*)t0)[2],t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
if(C_truep(C_i_symbolp(t5))){
t6=C_i_assq(t5,((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(t6)){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_i_cdr(t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17740,a[2]=((C_word*)t0)[3],a[3]=t5,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1799: chicken.base#gensym */
t8=*((C_word*)lf[198]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17750,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_vectorp(t2))){
t6=C_block_size(t2);
t7=C_eqp(C_fix(2),t6);
if(C_truep(t7)){
t8=C_i_vector_ref(t2,C_fix(0));
t9=t5;
f_17750(t9,(C_truep(C_i_integerp(t8))?C_eqp(lf[457],C_i_vector_ref(t2,C_fix(1))):C_SCHEME_FALSE));}
else{
t8=t5;
f_17750(t8,C_SCHEME_FALSE);}}
else{
t6=t5;
f_17750(t6,C_SCHEME_FALSE);}}}

/* k17738 in subst in chicken.compiler.scrutinizer#specialize-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_17740,c,av);}
a=C_alloc(6);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k17748 in subst in chicken.compiler.scrutinizer#specialize-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17750(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,2)))){
C_save_and_reclaim_args((void *)trf_17750,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=C_i_vector_ref(((C_word*)t0)[2],C_fix(0));
t3=C_s_a_i_minus(&a,2,t2,C_fix(1));
t4=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_i_list_tail(((C_word*)t0)[4],t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=C_i_pairp(((C_word*)t0)[2]);
if(C_truep(C_i_not(t2))){
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(((C_word*)t0)[2]);
t4=C_eqp(lf[124],t3);
if(C_truep(t4)){
t5=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17777,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1809: subst */
t6=((C_word*)((C_word*)t0)[5])[1];
f_17693(t6,t5,C_u_i_car(((C_word*)t0)[2]));}}}}

/* k17775 in k17748 in subst in chicken.compiler.scrutinizer#specialize-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17777(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17777,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17781,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1809: subst */
t3=((C_word*)((C_word*)t0)[3])[1];
f_17693(t3,t2,C_u_i_cdr(((C_word*)t0)[4]));}

/* k17779 in k17775 in k17748 in subst in chicken.compiler.scrutinizer#specialize-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_17781,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k17839 in chicken.compiler.scrutinizer#specialize-node! in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17841,c,av);}
/* scrutinizer.scm:1810: mutate-node! */
f_17510(((C_word*)t0)[2],((C_word*)t0)[3],t1);}

/* chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(40,c,4)))){
C_save_and_reclaim((void *)f_17843,c,av);}
a=C_alloc(40);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_FALSE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_END_OF_LIST;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_END_OF_LIST;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17874,tmp=(C_word)a,a+=2,tmp));
t19=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17908,a[2]=t15,a[3]=t17,tmp=(C_word)a,a+=4,tmp));
t20=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18038,a[2]=t9,a[3]=t17,a[4]=t11,a[5]=t5,a[6]=t13,a[7]=t7,a[8]=t3,a[9]=t15,tmp=(C_word)a,a+=10,tmp));
t21=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19109,a[2]=t5,a[3]=t7,a[4]=t9,a[5]=t11,a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1989: validate */
t22=((C_word*)t17)[1];
f_18038(t22,t21,t2,C_a_i_list(&a,1,C_SCHEME_FALSE));}

/* loop in k18570 in k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17852(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_17852,3,t0,t1,t2);}
a=C_alloc(4);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17870,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1835: loop */
t7=t5;
t8=C_u_i_cdr(t2);
t1=t7;
t2=t8;
goto loop;}}

/* k17868 in loop in k18570 in k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17870(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_17870,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* memq* in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17874(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_17874,3,t1,t2,t3);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17880,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(
  f_17880(t4,t3)
);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* loop in memq* in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_17880(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;
loop:{}
t2=C_i_pairp(t1);
if(C_truep(C_i_not(t2))){
return(C_SCHEME_FALSE);}
else{
t3=C_i_car(t1);
t4=C_eqp(t3,((C_word*)t0)[2]);
if(C_truep(t4)){
return(t1);}
else{
t6=C_u_i_cdr(t1);
t1=t6;
goto loop;}}}

/* validate-llist in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_17908(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_17908,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_symbolp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=lf[458];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=C_eqp(lf[365],t4);
t6=(C_truep(t5)?t5:C_eqp(lf[459],C_u_i_car(t2)));
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17939,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1847: validate-llist */
t12=t7;
t13=C_u_i_cdr(t2);
t1=t12;
t2=t13;
goto loop;}
else{
t7=C_eqp(lf[366],C_u_i_car(t2));
t8=(C_truep(t7)?t7:C_eqp(lf[460],C_u_i_car(t2)));
if(C_truep(t8)){
if(C_truep(C_i_nullp(C_u_i_cdr(t2)))){
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=lf[461];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_i_pairp(C_u_i_cdr(t2));
if(C_truep(C_i_not(t9))){
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17971,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1854: validate */
t11=((C_word*)((C_word*)t0)[3])[1];
f_18038(t11,t10,C_i_cadr(t2),C_SCHEME_END_OF_LIST);}}}
else{
t9=C_eqp(lf[462],C_u_i_car(t2));
if(C_truep(t9)){
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=lf[463];
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17998,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1858: validate */
t11=((C_word*)((C_word*)t0)[3])[1];
f_18038(t11,t10,C_u_i_car(t2),C_SCHEME_END_OF_LIST);}}}}}}}

/* k17937 in validate-llist in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17939(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_17939,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_cons(&a,2,lf[365],t1):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k17969 in validate-llist in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17971(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_17971,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_list(&a,2,lf[366],t1):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k17996 in validate-llist in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_17998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17998,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18001,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1859: validate-llist */
t3=((C_word*)((C_word*)t0)[3])[1];
f_17908(t3,t2,C_u_i_cdr(((C_word*)t0)[4]));}

/* k17999 in k17996 in validate-llist in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18001,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(((C_word*)t0)[3])?(C_truep(t1)?C_a_i_cons(&a,2,((C_word*)t0)[3],t1):C_SCHEME_FALSE):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18038(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,3)))){
C_save_and_reclaim_args((void *)trf_18038,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t5=C_i_nullp(t3);
t6=(C_truep(t5)?C_SCHEME_TRUE:C_i_car(t3));
if(C_truep(C_i_memq(((C_word*)t4)[1],lf[19]))){
t7=((C_word*)t4)[1];
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
if(C_truep(C_i_memq(((C_word*)t4)[1],lf[21]))){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=((C_word*)t4)[1];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
if(C_truep(C_i_memq(((C_word*)t4)[1],lf[464]))){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_a_i_list(&a,2,lf[53],((C_word*)t4)[1]);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(((C_word*)t4)[1],lf[465]);
if(C_truep(t7)){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=lf[466];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=C_eqp(((C_word*)t4)[1],lf[467]);
if(C_truep(t8)){
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_eqp(((C_word*)t4)[1],lf[468]);
if(C_truep(t9)){
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=lf[36];
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t10=C_eqp(((C_word*)t4)[1],lf[469]);
if(C_truep(t10)){
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=lf[470];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t11=C_eqp(((C_word*)t4)[1],lf[471]);
if(C_truep(t11)){
t12=t1;{
C_word av2[2];
av2[0]=t12;
av2[1]=lf[472];
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t12=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_18096,a[2]=t1,a[3]=t4,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=t6,a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[8],a[12]=((C_word*)t0)[9],tmp=(C_word)a,a+=13,tmp);
if(C_truep(C_i_symbolp(((C_word*)t4)[1]))){
/* scrutinizer.scm:1870: ##sys#get */
t13=*((C_word*)lf[477]+1);{
C_word av2[4];
av2[0]=t13;
av2[1]=t12;
av2[2]=((C_word*)t4)[1];
av2[3]=lf[478];
((C_proc)(void*)(*((C_word*)t13+1)))(4,av2);}}
else{
t13=t12;{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
f_18096(2,av2);}}}}}}}}}}}

/* k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_18096,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_i_pairp(((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(C_i_not(t2))){
if(C_truep(C_i_memq(((C_word*)((C_word*)t0)[3])[1],((C_word*)((C_word*)t0)[4])[1]))){
t3=((C_word*)((C_word*)t0)[3])[1];
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=C_i_car(((C_word*)((C_word*)t0)[3])[1]);
t4=C_eqp(lf[70],t3);
if(C_truep(t4)){
t5=C_i_length(((C_word*)((C_word*)t0)[3])[1]);
t6=C_eqp(C_fix(2),t5);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18130,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t8=((C_word*)((C_word*)t0)[3])[1];
/* scrutinizer.scm:1876: validate */
t9=((C_word*)((C_word*)t0)[5])[1];
f_18038(t9,t7,C_i_cadr(t8),C_SCHEME_END_OF_LIST);}
else{
t7=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
t5=C_i_car(((C_word*)((C_word*)t0)[3])[1]);
t6=C_eqp(lf[29],t5);
if(C_truep(t6)){
t7=C_i_length(((C_word*)((C_word*)t0)[3])[1]);
t8=C_eqp(C_fix(3),t7);
if(C_truep(t8)){
t9=((C_word*)((C_word*)t0)[3])[1];
t10=C_i_cadr(t9);
if(C_truep(C_i_listp(t10))){
t11=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18162,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1880: chicken.base#call/cc */
t12=*((C_word*)lf[168]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t12;
av2[1]=((C_word*)t0)[2];
av2[2]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}
else{
t11=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}
else{
t9=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t7=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_18312,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
t8=C_i_car(((C_word*)((C_word*)t0)[3])[1]);
t9=C_eqp(lf[124],t8);
if(C_truep(t9)){
t10=C_i_cdr(((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(C_i_pairp(t10))){
t11=((C_word*)((C_word*)t0)[3])[1];
t12=C_i_cadr(t11);
if(C_truep(C_i_symbolp(t12))){
t13=C_i_cddr(((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(C_i_nullp(t13))){
t14=((C_word*)((C_word*)t0)[3])[1];
t15=t7;
f_18312(t15,C_i_cadr(t14));}
else{
t14=t7;
f_18312(t14,C_SCHEME_FALSE);}}
else{
t13=t7;
f_18312(t13,C_SCHEME_FALSE);}}
else{
t11=t7;
f_18312(t11,C_SCHEME_FALSE);}}
else{
t10=t7;
f_18312(t10,C_SCHEME_FALSE);}}}}}}

/* k18128 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_18130,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,2,lf[70],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18162(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_18162,c,av);}
a=C_alloc(29);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_18167,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=t2,tmp=(C_word)a,a+=9,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18219,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t9=((C_word*)((C_word*)t0)[4])[1];
t10=C_i_cadr(t9);
t11=C_i_check_list_2(t10,lf[6]);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18266,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18268,a[2]=t6,a[3]=t14,a[4]=t8,a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_18268(t16,t12,t10);}

/* k18165 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18167(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_18167,c,av);}
a=C_alloc(15);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18171,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18182,a[2]=t3,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18184,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t6=((C_word*)((C_word*)t0)[4])[1];
/* scrutinizer.scm:1893: filter-map */
f_7471(t4,t5,C_i_cadr(t6));}

/* k18169 in k18165 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18171,c,av);}
a=C_alloc(3);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)((C_word*)t0)[3])[1];
/* scrutinizer.scm:1902: validate */
t4=((C_word*)((C_word*)t0)[4])[1];
f_18038(t4,((C_word*)t0)[5],C_i_caddr(t3),C_a_i_list(&a,1,((C_word*)t0)[6]));}

/* k18180 in k18165 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_18182,c,av);}
/* scrutinizer.scm:1893: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a18183 in k18165 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18184(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_18184,c,av);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18200,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1897: validate */
t5=((C_word*)((C_word*)t0)[3])[1];
f_18038(t5,t4,C_i_cadr(t2),C_SCHEME_END_OF_LIST);}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18198 in a18183 in k18165 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_18200,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18203,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t1)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list2(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* scrutinizer.scm:1898: return */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k18201 in k18198 in a18183 in k18165 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_18203,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list2(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* g3838 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18219(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,2)))){
C_save_and_reclaim_args((void *)trf_18219,3,t0,t1,t2);}
if(C_truep(C_i_symbolp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_listp(t2))){
t3=C_eqp(C_fix(2),C_u_i_length(t2));
if(C_truep(t3)){
t4=C_i_car(t2);
if(C_truep(C_i_symbolp(t4))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* scrutinizer.scm:1889: return */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}
else{
/* scrutinizer.scm:1889: return */
t4=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}
else{
/* scrutinizer.scm:1889: return */
t3=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t3;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}

/* k18264 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18266(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_18266,c,av);}
/* scrutinizer.scm:1883: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop3832 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18268(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_18268,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18293,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1883: g3838 */
t4=((C_word*)t0)[4];
f_18219(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18291 in map-loop3832 in a18161 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_18293,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_18268(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18312(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,3)))){
C_save_and_reclaim_args((void *)trf_18312,2,t0,t1);}
a=C_alloc(16);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18316,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1862: g3874 */
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=(
/* scrutinizer.scm:1862: g3874 */
  f_18316(C_a_i(&a,3),t2,t1)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
t3=C_eqp(lf[28],t2);
if(C_truep(t3)){
if(C_truep(C_i_listp(((C_word*)((C_word*)t0)[4])[1]))){
t4=C_i_cdr(((C_word*)((C_word*)t0)[4])[1]);
t5=C_i_nullp(t4);
if(C_truep(C_i_not(t5))){
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=C_i_cdr(((C_word*)((C_word*)t0)[4])[1]);
t11=C_i_check_list_2(t10,lf[6]);
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18360,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18371,a[2]=t8,a[3]=t14,a[4]=((C_word*)t0)[5],a[5]=t9,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_18371(t16,t12,t10);}
else{
t6=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t4=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
t5=C_eqp(lf[53],t4);
if(C_truep(t5)){
t6=C_i_length(((C_word*)((C_word*)t0)[4])[1]);
t7=C_eqp(C_fix(2),t6);
if(C_truep(t7)){
t8=((C_word*)((C_word*)t0)[4])[1];
t9=C_i_cadr(t8);
if(C_truep(C_i_symbolp(t9))){
t10=((C_word*)((C_word*)t0)[4])[1];
t11=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t10=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}
else{
t8=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}
else{
t6=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
t7=C_eqp(lf[60],t6);
if(C_truep(t7)){
t8=C_i_length(((C_word*)((C_word*)t0)[4])[1]);
t9=C_eqp(C_fix(2),t8);
if(C_truep(t9)){
t10=((C_word*)((C_word*)t0)[4])[1];
t11=C_i_cadr(t10);
t12=C_i_symbolp(t11);
t13=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t13;
av2[1]=(C_truep(t12)?((C_word*)((C_word*)t0)[4])[1]:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t10=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}
else{
t8=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
t9=C_eqp(lf[373],t8);
if(C_truep(t9)){
t10=C_i_length(((C_word*)((C_word*)t0)[4])[1]);
t11=C_eqp(C_fix(3),t10);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18480,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t13=((C_word*)((C_word*)t0)[4])[1];
/* scrutinizer.scm:1924: validate */
t14=((C_word*)((C_word*)t0)[5])[1];
f_18038(t14,t12,C_i_caddr(t13),C_SCHEME_END_OF_LIST);}
else{
t12=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}
else{
t10=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_18549,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:1929: memq* */
f_17874(t10,lf[474],((C_word*)((C_word*)t0)[4])[1]);}}}}}}

/* g3874 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_18316(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;{}
if(C_truep(C_i_memq(t1,((C_word*)((C_word*)t0)[2])[1]))){
return(t1);}
else{
t2=C_a_i_cons(&a,2,t1,((C_word*)((C_word*)t0)[2])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
return(t1);}}

/* k18358 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18360(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18360,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18366,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1916: every */
f_7187(t2,*((C_word*)lf[397]+1),t1);}

/* k18364 in k18358 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18366,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_cons(&a,2,lf[28],((C_word*)t0)[3]):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop3883 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18371(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_18371,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18396,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1915: g3889 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_18038(t4,t3,C_slot(t2,C_fix(0)),C_SCHEME_END_OF_LIST);}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18394 in map-loop3883 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18396(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_18396,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_18371(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k18478 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18480(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_18480,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18510,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_pairp(t1))){
t3=C_eqp(C_u_i_car(t1),lf[53]);
t4=t2;
f_18510(t4,(C_truep(t3)?t3:C_i_memq(t1,lf[19])));}
else{
t3=t2;
f_18510(t3,C_i_memq(t1,lf[19]));}}

/* k18508 in k18478 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18510(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_18510,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_i_cadr(t2);
if(C_truep(C_i_listp(t3))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18522,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=((C_word*)((C_word*)t0)[2])[1];
/* scrutinizer.scm:1927: every */
f_7187(t4,*((C_word*)lf[473]+1),C_i_cadr(t5));}
else{
t4=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k18520 in k18508 in k18478 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18522(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_18522,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_i_cadr(t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list3(&a,3,lf[373],t3,((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_18549,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_18552,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(t1)){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
f_18552(2,av2);}}
else{
/* scrutinizer.scm:1929: memq* */
f_17874(t2,lf[476],((C_word*)((C_word*)t0)[4])[1]);}}

/* k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18552(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_18552,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18556,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1862: g3934 */
t3=t2;
f_18556(t3,((C_word*)t0)[8],t1);}
else{
t2=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
if(C_truep((C_truep(C_eqp(t2,lf[360]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[362]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
if(C_truep(C_i_listp(((C_word*)((C_word*)t0)[4])[1]))){
t3=C_i_length(((C_word*)((C_word*)t0)[4])[1]);
t4=C_eqp(C_fix(2),t3);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18698,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
t6=((C_word*)((C_word*)t0)[4])[1];
/* scrutinizer.scm:1952: validate */
t7=((C_word*)((C_word*)t0)[3])[1];
f_18038(t7,t5,C_i_cadr(t6),C_SCHEME_END_OF_LIST);}
else{
t5=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
if(C_truep((C_truep(C_eqp(t3,lf[51]))?C_SCHEME_TRUE:(C_truep(C_eqp(t3,lf[48]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
if(C_truep(C_i_listp(((C_word*)((C_word*)t0)[4])[1]))){
t4=C_i_cdr(((C_word*)((C_word*)t0)[4])[1]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18740,a[2]=((C_word*)t0)[4],a[3]=t6,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_18740(t8,((C_word*)t0)[8],t4,C_SCHEME_END_OF_LIST);}
else{
t4=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
t5=C_eqp(lf[49],t4);
if(C_truep(t5)){
t6=C_i_length(((C_word*)((C_word*)t0)[4])[1]);
t7=C_eqp(C_fix(3),t6);
if(C_truep(t7)){
t8=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t9=t8;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=((C_word*)t10)[1];
t12=C_i_cdr(((C_word*)((C_word*)t0)[4])[1]);
t13=C_i_check_list_2(t12,lf[6]);
t14=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18808,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18819,a[2]=t10,a[3]=t16,a[4]=((C_word*)t0)[3],a[5]=t11,tmp=(C_word)a,a+=6,tmp));
t18=((C_word*)t16)[1];
f_18819(t18,t14,t12);}
else{
t8=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}
else{
t6=C_i_car(((C_word*)((C_word*)t0)[4])[1]);
t7=C_eqp(lf[85],t6);
if(C_truep(t7)){
t8=C_i_cdr(((C_word*)((C_word*)t0)[4])[1]);
if(C_truep(C_i_pairp(t8))){
t9=C_i_cadr(((C_word*)((C_word*)t0)[4])[1]);
t10=C_i_symbolp(t9);
t11=(C_truep(t10)?C_i_cadr(((C_word*)((C_word*)t0)[4])[1]):((C_word*)t0)[9]);
t12=C_i_cadr(((C_word*)((C_word*)t0)[4])[1]);
t13=C_i_symbolp(t12);
t14=(C_truep(t13)?C_i_cddr(((C_word*)((C_word*)t0)[4])[1]):C_i_cdr(((C_word*)((C_word*)t0)[4])[1]));
if(C_truep(C_i_pairp(t14))){
if(C_truep(C_i_listp(C_u_i_car(t14)))){
t15=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18889,a[2]=t14,a[3]=((C_word*)t0)[8],a[4]=t11,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1973: validate-llist */
t16=((C_word*)((C_word*)t0)[10])[1];
f_17908(t16,t15,C_u_i_car(t14));}
else{
t15=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t15;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}}
else{
t15=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t15;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}}
else{
t9=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t8=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}}}}

/* g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18556(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_18556,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_car(t2);
t4=C_eqp(lf[474],t3);
t5=C_i_not(((C_word*)t0)[2]);
t6=(C_truep(t5)?t5:C_i_not(t4));
t7=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18569,a[2]=t6,a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[2])){
t8=t7;
f_18569(t8,C_SCHEME_UNDEFINED);}
else{
t8=C_set_block_item(((C_word*)t0)[7],0,t4);
t9=t7;
f_18569(t9,t8);}}

/* k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18569(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_18569,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_18572,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:1934: memq* */
f_17874(t2,lf[475],((C_word*)t0)[3]);}

/* k18570 in k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_18572,c,av);}
a=C_alloc(12);
if(C_truep(C_i_not(t1))){
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18596,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t3=((C_word*)((C_word*)t0)[7])[1];
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17852,a[2]=((C_word*)t0)[3],a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_17852(t7,t2,t3);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_18604,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[4],a[7]=t1,a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
t3=C_i_length(((C_word*)((C_word*)t0)[7])[1]);
t4=C_eqp(C_fix(5),t3);
if(C_truep(t4)){
t5=C_i_cdr(((C_word*)((C_word*)t0)[7])[1]);
t6=C_eqp(((C_word*)t0)[3],t5);
t7=t2;
f_18604(t7,(C_truep(t6)?C_eqp(t1,C_i_cdddr(((C_word*)((C_word*)t0)[7])[1])):C_SCHEME_FALSE));}
else{
t5=t2;
f_18604(t5,C_SCHEME_FALSE);}}}

/* k18594 in k18570 in k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18596(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_18596,c,av);}
a=C_alloc(9);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
t4=C_a_i_cons(&a,2,lf[85],t3);
/* scrutinizer.scm:1937: validate */
t5=((C_word*)((C_word*)t0)[3])[1];
f_18038(t5,((C_word*)t0)[4],t4,C_a_i_list(&a,1,((C_word*)t0)[5]));}

/* k18602 in k18570 in k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18604(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,0,3)))){
C_save_and_reclaim_args((void *)trf_18604,2,t0,t1);}
a=C_alloc(23);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18608,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=((C_word*)((C_word*)t0)[2])[1];
t4=C_i_car(t3);
t5=C_a_i_list(&a,1,t4);
t6=((C_word*)((C_word*)t0)[2])[1];
t7=C_i_caddr(t6);
t8=C_a_i_list(&a,3,lf[85],t5,t7);
/* scrutinizer.scm:1943: validate */
t9=((C_word*)((C_word*)t0)[6])[1];
f_18038(t9,t2,t8,C_a_i_list(&a,1,((C_word*)t0)[8]));}
else{
t2=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k18606 in k18602 in k18570 in k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18608(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_18608,c,av);}
a=C_alloc(6);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18619,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1946: validate */
t4=((C_word*)((C_word*)t0)[6])[1];
f_18038(t4,t3,C_i_cadr(((C_word*)t0)[7]),C_SCHEME_END_OF_LIST);}

/* k18617 in k18606 in k18602 in k18570 in k18567 in g3934 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18619(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18619,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[2])[1],t1);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,t2);
if(C_truep(((C_word*)t0)[4])){
t4=((C_word*)((C_word*)t0)[2])[1];
t5=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k18696 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_18698,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_car(((C_word*)((C_word*)t0)[2])[1]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,2,t2,t1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* loop in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18740(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_18740,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t4=C_i_car(((C_word*)((C_word*)t0)[2])[1]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18758,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1957: scheme#reverse */
t6=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18761,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1958: validate */
t5=((C_word*)((C_word*)t0)[4])[1];
f_18038(t5,t4,C_i_car(t2),C_SCHEME_END_OF_LIST);}}

/* k18756 in loop in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18758(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18758,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k18759 in loop in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18761(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_18761,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18765,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:1957: g3980 */
t3=t2;
f_18765(t3,((C_word*)t0)[5],t1);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g3980 in k18759 in loop in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18765(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_18765,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_i_cdr(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,t2,((C_word*)t0)[3]);
/* scrutinizer.scm:1959: loop */
t5=((C_word*)((C_word*)t0)[4])[1];
f_18740(t5,t1,t3,t4);}

/* k18806 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18808,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18814,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1964: every */
f_7187(t2,*((C_word*)lf[397]+1),t1);}

/* k18812 in k18806 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18814,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_cons(&a,2,lf[49],((C_word*)t0)[3]):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop3988 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18819(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_18819,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18844,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1963: g3994 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_18038(t4,t3,C_slot(t2,C_fix(0)),C_SCHEME_END_OF_LIST);}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18842 in map-loop3988 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18844(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_18844,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_18819(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_18889,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18898,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:1975: every */
f_7187(t2,*((C_word*)lf[397]+1),t1);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k18896 in k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18898(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_18898,c,av);}
a=C_alloc(22);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18902,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t4=C_eqp(lf[54],t2);
if(C_truep(t4)){
t5=t3;
f_18902(t5,t2);}
else{
if(C_truep(C_i_listp(t2))){
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18944,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18952,a[2]=t7,a[3]=t11,a[4]=((C_word*)t0)[7],a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_18952(t13,t9,t2);}
else{
t5=t3;
f_18902(t5,C_SCHEME_FALSE);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k18900 in k18896 in k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18902(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_18902,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18912,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[3])){
t3=C_i_not(((C_word*)t0)[4]);
t4=(C_truep(t3)?C_a_i_list1(&a,1,((C_word*)t0)[3]):C_SCHEME_END_OF_LIST);
t5=C_a_i_cons(&a,2,((C_word*)t0)[5],t1);
/* scrutinizer.scm:1984: ##sys#append */
t6=*((C_word*)lf[405]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t2;
av2[2]=t4;
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_a_i_cons(&a,2,((C_word*)t0)[5],t1);
/* scrutinizer.scm:1984: ##sys#append */
t4=*((C_word*)lf[405]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t2;
av2[2]=C_SCHEME_END_OF_LIST;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k18910 in k18900 in k18896 in k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18912(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18912,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[85],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k18942 in k18896 in k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18944,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18950,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:1981: every */
f_7187(t2,*((C_word*)lf[397]+1),t1);}

/* k18948 in k18942 in k18896 in k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18950(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18950,c,av);}
t2=((C_word*)t0)[2];
f_18902(t2,(C_truep(t1)?((C_word*)t0)[3]:C_SCHEME_FALSE));}

/* map-loop4030 in k18896 in k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_18952(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_18952,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18977,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1980: g4036 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_18038(t4,t3,C_slot(t2,C_fix(0)),C_SCHEME_END_OF_LIST);}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18975 in map-loop4030 in k18896 in k18887 in k18550 in k18547 in k18310 in k18094 in validate in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_18977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_18977,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_18952(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19109(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_19109,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19113,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1989: g4061 */
t3=t2;
f_19113(t3,((C_word*)t0)[6],t1);}
else{
/* scrutinizer.scm:2005: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[6];
av2[2]=C_SCHEME_FALSE;
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_FALSE;
C_values(5,av2);}}}

/* g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19113(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,0,3)))){
C_save_and_reclaim_args((void *)trf_19113,3,t0,t1,t2);}
a=C_alloc(23);
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19117,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t1,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[4])[1]))){
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19152,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19176,a[2]=t3,a[3]=t4,a[4]=t7,a[5]=t9,a[6]=t8,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:1998: delete-duplicates */
f_7382(t10,((C_word*)((C_word*)t0)[4])[1],*((C_word*)lf[375]+1));}
else{
t5=t4;
f_19117(t5,C_SCHEME_UNDEFINED);}}

/* k19115 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19117(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19117,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19120,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2000: simplify-type */
f_13568(t2,((C_word*)((C_word*)t0)[3])[1]);}

/* k19118 in k19115 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19120(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19120,c,av);}
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=C_i_car(((C_word*)((C_word*)t0)[2])[1]);
t3=C_eqp(t2,((C_word*)((C_word*)t0)[3])[1]);
if(C_truep(t3)){
/* scrutinizer.scm:2001: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=C_i_cdr(((C_word*)((C_word*)t0)[2])[1]);
av2[4]=((C_word*)((C_word*)t0)[5])[1];
C_values(5,av2);}}
else{
/* scrutinizer.scm:2001: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)((C_word*)t0)[5])[1];
C_values(5,av2);}}}
else{
/* scrutinizer.scm:2001: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)((C_word*)t0)[5])[1];
C_values(5,av2);}}}

/* g4075 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19152(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_19152,3,t0,t1,t2);}
a=C_alloc(12);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19156,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19169,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19173,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1995: chicken.syntax#strip-syntax */
t6=*((C_word*)lf[480]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k19154 in g4075 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19156(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19156,c,av);}
t2=C_i_assq(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?t2:((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k19167 in g4075 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19169,c,av);}
/* scrutinizer.scm:1995: chicken.plist#put! */
t2=*((C_word*)lf[479]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[377];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k19171 in g4075 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19173(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19173,c,av);}
/* scrutinizer.scm:1995: scheme#symbol->string */
t2=*((C_word*)lf[443]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k19174 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19176(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_19176,c,av);}
a=C_alloc(12);
t2=C_i_check_list_2(t1,lf[6]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19182,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19184,a[2]=((C_word*)t0)[4],a[3]=t5,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_19184(t7,t3,t1);}

/* k19180 in k19174 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_19182,c,av);}
a=C_alloc(9);
t2=C_a_i_list(&a,3,lf[29],t1,((C_word*)((C_word*)t0)[2])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=((C_word*)t0)[3];
f_19117(t4,t3);}

/* map-loop4069 in k19174 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19184(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19184,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19209,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:1994: g4075 */
t4=((C_word*)t0)[4];
f_19152(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19207 in map-loop4069 in k19174 in g4061 in k19107 in chicken.compiler.scrutinizer#validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19209(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19209,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_19184(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* chicken.compiler.scrutinizer#check-and-validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19224(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_19224,c,av);}
a=C_alloc(8);
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?C_SCHEME_FALSE:C_get_rest_arg(c,4,av,4,t0));
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19233,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19243,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2008: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t6;
av2[3]=t7;
C_call_with_values(4,av2);}}

/* a19232 in chicken.compiler.scrutinizer#check-and-validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_19233,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19241,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2008: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[480]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k19239 in a19232 in chicken.compiler.scrutinizer#check-and-validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19241,c,av);}
/* scrutinizer.scm:2008: validate-type */
t2=*((C_word*)lf[408]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a19242 in chicken.compiler.scrutinizer#check-and-validate-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19243(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19243,c,av);}
if(C_truep(t2)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* scrutinizer.scm:2010: chicken.base#error */
t5=*((C_word*)lf[482]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[483];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_19258,c,av);}
a=C_alloc(24);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19261,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19273,a[2]=t2,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t10=C_i_check_list_2(t3,lf[6]);
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19501,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19503,a[2]=t7,a[3]=t13,a[4]=t9,a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t15=((C_word*)t13)[1];
f_19503(t15,t11,t3);}

/* fail in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19261(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_19261,3,t0,t1,t2);}
/* scrutinizer.scm:2014: chicken.base#error */
t3=*((C_word*)lf[482]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[484];
av2[3]=t2;
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19273(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,0,3)))){
C_save_and_reclaim_args((void *)trf_19273,3,t0,t1,t2);}
a=C_alloc(23);
t3=C_i_listp(t2);
t4=(C_truep(t3)?C_i_listp(C_i_car(t2)):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19284,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t10=C_i_car(t2);
t11=C_i_check_list_2(t10,lf[6]);
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19312,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19450,a[2]=t7,a[3]=t14,a[4]=t9,a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_19450(t16,t12,t10);}
else{
/* scrutinizer.scm:2054: fail */
t5=((C_word*)t0)[3];
f_19261(t5,t1,t2);}}

/* g4172 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19284(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,5)))){
C_save_and_reclaim_args((void *)trf_19284,3,t0,t1,t2);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19290,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19296,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2031: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=t1;
av2[2]=t3;
av2[3]=t4;
C_call_with_values(4,av2);}}

/* a19289 in g4172 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19290,c,av);}
/* scrutinizer.scm:2031: validate-type */
t2=*((C_word*)lf[408]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a19295 in g4172 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_19296,c,av);}
if(C_truep(t2)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* scrutinizer.scm:2033: chicken.base#error */
t5=*((C_word*)lf[482]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[485];
av2[3]=((C_word*)t0)[2];
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}}

/* k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19312(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_19312,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19315,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19448,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2036: append-map */
f_7017(t3,lf[162],t1,C_SCHEME_END_OF_LIST);}

/* k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_19315,c,av);}
a=C_alloc(26);
t2=C_i_length(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19325,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
switch(t2){
case C_fix(2):
t4=C_i_cdr(((C_word*)t0)[2]);
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}
case C_fix(3):
t4=C_i_cadr(((C_word*)t0)[2]);
if(C_truep(C_i_listp(t4))){
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19351,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t10=C_i_cadr(((C_word*)t0)[2]);
t11=C_i_check_list_2(t10,lf[6]);
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19379,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19385,a[2]=t7,a[3]=t14,a[4]=t9,a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_19385(t16,t12,t10);}
else{
t5=C_i_cadr(((C_word*)t0)[2]);
t6=C_eqp(lf[54],t5);
if(C_truep(t6)){
t7=C_i_cdr(((C_word*)t0)[2]);
t8=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t7);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
/* scrutinizer.scm:2052: fail */
t7=((C_word*)t0)[6];
f_19261(t7,t3,((C_word*)t0)[2]);}}
default:
/* scrutinizer.scm:2053: fail */
t4=((C_word*)t0)[6];
f_19261(t4,t3,((C_word*)t0)[2]);}}

/* k19323 in k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19325(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_19325,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* g4225 in k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19351(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,5)))){
C_save_and_reclaim_args((void *)trf_19351,3,t0,t1,t2);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19357,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19363,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2045: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=t1;
av2[2]=t3;
av2[3]=t4;
C_call_with_values(4,av2);}}

/* a19356 in g4225 in k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19357,c,av);}
/* scrutinizer.scm:2045: validate-type */
t2=*((C_word*)lf[408]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a19362 in g4225 in k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19363(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_19363,c,av);}
if(C_truep(t2)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* scrutinizer.scm:2047: chicken.base#error */
t5=*((C_word*)lf[482]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[486];
av2[3]=((C_word*)t0)[2];
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}}

/* k19377 in k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_19379,c,av);}
a=C_alloc(6);
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,t1,t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* map-loop4219 in k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19385(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19385,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19410,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2044: g4225 */
t4=((C_word*)t0)[4];
f_19351(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19408 in map-loop4219 in k19313 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19410,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_19385(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k19446 in k19310 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19448(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19448,c,av);}
/* scrutinizer.scm:2036: unzip1 */
t2=lf[12];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
f_7536(3,av2);}}

/* map-loop4166 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19450(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19450,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19475,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2030: g4172 */
t4=((C_word*)t0)[4];
f_19284(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19473 in map-loop4166 in g4150 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19475(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19475,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_19450(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k19499 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19501(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19501,c,av);}
/* scrutinizer.scm:2015: chicken.compiler.support#mark-variable */
t2=*((C_word*)lf[234]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[163];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop4144 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19503(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19503,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19528,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2027: g4150 */
t4=((C_word*)t0)[4];
f_19273(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19526 in map-loop4144 in chicken.compiler.scrutinizer#install-specializations in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19528(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19528,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_19503(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* chicken.compiler.scrutinizer#canonicalize-list-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19537(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_19537,2,t1,t2);}
a=C_alloc(9);
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=C_eqp(lf[49],t4);
if(C_truep(t5)){
t6=C_i_cadr(t2);
t7=C_i_caddr(t2);
t8=C_a_i_list1(&a,1,t6);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19565,a[2]=t10,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t12=((C_word*)t10)[1];
f_19565(t12,t1,t7,t8);}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}

/* rec in chicken.compiler.scrutinizer#canonicalize-list-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19565(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_19565,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_eqp(lf[32],t2);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19579,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2070: scheme#reverse */
t6=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_i_pairp(t2);
t6=(C_truep(t5)?C_eqp(lf[49],C_i_car(t2)):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=C_i_caddr(t2);
t8=C_i_cadr(t2);
t9=C_a_i_cons(&a,2,t8,t3);
/* scrutinizer.scm:2072: rec */
t12=t1;
t13=t7;
t14=t9;
t1=t12;
t2=t13;
t3=t14;
goto loop;}
else{
t7=C_i_pairp(t2);
t8=(C_truep(t7)?C_eqp(lf[48],C_i_car(t2)):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19613,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19617,a[2]=t9,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2074: scheme#reverse */
t11=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}}}

/* k19577 in rec in chicken.compiler.scrutinizer#canonicalize-list-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_19579,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[48],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k19611 in rec in chicken.compiler.scrutinizer#canonicalize-list-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_19613,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[48],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k19615 in rec in chicken.compiler.scrutinizer#canonicalize-list-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19617,c,av);}
/* scrutinizer.scm:2074: ##sys#append */
t2=*((C_word*)lf[405]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.compiler.scrutinizer#strip-namespace in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19651(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_19651,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19655,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2082: scheme#symbol->string */
t4=*((C_word*)lf[443]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19653 in chicken.compiler.scrutinizer#strip-namespace in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_19655,c,av);}
a=C_alloc(8);
t2=C_block_size(t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19663,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_19663(t6,((C_word*)t0)[3],C_fix(0));}

/* loop in k19653 in chicken.compiler.scrutinizer#strip-namespace in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19663(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_19663,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_eqp(C_subchar(((C_word*)t0)[4],t2),C_make_character(35));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19683,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2087: ##sys#substring */
t6=*((C_word*)lf[487]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
av2[3]=C_fixnum_plus(t2,C_fix(1));
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
/* scrutinizer.scm:2088: loop */
t7=t1;
t8=C_fixnum_plus(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}}}

/* k19681 in loop in k19653 in chicken.compiler.scrutinizer#strip-namespace in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19683,c,av);}
/* scrutinizer.scm:2087: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
C_string_to_symbol(3,av2);}}

/* k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19699(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,6)))){
C_save_and_reclaim((void *)f_19699,c,av);}
a=C_alloc(14);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_19701,tmp=(C_word)a,a+=2,tmp));
t7=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19800,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19855,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2141: ##sys#put! */
t9=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[657];
av2[3]=lf[275];
av2[4]=((C_word*)t5)[1];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* known-length-vector-index in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_19701(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_19701,5,t1,t2,t3,t4,t5);}
a=C_alloc(7);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19705,a[2]=t5,a[3]=t3,a[4]=t1,a[5]=t4,a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2115: chicken.compiler.support#node-subexpressions */
t7=*((C_word*)lf[87]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k19703 in known-length-vector-index in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(35,c,2)))){
C_save_and_reclaim((void *)f_19705,c,av);}
a=C_alloc(35);
if(C_truep(t1)){
t2=C_i_length(t1);
t3=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
if(C_truep(C_i_nequalp(t2,t3))){
t4=C_i_cadr(((C_word*)t0)[3]);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26845,a[2]=t1,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19766 in k19778 in k19782 */
static void C_ccall f_19768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19768,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k19778 in k19782 */
static void C_ccall f_19780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_19780,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
if(C_truep(t2)){
if(C_truep(C_fixnump(t2))){
t3=C_i_length(C_u_i_cdr(((C_word*)t0)[2]));
t4=C_i_greater_or_equalp(t2,C_fix(0));
t5=(C_truep(t4)?C_i_lessp(t2,t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19768,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2128: r-index-out-of-range */
f_22249(t6,((C_word*)t0)[4],((C_word*)t0)[5],t2,t3,lf[489]);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19782 */
static void C_ccall f_19784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19784,c,av);}
a=C_alloc(6);
t2=C_eqp(lf[124],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19780,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2122: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* vector-ref-result-type in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_19800,c,av);}
a=C_alloc(6);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19804,a[2]=t3,a[3]=t1,a[4]=t5,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2134: known-length-vector-index */
f_19701(t6,t2,t3,t4,C_fix(2));}

/* k19802 in vector-ref-result-type in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19804,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_cadr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26850,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19823 in k19846 */
static void C_ccall f_19825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_19825,c,av);}
a=C_alloc(3);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_i_list_ref(t2,((C_word*)t0)[3]);
t4=C_a_i_list1(&a,1,t3);
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?t4:((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k19846 */
static void C_ccall f_19848(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_19848,c,av);}
a=C_alloc(21);
t2=C_i_cadr(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=C_a_i_list(&a,2,lf[124],((C_word*)t0)[3]);
t5=C_a_i_list(&a,3,lf[490],t2,t4);
/* scrutinizer.scm:2137: mutate-node! */
f_17510(t3,((C_word*)t0)[6],t5);}
else{
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_19855,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19858,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2142: ##sys#put! */
t3=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[656];
av2[3]=lf[275];
av2[4]=((C_word*)((C_word*)t0)[4])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_19858,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19861,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23480,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2144: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[655];
av2[3]=lf[275];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_19861(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_19861,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_20046,tmp=(C_word)a,a+=2,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20141,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23462,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23464,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2224: list+index-call-result-type-special-case */
f_20046(t4,t5);}

/* a19913 in k20123 in k20127 */
static void C_ccall f_19914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_19914,c,av);}
a=C_alloc(5);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6984,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_6984(t6,t1,((C_word*)t0)[3],C_SCHEME_END_OF_LIST,t2);}

/* a19923 in k20123 in k20127 */
static void C_ccall f_19924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_19924,c,av);}
a=C_alloc(6);
t4=C_i_nullp(t2);
t5=(C_truep(t4)?lf[32]:C_a_i_cons(&a,2,lf[48],t2));
t6=C_i_nullp(t3);
t7=(C_truep(t6)?lf[32]:C_a_i_cons(&a,2,lf[48],t3));
/* scrutinizer.scm:2180: k */
t8=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t8;
av2[1]=t1;
av2[2]=t5;
av2[3]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}

/* lp in k20123 in k20127 */
static void C_fcall f_19951(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(32,0,4)))){
C_save_and_reclaim_args((void *)trf_19951,5,t0,t1,t2,t3,t4);}
a=C_alloc(32);
t5=C_eqp(t4,C_fix(0));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19969,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2185: scheme#reverse */
t7=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t6=C_i_pairp(t3);
t7=(C_truep(t6)?C_eqp(C_i_car(t3),lf[49]):C_SCHEME_FALSE);
if(C_truep(t7)){
t8=C_i_cadr(t3);
t9=C_a_i_cons(&a,2,t8,t2);
t10=C_i_caddr(t3);
t11=C_s_a_i_minus(&a,2,t4,C_fix(1));
/* scrutinizer.scm:2188: lp */
t13=t1;
t14=t9;
t15=t10;
t16=t11;
t1=t13;
t2=t14;
t3=t15;
t4=t16;
goto loop;}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}

/* k19967 in lp in k20123 in k20127 */
static void C_ccall f_19969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_19969,c,av);}
a=C_alloc(3);
t2=C_i_nullp(t1);
t3=(C_truep(t2)?lf[32]:C_a_i_cons(&a,2,lf[48],t1));
/* scrutinizer.scm:2185: k */
t4=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=t3;
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* list+index-call-result-type-special-case in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_20046(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,6)))){
C_save_and_reclaim_args((void *)trf_20046,2,t1,t2);}
a=C_alloc(3);
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20048,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_20048 in list+index-call-result-type-special-case in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20048(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_20048,c,av);}
a=C_alloc(8);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20052,a[2]=t1,a[3]=t5,a[4]=t3,a[5]=t4,a[6]=t2,a[7]=((C_word*)t0)[2],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2203: chicken.compiler.support#node-subexpressions */
t7=*((C_word*)lf[87]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k20050 */
static void C_ccall f_20052(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_20052,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20055,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t1)){
t3=C_i_length(t1);
t4=C_eqp(t3,C_fix(3));
if(C_truep(t4)){
t5=C_i_cadr(((C_word*)t0)[4]);
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f26859,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t2,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t7=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20053 in k20050 */
static void C_ccall f_20055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20055,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?t1:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20099 in k20123 in k20127 */
static void C_ccall f_20101(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20101,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20102 in k20123 in k20127 */
static void C_ccall f_20104(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_20104,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?t1:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20110,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
t3=C_eqp(((C_word*)t0)[8],lf[32]);
if(C_truep(t3)){
t4=t2;
f_20110(t4,C_fix(0));}
else{
t4=C_i_pairp(((C_word*)t0)[8]);
t5=(C_truep(t4)?C_eqp(C_u_i_car(((C_word*)t0)[8]),lf[48]):C_SCHEME_FALSE);
t6=t2;
f_20110(t6,(C_truep(t5)?C_i_length(C_i_cdr(((C_word*)t0)[8])):C_SCHEME_FALSE));}}}

/* k20108 in k20102 in k20123 in k20127 */
static void C_fcall f_20110(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_20110,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20114,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2210: g4496 */
t3=t2;
f_20114(t3,((C_word*)t0)[5],t1);}
else{
t2=((C_word*)t0)[6];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g4496 in k20108 in k20102 in k20123 in k20127 */
static void C_fcall f_20114(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,6)))){
C_save_and_reclaim_args((void *)trf_20114,3,t0,t1,t2);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20118,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2218: r-index-out-of-range */
f_22249(t3,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],t2,lf[493]);}

/* k20116 in g4496 in k20108 in k20102 in k20123 in k20127 */
static void C_ccall f_20118(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20118,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20123 in k20127 */
static void C_ccall f_20125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,6)))){
C_save_and_reclaim((void *)f_20125,c,av);}
a=C_alloc(16);
t2=C_i_car(t1);
if(C_truep(t2)){
if(C_truep(C_fixnump(t2))){
if(C_truep(C_i_negativep(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20101,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2211: r-index-out-of-range */
f_22249(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2,lf[491],lf[492]);}
else{
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20104,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t4=C_i_pairp(((C_word*)t0)[7]);
if(C_truep(C_i_not(t4))){
t5=C_eqp(t2,C_fix(0));
if(C_truep(t5)){
t6=C_eqp(((C_word*)t0)[7],lf[32]);
if(C_truep(t6)){
/* scrutinizer.scm:2176: k */
t7=((C_word*)t0)[8];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t7=t3;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
f_20104(2,av2);}}}
else{
t6=t3;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_20104(2,av2);}}}
else{
t5=C_i_car(((C_word*)t0)[7]);
t6=C_eqp(t5,lf[48]);
if(C_truep(t6)){
t7=C_i_length(((C_word*)t0)[7]);
if(C_truep(C_fixnum_lessp(t2,t7))){
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19914,a[2]=((C_word*)t0)[7],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19924,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2179: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t3;
av2[2]=t8;
av2[3]=t9;
C_call_with_values(4,av2);}}
else{
t8=t3;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_20104(2,av2);}}}
else{
t7=C_i_car(((C_word*)t0)[7]);
t8=C_eqp(t7,lf[49]);
if(C_truep(t8)){
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19951,a[2]=((C_word*)t0)[8],a[3]=t10,tmp=(C_word)a,a+=4,tmp));
t12=((C_word*)t10)[1];
f_19951(t12,t3,C_SCHEME_END_OF_LIST,((C_word*)t0)[7],t2);}
else{
t9=t3;{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_SCHEME_FALSE;
f_20104(2,av2);}}}}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20127 */
static void C_ccall f_20129(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20129,c,av);}
a=C_alloc(9);
t2=C_eqp(lf[124],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20125,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2208: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_20141,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20144,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23452,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23454,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2230: list+index-call-result-type-special-case */
f_20046(t3,t4);}

/* k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_20144,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20147,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23385,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2233: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[649];
av2[3]=lf[275];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20147(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_20147,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20150,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23320,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2239: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[647];
av2[3]=lf[275];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20150(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_20150,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20153,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23263,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2245: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[645];
av2[3]=lf[275];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20153(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_20153,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20156,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23206,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2249: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[644];
av2[3]=lf[275];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20156(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_20156,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20159,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23144,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2253: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[368];
av2[3]=lf[275];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20159(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_20159,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_20161,tmp=(C_word)a,a+=2,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20324,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2303: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[5];
av2[3]=lf[275];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* append-special-case in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20161,c,av);}
a=C_alloc(9);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20170,a[2]=t3,a[3]=t4,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20315,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2300: derive-result-type */
t8=t6;
f_20170(t8,t7);}

/* derive-result-type in append-special-case in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_fcall f_20170(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_20170,2,t0,t1);}
a=C_alloc(7);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20180,a[2]=t4,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_20180(t6,t1,t2,C_fix(1));}

/* lp in derive-result-type in append-special-case in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_fcall f_20180(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_20180,4,t0,t1,t2,t3);}
a=C_alloc(9);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=lf[32];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f26866,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=t4,tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k20200 */
static void C_ccall f_20202(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_20202,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20212,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2281: scheme#reverse */
t3=*((C_word*)lf[368]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20210 in k20200 */
static void C_ccall f_20212(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_20212,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20215,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20217,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_20217(t6,t2,t1,((C_word*)t0)[3]);}

/* k20213 in k20210 in k20200 */
static void C_ccall f_20215(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20215,c,av);}
/* scrutinizer.scm:2279: canonicalize-list-type */
f_19537(((C_word*)t0)[2],t1);}

/* foldl4701 in k20210 in k20200 */
static void C_fcall f_20217(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_20217,4,t0,t1,t2,t3);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=C_slot(t2,C_fix(0));
t6=C_a_i_list(&a,3,lf[49],t5,t3);
t8=t1;
t9=t4;
t10=t6;
t1=t8;
t2=t9;
t3=t10;
goto loop;}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k20259 */
static void C_ccall f_20261(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20261,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_a_i_list(&a,3,lf[28],((C_word*)t0)[2],t1);
/* scrutinizer.scm:2286: simplify-type */
f_13568(((C_word*)t0)[3],t2);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20276 */
static void C_ccall f_20278(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20278,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20282 */
static void C_ccall f_20284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_20284,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20291,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2298: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[5];
av2[3]=lf[66];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k20289 in k20282 */
static void C_ccall f_20291(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_20291,c,av);}
/* scrutinizer.scm:2296: r-proc-call-argument-type-mismatch */
f_22110(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],lf[48],((C_word*)t0)[7],t1);}

/* k20313 in append-special-case in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_20315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_20315,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_list1(&a,1,t1):((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_20324(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_20324,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20327,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2304: ##sys#put! */
t3=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[405];
av2[3]=lf[275];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_20327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_20327,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20422,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_20331,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2327: ##sys#put! */
t4=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[643];
av2[3]=lf[275];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* f_20331 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_20331(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_20331,c,av);}
a=C_alloc(5);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20335,a[2]=t1,a[3]=t5,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2314: chicken.compiler.support#node-subexpressions */
t7=*((C_word*)lf[87]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k20333 */
static void C_ccall f_20335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_20335,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_i_length(t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20347,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
switch(t2){
case C_fix(2):
t4=t3;
f_20347(t4,lf[54]);
case C_fix(3):
t4=C_i_caddr(((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f26905,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}
default:
t4=t3;
f_20347(t4,C_SCHEME_FALSE);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20345 in k20333 */
static void C_fcall f_20347(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20347,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_cadr(((C_word*)t0)[2]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20399,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2320: chicken.compiler.support#node-class */
t4=*((C_word*)lf[89]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20375 in k20393 in k20397 in k20345 in k20333 */
static void C_ccall f_20377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_20377,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20391,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2324: make-list */
f_8012(t2,((C_word*)t0)[4],C_a_i_list(&a,1,((C_word*)t0)[5]));}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20389 in k20375 in k20393 in k20397 in k20345 in k20333 */
static void C_ccall f_20391(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_20391,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[51],t1);
t3=C_a_i_list(&a,1,t2);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?t3:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k20393 in k20397 in k20345 in k20333 */
static void C_ccall f_20395(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20395,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
if(C_truep(t2)){
if(C_truep(C_fixnump(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20377,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2323: scheme#<= */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t3;
av2[2]=C_fix(0);
av2[3]=t2;
av2[4]=C_fix(256);
C_less_or_equal_p(5,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20397 in k20345 in k20333 */
static void C_ccall f_20399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_20399,c,av);}
a=C_alloc(5);
t2=C_eqp(lf[124],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20395,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2321: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_20422(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,9)))){
C_save_and_reclaim((void *)f_20422,c,av);}
a=C_alloc(36);
t2=C_mutate(&lf[370] /* (set! chicken.compiler.scrutinizer#over-all-instantiations ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_20424,tmp=(C_word)a,a+=2,tmp));
t3=C_mutate(&lf[316] /* (set! chicken.compiler.scrutinizer#string-add-indent ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_20749,tmp=(C_word)a,a+=2,tmp));
t4=C_mutate(&lf[75] /* (set! chicken.compiler.scrutinizer#type->pp-string ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_20840,tmp=(C_word)a,a+=2,tmp));
t5=C_mutate(&lf[143] /* (set! chicken.compiler.scrutinizer#fragment ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21306,tmp=(C_word)a,a+=2,tmp));
t6=C_mutate(&lf[76] /* (set! chicken.compiler.scrutinizer#pp-fragment ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21411,tmp=(C_word)a,a+=2,tmp));
t7=C_mutate(&lf[324] /* (set! chicken.compiler.scrutinizer#node-source-prefix ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21435,tmp=(C_word)a,a+=2,tmp));
t8=C_mutate(&lf[318] /* (set! chicken.compiler.scrutinizer#location-name ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21465,tmp=(C_word)a,a+=2,tmp));
t9=C_mutate(&lf[517] /* (set! chicken.compiler.scrutinizer#variable-and-module ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21635,tmp=(C_word)a,a+=2,tmp));
t10=C_mutate(&lf[92] /* (set! chicken.compiler.scrutinizer#variable-from-module ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21686,tmp=(C_word)a,a+=2,tmp));
t11=C_mutate(&lf[103] /* (set! chicken.compiler.scrutinizer#describe-expression ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21746,tmp=(C_word)a,a+=2,tmp));
t12=C_mutate(&lf[72] /* (set! chicken.compiler.scrutinizer#report2 ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21876,tmp=(C_word)a,a+=2,tmp));
t13=C_mutate(&lf[170] /* (set! chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_22110,tmp=(C_word)a,a+=2,tmp));
t14=C_mutate(&lf[271] /* (set! chicken.compiler.scrutinizer#r-proc-call-argument-value-count ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_22156,tmp=(C_word)a,a+=2,tmp));
t15=C_mutate(&lf[488] /* (set! chicken.compiler.scrutinizer#r-index-out-of-range ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_22249,tmp=(C_word)a,a+=2,tmp));
t16=C_mutate(&lf[220] /* (set! chicken.compiler.scrutinizer#r-conditional-value-count-invalid ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_22381,tmp=(C_word)a,a+=2,tmp));
t17=C_mutate(&lf[221] /* (set! chicken.compiler.scrutinizer#r-let-value-count-invalid ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_22443,tmp=(C_word)a,a+=2,tmp));
t18=C_mutate(&lf[268] /* (set! chicken.compiler.scrutinizer#r-assignment-value-count-invalid ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_22563,tmp=(C_word)a,a+=2,tmp));
t19=C_mutate(&lf[62] /* (set! chicken.compiler.scrutinizer#r-deprecated-identifier ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23054,tmp=(C_word)a,a+=2,tmp));
t20=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t20;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t20+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_20424(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,0,3)))){
C_save_and_reclaim_args((void *)trf_20424,5,t1,t2,t3,t4,t5);}
a=C_alloc(24);
t6=C_SCHEME_END_OF_LIST;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=lf[24];
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20427,a[2]=t8,a[3]=t7,a[4]=t3,tmp=(C_word)a,a+=5,tmp));
t14=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20491,a[2]=t4,a[3]=t7,tmp=(C_word)a,a+=4,tmp));
t15=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20623,a[2]=t2,a[3]=t3,a[4]=t12,a[5]=t10,a[6]=t4,a[7]=t5,a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2376: delete-duplicates */
f_7382(t15,t2,*((C_word*)lf[375]+1));}

/* restore in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_20427(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_20427,2,t0,t1);}
a=C_alloc(11);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20436,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t5,tmp=(C_word)a,a+=7,tmp));
t7=((C_word*)t5)[1];
f_20436(t7,t1,lf[24]);}

/* doloop4781 in restore in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_20436(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_20436,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=C_mutate(&lf[24] /* (set! chicken.compiler.scrutinizer#trail ...) */,t2);
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[3])[1]))){
t5=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[3])[1],((C_word*)((C_word*)t0)[4])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[4])+1,t5);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t5=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[3])[1],((C_word*)((C_word*)t0)[4])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[4])+1,t5);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20487,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2351: resolve */
t6=lf[119];{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_u_i_car(t2);
av2[3]=((C_word*)t0)[5];
f_16350(4,av2);}}}

/* k20485 in doloop4781 in restore in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_20487,c,av);}
a=C_alloc(6);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t6=C_i_assq(C_u_i_car(((C_word*)t0)[4]),((C_word*)t0)[5]);
t7=C_i_cdr(t6);
t8=C_i_set_car(t7,C_SCHEME_FALSE);
t9=((C_word*)((C_word*)t0)[6])[1];
f_20436(t9,((C_word*)t0)[7],C_u_i_cdr(((C_word*)t0)[4]));}

/* collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_20491(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,0,3)))){
C_save_and_reclaim_args((void *)trf_20491,2,t0,t1);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20495,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20569,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=lf[12];
t9=((C_word*)((C_word*)t0)[3])[1];
t10=C_i_check_list_2(t9,lf[6]);
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20579,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20581,a[2]=t6,a[3]=t13,a[4]=t7,tmp=(C_word)a,a+=5,tmp));
t15=((C_word*)t13)[1];
f_20581(t15,t11,t9);}

/* k20493 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20495(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_20495,c,av);}
a=C_alloc(17);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20499,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t7=C_i_check_list_2(t1,lf[6]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20533,a[2]=t4,a[3]=t9,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t11=((C_word*)t9)[1];
f_20533(t11,((C_word*)t0)[4],t1);}

/* g4829 in k20493 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_20499(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_20499,3,t0,t1,t2);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20507,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20509,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2363: filter-map */
f_7471(t3,t4,((C_word*)((C_word*)t0)[3])[1]);}

/* k20505 in g4829 in k20493 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20507(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_20507,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a20508 in g4829 in k20493 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20509,c,av);}
t3=C_i_assq(((C_word*)t0)[2],t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_i_cdr(t3):(C_truep(((C_word*)t0)[3])?lf[54]:C_SCHEME_FALSE));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* map-loop4823 in k20493 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_20533(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20533,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20558,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2360: g4829 */
t4=((C_word*)t0)[4];
f_20499(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20556 in map-loop4823 in k20493 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20558(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20558,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20533(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k20567 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20569,c,av);}
/* scrutinizer.scm:2359: delete-duplicates */
f_7382(((C_word*)t0)[2],t1,*((C_word*)lf[375]+1));}

/* k20577 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_20579,c,av);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7285,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_7285(t5,((C_word*)t0)[2],t1);}

/* map-loop4796 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_20581(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20581,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20606,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2359: g4802 */
t4=lf[12];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_7536(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20604 in map-loop4796 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20606,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20581(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_20623(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_20623,c,av);}
a=C_alloc(11);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20625,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t3,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp));
t5=((C_word*)t3)[1];
f_20625(t5,((C_word*)t0)[8],t1,C_SCHEME_FALSE);}

/* loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_20625(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_20625,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t4=(C_truep(t3)?t3:C_i_nullp(((C_word*)t0)[2]));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20639,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20674,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2385: collect */
t7=((C_word*)((C_word*)t0)[4])[1];
f_20491(t7,t6);}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20712,a[2]=((C_word*)t0)[5],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t3,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2388: process */
t5=((C_word*)t0)[8];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* g4874 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_20639(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_20639,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_car(t2);
t4=C_a_i_cons(&a,2,t3,lf[24]);
t5=C_mutate(&lf[24] /* (set! chicken.compiler.scrutinizer#trail ...) */,t4);
t6=C_i_assq(C_u_i_car(t2),((C_word*)t0)[2]);
t7=C_i_cdr(t6);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20655,a[2]=t1,a[3]=t7,tmp=(C_word)a,a+=4,tmp);
t9=C_u_i_cdr(t2);
t10=C_a_i_cons(&a,2,lf[28],t9);
/* scrutinizer.scm:2384: simplify-type */
f_13568(t8,t10);}

/* k20653 in g4874 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20655,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_set_car(((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20672 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_20674,c,av);}
a=C_alloc(9);
t2=C_i_check_list_2(t1,lf[213]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20680,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20682,a[2]=t5,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_20682(t7,t3,t1);}

/* k20678 in k20672 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20680,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* for-each-loop4873 in k20672 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_fcall f_20682(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20682,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20692,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2380: g4874 */
t4=((C_word*)t0)[3];
f_20639(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k20690 in for-each-loop4873 in k20672 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_20692(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20692,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_20682(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k20710 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20712(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_20712,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20715,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2389: restore */
t3=((C_word*)((C_word*)t0)[5])[1];
f_20427(t3,t2);}
else{
if(C_truep(((C_word*)t0)[6])){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20726,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2392: restore */
t3=((C_word*)((C_word*)t0)[5])[1];
f_20427(t3,t2);}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20729,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2395: restore */
t3=((C_word*)((C_word*)t0)[5])[1];
f_20427(t3,t2);}}}

/* k20713 in k20710 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20715,c,av);}
/* scrutinizer.scm:2390: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20625(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_SCHEME_TRUE);}

/* k20724 in k20710 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20726,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20727 in k20710 in loop in k20621 in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20729,c,av);}
/* scrutinizer.scm:2396: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20625(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),((C_word*)t0)[5]);}

/* chicken.compiler.scrutinizer#string-add-indent in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_20749(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_20749,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_i_nullp(t3);
t5=(C_truep(t4)?lf[494]:C_i_car(t3));
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20756,a[2]=t2,a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2404: chicken.string#string-split */
t7=*((C_word*)lf[499]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
av2[3]=lf[500];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}

/* k20754 in chicken.compiler.scrutinizer#string-add-indent in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_20756(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_20756,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20759,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20785,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20798,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20800,a[2]=t5,a[3]=t10,a[4]=t7,a[5]=t6,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_20800(t12,t8,t1);}

/* k20757 in k20754 in chicken.compiler.scrutinizer#string-add-indent in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_20759,c,av);}
a=C_alloc(5);
t2=C_block_size(((C_word*)t0)[2]);
t3=C_a_i_fixnum_difference(&a,2,t2,C_fix(1));
t4=C_i_string_ref(((C_word*)t0)[2],t3);
t5=C_eqp(C_make_character(10),t4);
if(C_truep(t5)){
/* ##sys#string-append */
t6=*((C_word*)lf[495]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=lf[496];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* g4925 in k20754 in chicken.compiler.scrutinizer#string-add-indent in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_20785(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_20785,3,t0,t1,t2);}
if(C_truep(C_i_string_equal_p(lf[497],t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* scrutinizer.scm:2409: scheme#string-append */
t3=*((C_word*)lf[77]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k20796 in k20754 in chicken.compiler.scrutinizer#string-add-indent in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20798,c,av);}
/* scrutinizer.scm:2405: chicken.string#string-intersperse */
t2=*((C_word*)lf[314]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[498];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop4919 in k20754 in chicken.compiler.scrutinizer#string-add-indent in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_20800(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20800,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2406: g4925 */
t4=((C_word*)t0)[4];
f_20785(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20823 in map-loop4919 in k20754 in chicken.compiler.scrutinizer#string-add-indent in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20825,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20800(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_20840(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_20840,2,t1,t2);}
a=C_alloc(12);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20866,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21283,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21304,a[2]=t4,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2452: chicken.syntax#strip-syntax */
t8=*((C_word*)lf[480]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}

/* k20845 in map-loop5021 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_20847,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20850,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f26473,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2420: scheme#string->symbol */
t4=*((C_word*)lf[253]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_a_i_list2(&a,2,lf[502],((C_word*)t0)[3]);
/* scrutinizer.scm:2419: ##sys#error */
t4=*((C_word*)lf[503]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k20848 in k20845 in map-loop5021 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_20850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20850,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20857,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2420: scheme#string->symbol */
t3=*((C_word*)lf[253]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k20855 in k20848 in k20845 in map-loop5021 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_20857(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_20857,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];
f_20992(t2,C_a_i_list2(&a,2,lf[124],t1));}

/* conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_20866(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_20866,4,t0,t1,t2,t3);}
a=C_alloc(11);
t4=C_i_nullp(t3);
t5=(C_truep(t4)?C_SCHEME_END_OF_LIST:C_i_car(t3));
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20872,a[2]=((C_word*)t0)[2],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=C_i_pairp(t2);
if(C_truep(C_i_not(t7))){
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20885,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2425: chicken.base#alist-ref */
t9=*((C_word*)lf[276]+1);{
C_word av2[5];
av2[0]=t9;
av2[1]=t8;
av2[2]=t2;
av2[3]=t5;
av2[4]=*((C_word*)lf[375]+1);
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t8=(
/* scrutinizer.scm:2426: refinement-type? */
  f_15928(t2)
);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20901,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2428: chicken.base#open-output-string */
t10=*((C_word*)lf[243]+1);{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t9=C_i_pairp(t2);
t10=(C_truep(t9)?C_u_i_car(t2):C_SCHEME_FALSE);
t11=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20980,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t10,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
t12=C_eqp(lf[29],t10);
if(C_truep(t12)){
/* scrutinizer.scm:2432: every */
f_7187(t11,*((C_word*)lf[473]+1),C_i_cadr(t2));}
else{
t13=t11;{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
f_20980(2,av2);}}}}}

/* R in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_20872(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_20872,3,t0,t1,t2);}
a=C_alloc(3);
/* scrutinizer.scm:2422: conv */
t3=((C_word*)((C_word*)t0)[2])[1];
f_20866(t3,t1,t2,C_a_i_list(&a,1,((C_word*)t0)[3]));}

/* k20883 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20885,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?t1:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20901(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,3)))){
C_save_and_reclaim((void *)f_20901,c,av);}
a=C_alloc(25);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20907,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20924,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=*((C_word*)lf[321]+1);
t10=C_i_cadr(((C_word*)t0)[3]);
t11=C_i_check_list_2(t10,lf[6]);
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20937,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20939,a[2]=t7,a[3]=t14,a[4]=t9,a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_20939(t16,t12,t10);}

/* k20905 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20907(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_20907,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20910,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2428: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(45);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k20908 in k20905 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20910(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_20910,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20913,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2428: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_caddr(((C_word*)t0)[4]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20911 in k20908 in k20905 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_20913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20913,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20916,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2428: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k20914 in k20911 in k20908 in k20905 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_20916(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20916,c,av);}
/* scrutinizer.scm:2427: scheme#string->symbol */
t2=*((C_word*)lf[253]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k20922 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20924,c,av);}
/* scrutinizer.scm:2428: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k20935 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_20937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20937,c,av);}
/* scrutinizer.scm:2428: chicken.string#string-intersperse */
t2=*((C_word*)lf[314]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[501];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop4983 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_20939(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20939,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20964,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2428: g4989 */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20962 in map-loop4983 in k20899 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_20964(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20964,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20939(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_20980(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_20980,c,av);}
a=C_alloc(17);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_cadr(((C_word*)t0)[2]);
t7=C_i_check_list_2(t6,lf[6]);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21001,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21010,a[2]=t4,a[3]=t10,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_21010(t12,t8,t6);}
else{
t2=C_eqp(lf[29],((C_word*)t0)[5]);
if(C_truep(t2)){
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep((C_truep(C_eqp(((C_word*)t0)[5],lf[28]))?C_SCHEME_TRUE:(C_truep(C_eqp(((C_word*)t0)[5],lf[70]))?C_SCHEME_TRUE:(C_truep(C_eqp(((C_word*)t0)[5],lf[48]))?C_SCHEME_TRUE:(C_truep(C_eqp(((C_word*)t0)[5],lf[51]))?C_SCHEME_TRUE:(C_truep(C_eqp(((C_word*)t0)[5],lf[49]))?C_SCHEME_TRUE:(C_truep(C_eqp(((C_word*)t0)[5],lf[362]))?C_SCHEME_TRUE:(C_truep(C_eqp(((C_word*)t0)[5],lf[360]))?C_SCHEME_TRUE:C_SCHEME_FALSE))))))))){
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_cdr(((C_word*)t0)[2]);
t8=C_i_check_list_2(t7,lf[6]);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21069,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21071,a[2]=t5,a[3]=t11,a[4]=((C_word*)t0)[6],a[5]=t6,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_21071(t13,t9,t7);}
else{
t3=C_eqp(lf[53],((C_word*)t0)[5]);
if(C_truep(t3)){
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_eqp(lf[85],((C_word*)t0)[5]);
if(C_truep(t4)){
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21121,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=t7,a[6]=t8,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2440: procedure-arguments */
f_15287(t9,((C_word*)t0)[2]);}
else{
/* scrutinizer.scm:2451: chicken.compiler.support#bomb */
t5=*((C_word*)lf[344]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[504];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}}}}}

/* k20990 in map-loop5021 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_fcall f_20992(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20992,2,t0,t1);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[3])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,t3);
t6=((C_word*)((C_word*)t0)[4])[1];
f_21010(t6,((C_word*)t0)[5],C_slot(((C_word*)t0)[6],C_fix(1)));}

/* k20999 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21001,c,av);}
a=C_alloc(3);
/* scrutinizer.scm:2434: conv */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20866(t2,((C_word*)t0)[3],C_i_caddr(((C_word*)t0)[4]),C_a_i_list(&a,1,t1));}

/* map-loop5021 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_21010(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_21010,3,t0,t1,t2);}
a=C_alloc(11);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20992,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t2,tmp=(C_word)a,a+=7,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20847,a[2]=t4,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2418: chicken.plist#get */
t6=*((C_word*)lf[378]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
av2[3]=lf[377];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21067 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21069(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_21069,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop5051 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_21071(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21071,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21096,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2437: g5057 */
t4=((C_word*)t0)[4];
f_20872(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21094 in map-loop5051 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21096,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_21071(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21121(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_21121,c,av);}
a=C_alloc(13);
t2=C_i_check_list_2(t1,lf[6]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21127,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21221,a[2]=((C_word*)t0)[5],a[3]=t5,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_21221(t7,t3,t1);}

/* k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21127(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21127,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21130,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2441: procedure-results */
f_15344(t2,((C_word*)t0)[3]);}

/* k21128 in k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_21130,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21133,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_eqp(lf[54],t1);
if(C_truep(t3)){
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_21133(2,av2);}}
else{
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=C_i_check_list_2(t1,lf[6]);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21187,a[2]=t6,a[3]=t10,a[4]=((C_word*)t0)[5],a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_21187(t12,t2,t1);}}

/* k21131 in k21128 in k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_21133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21133,c,av);}
a=C_alloc(6);
if(C_truep(C_i_not(t1))){
t2=(C_truep(t1)?C_a_i_cons(&a,2,((C_word*)t0)[2],t1):C_a_i_cons(&a,2,((C_word*)t0)[2],lf[54]));
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[85],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21164,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2447: procedure-name */
f_15236(t2,((C_word*)t0)[4]);}}

/* k21162 in k21131 in k21128 in k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_21164(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_21164,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21167,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21170,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2448: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
av2[3]=lf[273];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=t2;
f_21167(t3,C_SCHEME_FALSE);}}

/* k21165 in k21162 in k21131 in k21128 in k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_fcall f_21167(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_21167,2,t0,t1);}
a=C_alloc(3);
t2=(C_truep(t1)?C_a_i_cons(&a,2,lf[474],((C_word*)t0)[2]):C_a_i_cons(&a,2,lf[476],((C_word*)t0)[2]));
/* scrutinizer.scm:2447: ##sys#append */
t3=*((C_word*)lf[405]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k21168 in k21162 in k21131 in k21128 in k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_21170(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21170,c,av);}
t2=((C_word*)t0)[2];
f_21167(t2,(C_truep(t1)?t1:C_SCHEME_FALSE));}

/* map-loop5106 in k21128 in k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_fcall f_21187(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21187,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21212,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2444: g5112 */
t4=((C_word*)t0)[4];
f_20872(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21210 in map-loop5106 in k21128 in k21125 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_21212(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21212,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_21187(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* map-loop5079 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_fcall f_21221(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21221,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21246,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2440: g5085 */
t4=((C_word*)t0)[4];
f_20872(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21244 in map-loop5079 in k21119 in k20978 in conv in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21246(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21246,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_21221(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k21281 in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21283(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_21283,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21290,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21294,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21296,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2455: chicken.port#with-output-to-string */
t5=*((C_word*)lf[506]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k21288 in k21281 in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21290,c,av);}
/* scrutinizer.scm:2453: string-add-indent */
f_20749(((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST);}

/* k21292 in k21281 in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21294,c,av);}
/* scrutinizer.scm:2454: chicken.string#string-chomp */
t2=*((C_word*)lf[505]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a21295 in k21281 in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21296,c,av);}
/* scrutinizer.scm:2456: chicken.pretty-print#pp */
t2=*((C_word*)lf[435]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21302 in chicken.compiler.scrutinizer#type->pp-string in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21304(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21304,c,av);}
/* scrutinizer.scm:2452: conv */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20866(t2,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_21306(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21306,2,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21310,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21409,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2459: source-node-tree */
t5=lf[456];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
f_17555(3,av2);}}

/* k21308 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21310,c,av);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21315,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_21315(t5,((C_word*)t0)[2],t1,C_fix(0));}

/* walk in k21308 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_21315(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_21315,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_not_pair_p(t2))){
/* scrutinizer.scm:2461: chicken.syntax#strip-syntax */
t4=*((C_word*)lf[480]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
if(C_truep(C_i_greater_or_equalp(t3,C_fix(4)))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=lf[457];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_i_listp(t2))){
t4=C_u_i_length(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21341,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnum_lessp(C_fix(6),t4))){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21400,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2466: take */
f_6926(t6,t2,C_fix(6));}
else{
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
f_21341(2,av2);}}}
else{
/* scrutinizer.scm:2469: chicken.syntax#strip-syntax */
t4=*((C_word*)lf[480]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}}}

/* k21339 in walk in k21308 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21341(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(46,c,3)))){
C_save_and_reclaim((void *)f_21341,c,av);}
a=C_alloc(46);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_s_a_i_plus(&a,2,((C_word*)t0)[2],C_fix(1));
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21346,a[2]=((C_word*)t0)[3],a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t8=C_i_check_list_2(t1,lf[6]);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21358,a[2]=t4,a[3]=t10,a[4]=t7,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_21358(t12,((C_word*)t0)[4],t1);}

/* g5167 in k21339 in walk in k21308 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_fcall f_21346(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_21346,3,t0,t1,t2);}
/* scrutinizer.scm:2468: g51815182 */
t3=((C_word*)((C_word*)t0)[2])[1];
f_21315(t3,t1,t2,((C_word*)t0)[3]);}

/* map-loop5161 in k21339 in walk in k21308 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_fcall f_21358(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21358,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21383,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2468: g5167 */
t4=((C_word*)t0)[4];
f_21346(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21381 in map-loop5161 in k21339 in walk in k21308 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21383(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21383,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_21358(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k21398 in walk in k21308 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21400,c,av);}
/* scrutinizer.scm:2466: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[507];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k21407 in chicken.compiler.scrutinizer#fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21409,c,av);}
/* scrutinizer.scm:2459: chicken.compiler.support#build-expression-tree */
t2=*((C_word*)lf[508]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.compiler.scrutinizer#pp-fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_21411(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_21411,2,t1,t2);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21419,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21423,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21425,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2474: chicken.port#with-output-to-string */
t6=*((C_word*)lf[506]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k21417 in chicken.compiler.scrutinizer#pp-fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21419(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21419,c,av);}
/* scrutinizer.scm:2472: string-add-indent */
f_20749(((C_word*)t0)[2],t1,C_SCHEME_END_OF_LIST);}

/* k21421 in chicken.compiler.scrutinizer#pp-fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21423(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21423,c,av);}
/* scrutinizer.scm:2473: chicken.string#string-chomp */
t2=*((C_word*)lf[505]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a21424 in chicken.compiler.scrutinizer#pp-fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21425(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21425,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21433,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2476: fragment */
f_21306(t2,((C_word*)t0)[2]);}

/* k21431 in a21424 in chicken.compiler.scrutinizer#pp-fragment in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21433(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21433,c,av);}
/* scrutinizer.scm:2476: chicken.pretty-print#pp */
t2=*((C_word*)lf[435]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_21435(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_21435,2,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21439,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17630,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:1771: source-node */
f_17528(t4,t2,C_SCHEME_END_OF_LIST);}

/* k21437 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21439(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21439,c,av);}
a=C_alloc(4);
if(C_truep(C_i_not(t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[509];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21448,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2480: chicken.base#open-output-string */
t3=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21446 in k21437 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21448(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21448,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21454,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2480: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[511];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k21452 in k21446 in k21437 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21454,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21457,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2480: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21455 in k21452 in k21446 in k21437 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21457,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21460,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2480: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[510];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21458 in k21455 in k21452 in k21446 in k21437 in chicken.compiler.scrutinizer#node-source-prefix in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21460,c,av);}
/* scrutinizer.scm:2480: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_21465(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_21465,3,t1,t2,t3);}
a=C_alloc(9);
t4=C_i_nullp(t3);
t5=(C_truep(t4)?lf[513]:C_i_car(t3));
if(C_truep(C_i_nullp(t2))){
/* scrutinizer.scm:2488: chicken.string#conc */
t6=*((C_word*)lf[321]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[514];
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=C_a_i_list1(&a,1,lf[515]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21515,a[2]=t5,a[3]=t8,tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_21515(t10,t1,t2,t6);}}

/* k21476 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21478,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21484,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2485: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[525];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k21482 in k21476 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21484(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_21484,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21487,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21497,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2485: chicken.compiler.support#real-name */
t4=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k21485 in k21482 in k21476 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21487,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21490,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2485: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[524];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21488 in k21485 in k21482 in k21476 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21490,c,av);}
/* scrutinizer.scm:2485: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21495 in k21482 in k21476 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21497,c,av);}
/* scrutinizer.scm:2485: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_21515(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(14,0,4)))){
C_save_and_reclaim_args((void *)trf_21515,4,t0,t1,t2,t3);}
a=C_alloc(14);
t4=C_i_cdr(t2);
if(C_truep(C_i_nullp(t4))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21529,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21537,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_u_i_car(t2))){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21543,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21557,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2497: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=t6;
av2[2]=t7;
av2[3]=t8;
C_call_with_values(4,av2);}}
else{
t7=t5;
f_21529(t7,C_a_i_cons(&a,2,lf[523],t3));}}
else{
t5=C_u_i_cdr(t2);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21621,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
t7=C_u_i_car(t2);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21478,a[2]=t6,a[3]=t7,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2485: chicken.base#open-output-string */
t9=*((C_word*)lf[243]+1);{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=C_a_i_cons(&a,2,lf[526],t3);
/* scrutinizer.scm:2502: rec */
t10=t1;
t11=t5;
t12=t8;
t1=t10;
t2=t11;
t3=t12;
goto loop;}}}

/* k21527 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_21529(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_21529,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21533,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2501: chicken.string#conc */
t3=*((C_word*)lf[321]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[516];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k21531 in k21527 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21533,c,av);}
/* scrutinizer.scm:2492: chicken.string#string-intersperse */
t2=*((C_word*)lf[314]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k21535 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21537(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_21537,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];
f_21529(t2,C_a_i_cons(&a,2,t1,((C_word*)t0)[3]));}

/* a21542 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21543(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21543,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21551,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2497: chicken.compiler.support#real-name */
t3=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k21549 in a21542 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21551,c,av);}
/* scrutinizer.scm:2497: variable-and-module */
f_21635(((C_word*)t0)[2],t1);}

/* a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21557(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_21557,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21565,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t3)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21587,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2498: chicken.base#open-output-string */
t6=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=lf[522];
f_21565(2,av2);}}}

/* k21563 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21565(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21565,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21569,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2499: chicken.base#open-output-string */
t3=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k21567 in k21563 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_21569,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21575,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2499: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[519];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k21573 in k21567 in k21563 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21575(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21575,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21578,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2499: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21576 in k21573 in k21567 in k21563 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_21578(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21578,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21581,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2499: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[518];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21579 in k21576 in k21573 in k21567 in k21563 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_21581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21581,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21584,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2499: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k21582 in k21579 in k21576 in k21573 in k21567 in k21563 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_21584(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21584,c,av);}
/* scrutinizer.scm:2498: chicken.string#conc */
t2=*((C_word*)lf[321]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k21585 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21587(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_21587,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21593,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2498: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[521];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k21591 in k21585 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21593,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21596,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2498: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21594 in k21591 in k21585 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21596(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21596,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21599,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2498: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[520];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21597 in k21594 in k21591 in k21585 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_21599(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_21599,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21602,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2498: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k21600 in k21597 in k21594 in k21591 in k21585 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_21602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21602,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21605,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2498: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21603 in k21600 in k21597 in k21594 in k21591 in k21585 in a21556 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_21605(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21605,c,av);}
/* scrutinizer.scm:2498: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21619 in rec in chicken.compiler.scrutinizer#location-name in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21621(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21621,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* scrutinizer.scm:2502: rec */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21515(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* chicken.compiler.scrutinizer#variable-and-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_21635(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_21635,2,t1,t2);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21639,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_symbolp(t2))){
/* scrutinizer.scm:2506: scheme#symbol->string */
t4=*((C_word*)lf[443]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=t3;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
f_21639(2,av2);}}}

/* k21637 in chicken.compiler.scrutinizer#variable-and-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21639,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21642,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2507: chicken.string#string-split */
t3=*((C_word*)lf[499]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=lf[527];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21640 in k21637 in chicken.compiler.scrutinizer#variable-and-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21642,c,av);}
a=C_alloc(4);
t2=C_i_cdr(t1);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21655,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2509: scheme#string->symbol */
t4=*((C_word*)lf[253]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_cadr(t1);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21674,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2510: scheme#string->symbol */
t4=*((C_word*)lf[253]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k21653 in k21640 in k21637 in chicken.compiler.scrutinizer#variable-and-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21655,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21659,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2509: scheme#string->symbol */
t3=*((C_word*)lf[253]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k21657 in k21653 in k21640 in k21637 in chicken.compiler.scrutinizer#variable-and-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21659,c,av);}
/* scrutinizer.scm:2509: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_values(4,av2);}}

/* k21672 in k21640 in k21637 in chicken.compiler.scrutinizer#variable-and-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21674,c,av);}
/* scrutinizer.scm:2510: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
C_values(4,av2);}}

/* chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_21686(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_21686,2,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21692,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21698,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2513: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=t1;
av2[2]=t3;
av2[3]=t4;
C_call_with_values(4,av2);}}

/* a21691 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21692(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21692,c,av);}
/* scrutinizer.scm:2513: variable-and-module */
f_21635(t1,((C_word*)t0)[2]);}

/* a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21698,c,av);}
a=C_alloc(5);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21705,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2515: chicken.base#open-output-string */
t5=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21729,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2516: chicken.base#open-output-string */
t5=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k21703 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_21705,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21711,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2515: ##sys#write-char-0 */
t4=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(96);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k21709 in k21703 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21711,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21714,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2515: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21712 in k21709 in k21703 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21714(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_21714,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21717,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2515: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[528];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21715 in k21712 in k21709 in k21703 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21717,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21720,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2515: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21718 in k21715 in k21712 in k21709 in k21703 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_21720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_21720,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21723,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2515: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(39);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k21721 in k21718 in k21715 in k21712 in k21709 in k21703 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_21723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21723,c,av);}
/* scrutinizer.scm:2515: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21727 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_21729,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21735,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2516: ##sys#write-char-0 */
t4=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(96);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k21733 in k21727 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21735,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21738,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2516: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21736 in k21733 in k21727 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_21738,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21741,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2516: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(39);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k21739 in k21736 in k21733 in k21727 in a21697 in chicken.compiler.scrutinizer#variable-from-module in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21741(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21741,c,av);}
/* scrutinizer.scm:2516: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_21746(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,3)))){
C_save_and_reclaim_args((void *)trf_21746,2,t1,t2);}
a=C_alloc(14);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21749,tmp=(C_word)a,a+=2,tmp));
t8=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21763,a[2]=t6,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21860,a[2]=t6,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2540: source-node-tree */
t10=lf[456];{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=t2;
f_17555(3,av2);}}

/* p-expr in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_21749(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_21749,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21757,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2520: scheme#string-append */
t4=*((C_word*)lf[77]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[529];
av2[3]=lf[530];
av2[4]=lf[531];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k21755 in p-expr in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21757,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21761,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2521: pp-fragment */
f_21411(t2,((C_word*)t0)[3]);}

/* k21759 in k21755 in p-expr in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21761(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21761,c,av);}
/* scrutinizer.scm:2520: chicken.format#sprintf */
t2=*((C_word*)lf[411]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_21763(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_21763,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21767,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21853,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2523: chicken.compiler.support#node-class */
t5=*((C_word*)lf[89]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k21765 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21767(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21767,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21794,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2537: chicken.compiler.support#node-class */
t3=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k21785 in k21792 in k21765 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21787(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21787,c,av);}
/* scrutinizer.scm:2538: p-node */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21763(t2,((C_word*)t0)[3],C_i_car(t1));}

/* k21792 in k21765 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21794,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[86],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21787,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2538: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* scrutinizer.scm:2539: p-expr */
f_21749(((C_word*)t0)[3],((C_word*)t0)[4]);}}

/* k21813 in k21839 in k21843 in k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_21815(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,6)))){
C_save_and_reclaim((void *)f_21815,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2528: scheme#string-append */
t3=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[532];
av2[3]=lf[533];
av2[4]=lf[534];
av2[5]=lf[535];
av2[6]=lf[536];
((C_proc)(void*)(*((C_word*)t3+1)))(7,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_21767(2,av2);}}}

/* k21823 in k21813 in k21839 in k21843 in k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_21825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_21825,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21829,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2534: variable-from-module */
f_21686(t2,((C_word*)t0)[6]);}

/* k21827 in k21823 in k21813 in k21839 in k21843 in k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_21829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_21829,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21833,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2535: type->pp-string */
f_20840(t2,((C_word*)t0)[6]);}

/* k21831 in k21827 in k21823 in k21813 in k21839 in k21843 in k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_21833(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21833,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21837,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2536: p-expr */
f_21749(t2,((C_word*)t0)[6]);}

/* k21835 in k21831 in k21827 in k21823 in k21813 in k21839 in k21843 in k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in ... */
static void C_ccall f_21837(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21837,c,av);}
/* scrutinizer.scm:2528: chicken.format#sprintf */
t2=*((C_word*)lf[411]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k21839 in k21843 in k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_21841,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21815,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2527: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[66];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_21767(2,av2);}}}

/* k21843 in k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21845(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21845,c,av);}
a=C_alloc(5);
t2=C_eqp(lf[88],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21841,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2526: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_21767(2,av2);}}}

/* k21847 in k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21849,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21845,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2525: chicken.compiler.support#node-class */
t4=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k21851 in p-node in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21853,c,av);}
a=C_alloc(5);
t2=C_eqp(lf[121],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21849,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2524: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_21767(2,av2);}}}

/* k21858 in chicken.compiler.scrutinizer#describe-expression in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21860(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21860,c,av);}
/* scrutinizer.scm:2540: p-node */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21763(t2,((C_word*)t0)[3],t1);}

/* chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_21876(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-7)*C_SIZEOF_PAIR +23,c,2)))){
C_save_and_reclaim((void*)f_21876,c,av);}
a=C_alloc((c-7)*C_SIZEOF_PAIR+23);
t7=C_build_rest(&a,c,7,av);
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21879,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
if(C_truep(lf[18])){
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21907,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21914,a[2]=t3,a[3]=t9,tmp=(C_word)a,a+=4,tmp);
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21918,a[2]=t10,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21922,a[2]=t11,tmp=(C_word)a,a+=3,tmp);
t13=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21926,a[2]=t12,a[3]=t6,a[4]=t7,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2555: file-location */
t14=t8;
f_21879(t14,t13);}
else{
t9=C_SCHEME_UNDEFINED;
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}

/* file-location in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_21879(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(2,0,3)))){
C_save_and_reclaim_args((void *)trf_21879,2,t0,t1);}
a=C_alloc(2);
t2=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21885,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2547: any */
f_7221(t1,t2,((C_word*)t0)[2]);}

/* a21884 in file-location in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21885,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21901,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2547: node-source-prefix */
f_21435(t3,t2);}

/* k21899 in a21884 in file-location in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21901(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21901,c,av);}
if(C_truep(C_i_not(C_u_i_string_equal_p(lf[537],t1)))){
/* scrutinizer.scm:2548: node-source-prefix */
f_21435(((C_word*)t0)[2],((C_word*)t0)[3]);}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k21905 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21907(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21907,c,av);}
/* scrutinizer.scm:2559: chicken.base#flush-output */
t2=*((C_word*)lf[538]+1);{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k21912 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21914,c,av);}
/* scrutinizer.scm:2551: report-f */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21916 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21918,c,av);}
/* scrutinizer.scm:2552: chicken.string#conc */
t2=*((C_word*)lf[321]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k21920 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21922(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21922,c,av);}
a=C_alloc(3);
/* scrutinizer.scm:2554: string-add-indent */
f_20749(((C_word*)t0)[2],t1,C_a_i_list(&a,1,lf[539]));}

/* k21924 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_21926(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_21926,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21929,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t1)){
/* scrutinizer.scm:2555: chicken.string#conc */
t3=*((C_word*)lf[321]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[543];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[544];
f_21929(2,av2);}}}

/* k21927 in k21924 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_21929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_21929,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21933,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2556: location-name */
f_21465(t2,((C_word*)t0)[5],C_a_i_list(&a,1,lf[542]));}

/* k21931 in k21927 in k21924 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_21933(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_21933,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21937,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2557: chicken.base#open-output-string */
t3=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k21935 in k21931 in k21927 in k21924 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_21937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_21937,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21943,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=t3;
av2[2]=*((C_word*)lf[541]+1);
av2[3]=t1;
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
C_apply(6,av2);}}

/* k21941 in k21935 in k21931 in k21927 in k21924 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_21943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21943,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21946,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2557: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k21944 in k21941 in k21935 in k21931 in k21927 in k21924 in chicken.compiler.scrutinizer#report2 in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_21946(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21946,c,av);}
/* scrutinizer.scm:2555: chicken.string#conc */
t2=*((C_word*)lf[321]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[540];
av2[4]=((C_word*)t0)[4];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* variable-node-name in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_21960(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_21960,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21999,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2568: chicken.compiler.support#node-class */
t4=*((C_word*)lf[89]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k21976 in k21997 in variable-node-name in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_21978(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21978,c,av);}
/* scrutinizer.scm:2569: variable-node-name */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21960(t2,((C_word*)t0)[3],C_i_car(t1));}

/* k21989 in k21993 in k21997 in variable-node-name in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_21991(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21991,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k21993 in k21997 in variable-node-name in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_21995(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21995,c,av);}
a=C_alloc(3);
t2=C_eqp(lf[88],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21991,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2570: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21997 in variable-node-name in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_21999(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21999,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[86],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21978,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2569: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21995,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2570: chicken.compiler.support#node-class */
t4=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22005(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,16)))){
C_save_and_reclaim((void *)f_22005,c,av);}
a=C_alloc(15);
if(C_truep(t1)){
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22016,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2578: scheme#string-append */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[93];
av2[3]=lf[94];
av2[4]=lf[95];
av2[5]=lf[96];
av2[6]=lf[97];
av2[7]=lf[98];
av2[8]=lf[99];
av2[9]=lf[100];
av2[10]=lf[101];
((C_proc)(void*)(*((C_word*)t4+1)))(11,av2);}}
else{
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22043,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2596: scheme#string-append */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 17) {
  av2=av;
} else {
  av2=C_alloc(17);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[104];
av2[3]=lf[105];
av2[4]=lf[106];
av2[5]=lf[107];
av2[6]=lf[108];
av2[7]=lf[109];
av2[8]=lf[110];
av2[9]=lf[111];
av2[10]=lf[112];
av2[11]=lf[113];
av2[12]=lf[114];
av2[13]=lf[115];
av2[14]=lf[116];
av2[15]=lf[117];
av2[16]=lf[118];
((C_proc)(void*)(*((C_word*)t4+1)))(17,av2);}}}

/* k22014 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22016(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22016,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22020,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2588: pp-fragment */
f_21411(t2,((C_word*)t0)[8]);}

/* k22018 in k22014 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22020(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22020,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22024,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22032,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2589: variable-node-name */
t4=((C_word*)((C_word*)t0)[7])[1];
f_21960(t4,t3,((C_word*)t0)[8]);}

/* k22022 in k22018 in k22014 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_22024(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22024,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22028,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2590: type->pp-string */
f_20840(t2,((C_word*)t0)[7]);}

/* k22026 in k22022 in k22018 in k22014 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_22028(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_22028,c,av);}
/* scrutinizer.scm:2573: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[90];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=t1;
f_21876(10,av2);}}

/* k22030 in k22018 in k22014 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_22032(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22032,c,av);}
/* scrutinizer.scm:2589: variable-from-module */
f_21686(((C_word*)t0)[2],t1);}

/* k22041 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22043(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22043,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22047,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2612: pp-fragment */
f_21411(t2,((C_word*)t0)[8]);}

/* k22045 in k22041 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22047,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22051,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2613: describe-expression */
f_21746(t2,((C_word*)t0)[8]);}

/* k22049 in k22045 in k22041 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_22051(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22051,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22055,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2614: type->pp-string */
f_20840(t2,((C_word*)t0)[8]);}

/* k22053 in k22049 in k22045 in k22041 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_22055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22055,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22059,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2615: type->pp-string */
f_20840(t2,((C_word*)t0)[8]);}

/* k22057 in k22053 in k22049 in k22045 in k22041 in k22003 in k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_22059(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,10)))){
C_save_and_reclaim((void *)f_22059,c,av);}
/* scrutinizer.scm:2591: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[102];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=((C_word*)t0)[8];
av2[10]=t1;
f_21876(11,av2);}}

/* k22064 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22066(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,10)))){
C_save_and_reclaim((void *)f_22066,c,av);}
a=C_alloc(13);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_a_i_list1(&a,1,((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22077,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=t3,a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[3],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2624: scheme#string-append */
t5=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[178];
av2[3]=lf[179];
av2[4]=lf[180];
av2[5]=lf[181];
av2[6]=lf[182];
av2[7]=lf[183];
av2[8]=lf[184];
av2[9]=lf[185];
av2[10]=lf[186];
((C_proc)(void*)(*((C_word*)t5+1)))(11,av2);}}

/* k22075 in k22064 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22077(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22077,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22081,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2634: pp-fragment */
f_21411(t2,((C_word*)t0)[9]);}

/* k22079 in k22075 in k22064 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22081(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22081,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22085,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2635: strip-namespace */
f_19651(t2,((C_word*)((C_word*)t0)[9])[1]);}

/* k22083 in k22079 in k22075 in k22064 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_22085,c,av);}
a=C_alloc(14);
t2=C_i_nequalp(((C_word*)t0)[2],C_fix(1));
t3=(C_truep(t2)?lf[172]:lf[173]);
t4=C_i_nequalp(((C_word*)t0)[3],C_fix(1));
t5=(C_truep(t4)?lf[172]:lf[173]);
t6=C_i_nequalp(((C_word*)t0)[3],C_fix(1));
t7=(C_truep(t6)?lf[174]:lf[175]);
t8=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_22101,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=t1,a[8]=((C_word*)t0)[2],a[9]=t3,a[10]=((C_word*)t0)[3],a[11]=t5,a[12]=t7,a[13]=((C_word*)t0)[9],tmp=(C_word)a,a+=14,tmp);
/* scrutinizer.scm:2639: variable-from-module */
f_21686(t8,((C_word*)((C_word*)t0)[10])[1]);}

/* k22099 in k22083 in k22079 in k22075 in k22064 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_22101(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_22101,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_22105,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=t1,tmp=(C_word)a,a+=14,tmp);
/* scrutinizer.scm:2640: type->pp-string */
f_20840(t2,((C_word*)t0)[13]);}

/* k22103 in k22099 in k22083 in k22079 in k22075 in k22064 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_22105(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,15)))){
C_save_and_reclaim((void *)f_22105,c,av);}
/* scrutinizer.scm:2619: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 16) {
  av2=av;
} else {
  av2=C_alloc(16);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[176];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=((C_word*)t0)[8];
av2[10]=((C_word*)t0)[9];
av2[11]=((C_word*)t0)[10];
av2[12]=((C_word*)t0)[11];
av2[13]=((C_word*)t0)[12];
av2[14]=((C_word*)t0)[13];
av2[15]=t1;
f_21876(16,av2);}}

/* chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_22110(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8){
C_word tmp;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,2)))){
C_save_and_reclaim_args((void *)trf_22110,8,t1,t2,t3,t4,t5,t6,t7,t8);}
a=C_alloc(16);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22115,a[2]=t10,a[3]=t3,a[4]=t1,a[5]=t2,a[6]=t4,a[7]=t8,a[8]=t5,a[9]=t6,a[10]=t7,tmp=(C_word)a,a+=11,tmp);
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f28508,a[2]=t11,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2543: chicken.compiler.support#node-subexpressions */
t13=*((C_word*)lf[87]+1);{
C_word av2[3];
av2[0]=t13;
av2[1]=t12;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}

/* k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22115(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,18)))){
C_save_and_reclaim((void *)f_22115,c,av);}
a=C_alloc(15);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_a_i_list1(&a,1,((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_22126,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[3],tmp=(C_word)a,a+=12,tmp);
/* scrutinizer.scm:2649: scheme#string-append */
t5=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 19) {
  av2=av;
} else {
  av2=C_alloc(19);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[546];
av2[3]=lf[547];
av2[4]=lf[548];
av2[5]=lf[549];
av2[6]=lf[550];
av2[7]=lf[551];
av2[8]=lf[552];
av2[9]=lf[553];
av2[10]=lf[554];
av2[11]=lf[555];
av2[12]=lf[556];
av2[13]=lf[557];
av2[14]=lf[558];
av2[15]=lf[559];
av2[16]=lf[560];
av2[17]=lf[561];
av2[18]=lf[562];
((C_proc)(void*)(*((C_word*)t5+1)))(19,av2);}}

/* k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_22126,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_22130,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* scrutinizer.scm:2667: pp-fragment */
f_21411(t2,((C_word*)t0)[11]);}

/* k22128 in k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22130,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22134,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:2669: strip-namespace */
f_19651(t2,((C_word*)((C_word*)t0)[8])[1]);}

/* k22132 in k22128 in k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22134,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22138,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:2670: type->pp-string */
f_20840(t2,((C_word*)t0)[12]);}

/* k22136 in k22132 in k22128 in k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22138(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22138,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22142,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:2671: type->pp-string */
f_20840(t2,((C_word*)t0)[12]);}

/* k22140 in k22136 in k22132 in k22128 in k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_22142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22142,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22146,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:2672: describe-expression */
f_21746(t2,((C_word*)t0)[12]);}

/* k22144 in k22140 in k22136 in k22132 in k22128 in k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_22146(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22146,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22150,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:2673: variable-from-module */
f_21686(t2,((C_word*)((C_word*)t0)[12])[1]);}

/* k22148 in k22144 in k22140 in k22136 in k22132 in k22128 in k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_22150(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22150,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22154,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:2674: type->pp-string */
f_20840(t2,((C_word*)t0)[12]);}

/* k22152 in k22148 in k22144 in k22140 in k22136 in k22132 in k22128 in k22124 in k22113 in chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_22154(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,14)))){
C_save_and_reclaim((void *)f_22154,c,av);}
/* scrutinizer.scm:2644: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 15) {
  av2=av;
} else {
  av2=C_alloc(15);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[545];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=((C_word*)t0)[8];
av2[10]=((C_word*)t0)[9];
av2[11]=((C_word*)t0)[10];
av2[12]=((C_word*)t0)[11];
av2[13]=((C_word*)t0)[12];
av2[14]=t1;
f_21876(15,av2);}}

/* chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_22156(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_22156,c,av);}
a=C_alloc(17);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22161,a[2]=t8,a[3]=t10,a[4]=t5,a[5]=t3,a[6]=t2,a[7]=t4,a[8]=t6,a[9]=t1,tmp=(C_word)a,a+=10,tmp);
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f28513,a[2]=t11,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2543: chicken.compiler.support#node-subexpressions */
t13=*((C_word*)lf[87]+1);{
C_word *av2=av;
av2[0]=t13;
av2[1]=t12;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}

/* k22159 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_22161,c,av);}
a=C_alloc(12);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22163,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp));
t4=C_i_length(((C_word*)t0)[8]);
t5=C_eqp(t4,C_fix(0));
if(C_truep(t5)){
/* scrutinizer.scm:2698: p */
t6=((C_word*)((C_word*)t0)[3])[1];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[9];
av2[2]=lf[572];
av2[3]=lf[573];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22226,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2701: chicken.base#open-output-string */
t7=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* f_22163 in k22159 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22163(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,8)))){
C_save_and_reclaim((void *)f_22163,c,av);}
a=C_alloc(17);
t4=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t5=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22175,a[2]=t1,a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t3,a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[3],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2684: scheme#string-append */
t6=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[565];
av2[3]=lf[566];
av2[4]=lf[567];
av2[5]=lf[568];
av2[6]=lf[569];
av2[7]=lf[570];
av2[8]=lf[571];
((C_proc)(void*)(*((C_word*)t6+1)))(9,av2);}}

/* k22173 */
static void C_ccall f_22175(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22175,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22179,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2692: pp-fragment */
f_21411(t2,((C_word*)t0)[10]);}

/* k22177 in k22173 */
static void C_ccall f_22179(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_22179,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22183,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_zerop(((C_word*)t0)[7]))){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[563];
f_22183(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22191,a[2]=t2,a[3]=((C_word*)t0)[10],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2694: chicken.base#open-output-string */
t4=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k22181 in k22177 in k22173 */
static void C_ccall f_22183(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22183,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22187,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2696: describe-expression */
f_21746(t2,((C_word*)t0)[10]);}

/* k22185 in k22181 in k22177 in k22173 */
static void C_ccall f_22187(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,11)))){
C_save_and_reclaim((void *)f_22187,c,av);}
/* scrutinizer.scm:2679: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 12) {
  av2=av;
} else {
  av2=C_alloc(12);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=((C_word*)t0)[6];
av2[7]=((C_word*)t0)[7];
av2[8]=((C_word*)t0)[8];
av2[9]=((C_word*)t0)[9];
av2[10]=((C_word*)t0)[10];
av2[11]=t1;
f_21876(12,av2);}}

/* k22189 in k22177 in k22173 */
static void C_ccall f_22191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22191,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22197,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2694: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[564];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22195 in k22189 in k22177 in k22173 */
static void C_ccall f_22197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22197,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22200,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22210,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2694: strip-namespace */
f_19651(t3,((C_word*)((C_word*)t0)[4])[1]);}

/* k22198 in k22195 in k22189 in k22177 in k22173 */
static void C_ccall f_22200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_22200,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22203,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2694: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(39);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k22201 in k22198 in k22195 in k22189 in k22177 in k22173 */
static void C_ccall f_22203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22203,c,av);}
/* scrutinizer.scm:2694: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22208 in k22195 in k22189 in k22177 in k22173 */
static void C_ccall f_22210(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22210,c,av);}
/* scrutinizer.scm:2694: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22224 in k22159 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22226,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22232,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2701: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[576];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22230 in k22224 in k22159 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22232(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22232,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22235,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2701: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_length(((C_word*)t0)[5]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22233 in k22230 in k22224 in k22159 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22235(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22235,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22238,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2701: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[575];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22236 in k22233 in k22230 in k22224 in k22159 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22238(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22238,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22241,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2701: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22239 in k22236 in k22233 in k22230 in k22224 in k22159 in chicken.compiler.scrutinizer#r-proc-call-argument-value-count in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_22241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22241,c,av);}
/* scrutinizer.scm:2700: p */
t2=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[574];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_22249(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_22249,6,t1,t2,t3,t4,t5,t6);}
a=C_alloc(14);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22254,a[2]=t8,a[3]=t3,a[4]=t1,a[5]=t2,a[6]=t4,a[7]=t5,a[8]=t6,tmp=(C_word)a,a+=9,tmp);
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f28518,a[2]=t9,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2543: chicken.compiler.support#node-subexpressions */
t11=*((C_word*)lf[87]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}

/* k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22254(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_22254,c,av);}
a=C_alloc(13);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22261,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[2],tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_i_negativep(((C_word*)t0)[6]))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22334,a[2]=t3,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2708: chicken.base#open-output-string */
t5=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22352,a[2]=t3,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2709: chicken.base#open-output-string */
t5=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22261(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,6)))){
C_save_and_reclaim((void *)f_22261,c,av);}
a=C_alloc(14);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22269,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[2],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2715: scheme#string-append */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[582];
av2[3]=lf[583];
av2[4]=lf[584];
av2[5]=lf[585];
av2[6]=lf[586];
((C_proc)(void*)(*((C_word*)t4+1)))(7,av2);}}

/* k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22269(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22269,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22273,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2721: pp-fragment */
f_21411(t2,((C_word*)t0)[10]);}

/* k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22273,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22277,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2722: variable-from-module */
f_21686(t2,((C_word*)((C_word*)t0)[10])[1]);}

/* k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_22277,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22281,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_i_negativep(((C_word*)t0)[8]))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22285,a[2]=t2,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2724: chicken.base#open-output-string */
t4=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22303,a[2]=t2,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[8],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2725: chicken.base#open-output-string */
t4=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k22279 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_22281(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_22281,c,av);}
/* scrutinizer.scm:2706: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=((C_word*)t0)[6];
av2[7]=((C_word*)t0)[7];
av2[8]=((C_word*)t0)[8];
av2[9]=t1;
f_21876(10,av2);}}

/* k22283 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_22285(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22285,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22291,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2724: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[577];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22289 in k22283 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_22291(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_22291,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22294,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2724: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22292 in k22289 in k22283 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_22294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_22294,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22297,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2724: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(46);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k22295 in k22292 in k22289 in k22283 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_22297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22297,c,av);}
/* scrutinizer.scm:2724: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_22303(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_22303,c,av);}
a=C_alloc(7);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22309,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2725: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[581];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22307 in k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_22309(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22309,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22312,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2725: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22310 in k22307 in k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_22312(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22312,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22315,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2725: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[580];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22313 in k22310 in k22307 in k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_22315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22315,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22318,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2725: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22316 in k22313 in k22310 in k22307 in k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in ... */
static void C_ccall f_22318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22318,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22321,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2725: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[579];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22319 in k22316 in k22313 in k22310 in k22307 in k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in ... */
static void C_ccall f_22321(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_22321,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22324,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2725: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22322 in k22319 in k22316 in k22313 in k22310 in k22307 in k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in ... */
static void C_ccall f_22324(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_22324,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22327,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2725: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[578];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22325 in k22322 in k22319 in k22316 in k22313 in k22310 in k22307 in k22301 in k22275 in k22271 in k22267 in k22259 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in ... */
static void C_ccall f_22327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22327,c,av);}
/* scrutinizer.scm:2725: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22332 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22334,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22340,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2708: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[588];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22338 in k22332 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22340(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_22340,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22343,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2708: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22341 in k22338 in k22332 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22343(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_22343,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22346,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2708: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[587];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22344 in k22341 in k22338 in k22332 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22346(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22346,c,av);}
/* scrutinizer.scm:2708: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22350 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22352(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22352,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22358,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=C_i_string_ref(((C_word*)t0)[3],C_fix(0));
/* scrutinizer.scm:2709: ##sys#print */
t5=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_u_i_char_upcase(t4);
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k22356 in k22350 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22358(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_22358,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22361,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22371,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2711: scheme#substring */
t4=*((C_word*)lf[590]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=C_fix(1);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k22359 in k22356 in k22350 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22361(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_22361,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22364,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2709: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[589];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22362 in k22359 in k22356 in k22350 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22364(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22364,c,av);}
/* scrutinizer.scm:2709: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22369 in k22356 in k22350 in k22252 in chicken.compiler.scrutinizer#r-index-out-of-range in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22371(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22371,c,av);}
/* scrutinizer.scm:2709: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_22381(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_22381,c,av);}
a=C_alloc(10);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22384,a[2]=t4,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t7=C_i_length(t5);
t8=C_eqp(t7,C_fix(0));
if(C_truep(t8)){
/* scrutinizer.scm:2743: p */
t9=t6;
f_22384(t9,t1,lf[598],lf[599]);}
else{
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22420,a[2]=t6,a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2746: chicken.base#open-output-string */
t10=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}

/* p in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_22384(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,8)))){
C_save_and_reclaim_args((void *)trf_22384,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22396,a[2]=t1,a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=t3,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2731: scheme#string-append */
t6=*((C_word*)lf[77]+1);{
C_word av2[9];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[591];
av2[3]=lf[592];
av2[4]=lf[593];
av2[5]=lf[594];
av2[6]=lf[595];
av2[7]=lf[596];
av2[8]=lf[597];
((C_proc)(void*)(*((C_word*)t6+1)))(9,av2);}}

/* k22394 in p in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22396(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22396,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22400,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2739: pp-fragment */
f_21411(t2,((C_word*)t0)[8]);}

/* k22398 in k22394 in p in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22400,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22404,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2741: describe-expression */
f_21746(t2,((C_word*)t0)[8]);}

/* k22402 in k22398 in k22394 in p in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22404(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_22404,c,av);}
/* scrutinizer.scm:2729: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=((C_word*)t0)[6];
av2[7]=((C_word*)t0)[7];
av2[8]=((C_word*)t0)[8];
av2[9]=t1;
f_21876(10,av2);}}

/* k22418 in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22420(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22420,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22426,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2746: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[602];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22424 in k22418 in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22426,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22429,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2746: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_length(((C_word*)t0)[5]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22427 in k22424 in k22418 in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22429(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22429,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22432,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2746: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[601];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22430 in k22427 in k22424 in k22418 in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22432(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22432,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22435,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2746: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22433 in k22430 in k22427 in k22424 in k22418 in chicken.compiler.scrutinizer#r-conditional-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22435(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22435,c,av);}
/* scrutinizer.scm:2745: p */
t2=((C_word*)t0)[2];
f_22384(t2,((C_word*)t0)[3],lf[600],t1);}

/* chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_22443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_22443,c,av);}
a=C_alloc(12);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22446,a[2]=t5,a[3]=t4,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t8=C_i_length(t6);
t9=C_eqp(t8,C_fix(0));
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22483,a[2]=t7,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2765: chicken.base#open-output-string */
t11=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22509,a[2]=t7,a[3]=t1,a[4]=t6,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2767: chicken.base#open-output-string */
t11=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}

/* p in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_22446(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,8)))){
C_save_and_reclaim_args((void *)trf_22446,4,t0,t1,t2,t3);}
a=C_alloc(16);
t4=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22458,a[2]=t1,a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=t3,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[3],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2752: scheme#string-append */
t6=*((C_word*)lf[77]+1);{
C_word av2[9];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[603];
av2[3]=lf[604];
av2[4]=lf[605];
av2[5]=lf[606];
av2[6]=lf[607];
av2[7]=lf[608];
av2[8]=lf[609];
((C_proc)(void*)(*((C_word*)t6+1)))(9,av2);}}

/* k22456 in p in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22458(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22458,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22462,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2760: pp-fragment */
f_21411(t2,((C_word*)t0)[9]);}

/* k22460 in k22456 in p in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22462,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22466,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2761: chicken.compiler.support#real-name */
t3=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22464 in k22460 in k22456 in p in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22466(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22466,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22470,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2763: describe-expression */
f_21746(t2,((C_word*)t0)[9]);}

/* k22468 in k22464 in k22460 in k22456 in p in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22470(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,10)))){
C_save_and_reclaim((void *)f_22470,c,av);}
/* scrutinizer.scm:2750: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=((C_word*)t0)[6];
av2[7]=((C_word*)t0)[7];
av2[8]=((C_word*)t0)[8];
av2[9]=((C_word*)t0)[9];
av2[10]=t1;
f_21876(11,av2);}}

/* k22481 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22483,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22489,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2765: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[612];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22487 in k22481 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22489(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22489,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22492,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22502,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2765: chicken.compiler.support#real-name */
t4=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k22490 in k22487 in k22481 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22492(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22492,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22495,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2765: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[611];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22493 in k22490 in k22487 in k22481 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22495(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22495,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22498,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2765: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22496 in k22493 in k22490 in k22487 in k22481 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22498(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22498,c,av);}
/* scrutinizer.scm:2765: p */
t2=((C_word*)t0)[2];
f_22446(t2,((C_word*)t0)[3],t1,lf[610]);}

/* k22500 in k22487 in k22481 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22502(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22502,c,av);}
/* scrutinizer.scm:2765: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_22509,c,av);}
a=C_alloc(7);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22515,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2767: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[617];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22515(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22515,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22518,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22557,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2767: chicken.compiler.support#real-name */
t4=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22518(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22518,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22521,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2767: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[616];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22521(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22521,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22524,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2767: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_length(((C_word*)t0)[4]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22524,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22527,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2767: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[615];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22525 in k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_22527(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22527,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22530,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2767: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22528 in k22525 in k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_22530(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_22530,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22534,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2768: chicken.base#open-output-string */
t3=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k22532 in k22528 in k22525 in k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_22534(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_22534,c,av);}
a=C_alloc(7);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22540,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2768: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[614];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22538 in k22532 in k22528 in k22525 in k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_22540(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22540,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22543,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2768: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_length(((C_word*)t0)[6]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22541 in k22538 in k22532 in k22528 in k22525 in k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in ... */
static void C_ccall f_22543(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22543,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22546,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2768: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[613];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22544 in k22541 in k22538 in k22532 in k22528 in k22525 in k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in ... */
static void C_ccall f_22546(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22546,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22549,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2768: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22547 in k22544 in k22541 in k22538 in k22532 in k22528 in k22525 in k22522 in k22519 in k22516 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in ... */
static void C_ccall f_22549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22549,c,av);}
/* scrutinizer.scm:2767: p */
t2=((C_word*)t0)[2];
f_22446(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k22555 in k22513 in k22507 in chicken.compiler.scrutinizer#r-let-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22557(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22557,c,av);}
/* scrutinizer.scm:2767: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_22563(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_22563,c,av);}
a=C_alloc(12);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22566,a[2]=t5,a[3]=t4,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t8=C_i_length(t6);
t9=C_eqp(t8,C_fix(0));
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22603,a[2]=t7,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2787: chicken.base#open-output-string */
t11=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22629,a[2]=t7,a[3]=t1,a[4]=t6,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2789: chicken.base#open-output-string */
t11=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}

/* p in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_22566(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,8)))){
C_save_and_reclaim_args((void *)trf_22566,4,t0,t1,t2,t3);}
a=C_alloc(16);
t4=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22578,a[2]=t1,a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=t3,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[3],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2774: scheme#string-append */
t6=*((C_word*)lf[77]+1);{
C_word av2[9];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[618];
av2[3]=lf[619];
av2[4]=lf[620];
av2[5]=lf[621];
av2[6]=lf[622];
av2[7]=lf[623];
av2[8]=lf[624];
((C_proc)(void*)(*((C_word*)t6+1)))(9,av2);}}

/* k22576 in p in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22578(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22578,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22582,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2782: pp-fragment */
f_21411(t2,((C_word*)t0)[9]);}

/* k22580 in k22576 in p in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22582(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22582,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22586,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2783: strip-namespace */
f_19651(t2,((C_word*)t0)[9]);}

/* k22584 in k22580 in k22576 in p in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22586,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22590,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2785: describe-expression */
f_21746(t2,((C_word*)t0)[9]);}

/* k22588 in k22584 in k22580 in k22576 in p in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,10)))){
C_save_and_reclaim((void *)f_22590,c,av);}
/* scrutinizer.scm:2772: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 11) {
  av2=av;
} else {
  av2=C_alloc(11);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=((C_word*)t0)[6];
av2[7]=((C_word*)t0)[7];
av2[8]=((C_word*)t0)[8];
av2[9]=((C_word*)t0)[9];
av2[10]=t1;
f_21876(11,av2);}}

/* k22601 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22603(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22603,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22609,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2787: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[627];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22607 in k22601 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22609(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22609,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22612,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22622,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2787: strip-namespace */
f_19651(t3,((C_word*)t0)[5]);}

/* k22610 in k22607 in k22601 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22612(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22612,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22615,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2787: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[626];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22613 in k22610 in k22607 in k22601 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22615(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22615,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22618,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2787: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22616 in k22613 in k22610 in k22607 in k22601 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22618(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22618,c,av);}
/* scrutinizer.scm:2787: p */
t2=((C_word*)t0)[2];
f_22566(t2,((C_word*)t0)[3],t1,lf[625]);}

/* k22620 in k22607 in k22601 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22622(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22622,c,av);}
/* scrutinizer.scm:2787: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_22629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_22629,c,av);}
a=C_alloc(7);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22635,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2789: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[632];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22635,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22638,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22677,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2789: strip-namespace */
f_19651(t3,((C_word*)t0)[6]);}

/* k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22638(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22638,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22641,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2789: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[631];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22641(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22641,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22644,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2789: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_length(((C_word*)t0)[4]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_22644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22644,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22647,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2789: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[630];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22645 in k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_22647(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22647,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22650,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2789: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22648 in k22645 in k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_22650(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_22650,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22654,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2790: chicken.base#open-output-string */
t3=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k22652 in k22648 in k22645 in k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_22654(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_22654,c,av);}
a=C_alloc(7);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22660,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2790: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[629];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22658 in k22652 in k22648 in k22645 in k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_22660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22660,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22663,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2790: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_length(((C_word*)t0)[6]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22661 in k22658 in k22652 in k22648 in k22645 in k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in ... */
static void C_ccall f_22663(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22663,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22666,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2790: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[628];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22664 in k22661 in k22658 in k22652 in k22648 in k22645 in k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in ... */
static void C_ccall f_22666(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22666,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22669,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2790: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22667 in k22664 in k22661 in k22658 in k22652 in k22648 in k22645 in k22642 in k22639 in k22636 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in ... */
static void C_ccall f_22669(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22669,c,av);}
/* scrutinizer.scm:2789: p */
t2=((C_word*)t0)[2];
f_22566(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k22675 in k22633 in k22627 in chicken.compiler.scrutinizer#r-assignment-value-count-invalid in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22677(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22677,c,av);}
/* scrutinizer.scm:2789: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22686 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_22688(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,14)))){
C_save_and_reclaim((void *)f_22688,c,av);}
a=C_alloc(12);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_a_i_list1(&a,1,((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22699,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2798: scheme#string-append */
t5=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 15) {
  av2=av;
} else {
  av2=C_alloc(15);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[130];
av2[3]=lf[131];
av2[4]=lf[132];
av2[5]=lf[133];
av2[6]=lf[134];
av2[7]=lf[135];
av2[8]=lf[136];
av2[9]=lf[137];
av2[10]=lf[138];
av2[11]=lf[139];
av2[12]=lf[140];
av2[13]=lf[141];
av2[14]=lf[142];
((C_proc)(void*)(*((C_word*)t5+1)))(15,av2);}}

/* k22697 in k22686 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_22699(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22699,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22703,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2812: pp-fragment */
f_21411(t2,((C_word*)t0)[8]);}

/* k22701 in k22697 in k22686 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22703(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22703,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22707,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2813: variable-from-module */
f_21686(t2,((C_word*)((C_word*)t0)[8])[1]);}

/* k22705 in k22701 in k22697 in k22686 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in ... */
static void C_ccall f_22707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22707,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22711,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2814: type->pp-string */
f_20840(t2,((C_word*)t0)[8]);}

/* k22709 in k22705 in k22701 in k22697 in k22686 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in ... */
static void C_ccall f_22711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22711,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22715,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2815: type->pp-string */
f_20840(t2,((C_word*)t0)[8]);}

/* k22713 in k22709 in k22705 in k22701 in k22697 in k22686 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in ... */
static void C_ccall f_22715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,8)))){
C_save_and_reclaim((void *)f_22715,c,av);}
a=C_alloc(12);
t2=C_a_i_list(&a,4,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],t1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=lf[72];
av2[3]=lf[129];
av2[4]=*((C_word*)lf[74]+1);
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=t2;
C_apply(9,av2);}}

/* k22720 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f_22722(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,14)))){
C_save_and_reclaim((void *)f_22722,c,av);}
a=C_alloc(12);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_a_i_list1(&a,1,((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22733,a[2]=((C_word*)t0)[4],a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2823: scheme#string-append */
t5=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 15) {
  av2=av;
} else {
  av2=C_alloc(15);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[146];
av2[3]=lf[147];
av2[4]=lf[148];
av2[5]=lf[149];
av2[6]=lf[150];
av2[7]=lf[151];
av2[8]=lf[152];
av2[9]=lf[153];
av2[10]=lf[154];
av2[11]=lf[155];
av2[12]=lf[156];
av2[13]=lf[157];
av2[14]=lf[158];
((C_proc)(void*)(*((C_word*)t5+1)))(15,av2);}}

/* k22731 in k22720 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in ... */
static void C_ccall f_22733(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22733,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22737,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2837: pp-fragment */
f_21411(t2,((C_word*)t0)[8]);}

/* k22735 in k22731 in k22720 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in ... */
static void C_ccall f_22737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22737,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22741,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2838: variable-from-module */
f_21686(t2,((C_word*)((C_word*)t0)[8])[1]);}

/* k22739 in k22735 in k22731 in k22720 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in ... */
static void C_ccall f_22741(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22741,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22745,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2839: type->pp-string */
f_20840(t2,((C_word*)t0)[8]);}

/* k22743 in k22739 in k22735 in k22731 in k22720 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in ... */
static void C_ccall f_22745(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_22745,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22749,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2840: type->pp-string */
f_20840(t2,((C_word*)t0)[8]);}

/* k22747 in k22743 in k22739 in k22735 in k22731 in k22720 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in ... */
static void C_ccall f_22749(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,8)))){
C_save_and_reclaim((void *)f_22749,c,av);}
a=C_alloc(12);
t2=C_a_i_list(&a,4,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],t1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=lf[72];
av2[3]=lf[145];
av2[4]=*((C_word*)lf[74]+1);
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=((C_word*)t0)[8];
av2[8]=t2;
C_apply(9,av2);}}

/* k22761 in k8684 in always-true in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22763,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22767,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2855: pp-fragment */
f_21411(t2,((C_word*)t0)[6]);}

/* k22765 in k22761 in k8684 in always-true in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22767(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22767,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22771,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2856: type->pp-string */
f_20840(t2,((C_word*)t0)[6]);}

/* k22769 in k22765 in k22761 in k8684 in always-true in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,8)))){
C_save_and_reclaim((void *)f_22771,c,av);}
a=C_alloc(6);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[72];
av2[3]=lf[73];
av2[4]=*((C_word*)lf[74]+1);
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=t2;
C_apply(9,av2);}}

/* k22783 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22785(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_22785,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22789,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2869: pp-fragment */
f_21411(t2,((C_word*)t0)[5]);}

/* k22787 in k22783 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22789(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,8)))){
C_save_and_reclaim((void *)f_22789,c,av);}
a=C_alloc(3);
t2=C_a_i_list(&a,1,t1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[72];
av2[3]=lf[214];
av2[4]=*((C_word*)lf[74]+1);
av2[5]=((C_word*)t0)[3];
av2[6]=((C_word*)t0)[4];
av2[7]=((C_word*)t0)[5];
av2[8]=t2;
C_apply(9,av2);}}

/* k22801 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22803(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22803,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22807,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2886: pp-fragment */
f_21411(t2,((C_word*)t0)[6]);}

/* k22805 in k22801 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22807,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22811,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2887: type->pp-string */
f_20840(t2,((C_word*)t0)[6]);}

/* k22809 in k22805 in k22801 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_22811,c,av);}
/* scrutinizer.scm:2873: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[279];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=t1;
f_21876(9,av2);}}

/* k22823 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22825,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22829,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2905: pp-fragment */
f_21411(t2,((C_word*)t0)[7]);}

/* k22827 in k22823 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22829,c,av);}
a=C_alloc(8);
t2=C_i_length(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22837,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=t2,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2907: type->pp-string */
f_20840(t3,((C_word*)t0)[7]);}

/* k22835 in k22827 in k22823 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22837(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_22837,c,av);}
/* scrutinizer.scm:2890: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[302];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=t1;
f_21876(10,av2);}}

/* k22849 in k11355 in k11352 in k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22851,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22855,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2929: pp-fragment */
f_21411(t2,((C_word*)t0)[7]);}

/* k22853 in k22849 in k11355 in k11352 in k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22855,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22859,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2930: type->pp-string */
f_20840(t2,((C_word*)t0)[7]);}

/* k22857 in k22853 in k22849 in k11355 in k11352 in k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22859,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22863,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2931: type->pp-string */
f_20840(t2,((C_word*)t0)[7]);}

/* k22861 in k22857 in k22853 in k22849 in k11355 in k11352 in k11346 in k11321 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_22863(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_22863,c,av);}
/* scrutinizer.scm:2910: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[287];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=t1;
f_21876(10,av2);}}

/* k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22883(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_22883,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22887,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22952,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2954: node-source-prefix */
f_21435(t3,((C_word*)t0)[5]);}

/* k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_22887,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22891,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2957: location-name */
f_21465(t2,((C_word*)t0)[7],C_SCHEME_END_OF_LIST);}

/* k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22891(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22891,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22895,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:2958: pp-fragment */
f_21411(t2,((C_word*)t0)[7]);}

/* k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22895,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22899,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f26225,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2934: type->pp-string */
f_20840(t3,((C_word*)t0)[7]);}

/* k22897 in k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_22899(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_22899,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22903,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(((C_word*)t0)[7],lf[6]);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22913,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22915,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_22915(t12,t8,((C_word*)t0)[7]);}

/* k22901 in k22897 in k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_22903(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_22903,c,av);}
/* scrutinizer.scm:2935: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[313]+1);{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=((C_word*)t0)[7];
av2[7]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(8,av2);}}

/* k22911 in k22897 in k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_22913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22913,c,av);}
/* scrutinizer.scm:2960: chicken.string#string-intersperse */
t2=*((C_word*)lf[314]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[315];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop5660 in k22897 in k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_fcall f_22915(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_22915,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22940,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f26218,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2934: type->pp-string */
f_20840(t5,t4);}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k22938 in map-loop5660 in k22897 in k22893 in k22889 in k22885 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_22940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_22940,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_22915(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k22950 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22952(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_22952,c,av);}
a=C_alloc(3);
if(C_truep(C_u_i_string_equal_p(lf[319],t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[320];
f_22887(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22959,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2956: node-source-prefix */
f_21435(t2,((C_word*)t0)[3]);}}

/* k22957 in k22950 in k22881 in loop in k11412 in k11409 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_22959(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22959,c,av);}
/* scrutinizer.scm:2956: chicken.string#conc */
t2=*((C_word*)lf[321]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[322];
av2[3]=t1;
av2[4]=lf[323];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22971 in k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_22973(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_22973,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22977,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2982: pp-fragment */
f_21411(t2,((C_word*)t0)[9]);}

/* k22975 in k22971 in k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_22977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22977,c,av);}
a=C_alloc(11);
t2=C_i_length(((C_word*)t0)[2]);
t3=C_u_i_length(((C_word*)t0)[2]);
t4=C_i_nequalp(t3,C_fix(1));
t5=(C_truep(t4)?lf[172]:lf[173]);
t6=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22989,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t1,a[8]=t2,a[9]=t5,a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:2984: pp-fragment */
f_21411(t6,((C_word*)t0)[9]);}

/* k22987 in k22975 in k22971 in k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_22989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_22989,c,av);}
a=C_alloc(12);
t2=C_i_length(((C_word*)t0)[2]);
t3=C_u_i_length(((C_word*)t0)[2]);
t4=C_i_nequalp(t3,C_fix(1));
t5=(C_truep(t4)?lf[172]:lf[173]);
t6=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_23001,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=t1,a[10]=t2,a[11]=t5,tmp=(C_word)a,a+=12,tmp);
/* scrutinizer.scm:2986: pp-fragment */
f_21411(t6,((C_word*)t0)[10]);}

/* k22999 in k22987 in k22975 in k22971 in k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_23001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,13)))){
C_save_and_reclaim((void *)f_23001,c,av);}
/* scrutinizer.scm:2963: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 14) {
  av2=av;
} else {
  av2=C_alloc(14);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[199];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=((C_word*)t0)[8];
av2[10]=((C_word*)t0)[9];
av2[11]=((C_word*)t0)[10];
av2[12]=((C_word*)t0)[11];
av2[13]=t1;
f_21876(14,av2);}}

/* k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_23019,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_23023,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:3008: pp-fragment */
f_21411(t2,((C_word*)t0)[8]);}

/* k23021 in k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23023(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_23023,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_23027,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:3009: strip-namespace */
f_19651(t2,((C_word*)t0)[7]);}

/* k23025 in k23021 in k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_23027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_23027,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_23031,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:3010: type->pp-string */
f_20840(t2,((C_word*)t0)[9]);}

/* k23029 in k23025 in k23021 in k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_23031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_23031,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_23035,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23043,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:3012: chicken.compiler.support#real-name */
t4=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k23033 in k23029 in k23025 in k23021 in k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_23035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_23035,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_23039,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:3014: type->pp-string */
f_20840(t2,((C_word*)t0)[9]);}

/* k23037 in k23033 in k23029 in k23025 in k23021 in k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_23039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,11)))){
C_save_and_reclaim((void *)f_23039,c,av);}
/* scrutinizer.scm:2989: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 12) {
  av2=av;
} else {
  av2=C_alloc(12);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[252];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=((C_word*)t0)[7];
av2[9]=((C_word*)t0)[8];
av2[10]=((C_word*)t0)[9];
av2[11]=t1;
f_21876(12,av2);}}

/* k23041 in k23029 in k23025 in k23021 in k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_23043(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_23043,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23046,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_symbolp(t1))){
/* scrutinizer.scm:3011: variable-from-module */
f_21686(((C_word*)t0)[2],t1);}
else{
/* scrutinizer.scm:3013: scheme#string->symbol */
t3=*((C_word*)lf[253]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k23044 in k23041 in k23029 in k23025 in k23021 in k23017 in k10645 in k10642 in k10378 in k10375 in k10372 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_23046(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23046,c,av);}
/* scrutinizer.scm:3011: variable-from-module */
f_21686(((C_word*)t0)[2],t1);}

/* chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_23054(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_23054,5,t1,t2,t3,t4,t5);}
a=C_alloc(7);
t6=C_i_nullp(t5);
t7=(C_truep(t6)?C_SCHEME_FALSE:C_i_car(t5));
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23065,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=t7,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:3018: chicken.base#open-output-string */
t9=*((C_word*)lf[243]+1);{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_23065(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_23065,c,av);}
a=C_alloc(8);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23071,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:3018: ##sys#print */
t4=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[641];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_23071(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_23071,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23074,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23132,a[2]=t2,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:3018: strip-namespace */
f_19651(t3,((C_word*)t0)[6]);}

/* k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_23074(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_23074,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23077,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:3018: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(39);
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_23077(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_23077,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23080,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:3018: chicken.base#get-output-string */
t3=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in ... */
static void C_ccall f_23080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,7)))){
C_save_and_reclaim((void *)f_23080,c,av);}
a=C_alloc(12);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_23088,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[2],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:3022: scheme#string-append */
t4=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[635];
av2[3]=lf[636];
av2[4]=lf[637];
av2[5]=lf[638];
av2[6]=lf[639];
av2[7]=lf[640];
((C_proc)(void*)(*((C_word*)t4+1)))(8,av2);}}

/* k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in ... */
static void C_ccall f_23088(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_23088,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_23092,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:3029: pp-fragment */
f_21411(t2,((C_word*)t0)[8]);}

/* k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in ... */
static void C_ccall f_23092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_23092,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_23096,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:3030: variable-from-module */
f_21686(t2,((C_word*)t0)[8]);}

/* k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in ... */
static void C_ccall f_23096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_23096,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_23100,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)t0)[8])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23103,a[2]=t2,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:3032: chicken.base#open-output-string */
t4=*((C_word*)lf[243]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[634];
f_23100(2,av2);}}}

/* k23098 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_23100(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_23100,c,av);}
/* scrutinizer.scm:3017: report2 */
t2=lf[72];{
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[91]+1);
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=((C_word*)t0)[6];
av2[7]=((C_word*)t0)[7];
av2[8]=((C_word*)t0)[8];
av2[9]=t1;
f_21876(10,av2);}}

/* k23101 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in ... */
static void C_ccall f_23103(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_23103,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[236]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23109,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:3032: ##sys#write-char-0 */
t4=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(10);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k23107 in k23101 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in ... */
static void C_ccall f_23109(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_23109,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23112,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:3032: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k23110 in k23107 in k23101 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in ... */
static void C_ccall f_23112(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_23112,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23115,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:3032: ##sys#print */
t3=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[633];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k23113 in k23110 in k23107 in k23101 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in ... */
static void C_ccall f_23115(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_23115,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23118,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23128,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:3033: variable-from-module */
f_21686(t3,((C_word*)t0)[4]);}

/* k23116 in k23113 in k23110 in k23107 in k23101 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in ... */
static void C_ccall f_23118(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_23118,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23121,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:3032: ##sys#write-char-0 */
t3=*((C_word*)lf[240]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(46);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k23119 in k23116 in k23113 in k23110 in k23107 in k23101 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in ... */
static void C_ccall f_23121(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23121,c,av);}
/* scrutinizer.scm:3032: chicken.base#get-output-string */
t2=*((C_word*)lf[239]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k23126 in k23113 in k23110 in k23107 in k23101 in k23094 in k23090 in k23086 in k23078 in k23075 in k23072 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in ... */
static void C_ccall f_23128(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_23128,c,av);}
/* scrutinizer.scm:3032: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k23130 in k23069 in k23063 in chicken.compiler.scrutinizer#r-deprecated-identifier in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_23132(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_23132,c,av);}
/* scrutinizer.scm:3018: ##sys#print */
t2=*((C_word*)lf[241]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a23143 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_23144,c,av);}
a=C_alloc(5);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23148,a[2]=t3,a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2255: chicken.compiler.support#node-subexpressions */
t7=*((C_word*)lf[87]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k23146 in a23143 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_23148,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=C_i_length(t1);
t3=C_eqp(t2,C_fix(2));
if(C_truep(t3)){
t4=C_i_cadr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f26910,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k23187 */
static void C_ccall f_23189(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23189,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[48],t1);
t3=C_a_i_list(&a,1,t2);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?t3:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a23205 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23206(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_23206,c,av);}
a=C_alloc(15);
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=lf[25];
t11=C_i_cdr(t3);
t12=C_i_check_list_2(t11,lf[6]);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23227,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23229,a[2]=t8,a[3]=t15,a[4]=t9,tmp=(C_word)a,a+=5,tmp));
t17=((C_word*)t15)[1];
f_23229(t17,t13,t11);}

/* k23225 in a23205 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23227,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[51],t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop4623 in a23205 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_23229(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_23229,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26915,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a23262 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23263(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_23263,c,av);}
a=C_alloc(15);
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=lf[25];
t11=C_i_cdr(t3);
t12=C_i_check_list_2(t11,lf[6]);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23284,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23286,a[2]=t8,a[3]=t15,a[4]=t9,tmp=(C_word)a,a+=5,tmp));
t17=((C_word*)t15)[1];
f_23286(t17,t13,t11);}

/* k23282 in a23262 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23284,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[51],t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop4589 in a23262 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_23286(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_23286,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26922,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a23319 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23320(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_23320,c,av);}
a=C_alloc(15);
t6=C_i_cdr(t3);
if(C_truep(C_i_nullp(t6))){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=lf[646];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=lf[25];
t12=C_u_i_cdr(t3);
t13=C_i_check_list_2(t12,lf[6]);
t14=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23345,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23347,a[2]=t9,a[3]=t16,a[4]=t10,tmp=(C_word)a,a+=5,tmp));
t18=((C_word*)t16)[1];
f_23347(t18,t14,t12);}}

/* k23343 in a23319 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23345(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23345,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[48],t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop4555 in a23319 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_23347(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_23347,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26929,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a23384 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23385(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_23385,c,av);}
a=C_alloc(15);
t6=C_i_cdr(t3);
if(C_truep(C_i_nullp(t6))){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=lf[648];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=lf[25];
t12=C_u_i_cdr(t3);
t13=C_i_check_list_2(t12,lf[6]);
t14=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23410,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23412,a[2]=t9,a[3]=t16,a[4]=t10,tmp=(C_word)a,a+=5,tmp));
t18=((C_word*)t16)[1];
f_23412(t18,t14,t12);}}

/* k23408 in a23384 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_23410,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,lf[48],t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop4521 in a23384 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_23412(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_23412,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26936,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k23450 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_23452,c,av);}
/* scrutinizer.scm:2229: ##sys#put! */
t2=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[650];
av2[3]=lf[275];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a23453 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_23454,c,av);}
a=C_alloc(3);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list1(&a,1,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k23460 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_23462,c,av);}
/* scrutinizer.scm:2223: ##sys#put! */
t2=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[651];
av2[3]=lf[275];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a23463 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23464(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_23464,c,av);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t3))){
t4=C_i_cadr(t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_a_i_list1(&a,1,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* a23479 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23480(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_23480,c,av);}
a=C_alloc(6);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23484,a[2]=t3,a[3]=t1,a[4]=t5,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2146: known-length-vector-index */
f_19701(t6,t2,t3,t4,C_fix(3));}

/* k23482 in a23479 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23484(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_23484,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23493,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2147: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k23491 in k23482 in a23479 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23493(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_23493,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_i_cadr(t1);
if(C_truep(t2)){
t3=C_i_cadddr(t1);
if(C_truep(t3)){
t4=C_i_cadddr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f26943,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=t3,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k23518 in k23529 */
static void C_ccall f_23520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23520,c,av);}
t2=lf[654];
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?t2:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k23529 */
static void C_ccall f_23531(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_23531,c,av);}
a=C_alloc(22);
t2=(C_truep(t1)?lf[652]:lf[653]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23520,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_a_i_list(&a,2,lf[124],((C_word*)t0)[4]);
t5=C_a_i_list(&a,4,t2,((C_word*)t0)[5],t4,((C_word*)t0)[6]);
/* scrutinizer.scm:2154: mutate-node! */
f_17510(t3,((C_word*)t0)[7],t5);}

/* a23536 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23537(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_23537,c,av);}
a=C_alloc(4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23541,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2100: chicken.compiler.support#node-subexpressions */
t7=*((C_word*)lf[87]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k23539 in a23536 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23541(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_23541,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_i_length(t1);
if(C_truep(C_fixnum_greater_or_equal_p(t2,C_fix(2)))){
t3=C_i_cadr(t1);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23602,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:2103: chicken.compiler.support#node-class */
t5=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k23592 in k23596 in k23600 in k23539 in a23536 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_23594,c,av);}
a=C_alloc(9);
t2=C_a_i_list(&a,2,lf[53],t1);
t3=C_a_i_list(&a,1,t2);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?t3:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k23596 in k23600 in k23539 in a23536 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23598(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_23598,c,av);}
a=C_alloc(4);
t2=C_i_car(t1);
if(C_truep(t2)){
if(C_truep(C_i_symbolp(t2))){
t3=C_eqp(lf[658],t2);
if(C_truep(t3)){
t4=lf[659];
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?t4:((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23594,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2110: strip-namespace */
f_19651(t4,t2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k23600 in k23539 in a23536 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_23602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_23602,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[124],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23598,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:2104: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k6790 */
static void C_ccall f_6792(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6792,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6795,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_eval_toplevel(2,av2);}}

/* k6793 in k6790 */
static void C_ccall f_6795(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6795,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6798,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_data_2dstructures_toplevel(2,av2);}}

/* k6796 in k6793 in k6790 */
static void C_ccall f_6798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6798,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6801,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_expand_toplevel(2,av2);}}

/* k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6801(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6801,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6804,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_extras_toplevel(2,av2);}}

/* k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6804,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6807,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_pathname_toplevel(2,av2);}}

/* k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6807,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6810,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_port_toplevel(2,av2);}}

/* k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6810(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6810,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6813,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_support_toplevel(2,av2);}}

/* k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6813,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6816,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_internal_toplevel(2,av2);}}

/* k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6816(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(111,c,8)))){
C_save_and_reclaim((void *)f_6816,c,av);}
a=C_alloc(111);
t2=C_a_i_provide(&a,1,lf[0]);
t3=C_a_i_provide(&a,1,lf[1]);
t4=C_mutate(&lf[2] /* (set! chicken.compiler.scrutinizer#take ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_6926,tmp=(C_word)a,a+=2,tmp));
t5=C_mutate(&lf[3] /* (set! chicken.compiler.scrutinizer#append-map ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7017,tmp=(C_word)a,a+=2,tmp));
t6=C_mutate(&lf[9] /* (set! chicken.compiler.scrutinizer#every ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7187,tmp=(C_word)a,a+=2,tmp));
t7=C_mutate(&lf[7] /* (set! chicken.compiler.scrutinizer#any ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7221,tmp=(C_word)a,a+=2,tmp));
t8=C_mutate(&lf[10] /* (set! chicken.compiler.scrutinizer#delete-duplicates ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7382,tmp=(C_word)a,a+=2,tmp));
t9=C_mutate(&lf[11] /* (set! chicken.compiler.scrutinizer#filter-map ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7471,tmp=(C_word)a,a+=2,tmp));
t10=C_mutate(&lf[12] /* (set! chicken.compiler.scrutinizer#unzip1 ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7536,tmp=(C_word)a,a+=2,tmp));
t11=C_mutate(&lf[13] /* (set! chicken.compiler.scrutinizer#list-tabulate ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7829,tmp=(C_word)a,a+=2,tmp));
t12=C_mutate(&lf[14] /* (set! chicken.compiler.scrutinizer#lset=/eq? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7871,tmp=(C_word)a,a+=2,tmp));
t13=C_mutate(&lf[15] /* (set! chicken.compiler.scrutinizer#make-list ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8012,tmp=(C_word)a,a+=2,tmp));
t14=lf[16] /* chicken.compiler.scrutinizer#d-depth */ =C_fix(0);;
t15=lf[17] /* chicken.compiler.scrutinizer#scrutiny-debug */ =C_SCHEME_TRUE;;
t16=lf[18] /* chicken.compiler.scrutinizer#*complain?* */ =C_SCHEME_FALSE;;
t17=C_mutate(&lf[19] /* (set! chicken.compiler.scrutinizer#constant733 ...) */,lf[20]);
t18=C_mutate(&lf[21] /* (set! chicken.compiler.scrutinizer#constant740 ...) */,lf[22]);
t19=lf[23] /* chicken.compiler.scrutinizer#specialization-statistics */ =C_SCHEME_END_OF_LIST;;
t20=lf[24] /* chicken.compiler.scrutinizer#trail */ =C_SCHEME_END_OF_LIST;;
t21=C_mutate(&lf[25] /* (set! chicken.compiler.scrutinizer#walked-result ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8141,tmp=(C_word)a,a+=2,tmp));
t22=C_mutate(&lf[27] /* (set! chicken.compiler.scrutinizer#type-always-immediate? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8151,tmp=(C_word)a,a+=2,tmp));
t23=C_mutate((C_word*)lf[37]+1 /* (set! chicken.compiler.scrutinizer#scrutinize ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8194,tmp=(C_word)a,a+=2,tmp));
t24=C_mutate(&lf[244] /* (set! chicken.compiler.scrutinizer#smash-component-types! ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11712,tmp=(C_word)a,a+=2,tmp));
t25=C_mutate((C_word*)lf[171]+1 /* (set! chicken.compiler.scrutinizer#match-types ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11908,tmp=(C_word)a,a+=2,tmp));
t26=C_mutate(&lf[160] /* (set! chicken.compiler.scrutinizer#match-argument-types ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13496,tmp=(C_word)a,a+=2,tmp));
t27=C_mutate(&lf[50] /* (set! chicken.compiler.scrutinizer#simplify-type ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13568,tmp=(C_word)a,a+=2,tmp));
t28=C_mutate(&lf[381] /* (set! chicken.compiler.scrutinizer#merge-argument-types ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_14537,tmp=(C_word)a,a+=2,tmp));
t29=C_mutate(&lf[301] /* (set! chicken.compiler.scrutinizer#compatible-types? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_14775,tmp=(C_word)a,a+=2,tmp));
t30=C_mutate((C_word*)lf[383]+1 /* (set! chicken.compiler.scrutinizer#type<=? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_14834,tmp=(C_word)a,a+=2,tmp));
t31=C_mutate((C_word*)lf[274]+1 /* (set! chicken.compiler.scrutinizer#refine-types ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_14862,tmp=(C_word)a,a+=2,tmp));
t32=C_mutate(&lf[122] /* (set! chicken.compiler.scrutinizer#procedure-type? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15184,tmp=(C_word)a,a+=2,tmp));
t33=C_mutate(&lf[167] /* (set! chicken.compiler.scrutinizer#procedure-name ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15236,tmp=(C_word)a,a+=2,tmp));
t34=C_mutate(&lf[372] /* (set! chicken.compiler.scrutinizer#procedure-arguments ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15287,tmp=(C_word)a,a+=2,tmp));
t35=C_mutate(&lf[371] /* (set! chicken.compiler.scrutinizer#procedure-results ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15344,tmp=(C_word)a,a+=2,tmp));
t36=C_mutate(&lf[120] /* (set! chicken.compiler.scrutinizer#procedure-argument-types ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15401,tmp=(C_word)a,a+=2,tmp));
t37=C_mutate(&lf[389] /* (set! chicken.compiler.scrutinizer#named? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15752,tmp=(C_word)a,a+=2,tmp));
t38=C_mutate(&lf[367] /* (set! chicken.compiler.scrutinizer#rest-type ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15805,tmp=(C_word)a,a+=2,tmp));
t39=C_mutate(&lf[169] /* (set! chicken.compiler.scrutinizer#noreturn-procedure-type? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15825,tmp=(C_word)a,a+=2,tmp));
t40=C_mutate(&lf[403] /* (set! chicken.compiler.scrutinizer#noreturn-type? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15884,tmp=(C_word)a,a+=2,tmp));
t41=C_mutate(&lf[387] /* (set! chicken.compiler.scrutinizer#refinement-type? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15928,tmp=(C_word)a,a+=2,tmp));
t42=C_mutate(&lf[162] /* (set! chicken.compiler.scrutinizer#type-typeenv ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15975,tmp=(C_word)a,a+=2,tmp));
t43=C_mutate(&lf[159] /* (set! chicken.compiler.scrutinizer#trail-restore ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_16307,tmp=(C_word)a,a+=2,tmp));
t44=C_mutate(&lf[119] /* (set! chicken.compiler.scrutinizer#resolve ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_16350,tmp=(C_word)a,a+=2,tmp));
t45=C_mutate((C_word*)lf[407]+1 /* (set! chicken.compiler.scrutinizer#load-type-database ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_16815,tmp=(C_word)a,a+=2,tmp));
t46=C_mutate((C_word*)lf[433]+1 /* (set! chicken.compiler.scrutinizer#emit-types-file ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17289,tmp=(C_word)a,a+=2,tmp));
t47=lf[450] /* chicken.compiler.scrutinizer#node-mutations */ =C_SCHEME_END_OF_LIST;;
t48=C_mutate(&lf[161] /* (set! chicken.compiler.scrutinizer#mutate-node! ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17510,tmp=(C_word)a,a+=2,tmp));
t49=C_mutate(&lf[454] /* (set! chicken.compiler.scrutinizer#source-node ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17528,tmp=(C_word)a,a+=2,tmp));
t50=C_mutate(&lf[456] /* (set! chicken.compiler.scrutinizer#source-node-tree ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17555,tmp=(C_word)a,a+=2,tmp));
t51=C_mutate(&lf[126] /* (set! chicken.compiler.scrutinizer#specialize-node! ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17690,tmp=(C_word)a,a+=2,tmp));
t52=C_mutate((C_word*)lf[408]+1 /* (set! chicken.compiler.scrutinizer#validate-type ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17843,tmp=(C_word)a,a+=2,tmp));
t53=C_mutate((C_word*)lf[481]+1 /* (set! chicken.compiler.scrutinizer#check-and-validate-type ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_19224,tmp=(C_word)a,a+=2,tmp));
t54=C_mutate((C_word*)lf[409]+1 /* (set! chicken.compiler.scrutinizer#install-specializations ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_19258,tmp=(C_word)a,a+=2,tmp));
t55=C_mutate(&lf[388] /* (set! chicken.compiler.scrutinizer#canonicalize-list-type ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_19537,tmp=(C_word)a,a+=2,tmp));
t56=C_mutate(&lf[177] /* (set! chicken.compiler.scrutinizer#strip-namespace ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_19651,tmp=(C_word)a,a+=2,tmp));
t57=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19699,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t58=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_23537,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:2098: ##sys#put! */
t59=*((C_word*)lf[642]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t59;
av2[1]=t57;
av2[2]=lf[660];
av2[3]=lf[275];
av2[4]=t58;
((C_proc)(void*)(*((C_word*)t59+1)))(5,av2);}}

/* loop in a12059 in match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_6882(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_6882,4,t0,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t2))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6896,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:49: scheme#reverse */
t5=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_i_car(t2);
t5=C_eqp(lf[366],t4);
if(C_truep(C_i_not(t5))){
t6=C_u_i_cdr(t2);
t7=C_u_i_car(t2);
t8=C_a_i_cons(&a,2,t7,t3);
/* mini-srfi-1.scm:50: loop */
t10=t1;
t11=t6;
t12=t8;
t1=t10;
t2=t11;
t3=t12;
goto loop;}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6920,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:51: scheme#reverse */
t7=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}}

/* k6894 in loop in a12059 in match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6896,c,av);}
/* mini-srfi-1.scm:49: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
C_values(4,av2);}}

/* k6918 in loop in a12059 in match-rest in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6920(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6920,c,av);}
/* mini-srfi-1.scm:51: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
C_values(4,av2);}}

/* chicken.compiler.scrutinizer#take in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_6926(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_6926,3,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(0)))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6944,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:56: take */
t7=t5;
t8=C_u_i_cdr(t2);
t9=C_fixnum_difference(t3,C_fix(1));
t1=t7;
t2=t8;
t3=t9;
goto loop;}}

/* k6942 in chicken.compiler.scrutinizer#take in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_6944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_6944,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in a19913 in k20123 in k20127 */
static void C_fcall f_6984(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_6984,5,t0,t1,t2,t3,t4);}
a=C_alloc(4);
if(C_truep(C_fixnum_less_or_equal_p(t2,C_fix(0)))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6998,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:67: scheme#reverse */
t6=*((C_word*)lf[368]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_fixnum_difference(t2,C_fix(1));
t6=C_i_car(t4);
t7=C_a_i_cons(&a,2,t6,t3);
/* mini-srfi-1.scm:68: loop */
t9=t1;
t10=t5;
t11=t7;
t12=C_u_i_cdr(t4);
t1=t9;
t2=t10;
t3=t11;
t4=t12;
goto loop;}}

/* k6996 in loop in a19913 in k20123 in k20127 */
static void C_ccall f_6998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6998,c,av);}
/* mini-srfi-1.scm:67: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
C_values(4,av2);}}

/* chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7017(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_7017,4,t1,t2,t3,t4);}
a=C_alloc(9);
if(C_truep(C_i_nullp(t4))){
t5=C_i_check_list_2(t3,lf[4]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7032,a[2]=t2,a[3]=t7,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_7032(t9,t1,t3);}
else{
t5=C_a_i_cons(&a,2,t3,t4);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7072,a[2]=t7,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_7072(t9,t1,t5);}}

/* foldr194 in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7032(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_7032,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7040,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7059,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g199 in foldr194 in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7040(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_7040,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7048,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:72: proc */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k7046 in g199 in foldr194 in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7048(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7048,c,av);}
/* mini-srfi-1.scm:72: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k7057 in foldr194 in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7059(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7059,c,av);}
/* mini-srfi-1.scm:72: g199 */
t2=((C_word*)t0)[2];
f_7040(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7072(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_7072,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7079,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* mini-srfi-1.scm:74: any */
f_7221(t3,*((C_word*)lf[8]+1),t2);}

/* k7077 in loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_7079,c,av);}
a=C_alloc(21);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7086,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(((C_word*)t0)[4],lf[6]);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7151,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7153,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_7153(t12,t8,((C_word*)t0)[4]);}}

/* k7084 in k7077 in loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7086(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_7086,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7090,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7102,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7104,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_7104(t11,t7,((C_word*)t0)[4]);}

/* k7088 in k7084 in k7077 in loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7090(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7090,c,av);}
/* mini-srfi-1.scm:76: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k7100 in k7084 in k7077 in loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7102,c,av);}
/* mini-srfi-1.scm:77: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7072(t2,((C_word*)t0)[3],t1);}

/* map-loop236 in k7084 in k7077 in loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7104(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_7104,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_cdr(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k7149 in k7077 in loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7151(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7151,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop209 in k7077 in loop in chicken.compiler.scrutinizer#append-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7153(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_7153,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.compiler.scrutinizer#every in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7187(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_7187,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7193,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_7193(t7,t1,t3);}

/* loop in chicken.compiler.scrutinizer#every in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7193(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7193,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_nullp(t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7215,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:82: pred */
t5=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k7213 in loop in chicken.compiler.scrutinizer#every in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7215(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7215,c,av);}
if(C_truep(C_i_not(t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* mini-srfi-1.scm:83: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_7193(t2,((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[4]));}}

/* chicken.compiler.scrutinizer#any in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7221(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_7221,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7227,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_7227(t7,t1,t3);}

/* loop in chicken.compiler.scrutinizer#any in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7227(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7227,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7237,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:88: pred */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k7235 in loop in chicken.compiler.scrutinizer#any in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7237,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* mini-srfi-1.scm:89: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_7227(t2,((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[4]));}}

/* loop in k17347 in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_fcall f_7257(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_7257,4,t0,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7271,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:95: loop */
t6=t4;
t7=C_i_car(t3);
t8=C_u_i_cdr(t3);
t1=t6;
t2=t7;
t3=t8;
goto loop;}}

/* k7269 in loop in k17347 in k17333 in k17330 in k17327 in k17324 in k17321 in k17318 in k17312 in k17309 in g3596 in k17297 in a17294 in chicken.compiler.scrutinizer#emit-types-file in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_7271(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_7271,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in k20577 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_7285(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_7285,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7303,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:101: loop */
t6=t4;
t7=C_u_i_cdr(t2);
t1=t6;
t2=t7;
goto loop;}}

/* k7301 in loop in k20577 in collect in chicken.compiler.scrutinizer#over-all-instantiations in k20420 in k20325 in k20322 in k20157 in k20154 in k20151 in k20148 in k20145 in k20142 in k20139 in k19859 in k19856 in k19853 in k19697 in k6814 in k6811 in k6808 in ... */
static void C_ccall f_7303(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7303,c,av);}
/* mini-srfi-1.scm:101: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* loop in loop in chicken.compiler.scrutinizer#delete-duplicates in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7313(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_7313,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7326,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:106: test */
t4=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k7324 in loop in loop in chicken.compiler.scrutinizer#delete-duplicates in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7326(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_7326,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
/* mini-srfi-1.scm:107: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7313(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}
else{
t2=C_u_i_car(((C_word*)t0)[4]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7340,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:109: loop */
t4=((C_word*)((C_word*)t0)[2])[1];
f_7313(t4,t3,C_u_i_cdr(((C_word*)t0)[4]));}}

/* k7338 in k7324 in loop in loop in chicken.compiler.scrutinizer#delete-duplicates in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7340(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_7340,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#delete-duplicates in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7382(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_7382,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7388,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_7388(t7,t1,t2);}

/* loop in chicken.compiler.scrutinizer#delete-duplicates in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7388(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,0,3)))){
C_save_and_reclaim_args((void *)trf_7388,3,t0,t1,t2);}
a=C_alloc(17);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7402,a[2]=t4,a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7415,a[2]=((C_word*)t0)[2],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7313,a[2]=t8,a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_7313(t10,t6,t4);}}

/* k7400 in loop in chicken.compiler.scrutinizer#delete-duplicates in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7402(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_7402,c,av);}
a=C_alloc(3);
t2=C_i_equalp(((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?((C_word*)t0)[4]:C_a_i_cons(&a,2,((C_word*)t0)[5],t1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7413 in loop in chicken.compiler.scrutinizer#delete-duplicates in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7415,c,av);}
/* mini-srfi-1.scm:123: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7388(t2,((C_word*)t0)[3],t1);}

/* chicken.compiler.scrutinizer#filter-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7471(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_7471,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_check_list_2(t3,lf[4]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7480,a[2]=t2,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_7480(t8,t1,t3);}

/* foldr359 in chicken.compiler.scrutinizer#filter-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7480(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_7480,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7488,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7514,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g364 in foldr359 in chicken.compiler.scrutinizer#filter-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7488(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_7488,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7492,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:135: pred */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k7490 in g364 in foldr359 in chicken.compiler.scrutinizer#filter-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7492(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_7492,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7496,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:135: g374 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* mini-srfi-1.scm:135: g374 */
  f_7496(C_a_i(&a,3),t2,t1)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g374 in k7490 in g364 in foldr359 in chicken.compiler.scrutinizer#filter-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_7496(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_a_i_cons(&a,2,t1,((C_word*)t0)[2]));}

/* k7512 in foldr359 in chicken.compiler.scrutinizer#filter-map in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7514(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7514,c,av);}
/* mini-srfi-1.scm:134: g364 */
t2=((C_word*)t0)[2];
f_7488(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.compiler.scrutinizer#unzip1 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7536(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_7536,c,av);}
a=C_alloc(12);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(t2,lf[6]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7553,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_7553(t11,t1,t2);}

/* map-loop387 in chicken.compiler.scrutinizer#unzip1 in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7553(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_7553,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* loop in g2702 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7652(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_7652,4,t0,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
if(C_truep(C_i_memq(t4,t3))){
/* mini-srfi-1.scm:160: loop */
t9=t1;
t10=C_u_i_cdr(t2);
t11=t3;
t1=t9;
t2=t10;
t3=t11;
goto loop;}
else{
t5=C_u_i_cdr(t2);
t6=C_u_i_car(t2);
t7=C_a_i_cons(&a,2,t6,t3);
/* mini-srfi-1.scm:161: loop */
t9=t1;
t10=t5;
t11=t7;
t1=t9;
t2=t10;
t3=t11;
goto loop;}}}

/* foldl469 in k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7738(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_7738,4,t0,t1,t2,t3);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7805,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=C_slot(t2,C_fix(0));
t7=C_i_check_list_2(t6,lf[379]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7763,a[2]=t9,tmp=(C_word)a,a+=3,tmp));
t11=((C_word*)t9)[1];
f_7763(t11,t5,t6,t3);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* foldl485 in foldl469 in k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7763(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_7763,4,t0,t1,t2,t3);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=C_slot(t2,C_fix(0));
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7786,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,a[5]=t3,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7791,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:175: any */
f_7221(t6,t7,t3);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7784 in foldl485 in foldl469 in k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7786(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_7786,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=((C_word*)((C_word*)t0)[2])[1];
f_7763(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t2=C_a_i_cons(&a,2,((C_word*)t0)[6],((C_word*)t0)[5]);
t3=((C_word*)((C_word*)t0)[2])[1];
f_7763(t3,((C_word*)t0)[3],((C_word*)t0)[4],t2);}}

/* a7790 in foldl485 in foldl469 in k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7791(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7791,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_eqp(t2,((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7803 in foldl469 in k14045 in a13576 in simplify in chicken.compiler.scrutinizer#simplify-type in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7805,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7738(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.compiler.scrutinizer#list-tabulate in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7829(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_7829,3,t1,t2,t3);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7835,a[2]=t2,a[3]=t5,a[4]=t3,tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_7835(t7,t1,C_fix(0));}

/* loop in chicken.compiler.scrutinizer#list-tabulate in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7835(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7835,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7849,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:190: proc */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k7847 in loop in chicken.compiler.scrutinizer#list-tabulate in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_7849,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7853,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:190: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_7835(t3,t2,C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* k7851 in k7847 in loop in chicken.compiler.scrutinizer#list-tabulate in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_7853,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a7864 in k12877 in k12757 in k12517 in k12503 in match1 in k11910 in chicken.compiler.scrutinizer#match-types in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7865(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7865,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_memq(t2,((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#lset=/eq? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_7871(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_7871,3,t1,t2,t3);}
a=C_alloc(3);
t4=C_i_length(t2);
t5=C_i_length(t3);
t6=C_eqp(t4,t5);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7883,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:197: every */
f_7187(t1,t7,t2);}
else{
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* a7882 in chicken.compiler.scrutinizer#lset=/eq? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_7883(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7883,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_memq(t2,((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* loop in blist-type in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_7948(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_nullp(t1))){
return(C_SCHEME_FALSE);}
else{
t2=(
/* mini-srfi-1.scm:216: pred */
  f_8538(((C_word*)t0)[2],C_i_car(t1))
);
if(C_truep(t2)){
return(C_u_i_car(t1));}
else{
t4=C_u_i_cdr(t1);
t1=t4;
goto loop;}}}

/* a8008 in k10734 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8009(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8009,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#make-list in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8012(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_8012,3,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_i_nullp(t3))){
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f26096,tmp=(C_word)a,a+=2,tmp);
/* mini-srfi-1.scm:228: list-tabulate */
f_7829(t1,t2,t4);}
else{
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8021,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:228: list-tabulate */
f_7829(t1,t2,t5);}}

/* a8020 in chicken.compiler.scrutinizer#make-list in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8021,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#walked-result in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8141,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8149,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[26]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8147 in chicken.compiler.scrutinizer#walked-result in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8149,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.scrutinizer#type-always-immediate? in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8151(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
av[0]=t0;
av[1]=t1;
av[2]=t2;
C_save_and_reclaim((void *)f_8151,c,av);}
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[28]);
if(C_truep(t4)){
/* scrutinizer.scm:172: every */
f_7187(t1,lf[27],C_u_i_cdr(t2));}
else{
t5=C_eqp(t3,lf[29]);
if(C_truep(t5)){
/* scrutinizer.scm:173: type-always-immediate? */
t7=t1;
t8=C_i_caddr(t2);
t1=t7;
t2=t8;
c=3;
goto loop;}
else{
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep((C_truep(C_eqp(t2,lf[30]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[31]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[32]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[33]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[34]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[35]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[36]))?C_SCHEME_TRUE:C_SCHEME_FALSE))))))))?C_SCHEME_TRUE:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7=av[7];
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(106,c,8)))){
C_save_and_reclaim((void *)f_8194,c,av);}
a=C_alloc(106);
t8=C_mutate(&lf[18] /* (set! chicken.compiler.scrutinizer#*complain?* ...) */,t4);
t9=C_SCHEME_END_OF_LIST;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_END_OF_LIST;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_SCHEME_FALSE;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_fix(0);
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_fix(0);
t18=(*a=C_VECTOR_TYPE|1,a[1]=t17,tmp=(C_word)a,a+=2,tmp);
t19=C_SCHEME_FALSE;
t20=(*a=C_VECTOR_TYPE|1,a[1]=t19,tmp=(C_word)a,a+=2,tmp);
t21=C_fix(0);
t22=(*a=C_VECTOR_TYPE|1,a[1]=t21,tmp=(C_word)a,a+=2,tmp);
t23=C_SCHEME_UNDEFINED;
t24=(*a=C_VECTOR_TYPE|1,a[1]=t23,tmp=(C_word)a,a+=2,tmp);
t25=C_SCHEME_UNDEFINED;
t26=(*a=C_VECTOR_TYPE|1,a[1]=t25,tmp=(C_word)a,a+=2,tmp);
t27=C_SCHEME_UNDEFINED;
t28=(*a=C_VECTOR_TYPE|1,a[1]=t27,tmp=(C_word)a,a+=2,tmp);
t29=C_SCHEME_UNDEFINED;
t30=(*a=C_VECTOR_TYPE|1,a[1]=t29,tmp=(C_word)a,a+=2,tmp);
t31=C_SCHEME_UNDEFINED;
t32=(*a=C_VECTOR_TYPE|1,a[1]=t31,tmp=(C_word)a,a+=2,tmp);
t33=C_SCHEME_UNDEFINED;
t34=(*a=C_VECTOR_TYPE|1,a[1]=t33,tmp=(C_word)a,a+=2,tmp);
t35=C_SCHEME_UNDEFINED;
t36=(*a=C_VECTOR_TYPE|1,a[1]=t35,tmp=(C_word)a,a+=2,tmp);
t37=C_SCHEME_UNDEFINED;
t38=(*a=C_VECTOR_TYPE|1,a[1]=t37,tmp=(C_word)a,a+=2,tmp);
t39=C_SCHEME_UNDEFINED;
t40=(*a=C_VECTOR_TYPE|1,a[1]=t39,tmp=(C_word)a,a+=2,tmp);
t41=C_SCHEME_UNDEFINED;
t42=(*a=C_VECTOR_TYPE|1,a[1]=t41,tmp=(C_word)a,a+=2,tmp);
t43=C_SCHEME_UNDEFINED;
t44=(*a=C_VECTOR_TYPE|1,a[1]=t43,tmp=(C_word)a,a+=2,tmp);
t45=C_set_block_item(t24,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8231,a[2]=t24,tmp=(C_word)a,a+=3,tmp));
t46=C_set_block_item(t26,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8526,a[2]=t10,tmp=(C_word)a,a+=3,tmp));
t47=C_set_block_item(t28,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8557,a[2]=t6,a[3]=t3,a[4]=t26,tmp=(C_word)a,a+=5,tmp));
t48=C_set_block_item(t30,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8620,a[2]=t30,tmp=(C_word)a,a+=3,tmp));
t49=C_set_block_item(t32,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8682,a[2]=t30,tmp=(C_word)a,a+=3,tmp));
t50=C_set_block_item(t34,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_8706,tmp=(C_word)a,a+=2,tmp));
t51=C_set_block_item(t36,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8772,a[2]=t22,a[3]=t5,a[4]=t14,tmp=(C_word)a,a+=5,tmp));
t52=C_fix(0);
t53=(*a=C_VECTOR_TYPE|1,a[1]=t52,tmp=(C_word)a,a+=2,tmp);
t54=C_set_block_item(t38,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9406,a[2]=t53,tmp=(C_word)a,a+=3,tmp));
t55=C_set_block_item(t40,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9411,a[2]=t10,a[3]=t12,tmp=(C_word)a,a+=4,tmp));
t56=C_set_block_item(t42,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9444,a[2]=t6,tmp=(C_word)a,a+=3,tmp));
t57=C_set_block_item(t44,0,(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_9540,a[2]=t24,a[3]=t28,a[4]=t38,a[5]=t14,a[6]=t5,a[7]=t16,a[8]=t44,a[9]=t40,a[10]=t10,a[11]=t32,a[12]=t34,a[13]=t12,a[14]=t3,a[15]=t42,a[16]=t18,a[17]=t6,a[18]=t7,a[19]=t20,a[20]=t36,a[21]=t26,tmp=(C_word)a,a+=22,tmp));
t58=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11594,a[2]=t1,a[3]=t20,a[4]=t18,a[5]=t16,a[6]=t22,tmp=(C_word)a,a+=7,tmp);
t59=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11710,a[2]=t38,a[3]=t44,a[4]=t58,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:804: chicken.compiler.support#node-subexpressions */
t60=*((C_word*)lf[87]+1);{
C_word *av2=av;
av2[0]=t60;
av2[1]=t59;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t60+1)))(3,av2);}}

/* constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8231(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_8231,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_stringp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=lf[38];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8244,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:198: chicken.keyword#keyword? */
t4=*((C_word*)lf[57]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8244,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[39];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_symbolp(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[40];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8256,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:201: chicken.compiler.support#big-fixnum? */
t3=*((C_word*)lf[56]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}

/* k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8256(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8256,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8259,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t1)){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
f_8259(2,av2);}}
else{
/* scrutinizer.scm:201: chicken.compiler.support#small-bignum? */
t3=*((C_word*)lf[55]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_8259,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[41];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_fixnump(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[33];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_bignump(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[42];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[43];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_ratnump(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[44];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_cplxnump(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[45];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_booleanp(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(((C_word*)t0)[3])?lf[46]:lf[47]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_nullp(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[32];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_listp(((C_word*)t0)[3]))){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8320,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8322,a[2]=t4,a[3]=t8,a[4]=((C_word*)t0)[4],a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t10=((C_word*)t8)[1];
f_8322(t10,t6,((C_word*)t0)[3]);}
else{
if(C_truep(C_i_pairp(((C_word*)t0)[3]))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8371,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:214: constant-result */
t3=((C_word*)((C_word*)t0)[4])[1];
f_8231(t3,t2,C_u_i_car(((C_word*)t0)[3]));}
else{
if(C_truep(C_eofp(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[30];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_bwpp(((C_word*)t0)[3]))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[31];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_vectorp(((C_word*)t0)[3]))){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8408,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:220: scheme#vector->list */
t7=*((C_word*)lf[52]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t2=C_immp(((C_word*)t0)[3]);
t3=C_i_not(t2);
t4=(C_truep(t3)?C_structurep(((C_word*)t0)[3]):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_slot(((C_word*)t0)[3],C_fix(0));
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_list(&a,2,lf[53],t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=C_charp(((C_word*)t0)[3]);
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=(C_truep(t5)?lf[34]:lf[54]);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}}}}}}}}}}}}

/* k8318 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8320(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_8320,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[48],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop832 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8322(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_8322,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8347,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:211: g838 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_8231(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k8345 in map-loop832 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8347(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8347,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_8322(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k8369 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8371(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8371,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8375,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:214: constant-result */
t3=((C_word*)((C_word*)t0)[3])[1];
f_8231(t3,t2,C_u_i_cdr(((C_word*)t0)[4]));}

/* k8373 in k8369 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8375(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_8375,c,av);}
a=C_alloc(9);
t2=C_a_i_list(&a,3,lf[49],((C_word*)t0)[2],t1);
/* scrutinizer.scm:213: simplify-type */
f_13568(((C_word*)t0)[3],t2);}

/* k8406 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8408(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_8408,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8411,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8413,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_8413(t6,t2,t1);}

/* k8409 in k8406 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8411(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8411,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[51],t1);
/* scrutinizer.scm:219: simplify-type */
f_13568(((C_word*)t0)[2],t2);}

/* map-loop864 in k8406 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8413(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_8413,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8438,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:220: g870 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_8231(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k8436 in map-loop864 in k8406 in k8257 in k8254 in k8242 in constant-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8438(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8438,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_8413(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k8481 in k8571 in k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_8483,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8487,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:227: g901 */
t3=t2;
f_8487(t3,((C_word*)t0)[5],t1);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[64];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g901 in k8481 in k8571 in k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8487(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_8487,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_eqp(t2,lf[60]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8497,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:231: r-deprecated-identifier */
f_23054(t4,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],C_SCHEME_END_OF_LIST);}
else{
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_eqp(C_u_i_car(t2),lf[60]):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8506,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t7=C_i_cadr(t2);
/* scrutinizer.scm:234: r-deprecated-identifier */
f_23054(t6,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],C_a_i_list(&a,1,t7));}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_a_i_list1(&a,1,t2);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}

/* k8495 in g901 in k8481 in k8571 in k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8497,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[61];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8504 in g901 in k8481 in k8571 in k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8506(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8506,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[63];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* blist-type in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8526(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_8526,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8538,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=((C_word*)((C_word*)t0)[2])[1];
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7948,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t7=(
  f_7948(t6,t5)
);
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=(C_truep(t7)?C_i_cdr(t7):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}

/* a8537 in blist-type in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_8538(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;{}
t2=C_i_caar(t1);
t3=C_eqp(((C_word*)t0)[2],t2);
if(C_truep(t3)){
t4=C_u_i_car(t1);
return(C_i_memq(C_u_i_cdr(t4),((C_word*)t0)[3]));}
else{
return(C_SCHEME_FALSE);}}

/* variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8557(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_8557,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(9);
t7=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8561,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:248: blist-type */
t8=((C_word*)((C_word*)t0)[4])[1];
f_8526(t8,t7,t2,t6);}

/* k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_8561,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list1(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8573,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_not(((C_word*)t0)[7]))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8611,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:250: chicken.compiler.support#db-get */
t4=*((C_word*)lf[68]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[69];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=t2;
f_8573(t3,C_SCHEME_FALSE);}}}

/* k8571 in k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8573(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_8573,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=lf[58];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_i_assq(((C_word*)t0)[3],((C_word*)t0)[4]);
if(C_truep(t2)){
t3=C_i_cdr(t2);
t4=C_eqp(lf[36],t3);
if(C_truep(t4)){
t5=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[59];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_u_i_cdr(t2);
t6=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t6;
av2[1]=C_a_i_list1(&a,1,t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8483,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:227: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[65]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[66];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}}

/* k8609 in k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8611(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_8611,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8618,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:251: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[67];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_8573(t2,C_SCHEME_FALSE);}}

/* k8616 in k8609 in k8559 in variable-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8618(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8618,c,av);}
t2=((C_word*)t0)[2];
f_8573(t2,C_i_not(t1));}

/* always-true1 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8620(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
av[0]=t0;
av[1]=t1;
av[2]=t2;
C_save_and_reclaim((void *)f_8620,c,av);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_eqp(t3,lf[28]);
if(C_truep(t4)){
/* scrutinizer.scm:267: every */
f_7187(t1,((C_word*)((C_word*)t0)[2])[1],C_u_i_cdr(t2));}
else{
t5=C_eqp(t3,lf[70]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8652,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:268: always-true1 */
t8=t6;
t9=C_i_cadr(t2);
t1=t8;
t2=t9;
c=3;
goto loop;}
else{
t6=C_eqp(t3,lf[29]);
if(C_truep(t6)){
/* scrutinizer.scm:269: always-true1 */
t8=t1;
t9=C_i_caddr(t2);
t1=t8;
t2=t9;
c=3;
goto loop;}
else{
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep((C_truep(C_eqp(t2,lf[54]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[35]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[47]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[36]))?C_SCHEME_TRUE:(C_truep(C_eqp(t2,lf[71]))?C_SCHEME_TRUE:C_SCHEME_FALSE))))))?C_SCHEME_FALSE:C_SCHEME_TRUE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k8650 in always-true1 in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8652,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_not(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* always-true in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8682(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_8682,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(7);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8686,a[2]=t1,a[3]=t3,a[4]=t2,a[5]=t5,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:275: always-true1 */
t7=((C_word*)((C_word*)t0)[2])[1];{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
f_8620(3,av2);}}

/* k8684 in always-true in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,8)))){
C_save_and_reclaim((void *)f_8686,c,av);}
a=C_alloc(16);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8692,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_a_i_list2(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22763,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:2847: scheme#string-append */
t5=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[78];
av2[3]=lf[79];
av2[4]=lf[80];
av2[5]=lf[81];
av2[6]=lf[82];
av2[7]=lf[83];
av2[8]=lf[84];
((C_proc)(void*)(*((C_word*)t5+1)))(9,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k8690 in k8684 in always-true in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8692(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8692,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8702 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8704(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8704,c,av);}
t2=((C_word*)t0)[2];
f_9707(t2,((C_word*)t0)[3]);}

/* single in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8706(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_8706,3,t1,t2,t3);}
a=C_alloc(4);
t4=C_eqp(lf[54],t2);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_length(t2);
t6=C_eqp(C_fix(1),t5);
if(C_truep(t6)){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_eqp(t5,C_fix(0));
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8734,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:290: r-value-count-mismatch */
t9=t3;{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8737,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:293: r-value-count-mismatch */
t9=t3;{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}}}}

/* k8732 in single in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8734,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[36];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8735 in single in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8737,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8748 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_8750(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_8750,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8753,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:300: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[163];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k8751 in k8748 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_8753(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_8753,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8756,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(C_truep(((C_word*)t0)[3])?((C_word*)t0)[3]:C_SCHEME_END_OF_LIST);
if(C_truep(t1)){
/* scrutinizer.scm:301: scheme#append */
t4=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
/* scrutinizer.scm:301: scheme#append */
t4=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k8754 in k8751 in k8748 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_8756(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8756,c,av);}
t2=C_i_pairp(t1);
t3=((C_word*)t0)[2];
f_9165(t3,(C_truep(t2)?t1:C_SCHEME_FALSE));}

/* call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8772(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,3)))){
C_save_and_reclaim_args((void *)trf_8772,5,t0,t1,t2,t3,t4);}
a=C_alloc(21);
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=lf[25];
t10=C_i_check_list_2(t3,lf[6]);
t11=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8782,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=t4,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[4],tmp=(C_word)a,a+=9,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9372,a[2]=t7,a[3]=t13,a[4]=t8,tmp=(C_word)a,a+=5,tmp));
t15=((C_word*)t13)[1];
f_9372(t15,t11,t3);}

/* k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_8782,c,av);}
a=C_alloc(11);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8788,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=t1,a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:307: procedure-type? */
t4=lf[122];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
f_15184(3,av2);}}

/* k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8788(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_8788,c,av);}
a=C_alloc(16);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_u_i_length(t2);
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9370,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t3,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=t1,tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:309: make-list */
f_8012(t4,t3,C_a_i_list(&a,1,lf[54]));}

/* k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_8798,c,av);}
a=C_alloc(22);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_8807,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t3,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=t5,a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],a[14]=((C_word*)t0)[12],tmp=(C_word)a,a+=15,tmp);
if(C_truep(C_i_not(((C_word*)t0)[13]))){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9366,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:313: match-types */
t8=*((C_word*)lf[171]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t3)[1];
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
t7=t6;
f_8807(t7,C_SCHEME_FALSE);}}

/* k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8807(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,6)))){
C_save_and_reclaim_args((void *)trf_8807,2,t0,t1);}
a=C_alloc(18);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8810,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_8817,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* scrutinizer.scm:315: resolve */
t4=lf[119];{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
av2[3]=((C_word*)((C_word*)t0)[7])[1];
f_16350(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8828,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_8834,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[12],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[13],a[10]=((C_word*)t0)[5],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[14],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:318: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}}

/* k8808 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8810(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8810,c,av);}
/* scrutinizer.scm:316: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[54];
av2[3]=C_SCHEME_FALSE;
C_values(4,av2);}}

/* k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8817(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_8817,c,av);}
a=C_alloc(7);
t2=C_u_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8823,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:315: resolve */
t4=lf[119];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)((C_word*)t0)[7])[1];
f_16350(4,av2);}}

/* k8821 in k8815 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_8823,c,av);}
a=C_alloc(14);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21960,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22005,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=t3,a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:2572: variable-node-name */
t6=((C_word*)t3)[1];
f_21960(t6,t5,((C_word*)t0)[2]);}

/* a8827 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_8828,c,av);}
/* scrutinizer.scm:319: procedure-argument-types */
f_15401(t1,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)((C_word*)t0)[4])[1],C_SCHEME_END_OF_LIST);}

/* a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8834(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,2)))){
C_save_and_reclaim((void *)f_8834,c,av);}
a=C_alloc(30);
t6=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_8838,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=t3,a[14]=((C_word*)t0)[12],a[15]=t2,tmp=(C_word)a,a+=16,tmp);
if(C_truep(t4)){
t7=t6;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_8838(2,av2);}}
else{
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22066,a[2]=t8,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[11],a[5]=t5,a[6]=t6,a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f28274,a[2]=t9,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2543: chicken.compiler.support#node-subexpressions */
t11=*((C_word*)lf[87]+1);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}}

/* k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8838(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,6)))){
C_save_and_reclaim((void *)f_8838,c,av);}
a=C_alloc(24);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_8841,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],tmp=(C_word)a,a+=15,tmp);
t3=C_i_cdr(((C_word*)t0)[10]);
t4=C_i_cdr(((C_word*)t0)[9]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9294,a[2]=t6,a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp));
t8=((C_word*)t6)[1];
f_9294(t8,t2,t3,t4,((C_word*)t0)[15],C_fix(1));}

/* k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_8841,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_8844,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
t3=(
/* scrutinizer.scm:337: noreturn-procedure-type? */
  f_15825(((C_word*)t0)[8])
);
if(C_truep(t3)){
t4=C_set_block_item(((C_word*)t0)[14],0,C_SCHEME_TRUE);
t5=t2;
f_8844(t5,t4);}
else{
t4=t2;
f_8844(t4,C_SCHEME_UNDEFINED);}}

/* k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_8844(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,3)))){
C_save_and_reclaim_args((void *)trf_8844,2,t0,t1);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_8847,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
t3=C_u_i_cdr(((C_word*)t0)[10]);
t4=((C_word*)((C_word*)t0)[4])[1];
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15624,a[2]=((C_word*)t0)[13],a[3]=t3,a[4]=t4,a[5]=t6,tmp=(C_word)a,a+=6,tmp));
/* scrutinizer.scm:1475: loop1 */
t8=((C_word*)t6)[1];
f_15624(t8,t2,((C_word*)t0)[8]);}

/* k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_8847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_8847,c,av);}
a=C_alloc(16);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_8850,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* scrutinizer.scm:340: procedure-name */
f_15236(t4,((C_word*)t0)[8]);}

/* k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_8850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_8850,c,av);}
a=C_alloc(23);
t2=lf[24];
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8853,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t1)){
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_8950,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[4],a[6]=t1,a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[12],a[11]=t2,a[12]=((C_word*)t0)[5],tmp=(C_word)a,a+=13,tmp);
t5=C_eqp(C_fix(1),((C_word*)t0)[13]);
if(C_truep(t5)){
/* scrutinizer.scm:344: chicken.compiler.support#variable-mark */
t6=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=t1;
av2[3]=lf[166];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_8950(2,av2);}}}
else{
t4=t3;
f_8853(t4,C_SCHEME_UNDEFINED);}}

/* k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_fcall f_8853(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,2)))){
C_save_and_reclaim_args((void *)trf_8853,2,t0,t1);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8856,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8919,a[2]=((C_word*)t0)[6],a[3]=t2,a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[8])){
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[3])[1]))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8940,a[2]=t3,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:404: procedure-type? */
t5=lf[122];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
f_15184(3,av2);}}
else{
t4=t3;
f_8919(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_8919(t4,C_SCHEME_FALSE);}}

/* k8854 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_8856(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,3)))){
C_save_and_reclaim_args((void *)trf_8856,2,t0,t1);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8859,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_eqp(lf[54],((C_word*)((C_word*)t0)[4])[1]);
if(C_truep(t3)){
t4=((C_word*)((C_word*)t0)[4])[1];
/* scrutinizer.scm:410: scheme#values */{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t4;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
C_values(4,av2);}}
else{
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8872,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
t9=((C_word*)((C_word*)t0)[4])[1];
t10=C_i_check_list_2(t9,lf[6]);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8884,a[2]=t6,a[3]=t12,a[4]=t8,a[5]=t7,tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_8884(t14,t2,t9);}}

/* k8857 in k8854 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_8859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8859,c,av);}
/* scrutinizer.scm:410: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
C_values(4,av2);}}

/* g1155 in k8854 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_8872(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_8872,3,t0,t1,t2);}
t3=lf[119];
/* scrutinizer.scm:408: g1172 */
t4=lf[119];{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
av2[3]=((C_word*)((C_word*)t0)[2])[1];
f_16350(4,av2);}}

/* map-loop1149 in k8854 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_8884(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_8884,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8909,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:408: g1155 */
t4=((C_word*)t0)[4];
f_8872(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k8907 in map-loop1149 in k8854 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_8909(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8909,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_8884(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k8917 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_8919(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_8919,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8928,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:406: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];
f_8856(t2,C_SCHEME_UNDEFINED);}}

/* k8926 in k8917 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_8928(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_8928,c,av);}
a=C_alloc(29);
t2=C_i_set_car(t1,C_SCHEME_TRUE);
t3=((C_word*)((C_word*)t0)[2])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t3,C_fix(1)));
t5=((C_word*)t0)[3];
f_8856(t5,t4);}

/* k8938 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_8940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8940,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8947,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:405: chicken.compiler.support#node-class */
t3=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];
f_8919(t2,C_SCHEME_FALSE);}}

/* k8945 in k8938 in k8851 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_8947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8947,c,av);}
t2=((C_word*)t0)[2];
f_8919(t2,C_eqp(lf[121],t1));}

/* k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_8950(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_8950,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8953,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_8987,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
/* scrutinizer.scm:343: g1071 */
t4=t3;
f_8987(t4,t2,t1);}
else{
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9142,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[8],a[4]=t2,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[4],tmp=(C_word)a,a+=12,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9263,a[2]=t3,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:367: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k8951 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_8953(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_8953,c,av);}
a=C_alloc(29);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=C_i_assoc(((C_word*)((C_word*)t0)[2])[1],lf[23]);
if(C_truep(t2)){
t3=C_i_cdr(t2);
t4=C_s_a_i_plus(&a,2,t3,C_fix(1));
t5=((C_word*)t0)[3];
f_8853(t5,C_i_set_cdr(t2,t4));}
else{
t3=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[2])[1],C_fix(1));
t4=C_a_i_cons(&a,2,t3,lf[23]);
t5=C_mutate(&lf[23] /* (set! chicken.compiler.scrutinizer#specialization-statistics ...) */,t4);
t6=((C_word*)t0)[3];
f_8853(t6,t5);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];
f_8853(t3,t2);}}

/* g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_fcall f_8987(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,0,4)))){
C_save_and_reclaim_args((void *)trf_8987,3,t0,t1,t2);}
a=C_alloc(17);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_8994,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=((C_word*)t0)[5],a[7]=t1,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],tmp=(C_word)a,a+=14,tmp);
t4=C_a_i_list1(&a,1,t2);
/* scrutinizer.scm:346: match-argument-types */
f_13496(t3,t4,C_i_cdr(((C_word*)t0)[8]),((C_word*)((C_word*)t0)[11])[1]);}

/* k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_8994(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_8994,c,av);}
a=C_alloc(23);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8997,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t3=C_i_cadr(((C_word*)t0)[10]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22688,a[2]=t5,a[3]=((C_word*)t0)[9],a[4]=t2,a[5]=((C_word*)t0)[11],a[6]=t3,a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f28250,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2543: chicken.compiler.support#node-subexpressions */
t8=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9054,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:356: trail-restore */
f_16307(t2,((C_word*)t0)[12],((C_word*)((C_word*)t0)[13])[1]);}}

/* k8995 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_8997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_8997,c,av);}
a=C_alloc(15);
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9003,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
t3=C_i_cdr(((C_word*)t0)[8]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9032,a[2]=t2,a[3]=((C_word*)t0)[9],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_a_i_list(&a,1,lf[128]);
/* scrutinizer.scm:352: ##sys#list->vector */
t6=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t2=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k9001 in k8995 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_9003(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_9003,c,av);}
a=C_alloc(6);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,lf[123]);
t3=C_a_i_list2(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t4=C_mutate(((C_word *)((C_word*)t0)[5])+1,t3);
t5=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k9030 in k8995 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_9032(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_9032,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9036,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=C_a_i_list(&a,1,C_fix(1));
/* scrutinizer.scm:352: ##sys#list->vector */
t4=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k9034 in k9030 in k8995 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f_9036(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,4)))){
C_save_and_reclaim((void *)f_9036,c,av);}
a=C_alloc(24);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_list(&a,1,t2);
t4=C_a_i_list(&a,2,lf[124],C_SCHEME_TRUE);
t5=C_a_i_list(&a,3,lf[125],t3,t4);
/* scrutinizer.scm:350: specialize-node! */
f_17690(((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t5);}

/* k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_ccall f_9054(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_9054,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9057,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
t3=C_a_i_list(&a,2,lf[70],((C_word*)t0)[4]);
t4=C_a_i_list1(&a,1,t3);
/* scrutinizer.scm:357: match-argument-types */
f_13496(t2,t4,C_u_i_cdr(((C_word*)t0)[9]),((C_word*)((C_word*)t0)[12])[1]);}

/* k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in ... */
static void C_ccall f_9057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_9057,c,av);}
a=C_alloc(22);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9060,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=C_i_cadr(((C_word*)t0)[9]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22722,a[2]=t5,a[3]=((C_word*)t0)[8],a[4]=t2,a[5]=((C_word*)t0)[10],a[6]=t3,a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f28255,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:2543: chicken.compiler.support#node-subexpressions */
t8=*((C_word*)lf[87]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
/* scrutinizer.scm:366: trail-restore */
f_16307(((C_word*)t0)[6],((C_word*)t0)[11],((C_word*)((C_word*)t0)[12])[1]);}}

/* k9058 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f_9060(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_9060,c,av);}
a=C_alloc(14);
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9066,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t3=C_i_cdr(((C_word*)t0)[7]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9099,a[2]=t2,a[3]=((C_word*)t0)[8],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_a_i_list(&a,1,lf[128]);
/* scrutinizer.scm:363: ##sys#list->vector */
t6=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9064 in k9058 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in ... */
static void C_ccall f_9066(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_9066,c,av);}
a=C_alloc(12);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,lf[144]);
t3=C_a_i_list(&a,2,lf[70],((C_word*)t0)[3]);
t4=C_a_i_list2(&a,2,((C_word*)t0)[3],t3);
t5=C_mutate(((C_word *)((C_word*)t0)[4])+1,t4);
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k9097 in k9058 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in ... */
static void C_ccall f_9099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_9099,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9103,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=C_a_i_list(&a,1,C_fix(1));
/* scrutinizer.scm:363: ##sys#list->vector */
t4=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k9101 in k9097 in k9058 in k9055 in k9052 in k8992 in g1071 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in ... */
static void C_ccall f_9103(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,4)))){
C_save_and_reclaim((void *)f_9103,c,av);}
a=C_alloc(24);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_list(&a,1,t2);
t4=C_a_i_list(&a,2,lf[124],C_SCHEME_FALSE);
t5=C_a_i_list(&a,3,lf[125],t3,t4);
/* scrutinizer.scm:361: specialize-node! */
f_17690(((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t5);}

/* k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_9142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_9142,c,av);}
a=C_alloc(15);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9146,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:343: g1102 */
t3=t2;
f_9146(t3,((C_word*)t0)[4],t1);}
else{
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9165,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[4],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)t0)[11])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8750,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:299: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[164];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=t2;
f_9165(t3,C_SCHEME_FALSE);}}}

/* g1102 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_9146(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_9146,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,lf[54]);
t4=C_i_car(t2);
t5=C_a_i_list2(&a,2,lf[124],t4);
/* scrutinizer.scm:373: mutate-node! */
f_17510(t1,((C_word*)t0)[3],t5);}

/* k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_fcall f_9165(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_9165,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9169,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:343: g1108 */
t3=t2;
f_9169(t3,((C_word*)t0)[10],t1);}
else{
t2=((C_word*)t0)[10];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_8953(2,av2);}}}

/* g1108 in k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in ... */
static void C_fcall f_9169(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_9169,3,t0,t1,t2);}
a=C_alloc(13);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9175,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t4,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp));
t6=((C_word*)t4)[1];
f_9175(t6,t1,t2);}

/* loop in g1108 in k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in ... */
static void C_fcall f_9175(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,4)))){
C_save_and_reclaim_args((void *)trf_9175,3,t0,t1,t2);}
a=C_alloc(19);
if(C_truep(C_i_pairp(t2))){
t3=C_u_i_car(t2);
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_9189,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t1,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=t2,a[12]=((C_word*)t0)[9],a[13]=t4,a[14]=((C_word*)t0)[10],tmp=(C_word)a,a+=15,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9253,a[2]=t5,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:381: append-map */
f_7017(t6,lf[162],t4,C_SCHEME_END_OF_LIST);}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9187 in loop in g1108 in k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f_9189(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_9189,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_9195,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* scrutinizer.scm:383: match-argument-types */
f_13496(t2,((C_word*)t0)[13],C_i_cdr(((C_word*)t0)[14]),t1);}

/* k9193 in k9187 in loop in g1108 in k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in ... */
static void C_ccall f_9195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_9195,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
t4=C_mutate(((C_word *)((C_word*)t0)[4])+1,t3);
t5=C_mutate(((C_word *)((C_word*)t0)[5])+1,((C_word*)t0)[6]);
t6=C_i_cddr(((C_word*)t0)[2]);
t7=C_i_pairp(t6);
t8=(C_truep(t7)?C_i_cadr(((C_word*)t0)[2]):C_SCHEME_FALSE);
t9=(C_truep(t8)?C_i_caddr(((C_word*)t0)[2]):C_i_cadr(((C_word*)t0)[2]));
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9209,a[2]=t8,a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:391: specialize-node! */
f_17690(t10,((C_word*)t0)[9],C_i_cdr(((C_word*)t0)[10]),t9);}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9240,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[12],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:394: trail-restore */
f_16307(t2,((C_word*)t0)[13],((C_word*)t0)[6]);}}

/* k9207 in k9193 in k9187 in loop in g1108 in k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in ... */
static void C_ccall f_9209(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9209,c,av);}
if(C_truep(((C_word*)t0)[2])){
t2=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)t0)[2]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9238 in k9193 in k9187 in loop in g1108 in k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in ... */
static void C_ccall f_9240(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9240,c,av);}
/* scrutinizer.scm:395: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9175(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* k9251 in loop in g1108 in k9163 in k9140 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in ... */
static void C_ccall f_9253(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9253,c,av);}
/* scrutinizer.scm:380: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k9261 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in ... */
static void C_ccall f_9263(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(2,c,5)))){
C_save_and_reclaim((void *)f_9263,c,av);}
a=C_alloc(2);
t2=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9265,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:367: chicken.compiler.support#maybe-constant-fold-call */
t3=*((C_word*)lf[165]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a9264 in k9261 in k8948 in k8848 in k8845 in k8842 in k8839 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in ... */
static void C_ccall f_9265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_9265,c,av);}
a=C_alloc(3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t2)?C_a_i_cons(&a,2,t3,t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* doloop1050 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9294(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,4)))){
C_save_and_reclaim_args((void *)trf_9294,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(19);
t6=C_i_nullp(t2);
t7=(C_truep(t6)?t6:C_i_nullp(t4));
if(C_truep(t7)){
t8=C_SCHEME_UNDEFINED;
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9307,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t5,a[6]=((C_word*)t0)[2],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t9=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9323,a[2]=t8,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t5,a[7]=((C_word*)t0)[5],a[8]=t2,a[9]=((C_word*)t0)[6],a[10]=t4,tmp=(C_word)a,a+=11,tmp);
/* scrutinizer.scm:327: match-types */
t10=*((C_word*)lf[171]+1);{
C_word av2[5];
av2[0]=t10;
av2[1]=t9;
av2[2]=C_i_car(t4);
av2[3]=C_i_car(t2);
av2[4]=((C_word*)((C_word*)t0)[6])[1];
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}}

/* k9305 in doloop1050 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9307(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,5)))){
C_save_and_reclaim((void *)f_9307,c,av);}
a=C_alloc(29);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_i_cdr(((C_word*)t0)[3]);
t4=C_u_i_cdr(((C_word*)t0)[4]);
t5=C_s_a_i_plus(&a,2,((C_word*)t0)[5],C_fix(1));
t6=((C_word*)((C_word*)t0)[6])[1];
f_9294(t6,((C_word*)t0)[7],t2,t3,t4,t5);}

/* k9321 in doloop1050 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_9323,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_9307(2,av2);}}
else{
t2=C_i_car(((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9334,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t2,a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:334: resolve */
t4=lf[119];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_u_i_car(((C_word*)t0)[10]);
av2[3]=((C_word*)((C_word*)t0)[9])[1];
f_16350(4,av2);}}}

/* k9332 in k9321 in doloop1050 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_9334,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9338,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:335: resolve */
t3=lf[119];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_car(((C_word*)t0)[8]);
av2[3]=((C_word*)((C_word*)t0)[9])[1];
f_16350(4,av2);}}

/* k9336 in k9332 in k9321 in doloop1050 in k8836 in a8833 in k8805 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_9338(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_9338,c,av);}
/* scrutinizer.scm:331: r-proc-call-argument-type-mismatch */
f_22110(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t1,((C_word*)t0)[8]);}

/* k9364 in k8796 in k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9366,c,av);}
t2=((C_word*)t0)[2];
f_8807(t2,C_i_not(t1));}

/* k9368 in k8786 in k8780 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9370(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,4)))){
C_save_and_reclaim((void *)f_9370,c,av);}
a=C_alloc(23);
t2=C_a_i_list(&a,3,lf[85],t1,lf[54]);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_8798,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t2,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* scrutinizer.scm:310: append-map */
f_7017(t3,lf[162],((C_word*)t0)[10],C_SCHEME_END_OF_LIST);}

/* map-loop994 in call-result in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9372(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9372,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f26621,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:167: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[26]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* tag in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static C_word C_fcall f_9406(C_word *a,C_word t0){
C_word tmp;
C_word t1;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
t1=((C_word*)((C_word*)t0)[2])[1];
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t1,C_fix(1)));
return(((C_word*)((C_word*)t0)[2])[1]);}

/* add-to-blist in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9411(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_9411,5,t0,t1,t2,t3,t4);}
a=C_alloc(9);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9417,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t6,a[5]=t3,a[6]=t4,tmp=(C_word)a,a+=7,tmp));
t8=((C_word*)t6)[1];
f_9417(t8,t1,t2);}

/* loop in add-to-blist in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9417(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,5)))){
C_save_and_reclaim_args((void *)trf_9417,3,t0,t1,t2);}
a=C_alloc(10);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9422,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
t4=C_a_i_cons(&a,2,t2,((C_word*)t0)[5]);
/* scrutinizer.scm:420: chicken.base#alist-update! */
t5=*((C_word*)lf[187]+1);{
C_word av2[6];
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)((C_word*)t0)[2])[1];
av2[5]=*((C_word*)lf[188]+1);
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}

/* k9420 in loop in add-to-blist in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9422(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9422,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=C_i_assq(((C_word*)t0)[3],((C_word*)((C_word*)t0)[4])[1]);
if(C_truep(t3)){
/* scrutinizer.scm:424: loop */
t4=((C_word*)((C_word*)t0)[5])[1];
f_9417(t4,((C_word*)t0)[6],C_i_cdr(t3));}
else{
t4=C_SCHEME_UNDEFINED;
t5=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9444(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_9444,4,t0,t1,t2,t3);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9451,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t2)){
if(C_truep(((C_word*)t0)[2])){
/* scrutinizer.scm:428: chicken.compiler.support#variable-mark */
t5=*((C_word*)lf[65]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[67];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_9451(2,av2);}}}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_9451(2,av2);}}}

/* k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9451(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9451,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9454,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* scrutinizer.scm:429: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[66];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* scrutinizer.scm:435: make-list */
f_8012(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,1,lf[54]));}}

/* k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9454,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9457,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:430: type-typeenv */
t3=lf[162];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
f_15975(3,av2);}}

/* k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_9457,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9463,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:431: procedure-type? */
t3=lf[122];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
f_15184(3,av2);}}

/* k9461 in k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_9463,c,av);}
a=C_alloc(20);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9467,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9474,a[2]=t4,a[3]=t6,a[4]=t5,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9516,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t9=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_9522,tmp=(C_word)a,a+=2,tmp);
/* scrutinizer.scm:433: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t7;
av2[2]=t8;
av2[3]=t9;
C_call_with_values(4,av2);}}
else{
/* scrutinizer.scm:434: make-list */
f_8012(((C_word*)t0)[3],((C_word*)t0)[5],C_a_i_list(&a,1,lf[54]));}}

/* g1215 in k9461 in k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9467(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_9467,3,t0,t1,t2);}
t3=lf[119];
/* scrutinizer.scm:432: g1232 */
t4=lf[119];{
C_word av2[4];
av2[0]=t4;
av2[1]=t1;
av2[2]=t2;
av2[3]=((C_word*)t0)[2];
f_16350(4,av2);}}

/* k9472 in k9461 in k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9474(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_9474,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[6]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9482,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_9482(t6,((C_word*)t0)[5],t1);}

/* map-loop1209 in k9472 in k9461 in k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9482(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9482,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9507,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:432: g1215 */
t4=((C_word*)t0)[4];
f_9467(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9505 in map-loop1209 in k9472 in k9461 in k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9507(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9507,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9482(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a9515 in k9461 in k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9516(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_9516,c,av);}
a=C_alloc(3);
/* scrutinizer.scm:433: procedure-argument-types */
f_15401(t1,((C_word*)t0)[2],((C_word*)t0)[3],C_SCHEME_END_OF_LIST,C_a_i_list(&a,1,C_SCHEME_TRUE));}

/* a9521 in k9461 in k9455 in k9452 in k9449 in initial-argument-types in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9522(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_9522,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_list_ref(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9540(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7){
C_word tmp;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,2)))){
C_save_and_reclaim_args((void *)trf_9540,8,t0,t1,t2,t3,t4,t5,t6,t7);}
a=C_alloc(29);
t8=(*a=C_CLOSURE_TYPE|28,a[1]=(C_word)f_9544,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t3,a[6]=t4,a[7]=t2,a[8]=t6,a[9]=((C_word*)t0)[4],a[10]=((C_word*)t0)[5],a[11]=((C_word*)t0)[6],a[12]=((C_word*)t0)[7],a[13]=((C_word*)t0)[8],a[14]=t5,a[15]=t7,a[16]=((C_word*)t0)[9],a[17]=((C_word*)t0)[10],a[18]=((C_word*)t0)[11],a[19]=((C_word*)t0)[12],a[20]=((C_word*)t0)[13],a[21]=((C_word*)t0)[14],a[22]=((C_word*)t0)[15],a[23]=((C_word*)t0)[16],a[24]=((C_word*)t0)[17],a[25]=((C_word*)t0)[18],a[26]=((C_word*)t0)[19],a[27]=((C_word*)t0)[20],a[28]=((C_word*)t0)[21],tmp=(C_word)a,a+=29,tmp);
/* scrutinizer.scm:438: chicken.compiler.support#node-subexpressions */
t9=*((C_word*)lf[87]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}

/* k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9544(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,2)))){
C_save_and_reclaim((void *)f_9544,c,av);}
a=C_alloc(30);
t2=(*a=C_CLOSURE_TYPE|29,a[1]=(C_word)f_9547,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],a[26]=((C_word*)t0)[25],a[27]=((C_word*)t0)[26],a[28]=((C_word*)t0)[27],a[29]=((C_word*)t0)[28],tmp=(C_word)a,a+=30,tmp);
/* scrutinizer.scm:439: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[26]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9547(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(31,c,2)))){
C_save_and_reclaim((void *)f_9547,c,av);}
a=C_alloc(31);
t2=(*a=C_CLOSURE_TYPE|30,a[1]=(C_word)f_9550,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],a[26]=((C_word*)t0)[25],a[27]=((C_word*)t0)[26],a[28]=((C_word*)t0)[27],a[29]=((C_word*)t0)[28],a[30]=((C_word*)t0)[29],tmp=(C_word)a,a+=31,tmp);
/* scrutinizer.scm:440: chicken.compiler.support#node-class */
t3=*((C_word*)lf[89]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9550(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(121,c,7)))){
C_save_and_reclaim((void *)f_9550,c,av);}
a=C_alloc(121);
t2=lf[16];
t3=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_plus(&a,2,lf[16],C_fix(1)));
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9558,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t5=C_eqp(t1,lf[86]);
if(C_truep(t5)){
t6=C_i_car(((C_word*)t0)[3]);
t7=C_a_i_list1(&a,1,t6);
t8=lf[16];
t9=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t10=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t10;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t6=C_eqp(t1,lf[124]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9586,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:449: constant-result */
t8=((C_word*)((C_word*)t0)[4])[1];
f_8231(t8,t7,C_i_car(((C_word*)t0)[3]));}
else{
t7=C_eqp(t1,lf[189]);
if(C_truep(t7)){
t8=lf[16];
t9=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t10=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t10;
av2[1]=lf[190];
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t8=C_eqp(t1,lf[191]);
if(C_truep(t8)){
t9=lf[16];
t10=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t11=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t11;
av2[1]=lf[192];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t9=C_eqp(t1,lf[88]);
if(C_truep(t9)){
/* scrutinizer.scm:452: variable-result */
t10=((C_word*)((C_word*)t0)[5])[1];
f_8557(t10,t4,C_i_car(((C_word*)t0)[3]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}
else{
t10=C_eqp(t1,lf[193]);
if(C_truep(t10)){
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9628,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:454: chicken.compiler.support#foreign-type->scrutiny-type */
t12=*((C_word*)lf[194]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t12;
av2[1]=t11;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
av2[3]=lf[195];
((C_proc)(void*)(*((C_word*)t12+1)))(4,av2);}}
else{
t11=C_eqp(t1,lf[196]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9645,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* scrutinizer.scm:456: chicken.compiler.support#foreign-type->scrutiny-type */
t13=*((C_word*)lf[194]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t13;
av2[1]=t12;
av2[2]=C_i_car(((C_word*)t0)[3]);
av2[3]=lf[195];
((C_proc)(void*)(*((C_word*)t13+1)))(4,av2);}}
else{
t12=C_eqp(t1,lf[197]);
if(C_truep(t12)){
t13=(
/* scrutinizer.scm:458: tag */
  f_9406(C_a_i(&a,29),((C_word*)((C_word*)t0)[10])[1])
);
t14=(
/* scrutinizer.scm:458: tag */
  f_9406(C_a_i(&a,29),((C_word*)((C_word*)t0)[10])[1])
);
t15=C_a_i_cons(&a,2,t13,t14);
t16=C_i_car(((C_word*)t0)[11]);
t17=((C_word*)((C_word*)t0)[12])[1];
t18=C_set_block_item(((C_word*)t0)[12],0,C_SCHEME_FALSE);
t19=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_9665,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[14],a[6]=((C_word*)t0)[15],a[7]=t4,a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[16],a[12]=((C_word*)t0)[9],a[13]=((C_word*)t0)[17],a[14]=t16,a[15]=t17,a[16]=((C_word*)t0)[2],a[17]=t15,a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],tmp=(C_word)a,a+=21,tmp);
t20=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9980,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=t16,a[5]=((C_word*)t0)[21],a[6]=t19,tmp=(C_word)a,a+=7,tmp);
/* scrutinizer.scm:462: walk */
t21=((C_word*)((C_word*)t0)[15])[1];
f_9540(t21,t20,t16,((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE,((C_word*)t0)[9],t15);}
else{
t13=C_eqp(t1,lf[125]);
if(C_truep(t13)){
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10005,a[2]=((C_word*)t0)[15],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[16],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[17],a[7]=((C_word*)t0)[6],a[8]=t15,a[9]=((C_word*)t0)[22],a[10]=((C_word*)t0)[23],a[11]=((C_word*)t0)[8],a[12]=((C_word*)t0)[21],tmp=(C_word)a,a+=13,tmp));
t17=((C_word*)t15)[1];
f_10005(t17,t4,((C_word*)t0)[3],((C_word*)t0)[11],C_SCHEME_END_OF_LIST);}
else{
t14=C_eqp(t1,lf[222]);
t15=(C_truep(t14)?t14:C_eqp(t1,lf[223]));
if(C_truep(t15)){
t16=C_i_car(((C_word*)t0)[3]);
t17=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10110,a[2]=((C_word*)t0)[16],a[3]=((C_word*)t0)[19],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[22],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[23],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[15],a[11]=((C_word*)t0)[6],a[12]=((C_word*)t0)[24],tmp=(C_word)a,a+=13,tmp);
/* scrutinizer.scm:525: ##sys#decompose-lambda-list */
t18=*((C_word*)lf[228]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t18;
av2[1]=t4;
av2[2]=t16;
av2[3]=t17;
((C_proc)(void*)(*((C_word*)t18+1)))(4,av2);}}
else{
t16=C_eqp(t1,lf[229]);
t17=(C_truep(t16)?t16:C_eqp(t1,lf[230]));
if(C_truep(t17)){
t18=C_i_car(((C_word*)t0)[3]);
t19=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10374,a[2]=t18,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[25],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[19],a[9]=((C_word*)t0)[26],a[10]=((C_word*)t0)[23],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[27],a[13]=((C_word*)t0)[8],a[14]=((C_word*)t0)[7],a[15]=((C_word*)t0)[28],a[16]=((C_word*)t0)[21],a[17]=((C_word*)t0)[15],tmp=(C_word)a,a+=18,tmp);
/* scrutinizer.scm:580: chicken.compiler.support#variable-mark */
t20=*((C_word*)lf[65]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t20;
av2[1]=t19;
av2[2]=t18;
av2[3]=lf[66];
((C_proc)(void*)(*((C_word*)t20+1)))(4,av2);}}
else{
t18=C_eqp(t1,lf[269]);
if(C_truep(t18)){
t19=lf[16];
t20=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t21=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t21;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t21+1)))(2,av2);}}
else{
t19=C_eqp(t1,lf[121]);
if(C_truep(t19)){
t20=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_10736,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[21],a[6]=((C_word*)t0)[15],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[29],a[10]=((C_word*)t0)[19],a[11]=((C_word*)t0)[26],a[12]=((C_word*)t0)[16],a[13]=((C_word*)t0)[17],a[14]=((C_word*)t0)[18],a[15]=((C_word*)t0)[23],a[16]=((C_word*)t0)[30],a[17]=t4,tmp=(C_word)a,a+=18,tmp);
/* scrutinizer.scm:668: fragment */
f_21306(t20,((C_word*)t0)[8]);}
else{
t20=C_eqp(t1,lf[278]);
if(C_truep(t20)){
t21=C_i_car(((C_word*)t0)[3]);
t22=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11323,a[2]=t21,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[26],a[7]=((C_word*)t0)[28],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* scrutinizer.scm:768: walk */
t23=((C_word*)((C_word*)t0)[15])[1];
f_9540(t23,t22,C_i_car(((C_word*)t0)[11]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[16],((C_word*)t0)[9],((C_word*)t0)[17]);}
else{
t21=C_eqp(t1,lf[312]);
if(C_truep(t21)){
t22=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11411,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[15],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[16],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[17],a[11]=t4,tmp=(C_word)a,a+=12,tmp);
/* scrutinizer.scm:780: walk */
t23=((C_word*)((C_word*)t0)[15])[1];
f_9540(t23,t22,C_i_car(((C_word*)t0)[11]),((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE,((C_word*)t0)[9],((C_word*)t0)[17]);}
else{
t22=C_eqp(t1,lf[342]);
t23=(C_truep(t22)?t22:C_eqp(t1,lf[343]));
if(C_truep(t23)){
/* scrutinizer.scm:796: chicken.compiler.support#bomb */
t24=*((C_word*)lf[344]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t24;
av2[1]=t4;
av2[2]=lf[345];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t24+1)))(4,av2);}}
else{
t24=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11511,a[2]=((C_word*)t0)[15],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[9],tmp=(C_word)a,a+=6,tmp);
t25=C_i_check_list_2(((C_word*)t0)[11],lf[213]);
t26=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11521,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t27=C_SCHEME_UNDEFINED;
t28=(*a=C_VECTOR_TYPE|1,a[1]=t27,tmp=(C_word)a,a+=2,tmp);
t29=C_set_block_item(t28,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11523,a[2]=t28,a[3]=t24,tmp=(C_word)a,a+=4,tmp));
t30=((C_word*)t28)[1];
f_11523(t30,t26,((C_word*)t0)[11]);}}}}}}}}}}}}}}}}}

/* k9556 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9558(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_9558,c,av);}
a=C_alloc(29);
t2=lf[16];
t3=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k9584 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_9586,c,av);}
a=C_alloc(32);
t2=C_a_i_list1(&a,1,t1);
t3=lf[16];
t4=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k9626 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_9628,c,av);}
a=C_alloc(32);
t2=C_a_i_list1(&a,1,t1);
t3=lf[16];
t4=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k9643 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9645(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_9645,c,av);}
a=C_alloc(32);
t2=C_a_i_list1(&a,1,t1);
t3=lf[16];
t4=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9665(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,5)))){
C_save_and_reclaim((void *)f_9665,c,av);}
a=C_alloc(23);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=C_i_caddr(((C_word*)t0)[2]);
t4=((C_word*)((C_word*)t0)[3])[1];
t5=(*a=C_CLOSURE_TYPE|22,a[1]=(C_word)f_9976,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=t2,a[14]=t3,a[15]=((C_word*)t0)[3],a[16]=((C_word*)t0)[15],a[17]=t4,a[18]=((C_word*)t0)[16],a[19]=((C_word*)t0)[17],a[20]=((C_word*)t0)[18],a[21]=((C_word*)t0)[19],a[22]=t1,tmp=(C_word)a,a+=23,tmp);
/* scrutinizer.scm:468: always-true */
t6=((C_word*)((C_word*)t0)[20])[1];
f_8682(t6,t5,((C_word*)t0)[8],((C_word*)t0)[14],t1,((C_word*)t0)[10]);}

/* k9680 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_9682,c,av);}
/* scrutinizer.scm:471: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9540(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k9699 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_9701,c,av);}
a=C_alloc(18);
t2=C_a_i_list(&a,2,t1,((C_word*)t0)[2]);
t3=C_a_i_list(&a,1,t2);
t4=C_a_i_list(&a,3,lf[125],t3,((C_word*)t0)[3]);
/* scrutinizer.scm:470: mutate-node! */
f_17510(((C_word*)t0)[4],((C_word*)t0)[5],t4);}

/* k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9707(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(45,0,7)))){
C_save_and_reclaim_args((void *)trf_9707,2,t0,t1);}
a=C_alloc(45);
if(C_truep(t1)){
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t2,C_fix(1)));
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9712,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9731,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=t4,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:474: chicken.base#gensym */
t6=*((C_word*)lf[198]+1);{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_9734,a[2]=((C_word*)t0)[13],a[3]=((C_word*)t0)[14],a[4]=((C_word*)t0)[15],a[5]=((C_word*)t0)[16],a[6]=((C_word*)t0)[12],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[17],a[10]=((C_word*)t0)[4],a[11]=((C_word*)t0)[18],a[12]=((C_word*)t0)[19],a[13]=((C_word*)t0)[9],a[14]=((C_word*)t0)[20],a[15]=((C_word*)t0)[3],a[16]=((C_word*)t0)[6],a[17]=((C_word*)t0)[8],tmp=(C_word)a,a+=18,tmp);
t3=C_u_i_car(((C_word*)t0)[18]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[9]);
/* scrutinizer.scm:477: walk */
t5=((C_word*)((C_word*)t0)[3])[1];
f_9540(t5,t2,((C_word*)t0)[17],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],t4,C_SCHEME_FALSE);}}

/* k9710 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9712(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_9712,c,av);}
/* scrutinizer.scm:475: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9540(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k9729 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9731(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_9731,c,av);}
a=C_alloc(18);
t2=C_a_i_list(&a,2,t1,((C_word*)t0)[2]);
t3=C_a_i_list(&a,1,t2);
t4=C_a_i_list(&a,3,lf[125],t3,((C_word*)t0)[3]);
/* scrutinizer.scm:474: mutate-node! */
f_17510(((C_word*)t0)[4],((C_word*)t0)[5],t4);}

/* k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,7)))){
C_save_and_reclaim((void *)f_9734,c,av);}
a=C_alloc(20);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t4=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_9738,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=t1,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],a[14]=((C_word*)t0)[12],a[15]=((C_word*)t0)[13],a[16]=((C_word*)t0)[14],tmp=(C_word)a,a+=17,tmp);
t5=C_u_i_cdr(((C_word*)t0)[11]);
t6=C_a_i_cons(&a,2,t5,((C_word*)t0)[13]);
/* scrutinizer.scm:480: walk */
t7=((C_word*)((C_word*)t0)[15])[1];
f_9540(t7,t4,((C_word*)t0)[6],((C_word*)t0)[16],((C_word*)t0)[8],((C_word*)t0)[17],t6,C_SCHEME_FALSE);}

/* k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_9738,c,av);}
a=C_alloc(23);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=(C_truep(((C_word*)t0)[3])?((C_word*)t0)[3]:(C_truep(((C_word*)t0)[4])?((C_word*)t0)[4]:(C_truep(((C_word*)t0)[5])?t2:C_SCHEME_FALSE)));
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9745,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[5],a[10]=t2,a[11]=((C_word*)t0)[12],tmp=(C_word)a,a+=12,tmp);
t6=(C_truep(((C_word*)t0)[5])?C_i_not(t2):C_SCHEME_FALSE);
t7=(C_truep(t6)?t6:(C_truep(t2)?C_i_not(((C_word*)t0)[5]):C_SCHEME_FALSE));
if(C_truep(t7)){
t8=(C_truep(((C_word*)t0)[5])?C_u_i_cdr(((C_word*)t0)[13]):C_u_i_car(((C_word*)t0)[13]));
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9886,a[2]=t8,a[3]=((C_word*)t0)[14],a[4]=((C_word*)t0)[15],tmp=(C_word)a,a+=5,tmp);
t10=((C_word*)((C_word*)t0)[16])[1];
t11=C_i_check_list_2(t10,lf[213]);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9920,a[2]=t13,a[3]=t9,tmp=(C_word)a,a+=4,tmp));
t15=((C_word*)t13)[1];
f_9920(t15,t5,t10);}
else{
t8=t5;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_9745(2,av2);}}}

/* k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9745(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_9745,c,av);}
a=C_alloc(29);
t2=C_eqp(lf[54],((C_word*)t0)[2]);
t3=C_i_not(t2);
t4=(C_truep(t3)?C_i_not(C_eqp(lf[54],((C_word*)t0)[3])):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9757,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(C_i_not(((C_word*)t0)[9]))){
if(C_truep(C_i_not(((C_word*)t0)[10]))){
t6=C_i_length(((C_word*)t0)[2]);
t7=C_i_length(((C_word*)t0)[3]);
t8=t5;
f_9757(t8,C_i_not(C_eqp(t6,t7)));}
else{
t6=t5;
f_9757(t6,C_SCHEME_FALSE);}}
else{
t6=t5;
f_9757(t6,C_SCHEME_FALSE);}}
else{
t5=lf[16];
t6=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t7=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t7;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9757(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,14)))){
C_save_and_reclaim_args((void *)trf_9757,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9760,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_a_i_list2(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22973,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[4],tmp=(C_word)a,a+=10,tmp);
/* scrutinizer.scm:2968: scheme#string-append */
t5=*((C_word*)lf[77]+1);{
C_word av2[15];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[200];
av2[3]=lf[201];
av2[4]=lf[202];
av2[5]=lf[203];
av2[6]=lf[204];
av2[7]=lf[205];
av2[8]=lf[206];
av2[9]=lf[207];
av2[10]=lf[208];
av2[11]=lf[209];
av2[12]=lf[210];
av2[13]=lf[211];
av2[14]=lf[212];
((C_proc)(void*)(*((C_word*)t5+1)))(15,av2);}}
else{
if(C_truep(((C_word*)t0)[9])){
t2=lf[16];
t3=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t4=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t4;
av2[1]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(((C_word*)t0)[10])){
t2=lf[16];
t3=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t4=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t4;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(((C_word*)t0)[5],lf[6]);
t7=C_i_check_list_2(((C_word*)t0)[6],lf[6]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9792,a[2]=t4,a[3]=t9,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_9792(t11,((C_word*)t0)[11],((C_word*)t0)[5],((C_word*)t0)[6]);}}}}

/* k9758 in k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_ccall f_9760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_9760,c,av);}
a=C_alloc(29);
t2=lf[16];
t3=C_mutate(&lf[16] /* (set! chicken.compiler.scrutinizer#d-depth ...) */,C_s_a_i_minus(&a,2,lf[16],C_fix(1)));
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[54];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* map-loop1344 in k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 in ... */
static void C_fcall f_9792(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,2)))){
C_save_and_reclaim_args((void *)trf_9792,4,t0,t1,t2,t3);}
a=C_alloc(16);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9821,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
t7=C_slot(t2,C_fix(0));
t8=C_slot(t3,C_fix(0));
t9=C_a_i_list(&a,3,lf[28],t7,t8);
/* scrutinizer.scm:506: simplify-type */
f_13568(t6,t9);}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k9819 in map-loop1344 in k9755 in k9743 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in ... */
static void C_ccall f_9821(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9821,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9792(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)),C_slot(((C_word*)t0)[6],C_fix(1)));}

/* g1316 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9886(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_9886,3,t0,t1,t2);}
t3=C_i_cdar(t2);
t4=C_eqp(t3,((C_word*)t0)[2]);
if(C_truep(t4)){
t5=C_u_i_car(t2);
/* scrutinizer.scm:493: add-to-blist */
t6=((C_word*)((C_word*)t0)[3])[1];
f_9411(t6,t1,C_u_i_car(t5),C_i_car(((C_word*)t0)[4]),C_u_i_cdr(t2));}
else{
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* for-each-loop1315 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_fcall f_9920(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9920,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9930,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:488: g1316 */
t4=((C_word*)t0)[3];
f_9886(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9928 in for-each-loop1315 in k9736 in k9732 in k9705 in k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9930(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9930,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_9920(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k9974 in k9663 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9976(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(45,c,6)))){
C_save_and_reclaim((void *)f_9976,c,av);}
a=C_alloc(45);
t2=(C_truep(t1)?((C_word*)t0)[2]:C_SCHEME_FALSE);
if(C_truep(t2)){
t3=((C_word*)((C_word*)t0)[3])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[3])+1,C_s_a_i_plus(&a,2,t3,C_fix(1)));
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9682,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],tmp=(C_word)a,a+=10,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9701,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[13],a[4]=t5,a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:470: chicken.base#gensym */
t7=*((C_word*)lf[198]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_9707,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[14],a[13]=((C_word*)t0)[15],a[14]=((C_word*)t0)[16],a[15]=((C_word*)t0)[17],a[16]=((C_word*)t0)[18],a[17]=((C_word*)t0)[13],a[18]=((C_word*)t0)[19],a[19]=((C_word*)t0)[20],a[20]=((C_word*)t0)[21],tmp=(C_word)a,a+=21,tmp);
t4=C_eqp(((C_word*)t0)[22],lf[47]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8704,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t6=C_a_i_list2(&a,2,((C_word*)t0)[12],((C_word*)t0)[6]);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22785,a[2]=t5,a[3]=t6,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* scrutinizer.scm:2863: scheme#string-append */
t8=*((C_word*)lf[77]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=lf[215];
av2[3]=lf[216];
av2[4]=lf[217];
av2[5]=lf[218];
av2[6]=lf[219];
((C_proc)(void*)(*((C_word*)t8+1)))(7,av2);}}
else{
t5=t3;
f_9707(t5,C_SCHEME_FALSE);}}}

/* k9978 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9980(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_9980,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9982,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* scrutinizer.scm:462: single */
f_8706(((C_word*)t0)[6],t1,t2);}

/* a9981 in k9978 in k9548 in k9545 in k9542 in walk in chicken.compiler.scrutinizer#scrutinize in k6814 in k6811 in k6808 in k6805 in k6802 in k6799 in k6796 in k6793 in k6790 */
static void C_ccall f_9982(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9982,c,av);}
t3=lf[220];
/* scrutinizer.scm:463: g1271 */
t4=lf[220];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=t2;
f_22381(6,av2);}}

/* toplevel */
static C_TLS int toplevel_initialized=0;

void C_ccall C_scrutinizer_toplevel(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(toplevel_initialized) {C_kontinue(t1,C_SCHEME_UNDEFINED);}
else C_toplevel_entry(C_text("scrutinizer"));
C_check_nursery_minimum(C_calculate_demand(3,c,2));
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void*)C_scrutinizer_toplevel,c,av);}
toplevel_initialized=1;
if(C_unlikely(!C_demand_2(3131))){
C_save(t1);
C_rereclaim2(3131*sizeof(C_word),1);
t1=C_restore;}
a=C_alloc(3);
C_initialize_lf(lf,661);
lf[0]=C_h_intern(&lf[0],11, C_text("scrutinizer"));
lf[1]=C_h_intern(&lf[1],29, C_text("chicken.compiler.scrutinizer#"));
lf[4]=C_h_intern(&lf[4],5, C_text("foldr"));
lf[5]=C_h_intern(&lf[5],13, C_text("scheme#append"));
lf[6]=C_h_intern(&lf[6],3, C_text("map"));
lf[8]=C_h_intern(&lf[8],12, C_text("scheme#null\077"));
lf[20]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001string\376\003\000\000\002\376\001\000\000\006\001symbol\376\003\000\000\002\376\001\000\000\007\001keyword\376\003\000\000\002\376\001\000\000\004\001char\376\003\000\000\002\376\001\000\000\004\001nu"
"ll\376\003\000\000\002\376\001\000\000\007\001boolean\376\003\000\000\002\376\001\000\000\004\001true\376\003\000\000\002\376\001\000\000\005\001false\376\003\000\000\002\376\001\000\000\004\001blob\376\003\000\000\002\376\001\000\000\003\001eof"
"\376\003\000\000\002\376\001\000\000\003\001bwp\376\003\000\000\002\376\001\000\000\006\001fixnum\376\003\000\000\002\376\001\000\000\005\001float\376\003\000\000\002\376\001\000\000\006\001number\376\003\000\000\002\376\001\000\000\007\001integ"
"er\376\003\000\000\002\376\001\000\000\006\001bignum\376\003\000\000\002\376\001\000\000\006\001ratnum\376\003\000\000\002\376\001\000\000\007\001cplxnum\376\003\000\000\002\376\001\000\000\016\001pointer-vector\376"
"\003\000\000\002\376\001\000\000\004\001port\376\003\000\000\002\376\001\000\000\007\001pointer\376\003\000\000\002\376\001\000\000\010\001locative\376\377\016"));
lf[22]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\003\000\000\002\376\001\000\000\004\001list\376\003\000\000\002\376\001\000\000\004\001pair\376\003\000\000\002\376\001\000\000\011\001procedure\376\003\000\000\002\376\001\000\000\006\001vector\376"
"\003\000\000\002\376\001\000\000\011\001undefined\376\003\000\000\002\376\001\000\000\012\001deprecated\376\003\000\000\002\376\001\000\000\010\001noreturn\376\003\000\000\002\376\001\000\000\006\001values\376\377\016"));
lf[26]=C_h_intern(&lf[26],40, C_text("chicken.compiler.support#node-parameters"));
lf[28]=C_h_intern(&lf[28],2, C_text("or"));
lf[29]=C_h_intern(&lf[29],6, C_text("forall"));
lf[30]=C_h_intern(&lf[30],3, C_text("eof"));
lf[31]=C_h_intern(&lf[31],3, C_text("bwp"));
lf[32]=C_h_intern(&lf[32],4, C_text("null"));
lf[33]=C_h_intern(&lf[33],6, C_text("fixnum"));
lf[34]=C_h_intern(&lf[34],4, C_text("char"));
lf[35]=C_h_intern(&lf[35],7, C_text("boolean"));
lf[36]=C_h_intern(&lf[36],9, C_text("undefined"));
lf[37]=C_h_intern(&lf[37],39, C_text("chicken.compiler.scrutinizer#scrutinize"));
lf[38]=C_h_intern(&lf[38],6, C_text("string"));
lf[39]=C_h_intern(&lf[39],7, C_text("keyword"));
lf[40]=C_h_intern(&lf[40],6, C_text("symbol"));
lf[41]=C_h_intern(&lf[41],7, C_text("integer"));
lf[42]=C_h_intern(&lf[42],6, C_text("bignum"));
lf[43]=C_h_intern(&lf[43],5, C_text("float"));
lf[44]=C_h_intern(&lf[44],6, C_text("ratnum"));
lf[45]=C_h_intern(&lf[45],7, C_text("cplxnum"));
lf[46]=C_h_intern(&lf[46],4, C_text("true"));
lf[47]=C_h_intern(&lf[47],5, C_text("false"));
lf[48]=C_h_intern(&lf[48],4, C_text("list"));
lf[49]=C_h_intern(&lf[49],4, C_text("pair"));
lf[51]=C_h_intern(&lf[51],6, C_text("vector"));
lf[52]=C_h_intern(&lf[52],19, C_text("scheme#vector->list"));
lf[53]=C_h_intern(&lf[53],6, C_text("struct"));
lf[54]=C_h_intern(&lf[54],1, C_text("\052"));
lf[55]=C_h_intern(&lf[55],38, C_text("chicken.compiler.support#small-bignum\077"));
lf[56]=C_h_intern(&lf[56],36, C_text("chicken.compiler.support#big-fixnum\077"));
lf[57]=C_h_intern(&lf[57],24, C_text("chicken.keyword#keyword\077"));
lf[58]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[59]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[60]=C_h_intern(&lf[60],10, C_text("deprecated"));
lf[61]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[63]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[64]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[65]=C_h_intern(&lf[65],38, C_text("chicken.compiler.support#variable-mark"));
lf[66]=C_h_intern(&lf[66],15, C_text("##compiler#type"));
lf[67]=C_h_intern(&lf[67],22, C_text("##compiler#type-source"));
lf[68]=C_h_intern(&lf[68],31, C_text("chicken.compiler.support#db-get"));
lf[69]=C_h_intern(&lf[69],8, C_text("assigned"));
lf[70]=C_h_intern(&lf[70],3, C_text("not"));
lf[71]=C_h_intern(&lf[71],8, C_text("noreturn"));
lf[73]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023Test is always true"));
lf[74]=C_h_intern(&lf[74],12, C_text("##sys#notice"));
lf[77]=C_h_intern(&lf[77],20, C_text("scheme#string-append"));
lf[78]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032In conditional expression:"));
lf[79]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[80]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[81]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[82]=C_decode_literal(C_heaptop,C_text("\376B\000\000-Test condition has always true value of type:"));
lf[83]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[84]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[85]=C_h_intern(&lf[85],9, C_text("procedure"));
lf[86]=C_h_intern(&lf[86],17, C_text("##core#the/result"));
lf[87]=C_h_intern(&lf[87],44, C_text("chicken.compiler.support#node-subexpressions"));
lf[88]=C_h_intern(&lf[88],15, C_text("##core#variable"));
lf[89]=C_h_intern(&lf[89],35, C_text("chicken.compiler.support#node-class"));
lf[90]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021Invalid procedure"));
lf[91]=C_h_intern(&lf[91],20, C_text("chicken.base#warning"));
lf[93]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[94]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[95]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[96]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[97]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037Variable ~a is not a procedure."));
lf[98]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[99]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021It has this type:"));
lf[100]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[101]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[102]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021Invalid procedure"));
lf[104]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[105]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[106]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[107]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[108]=C_decode_literal(C_heaptop,C_text("\376B\000\000:The procedure expression does not appear to be a callable."));
lf[109]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[110]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[111]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[112]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025The expected type is:"));
lf[113]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[114]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[115]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[116]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023The actual type is:"));
lf[117]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[118]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[121]=C_h_intern(&lf[121],11, C_text("##core#call"));
lf[123]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\004\001true\376\377\016"));
lf[124]=C_h_intern(&lf[124],5, C_text("quote"));
lf[125]=C_h_intern(&lf[125],3, C_text("let"));
lf[127]=C_h_intern(&lf[127],18, C_text("##sys#list->vector"));
lf[128]=C_h_intern(&lf[128],3, C_text("tmp"));
lf[129]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030Predicate is always true"));
lf[130]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[131]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[132]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[133]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[134]=C_decode_literal(C_heaptop,C_text("\376B\000\000&The predicate will always return true."));
lf[135]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[136]=C_decode_literal(C_heaptop,C_text("\376B\000\000 Procedure ~a is a predicate for:"));
lf[137]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[138]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[139]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[140]=C_decode_literal(C_heaptop,C_text("\376B\000\000!The given argument has this type:"));
lf[141]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[142]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[144]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001false\376\377\016"));
lf[145]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031Predicate is always false"));
lf[146]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[147]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[148]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[149]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[150]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047The predicate will always return false."));
lf[151]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[152]=C_decode_literal(C_heaptop,C_text("\376B\000\000 Procedure ~a is a predicate for:"));
lf[153]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[154]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[155]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[156]=C_decode_literal(C_heaptop,C_text("\376B\000\000!The given argument has this type:"));
lf[157]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[158]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[163]=C_h_intern(&lf[163],26, C_text("##compiler#specializations"));
lf[164]=C_h_intern(&lf[164],32, C_text("##compiler#local-specializations"));
lf[165]=C_h_intern(&lf[165],49, C_text("chicken.compiler.support#maybe-constant-fold-call"));
lf[166]=C_h_intern(&lf[166],20, C_text("##compiler#predicate"));
lf[168]=C_h_intern(&lf[168],20, C_text("chicken.base#call/cc"));
lf[171]=C_h_intern(&lf[171],40, C_text("chicken.compiler.scrutinizer#match-types"));
lf[172]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[173]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001s"));
lf[174]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002is"));
lf[175]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003are"));
lf[176]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031Wrong number of arguments"));
lf[178]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[179]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[180]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[181]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[182]=C_decode_literal(C_heaptop,C_text("\376B\000\000JProcedure `~a\047 is called with ~a argument~a but ~a argument~a ~a expected."));
lf[183]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[184]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033Procedure ~a has this type:"));
lf[185]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[186]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[187]=C_h_intern(&lf[187],26, C_text("chicken.base#alist-update!"));
lf[188]=C_h_intern(&lf[188],13, C_text("scheme#equal\077"));
lf[189]=C_h_intern(&lf[189],16, C_text("##core#undefined"));
lf[190]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[191]=C_h_intern(&lf[191],11, C_text("##core#proc"));
lf[192]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\011\001procedure\376\377\016"));
lf[193]=C_h_intern(&lf[193],17, C_text("##core#inline_ref"));
lf[194]=C_h_intern(&lf[194],52, C_text("chicken.compiler.support#foreign-type->scrutiny-type"));
lf[195]=C_h_intern(&lf[195],6, C_text("result"));
lf[196]=C_h_intern(&lf[196],21, C_text("##core#inline_loc_ref"));
lf[197]=C_h_intern(&lf[197],2, C_text("if"));
lf[198]=C_h_intern(&lf[198],19, C_text("chicken.base#gensym"));
lf[199]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026Branch values mismatch"));
lf[200]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032In conditional expression:"));
lf[201]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[202]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[203]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[204]=C_decode_literal(C_heaptop,C_text("\376B\000\000.The branches have different numbers of values."));
lf[205]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[206]=C_decode_literal(C_heaptop,C_text("\376B\000\000#The true branch returns ~a value~a:"));
lf[207]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[208]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[209]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[210]=C_decode_literal(C_heaptop,C_text("\376B\000\000$The false branch returns ~a value~a:"));
lf[211]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[212]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[213]=C_h_intern(&lf[213],8, C_text("for-each"));
lf[214]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024Test is always false"));
lf[215]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032In conditional expression:"));
lf[216]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[217]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[218]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[219]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037Test condition is always false."));
lf[222]=C_h_intern(&lf[222],13, C_text("##core#lambda"));
lf[223]=C_h_intern(&lf[223],6, C_text("lambda"));
lf[224]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\011\001procedure\376\377\016"));
lf[225]=C_h_intern(&lf[225],18, C_text("##sys#dynamic-wind"));
lf[226]=C_h_intern(&lf[226],20, C_text("chicken.base#butlast"));
lf[227]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\377\016"));
lf[228]=C_h_intern(&lf[228],27, C_text("##sys#decompose-lambda-list"));
lf[229]=C_h_intern(&lf[229],4, C_text("set!"));
lf[230]=C_h_intern(&lf[230],11, C_text("##core#set!"));
lf[231]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\006\001\376\377\016"));
lf[232]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\011\001undefined\376\377\016"));
lf[233]=C_h_intern(&lf[233],8, C_text("captured"));
lf[234]=C_h_intern(&lf[234],38, C_text("chicken.compiler.support#mark-variable"));
lf[235]=C_h_intern(&lf[235],9, C_text("inference"));
lf[236]=C_h_intern(&lf[236],6, C_text("format"));
lf[237]=C_h_intern(&lf[237],34, C_text("chicken.compiler.support#debugging"));
lf[238]=C_h_intern(&lf[238],1, C_text("I"));
lf[239]=C_h_intern(&lf[239],30, C_text("chicken.base#get-output-string"));
lf[240]=C_h_intern(&lf[240],18, C_text("##sys#write-char-0"));
lf[241]=C_h_intern(&lf[241],11, C_text("##sys#print"));
lf[242]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003(: "));
lf[243]=C_h_intern(&lf[243],31, C_text("chicken.base#open-output-string"));
lf[245]=C_h_intern(&lf[245],34, C_text("chicken.compiler.support#tree-copy"));
lf[246]=C_h_intern(&lf[246],2, C_text("no"));
lf[247]=C_h_intern(&lf[247],17, C_text("##compiler#inline"));
lf[248]=C_h_intern(&lf[248],42, C_text("chicken.compiler.support#variable-visible\077"));
lf[249]=C_h_intern(&lf[249],11, C_text("local-value"));
lf[250]=C_h_intern(&lf[250],5, C_text("value"));
lf[251]=C_h_intern(&lf[251],7, C_text("unknown"));
lf[252]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022Invalid assignment"));
lf[253]=C_h_intern(&lf[253],21, C_text("scheme#string->symbol"));
lf[254]=C_h_intern(&lf[254],34, C_text("chicken.compiler.support#real-name"));
lf[255]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In assignment:"));
lf[256]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[257]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[258]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[259]=C_decode_literal(C_heaptop,C_text("\376B\000\000(Variable `~a\047 is assigned invalid value."));
lf[260]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[261]=C_decode_literal(C_heaptop,C_text("\376B\000\000!The assigned value has this type:"));
lf[262]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[263]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[264]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[265]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033The declared type of ~a is:"));
lf[266]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[267]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[269]=C_h_intern(&lf[269],16, C_text("##core#primitive"));
lf[270]=C_h_intern(&lf[270],34, C_text("chicken.compiler.support#make-node"));
lf[272]=C_h_intern(&lf[272],16, C_text("##compiler#clean"));
lf[273]=C_h_intern(&lf[273],15, C_text("##compiler#pure"));
lf[274]=C_h_intern(&lf[274],41, C_text("chicken.compiler.scrutinizer#refine-types"));
lf[275]=C_h_intern(&lf[275],30, C_text("##compiler#special-result-type"));
lf[276]=C_h_intern(&lf[276],22, C_text("chicken.base#alist-ref"));
lf[277]=C_h_intern(&lf[277],18, C_text("##compiler#enforce"));
lf[278]=C_h_intern(&lf[278],10, C_text("##core#the"));
lf[279]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021Not enough values"));
lf[280]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In expression:"));
lf[281]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[282]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[283]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[284]=C_decode_literal(C_heaptop,C_text("\376B\000\0006Expression returns 0 values but is declared to return:"));
lf[285]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[286]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[287]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015Type mismatch"));
lf[288]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In expression:"));
lf[289]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[290]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[291]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[292]=C_decode_literal(C_heaptop,C_text("\376B\000\0004Expression\047s declared and actual types do not match."));
lf[293]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[294]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025The declared type is:"));
lf[295]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[296]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[297]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[298]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023The actual type is:"));
lf[299]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[300]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[302]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017Too many values"));
lf[303]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In expression:"));
lf[304]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[305]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[306]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[307]=C_decode_literal(C_heaptop,C_text("\376B\000\000#Expression returns too many values."));
lf[308]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[309]=C_decode_literal(C_heaptop,C_text("\376B\000\000;The expression returns ~a values but is declared to return:"));
lf[310]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[311]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[312]=C_h_intern(&lf[312],15, C_text("##core#typecase"));
lf[313]=C_h_intern(&lf[313],39, C_text("chicken.compiler.support#quit-compiling"));
lf[314]=C_h_intern(&lf[314],33, C_text("chicken.string#string-intersperse"));
lf[315]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\012\012"));
lf[317]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002  "));
lf[319]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[320]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[321]=C_h_intern(&lf[321],19, C_text("chicken.string#conc"));
lf[322]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002  "));
lf[323]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\012  "));
lf[325]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021No typecase match"));
lf[326]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~%"));
lf[327]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[328]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[329]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042In `compiler-typecase\047 expression:"));
lf[330]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[331]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004  ~a"));
lf[332]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[333]=C_decode_literal(C_heaptop,C_text("\376B\000\000,  Tested expression does not match any case."));
lf[334]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[335]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037  The expression has this type:"));
lf[336]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[337]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[338]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[339]=C_decode_literal(C_heaptop,C_text("\376B\000\000%  The specified type cases are these:"));
lf[340]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[341]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[342]=C_h_intern(&lf[342],13, C_text("##core#switch"));
lf[343]=C_h_intern(&lf[343],11, C_text("##core#cond"));
lf[344]=C_h_intern(&lf[344],29, C_text("chicken.compiler.support#bomb"));
lf[345]=C_decode_literal(C_heaptop,C_text("\376B\000\000!scrutinize: unexpected node class"));
lf[346]=C_decode_literal(C_heaptop,C_text("\376B\000\000-some variable types do not satisfy strictness"));
lf[347]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001o\376\003\000\000\002\376\001\000\000\001\001e\376\377\016"));
lf[348]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037assignments to immediate values"));
lf[349]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001o\376\003\000\000\002\376\001\000\000\001\001e\376\377\016"));
lf[350]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020dropped branches"));
lf[351]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001o\376\003\000\000\002\376\001\000\000\001\001e\376\377\016"));
lf[352]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012safe calls"));
lf[353]=C_h_intern(&lf[353],21, C_text("##sys#standard-output"));
lf[354]=C_h_intern(&lf[354],6, C_text("printf"));
lf[355]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002  "));
lf[356]=C_h_intern(&lf[356],18, C_text("chicken.base#print"));
lf[357]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020specializations:"));
lf[358]=C_h_intern(&lf[358],46, C_text("chicken.compiler.support#with-debugging-output"));
lf[359]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001o\376\003\000\000\002\376\001\000\000\001\001e\376\377\016"));
lf[360]=C_h_intern(&lf[360],9, C_text("vector-of"));
lf[361]=C_h_intern(&lf[361],23, C_text("chicken.base#constantly"));
lf[362]=C_h_intern(&lf[362],7, C_text("list-of"));
lf[363]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\002\001or\376\003\000\000\002\376\001\000\000\004\001pair\376\003\000\000\002\376\001\000\000\004\001null\376\377\016"));
lf[364]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\003\000\000\002\376\001\000\000\012\001#!optional\376\377\016"));
lf[365]=C_h_intern(&lf[365],10, C_text("#!optional"));
lf[366]=C_h_intern(&lf[366],6, C_text("#!rest"));
lf[368]=C_h_intern(&lf[368],14, C_text("scheme#reverse"));
lf[369]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\011\001undefined\376\003\000\000\002\376\001\000\000\010\001noreturn\376\377\016"));
lf[373]=C_h_intern(&lf[373],6, C_text("refine"));
lf[374]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\003\000\000\002\376\001\000\000\004\001pair\376\003\000\000\002\376\001\000\000\004\001pair\376\003\000\000\002\376\001\000\000\001\001\052\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\004\001li"
"st\376\003\000\000\002\376\001\000\000\007\001list-of\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\006\001vector\376\003\000\000\002\376\001\000\000\011\001vector-of\376\003\000"
"\000\002\376\001\000\000\001\001\052\376\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\007\001boolean\376\003\000\000\002\376\001\000\000\002\001or\376\003\000\000\002\376\001\000\000\004\001true\376\003\000\000\002\376\001\000\000\005\001false\376"
"\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\007\001integer\376\003\000\000\002\376\001\000\000\002\001or\376\003\000\000\002\376\001\000\000\006\001fixnum\376\003\000\000\002\376\001\000\000\006\001bignum\376\377\016\376\003\000\000\002"
"\376\003\000\000\002\376\001\000\000\006\001number\376\003\000\000\002\376\001\000\000\002\001or\376\003\000\000\002\376\001\000\000\006\001fixnum\376\003\000\000\002\376\001\000\000\005\001float\376\003\000\000\002\376\001\000\000\006\001bignum"
"\376\003\000\000\002\376\001\000\000\006\001ratnum\376\003\000\000\002\376\001\000\000\007\001cplxnum\376\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\011\001procedure\376\003\000\000\002\376\001\000\000\011\001proced"
"ure\376\003\000\000\002\376\003\000\000\002\376\001\000\000\006\001#!rest\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016\376\001\000\000\001\001\052\376\377\016"));
lf[375]=C_h_intern(&lf[375],10, C_text("scheme#eq\077"));
lf[376]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\377\016"));
lf[377]=C_h_intern(&lf[377],14, C_text("##core#tv-root"));
lf[378]=C_h_intern(&lf[378],17, C_text("chicken.plist#get"));
lf[379]=C_h_intern(&lf[379],5, C_text("foldl"));
lf[380]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\011\001procedure\376\377\016"));
lf[382]=C_h_intern(&lf[382],6, C_text("number"));
lf[383]=C_h_intern(&lf[383],36, C_text("chicken.compiler.scrutinizer#type<=\077"));
lf[384]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001fixnum\376\003\000\000\002\376\001\000\000\005\001float\376\003\000\000\002\376\001\000\000\006\001bignum\376\003\000\000\002\376\001\000\000\006\001ratnum\376\003\000\000\002\376\001\000\000\007\001cp"
"lxnum\376\377\016"));
lf[385]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001fixnum\376\003\000\000\002\376\001\000\000\006\001bignum\376\377\016"));
lf[386]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\004\001true\376\003\000\000\002\376\001\000\000\005\001false\376\377\016"));
lf[390]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\011\001procedure\376\377\016"));
lf[391]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\377\016"));
lf[392]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\377\016"));
lf[393]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\377\016"));
lf[394]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\377\016"));
lf[395]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001forall\376\003\000\000\002\376\001\000\000\006\001refine\376\377\016"));
lf[396]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001forall\376\003\000\000\002\376\001\000\000\006\001refine\376\377\016"));
lf[397]=C_h_intern(&lf[397],21, C_text("chicken.base#identity"));
lf[398]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\004\001null\376\003\000\000\002\376\001\000\000\004\001pair\376\377\016"));
lf[399]=C_decode_literal(C_heaptop,C_text("\376B\000\000)procedure-arguments: not a procedure type"));
lf[400]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047procedure-results: not a procedure type"));
lf[401]=C_h_intern(&lf[401],6, C_text("values"));
lf[402]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\010\001noreturn\376\377\016"));
lf[404]=C_decode_literal(C_heaptop,C_text("\376B\000\000,resolve: can\047t resolve unknown type-variable"));
lf[405]=C_h_intern(&lf[405],12, C_text("##sys#append"));
lf[406]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001values\376\377\016"));
lf[407]=C_h_intern(&lf[407],47, C_text("chicken.compiler.scrutinizer#load-type-database"));
lf[408]=C_h_intern(&lf[408],42, C_text("chicken.compiler.scrutinizer#validate-type"));
lf[409]=C_h_intern(&lf[409],52, C_text("chicken.compiler.scrutinizer#install-specializations"));
lf[410]=C_h_intern(&lf[410],2, C_text("db"));
lf[411]=C_h_intern(&lf[411],22, C_text("chicken.format#sprintf"));
lf[412]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047Declared type for toplevel binding `~a\047"));
lf[413]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012~%~%~a~%~%"));
lf[414]=C_decode_literal(C_heaptop,C_text("\376B\000\000(  conflicts with previously loaded type:"));
lf[415]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006~%~%~a"));
lf[416]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\047:"));
lf[417]=C_decode_literal(C_heaptop,C_text("\376B\000\000 Invalid type specification for `"));
lf[418]=C_h_intern_kw(&lf[418],4, C_text("pure"));
lf[419]=C_h_intern_kw(&lf[419],5, C_text("clean"));
lf[420]=C_h_intern_kw(&lf[420],7, C_text("enforce"));
lf[421]=C_h_intern_kw(&lf[421],8, C_text("foldable"));
lf[422]=C_h_intern(&lf[422],19, C_text("##compiler#foldable"));
lf[423]=C_h_intern_kw(&lf[423],9, C_text("predicate"));
lf[424]=C_decode_literal(C_heaptop,C_text("\376B\000\0003load-type-database: invalid procedure-type property"));
lf[425]=C_h_intern(&lf[425],27, C_text("scheme#call-with-input-file"));
lf[426]=C_h_intern(&lf[426],41, C_text("chicken.compiler.support#read-expressions"));
lf[427]=C_h_intern(&lf[427],1, C_text("p"));
lf[428]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005\047 ..."));
lf[429]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027loading type database `"));
lf[430]=C_h_intern(&lf[430],18, C_text("##sys#file-exists\077"));
lf[431]=C_h_intern(&lf[431],22, C_text("chicken.load#find-file"));
lf[432]=C_h_intern(&lf[432],32, C_text("chicken.platform#repository-path"));
lf[433]=C_h_intern(&lf[433],44, C_text("chicken.compiler.scrutinizer#emit-types-file"));
lf[434]=C_h_intern(&lf[434],14, C_text("scheme#newline"));
lf[435]=C_h_intern(&lf[435],23, C_text("chicken.pretty-print#pp"));
lf[436]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\007\002enforce\376\377\016"));
lf[437]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\004\002pure\376\377\016"));
lf[438]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\002clean\376\377\016"));
lf[439]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\010\002foldable\376\377\016"));
lf[440]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001local\376\003\000\000\002\376\001\000\000\011\001inference\376\377\016"));
lf[441]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015; END OF FILE"));
lf[442]=C_h_intern(&lf[442],15, C_text("scheme#string<\077"));
lf[443]=C_h_intern(&lf[443],21, C_text("scheme#symbol->string"));
lf[444]=C_h_intern(&lf[444],17, C_text("chicken.sort#sort"));
lf[445]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027; GENERATED BY CHICKEN "));
lf[446]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006 FROM "));
lf[447]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[448]=C_h_intern(&lf[448],32, C_text("chicken.platform#chicken-version"));
lf[449]=C_h_intern(&lf[449],26, C_text("scheme#with-output-to-file"));
lf[451]=C_h_intern(&lf[451],35, C_text("chicken.compiler.support#copy-node!"));
lf[452]=C_h_intern(&lf[452],41, C_text("chicken.compiler.support#build-node-graph"));
lf[453]=C_h_intern(&lf[453],34, C_text("chicken.compiler.support#copy-node"));
lf[455]=C_h_intern(&lf[455],13, C_text("scheme#values"));
lf[457]=C_h_intern(&lf[457],3, C_text("..."));
lf[458]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[459]=C_h_intern(&lf[459],9, C_text("&optional"));
lf[460]=C_h_intern(&lf[460],5, C_text("&rest"));
lf[461]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[462]=C_h_intern(&lf[462],5, C_text("#!key"));
lf[463]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001#!rest\376\003\000\000\002\376\001\000\000\001\001\052\376\377\016"));
lf[464]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\010\001u8vector\376\003\000\000\002\376\001\000\000\010\001s8vector\376\003\000\000\002\376\001\000\000\011\001u16vector\376\003\000\000\002\376\001\000\000\011\001s16vector\376\003"
"\000\000\002\376\001\000\000\011\001u32vector\376\003\000\000\002\376\001\000\000\011\001s32vector\376\003\000\000\002\376\001\000\000\011\001u64vector\376\003\000\000\002\376\001\000\000\011\001s64vector\376\003"
"\000\000\002\376\001\000\000\011\001f32vector\376\003\000\000\002\376\001\000\000\011\001f64vector\376\003\000\000\002\376\001\000\000\006\001thread\376\003\000\000\002\376\001\000\000\005\001queue\376\003\000\000\002\376\001\000\000"
"\013\001environment\376\003\000\000\002\376\001\000\000\004\001time\376\003\000\000\002\376\001\000\000\014\001continuation\376\003\000\000\002\376\001\000\000\004\001lock\376\003\000\000\002\376\001\000\000\004\001mma"
"p\376\003\000\000\002\376\001\000\000\011\001condition\376\003\000\000\002\376\001\000\000\012\001hash-table\376\003\000\000\002\376\001\000\000\014\001tcp-listener\376\377\016"));
lf[465]=C_h_intern(&lf[465],9, C_text("immediate"));
lf[466]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\002\001or\376\003\000\000\002\376\001\000\000\003\001eof\376\003\000\000\002\376\001\000\000\004\001null\376\003\000\000\002\376\001\000\000\006\001fixnum\376\003\000\000\002\376\001\000\000\004\001char\376\003\000\000\002\376"
"\001\000\000\007\001boolean\376\377\016"));
lf[467]=C_h_intern(&lf[467],3, C_text("any"));
lf[468]=C_h_intern(&lf[468],4, C_text("void"));
lf[469]=C_h_intern(&lf[469],10, C_text("input-port"));
lf[470]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001refine\376\003\000\000\002\376\003\000\000\002\376\001\000\000\005\001input\376\377\016\376\003\000\000\002\376\001\000\000\004\001port\376\377\016"));
lf[471]=C_h_intern(&lf[471],11, C_text("output-port"));
lf[472]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001refine\376\003\000\000\002\376\003\000\000\002\376\001\000\000\006\001output\376\377\016\376\003\000\000\002\376\001\000\000\004\001port\376\377\016"));
lf[473]=C_h_intern(&lf[473],14, C_text("scheme#symbol\077"));
lf[474]=C_h_intern(&lf[474],3, C_text("-->"));
lf[475]=C_h_intern(&lf[475],1, C_text(":"));
lf[476]=C_h_intern(&lf[476],2, C_text("->"));
lf[477]=C_h_intern(&lf[477],9, C_text("##sys#get"));
lf[478]=C_h_intern(&lf[478],28, C_text("##compiler#type-abbreviation"));
lf[479]=C_h_intern(&lf[479],18, C_text("chicken.plist#put!"));
lf[480]=C_h_intern(&lf[480],27, C_text("chicken.syntax#strip-syntax"));
lf[481]=C_h_intern(&lf[481],52, C_text("chicken.compiler.scrutinizer#check-and-validate-type"));
lf[482]=C_h_intern(&lf[482],18, C_text("chicken.base#error"));
lf[483]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026invalid type specifier"));
lf[484]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035invalid specialization format"));
lf[485]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047invalid argument type in specialization"));
lf[486]=C_decode_literal(C_heaptop,C_text("\376B\000\000%invalid result type in specialization"));
lf[487]=C_h_intern(&lf[487],15, C_text("##sys#substring"));
lf[489]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006vector"));
lf[490]=C_h_intern(&lf[490],10, C_text("##sys#slot"));
lf[491]=C_h_intern(&lf[491],8, C_text("not-used"));
lf[492]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004list"));
lf[493]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004list"));
lf[494]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002  "));
lf[495]=C_h_intern(&lf[495],19, C_text("##sys#string-append"));
lf[496]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[497]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[498]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[499]=C_h_intern(&lf[499],27, C_text("chicken.string#string-split"));
lf[500]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[501]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001/"));
lf[502]=C_h_intern_kw(&lf[502],2, C_text("tv"));
lf[503]=C_h_intern(&lf[503],11, C_text("##sys#error"));
lf[504]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037type->pp-string: unhandled type"));
lf[505]=C_h_intern(&lf[505],27, C_text("chicken.string#string-chomp"));
lf[506]=C_h_intern(&lf[506],34, C_text("chicken.port#with-output-to-string"));
lf[507]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001...\376\377\016"));
lf[508]=C_h_intern(&lf[508],46, C_text("chicken.compiler.support#build-expression-tree"));
lf[509]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[510]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\047,"));
lf[511]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011In file `"));
lf[512]=C_h_intern(&lf[512],42, C_text("chicken.compiler.support#source-info->line"));
lf[513]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002  "));
lf[514]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021At the toplevel,\012"));
lf[515]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[516]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[518]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\047,"));
lf[519]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In procedure `"));
lf[520]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\047,"));
lf[521]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013In module `"));
lf[522]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[523]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030In a toplevel procedure,"));
lf[524]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\047,"));
lf[525]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In procedure `"));
lf[526]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025In a local procedure,"));
lf[527]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001#"));
lf[528]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017\047 from module `"));
lf[529]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027This is the expression:"));
lf[530]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[531]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[532]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047It is a call to ~a which has this type:"));
lf[533]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[534]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[535]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[536]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[537]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[538]=C_h_intern(&lf[538],25, C_text("chicken.base#flush-output"));
lf[539]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002  "));
lf[540]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[541]=C_h_intern(&lf[541],22, C_text("chicken.format#fprintf"));
lf[542]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[543]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[544]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[545]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020Invalid argument"));
lf[546]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[547]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[548]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[549]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[550]=C_decode_literal(C_heaptop,C_text("\376B\000\0003Argument #~a to procedure `~a\047 has an invalid type:"));
lf[551]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[552]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[553]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[554]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025The expected type is:"));
lf[555]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[556]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[557]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[558]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[559]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[560]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033Procedure ~a has this type:"));
lf[561]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[562]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[563]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[564]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002 `"));
lf[565]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[566]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[567]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[568]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[569]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036Argument #~a to procedure~a ~a"));
lf[570]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[571]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[572]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032Not enough argument values"));
lf[573]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033does not return any values."));
lf[574]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030Too many argument values"));
lf[575]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032 values but 1 is expected."));
lf[576]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010returns "));
lf[577]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021a negative index "));
lf[578]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\047."));
lf[579]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014 of length `"));
lf[580]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010\047 for a "));
lf[581]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007index `"));
lf[582]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In procedure call:"));
lf[583]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[584]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[585]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[586]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036Procedure ~a is called with ~a"));
lf[587]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006 index"));
lf[588]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011Negative "));
lf[589]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023 index out of range"));
lf[590]=C_h_intern(&lf[590],16, C_text("scheme#substring"));
lf[591]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017In conditional:"));
lf[592]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[593]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[594]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[595]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026The test expression ~a"));
lf[596]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[597]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[598]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033Zero values for conditional"));
lf[599]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021returns 0 values."));
lf[600]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037Too many values for conditional"));
lf[601]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010 values."));
lf[602]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010returns "));
lf[603]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022In let expression:"));
lf[604]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[605]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[606]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[607]=C_decode_literal(C_heaptop,C_text("\376B\000\000/Variable `~a\047 is bound to an expression that ~a"));
lf[608]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[609]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[610]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021returns 0 values."));
lf[611]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021\047 has zero values"));
lf[612]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020Let binding to `"));
lf[613]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010 values."));
lf[614]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010returns "));
lf[615]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007 values"));
lf[616]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006\047 has "));
lf[617]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020Let binding to `"));
lf[618]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In assignment:"));
lf[619]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[620]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[621]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[622]=C_decode_literal(C_heaptop,C_text("\376B\000\0001Variable `~a\047 is assigned from expression that ~a"));
lf[623]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[624]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[625]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021returns 0 values."));
lf[626]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021\047 has zero values"));
lf[627]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017Assignment to `"));
lf[628]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010 values."));
lf[629]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010returns "));
lf[630]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007 values"));
lf[631]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006\047 has "));
lf[632]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017Assignment to `"));
lf[633]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035The suggested alternative is "));
lf[634]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[635]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016In expression:"));
lf[636]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[637]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[638]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004~%~%"));
lf[639]=C_decode_literal(C_heaptop,C_text("\376B\000\000 Use of deprecated identifier ~a."));
lf[640]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002~a"));
lf[641]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027Deprecated identifier `"));
lf[642]=C_h_intern(&lf[642],10, C_text("##sys#put!"));
lf[643]=C_h_intern(&lf[643],18, C_text("scheme#make-vector"));
lf[644]=C_h_intern(&lf[644],12, C_text("##sys#vector"));
lf[645]=C_h_intern(&lf[645],13, C_text("scheme#vector"));
lf[646]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\004\001null\376\377\016"));
lf[647]=C_h_intern(&lf[647],10, C_text("##sys#list"));
lf[648]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\004\001null\376\377\016"));
lf[649]=C_h_intern(&lf[649],11, C_text("scheme#list"));
lf[650]=C_h_intern(&lf[650],16, C_text("scheme#list-tail"));
lf[651]=C_h_intern(&lf[651],15, C_text("scheme#list-ref"));
lf[652]=C_h_intern(&lf[652],14, C_text("##sys#setislot"));
lf[653]=C_h_intern(&lf[653],13, C_text("##sys#setslot"));
lf[654]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\011\001undefined\376\377\016"));
lf[655]=C_h_intern(&lf[655],18, C_text("scheme#vector-set!"));
lf[656]=C_h_intern(&lf[656],16, C_text("##sys#vector-ref"));
lf[657]=C_h_intern(&lf[657],17, C_text("scheme#vector-ref"));
lf[658]=C_h_intern(&lf[658],14, C_text("pointer-vector"));
lf[659]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\016\001pointer-vector\376\377\016"));
lf[660]=C_h_intern(&lf[660],20, C_text("##sys#make-structure"));
C_register_lf2(lf,661,create_ptable());{}
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6792,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_library_toplevel(2,av2);}}

#ifdef C_ENABLE_PTABLES
static C_PTABLE_ENTRY ptable[1331] = {
{C_text("f26096:scrutinizer_2escm"),(void*)f26096},
{C_text("f26203:scrutinizer_2escm"),(void*)f26203},
{C_text("f26218:scrutinizer_2escm"),(void*)f26218},
{C_text("f26225:scrutinizer_2escm"),(void*)f26225},
{C_text("f26473:scrutinizer_2escm"),(void*)f26473},
{C_text("f26621:scrutinizer_2escm"),(void*)f26621},
{C_text("f26686:scrutinizer_2escm"),(void*)f26686},
{C_text("f26693:scrutinizer_2escm"),(void*)f26693},
{C_text("f26845:scrutinizer_2escm"),(void*)f26845},
{C_text("f26850:scrutinizer_2escm"),(void*)f26850},
{C_text("f26859:scrutinizer_2escm"),(void*)f26859},
{C_text("f26866:scrutinizer_2escm"),(void*)f26866},
{C_text("f26905:scrutinizer_2escm"),(void*)f26905},
{C_text("f26910:scrutinizer_2escm"),(void*)f26910},
{C_text("f26915:scrutinizer_2escm"),(void*)f26915},
{C_text("f26922:scrutinizer_2escm"),(void*)f26922},
{C_text("f26929:scrutinizer_2escm"),(void*)f26929},
{C_text("f26936:scrutinizer_2escm"),(void*)f26936},
{C_text("f26943:scrutinizer_2escm"),(void*)f26943},
{C_text("f28250:scrutinizer_2escm"),(void*)f28250},
{C_text("f28255:scrutinizer_2escm"),(void*)f28255},
{C_text("f28274:scrutinizer_2escm"),(void*)f28274},
{C_text("f28508:scrutinizer_2escm"),(void*)f28508},
{C_text("f28513:scrutinizer_2escm"),(void*)f28513},
{C_text("f28518:scrutinizer_2escm"),(void*)f28518},
{C_text("f_10005:scrutinizer_2escm"),(void*)f_10005},
{C_text("f_10023:scrutinizer_2escm"),(void*)f_10023},
{C_text("f_10032:scrutinizer_2escm"),(void*)f_10032},
{C_text("f_10035:scrutinizer_2escm"),(void*)f_10035},
{C_text("f_10051:scrutinizer_2escm"),(void*)f_10051},
{C_text("f_10060:scrutinizer_2escm"),(void*)f_10060},
{C_text("f_10068:scrutinizer_2escm"),(void*)f_10068},
{C_text("f_10078:scrutinizer_2escm"),(void*)f_10078},
{C_text("f_10082:scrutinizer_2escm"),(void*)f_10082},
{C_text("f_10086:scrutinizer_2escm"),(void*)f_10086},
{C_text("f_10088:scrutinizer_2escm"),(void*)f_10088},
{C_text("f_10110:scrutinizer_2escm"),(void*)f_10110},
{C_text("f_10117:scrutinizer_2escm"),(void*)f_10117},
{C_text("f_10120:scrutinizer_2escm"),(void*)f_10120},
{C_text("f_10123:scrutinizer_2escm"),(void*)f_10123},
{C_text("f_10131:scrutinizer_2escm"),(void*)f_10131},
{C_text("f_10140:scrutinizer_2escm"),(void*)f_10140},
{C_text("f_10147:scrutinizer_2escm"),(void*)f_10147},
{C_text("f_10154:scrutinizer_2escm"),(void*)f_10154},
{C_text("f_10162:scrutinizer_2escm"),(void*)f_10162},
{C_text("f_10164:scrutinizer_2escm"),(void*)f_10164},
{C_text("f_10172:scrutinizer_2escm"),(void*)f_10172},
{C_text("f_10176:scrutinizer_2escm"),(void*)f_10176},
{C_text("f_10188:scrutinizer_2escm"),(void*)f_10188},
{C_text("f_10223:scrutinizer_2escm"),(void*)f_10223},
{C_text("f_10245:scrutinizer_2escm"),(void*)f_10245},
{C_text("f_10257:scrutinizer_2escm"),(void*)f_10257},
{C_text("f_10270:scrutinizer_2escm"),(void*)f_10270},
{C_text("f_10292:scrutinizer_2escm"),(void*)f_10292},
{C_text("f_10301:scrutinizer_2escm"),(void*)f_10301},
{C_text("f_10303:scrutinizer_2escm"),(void*)f_10303},
{C_text("f_10374:scrutinizer_2escm"),(void*)f_10374},
{C_text("f_10377:scrutinizer_2escm"),(void*)f_10377},
{C_text("f_10380:scrutinizer_2escm"),(void*)f_10380},
{C_text("f_10386:scrutinizer_2escm"),(void*)f_10386},
{C_text("f_10389:scrutinizer_2escm"),(void*)f_10389},
{C_text("f_10392:scrutinizer_2escm"),(void*)f_10392},
{C_text("f_10398:scrutinizer_2escm"),(void*)f_10398},
{C_text("f_10412:scrutinizer_2escm"),(void*)f_10412},
{C_text("f_10420:scrutinizer_2escm"),(void*)f_10420},
{C_text("f_10454:scrutinizer_2escm"),(void*)f_10454},
{C_text("f_10503:scrutinizer_2escm"),(void*)f_10503},
{C_text("f_10518:scrutinizer_2escm"),(void*)f_10518},
{C_text("f_10521:scrutinizer_2escm"),(void*)f_10521},
{C_text("f_10524:scrutinizer_2escm"),(void*)f_10524},
{C_text("f_10533:scrutinizer_2escm"),(void*)f_10533},
{C_text("f_10539:scrutinizer_2escm"),(void*)f_10539},
{C_text("f_10545:scrutinizer_2escm"),(void*)f_10545},
{C_text("f_10548:scrutinizer_2escm"),(void*)f_10548},
{C_text("f_10555:scrutinizer_2escm"),(void*)f_10555},
{C_text("f_10561:scrutinizer_2escm"),(void*)f_10561},
{C_text("f_10564:scrutinizer_2escm"),(void*)f_10564},
{C_text("f_10567:scrutinizer_2escm"),(void*)f_10567},
{C_text("f_10570:scrutinizer_2escm"),(void*)f_10570},
{C_text("f_10573:scrutinizer_2escm"),(void*)f_10573},
{C_text("f_10576:scrutinizer_2escm"),(void*)f_10576},
{C_text("f_10584:scrutinizer_2escm"),(void*)f_10584},
{C_text("f_10604:scrutinizer_2escm"),(void*)f_10604},
{C_text("f_10608:scrutinizer_2escm"),(void*)f_10608},
{C_text("f_10637:scrutinizer_2escm"),(void*)f_10637},
{C_text("f_10644:scrutinizer_2escm"),(void*)f_10644},
{C_text("f_10647:scrutinizer_2escm"),(void*)f_10647},
{C_text("f_10667:scrutinizer_2escm"),(void*)f_10667},
{C_text("f_10674:scrutinizer_2escm"),(void*)f_10674},
{C_text("f_10696:scrutinizer_2escm"),(void*)f_10696},
{C_text("f_10700:scrutinizer_2escm"),(void*)f_10700},
{C_text("f_10707:scrutinizer_2escm"),(void*)f_10707},
{C_text("f_10709:scrutinizer_2escm"),(void*)f_10709},
{C_text("f_10736:scrutinizer_2escm"),(void*)f_10736},
{C_text("f_10743:scrutinizer_2escm"),(void*)f_10743},
{C_text("f_10759:scrutinizer_2escm"),(void*)f_10759},
{C_text("f_10763:scrutinizer_2escm"),(void*)f_10763},
{C_text("f_10765:scrutinizer_2escm"),(void*)f_10765},
{C_text("f_10772:scrutinizer_2escm"),(void*)f_10772},
{C_text("f_10778:scrutinizer_2escm"),(void*)f_10778},
{C_text("f_10784:scrutinizer_2escm"),(void*)f_10784},
{C_text("f_10787:scrutinizer_2escm"),(void*)f_10787},
{C_text("f_10790:scrutinizer_2escm"),(void*)f_10790},
{C_text("f_10793:scrutinizer_2escm"),(void*)f_10793},
{C_text("f_10798:scrutinizer_2escm"),(void*)f_10798},
{C_text("f_10804:scrutinizer_2escm"),(void*)f_10804},
{C_text("f_10807:scrutinizer_2escm"),(void*)f_10807},
{C_text("f_10814:scrutinizer_2escm"),(void*)f_10814},
{C_text("f_10817:scrutinizer_2escm"),(void*)f_10817},
{C_text("f_10842:scrutinizer_2escm"),(void*)f_10842},
{C_text("f_10846:scrutinizer_2escm"),(void*)f_10846},
{C_text("f_10852:scrutinizer_2escm"),(void*)f_10852},
{C_text("f_10855:scrutinizer_2escm"),(void*)f_10855},
{C_text("f_10865:scrutinizer_2escm"),(void*)f_10865},
{C_text("f_10877:scrutinizer_2escm"),(void*)f_10877},
{C_text("f_10902:scrutinizer_2escm"),(void*)f_10902},
{C_text("f_10919:scrutinizer_2escm"),(void*)f_10919},
{C_text("f_10932:scrutinizer_2escm"),(void*)f_10932},
{C_text("f_10935:scrutinizer_2escm"),(void*)f_10935},
{C_text("f_10938:scrutinizer_2escm"),(void*)f_10938},
{C_text("f_10944:scrutinizer_2escm"),(void*)f_10944},
{C_text("f_10950:scrutinizer_2escm"),(void*)f_10950},
{C_text("f_10956:scrutinizer_2escm"),(void*)f_10956},
{C_text("f_10962:scrutinizer_2escm"),(void*)f_10962},
{C_text("f_10985:scrutinizer_2escm"),(void*)f_10985},
{C_text("f_11000:scrutinizer_2escm"),(void*)f_11000},
{C_text("f_11006:scrutinizer_2escm"),(void*)f_11006},
{C_text("f_11012:scrutinizer_2escm"),(void*)f_11012},
{C_text("f_11028:scrutinizer_2escm"),(void*)f_11028},
{C_text("f_11034:scrutinizer_2escm"),(void*)f_11034},
{C_text("f_11038:scrutinizer_2escm"),(void*)f_11038},
{C_text("f_11046:scrutinizer_2escm"),(void*)f_11046},
{C_text("f_11068:scrutinizer_2escm"),(void*)f_11068},
{C_text("f_11079:scrutinizer_2escm"),(void*)f_11079},
{C_text("f_11083:scrutinizer_2escm"),(void*)f_11083},
{C_text("f_11092:scrutinizer_2escm"),(void*)f_11092},
{C_text("f_11095:scrutinizer_2escm"),(void*)f_11095},
{C_text("f_11105:scrutinizer_2escm"),(void*)f_11105},
{C_text("f_11117:scrutinizer_2escm"),(void*)f_11117},
{C_text("f_11142:scrutinizer_2escm"),(void*)f_11142},
{C_text("f_11151:scrutinizer_2escm"),(void*)f_11151},
{C_text("f_11161:scrutinizer_2escm"),(void*)f_11161},
{C_text("f_11190:scrutinizer_2escm"),(void*)f_11190},
{C_text("f_11192:scrutinizer_2escm"),(void*)f_11192},
{C_text("f_11200:scrutinizer_2escm"),(void*)f_11200},
{C_text("f_11208:scrutinizer_2escm"),(void*)f_11208},
{C_text("f_11225:scrutinizer_2escm"),(void*)f_11225},
{C_text("f_11227:scrutinizer_2escm"),(void*)f_11227},
{C_text("f_11265:scrutinizer_2escm"),(void*)f_11265},
{C_text("f_11294:scrutinizer_2escm"),(void*)f_11294},
{C_text("f_11323:scrutinizer_2escm"),(void*)f_11323},
{C_text("f_11329:scrutinizer_2escm"),(void*)f_11329},
{C_text("f_11348:scrutinizer_2escm"),(void*)f_11348},
{C_text("f_11354:scrutinizer_2escm"),(void*)f_11354},
{C_text("f_11357:scrutinizer_2escm"),(void*)f_11357},
{C_text("f_11379:scrutinizer_2escm"),(void*)f_11379},
{C_text("f_11411:scrutinizer_2escm"),(void*)f_11411},
{C_text("f_11414:scrutinizer_2escm"),(void*)f_11414},
{C_text("f_11427:scrutinizer_2escm"),(void*)f_11427},
{C_text("f_11448:scrutinizer_2escm"),(void*)f_11448},
{C_text("f_11454:scrutinizer_2escm"),(void*)f_11454},
{C_text("f_11457:scrutinizer_2escm"),(void*)f_11457},
{C_text("f_11467:scrutinizer_2escm"),(void*)f_11467},
{C_text("f_11486:scrutinizer_2escm"),(void*)f_11486},
{C_text("f_11511:scrutinizer_2escm"),(void*)f_11511},
{C_text("f_11521:scrutinizer_2escm"),(void*)f_11521},
{C_text("f_11523:scrutinizer_2escm"),(void*)f_11523},
{C_text("f_11533:scrutinizer_2escm"),(void*)f_11533},
{C_text("f_11594:scrutinizer_2escm"),(void*)f_11594},
{C_text("f_11597:scrutinizer_2escm"),(void*)f_11597},
{C_text("f_11600:scrutinizer_2escm"),(void*)f_11600},
{C_text("f_11603:scrutinizer_2escm"),(void*)f_11603},
{C_text("f_11606:scrutinizer_2escm"),(void*)f_11606},
{C_text("f_11612:scrutinizer_2escm"),(void*)f_11612},
{C_text("f_11635:scrutinizer_2escm"),(void*)f_11635},
{C_text("f_11639:scrutinizer_2escm"),(void*)f_11639},
{C_text("f_11647:scrutinizer_2escm"),(void*)f_11647},
{C_text("f_11650:scrutinizer_2escm"),(void*)f_11650},
{C_text("f_11653:scrutinizer_2escm"),(void*)f_11653},
{C_text("f_11656:scrutinizer_2escm"),(void*)f_11656},
{C_text("f_11673:scrutinizer_2escm"),(void*)f_11673},
{C_text("f_11683:scrutinizer_2escm"),(void*)f_11683},
{C_text("f_11710:scrutinizer_2escm"),(void*)f_11710},
{C_text("f_11712:scrutinizer_2escm"),(void*)f_11712},
{C_text("f_11718:scrutinizer_2escm"),(void*)f_11718},
{C_text("f_11728:scrutinizer_2escm"),(void*)f_11728},
{C_text("f_11740:scrutinizer_2escm"),(void*)f_11740},
{C_text("f_11748:scrutinizer_2escm"),(void*)f_11748},
{C_text("f_11768:scrutinizer_2escm"),(void*)f_11768},
{C_text("f_11781:scrutinizer_2escm"),(void*)f_11781},
{C_text("f_11793:scrutinizer_2escm"),(void*)f_11793},
{C_text("f_11800:scrutinizer_2escm"),(void*)f_11800},
{C_text("f_11802:scrutinizer_2escm"),(void*)f_11802},
{C_text("f_11827:scrutinizer_2escm"),(void*)f_11827},
{C_text("f_11849:scrutinizer_2escm"),(void*)f_11849},
{C_text("f_11862:scrutinizer_2escm"),(void*)f_11862},
{C_text("f_11883:scrutinizer_2escm"),(void*)f_11883},
{C_text("f_11908:scrutinizer_2escm"),(void*)f_11908},
{C_text("f_11912:scrutinizer_2escm"),(void*)f_11912},
{C_text("f_11923:scrutinizer_2escm"),(void*)f_11923},
{C_text("f_11932:scrutinizer_2escm"),(void*)f_11932},
{C_text("f_12029:scrutinizer_2escm"),(void*)f_12029},
{C_text("f_12054:scrutinizer_2escm"),(void*)f_12054},
{C_text("f_12060:scrutinizer_2escm"),(void*)f_12060},
{C_text("f_12076:scrutinizer_2escm"),(void*)f_12076},
{C_text("f_12083:scrutinizer_2escm"),(void*)f_12083},
{C_text("f_12100:scrutinizer_2escm"),(void*)f_12100},
{C_text("f_12117:scrutinizer_2escm"),(void*)f_12117},
{C_text("f_12160:scrutinizer_2escm"),(void*)f_12160},
{C_text("f_12185:scrutinizer_2escm"),(void*)f_12185},
{C_text("f_12191:scrutinizer_2escm"),(void*)f_12191},
{C_text("f_12196:scrutinizer_2escm"),(void*)f_12196},
{C_text("f_12202:scrutinizer_2escm"),(void*)f_12202},
{C_text("f_12207:scrutinizer_2escm"),(void*)f_12207},
{C_text("f_12213:scrutinizer_2escm"),(void*)f_12213},
{C_text("f_12226:scrutinizer_2escm"),(void*)f_12226},
{C_text("f_12243:scrutinizer_2escm"),(void*)f_12243},
{C_text("f_12260:scrutinizer_2escm"),(void*)f_12260},
{C_text("f_12273:scrutinizer_2escm"),(void*)f_12273},
{C_text("f_12301:scrutinizer_2escm"),(void*)f_12301},
{C_text("f_12314:scrutinizer_2escm"),(void*)f_12314},
{C_text("f_12351:scrutinizer_2escm"),(void*)f_12351},
{C_text("f_12392:scrutinizer_2escm"),(void*)f_12392},
{C_text("f_12405:scrutinizer_2escm"),(void*)f_12405},
{C_text("f_12435:scrutinizer_2escm"),(void*)f_12435},
{C_text("f_12505:scrutinizer_2escm"),(void*)f_12505},
{C_text("f_12509:scrutinizer_2escm"),(void*)f_12509},
{C_text("f_12519:scrutinizer_2escm"),(void*)f_12519},
{C_text("f_12523:scrutinizer_2escm"),(void*)f_12523},
{C_text("f_12544:scrutinizer_2escm"),(void*)f_12544},
{C_text("f_12549:scrutinizer_2escm"),(void*)f_12549},
{C_text("f_12553:scrutinizer_2escm"),(void*)f_12553},
{C_text("f_12556:scrutinizer_2escm"),(void*)f_12556},
{C_text("f_12565:scrutinizer_2escm"),(void*)f_12565},
{C_text("f_12585:scrutinizer_2escm"),(void*)f_12585},
{C_text("f_12590:scrutinizer_2escm"),(void*)f_12590},
{C_text("f_12594:scrutinizer_2escm"),(void*)f_12594},
{C_text("f_12597:scrutinizer_2escm"),(void*)f_12597},
{C_text("f_12606:scrutinizer_2escm"),(void*)f_12606},
{C_text("f_12624:scrutinizer_2escm"),(void*)f_12624},
{C_text("f_12643:scrutinizer_2escm"),(void*)f_12643},
{C_text("f_12759:scrutinizer_2escm"),(void*)f_12759},
{C_text("f_12771:scrutinizer_2escm"),(void*)f_12771},
{C_text("f_12774:scrutinizer_2escm"),(void*)f_12774},
{C_text("f_12777:scrutinizer_2escm"),(void*)f_12777},
{C_text("f_12780:scrutinizer_2escm"),(void*)f_12780},
{C_text("f_12786:scrutinizer_2escm"),(void*)f_12786},
{C_text("f_12879:scrutinizer_2escm"),(void*)f_12879},
{C_text("f_12989:scrutinizer_2escm"),(void*)f_12989},
{C_text("f_13022:scrutinizer_2escm"),(void*)f_13022},
{C_text("f_13091:scrutinizer_2escm"),(void*)f_13091},
{C_text("f_13124:scrutinizer_2escm"),(void*)f_13124},
{C_text("f_13198:scrutinizer_2escm"),(void*)f_13198},
{C_text("f_13232:scrutinizer_2escm"),(void*)f_13232},
{C_text("f_13274:scrutinizer_2escm"),(void*)f_13274},
{C_text("f_13308:scrutinizer_2escm"),(void*)f_13308},
{C_text("f_13496:scrutinizer_2escm"),(void*)f_13496},
{C_text("f_13502:scrutinizer_2escm"),(void*)f_13502},
{C_text("f_13535:scrutinizer_2escm"),(void*)f_13535},
{C_text("f_13549:scrutinizer_2escm"),(void*)f_13549},
{C_text("f_13568:scrutinizer_2escm"),(void*)f_13568},
{C_text("f_13571:scrutinizer_2escm"),(void*)f_13571},
{C_text("f_13577:scrutinizer_2escm"),(void*)f_13577},
{C_text("f_13598:scrutinizer_2escm"),(void*)f_13598},
{C_text("f_13602:scrutinizer_2escm"),(void*)f_13602},
{C_text("f_13613:scrutinizer_2escm"),(void*)f_13613},
{C_text("f_13615:scrutinizer_2escm"),(void*)f_13615},
{C_text("f_13650:scrutinizer_2escm"),(void*)f_13650},
{C_text("f_13652:scrutinizer_2escm"),(void*)f_13652},
{C_text("f_13693:scrutinizer_2escm"),(void*)f_13693},
{C_text("f_13721:scrutinizer_2escm"),(void*)f_13721},
{C_text("f_13727:scrutinizer_2escm"),(void*)f_13727},
{C_text("f_13739:scrutinizer_2escm"),(void*)f_13739},
{C_text("f_13759:scrutinizer_2escm"),(void*)f_13759},
{C_text("f_13762:scrutinizer_2escm"),(void*)f_13762},
{C_text("f_13765:scrutinizer_2escm"),(void*)f_13765},
{C_text("f_13768:scrutinizer_2escm"),(void*)f_13768},
{C_text("f_13771:scrutinizer_2escm"),(void*)f_13771},
{C_text("f_13774:scrutinizer_2escm"),(void*)f_13774},
{C_text("f_13781:scrutinizer_2escm"),(void*)f_13781},
{C_text("f_13789:scrutinizer_2escm"),(void*)f_13789},
{C_text("f_13793:scrutinizer_2escm"),(void*)f_13793},
{C_text("f_13808:scrutinizer_2escm"),(void*)f_13808},
{C_text("f_13814:scrutinizer_2escm"),(void*)f_13814},
{C_text("f_13824:scrutinizer_2escm"),(void*)f_13824},
{C_text("f_13830:scrutinizer_2escm"),(void*)f_13830},
{C_text("f_13836:scrutinizer_2escm"),(void*)f_13836},
{C_text("f_13839:scrutinizer_2escm"),(void*)f_13839},
{C_text("f_13842:scrutinizer_2escm"),(void*)f_13842},
{C_text("f_13859:scrutinizer_2escm"),(void*)f_13859},
{C_text("f_13884:scrutinizer_2escm"),(void*)f_13884},
{C_text("f_13895:scrutinizer_2escm"),(void*)f_13895},
{C_text("f_13913:scrutinizer_2escm"),(void*)f_13913},
{C_text("f_13923:scrutinizer_2escm"),(void*)f_13923},
{C_text("f_13939:scrutinizer_2escm"),(void*)f_13939},
{C_text("f_13943:scrutinizer_2escm"),(void*)f_13943},
{C_text("f_14001:scrutinizer_2escm"),(void*)f_14001},
{C_text("f_14003:scrutinizer_2escm"),(void*)f_14003},
{C_text("f_14028:scrutinizer_2escm"),(void*)f_14028},
{C_text("f_14047:scrutinizer_2escm"),(void*)f_14047},
{C_text("f_14066:scrutinizer_2escm"),(void*)f_14066},
{C_text("f_14081:scrutinizer_2escm"),(void*)f_14081},
{C_text("f_14094:scrutinizer_2escm"),(void*)f_14094},
{C_text("f_14097:scrutinizer_2escm"),(void*)f_14097},
{C_text("f_14133:scrutinizer_2escm"),(void*)f_14133},
{C_text("f_14157:scrutinizer_2escm"),(void*)f_14157},
{C_text("f_14198:scrutinizer_2escm"),(void*)f_14198},
{C_text("f_14200:scrutinizer_2escm"),(void*)f_14200},
{C_text("f_14225:scrutinizer_2escm"),(void*)f_14225},
{C_text("f_14254:scrutinizer_2escm"),(void*)f_14254},
{C_text("f_14256:scrutinizer_2escm"),(void*)f_14256},
{C_text("f_14281:scrutinizer_2escm"),(void*)f_14281},
{C_text("f_14315:scrutinizer_2escm"),(void*)f_14315},
{C_text("f_14329:scrutinizer_2escm"),(void*)f_14329},
{C_text("f_14354:scrutinizer_2escm"),(void*)f_14354},
{C_text("f_14374:scrutinizer_2escm"),(void*)f_14374},
{C_text("f_14376:scrutinizer_2escm"),(void*)f_14376},
{C_text("f_14401:scrutinizer_2escm"),(void*)f_14401},
{C_text("f_14454:scrutinizer_2escm"),(void*)f_14454},
{C_text("f_14459:scrutinizer_2escm"),(void*)f_14459},
{C_text("f_14468:scrutinizer_2escm"),(void*)f_14468},
{C_text("f_14485:scrutinizer_2escm"),(void*)f_14485},
{C_text("f_14487:scrutinizer_2escm"),(void*)f_14487},
{C_text("f_14502:scrutinizer_2escm"),(void*)f_14502},
{C_text("f_14510:scrutinizer_2escm"),(void*)f_14510},
{C_text("f_14537:scrutinizer_2escm"),(void*)f_14537},
{C_text("f_14583:scrutinizer_2escm"),(void*)f_14583},
{C_text("f_14632:scrutinizer_2escm"),(void*)f_14632},
{C_text("f_14636:scrutinizer_2escm"),(void*)f_14636},
{C_text("f_14682:scrutinizer_2escm"),(void*)f_14682},
{C_text("f_14686:scrutinizer_2escm"),(void*)f_14686},
{C_text("f_14712:scrutinizer_2escm"),(void*)f_14712},
{C_text("f_14718:scrutinizer_2escm"),(void*)f_14718},
{C_text("f_14744:scrutinizer_2escm"),(void*)f_14744},
{C_text("f_14748:scrutinizer_2escm"),(void*)f_14748},
{C_text("f_14775:scrutinizer_2escm"),(void*)f_14775},
{C_text("f_14779:scrutinizer_2escm"),(void*)f_14779},
{C_text("f_14782:scrutinizer_2escm"),(void*)f_14782},
{C_text("f_14807:scrutinizer_2escm"),(void*)f_14807},
{C_text("f_14813:scrutinizer_2escm"),(void*)f_14813},
{C_text("f_14819:scrutinizer_2escm"),(void*)f_14819},
{C_text("f_14834:scrutinizer_2escm"),(void*)f_14834},
{C_text("f_14838:scrutinizer_2escm"),(void*)f_14838},
{C_text("f_14843:scrutinizer_2escm"),(void*)f_14843},
{C_text("f_14862:scrutinizer_2escm"),(void*)f_14862},
{C_text("f_14871:scrutinizer_2escm"),(void*)f_14871},
{C_text("f_14875:scrutinizer_2escm"),(void*)f_14875},
{C_text("f_14879:scrutinizer_2escm"),(void*)f_14879},
{C_text("f_14889:scrutinizer_2escm"),(void*)f_14889},
{C_text("f_14893:scrutinizer_2escm"),(void*)f_14893},
{C_text("f_14909:scrutinizer_2escm"),(void*)f_14909},
{C_text("f_14936:scrutinizer_2escm"),(void*)f_14936},
{C_text("f_14960:scrutinizer_2escm"),(void*)f_14960},
{C_text("f_14969:scrutinizer_2escm"),(void*)f_14969},
{C_text("f_14980:scrutinizer_2escm"),(void*)f_14980},
{C_text("f_14994:scrutinizer_2escm"),(void*)f_14994},
{C_text("f_15012:scrutinizer_2escm"),(void*)f_15012},
{C_text("f_15018:scrutinizer_2escm"),(void*)f_15018},
{C_text("f_15025:scrutinizer_2escm"),(void*)f_15025},
{C_text("f_15054:scrutinizer_2escm"),(void*)f_15054},
{C_text("f_15133:scrutinizer_2escm"),(void*)f_15133},
{C_text("f_15163:scrutinizer_2escm"),(void*)f_15163},
{C_text("f_15166:scrutinizer_2escm"),(void*)f_15166},
{C_text("f_15184:scrutinizer_2escm"),(void*)f_15184},
{C_text("f_15236:scrutinizer_2escm"),(void*)f_15236},
{C_text("f_15287:scrutinizer_2escm"),(void*)f_15287},
{C_text("f_15344:scrutinizer_2escm"),(void*)f_15344},
{C_text("f_15401:scrutinizer_2escm"),(void*)f_15401},
{C_text("f_15410:scrutinizer_2escm"),(void*)f_15410},
{C_text("f_15420:scrutinizer_2escm"),(void*)f_15420},
{C_text("f_15427:scrutinizer_2escm"),(void*)f_15427},
{C_text("f_15429:scrutinizer_2escm"),(void*)f_15429},
{C_text("f_15508:scrutinizer_2escm"),(void*)f_15508},
{C_text("f_15564:scrutinizer_2escm"),(void*)f_15564},
{C_text("f_15597:scrutinizer_2escm"),(void*)f_15597},
{C_text("f_15624:scrutinizer_2escm"),(void*)f_15624},
{C_text("f_15635:scrutinizer_2escm"),(void*)f_15635},
{C_text("f_15657:scrutinizer_2escm"),(void*)f_15657},
{C_text("f_15665:scrutinizer_2escm"),(void*)f_15665},
{C_text("f_15667:scrutinizer_2escm"),(void*)f_15667},
{C_text("f_15693:scrutinizer_2escm"),(void*)f_15693},
{C_text("f_15752:scrutinizer_2escm"),(void*)f_15752},
{C_text("f_15805:scrutinizer_2escm"),(void*)f_15805},
{C_text("f_15825:scrutinizer_2escm"),(void*)f_15825},
{C_text("f_15884:scrutinizer_2escm"),(void*)f_15884},
{C_text("f_15928:scrutinizer_2escm"),(void*)f_15928},
{C_text("f_15967:scrutinizer_2escm"),(void*)f_15967},
{C_text("f_15970:scrutinizer_2escm"),(void*)f_15970},
{C_text("f_15975:scrutinizer_2escm"),(void*)f_15975},
{C_text("f_15979:scrutinizer_2escm"),(void*)f_15979},
{C_text("f_15981:scrutinizer_2escm"),(void*)f_15981},
{C_text("f_16026:scrutinizer_2escm"),(void*)f_16026},
{C_text("f_16043:scrutinizer_2escm"),(void*)f_16043},
{C_text("f_16053:scrutinizer_2escm"),(void*)f_16053},
{C_text("f_16070:scrutinizer_2escm"),(void*)f_16070},
{C_text("f_16080:scrutinizer_2escm"),(void*)f_16080},
{C_text("f_16100:scrutinizer_2escm"),(void*)f_16100},
{C_text("f_16116:scrutinizer_2escm"),(void*)f_16116},
{C_text("f_16126:scrutinizer_2escm"),(void*)f_16126},
{C_text("f_16143:scrutinizer_2escm"),(void*)f_16143},
{C_text("f_16153:scrutinizer_2escm"),(void*)f_16153},
{C_text("f_16185:scrutinizer_2escm"),(void*)f_16185},
{C_text("f_16227:scrutinizer_2escm"),(void*)f_16227},
{C_text("f_16229:scrutinizer_2escm"),(void*)f_16229},
{C_text("f_16254:scrutinizer_2escm"),(void*)f_16254},
{C_text("f_16276:scrutinizer_2escm"),(void*)f_16276},
{C_text("f_16286:scrutinizer_2escm"),(void*)f_16286},
{C_text("f_16307:scrutinizer_2escm"),(void*)f_16307},
{C_text("f_16313:scrutinizer_2escm"),(void*)f_16313},
{C_text("f_16345:scrutinizer_2escm"),(void*)f_16345},
{C_text("f_16348:scrutinizer_2escm"),(void*)f_16348},
{C_text("f_16350:scrutinizer_2escm"),(void*)f_16350},
{C_text("f_16358:scrutinizer_2escm"),(void*)f_16358},
{C_text("f_16360:scrutinizer_2escm"),(void*)f_16360},
{C_text("f_16368:scrutinizer_2escm"),(void*)f_16368},
{C_text("f_16449:scrutinizer_2escm"),(void*)f_16449},
{C_text("f_16460:scrutinizer_2escm"),(void*)f_16460},
{C_text("f_16462:scrutinizer_2escm"),(void*)f_16462},
{C_text("f_16487:scrutinizer_2escm"),(void*)f_16487},
{C_text("f_16507:scrutinizer_2escm"),(void*)f_16507},
{C_text("f_16533:scrutinizer_2escm"),(void*)f_16533},
{C_text("f_16546:scrutinizer_2escm"),(void*)f_16546},
{C_text("f_16556:scrutinizer_2escm"),(void*)f_16556},
{C_text("f_16567:scrutinizer_2escm"),(void*)f_16567},
{C_text("f_16569:scrutinizer_2escm"),(void*)f_16569},
{C_text("f_16594:scrutinizer_2escm"),(void*)f_16594},
{C_text("f_16610:scrutinizer_2escm"),(void*)f_16610},
{C_text("f_16613:scrutinizer_2escm"),(void*)f_16613},
{C_text("f_16616:scrutinizer_2escm"),(void*)f_16616},
{C_text("f_16623:scrutinizer_2escm"),(void*)f_16623},
{C_text("f_16635:scrutinizer_2escm"),(void*)f_16635},
{C_text("f_16639:scrutinizer_2escm"),(void*)f_16639},
{C_text("f_16646:scrutinizer_2escm"),(void*)f_16646},
{C_text("f_16658:scrutinizer_2escm"),(void*)f_16658},
{C_text("f_16683:scrutinizer_2escm"),(void*)f_16683},
{C_text("f_16692:scrutinizer_2escm"),(void*)f_16692},
{C_text("f_16720:scrutinizer_2escm"),(void*)f_16720},
{C_text("f_16739:scrutinizer_2escm"),(void*)f_16739},
{C_text("f_16748:scrutinizer_2escm"),(void*)f_16748},
{C_text("f_16752:scrutinizer_2escm"),(void*)f_16752},
{C_text("f_16815:scrutinizer_2escm"),(void*)f_16815},
{C_text("f_16819:scrutinizer_2escm"),(void*)f_16819},
{C_text("f_16822:scrutinizer_2escm"),(void*)f_16822},
{C_text("f_16828:scrutinizer_2escm"),(void*)f_16828},
{C_text("f_16833:scrutinizer_2escm"),(void*)f_16833},
{C_text("f_16838:scrutinizer_2escm"),(void*)f_16838},
{C_text("f_16847:scrutinizer_2escm"),(void*)f_16847},
{C_text("f_16853:scrutinizer_2escm"),(void*)f_16853},
{C_text("f_16858:scrutinizer_2escm"),(void*)f_16858},
{C_text("f_16864:scrutinizer_2escm"),(void*)f_16864},
{C_text("f_16868:scrutinizer_2escm"),(void*)f_16868},
{C_text("f_16871:scrutinizer_2escm"),(void*)f_16871},
{C_text("f_16874:scrutinizer_2escm"),(void*)f_16874},
{C_text("f_16877:scrutinizer_2escm"),(void*)f_16877},
{C_text("f_16886:scrutinizer_2escm"),(void*)f_16886},
{C_text("f_16893:scrutinizer_2escm"),(void*)f_16893},
{C_text("f_16897:scrutinizer_2escm"),(void*)f_16897},
{C_text("f_16901:scrutinizer_2escm"),(void*)f_16901},
{C_text("f_16905:scrutinizer_2escm"),(void*)f_16905},
{C_text("f_16912:scrutinizer_2escm"),(void*)f_16912},
{C_text("f_16919:scrutinizer_2escm"),(void*)f_16919},
{C_text("f_16925:scrutinizer_2escm"),(void*)f_16925},
{C_text("f_16928:scrutinizer_2escm"),(void*)f_16928},
{C_text("f_16931:scrutinizer_2escm"),(void*)f_16931},
{C_text("f_16934:scrutinizer_2escm"),(void*)f_16934},
{C_text("f_16937:scrutinizer_2escm"),(void*)f_16937},
{C_text("f_16940:scrutinizer_2escm"),(void*)f_16940},
{C_text("f_16943:scrutinizer_2escm"),(void*)f_16943},
{C_text("f_16947:scrutinizer_2escm"),(void*)f_16947},
{C_text("f_16952:scrutinizer_2escm"),(void*)f_16952},
{C_text("f_16968:scrutinizer_2escm"),(void*)f_16968},
{C_text("f_16979:scrutinizer_2escm"),(void*)f_16979},
{C_text("f_16998:scrutinizer_2escm"),(void*)f_16998},
{C_text("f_17012:scrutinizer_2escm"),(void*)f_17012},
{C_text("f_17026:scrutinizer_2escm"),(void*)f_17026},
{C_text("f_17040:scrutinizer_2escm"),(void*)f_17040},
{C_text("f_17054:scrutinizer_2escm"),(void*)f_17054},
{C_text("f_17084:scrutinizer_2escm"),(void*)f_17084},
{C_text("f_17103:scrutinizer_2escm"),(void*)f_17103},
{C_text("f_17135:scrutinizer_2escm"),(void*)f_17135},
{C_text("f_17141:scrutinizer_2escm"),(void*)f_17141},
{C_text("f_17143:scrutinizer_2escm"),(void*)f_17143},
{C_text("f_17153:scrutinizer_2escm"),(void*)f_17153},
{C_text("f_17166:scrutinizer_2escm"),(void*)f_17166},
{C_text("f_17173:scrutinizer_2escm"),(void*)f_17173},
{C_text("f_17179:scrutinizer_2escm"),(void*)f_17179},
{C_text("f_17182:scrutinizer_2escm"),(void*)f_17182},
{C_text("f_17185:scrutinizer_2escm"),(void*)f_17185},
{C_text("f_17188:scrutinizer_2escm"),(void*)f_17188},
{C_text("f_17191:scrutinizer_2escm"),(void*)f_17191},
{C_text("f_17200:scrutinizer_2escm"),(void*)f_17200},
{C_text("f_17223:scrutinizer_2escm"),(void*)f_17223},
{C_text("f_17239:scrutinizer_2escm"),(void*)f_17239},
{C_text("f_17283:scrutinizer_2escm"),(void*)f_17283},
{C_text("f_17287:scrutinizer_2escm"),(void*)f_17287},
{C_text("f_17289:scrutinizer_2escm"),(void*)f_17289},
{C_text("f_17295:scrutinizer_2escm"),(void*)f_17295},
{C_text("f_17299:scrutinizer_2escm"),(void*)f_17299},
{C_text("f_17300:scrutinizer_2escm"),(void*)f_17300},
{C_text("f_17311:scrutinizer_2escm"),(void*)f_17311},
{C_text("f_17314:scrutinizer_2escm"),(void*)f_17314},
{C_text("f_17320:scrutinizer_2escm"),(void*)f_17320},
{C_text("f_17323:scrutinizer_2escm"),(void*)f_17323},
{C_text("f_17326:scrutinizer_2escm"),(void*)f_17326},
{C_text("f_17329:scrutinizer_2escm"),(void*)f_17329},
{C_text("f_17332:scrutinizer_2escm"),(void*)f_17332},
{C_text("f_17335:scrutinizer_2escm"),(void*)f_17335},
{C_text("f_17338:scrutinizer_2escm"),(void*)f_17338},
{C_text("f_17345:scrutinizer_2escm"),(void*)f_17345},
{C_text("f_17349:scrutinizer_2escm"),(void*)f_17349},
{C_text("f_17351:scrutinizer_2escm"),(void*)f_17351},
{C_text("f_17372:scrutinizer_2escm"),(void*)f_17372},
{C_text("f_17382:scrutinizer_2escm"),(void*)f_17382},
{C_text("f_17390:scrutinizer_2escm"),(void*)f_17390},
{C_text("f_17398:scrutinizer_2escm"),(void*)f_17398},
{C_text("f_17406:scrutinizer_2escm"),(void*)f_17406},
{C_text("f_17434:scrutinizer_2escm"),(void*)f_17434},
{C_text("f_17445:scrutinizer_2escm"),(void*)f_17445},
{C_text("f_17449:scrutinizer_2escm"),(void*)f_17449},
{C_text("f_17453:scrutinizer_2escm"),(void*)f_17453},
{C_text("f_17459:scrutinizer_2escm"),(void*)f_17459},
{C_text("f_17464:scrutinizer_2escm"),(void*)f_17464},
{C_text("f_17474:scrutinizer_2escm"),(void*)f_17474},
{C_text("f_17489:scrutinizer_2escm"),(void*)f_17489},
{C_text("f_17491:scrutinizer_2escm"),(void*)f_17491},
{C_text("f_17507:scrutinizer_2escm"),(void*)f_17507},
{C_text("f_17510:scrutinizer_2escm"),(void*)f_17510},
{C_text("f_17515:scrutinizer_2escm"),(void*)f_17515},
{C_text("f_17522:scrutinizer_2escm"),(void*)f_17522},
{C_text("f_17526:scrutinizer_2escm"),(void*)f_17526},
{C_text("f_17528:scrutinizer_2escm"),(void*)f_17528},
{C_text("f_17535:scrutinizer_2escm"),(void*)f_17535},
{C_text("f_17555:scrutinizer_2escm"),(void*)f_17555},
{C_text("f_17561:scrutinizer_2escm"),(void*)f_17561},
{C_text("f_17569:scrutinizer_2escm"),(void*)f_17569},
{C_text("f_17573:scrutinizer_2escm"),(void*)f_17573},
{C_text("f_17580:scrutinizer_2escm"),(void*)f_17580},
{C_text("f_17586:scrutinizer_2escm"),(void*)f_17586},
{C_text("f_17588:scrutinizer_2escm"),(void*)f_17588},
{C_text("f_17613:scrutinizer_2escm"),(void*)f_17613},
{C_text("f_17630:scrutinizer_2escm"),(void*)f_17630},
{C_text("f_17636:scrutinizer_2escm"),(void*)f_17636},
{C_text("f_17645:scrutinizer_2escm"),(void*)f_17645},
{C_text("f_17684:scrutinizer_2escm"),(void*)f_17684},
{C_text("f_17690:scrutinizer_2escm"),(void*)f_17690},
{C_text("f_17693:scrutinizer_2escm"),(void*)f_17693},
{C_text("f_17740:scrutinizer_2escm"),(void*)f_17740},
{C_text("f_17750:scrutinizer_2escm"),(void*)f_17750},
{C_text("f_17777:scrutinizer_2escm"),(void*)f_17777},
{C_text("f_17781:scrutinizer_2escm"),(void*)f_17781},
{C_text("f_17841:scrutinizer_2escm"),(void*)f_17841},
{C_text("f_17843:scrutinizer_2escm"),(void*)f_17843},
{C_text("f_17852:scrutinizer_2escm"),(void*)f_17852},
{C_text("f_17870:scrutinizer_2escm"),(void*)f_17870},
{C_text("f_17874:scrutinizer_2escm"),(void*)f_17874},
{C_text("f_17880:scrutinizer_2escm"),(void*)f_17880},
{C_text("f_17908:scrutinizer_2escm"),(void*)f_17908},
{C_text("f_17939:scrutinizer_2escm"),(void*)f_17939},
{C_text("f_17971:scrutinizer_2escm"),(void*)f_17971},
{C_text("f_17998:scrutinizer_2escm"),(void*)f_17998},
{C_text("f_18001:scrutinizer_2escm"),(void*)f_18001},
{C_text("f_18038:scrutinizer_2escm"),(void*)f_18038},
{C_text("f_18096:scrutinizer_2escm"),(void*)f_18096},
{C_text("f_18130:scrutinizer_2escm"),(void*)f_18130},
{C_text("f_18162:scrutinizer_2escm"),(void*)f_18162},
{C_text("f_18167:scrutinizer_2escm"),(void*)f_18167},
{C_text("f_18171:scrutinizer_2escm"),(void*)f_18171},
{C_text("f_18182:scrutinizer_2escm"),(void*)f_18182},
{C_text("f_18184:scrutinizer_2escm"),(void*)f_18184},
{C_text("f_18200:scrutinizer_2escm"),(void*)f_18200},
{C_text("f_18203:scrutinizer_2escm"),(void*)f_18203},
{C_text("f_18219:scrutinizer_2escm"),(void*)f_18219},
{C_text("f_18266:scrutinizer_2escm"),(void*)f_18266},
{C_text("f_18268:scrutinizer_2escm"),(void*)f_18268},
{C_text("f_18293:scrutinizer_2escm"),(void*)f_18293},
{C_text("f_18312:scrutinizer_2escm"),(void*)f_18312},
{C_text("f_18316:scrutinizer_2escm"),(void*)f_18316},
{C_text("f_18360:scrutinizer_2escm"),(void*)f_18360},
{C_text("f_18366:scrutinizer_2escm"),(void*)f_18366},
{C_text("f_18371:scrutinizer_2escm"),(void*)f_18371},
{C_text("f_18396:scrutinizer_2escm"),(void*)f_18396},
{C_text("f_18480:scrutinizer_2escm"),(void*)f_18480},
{C_text("f_18510:scrutinizer_2escm"),(void*)f_18510},
{C_text("f_18522:scrutinizer_2escm"),(void*)f_18522},
{C_text("f_18549:scrutinizer_2escm"),(void*)f_18549},
{C_text("f_18552:scrutinizer_2escm"),(void*)f_18552},
{C_text("f_18556:scrutinizer_2escm"),(void*)f_18556},
{C_text("f_18569:scrutinizer_2escm"),(void*)f_18569},
{C_text("f_18572:scrutinizer_2escm"),(void*)f_18572},
{C_text("f_18596:scrutinizer_2escm"),(void*)f_18596},
{C_text("f_18604:scrutinizer_2escm"),(void*)f_18604},
{C_text("f_18608:scrutinizer_2escm"),(void*)f_18608},
{C_text("f_18619:scrutinizer_2escm"),(void*)f_18619},
{C_text("f_18698:scrutinizer_2escm"),(void*)f_18698},
{C_text("f_18740:scrutinizer_2escm"),(void*)f_18740},
{C_text("f_18758:scrutinizer_2escm"),(void*)f_18758},
{C_text("f_18761:scrutinizer_2escm"),(void*)f_18761},
{C_text("f_18765:scrutinizer_2escm"),(void*)f_18765},
{C_text("f_18808:scrutinizer_2escm"),(void*)f_18808},
{C_text("f_18814:scrutinizer_2escm"),(void*)f_18814},
{C_text("f_18819:scrutinizer_2escm"),(void*)f_18819},
{C_text("f_18844:scrutinizer_2escm"),(void*)f_18844},
{C_text("f_18889:scrutinizer_2escm"),(void*)f_18889},
{C_text("f_18898:scrutinizer_2escm"),(void*)f_18898},
{C_text("f_18902:scrutinizer_2escm"),(void*)f_18902},
{C_text("f_18912:scrutinizer_2escm"),(void*)f_18912},
{C_text("f_18944:scrutinizer_2escm"),(void*)f_18944},
{C_text("f_18950:scrutinizer_2escm"),(void*)f_18950},
{C_text("f_18952:scrutinizer_2escm"),(void*)f_18952},
{C_text("f_18977:scrutinizer_2escm"),(void*)f_18977},
{C_text("f_19109:scrutinizer_2escm"),(void*)f_19109},
{C_text("f_19113:scrutinizer_2escm"),(void*)f_19113},
{C_text("f_19117:scrutinizer_2escm"),(void*)f_19117},
{C_text("f_19120:scrutinizer_2escm"),(void*)f_19120},
{C_text("f_19152:scrutinizer_2escm"),(void*)f_19152},
{C_text("f_19156:scrutinizer_2escm"),(void*)f_19156},
{C_text("f_19169:scrutinizer_2escm"),(void*)f_19169},
{C_text("f_19173:scrutinizer_2escm"),(void*)f_19173},
{C_text("f_19176:scrutinizer_2escm"),(void*)f_19176},
{C_text("f_19182:scrutinizer_2escm"),(void*)f_19182},
{C_text("f_19184:scrutinizer_2escm"),(void*)f_19184},
{C_text("f_19209:scrutinizer_2escm"),(void*)f_19209},
{C_text("f_19224:scrutinizer_2escm"),(void*)f_19224},
{C_text("f_19233:scrutinizer_2escm"),(void*)f_19233},
{C_text("f_19241:scrutinizer_2escm"),(void*)f_19241},
{C_text("f_19243:scrutinizer_2escm"),(void*)f_19243},
{C_text("f_19258:scrutinizer_2escm"),(void*)f_19258},
{C_text("f_19261:scrutinizer_2escm"),(void*)f_19261},
{C_text("f_19273:scrutinizer_2escm"),(void*)f_19273},
{C_text("f_19284:scrutinizer_2escm"),(void*)f_19284},
{C_text("f_19290:scrutinizer_2escm"),(void*)f_19290},
{C_text("f_19296:scrutinizer_2escm"),(void*)f_19296},
{C_text("f_19312:scrutinizer_2escm"),(void*)f_19312},
{C_text("f_19315:scrutinizer_2escm"),(void*)f_19315},
{C_text("f_19325:scrutinizer_2escm"),(void*)f_19325},
{C_text("f_19351:scrutinizer_2escm"),(void*)f_19351},
{C_text("f_19357:scrutinizer_2escm"),(void*)f_19357},
{C_text("f_19363:scrutinizer_2escm"),(void*)f_19363},
{C_text("f_19379:scrutinizer_2escm"),(void*)f_19379},
{C_text("f_19385:scrutinizer_2escm"),(void*)f_19385},
{C_text("f_19410:scrutinizer_2escm"),(void*)f_19410},
{C_text("f_19448:scrutinizer_2escm"),(void*)f_19448},
{C_text("f_19450:scrutinizer_2escm"),(void*)f_19450},
{C_text("f_19475:scrutinizer_2escm"),(void*)f_19475},
{C_text("f_19501:scrutinizer_2escm"),(void*)f_19501},
{C_text("f_19503:scrutinizer_2escm"),(void*)f_19503},
{C_text("f_19528:scrutinizer_2escm"),(void*)f_19528},
{C_text("f_19537:scrutinizer_2escm"),(void*)f_19537},
{C_text("f_19565:scrutinizer_2escm"),(void*)f_19565},
{C_text("f_19579:scrutinizer_2escm"),(void*)f_19579},
{C_text("f_19613:scrutinizer_2escm"),(void*)f_19613},
{C_text("f_19617:scrutinizer_2escm"),(void*)f_19617},
{C_text("f_19651:scrutinizer_2escm"),(void*)f_19651},
{C_text("f_19655:scrutinizer_2escm"),(void*)f_19655},
{C_text("f_19663:scrutinizer_2escm"),(void*)f_19663},
{C_text("f_19683:scrutinizer_2escm"),(void*)f_19683},
{C_text("f_19699:scrutinizer_2escm"),(void*)f_19699},
{C_text("f_19701:scrutinizer_2escm"),(void*)f_19701},
{C_text("f_19705:scrutinizer_2escm"),(void*)f_19705},
{C_text("f_19768:scrutinizer_2escm"),(void*)f_19768},
{C_text("f_19780:scrutinizer_2escm"),(void*)f_19780},
{C_text("f_19784:scrutinizer_2escm"),(void*)f_19784},
{C_text("f_19800:scrutinizer_2escm"),(void*)f_19800},
{C_text("f_19804:scrutinizer_2escm"),(void*)f_19804},
{C_text("f_19825:scrutinizer_2escm"),(void*)f_19825},
{C_text("f_19848:scrutinizer_2escm"),(void*)f_19848},
{C_text("f_19855:scrutinizer_2escm"),(void*)f_19855},
{C_text("f_19858:scrutinizer_2escm"),(void*)f_19858},
{C_text("f_19861:scrutinizer_2escm"),(void*)f_19861},
{C_text("f_19914:scrutinizer_2escm"),(void*)f_19914},
{C_text("f_19924:scrutinizer_2escm"),(void*)f_19924},
{C_text("f_19951:scrutinizer_2escm"),(void*)f_19951},
{C_text("f_19969:scrutinizer_2escm"),(void*)f_19969},
{C_text("f_20046:scrutinizer_2escm"),(void*)f_20046},
{C_text("f_20048:scrutinizer_2escm"),(void*)f_20048},
{C_text("f_20052:scrutinizer_2escm"),(void*)f_20052},
{C_text("f_20055:scrutinizer_2escm"),(void*)f_20055},
{C_text("f_20101:scrutinizer_2escm"),(void*)f_20101},
{C_text("f_20104:scrutinizer_2escm"),(void*)f_20104},
{C_text("f_20110:scrutinizer_2escm"),(void*)f_20110},
{C_text("f_20114:scrutinizer_2escm"),(void*)f_20114},
{C_text("f_20118:scrutinizer_2escm"),(void*)f_20118},
{C_text("f_20125:scrutinizer_2escm"),(void*)f_20125},
{C_text("f_20129:scrutinizer_2escm"),(void*)f_20129},
{C_text("f_20141:scrutinizer_2escm"),(void*)f_20141},
{C_text("f_20144:scrutinizer_2escm"),(void*)f_20144},
{C_text("f_20147:scrutinizer_2escm"),(void*)f_20147},
{C_text("f_20150:scrutinizer_2escm"),(void*)f_20150},
{C_text("f_20153:scrutinizer_2escm"),(void*)f_20153},
{C_text("f_20156:scrutinizer_2escm"),(void*)f_20156},
{C_text("f_20159:scrutinizer_2escm"),(void*)f_20159},
{C_text("f_20161:scrutinizer_2escm"),(void*)f_20161},
{C_text("f_20170:scrutinizer_2escm"),(void*)f_20170},
{C_text("f_20180:scrutinizer_2escm"),(void*)f_20180},
{C_text("f_20202:scrutinizer_2escm"),(void*)f_20202},
{C_text("f_20212:scrutinizer_2escm"),(void*)f_20212},
{C_text("f_20215:scrutinizer_2escm"),(void*)f_20215},
{C_text("f_20217:scrutinizer_2escm"),(void*)f_20217},
{C_text("f_20261:scrutinizer_2escm"),(void*)f_20261},
{C_text("f_20278:scrutinizer_2escm"),(void*)f_20278},
{C_text("f_20284:scrutinizer_2escm"),(void*)f_20284},
{C_text("f_20291:scrutinizer_2escm"),(void*)f_20291},
{C_text("f_20315:scrutinizer_2escm"),(void*)f_20315},
{C_text("f_20324:scrutinizer_2escm"),(void*)f_20324},
{C_text("f_20327:scrutinizer_2escm"),(void*)f_20327},
{C_text("f_20331:scrutinizer_2escm"),(void*)f_20331},
{C_text("f_20335:scrutinizer_2escm"),(void*)f_20335},
{C_text("f_20347:scrutinizer_2escm"),(void*)f_20347},
{C_text("f_20377:scrutinizer_2escm"),(void*)f_20377},
{C_text("f_20391:scrutinizer_2escm"),(void*)f_20391},
{C_text("f_20395:scrutinizer_2escm"),(void*)f_20395},
{C_text("f_20399:scrutinizer_2escm"),(void*)f_20399},
{C_text("f_20422:scrutinizer_2escm"),(void*)f_20422},
{C_text("f_20424:scrutinizer_2escm"),(void*)f_20424},
{C_text("f_20427:scrutinizer_2escm"),(void*)f_20427},
{C_text("f_20436:scrutinizer_2escm"),(void*)f_20436},
{C_text("f_20487:scrutinizer_2escm"),(void*)f_20487},
{C_text("f_20491:scrutinizer_2escm"),(void*)f_20491},
{C_text("f_20495:scrutinizer_2escm"),(void*)f_20495},
{C_text("f_20499:scrutinizer_2escm"),(void*)f_20499},
{C_text("f_20507:scrutinizer_2escm"),(void*)f_20507},
{C_text("f_20509:scrutinizer_2escm"),(void*)f_20509},
{C_text("f_20533:scrutinizer_2escm"),(void*)f_20533},
{C_text("f_20558:scrutinizer_2escm"),(void*)f_20558},
{C_text("f_20569:scrutinizer_2escm"),(void*)f_20569},
{C_text("f_20579:scrutinizer_2escm"),(void*)f_20579},
{C_text("f_20581:scrutinizer_2escm"),(void*)f_20581},
{C_text("f_20606:scrutinizer_2escm"),(void*)f_20606},
{C_text("f_20623:scrutinizer_2escm"),(void*)f_20623},
{C_text("f_20625:scrutinizer_2escm"),(void*)f_20625},
{C_text("f_20639:scrutinizer_2escm"),(void*)f_20639},
{C_text("f_20655:scrutinizer_2escm"),(void*)f_20655},
{C_text("f_20674:scrutinizer_2escm"),(void*)f_20674},
{C_text("f_20680:scrutinizer_2escm"),(void*)f_20680},
{C_text("f_20682:scrutinizer_2escm"),(void*)f_20682},
{C_text("f_20692:scrutinizer_2escm"),(void*)f_20692},
{C_text("f_20712:scrutinizer_2escm"),(void*)f_20712},
{C_text("f_20715:scrutinizer_2escm"),(void*)f_20715},
{C_text("f_20726:scrutinizer_2escm"),(void*)f_20726},
{C_text("f_20729:scrutinizer_2escm"),(void*)f_20729},
{C_text("f_20749:scrutinizer_2escm"),(void*)f_20749},
{C_text("f_20756:scrutinizer_2escm"),(void*)f_20756},
{C_text("f_20759:scrutinizer_2escm"),(void*)f_20759},
{C_text("f_20785:scrutinizer_2escm"),(void*)f_20785},
{C_text("f_20798:scrutinizer_2escm"),(void*)f_20798},
{C_text("f_20800:scrutinizer_2escm"),(void*)f_20800},
{C_text("f_20825:scrutinizer_2escm"),(void*)f_20825},
{C_text("f_20840:scrutinizer_2escm"),(void*)f_20840},
{C_text("f_20847:scrutinizer_2escm"),(void*)f_20847},
{C_text("f_20850:scrutinizer_2escm"),(void*)f_20850},
{C_text("f_20857:scrutinizer_2escm"),(void*)f_20857},
{C_text("f_20866:scrutinizer_2escm"),(void*)f_20866},
{C_text("f_20872:scrutinizer_2escm"),(void*)f_20872},
{C_text("f_20885:scrutinizer_2escm"),(void*)f_20885},
{C_text("f_20901:scrutinizer_2escm"),(void*)f_20901},
{C_text("f_20907:scrutinizer_2escm"),(void*)f_20907},
{C_text("f_20910:scrutinizer_2escm"),(void*)f_20910},
{C_text("f_20913:scrutinizer_2escm"),(void*)f_20913},
{C_text("f_20916:scrutinizer_2escm"),(void*)f_20916},
{C_text("f_20924:scrutinizer_2escm"),(void*)f_20924},
{C_text("f_20937:scrutinizer_2escm"),(void*)f_20937},
{C_text("f_20939:scrutinizer_2escm"),(void*)f_20939},
{C_text("f_20964:scrutinizer_2escm"),(void*)f_20964},
{C_text("f_20980:scrutinizer_2escm"),(void*)f_20980},
{C_text("f_20992:scrutinizer_2escm"),(void*)f_20992},
{C_text("f_21001:scrutinizer_2escm"),(void*)f_21001},
{C_text("f_21010:scrutinizer_2escm"),(void*)f_21010},
{C_text("f_21069:scrutinizer_2escm"),(void*)f_21069},
{C_text("f_21071:scrutinizer_2escm"),(void*)f_21071},
{C_text("f_21096:scrutinizer_2escm"),(void*)f_21096},
{C_text("f_21121:scrutinizer_2escm"),(void*)f_21121},
{C_text("f_21127:scrutinizer_2escm"),(void*)f_21127},
{C_text("f_21130:scrutinizer_2escm"),(void*)f_21130},
{C_text("f_21133:scrutinizer_2escm"),(void*)f_21133},
{C_text("f_21164:scrutinizer_2escm"),(void*)f_21164},
{C_text("f_21167:scrutinizer_2escm"),(void*)f_21167},
{C_text("f_21170:scrutinizer_2escm"),(void*)f_21170},
{C_text("f_21187:scrutinizer_2escm"),(void*)f_21187},
{C_text("f_21212:scrutinizer_2escm"),(void*)f_21212},
{C_text("f_21221:scrutinizer_2escm"),(void*)f_21221},
{C_text("f_21246:scrutinizer_2escm"),(void*)f_21246},
{C_text("f_21283:scrutinizer_2escm"),(void*)f_21283},
{C_text("f_21290:scrutinizer_2escm"),(void*)f_21290},
{C_text("f_21294:scrutinizer_2escm"),(void*)f_21294},
{C_text("f_21296:scrutinizer_2escm"),(void*)f_21296},
{C_text("f_21304:scrutinizer_2escm"),(void*)f_21304},
{C_text("f_21306:scrutinizer_2escm"),(void*)f_21306},
{C_text("f_21310:scrutinizer_2escm"),(void*)f_21310},
{C_text("f_21315:scrutinizer_2escm"),(void*)f_21315},
{C_text("f_21341:scrutinizer_2escm"),(void*)f_21341},
{C_text("f_21346:scrutinizer_2escm"),(void*)f_21346},
{C_text("f_21358:scrutinizer_2escm"),(void*)f_21358},
{C_text("f_21383:scrutinizer_2escm"),(void*)f_21383},
{C_text("f_21400:scrutinizer_2escm"),(void*)f_21400},
{C_text("f_21409:scrutinizer_2escm"),(void*)f_21409},
{C_text("f_21411:scrutinizer_2escm"),(void*)f_21411},
{C_text("f_21419:scrutinizer_2escm"),(void*)f_21419},
{C_text("f_21423:scrutinizer_2escm"),(void*)f_21423},
{C_text("f_21425:scrutinizer_2escm"),(void*)f_21425},
{C_text("f_21433:scrutinizer_2escm"),(void*)f_21433},
{C_text("f_21435:scrutinizer_2escm"),(void*)f_21435},
{C_text("f_21439:scrutinizer_2escm"),(void*)f_21439},
{C_text("f_21448:scrutinizer_2escm"),(void*)f_21448},
{C_text("f_21454:scrutinizer_2escm"),(void*)f_21454},
{C_text("f_21457:scrutinizer_2escm"),(void*)f_21457},
{C_text("f_21460:scrutinizer_2escm"),(void*)f_21460},
{C_text("f_21465:scrutinizer_2escm"),(void*)f_21465},
{C_text("f_21478:scrutinizer_2escm"),(void*)f_21478},
{C_text("f_21484:scrutinizer_2escm"),(void*)f_21484},
{C_text("f_21487:scrutinizer_2escm"),(void*)f_21487},
{C_text("f_21490:scrutinizer_2escm"),(void*)f_21490},
{C_text("f_21497:scrutinizer_2escm"),(void*)f_21497},
{C_text("f_21515:scrutinizer_2escm"),(void*)f_21515},
{C_text("f_21529:scrutinizer_2escm"),(void*)f_21529},
{C_text("f_21533:scrutinizer_2escm"),(void*)f_21533},
{C_text("f_21537:scrutinizer_2escm"),(void*)f_21537},
{C_text("f_21543:scrutinizer_2escm"),(void*)f_21543},
{C_text("f_21551:scrutinizer_2escm"),(void*)f_21551},
{C_text("f_21557:scrutinizer_2escm"),(void*)f_21557},
{C_text("f_21565:scrutinizer_2escm"),(void*)f_21565},
{C_text("f_21569:scrutinizer_2escm"),(void*)f_21569},
{C_text("f_21575:scrutinizer_2escm"),(void*)f_21575},
{C_text("f_21578:scrutinizer_2escm"),(void*)f_21578},
{C_text("f_21581:scrutinizer_2escm"),(void*)f_21581},
{C_text("f_21584:scrutinizer_2escm"),(void*)f_21584},
{C_text("f_21587:scrutinizer_2escm"),(void*)f_21587},
{C_text("f_21593:scrutinizer_2escm"),(void*)f_21593},
{C_text("f_21596:scrutinizer_2escm"),(void*)f_21596},
{C_text("f_21599:scrutinizer_2escm"),(void*)f_21599},
{C_text("f_21602:scrutinizer_2escm"),(void*)f_21602},
{C_text("f_21605:scrutinizer_2escm"),(void*)f_21605},
{C_text("f_21621:scrutinizer_2escm"),(void*)f_21621},
{C_text("f_21635:scrutinizer_2escm"),(void*)f_21635},
{C_text("f_21639:scrutinizer_2escm"),(void*)f_21639},
{C_text("f_21642:scrutinizer_2escm"),(void*)f_21642},
{C_text("f_21655:scrutinizer_2escm"),(void*)f_21655},
{C_text("f_21659:scrutinizer_2escm"),(void*)f_21659},
{C_text("f_21674:scrutinizer_2escm"),(void*)f_21674},
{C_text("f_21686:scrutinizer_2escm"),(void*)f_21686},
{C_text("f_21692:scrutinizer_2escm"),(void*)f_21692},
{C_text("f_21698:scrutinizer_2escm"),(void*)f_21698},
{C_text("f_21705:scrutinizer_2escm"),(void*)f_21705},
{C_text("f_21711:scrutinizer_2escm"),(void*)f_21711},
{C_text("f_21714:scrutinizer_2escm"),(void*)f_21714},
{C_text("f_21717:scrutinizer_2escm"),(void*)f_21717},
{C_text("f_21720:scrutinizer_2escm"),(void*)f_21720},
{C_text("f_21723:scrutinizer_2escm"),(void*)f_21723},
{C_text("f_21729:scrutinizer_2escm"),(void*)f_21729},
{C_text("f_21735:scrutinizer_2escm"),(void*)f_21735},
{C_text("f_21738:scrutinizer_2escm"),(void*)f_21738},
{C_text("f_21741:scrutinizer_2escm"),(void*)f_21741},
{C_text("f_21746:scrutinizer_2escm"),(void*)f_21746},
{C_text("f_21749:scrutinizer_2escm"),(void*)f_21749},
{C_text("f_21757:scrutinizer_2escm"),(void*)f_21757},
{C_text("f_21761:scrutinizer_2escm"),(void*)f_21761},
{C_text("f_21763:scrutinizer_2escm"),(void*)f_21763},
{C_text("f_21767:scrutinizer_2escm"),(void*)f_21767},
{C_text("f_21787:scrutinizer_2escm"),(void*)f_21787},
{C_text("f_21794:scrutinizer_2escm"),(void*)f_21794},
{C_text("f_21815:scrutinizer_2escm"),(void*)f_21815},
{C_text("f_21825:scrutinizer_2escm"),(void*)f_21825},
{C_text("f_21829:scrutinizer_2escm"),(void*)f_21829},
{C_text("f_21833:scrutinizer_2escm"),(void*)f_21833},
{C_text("f_21837:scrutinizer_2escm"),(void*)f_21837},
{C_text("f_21841:scrutinizer_2escm"),(void*)f_21841},
{C_text("f_21845:scrutinizer_2escm"),(void*)f_21845},
{C_text("f_21849:scrutinizer_2escm"),(void*)f_21849},
{C_text("f_21853:scrutinizer_2escm"),(void*)f_21853},
{C_text("f_21860:scrutinizer_2escm"),(void*)f_21860},
{C_text("f_21876:scrutinizer_2escm"),(void*)f_21876},
{C_text("f_21879:scrutinizer_2escm"),(void*)f_21879},
{C_text("f_21885:scrutinizer_2escm"),(void*)f_21885},
{C_text("f_21901:scrutinizer_2escm"),(void*)f_21901},
{C_text("f_21907:scrutinizer_2escm"),(void*)f_21907},
{C_text("f_21914:scrutinizer_2escm"),(void*)f_21914},
{C_text("f_21918:scrutinizer_2escm"),(void*)f_21918},
{C_text("f_21922:scrutinizer_2escm"),(void*)f_21922},
{C_text("f_21926:scrutinizer_2escm"),(void*)f_21926},
{C_text("f_21929:scrutinizer_2escm"),(void*)f_21929},
{C_text("f_21933:scrutinizer_2escm"),(void*)f_21933},
{C_text("f_21937:scrutinizer_2escm"),(void*)f_21937},
{C_text("f_21943:scrutinizer_2escm"),(void*)f_21943},
{C_text("f_21946:scrutinizer_2escm"),(void*)f_21946},
{C_text("f_21960:scrutinizer_2escm"),(void*)f_21960},
{C_text("f_21978:scrutinizer_2escm"),(void*)f_21978},
{C_text("f_21991:scrutinizer_2escm"),(void*)f_21991},
{C_text("f_21995:scrutinizer_2escm"),(void*)f_21995},
{C_text("f_21999:scrutinizer_2escm"),(void*)f_21999},
{C_text("f_22005:scrutinizer_2escm"),(void*)f_22005},
{C_text("f_22016:scrutinizer_2escm"),(void*)f_22016},
{C_text("f_22020:scrutinizer_2escm"),(void*)f_22020},
{C_text("f_22024:scrutinizer_2escm"),(void*)f_22024},
{C_text("f_22028:scrutinizer_2escm"),(void*)f_22028},
{C_text("f_22032:scrutinizer_2escm"),(void*)f_22032},
{C_text("f_22043:scrutinizer_2escm"),(void*)f_22043},
{C_text("f_22047:scrutinizer_2escm"),(void*)f_22047},
{C_text("f_22051:scrutinizer_2escm"),(void*)f_22051},
{C_text("f_22055:scrutinizer_2escm"),(void*)f_22055},
{C_text("f_22059:scrutinizer_2escm"),(void*)f_22059},
{C_text("f_22066:scrutinizer_2escm"),(void*)f_22066},
{C_text("f_22077:scrutinizer_2escm"),(void*)f_22077},
{C_text("f_22081:scrutinizer_2escm"),(void*)f_22081},
{C_text("f_22085:scrutinizer_2escm"),(void*)f_22085},
{C_text("f_22101:scrutinizer_2escm"),(void*)f_22101},
{C_text("f_22105:scrutinizer_2escm"),(void*)f_22105},
{C_text("f_22110:scrutinizer_2escm"),(void*)f_22110},
{C_text("f_22115:scrutinizer_2escm"),(void*)f_22115},
{C_text("f_22126:scrutinizer_2escm"),(void*)f_22126},
{C_text("f_22130:scrutinizer_2escm"),(void*)f_22130},
{C_text("f_22134:scrutinizer_2escm"),(void*)f_22134},
{C_text("f_22138:scrutinizer_2escm"),(void*)f_22138},
{C_text("f_22142:scrutinizer_2escm"),(void*)f_22142},
{C_text("f_22146:scrutinizer_2escm"),(void*)f_22146},
{C_text("f_22150:scrutinizer_2escm"),(void*)f_22150},
{C_text("f_22154:scrutinizer_2escm"),(void*)f_22154},
{C_text("f_22156:scrutinizer_2escm"),(void*)f_22156},
{C_text("f_22161:scrutinizer_2escm"),(void*)f_22161},
{C_text("f_22163:scrutinizer_2escm"),(void*)f_22163},
{C_text("f_22175:scrutinizer_2escm"),(void*)f_22175},
{C_text("f_22179:scrutinizer_2escm"),(void*)f_22179},
{C_text("f_22183:scrutinizer_2escm"),(void*)f_22183},
{C_text("f_22187:scrutinizer_2escm"),(void*)f_22187},
{C_text("f_22191:scrutinizer_2escm"),(void*)f_22191},
{C_text("f_22197:scrutinizer_2escm"),(void*)f_22197},
{C_text("f_22200:scrutinizer_2escm"),(void*)f_22200},
{C_text("f_22203:scrutinizer_2escm"),(void*)f_22203},
{C_text("f_22210:scrutinizer_2escm"),(void*)f_22210},
{C_text("f_22226:scrutinizer_2escm"),(void*)f_22226},
{C_text("f_22232:scrutinizer_2escm"),(void*)f_22232},
{C_text("f_22235:scrutinizer_2escm"),(void*)f_22235},
{C_text("f_22238:scrutinizer_2escm"),(void*)f_22238},
{C_text("f_22241:scrutinizer_2escm"),(void*)f_22241},
{C_text("f_22249:scrutinizer_2escm"),(void*)f_22249},
{C_text("f_22254:scrutinizer_2escm"),(void*)f_22254},
{C_text("f_22261:scrutinizer_2escm"),(void*)f_22261},
{C_text("f_22269:scrutinizer_2escm"),(void*)f_22269},
{C_text("f_22273:scrutinizer_2escm"),(void*)f_22273},
{C_text("f_22277:scrutinizer_2escm"),(void*)f_22277},
{C_text("f_22281:scrutinizer_2escm"),(void*)f_22281},
{C_text("f_22285:scrutinizer_2escm"),(void*)f_22285},
{C_text("f_22291:scrutinizer_2escm"),(void*)f_22291},
{C_text("f_22294:scrutinizer_2escm"),(void*)f_22294},
{C_text("f_22297:scrutinizer_2escm"),(void*)f_22297},
{C_text("f_22303:scrutinizer_2escm"),(void*)f_22303},
{C_text("f_22309:scrutinizer_2escm"),(void*)f_22309},
{C_text("f_22312:scrutinizer_2escm"),(void*)f_22312},
{C_text("f_22315:scrutinizer_2escm"),(void*)f_22315},
{C_text("f_22318:scrutinizer_2escm"),(void*)f_22318},
{C_text("f_22321:scrutinizer_2escm"),(void*)f_22321},
{C_text("f_22324:scrutinizer_2escm"),(void*)f_22324},
{C_text("f_22327:scrutinizer_2escm"),(void*)f_22327},
{C_text("f_22334:scrutinizer_2escm"),(void*)f_22334},
{C_text("f_22340:scrutinizer_2escm"),(void*)f_22340},
{C_text("f_22343:scrutinizer_2escm"),(void*)f_22343},
{C_text("f_22346:scrutinizer_2escm"),(void*)f_22346},
{C_text("f_22352:scrutinizer_2escm"),(void*)f_22352},
{C_text("f_22358:scrutinizer_2escm"),(void*)f_22358},
{C_text("f_22361:scrutinizer_2escm"),(void*)f_22361},
{C_text("f_22364:scrutinizer_2escm"),(void*)f_22364},
{C_text("f_22371:scrutinizer_2escm"),(void*)f_22371},
{C_text("f_22381:scrutinizer_2escm"),(void*)f_22381},
{C_text("f_22384:scrutinizer_2escm"),(void*)f_22384},
{C_text("f_22396:scrutinizer_2escm"),(void*)f_22396},
{C_text("f_22400:scrutinizer_2escm"),(void*)f_22400},
{C_text("f_22404:scrutinizer_2escm"),(void*)f_22404},
{C_text("f_22420:scrutinizer_2escm"),(void*)f_22420},
{C_text("f_22426:scrutinizer_2escm"),(void*)f_22426},
{C_text("f_22429:scrutinizer_2escm"),(void*)f_22429},
{C_text("f_22432:scrutinizer_2escm"),(void*)f_22432},
{C_text("f_22435:scrutinizer_2escm"),(void*)f_22435},
{C_text("f_22443:scrutinizer_2escm"),(void*)f_22443},
{C_text("f_22446:scrutinizer_2escm"),(void*)f_22446},
{C_text("f_22458:scrutinizer_2escm"),(void*)f_22458},
{C_text("f_22462:scrutinizer_2escm"),(void*)f_22462},
{C_text("f_22466:scrutinizer_2escm"),(void*)f_22466},
{C_text("f_22470:scrutinizer_2escm"),(void*)f_22470},
{C_text("f_22483:scrutinizer_2escm"),(void*)f_22483},
{C_text("f_22489:scrutinizer_2escm"),(void*)f_22489},
{C_text("f_22492:scrutinizer_2escm"),(void*)f_22492},
{C_text("f_22495:scrutinizer_2escm"),(void*)f_22495},
{C_text("f_22498:scrutinizer_2escm"),(void*)f_22498},
{C_text("f_22502:scrutinizer_2escm"),(void*)f_22502},
{C_text("f_22509:scrutinizer_2escm"),(void*)f_22509},
{C_text("f_22515:scrutinizer_2escm"),(void*)f_22515},
{C_text("f_22518:scrutinizer_2escm"),(void*)f_22518},
{C_text("f_22521:scrutinizer_2escm"),(void*)f_22521},
{C_text("f_22524:scrutinizer_2escm"),(void*)f_22524},
{C_text("f_22527:scrutinizer_2escm"),(void*)f_22527},
{C_text("f_22530:scrutinizer_2escm"),(void*)f_22530},
{C_text("f_22534:scrutinizer_2escm"),(void*)f_22534},
{C_text("f_22540:scrutinizer_2escm"),(void*)f_22540},
{C_text("f_22543:scrutinizer_2escm"),(void*)f_22543},
{C_text("f_22546:scrutinizer_2escm"),(void*)f_22546},
{C_text("f_22549:scrutinizer_2escm"),(void*)f_22549},
{C_text("f_22557:scrutinizer_2escm"),(void*)f_22557},
{C_text("f_22563:scrutinizer_2escm"),(void*)f_22563},
{C_text("f_22566:scrutinizer_2escm"),(void*)f_22566},
{C_text("f_22578:scrutinizer_2escm"),(void*)f_22578},
{C_text("f_22582:scrutinizer_2escm"),(void*)f_22582},
{C_text("f_22586:scrutinizer_2escm"),(void*)f_22586},
{C_text("f_22590:scrutinizer_2escm"),(void*)f_22590},
{C_text("f_22603:scrutinizer_2escm"),(void*)f_22603},
{C_text("f_22609:scrutinizer_2escm"),(void*)f_22609},
{C_text("f_22612:scrutinizer_2escm"),(void*)f_22612},
{C_text("f_22615:scrutinizer_2escm"),(void*)f_22615},
{C_text("f_22618:scrutinizer_2escm"),(void*)f_22618},
{C_text("f_22622:scrutinizer_2escm"),(void*)f_22622},
{C_text("f_22629:scrutinizer_2escm"),(void*)f_22629},
{C_text("f_22635:scrutinizer_2escm"),(void*)f_22635},
{C_text("f_22638:scrutinizer_2escm"),(void*)f_22638},
{C_text("f_22641:scrutinizer_2escm"),(void*)f_22641},
{C_text("f_22644:scrutinizer_2escm"),(void*)f_22644},
{C_text("f_22647:scrutinizer_2escm"),(void*)f_22647},
{C_text("f_22650:scrutinizer_2escm"),(void*)f_22650},
{C_text("f_22654:scrutinizer_2escm"),(void*)f_22654},
{C_text("f_22660:scrutinizer_2escm"),(void*)f_22660},
{C_text("f_22663:scrutinizer_2escm"),(void*)f_22663},
{C_text("f_22666:scrutinizer_2escm"),(void*)f_22666},
{C_text("f_22669:scrutinizer_2escm"),(void*)f_22669},
{C_text("f_22677:scrutinizer_2escm"),(void*)f_22677},
{C_text("f_22688:scrutinizer_2escm"),(void*)f_22688},
{C_text("f_22699:scrutinizer_2escm"),(void*)f_22699},
{C_text("f_22703:scrutinizer_2escm"),(void*)f_22703},
{C_text("f_22707:scrutinizer_2escm"),(void*)f_22707},
{C_text("f_22711:scrutinizer_2escm"),(void*)f_22711},
{C_text("f_22715:scrutinizer_2escm"),(void*)f_22715},
{C_text("f_22722:scrutinizer_2escm"),(void*)f_22722},
{C_text("f_22733:scrutinizer_2escm"),(void*)f_22733},
{C_text("f_22737:scrutinizer_2escm"),(void*)f_22737},
{C_text("f_22741:scrutinizer_2escm"),(void*)f_22741},
{C_text("f_22745:scrutinizer_2escm"),(void*)f_22745},
{C_text("f_22749:scrutinizer_2escm"),(void*)f_22749},
{C_text("f_22763:scrutinizer_2escm"),(void*)f_22763},
{C_text("f_22767:scrutinizer_2escm"),(void*)f_22767},
{C_text("f_22771:scrutinizer_2escm"),(void*)f_22771},
{C_text("f_22785:scrutinizer_2escm"),(void*)f_22785},
{C_text("f_22789:scrutinizer_2escm"),(void*)f_22789},
{C_text("f_22803:scrutinizer_2escm"),(void*)f_22803},
{C_text("f_22807:scrutinizer_2escm"),(void*)f_22807},
{C_text("f_22811:scrutinizer_2escm"),(void*)f_22811},
{C_text("f_22825:scrutinizer_2escm"),(void*)f_22825},
{C_text("f_22829:scrutinizer_2escm"),(void*)f_22829},
{C_text("f_22837:scrutinizer_2escm"),(void*)f_22837},
{C_text("f_22851:scrutinizer_2escm"),(void*)f_22851},
{C_text("f_22855:scrutinizer_2escm"),(void*)f_22855},
{C_text("f_22859:scrutinizer_2escm"),(void*)f_22859},
{C_text("f_22863:scrutinizer_2escm"),(void*)f_22863},
{C_text("f_22883:scrutinizer_2escm"),(void*)f_22883},
{C_text("f_22887:scrutinizer_2escm"),(void*)f_22887},
{C_text("f_22891:scrutinizer_2escm"),(void*)f_22891},
{C_text("f_22895:scrutinizer_2escm"),(void*)f_22895},
{C_text("f_22899:scrutinizer_2escm"),(void*)f_22899},
{C_text("f_22903:scrutinizer_2escm"),(void*)f_22903},
{C_text("f_22913:scrutinizer_2escm"),(void*)f_22913},
{C_text("f_22915:scrutinizer_2escm"),(void*)f_22915},
{C_text("f_22940:scrutinizer_2escm"),(void*)f_22940},
{C_text("f_22952:scrutinizer_2escm"),(void*)f_22952},
{C_text("f_22959:scrutinizer_2escm"),(void*)f_22959},
{C_text("f_22973:scrutinizer_2escm"),(void*)f_22973},
{C_text("f_22977:scrutinizer_2escm"),(void*)f_22977},
{C_text("f_22989:scrutinizer_2escm"),(void*)f_22989},
{C_text("f_23001:scrutinizer_2escm"),(void*)f_23001},
{C_text("f_23019:scrutinizer_2escm"),(void*)f_23019},
{C_text("f_23023:scrutinizer_2escm"),(void*)f_23023},
{C_text("f_23027:scrutinizer_2escm"),(void*)f_23027},
{C_text("f_23031:scrutinizer_2escm"),(void*)f_23031},
{C_text("f_23035:scrutinizer_2escm"),(void*)f_23035},
{C_text("f_23039:scrutinizer_2escm"),(void*)f_23039},
{C_text("f_23043:scrutinizer_2escm"),(void*)f_23043},
{C_text("f_23046:scrutinizer_2escm"),(void*)f_23046},
{C_text("f_23054:scrutinizer_2escm"),(void*)f_23054},
{C_text("f_23065:scrutinizer_2escm"),(void*)f_23065},
{C_text("f_23071:scrutinizer_2escm"),(void*)f_23071},
{C_text("f_23074:scrutinizer_2escm"),(void*)f_23074},
{C_text("f_23077:scrutinizer_2escm"),(void*)f_23077},
{C_text("f_23080:scrutinizer_2escm"),(void*)f_23080},
{C_text("f_23088:scrutinizer_2escm"),(void*)f_23088},
{C_text("f_23092:scrutinizer_2escm"),(void*)f_23092},
{C_text("f_23096:scrutinizer_2escm"),(void*)f_23096},
{C_text("f_23100:scrutinizer_2escm"),(void*)f_23100},
{C_text("f_23103:scrutinizer_2escm"),(void*)f_23103},
{C_text("f_23109:scrutinizer_2escm"),(void*)f_23109},
{C_text("f_23112:scrutinizer_2escm"),(void*)f_23112},
{C_text("f_23115:scrutinizer_2escm"),(void*)f_23115},
{C_text("f_23118:scrutinizer_2escm"),(void*)f_23118},
{C_text("f_23121:scrutinizer_2escm"),(void*)f_23121},
{C_text("f_23128:scrutinizer_2escm"),(void*)f_23128},
{C_text("f_23132:scrutinizer_2escm"),(void*)f_23132},
{C_text("f_23144:scrutinizer_2escm"),(void*)f_23144},
{C_text("f_23148:scrutinizer_2escm"),(void*)f_23148},
{C_text("f_23189:scrutinizer_2escm"),(void*)f_23189},
{C_text("f_23206:scrutinizer_2escm"),(void*)f_23206},
{C_text("f_23227:scrutinizer_2escm"),(void*)f_23227},
{C_text("f_23229:scrutinizer_2escm"),(void*)f_23229},
{C_text("f_23263:scrutinizer_2escm"),(void*)f_23263},
{C_text("f_23284:scrutinizer_2escm"),(void*)f_23284},
{C_text("f_23286:scrutinizer_2escm"),(void*)f_23286},
{C_text("f_23320:scrutinizer_2escm"),(void*)f_23320},
{C_text("f_23345:scrutinizer_2escm"),(void*)f_23345},
{C_text("f_23347:scrutinizer_2escm"),(void*)f_23347},
{C_text("f_23385:scrutinizer_2escm"),(void*)f_23385},
{C_text("f_23410:scrutinizer_2escm"),(void*)f_23410},
{C_text("f_23412:scrutinizer_2escm"),(void*)f_23412},
{C_text("f_23452:scrutinizer_2escm"),(void*)f_23452},
{C_text("f_23454:scrutinizer_2escm"),(void*)f_23454},
{C_text("f_23462:scrutinizer_2escm"),(void*)f_23462},
{C_text("f_23464:scrutinizer_2escm"),(void*)f_23464},
{C_text("f_23480:scrutinizer_2escm"),(void*)f_23480},
{C_text("f_23484:scrutinizer_2escm"),(void*)f_23484},
{C_text("f_23493:scrutinizer_2escm"),(void*)f_23493},
{C_text("f_23520:scrutinizer_2escm"),(void*)f_23520},
{C_text("f_23531:scrutinizer_2escm"),(void*)f_23531},
{C_text("f_23537:scrutinizer_2escm"),(void*)f_23537},
{C_text("f_23541:scrutinizer_2escm"),(void*)f_23541},
{C_text("f_23594:scrutinizer_2escm"),(void*)f_23594},
{C_text("f_23598:scrutinizer_2escm"),(void*)f_23598},
{C_text("f_23602:scrutinizer_2escm"),(void*)f_23602},
{C_text("f_6792:scrutinizer_2escm"),(void*)f_6792},
{C_text("f_6795:scrutinizer_2escm"),(void*)f_6795},
{C_text("f_6798:scrutinizer_2escm"),(void*)f_6798},
{C_text("f_6801:scrutinizer_2escm"),(void*)f_6801},
{C_text("f_6804:scrutinizer_2escm"),(void*)f_6804},
{C_text("f_6807:scrutinizer_2escm"),(void*)f_6807},
{C_text("f_6810:scrutinizer_2escm"),(void*)f_6810},
{C_text("f_6813:scrutinizer_2escm"),(void*)f_6813},
{C_text("f_6816:scrutinizer_2escm"),(void*)f_6816},
{C_text("f_6882:scrutinizer_2escm"),(void*)f_6882},
{C_text("f_6896:scrutinizer_2escm"),(void*)f_6896},
{C_text("f_6920:scrutinizer_2escm"),(void*)f_6920},
{C_text("f_6926:scrutinizer_2escm"),(void*)f_6926},
{C_text("f_6944:scrutinizer_2escm"),(void*)f_6944},
{C_text("f_6984:scrutinizer_2escm"),(void*)f_6984},
{C_text("f_6998:scrutinizer_2escm"),(void*)f_6998},
{C_text("f_7017:scrutinizer_2escm"),(void*)f_7017},
{C_text("f_7032:scrutinizer_2escm"),(void*)f_7032},
{C_text("f_7040:scrutinizer_2escm"),(void*)f_7040},
{C_text("f_7048:scrutinizer_2escm"),(void*)f_7048},
{C_text("f_7059:scrutinizer_2escm"),(void*)f_7059},
{C_text("f_7072:scrutinizer_2escm"),(void*)f_7072},
{C_text("f_7079:scrutinizer_2escm"),(void*)f_7079},
{C_text("f_7086:scrutinizer_2escm"),(void*)f_7086},
{C_text("f_7090:scrutinizer_2escm"),(void*)f_7090},
{C_text("f_7102:scrutinizer_2escm"),(void*)f_7102},
{C_text("f_7104:scrutinizer_2escm"),(void*)f_7104},
{C_text("f_7151:scrutinizer_2escm"),(void*)f_7151},
{C_text("f_7153:scrutinizer_2escm"),(void*)f_7153},
{C_text("f_7187:scrutinizer_2escm"),(void*)f_7187},
{C_text("f_7193:scrutinizer_2escm"),(void*)f_7193},
{C_text("f_7215:scrutinizer_2escm"),(void*)f_7215},
{C_text("f_7221:scrutinizer_2escm"),(void*)f_7221},
{C_text("f_7227:scrutinizer_2escm"),(void*)f_7227},
{C_text("f_7237:scrutinizer_2escm"),(void*)f_7237},
{C_text("f_7257:scrutinizer_2escm"),(void*)f_7257},
{C_text("f_7271:scrutinizer_2escm"),(void*)f_7271},
{C_text("f_7285:scrutinizer_2escm"),(void*)f_7285},
{C_text("f_7303:scrutinizer_2escm"),(void*)f_7303},
{C_text("f_7313:scrutinizer_2escm"),(void*)f_7313},
{C_text("f_7326:scrutinizer_2escm"),(void*)f_7326},
{C_text("f_7340:scrutinizer_2escm"),(void*)f_7340},
{C_text("f_7382:scrutinizer_2escm"),(void*)f_7382},
{C_text("f_7388:scrutinizer_2escm"),(void*)f_7388},
{C_text("f_7402:scrutinizer_2escm"),(void*)f_7402},
{C_text("f_7415:scrutinizer_2escm"),(void*)f_7415},
{C_text("f_7471:scrutinizer_2escm"),(void*)f_7471},
{C_text("f_7480:scrutinizer_2escm"),(void*)f_7480},
{C_text("f_7488:scrutinizer_2escm"),(void*)f_7488},
{C_text("f_7492:scrutinizer_2escm"),(void*)f_7492},
{C_text("f_7496:scrutinizer_2escm"),(void*)f_7496},
{C_text("f_7514:scrutinizer_2escm"),(void*)f_7514},
{C_text("f_7536:scrutinizer_2escm"),(void*)f_7536},
{C_text("f_7553:scrutinizer_2escm"),(void*)f_7553},
{C_text("f_7652:scrutinizer_2escm"),(void*)f_7652},
{C_text("f_7738:scrutinizer_2escm"),(void*)f_7738},
{C_text("f_7763:scrutinizer_2escm"),(void*)f_7763},
{C_text("f_7786:scrutinizer_2escm"),(void*)f_7786},
{C_text("f_7791:scrutinizer_2escm"),(void*)f_7791},
{C_text("f_7805:scrutinizer_2escm"),(void*)f_7805},
{C_text("f_7829:scrutinizer_2escm"),(void*)f_7829},
{C_text("f_7835:scrutinizer_2escm"),(void*)f_7835},
{C_text("f_7849:scrutinizer_2escm"),(void*)f_7849},
{C_text("f_7853:scrutinizer_2escm"),(void*)f_7853},
{C_text("f_7865:scrutinizer_2escm"),(void*)f_7865},
{C_text("f_7871:scrutinizer_2escm"),(void*)f_7871},
{C_text("f_7883:scrutinizer_2escm"),(void*)f_7883},
{C_text("f_7948:scrutinizer_2escm"),(void*)f_7948},
{C_text("f_8009:scrutinizer_2escm"),(void*)f_8009},
{C_text("f_8012:scrutinizer_2escm"),(void*)f_8012},
{C_text("f_8021:scrutinizer_2escm"),(void*)f_8021},
{C_text("f_8141:scrutinizer_2escm"),(void*)f_8141},
{C_text("f_8149:scrutinizer_2escm"),(void*)f_8149},
{C_text("f_8151:scrutinizer_2escm"),(void*)f_8151},
{C_text("f_8194:scrutinizer_2escm"),(void*)f_8194},
{C_text("f_8231:scrutinizer_2escm"),(void*)f_8231},
{C_text("f_8244:scrutinizer_2escm"),(void*)f_8244},
{C_text("f_8256:scrutinizer_2escm"),(void*)f_8256},
{C_text("f_8259:scrutinizer_2escm"),(void*)f_8259},
{C_text("f_8320:scrutinizer_2escm"),(void*)f_8320},
{C_text("f_8322:scrutinizer_2escm"),(void*)f_8322},
{C_text("f_8347:scrutinizer_2escm"),(void*)f_8347},
{C_text("f_8371:scrutinizer_2escm"),(void*)f_8371},
{C_text("f_8375:scrutinizer_2escm"),(void*)f_8375},
{C_text("f_8408:scrutinizer_2escm"),(void*)f_8408},
{C_text("f_8411:scrutinizer_2escm"),(void*)f_8411},
{C_text("f_8413:scrutinizer_2escm"),(void*)f_8413},
{C_text("f_8438:scrutinizer_2escm"),(void*)f_8438},
{C_text("f_8483:scrutinizer_2escm"),(void*)f_8483},
{C_text("f_8487:scrutinizer_2escm"),(void*)f_8487},
{C_text("f_8497:scrutinizer_2escm"),(void*)f_8497},
{C_text("f_8506:scrutinizer_2escm"),(void*)f_8506},
{C_text("f_8526:scrutinizer_2escm"),(void*)f_8526},
{C_text("f_8538:scrutinizer_2escm"),(void*)f_8538},
{C_text("f_8557:scrutinizer_2escm"),(void*)f_8557},
{C_text("f_8561:scrutinizer_2escm"),(void*)f_8561},
{C_text("f_8573:scrutinizer_2escm"),(void*)f_8573},
{C_text("f_8611:scrutinizer_2escm"),(void*)f_8611},
{C_text("f_8618:scrutinizer_2escm"),(void*)f_8618},
{C_text("f_8620:scrutinizer_2escm"),(void*)f_8620},
{C_text("f_8652:scrutinizer_2escm"),(void*)f_8652},
{C_text("f_8682:scrutinizer_2escm"),(void*)f_8682},
{C_text("f_8686:scrutinizer_2escm"),(void*)f_8686},
{C_text("f_8692:scrutinizer_2escm"),(void*)f_8692},
{C_text("f_8704:scrutinizer_2escm"),(void*)f_8704},
{C_text("f_8706:scrutinizer_2escm"),(void*)f_8706},
{C_text("f_8734:scrutinizer_2escm"),(void*)f_8734},
{C_text("f_8737:scrutinizer_2escm"),(void*)f_8737},
{C_text("f_8750:scrutinizer_2escm"),(void*)f_8750},
{C_text("f_8753:scrutinizer_2escm"),(void*)f_8753},
{C_text("f_8756:scrutinizer_2escm"),(void*)f_8756},
{C_text("f_8772:scrutinizer_2escm"),(void*)f_8772},
{C_text("f_8782:scrutinizer_2escm"),(void*)f_8782},
{C_text("f_8788:scrutinizer_2escm"),(void*)f_8788},
{C_text("f_8798:scrutinizer_2escm"),(void*)f_8798},
{C_text("f_8807:scrutinizer_2escm"),(void*)f_8807},
{C_text("f_8810:scrutinizer_2escm"),(void*)f_8810},
{C_text("f_8817:scrutinizer_2escm"),(void*)f_8817},
{C_text("f_8823:scrutinizer_2escm"),(void*)f_8823},
{C_text("f_8828:scrutinizer_2escm"),(void*)f_8828},
{C_text("f_8834:scrutinizer_2escm"),(void*)f_8834},
{C_text("f_8838:scrutinizer_2escm"),(void*)f_8838},
{C_text("f_8841:scrutinizer_2escm"),(void*)f_8841},
{C_text("f_8844:scrutinizer_2escm"),(void*)f_8844},
{C_text("f_8847:scrutinizer_2escm"),(void*)f_8847},
{C_text("f_8850:scrutinizer_2escm"),(void*)f_8850},
{C_text("f_8853:scrutinizer_2escm"),(void*)f_8853},
{C_text("f_8856:scrutinizer_2escm"),(void*)f_8856},
{C_text("f_8859:scrutinizer_2escm"),(void*)f_8859},
{C_text("f_8872:scrutinizer_2escm"),(void*)f_8872},
{C_text("f_8884:scrutinizer_2escm"),(void*)f_8884},
{C_text("f_8909:scrutinizer_2escm"),(void*)f_8909},
{C_text("f_8919:scrutinizer_2escm"),(void*)f_8919},
{C_text("f_8928:scrutinizer_2escm"),(void*)f_8928},
{C_text("f_8940:scrutinizer_2escm"),(void*)f_8940},
{C_text("f_8947:scrutinizer_2escm"),(void*)f_8947},
{C_text("f_8950:scrutinizer_2escm"),(void*)f_8950},
{C_text("f_8953:scrutinizer_2escm"),(void*)f_8953},
{C_text("f_8987:scrutinizer_2escm"),(void*)f_8987},
{C_text("f_8994:scrutinizer_2escm"),(void*)f_8994},
{C_text("f_8997:scrutinizer_2escm"),(void*)f_8997},
{C_text("f_9003:scrutinizer_2escm"),(void*)f_9003},
{C_text("f_9032:scrutinizer_2escm"),(void*)f_9032},
{C_text("f_9036:scrutinizer_2escm"),(void*)f_9036},
{C_text("f_9054:scrutinizer_2escm"),(void*)f_9054},
{C_text("f_9057:scrutinizer_2escm"),(void*)f_9057},
{C_text("f_9060:scrutinizer_2escm"),(void*)f_9060},
{C_text("f_9066:scrutinizer_2escm"),(void*)f_9066},
{C_text("f_9099:scrutinizer_2escm"),(void*)f_9099},
{C_text("f_9103:scrutinizer_2escm"),(void*)f_9103},
{C_text("f_9142:scrutinizer_2escm"),(void*)f_9142},
{C_text("f_9146:scrutinizer_2escm"),(void*)f_9146},
{C_text("f_9165:scrutinizer_2escm"),(void*)f_9165},
{C_text("f_9169:scrutinizer_2escm"),(void*)f_9169},
{C_text("f_9175:scrutinizer_2escm"),(void*)f_9175},
{C_text("f_9189:scrutinizer_2escm"),(void*)f_9189},
{C_text("f_9195:scrutinizer_2escm"),(void*)f_9195},
{C_text("f_9209:scrutinizer_2escm"),(void*)f_9209},
{C_text("f_9240:scrutinizer_2escm"),(void*)f_9240},
{C_text("f_9253:scrutinizer_2escm"),(void*)f_9253},
{C_text("f_9263:scrutinizer_2escm"),(void*)f_9263},
{C_text("f_9265:scrutinizer_2escm"),(void*)f_9265},
{C_text("f_9294:scrutinizer_2escm"),(void*)f_9294},
{C_text("f_9307:scrutinizer_2escm"),(void*)f_9307},
{C_text("f_9323:scrutinizer_2escm"),(void*)f_9323},
{C_text("f_9334:scrutinizer_2escm"),(void*)f_9334},
{C_text("f_9338:scrutinizer_2escm"),(void*)f_9338},
{C_text("f_9366:scrutinizer_2escm"),(void*)f_9366},
{C_text("f_9370:scrutinizer_2escm"),(void*)f_9370},
{C_text("f_9372:scrutinizer_2escm"),(void*)f_9372},
{C_text("f_9406:scrutinizer_2escm"),(void*)f_9406},
{C_text("f_9411:scrutinizer_2escm"),(void*)f_9411},
{C_text("f_9417:scrutinizer_2escm"),(void*)f_9417},
{C_text("f_9422:scrutinizer_2escm"),(void*)f_9422},
{C_text("f_9444:scrutinizer_2escm"),(void*)f_9444},
{C_text("f_9451:scrutinizer_2escm"),(void*)f_9451},
{C_text("f_9454:scrutinizer_2escm"),(void*)f_9454},
{C_text("f_9457:scrutinizer_2escm"),(void*)f_9457},
{C_text("f_9463:scrutinizer_2escm"),(void*)f_9463},
{C_text("f_9467:scrutinizer_2escm"),(void*)f_9467},
{C_text("f_9474:scrutinizer_2escm"),(void*)f_9474},
{C_text("f_9482:scrutinizer_2escm"),(void*)f_9482},
{C_text("f_9507:scrutinizer_2escm"),(void*)f_9507},
{C_text("f_9516:scrutinizer_2escm"),(void*)f_9516},
{C_text("f_9522:scrutinizer_2escm"),(void*)f_9522},
{C_text("f_9540:scrutinizer_2escm"),(void*)f_9540},
{C_text("f_9544:scrutinizer_2escm"),(void*)f_9544},
{C_text("f_9547:scrutinizer_2escm"),(void*)f_9547},
{C_text("f_9550:scrutinizer_2escm"),(void*)f_9550},
{C_text("f_9558:scrutinizer_2escm"),(void*)f_9558},
{C_text("f_9586:scrutinizer_2escm"),(void*)f_9586},
{C_text("f_9628:scrutinizer_2escm"),(void*)f_9628},
{C_text("f_9645:scrutinizer_2escm"),(void*)f_9645},
{C_text("f_9665:scrutinizer_2escm"),(void*)f_9665},
{C_text("f_9682:scrutinizer_2escm"),(void*)f_9682},
{C_text("f_9701:scrutinizer_2escm"),(void*)f_9701},
{C_text("f_9707:scrutinizer_2escm"),(void*)f_9707},
{C_text("f_9712:scrutinizer_2escm"),(void*)f_9712},
{C_text("f_9731:scrutinizer_2escm"),(void*)f_9731},
{C_text("f_9734:scrutinizer_2escm"),(void*)f_9734},
{C_text("f_9738:scrutinizer_2escm"),(void*)f_9738},
{C_text("f_9745:scrutinizer_2escm"),(void*)f_9745},
{C_text("f_9757:scrutinizer_2escm"),(void*)f_9757},
{C_text("f_9760:scrutinizer_2escm"),(void*)f_9760},
{C_text("f_9792:scrutinizer_2escm"),(void*)f_9792},
{C_text("f_9821:scrutinizer_2escm"),(void*)f_9821},
{C_text("f_9886:scrutinizer_2escm"),(void*)f_9886},
{C_text("f_9920:scrutinizer_2escm"),(void*)f_9920},
{C_text("f_9930:scrutinizer_2escm"),(void*)f_9930},
{C_text("f_9976:scrutinizer_2escm"),(void*)f_9976},
{C_text("f_9980:scrutinizer_2escm"),(void*)f_9980},
{C_text("f_9982:scrutinizer_2escm"),(void*)f_9982},
{C_text("toplevel:scrutinizer_2escm"),(void*)C_scrutinizer_toplevel},
{NULL,NULL}};
#endif

static C_PTABLE_ENTRY *create_ptable(void){
#ifdef C_ENABLE_PTABLES
return ptable;
#else
return NULL;
#endif
}

/*
o|hiding unexported module binding: chicken.compiler.scrutinizer#partition 
o|hiding unexported module binding: chicken.compiler.scrutinizer#span 
o|hiding unexported module binding: chicken.compiler.scrutinizer#take 
o|hiding unexported module binding: chicken.compiler.scrutinizer#drop 
o|hiding unexported module binding: chicken.compiler.scrutinizer#split-at 
o|hiding unexported module binding: chicken.compiler.scrutinizer#append-map 
o|hiding unexported module binding: chicken.compiler.scrutinizer#every 
o|hiding unexported module binding: chicken.compiler.scrutinizer#any 
o|hiding unexported module binding: chicken.compiler.scrutinizer#cons* 
o|hiding unexported module binding: chicken.compiler.scrutinizer#concatenate 
o|hiding unexported module binding: chicken.compiler.scrutinizer#delete 
o|hiding unexported module binding: chicken.compiler.scrutinizer#first 
o|hiding unexported module binding: chicken.compiler.scrutinizer#second 
o|hiding unexported module binding: chicken.compiler.scrutinizer#third 
o|hiding unexported module binding: chicken.compiler.scrutinizer#fourth 
o|hiding unexported module binding: chicken.compiler.scrutinizer#fifth 
o|hiding unexported module binding: chicken.compiler.scrutinizer#delete-duplicates 
o|hiding unexported module binding: chicken.compiler.scrutinizer#alist-cons 
o|hiding unexported module binding: chicken.compiler.scrutinizer#filter 
o|hiding unexported module binding: chicken.compiler.scrutinizer#filter-map 
o|hiding unexported module binding: chicken.compiler.scrutinizer#remove 
o|hiding unexported module binding: chicken.compiler.scrutinizer#unzip1 
o|hiding unexported module binding: chicken.compiler.scrutinizer#last 
o|hiding unexported module binding: chicken.compiler.scrutinizer#list-index 
o|hiding unexported module binding: chicken.compiler.scrutinizer#lset-adjoin/eq? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#lset-difference/eq? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#lset-union/eq? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#lset-intersection/eq? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#list-tabulate 
o|hiding unexported module binding: chicken.compiler.scrutinizer#lset<=/eq? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#lset=/eq? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#length+ 
o|hiding unexported module binding: chicken.compiler.scrutinizer#find 
o|hiding unexported module binding: chicken.compiler.scrutinizer#find-tail 
o|hiding unexported module binding: chicken.compiler.scrutinizer#iota 
o|hiding unexported module binding: chicken.compiler.scrutinizer#make-list 
o|hiding unexported module binding: chicken.compiler.scrutinizer#posq 
o|hiding unexported module binding: chicken.compiler.scrutinizer#posv 
o|hiding unexported module binding: chicken.compiler.scrutinizer#d-depth 
o|hiding unexported module binding: chicken.compiler.scrutinizer#scrutiny-debug 
o|hiding unexported module binding: chicken.compiler.scrutinizer#*complain?* 
o|hiding unexported module binding: chicken.compiler.scrutinizer#d 
o|hiding unexported module binding: chicken.compiler.scrutinizer#dd 
o|hiding unexported module binding: chicken.compiler.scrutinizer#ddd 
o|hiding unexported module binding: chicken.compiler.scrutinizer#d 
o|hiding unexported module binding: chicken.compiler.scrutinizer#dd 
o|hiding unexported module binding: chicken.compiler.scrutinizer#ddd 
o|hiding unexported module binding: chicken.compiler.scrutinizer#constant733 
o|hiding unexported module binding: chicken.compiler.scrutinizer#constant740 
o|hiding unexported module binding: chicken.compiler.scrutinizer#constant748 
o|hiding unexported module binding: chicken.compiler.scrutinizer#constant757 
o|hiding unexported module binding: chicken.compiler.scrutinizer#specialization-statistics 
o|hiding unexported module binding: chicken.compiler.scrutinizer#trail 
o|hiding unexported module binding: chicken.compiler.scrutinizer#walked-result 
o|hiding unexported module binding: chicken.compiler.scrutinizer#type-always-immediate? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#smash-component-types! 
o|hiding unexported module binding: chicken.compiler.scrutinizer#ble-id 
o|hiding unexported module binding: chicken.compiler.scrutinizer#ble-tag 
o|hiding unexported module binding: chicken.compiler.scrutinizer#ble-type 
o|hiding unexported module binding: chicken.compiler.scrutinizer#ble-type-set! 
o|hiding unexported module binding: chicken.compiler.scrutinizer#match-argument-types 
o|hiding unexported module binding: chicken.compiler.scrutinizer#simplify-type 
o|hiding unexported module binding: chicken.compiler.scrutinizer#maybe-expand-type 
o|hiding unexported module binding: chicken.compiler.scrutinizer#merge-argument-types 
o|hiding unexported module binding: chicken.compiler.scrutinizer#merge-result-types 
o|hiding unexported module binding: chicken.compiler.scrutinizer#compatible-types? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#type-min 
o|hiding unexported module binding: chicken.compiler.scrutinizer#procedure-type? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#procedure-name 
o|hiding unexported module binding: chicken.compiler.scrutinizer#procedure-arguments 
o|hiding unexported module binding: chicken.compiler.scrutinizer#procedure-results 
o|hiding unexported module binding: chicken.compiler.scrutinizer#procedure-argument-types 
o|hiding unexported module binding: chicken.compiler.scrutinizer#procedure-result-types 
o|hiding unexported module binding: chicken.compiler.scrutinizer#named? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#rest-type 
o|hiding unexported module binding: chicken.compiler.scrutinizer#noreturn-procedure-type? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#noreturn-type? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#refinement-type? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#make-tv 
o|hiding unexported module binding: chicken.compiler.scrutinizer#type-typeenv 
o|hiding unexported module binding: chicken.compiler.scrutinizer#trail-restore 
o|hiding unexported module binding: chicken.compiler.scrutinizer#with-trail-restore 
o|hiding unexported module binding: chicken.compiler.scrutinizer#resolve 
o|hiding unexported module binding: chicken.compiler.scrutinizer#hash-table->list 
o|hiding unexported module binding: chicken.compiler.scrutinizer#symbol<? 
o|hiding unexported module binding: chicken.compiler.scrutinizer#node-mutations 
o|hiding unexported module binding: chicken.compiler.scrutinizer#mutate-node! 
o|hiding unexported module binding: chicken.compiler.scrutinizer#source-node 
o|hiding unexported module binding: chicken.compiler.scrutinizer#source-node-tree 
o|hiding unexported module binding: chicken.compiler.scrutinizer#node-line-number 
o|hiding unexported module binding: chicken.compiler.scrutinizer#node-debug-info 
o|hiding unexported module binding: chicken.compiler.scrutinizer#specialize-node! 
o|hiding unexported module binding: chicken.compiler.scrutinizer#canonicalize-list-type 
o|hiding unexported module binding: chicken.compiler.scrutinizer#strip-namespace 
o|hiding unexported module binding: chicken.compiler.scrutinizer#define-special-case 
o|hiding unexported module binding: chicken.compiler.scrutinizer#over-all-instantiations 
o|hiding unexported module binding: chicken.compiler.scrutinizer#multiples 
o|hiding unexported module binding: chicken.compiler.scrutinizer#string-add-indent 
o|hiding unexported module binding: chicken.compiler.scrutinizer#type->pp-string 
o|hiding unexported module binding: chicken.compiler.scrutinizer#fragment 
o|hiding unexported module binding: chicken.compiler.scrutinizer#pp-fragment 
o|hiding unexported module binding: chicken.compiler.scrutinizer#node-source-prefix 
o|hiding unexported module binding: chicken.compiler.scrutinizer#location-name 
o|hiding unexported module binding: chicken.compiler.scrutinizer#variable-and-module 
o|hiding unexported module binding: chicken.compiler.scrutinizer#variable-from-module 
o|hiding unexported module binding: chicken.compiler.scrutinizer#describe-expression 
o|hiding unexported module binding: chicken.compiler.scrutinizer#call-node-procedure-name 
o|hiding unexported module binding: chicken.compiler.scrutinizer#report2 
o|hiding unexported module binding: chicken.compiler.scrutinizer#report-notice 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-invalid-called-procedure-type 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-proc-call-argument-count-mismatch 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-proc-call-argument-value-count 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-index-out-of-range 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-conditional-value-count-invalid 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-let-value-count-invalid 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-assignment-value-count-invalid 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-pred-call-always-true 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-pred-call-always-false 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-cond-test-always-true 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-cond-test-always-false 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-zero-values-for-the 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-too-many-values-for-the 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-type-mismatch-in-the 
o|hiding unexported module binding: chicken.compiler.scrutinizer#fail-compiler-typecase 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-cond-branch-value-count-mismatch 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-toplevel-var-assignment-type-mismatch 
o|hiding unexported module binding: chicken.compiler.scrutinizer#r-deprecated-identifier 
S|applied compiler syntax:
S|  scheme#for-each		12
S|  chicken.format#sprintf		27
S|  chicken.format#printf		2
S|  chicken.base#foldl		5
S|  scheme#map		49
S|  chicken.base#foldr		3
o|eliminated procedure checks: 465 
o|eliminated procedure checks: 1 
o|eliminated procedure checks: 1 
o|specializations:
o|  2 (scheme#string=? string string)
o|  1 (scheme#< fixnum fixnum)
o|  1 (scheme#string-append string string)
o|  1 (scheme#>= fixnum fixnum)
o|  2 (scheme#string-length string)
o|  4 (scheme#eqv? (or eof null fixnum char boolean symbol keyword) *)
o|  1 (scheme#- *)
o|  4 (scheme#negative? *)
o|  2 (scheme#integer? *)
o|  2 (scheme#vector-length vector)
o|  1 (scheme#cdddr (pair * (pair * pair)))
o|  1 (chicken.plist#put! symbol symbol *)
o|  3 (scheme#cadr (pair * pair))
o|  4 (scheme#cddr (pair * pair))
o|  4 (scheme#positive? *)
o|  2 (scheme#> fixnum fixnum)
o|  2 (chicken.base#sub1 fixnum)
o|  2 (scheme#set-cdr! pair *)
o|  8 (chicken.base#sub1 *)
o|  3 (scheme#zero? *)
o|  1 (scheme#caar (pair pair *))
o|  14 (chicken.base#add1 *)
o|  11 (scheme#length list)
o|  5 (scheme#zero? integer)
o|  16 (scheme#= fixnum fixnum)
o|  2 (scheme#cdar (pair pair *))
o|  15 (scheme#memq * list)
o|  91 (scheme#eqv? * (or eof null fixnum char boolean symbol keyword))
o|  29 (##sys#check-output-port * * *)
o|  1 (##sys#debug-mode?)
o|  1 (scheme#eqv? * *)
o|  11 (##sys#check-list (or pair list) *)
o|  124 (scheme#cdr pair)
o|  129 (scheme#car pair)
(o e)|safe calls: 2532 
(o e)|dropped branches: 2 
(o e)|assignments to immediate values: 7 
o|safe globals: (chicken.compiler.scrutinizer#strip-namespace chicken.compiler.scrutinizer#canonicalize-list-type chicken.compiler.scrutinizer#install-specializations chicken.compiler.scrutinizer#check-and-validate-type chicken.compiler.scrutinizer#validate-type chicken.compiler.scrutinizer#specialize-node! chicken.compiler.scrutinizer#node-debug-info chicken.compiler.scrutinizer#node-line-number chicken.compiler.scrutinizer#source-node-tree chicken.compiler.scrutinizer#source-node chicken.compiler.scrutinizer#mutate-node! chicken.compiler.scrutinizer#node-mutations chicken.compiler.scrutinizer#emit-types-file chicken.compiler.scrutinizer#symbol<? chicken.compiler.scrutinizer#hash-table->list chicken.compiler.scrutinizer#load-type-database chicken.compiler.scrutinizer#resolve chicken.compiler.scrutinizer#with-trail-restore chicken.compiler.scrutinizer#trail-restore chicken.compiler.scrutinizer#type-typeenv chicken.compiler.scrutinizer#make-tv chicken.compiler.scrutinizer#refinement-type? chicken.compiler.scrutinizer#noreturn-type? chicken.compiler.scrutinizer#noreturn-procedure-type? chicken.compiler.scrutinizer#rest-type chicken.compiler.scrutinizer#named? chicken.compiler.scrutinizer#procedure-result-types chicken.compiler.scrutinizer#procedure-argument-types chicken.compiler.scrutinizer#procedure-results chicken.compiler.scrutinizer#procedure-arguments chicken.compiler.scrutinizer#procedure-name chicken.compiler.scrutinizer#procedure-type? chicken.compiler.scrutinizer#refine-types chicken.compiler.scrutinizer#type<=? chicken.compiler.scrutinizer#type-min chicken.compiler.scrutinizer#compatible-types? chicken.compiler.scrutinizer#merge-result-types chicken.compiler.scrutinizer#merge-argument-types chicken.compiler.scrutinizer#maybe-expand-type chicken.compiler.scrutinizer#simplify-type chicken.compiler.scrutinizer#match-argument-types chicken.compiler.scrutinizer#match-types chicken.compiler.scrutinizer#ble-type-set! chicken.compiler.scrutinizer#ble-type chicken.compiler.scrutinizer#ble-tag chicken.compiler.scrutinizer#ble-id chicken.compiler.scrutinizer#smash-component-types! chicken.compiler.scrutinizer#scrutinize chicken.compiler.scrutinizer#type-always-immediate? chicken.compiler.scrutinizer#walked-result chicken.compiler.scrutinizer#trail chicken.compiler.scrutinizer#specialization-statistics chicken.compiler.scrutinizer#constant757 chicken.compiler.scrutinizer#constant748 chicken.compiler.scrutinizer#constant740 chicken.compiler.scrutinizer#constant733 chicken.compiler.scrutinizer#ddd chicken.compiler.scrutinizer#dd chicken.compiler.scrutinizer#d chicken.compiler.scrutinizer#*complain?* chicken.compiler.scrutinizer#scrutiny-debug chicken.compiler.scrutinizer#d-depth chicken.compiler.scrutinizer#posv chicken.compiler.scrutinizer#posq chicken.compiler.scrutinizer#make-list chicken.compiler.scrutinizer#iota chicken.compiler.scrutinizer#find-tail chicken.compiler.scrutinizer#find chicken.compiler.scrutinizer#length+ chicken.compiler.scrutinizer#lset=/eq? chicken.compiler.scrutinizer#lset<=/eq? chicken.compiler.scrutinizer#list-tabulate chicken.compiler.scrutinizer#lset-intersection/eq? chicken.compiler.scrutinizer#lset-union/eq? chicken.compiler.scrutinizer#lset-difference/eq? chicken.compiler.scrutinizer#lset-adjoin/eq? chicken.compiler.scrutinizer#list-index chicken.compiler.scrutinizer#last chicken.compiler.scrutinizer#unzip1 chicken.compiler.scrutinizer#remove chicken.compiler.scrutinizer#filter-map chicken.compiler.scrutinizer#filter chicken.compiler.scrutinizer#alist-cons chicken.compiler.scrutinizer#delete-duplicates chicken.compiler.scrutinizer#fifth chicken.compiler.scrutinizer#fourth chicken.compiler.scrutinizer#third chicken.compiler.scrutinizer#second chicken.compiler.scrutinizer#first chicken.compiler.scrutinizer#delete chicken.compiler.scrutinizer#concatenate chicken.compiler.scrutinizer#cons* chicken.compiler.scrutinizer#any chicken.compiler.scrutinizer#every chicken.compiler.scrutinizer#append-map chicken.compiler.scrutinizer#split-at chicken.compiler.scrutinizer#drop chicken.compiler.scrutinizer#take chicken.compiler.scrutinizer#span chicken.compiler.scrutinizer#partition) 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#partition 
o|inlining procedure: k6928 
o|inlining procedure: k6928 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#drop 
o|merged explicitly consed rest parameter: lsts189 
o|inlining procedure: k7019 
o|inlining procedure: k7034 
o|inlining procedure: k7034 
o|inlining procedure: k7019 
o|inlining procedure: k7074 
o|inlining procedure: k7074 
o|inlining procedure: k7106 
o|contracted procedure: "(mini-srfi-1.scm:77) g242251" 
o|inlining procedure: k7106 
o|inlining procedure: k7155 
o|contracted procedure: "(mini-srfi-1.scm:76) g215224" 
o|inlining procedure: k7155 
o|inlining procedure: k7198 
o|inlining procedure: k7198 
o|inlining procedure: k7229 
o|inlining procedure: k7229 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#fifth 
o|inlining procedure: k7390 
o|inlining procedure: k7390 
o|contracted procedure: "(mini-srfi-1.scm:123) chicken.compiler.scrutinizer#delete" 
o|inlining procedure: k7315 
o|inlining procedure: k7315 
o|inlining procedure: k7446 
o|inlining procedure: k7446 
o|inlining procedure: k7438 
o|inlining procedure: k7438 
o|inlining procedure: k7493 
o|inlining procedure: k7493 
o|inlining procedure: k7482 
o|inlining procedure: k7482 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#remove 
o|inlining procedure: k7555 
o|contracted procedure: "(mini-srfi-1.scm:143) g393402" 
o|inlining procedure: k7555 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#last 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#list-index 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#lset-difference/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#lset-intersection/eq? 
o|inlining procedure: k7837 
o|inlining procedure: k7837 
o|inlining procedure: k7873 
o|inlining procedure: k7873 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#length+ 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#find-tail 
o|merged explicitly consed rest parameter: rest561563 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#posq 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#posv 
o|propagated global variable: out636639 ##sys#standard-output 
o|substituted constant variable: a8108 
o|substituted constant variable: a8109 
o|inlining procedure: k8101 
o|propagated global variable: out636639 ##sys#standard-output 
o|inlining procedure: k8101 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#dd 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#ddd 
o|inlining procedure: "(scrutinizer.scm:167) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k8153 
o|inlining procedure: k8171 
o|inlining procedure: "(scrutinizer.scm:173) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k8171 
o|substituted constant variable: a8185 
o|substituted constant variable: a8187 
o|inlining procedure: k8153 
o|substituted constant variable: a8192 
o|removed side-effect free assignment to unused variable: report783 
o|inlining procedure: k8233 
o|inlining procedure: k8233 
o|inlining procedure: k8245 
o|inlining procedure: k8245 
o|inlining procedure: k8260 
o|inlining procedure: k8260 
o|inlining procedure: k8272 
o|inlining procedure: k8272 
o|inlining procedure: k8284 
o|inlining procedure: k8284 
o|inlining procedure: k8296 
o|inlining procedure: k8296 
o|inlining procedure: k8299 
o|inlining procedure: k8299 
o|inlining procedure: k8324 
o|inlining procedure: k8324 
o|inlining procedure: k8355 
o|inlining procedure: k8355 
o|inlining procedure: k8386 
o|inlining procedure: k8386 
o|inlining procedure: k8415 
o|inlining procedure: k8415 
o|inlining procedure: k8446 
o|inlining procedure: k8446 
o|inlining procedure: k8531 
o|inlining procedure: k8531 
o|inlining procedure: k8540 
o|inlining procedure: k8540 
o|contracted procedure: "(scrutinizer.scm:240) chicken.compiler.scrutinizer#find" 
o|inlining procedure: k7950 
o|inlining procedure: k7950 
o|inlining procedure: k8562 
o|inlining procedure: k8562 
o|inlining procedure: k8577 
o|contracted procedure: "(scrutinizer.scm:248) g935936" 
o|inlining procedure: k8582 
o|inlining procedure: k8582 
o|inlining procedure: k8577 
o|contracted procedure: "(scrutinizer.scm:262) global-result805" 
o|inlining procedure: k8489 
o|consed rest parameter at call site: "(scrutinizer.scm:231) chicken.compiler.scrutinizer#r-deprecated-identifier" 4 
o|inlining procedure: k8489 
o|consed rest parameter at call site: "(scrutinizer.scm:234) chicken.compiler.scrutinizer#r-deprecated-identifier" 4 
o|inlining procedure: k8484 
o|inlining procedure: k8484 
o|inlining procedure: k8606 
o|inlining procedure: k8606 
o|inlining procedure: k8622 
o|inlining procedure: k8640 
o|inlining procedure: "(scrutinizer.scm:268) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k8640 
o|inlining procedure: "(scrutinizer.scm:269) chicken.compiler.scrutinizer#third" 
o|substituted constant variable: a8671 
o|substituted constant variable: a8673 
o|substituted constant variable: a8675 
o|inlining procedure: k8622 
o|substituted constant variable: a8680 
o|inlining procedure: k8687 
o|contracted procedure: "(scrutinizer.scm:276) chicken.compiler.scrutinizer#r-cond-test-always-true" 
o|consed rest parameter at call site: "(scrutinizer.scm:2843) chicken.compiler.scrutinizer#report-notice" 5 
o|inlining procedure: k8687 
o|inlining procedure: k8708 
o|inlining procedure: k8708 
o|inlining procedure: k8726 
o|inlining procedure: k8726 
o|inlining procedure: "(scrutinizer.scm:294) chicken.compiler.scrutinizer#first" 
o|substituted constant variable: a8742 
o|removed unused formal parameters: (typeenv990) 
o|inlining procedure: k8802 
o|contracted procedure: "(scrutinizer.scm:314) chicken.compiler.scrutinizer#r-invalid-called-procedure-type" 
o|inlining procedure: k21962 
o|inlining procedure: "(scrutinizer.scm:2569) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k21962 
o|inlining procedure: k22000 
o|inlining procedure: k22000 
o|inlining procedure: k8802 
o|consed rest parameter at call site: "(scrutinizer.scm:319) chicken.compiler.scrutinizer#procedure-argument-types" 4 
o|inlining procedure: k8886 
o|inlining procedure: k8886 
o|inlining procedure: k8929 
o|inlining procedure: k8929 
o|inlining procedure: k8954 
o|contracted procedure: "(scrutinizer.scm:398) g11361137" 
o|inlining procedure: k8954 
o|inlining procedure: k8989 
o|contracted procedure: "(scrutinizer.scm:347) chicken.compiler.scrutinizer#r-pred-call-always-true" 
o|consed rest parameter at call site: "(scrutinizer.scm:2794) chicken.compiler.scrutinizer#report-notice" 5 
o|inlining procedure: k8989 
o|inlining procedure: k9061 
o|inlining procedure: k9061 
o|contracted procedure: "(scrutinizer.scm:358) chicken.compiler.scrutinizer#r-pred-call-always-false" 
o|consed rest parameter at call site: "(scrutinizer.scm:2819) chicken.compiler.scrutinizer#report-notice" 5 
o|inlining procedure: k9143 
o|inlining procedure: k9143 
o|inlining procedure: k9177 
o|inlining procedure: k9210 
o|inlining procedure: k9210 
o|inlining procedure: "(scrutinizer.scm:389) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:390) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:387) chicken.compiler.scrutinizer#second" 
o|consed rest parameter at call site: "(scrutinizer.scm:381) chicken.compiler.scrutinizer#append-map" 3 
o|inlining procedure: "(scrutinizer.scm:379) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k9177 
o|contracted procedure: "(scrutinizer.scm:374) get-specializations813" 
o|inlining procedure: k8757 
o|inlining procedure: k8757 
o|inlining procedure: k8768 
o|inlining procedure: k8768 
o|inlining procedure: k9267 
o|inlining procedure: k9267 
o|contracted procedure: "(scrutinizer.scm:339) chicken.compiler.scrutinizer#procedure-result-types" 
o|inlining procedure: k15626 
o|inlining procedure: k15626 
o|inlining procedure: "(scrutinizer.scm:1462) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k15647 
o|inlining procedure: k15669 
o|inlining procedure: k15669 
o|substituted constant variable: a15679 
o|inlining procedure: "(scrutinizer.scm:1466) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1466) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k15647 
o|inlining procedure: "(scrutinizer.scm:1473) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k9296 
o|inlining procedure: k9296 
o|contracted procedure: "(scrutinizer.scm:321) chicken.compiler.scrutinizer#r-proc-call-argument-count-mismatch" 
o|consed rest parameter at call site: "(scrutinizer.scm:310) chicken.compiler.scrutinizer#append-map" 3 
o|consed rest parameter at call site: "(scrutinizer.scm:309) chicken.compiler.scrutinizer#make-list" 2 
o|inlining procedure: k9374 
o|inlining procedure: k9374 
o|inlining procedure: k9426 
o|inlining procedure: k9426 
o|removed unused formal parameters: (vars1201) 
o|inlining procedure: k9446 
o|inlining procedure: k9484 
o|inlining procedure: k9484 
o|consed rest parameter at call site: "(scrutinizer.scm:433) chicken.compiler.scrutinizer#procedure-argument-types" 4 
o|consed rest parameter at call site: "(scrutinizer.scm:434) chicken.compiler.scrutinizer#make-list" 2 
o|inlining procedure: k9446 
o|consed rest parameter at call site: "(scrutinizer.scm:435) chicken.compiler.scrutinizer#make-list" 2 
o|inlining procedure: k9533 
o|inlining procedure: k9533 
o|propagated global variable: a9555 chicken.compiler.scrutinizer#d-depth 
o|propagated global variable: a9560 chicken.compiler.scrutinizer#d-depth 
o|inlining procedure: "(scrutinizer.scm:448) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k9574 
o|inlining procedure: "(scrutinizer.scm:449) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k9574 
o|inlining procedure: k9597 
o|inlining procedure: k9597 
o|inlining procedure: "(scrutinizer.scm:452) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k9616 
o|inlining procedure: "(scrutinizer.scm:454) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k9616 
o|inlining procedure: "(scrutinizer.scm:456) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k9650 
o|inlining procedure: k9702 
o|inlining procedure: k9702 
o|inlining procedure: k9752 
o|contracted procedure: "(scrutinizer.scm:499) chicken.compiler.scrutinizer#r-cond-branch-value-count-mismatch" 
o|inlining procedure: k9752 
o|inlining procedure: k9764 
o|inlining procedure: k9764 
o|inlining procedure: k9794 
o|contracted procedure: "(scrutinizer.scm:505) g13501360" 
o|inlining procedure: k9794 
o|inlining procedure: k9842 
o|inlining procedure: k9842 
o|inlining procedure: k9888 
o|inlining procedure: k9888 
o|inlining procedure: k9922 
o|inlining procedure: k9922 
o|inlining procedure: k9944 
o|inlining procedure: k9944 
o|inlining procedure: k9953 
o|inlining procedure: k9953 
o|contracted procedure: "(scrutinizer.scm:472) always-false810" 
o|inlining procedure: k8699 
o|contracted procedure: "(scrutinizer.scm:281) chicken.compiler.scrutinizer#r-cond-test-always-false" 
o|consed rest parameter at call site: "(scrutinizer.scm:2859) chicken.compiler.scrutinizer#report-notice" 5 
o|inlining procedure: k8699 
o|inlining procedure: "(scrutinizer.scm:465) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:464) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:459) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k9650 
o|inlining procedure: k10007 
o|inlining procedure: k10007 
o|inlining procedure: k10055 
o|inlining procedure: k10055 
o|inlining procedure: "(scrutinizer.scm:520) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k10093 
o|inlining procedure: k10166 
o|inlining procedure: k10166 
o|inlining procedure: "(scrutinizer.scm:541) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k10305 
o|contracted procedure: "(scrutinizer.scm:531) g14201430" 
o|inlining procedure: k10305 
o|inlining procedure: k10354 
o|inlining procedure: k10354 
o|removed unused parameter to known procedure: vars1201 "(scrutinizer.scm:529) initial-argument-types817" 
o|inlining procedure: "(scrutinizer.scm:526) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k10093 
o|inlining procedure: k10393 
o|inlining procedure: k10393 
o|inlining procedure: k10422 
o|inlining procedure: k10422 
o|inlining procedure: k10467 
o|inlining procedure: k10467 
o|inlining procedure: k10494 
o|inlining procedure: k10494 
o|inlining procedure: k10525 
o|substituted constant variable: a10557 
o|substituted constant variable: a10558 
o|removed unused parameter to known procedure: where1937 "(scrutinizer.scm:606) chicken.compiler.scrutinizer#smash-component-types!" 
o|inlining procedure: k10591 
o|inlining procedure: k10591 
o|inlining procedure: "(scrutinizer.scm:601) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k10525 
o|inlining procedure: k10619 
o|inlining procedure: k10619 
o|contracted procedure: "(scrutinizer.scm:594) chicken.compiler.scrutinizer#r-toplevel-var-assignment-type-mismatch" 
o|inlining procedure: k23044 
o|inlining procedure: k23044 
o|inlining procedure: "(scrutinizer.scm:594) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k10656 
o|inlining procedure: k10679 
o|inlining procedure: k10679 
o|inlining procedure: k10656 
o|inlining procedure: "(scrutinizer.scm:583) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:581) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:579) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k10722 
o|inlining procedure: k10722 
o|removed unused parameter to known procedure: typeenv990 "(scrutinizer.scm:688) call-result814" 
o|inlining procedure: k10809 
o|removed unused parameter to known procedure: where1937 "(scrutinizer.scm:696) chicken.compiler.scrutinizer#smash-component-types!" 
o|removed unused parameter to known procedure: where1937 "(scrutinizer.scm:695) chicken.compiler.scrutinizer#smash-component-types!" 
o|inlining procedure: k10809 
o|inlining procedure: k10827 
o|inlining procedure: k10827 
o|inlining procedure: k10847 
o|inlining procedure: k10879 
o|inlining procedure: k10879 
o|inlining procedure: k10847 
o|inlining procedure: k10921 
o|inlining procedure: k10957 
o|inlining procedure: k10957 
o|inlining procedure: k10983 
o|inlining procedure: k10983 
o|inlining procedure: k10992 
o|inlining procedure: k11007 
o|inlining procedure: k11007 
o|inlining procedure: k10992 
o|inlining procedure: k11053 
o|inlining procedure: k11053 
o|inlining procedure: "(scrutinizer.scm:714) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:711) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k10921 
o|inlining procedure: k11096 
o|inlining procedure: k11096 
o|inlining procedure: k11119 
o|inlining procedure: k11119 
o|inlining procedure: k11153 
o|inlining procedure: k11153 
o|consed rest parameter at call site: "(scrutinizer.scm:761) chicken.compiler.scrutinizer#procedure-argument-types" 4 
o|inlining procedure: k11229 
o|inlining procedure: k11229 
o|inlining procedure: k11267 
o|inlining procedure: k11267 
o|contracted procedure: "(scrutinizer.scm:679) chicken.compiler.scrutinizer#iota" 
o|inlining procedure: k11312 
o|inlining procedure: k11333 
o|contracted procedure: "(scrutinizer.scm:770) chicken.compiler.scrutinizer#r-zero-values-for-the" 
o|inlining procedure: "(scrutinizer.scm:770) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k11333 
o|contracted procedure: "(scrutinizer.scm:777) chicken.compiler.scrutinizer#r-type-mismatch-in-the" 
o|inlining procedure: "(scrutinizer.scm:777) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:777) chicken.compiler.scrutinizer#first" 
o|consed rest parameter at call site: "(scrutinizer.scm:775) chicken.compiler.scrutinizer#compatible-types?" 3 
o|inlining procedure: "(scrutinizer.scm:775) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:774) chicken.compiler.scrutinizer#second" 
o|contracted procedure: "(scrutinizer.scm:773) chicken.compiler.scrutinizer#r-too-many-values-for-the" 
o|inlining procedure: "(scrutinizer.scm:773) chicken.compiler.scrutinizer#first" 
o|substituted constant variable: a11398 
o|inlining procedure: "(scrutinizer.scm:768) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:767) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k11312 
o|inlining procedure: k11429 
o|contracted procedure: "(scrutinizer.scm:786) chicken.compiler.scrutinizer#fail-compiler-typecase" 
o|consed rest parameter at call site: "(scrutinizer.scm:2934) chicken.compiler.scrutinizer#string-add-indent" 2 
o|inlining procedure: k22917 
o|inlining procedure: k22917 
o|consed rest parameter at call site: "(scrutinizer.scm:2957) chicken.compiler.scrutinizer#location-name" 2 
o|substituted constant variable: a22948 
o|inlining procedure: k11429 
o|inlining procedure: "(scrutinizer.scm:780) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k11499 
o|inlining procedure: k11499 
o|inlining procedure: k11525 
o|inlining procedure: k11525 
o|substituted constant variable: a11549 
o|substituted constant variable: a11551 
o|substituted constant variable: a11553 
o|substituted constant variable: a11555 
o|substituted constant variable: a11557 
o|substituted constant variable: a11559 
o|substituted constant variable: a11564 
o|substituted constant variable: a11566 
o|substituted constant variable: a11571 
o|substituted constant variable: a11573 
o|substituted constant variable: a11575 
o|substituted constant variable: a11577 
o|substituted constant variable: a11579 
o|substituted constant variable: a11581 
o|substituted constant variable: a11583 
o|substituted constant variable: a11585 
o|substituted constant variable: a11587 
o|substituted constant variable: a11589 
o|substituted constant variable: a11591 
o|inlining procedure: k11610 
o|inlining procedure: k11610 
o|inlining procedure: k11675 
o|contracted procedure: "(scrutinizer.scm:810) g18861893" 
o|propagated global variable: out18961899 ##sys#standard-output 
o|substituted constant variable: a11643 
o|substituted constant variable: a11644 
o|propagated global variable: out18961899 ##sys#standard-output 
o|inlining procedure: k11675 
o|propagated global variable: g18921894 chicken.compiler.scrutinizer#specialization-statistics 
o|inlining procedure: "(scrutinizer.scm:804) chicken.compiler.scrutinizer#first" 
o|removed unused formal parameters: (where1937) 
o|inlining procedure: k11720 
o|inlining procedure: k11720 
o|inlining procedure: k11750 
o|inlining procedure: k11770 
o|inlining procedure: k11804 
o|inlining procedure: k11804 
o|inlining procedure: k11770 
o|inlining procedure: k11851 
o|inlining procedure: k11851 
o|inlining procedure: "(scrutinizer.scm:856) chicken.compiler.scrutinizer#third" 
o|substituted constant variable: a11889 
o|substituted constant variable: a11891 
o|substituted constant variable: a11896 
o|substituted constant variable: a11898 
o|substituted constant variable: a11900 
o|substituted constant variable: a11902 
o|inlining procedure: k11750 
o|inlining procedure: k11934 
o|inlining procedure: k11946 
o|inlining procedure: k11946 
o|inlining procedure: "(scrutinizer.scm:882) optargs?2046" 
o|inlining procedure: k11934 
o|inlining procedure: k11962 
o|inlining procedure: k11962 
o|inlining procedure: "(scrutinizer.scm:885) optargs?2046" 
o|inlining procedure: k11972 
o|inlining procedure: k11972 
o|inlining procedure: k11994 
o|removed unused parameter to known procedure: opt2076 "(scrutinizer.scm:891) match-rest2045" 
o|inlining procedure: k11994 
o|removed unused parameter to known procedure: opt2076 "(scrutinizer.scm:893) match-rest2045" 
o|inlining procedure: k12024 
o|inlining procedure: k12024 
o|removed unused formal parameters: (opt2076) 
o|contracted procedure: "(scrutinizer.scm:899) chicken.compiler.scrutinizer#span" 
o|inlining procedure: k6884 
o|inlining procedure: k6884 
o|inlining procedure: k12078 
o|inlining procedure: k12088 
o|inlining procedure: k12088 
o|inlining procedure: k12078 
o|inlining procedure: k12105 
o|inlining procedure: k12105 
o|substituted constant variable: a12115 
o|inlining procedure: k12122 
o|inlining procedure: k12122 
o|inlining procedure: k12134 
o|inlining procedure: k12134 
o|inlining procedure: k12152 
o|inlining procedure: k12152 
o|substituted constant variable: a12178 
o|substituted constant variable: a12183 
o|inlining procedure: k12218 
o|inlining procedure: k12218 
o|inlining procedure: k12251 
o|inlining procedure: k12251 
o|inlining procedure: k12262 
o|inlining procedure: k12277 
o|inlining procedure: k12277 
o|inlining procedure: "(scrutinizer.scm:941) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:940) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:939) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12262 
o|inlining procedure: k12306 
o|inlining procedure: k12306 
o|inlining procedure: k12318 
o|inlining procedure: k12318 
o|inlining procedure: "(scrutinizer.scm:951) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:950) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:949) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:948) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12343 
o|inlining procedure: k12343 
o|inlining procedure: "(scrutinizer.scm:953) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:952) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:938) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12394 
o|inlining procedure: k12409 
o|inlining procedure: k12409 
o|inlining procedure: "(scrutinizer.scm:964) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:963) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:962) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12394 
o|inlining procedure: "(scrutinizer.scm:966) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:965) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:961) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12389 
o|inlining procedure: k12389 
o|inlining procedure: k12470 
o|inlining procedure: k12470 
o|inlining procedure: k12485 
o|inlining procedure: k12485 
o|inlining procedure: k12500 
o|inlining procedure: k12500 
o|inlining procedure: k12520 
o|inlining procedure: k12520 
o|inlining procedure: k12569 
o|inlining procedure: k12569 
o|inlining procedure: k12629 
o|inlining procedure: k12629 
o|inlining procedure: "(scrutinizer.scm:1009) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k12661 
o|inlining procedure: "(scrutinizer.scm:1011) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k12661 
o|inlining procedure: k12680 
o|inlining procedure: k12680 
o|inlining procedure: k12691 
o|inlining procedure: k12703 
o|inlining procedure: k12703 
o|inlining procedure: k12691 
o|inlining procedure: k12720 
o|inlining procedure: k12720 
o|inlining procedure: k12737 
o|inlining procedure: k12737 
o|inlining procedure: k12763 
o|inlining procedure: k12763 
o|inlining procedure: k12799 
o|inlining procedure: k12799 
o|inlining procedure: "(scrutinizer.scm:1033) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1033) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12834 
o|inlining procedure: k12834 
o|inlining procedure: k12874 
o|contracted procedure: "(scrutinizer.scm:1040) chicken.compiler.scrutinizer#lset<=/eq?" 
o|inlining procedure: "(scrutinizer.scm:1040) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1040) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12874 
o|inlining procedure: "(scrutinizer.scm:1038) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1038) chicken.compiler.scrutinizer#third" 
o|substituted constant variable: a12906 
o|substituted constant variable: a12911 
o|substituted constant variable: a12913 
o|substituted constant variable: a12918 
o|substituted constant variable: a12920 
o|substituted constant variable: a12922 
o|substituted constant variable: a12924 
o|substituted constant variable: a12926 
o|inlining procedure: k12927 
o|inlining procedure: "(scrutinizer.scm:1043) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k12927 
o|inlining procedure: "(scrutinizer.scm:1045) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k12959 
o|inlining procedure: k12972 
o|inlining procedure: k12984 
o|inlining procedure: "(scrutinizer.scm:1052) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k12984 
o|inlining procedure: "(scrutinizer.scm:1051) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1051) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k12972 
o|inlining procedure: k13011 
o|inlining procedure: k13031 
o|inlining procedure: k13031 
o|inlining procedure: "(scrutinizer.scm:1056) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1055) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1055) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13011 
o|substituted constant variable: a13058 
o|substituted constant variable: a13060 
o|inlining procedure: k12959 
o|inlining procedure: k13067 
o|inlining procedure: k13080 
o|inlining procedure: "(scrutinizer.scm:1067) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1066) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1066) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13080 
o|inlining procedure: k13107 
o|inlining procedure: k13119 
o|inlining procedure: "(scrutinizer.scm:1074) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k13119 
o|inlining procedure: "(scrutinizer.scm:1070) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1070) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13107 
o|substituted constant variable: a13160 
o|substituted constant variable: a13162 
o|inlining procedure: k13067 
o|inlining procedure: k13163 
o|inlining procedure: k13175 
o|inlining procedure: "(scrutinizer.scm:1083) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13175 
o|inlining procedure: k13163 
o|inlining procedure: k13211 
o|inlining procedure: "(scrutinizer.scm:1090) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13211 
o|inlining procedure: k13239 
o|inlining procedure: k13251 
o|inlining procedure: "(scrutinizer.scm:1098) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13251 
o|inlining procedure: k13239 
o|inlining procedure: k13287 
o|inlining procedure: "(scrutinizer.scm:1105) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13287 
o|inlining procedure: k13382 
o|inlining procedure: k13382 
o|inlining procedure: k13504 
o|inlining procedure: k13504 
o|inlining procedure: k13522 
o|inlining procedure: k13522 
o|inlining procedure: k13544 
o|inlining procedure: k13544 
o|inlining procedure: k13579 
o|inlining procedure: "(scrutinizer.scm:1160) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k13617 
o|inlining procedure: k13617 
o|inlining procedure: k13654 
o|contracted procedure: "(scrutinizer.scm:1149) g24412450" 
o|contracted procedure: "(scrutinizer.scm:1151) chicken.compiler.scrutinizer#make-tv" 
o|substituted constant variable: a15972 
o|inlining procedure: "(scrutinizer.scm:1150) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k13654 
o|inlining procedure: "(scrutinizer.scm:1147) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k13685 
o|inlining procedure: k13700 
o|inlining procedure: k13700 
o|inlining procedure: k13716 
o|inlining procedure: k13741 
o|contracted procedure: "(scrutinizer.scm:1171) g25182519" 
o|contracted procedure: "(scrutinizer.scm:1183) chicken.compiler.scrutinizer#merge-result-types" 
o|inlining procedure: k14720 
o|inlining procedure: k14720 
o|inlining procedure: k13800 
o|inlining procedure: k13800 
o|inlining procedure: k13741 
o|inlining procedure: k13716 
o|inlining procedure: k13825 
o|inlining procedure: k13825 
o|inlining procedure: k13843 
o|inlining procedure: k13843 
o|inlining procedure: k13861 
o|inlining procedure: k13861 
o|inlining procedure: k13879 
o|inlining procedure: k13879 
o|inlining procedure: k13944 
o|inlining procedure: k13944 
o|inlining procedure: k13962 
o|inlining procedure: k13962 
o|consed rest parameter at call site: "(scrutinizer.scm:1190) chicken.compiler.scrutinizer#append-map" 3 
o|substituted constant variable: a13986 
o|inlining procedure: k14005 
o|inlining procedure: k14005 
o|inlining procedure: k13685 
o|inlining procedure: k14048 
o|inlining procedure: k14048 
o|inlining procedure: "(scrutinizer.scm:1215) chicken.compiler.scrutinizer#third" 
o|contracted procedure: "(scrutinizer.scm:1215) chicken.compiler.scrutinizer#lset-union/eq?" 
o|inlining procedure: k7740 
o|contracted procedure: "(mini-srfi-1.scm:171) g476477" 
o|inlining procedure: k7765 
o|contracted procedure: "(mini-srfi-1.scm:173) g492493" 
o|inlining procedure: k7781 
o|inlining procedure: k7781 
o|inlining procedure: k7765 
o|inlining procedure: k7740 
o|inlining procedure: "(scrutinizer.scm:1215) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1212) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1211) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k14086 
o|inlining procedure: "(scrutinizer.scm:1220) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1219) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k14086 
o|inlining procedure: k14134 
o|inlining procedure: k14134 
o|inlining procedure: "(scrutinizer.scm:1226) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k14149 
o|inlining procedure: "(scrutinizer.scm:1231) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k14149 
o|inlining procedure: k14179 
o|inlining procedure: k14179 
o|inlining procedure: k14202 
o|inlining procedure: k14202 
o|inlining procedure: k14235 
o|inlining procedure: k14258 
o|inlining procedure: k14258 
o|inlining procedure: k14235 
o|inlining procedure: k14313 
o|inlining procedure: k14313 
o|inlining procedure: k14331 
o|inlining procedure: k14331 
o|inlining procedure: k14378 
o|inlining procedure: k14378 
o|inlining procedure: "(scrutinizer.scm:1247) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1247) chicken.compiler.scrutinizer#second" 
o|substituted constant variable: a14431 
o|substituted constant variable: a14433 
o|substituted constant variable: a14435 
o|substituted constant variable: a14437 
o|substituted constant variable: a14439 
o|substituted constant variable: a14441 
o|substituted constant variable: a14443 
o|substituted constant variable: a14445 
o|substituted constant variable: a14447 
o|inlining procedure: k13579 
o|contracted procedure: "(scrutinizer.scm:1254) chicken.compiler.scrutinizer#lset-adjoin/eq?" 
o|inlining procedure: k7654 
o|inlining procedure: k7654 
o|inlining procedure: k14469 
o|inlining procedure: k14489 
o|inlining procedure: k14489 
o|inlining procedure: k14469 
o|inlining procedure: k14527 
o|substituted constant variable: chicken.compiler.scrutinizer#constant757 
o|inlining procedure: k14527 
o|inlining procedure: k14539 
o|substituted constant variable: a14558 
o|inlining procedure: k14551 
o|inlining procedure: k14551 
o|inlining procedure: k14539 
o|inlining procedure: k14565 
o|inlining procedure: k14565 
o|inlining procedure: k14616 
o|inlining procedure: k14616 
o|substituted constant variable: a14672 
o|inlining procedure: k14665 
o|inlining procedure: k14665 
o|merged explicitly consed rest parameter: rest27882791 
o|inlining procedure: k14783 
o|inlining procedure: k14783 
o|contracted procedure: "(scrutinizer.scm:1325) chicken.compiler.scrutinizer#with-trail-restore" 
o|inlining procedure: k15170 
o|inlining procedure: k15170 
o|contracted procedure: "(scrutinizer.scm:1368) refine2842" 
o|inlining procedure: k14876 
o|inlining procedure: k14876 
o|inlining procedure: k14901 
o|inlining procedure: "(scrutinizer.scm:1345) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1344) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k14901 
o|inlining procedure: k14937 
o|inlining procedure: "(scrutinizer.scm:1348) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k14937 
o|inlining procedure: "(scrutinizer.scm:1347) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k14955 
o|inlining procedure: k14955 
o|inlining procedure: k14970 
o|inlining procedure: k14970 
o|inlining procedure: k14989 
o|inlining procedure: k15027 
o|inlining procedure: k15027 
o|inlining procedure: k14989 
o|contracted procedure: "(scrutinizer.scm:1365) chicken.compiler.scrutinizer#type-min" 
o|inlining procedure: k14808 
o|inlining procedure: k14808 
o|substituted constant variable: a15083 
o|inlining procedure: k15078 
o|inlining procedure: k15090 
o|inlining procedure: k15090 
o|inlining procedure: k15078 
o|inlining procedure: k15122 
o|inlining procedure: k15134 
o|inlining procedure: k15134 
o|inlining procedure: k15122 
o|substituted constant variable: a15154 
o|substituted constant variable: a15160 
o|inlining procedure: k15189 
o|inlining procedure: k15189 
o|inlining procedure: k15199 
o|inlining procedure: "(scrutinizer.scm:1379) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15199 
o|inlining procedure: k15218 
o|inlining procedure: k15218 
o|substituted constant variable: a15230 
o|substituted constant variable: a15232 
o|substituted constant variable: a15234 
o|inlining procedure: k15238 
o|inlining procedure: "(scrutinizer.scm:1387) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15258 
o|inlining procedure: k15276 
o|inlining procedure: k15276 
o|inlining procedure: k15258 
o|substituted constant variable: a15283 
o|substituted constant variable: a15285 
o|inlining procedure: k15238 
o|inlining procedure: k15289 
o|inlining procedure: "(scrutinizer.scm:1398) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15309 
o|inlining procedure: "(scrutinizer.scm:1402) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1403) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1400) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k15309 
o|substituted constant variable: a15340 
o|substituted constant variable: a15342 
o|inlining procedure: k15289 
o|inlining procedure: k15346 
o|inlining procedure: "(scrutinizer.scm:1409) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15366 
o|inlining procedure: "(scrutinizer.scm:1411) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k15366 
o|substituted constant variable: a15397 
o|substituted constant variable: a15399 
o|inlining procedure: k15346 
o|merged explicitly consed rest parameter: rest29932997 
o|inlining procedure: k15412 
o|inlining procedure: k15431 
o|inlining procedure: k15431 
o|inlining procedure: k15448 
o|inlining procedure: k15448 
o|inlining procedure: k15456 
o|consed rest parameter at call site: "(scrutinizer.scm:1442) chicken.compiler.scrutinizer#make-list" 2 
o|inlining procedure: k15456 
o|inlining procedure: "(scrutinizer.scm:1427) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1428) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1426) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1426) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k15412 
o|inlining procedure: "(scrutinizer.scm:1450) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15569 
o|inlining procedure: k15569 
o|inlining procedure: "(scrutinizer.scm:1453) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k15561 
o|inlining procedure: k15561 
o|consed rest parameter at call site: "(scrutinizer.scm:1457) chicken.compiler.scrutinizer#make-list" 2 
o|inlining procedure: k15754 
o|inlining procedure: k15774 
o|inlining procedure: k15774 
o|inlining procedure: k15787 
o|inlining procedure: "(scrutinizer.scm:1482) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15787 
o|substituted constant variable: a15801 
o|substituted constant variable: a15803 
o|inlining procedure: k15754 
o|inlining procedure: k15807 
o|inlining procedure: k15807 
o|inlining procedure: k15827 
o|inlining procedure: k15840 
o|inlining procedure: k15850 
o|inlining procedure: k15850 
o|inlining procedure: "(scrutinizer.scm:1496) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k15840 
o|inlining procedure: k15866 
o|inlining procedure: "(scrutinizer.scm:1500) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15866 
o|substituted constant variable: a15880 
o|substituted constant variable: a15882 
o|inlining procedure: k15827 
o|inlining procedure: k15889 
o|inlining procedure: k15889 
o|inlining procedure: k15899 
o|inlining procedure: k15899 
o|inlining procedure: "(scrutinizer.scm:1508) chicken.compiler.scrutinizer#third" 
o|substituted constant variable: a15924 
o|substituted constant variable: a15926 
o|inlining procedure: k15930 
o|inlining procedure: k15945 
o|inlining procedure: "(scrutinizer.scm:1517) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k15945 
o|substituted constant variable: a15959 
o|substituted constant variable: a15961 
o|inlining procedure: "(scrutinizer.scm:1515) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k15930 
o|inlining procedure: k15983 
o|inlining procedure: "(scrutinizer.scm:1535) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k16003 
o|inlining procedure: k16027 
o|inlining procedure: k16045 
o|inlining procedure: k16045 
o|inlining procedure: k16027 
o|inlining procedure: k16072 
o|inlining procedure: k16072 
o|inlining procedure: "(scrutinizer.scm:1538) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k16101 
o|inlining procedure: k16118 
o|inlining procedure: k16118 
o|inlining procedure: k16101 
o|inlining procedure: k16145 
o|inlining procedure: k16145 
o|inlining procedure: "(scrutinizer.scm:1542) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1537) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1537) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k16003 
o|inlining procedure: "(scrutinizer.scm:1552) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k16231 
o|contracted procedure: "(scrutinizer.scm:1546) g32283237" 
o|inlining procedure: k16199 
o|inlining procedure: k16199 
o|inlining procedure: "(scrutinizer.scm:1549) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1549) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k16231 
o|inlining procedure: "(scrutinizer.scm:1550) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k16262 
o|inlining procedure: k16278 
o|inlining procedure: k16278 
o|inlining procedure: k16262 
o|substituted constant variable: a16299 
o|substituted constant variable: a16301 
o|substituted constant variable: a16303 
o|substituted constant variable: a16305 
o|inlining procedure: k15983 
o|inlining procedure: k16315 
o|inlining procedure: k16315 
o|inlining procedure: k16373 
o|inlining procedure: "(scrutinizer.scm:1578) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1577) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k16373 
o|inlining procedure: "(scrutinizer.scm:1574) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k16365 
o|inlining procedure: k16365 
o|inlining procedure: k16418 
o|inlining procedure: k16418 
o|inlining procedure: k16436 
o|inlining procedure: k16464 
o|inlining procedure: k16464 
o|inlining procedure: k16436 
o|inlining procedure: "(scrutinizer.scm:1588) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k16512 
o|inlining procedure: "(scrutinizer.scm:1590) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1590) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k16512 
o|inlining procedure: k16571 
o|inlining procedure: k16571 
o|inlining procedure: k16602 
o|inlining procedure: k16637 
o|inlining procedure: k16637 
o|inlining procedure: k16660 
o|inlining procedure: k16660 
o|inlining procedure: k16694 
o|inlining procedure: k16694 
o|inlining procedure: k16706 
o|inlining procedure: k16706 
o|inlining procedure: k16725 
o|inlining procedure: k16725 
o|inlining procedure: k16602 
o|substituted constant variable: a16767 
o|inlining procedure: k16771 
o|inlining procedure: k16771 
o|inlining procedure: k16783 
o|inlining procedure: k16783 
o|substituted constant variable: a16790 
o|substituted constant variable: a16792 
o|substituted constant variable: a16794 
o|substituted constant variable: a16796 
o|substituted constant variable: a16798 
o|substituted constant variable: a16803 
o|substituted constant variable: a16805 
o|substituted constant variable: a16807 
o|substituted constant variable: a16809 
o|inlining procedure: k16823 
o|inlining procedure: k17145 
o|contracted procedure: "(scrutinizer.scm:1623) g34863493" 
o|inlining procedure: k16878 
o|inlining procedure: k16878 
o|consed rest parameter at call site: "(scrutinizer.scm:1668) chicken.compiler.scrutinizer#compatible-types?" 3 
o|substituted constant variable: a16921 
o|substituted constant variable: a16922 
o|inlining procedure: k16954 
o|inlining procedure: k16981 
o|inlining procedure: k16981 
o|inlining procedure: k17004 
o|inlining procedure: k17004 
o|inlining procedure: k17032 
o|inlining procedure: k17032 
o|substituted constant variable: a17072 
o|substituted constant variable: a17074 
o|substituted constant variable: a17076 
o|substituted constant variable: a17078 
o|substituted constant variable: a17080 
o|inlining procedure: k17087 
o|inlining procedure: "(scrutinizer.scm:1657) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1657) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k17087 
o|inlining procedure: k16954 
o|inlining procedure: k17145 
o|substituted constant variable: a17175 
o|substituted constant variable: a17176 
o|inlining procedure: k16823 
o|inlining procedure: k17195 
o|inlining procedure: k17195 
o|inlining procedure: k17306 
o|contracted procedure: "(scrutinizer.scm:1720) chicken.compiler.scrutinizer#cons*" 
o|inlining procedure: k7259 
o|inlining procedure: k7259 
o|inlining procedure: k17353 
o|inlining procedure: k17412 
o|inlining procedure: k17412 
o|inlining procedure: k17418 
o|inlining procedure: "(scrutinizer.scm:1733) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1733) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k17418 
o|substituted constant variable: a17440 
o|substituted constant variable: a17442 
o|inlining procedure: k17353 
o|inlining procedure: k17306 
o|substituted constant variable: a17450 
o|inlining procedure: k17466 
o|inlining procedure: k17466 
o|contracted procedure: "(scrutinizer.scm:1739) chicken.compiler.scrutinizer#symbol<?" 
o|contracted procedure: "(scrutinizer.scm:1738) chicken.compiler.scrutinizer#hash-table->list" 
o|inlining procedure: k17225 
o|inlining procedure: k17225 
o|inlining procedure: k17241 
o|inlining procedure: k17241 
o|merged explicitly consed rest parameter: rest36563658 
o|inlining procedure: k17536 
o|inlining procedure: k17536 
o|consed rest parameter at call site: "(scrutinizer.scm:1760) chicken.compiler.scrutinizer#source-node" 2 
o|inlining procedure: k17590 
o|inlining procedure: k17590 
o|consed rest parameter at call site: "(scrutinizer.scm:1763) chicken.compiler.scrutinizer#source-node" 2 
o|inlining procedure: k17695 
o|inlining procedure: k17708 
o|inlining procedure: k17708 
o|inlining procedure: k17723 
o|inlining procedure: k17723 
o|inlining procedure: k17695 
o|inlining procedure: k17759 
o|inlining procedure: k17759 
o|inlining procedure: k17797 
o|inlining procedure: k17797 
o|substituted constant variable: a17817 
o|substituted constant variable: a17829 
o|inlining procedure: k17882 
o|inlining procedure: k17882 
o|inlining procedure: k17910 
o|inlining procedure: k17910 
o|inlining procedure: k17922 
o|inlining procedure: k17922 
o|inlining procedure: k17940 
o|inlining procedure: k17940 
o|inlining procedure: k17948 
o|inlining procedure: k17963 
o|inlining procedure: k17963 
o|inlining procedure: k17948 
o|inlining procedure: k18002 
o|inlining procedure: k18002 
o|inlining procedure: k18043 
o|inlining procedure: k18043 
o|inlining procedure: k18055 
o|inlining procedure: k18055 
o|inlining procedure: k18070 
o|inlining procedure: k18070 
o|inlining procedure: k18082 
o|inlining procedure: k18082 
o|inlining procedure: k18097 
o|inlining procedure: k18097 
o|inlining procedure: k18106 
o|inlining procedure: k18106 
o|inlining procedure: k18112 
o|inlining procedure: "(scrutinizer.scm:1876) chicken.compiler.scrutinizer#second" 
o|substituted constant variable: a18135 
o|inlining procedure: k18112 
o|inlining procedure: k18146 
o|inlining procedure: "(scrutinizer.scm:1902) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k18186 
o|inlining procedure: k18201 
o|inlining procedure: k18201 
o|inlining procedure: k18186 
o|inlining procedure: "(scrutinizer.scm:1900) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k18221 
o|inlining procedure: k18221 
o|inlining procedure: k18242 
o|inlining procedure: k18242 
o|substituted constant variable: a18255 
o|inlining procedure: k18270 
o|inlining procedure: k18270 
o|inlining procedure: "(scrutinizer.scm:1890) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1879) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k18146 
o|substituted constant variable: a18305 
o|inlining procedure: k18318 
o|inlining procedure: k18318 
o|inlining procedure: k18313 
o|inlining procedure: k18313 
o|inlining procedure: k18337 
o|inlining procedure: k18361 
o|inlining procedure: k18361 
o|inlining procedure: k18373 
o|inlining procedure: k18373 
o|inlining procedure: k18337 
o|inlining procedure: k18412 
o|inlining procedure: k18424 
o|inlining procedure: k18424 
o|inlining procedure: "(scrutinizer.scm:1919) chicken.compiler.scrutinizer#second" 
o|substituted constant variable: a18434 
o|inlining procedure: k18412 
o|inlining procedure: k18445 
o|inlining procedure: "(scrutinizer.scm:1921) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k18445 
o|substituted constant variable: a18461 
o|inlining procedure: k18466 
o|inlining procedure: k18481 
o|inlining procedure: k18517 
o|inlining procedure: "(scrutinizer.scm:1928) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k18517 
o|inlining procedure: "(scrutinizer.scm:1927) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:1926) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k18481 
o|contracted procedure: "(scrutinizer.scm:1925) g39183919" 
o|inlining procedure: k18502 
o|inlining procedure: k18502 
o|contracted procedure: "(scrutinizer.scm:161) g39243925" 
o|inlining procedure: k18488 
o|inlining procedure: k18488 
o|inlining procedure: "(scrutinizer.scm:1924) chicken.compiler.scrutinizer#third" 
o|substituted constant variable: a18542 
o|inlining procedure: k18466 
o|inlining procedure: k18573 
o|contracted procedure: "(scrutinizer.scm:1938) upto3748" 
o|inlining procedure: k17854 
o|inlining procedure: k17854 
o|inlining procedure: k18573 
o|inlining procedure: k18613 
o|inlining procedure: k18613 
o|inlining procedure: "(scrutinizer.scm:1943) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:1943) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k18643 
o|inlining procedure: k18643 
o|substituted constant variable: a18660 
o|substituted constant variable: a18683 
o|inlining procedure: k18676 
o|inlining procedure: k18690 
o|inlining procedure: "(scrutinizer.scm:1952) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k18690 
o|substituted constant variable: a18713 
o|inlining procedure: k18676 
o|substituted constant variable: a18725 
o|inlining procedure: k18726 
o|inlining procedure: k18742 
o|inlining procedure: k18742 
o|inlining procedure: k18726 
o|inlining procedure: k18785 
o|inlining procedure: k18809 
o|inlining procedure: k18809 
o|inlining procedure: k18821 
o|inlining procedure: k18821 
o|substituted constant variable: a18852 
o|inlining procedure: k18785 
o|inlining procedure: k18863 
o|inlining procedure: k18881 
o|inlining procedure: k18893 
o|inlining procedure: k18933 
o|inlining procedure: k18954 
o|inlining procedure: k18954 
o|inlining procedure: k18933 
o|inlining procedure: k18893 
o|inlining procedure: k18881 
o|inlining procedure: k18863 
o|inlining procedure: k19046 
o|inlining procedure: k19058 
o|inlining procedure: "(scrutinizer.scm:1907) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k19058 
o|inlining procedure: "(scrutinizer.scm:1905) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k19046 
o|substituted constant variable: chicken.compiler.scrutinizer#constant748 
o|inlining procedure: k19125 
o|inlining procedure: k19125 
o|inlining procedure: k19160 
o|inlining procedure: k19160 
o|inlining procedure: k19186 
o|inlining procedure: k19186 
o|inlining procedure: k19110 
o|inlining procedure: k19110 
o|inlining procedure: k19245 
o|inlining procedure: k19245 
o|inlining procedure: k19298 
o|inlining procedure: k19298 
o|inlining procedure: k19275 
o|inlining procedure: k19323 
o|inlining procedure: k19323 
o|inlining procedure: k19338 
o|inlining procedure: k19365 
o|inlining procedure: k19365 
o|inlining procedure: k19387 
o|inlining procedure: k19387 
o|inlining procedure: "(scrutinizer.scm:2049) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k19338 
o|inlining procedure: "(scrutinizer.scm:2051) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:2042) chicken.compiler.scrutinizer#second" 
o|substituted constant variable: a19442 
o|substituted constant variable: a19444 
o|consed rest parameter at call site: "(scrutinizer.scm:2036) chicken.compiler.scrutinizer#append-map" 3 
o|inlining procedure: k19452 
o|inlining procedure: k19452 
o|inlining procedure: "(scrutinizer.scm:2035) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k19275 
o|inlining procedure: "(scrutinizer.scm:2028) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k19505 
o|inlining procedure: k19505 
o|inlining procedure: k19539 
o|inlining procedure: k19539 
o|inlining procedure: k19567 
o|inlining procedure: k19567 
o|inlining procedure: "(scrutinizer.scm:2072) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:2072) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k19601 
o|inlining procedure: k19601 
o|inlining procedure: "(scrutinizer.scm:2073) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:2071) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:2067) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:2066) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k19665 
o|inlining procedure: k19665 
o|inlining procedure: k19706 
o|inlining procedure: k19718 
o|inlining procedure: k19730 
o|inlining procedure: k19742 
o|inlining procedure: k19754 
o|inlining procedure: k19754 
o|inlining procedure: "(scrutinizer.scm:2122) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k19742 
o|inlining procedure: "(scrutinizer.scm:2120) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k19730 
o|inlining procedure: k19718 
o|inlining procedure: "(scrutinizer.scm:2117) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k19706 
o|inlining procedure: k19808 
o|inlining procedure: k19808 
o|inlining procedure: k19814 
o|inlining procedure: "(scrutinizer.scm:2136) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k19814 
o|inlining procedure: "(scrutinizer.scm:2135) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k19865 
o|inlining procedure: k19865 
o|inlining procedure: k19877 
o|inlining procedure: k19889 
o|inlining procedure: k19889 
o|inlining procedure: k19877 
o|inlining procedure: k19904 
o|contracted procedure: "(scrutinizer.scm:2179) chicken.compiler.scrutinizer#split-at" 
o|inlining procedure: k6986 
o|inlining procedure: k6986 
o|inlining procedure: k19904 
o|inlining procedure: k19941 
o|inlining procedure: k19953 
o|inlining procedure: k19953 
o|inlining procedure: "(scrutinizer.scm:2189) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:2188) chicken.compiler.scrutinizer#second" 
o|inlining procedure: "(scrutinizer.scm:2187) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k19941 
o|inlining procedure: "(scrutinizer.scm:2182) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:2177) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k20056 
o|inlining procedure: k20056 
o|inlining procedure: k20062 
o|inlining procedure: k20074 
o|inlining procedure: k20086 
o|inlining procedure: k20095 
o|inlining procedure: k20095 
o|inlining procedure: k20111 
o|inlining procedure: k20111 
o|contracted procedure: "(scrutinizer.scm:2216) proper-list-type-length4430" 
o|inlining procedure: k20018 
o|inlining procedure: k20018 
o|inlining procedure: k20086 
o|inlining procedure: "(scrutinizer.scm:2208) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k20074 
o|inlining procedure: "(scrutinizer.scm:2206) chicken.compiler.scrutinizer#third" 
o|inlining procedure: "(scrutinizer.scm:2205) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k20062 
o|substituted constant variable: a20138 
o|inlining procedure: k20182 
o|inlining procedure: k20182 
o|inlining procedure: k20203 
o|inlining procedure: k20219 
o|contracted procedure: "(scrutinizer.scm:2280) g47084709" 
o|inlining procedure: k20219 
o|inlining procedure: k20203 
o|inlining procedure: k20253 
o|inlining procedure: k20253 
o|contracted procedure: "(scrutinizer.scm:2295) potentially-proper-list?4682" 
o|inlining procedure: k20316 
o|inlining procedure: k20316 
o|inlining procedure: k20438 
o|removed side-effect free assignment to unused variable: anyinst4774 
o|inlining procedure: k20438 
o|inlining procedure: k20514 
o|inlining procedure: k20514 
o|inlining procedure: k20535 
o|inlining procedure: k20535 
o|contracted procedure: "(scrutinizer.scm:2359) chicken.compiler.scrutinizer#concatenate" 
o|inlining procedure: k7287 
o|inlining procedure: k7287 
o|inlining procedure: k20583 
o|inlining procedure: k20583 
o|inlining procedure: k20627 
o|inlining procedure: k20684 
o|inlining procedure: k20684 
o|inlining procedure: k20627 
o|inlining procedure: k20721 
o|inlining procedure: k20721 
o|inlining procedure: k20742 
o|inlining procedure: k20742 
o|merged explicitly consed rest parameter: rest49074909 
o|inlining procedure: k20760 
o|substituted constant variable: a20770 
o|inlining procedure: k20760 
o|inlining procedure: k20787 
o|inlining procedure: k20787 
o|inlining procedure: k20802 
o|inlining procedure: k20802 
o|merged explicitly consed rest parameter: rest49564958 
o|consed rest parameter at call site: "(scrutinizer.scm:2422) conv4947" 2 
o|inlining procedure: k20877 
o|inlining procedure: k20877 
o|substituted constant variable: a20903 
o|substituted constant variable: a20904 
o|inlining procedure: "(scrutinizer.scm:2428) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k20941 
o|inlining procedure: k20941 
o|inlining procedure: "(scrutinizer.scm:2428) chicken.compiler.scrutinizer#second" 
o|contracted procedure: "(scrutinizer.scm:2433) pp-tv4946" 
o|inlining procedure: k20975 
o|consed rest parameter at call site: "(scrutinizer.scm:2434) conv4947" 2 
o|inlining procedure: "(scrutinizer.scm:2434) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k21012 
o|inlining procedure: k21012 
o|inlining procedure: "(scrutinizer.scm:2433) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k20975 
o|substituted constant variable: a21053 
o|inlining procedure: k21049 
o|inlining procedure: k21073 
o|inlining procedure: k21073 
o|inlining procedure: k21049 
o|inlining procedure: k21110 
o|inlining procedure: k21148 
o|inlining procedure: k21148 
o|inlining procedure: k21159 
o|inlining procedure: k21159 
o|inlining procedure: k21171 
o|inlining procedure: k21171 
o|inlining procedure: k21189 
o|inlining procedure: k21189 
o|inlining procedure: k21223 
o|inlining procedure: k21223 
o|inlining procedure: k21110 
o|inlining procedure: "(scrutinizer.scm:2432) chicken.compiler.scrutinizer#second" 
o|consed rest parameter at call site: "(scrutinizer.scm:2453) chicken.compiler.scrutinizer#string-add-indent" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:2452) conv4947" 2 
o|inlining procedure: k21317 
o|inlining procedure: k21317 
o|inlining procedure: k21332 
o|inlining procedure: k21360 
o|inlining procedure: k21360 
o|substituted constant variable: a21401 
o|inlining procedure: k21332 
o|consed rest parameter at call site: "(scrutinizer.scm:2472) chicken.compiler.scrutinizer#string-add-indent" 2 
o|inlining procedure: k21440 
o|substituted constant variable: a21450 
o|substituted constant variable: a21451 
o|inlining procedure: k21440 
o|contracted procedure: "(scrutinizer.scm:2479) chicken.compiler.scrutinizer#node-line-number" 
o|contracted procedure: "(scrutinizer.scm:1771) chicken.compiler.scrutinizer#node-debug-info" 
o|inlining procedure: k17637 
o|inlining procedure: k17652 
o|inlining procedure: k17652 
o|inlining procedure: k17637 
o|substituted constant variable: a17686 
o|substituted constant variable: a17688 
o|consed rest parameter at call site: "(scrutinizer.scm:1771) chicken.compiler.scrutinizer#source-node" 2 
o|merged explicitly consed rest parameter: rest52195221 
o|inlining procedure: k21498 
o|inlining procedure: k21498 
o|inlining procedure: k21517 
o|inlining procedure: k21535 
o|substituted constant variable: a21571 
o|substituted constant variable: a21572 
o|substituted constant variable: a21589 
o|substituted constant variable: a21590 
o|inlining procedure: k21535 
o|inlining procedure: k21517 
o|contracted procedure: "(scrutinizer.scm:2503) lname5227" 
o|substituted constant variable: a21480 
o|substituted constant variable: a21481 
o|inlining procedure: k21473 
o|inlining procedure: k21473 
o|inlining procedure: k21643 
o|inlining procedure: "(scrutinizer.scm:2509) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:2509) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k21643 
o|substituted constant variable: a21707 
o|substituted constant variable: a21708 
o|inlining procedure: k21700 
o|substituted constant variable: a21731 
o|substituted constant variable: a21732 
o|inlining procedure: k21700 
o|inlining procedure: k21768 
o|inlining procedure: k21768 
o|inlining procedure: "(scrutinizer.scm:2538) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k21804 
o|inlining procedure: k21816 
o|inlining procedure: k21816 
o|inlining procedure: k21804 
o|inlining procedure: "(scrutinizer.scm:2524) chicken.compiler.scrutinizer#first" 
o|inlining procedure: "(scrutinizer.scm:2543) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k21887 
o|inlining procedure: k21887 
o|substituted constant variable: a21897 
o|inlining procedure: k21902 
o|consed rest parameter at call site: "(scrutinizer.scm:2554) chicken.compiler.scrutinizer#string-add-indent" 2 
o|substituted constant variable: a21939 
o|substituted constant variable: a21940 
o|consed rest parameter at call site: "(scrutinizer.scm:2556) chicken.compiler.scrutinizer#location-name" 2 
o|inlining procedure: k21902 
o|merged explicitly consed rest parameter: args5369 
o|substituted constant variable: a22193 
o|substituted constant variable: a22194 
o|inlining procedure: k22211 
o|inlining procedure: k22211 
o|substituted constant variable: a22228 
o|substituted constant variable: a22229 
o|substituted constant variable: a22287 
o|substituted constant variable: a22288 
o|substituted constant variable: a22305 
o|substituted constant variable: a22306 
o|substituted constant variable: a22336 
o|substituted constant variable: a22337 
o|substituted constant variable: a22354 
o|substituted constant variable: a22355 
o|inlining procedure: k22405 
o|inlining procedure: k22405 
o|substituted constant variable: a22422 
o|substituted constant variable: a22423 
o|inlining procedure: k22471 
o|substituted constant variable: a22485 
o|substituted constant variable: a22486 
o|inlining procedure: k22471 
o|substituted constant variable: a22511 
o|substituted constant variable: a22512 
o|substituted constant variable: a22536 
o|substituted constant variable: a22537 
o|inlining procedure: k22591 
o|substituted constant variable: a22605 
o|substituted constant variable: a22606 
o|inlining procedure: k22591 
o|substituted constant variable: a22631 
o|substituted constant variable: a22632 
o|substituted constant variable: a22656 
o|substituted constant variable: a22657 
o|merged explicitly consed rest parameter: rest57045708 
o|substituted constant variable: a23067 
o|substituted constant variable: a23068 
o|substituted constant variable: a23105 
o|substituted constant variable: a23106 
o|contracted procedure: "(scrutinizer.scm:2328) complex-object-constructor-result-type-special-case4735" 
o|inlining procedure: k20339 
o|inlining procedure: k20339 
o|inlining procedure: k20348 
o|inlining procedure: k20360 
o|inlining procedure: k20372 
o|consed rest parameter at call site: "(scrutinizer.scm:2324) chicken.compiler.scrutinizer#make-list" 2 
o|inlining procedure: k20372 
o|inlining procedure: "(scrutinizer.scm:2321) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k20360 
o|inlining procedure: "(scrutinizer.scm:2319) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k20348 
o|inlining procedure: k20403 
o|inlining procedure: "(scrutinizer.scm:2317) chicken.compiler.scrutinizer#third" 
o|inlining procedure: k20403 
o|substituted constant variable: a20417 
o|substituted constant variable: a20419 
o|inlining procedure: k23152 
o|inlining procedure: k23152 
o|inlining procedure: k23158 
o|inlining procedure: k23170 
o|inlining procedure: k23170 
o|inlining procedure: "(scrutinizer.scm:2257) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k23158 
o|substituted constant variable: a23204 
o|inlining procedure: k23231 
o|inlining procedure: k23231 
o|inlining procedure: k23288 
o|inlining procedure: k23288 
o|inlining procedure: k23322 
o|inlining procedure: k23322 
o|inlining procedure: k23349 
o|inlining procedure: k23349 
o|inlining procedure: k23387 
o|inlining procedure: k23387 
o|inlining procedure: k23414 
o|inlining procedure: k23414 
o|inlining procedure: k23466 
o|inlining procedure: k23466 
o|inlining procedure: k23488 
o|inlining procedure: k23488 
o|inlining procedure: k23494 
o|inlining procedure: k23506 
o|inlining procedure: "(scrutinizer.scm:2150) chicken.compiler.scrutinizer#fourth" 
o|inlining procedure: k23506 
o|inlining procedure: "(scrutinizer.scm:2149) chicken.compiler.scrutinizer#fourth" 
o|inlining procedure: "(scrutinizer.scm:2148) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k23494 
o|inlining procedure: k23545 
o|inlining procedure: k23545 
o|inlining procedure: k23551 
o|inlining procedure: k23563 
o|inlining procedure: k23575 
o|inlining procedure: k23575 
o|inlining procedure: "(scrutinizer.scm:2104) chicken.compiler.scrutinizer#first" 
o|inlining procedure: k23563 
o|inlining procedure: "(scrutinizer.scm:2102) chicken.compiler.scrutinizer#second" 
o|inlining procedure: k23551 
o|substituted constant variable: a23607 
o|simplifications: ((if . 10)) 
o|replaced variables: 4808 
o|removed binding forms: 911 
o|substituted constant variable: r692923608 
o|substituted constant variable: r703523612 
o|substituted constant variable: r707523614 
o|substituted constant variable: r723023622 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#first 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#second 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#third 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#fourth 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#filter 
o|substituted constant variable: r748323635 
o|substituted constant variable: r783823638 
o|substituted constant variable: r787423641 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#d 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#constant748 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#constant757 
o|substituted constant variable: r817223656 
o|substituted constant variable: r823423659 
o|substituted constant variable: r824623661 
o|substituted constant variable: r826123663 
o|substituted constant variable: r827323665 
o|substituted constant variable: r828523667 
o|substituted constant variable: r829723669 
o|substituted constant variable: r829723670 
o|substituted constant variable: r830023671 
o|substituted constant variable: r838723677 
o|substituted constant variable: r853223684 
o|substituted constant variable: r854123686 
o|substituted constant variable: r795123687 
o|substituted constant variable: r858323692 
o|substituted constant variable: r849023695 
o|substituted constant variable: r848523698 
o|substituted constant variable: r860723700 
o|substituted constant variable: r868823716 
o|substituted constant variable: r868823717 
o|substituted constant variable: r870923718 
o|substituted constant variable: r872723720 
o|removed side-effect free assignment to unused variable: add-loc812 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:409) chicken.base#void" 
o|substituted constant variable: r893023741 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:397) chicken.base#void" 
o|substituted constant variable: r917823773 
o|substituted constant variable: r875823775 
o|substituted constant variable: r876923778 
o|substituted constant variable: r876923778 
o|substituted constant variable: r926823781 
o|substituted constant variable: r1567023790 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:312) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:423) chicken.base#void" 
o|substituted constant variable: r953423820 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:801) chicken.base#void" 
o|substituted constant variable: r959823833 
o|substituted constant variable: r975323855 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:504) chicken.base#void" 
o|substituted constant variable: r984323862 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:491) chicken.base#void" 
o|substituted constant variable: r994523868 
o|substituted constant variable: r870023871 
o|substituted constant variable: r870023872 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:569) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:536) chicken.base#void" 
o|substituted constant variable: r1035523908 
o|substituted constant variable: r1035523908 
o|substituted constant variable: r1035523910 
o|substituted constant variable: r1035523910 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:661) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:648) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:654) chicken.base#void" 
o|substituted constant variable: r1052623938 
o|substituted constant variable: r1062023940 
o|inlining procedure: k10679 
o|substituted constant variable: r1065723955 
o|substituted constant variable: r1072323971 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:735) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:723) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:743) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:754) chicken.base#void" 
o|substituted constant variable: r1105423993 
o|converted assignments to bindings: (smash1686) 
o|inlining procedure: k11327 
o|inlining procedure: k11327 
o|converted assignments to bindings: (pp-type5656) 
o|substituted constant variable: r1150024069 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:441) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:820) chicken.base#void" 
o|propagated global variable: out18961899 ##sys#standard-output 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:179) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:839) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:843) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:848) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:852) chicken.base#void" 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#ble-id 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#ble-tag 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#ble-type 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#ble-type-set! 
o|substituted constant variable: a1211524104 
o|substituted constant variable: a1211524111 
o|substituted constant variable: r1202524117 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:877) chicken.base#void" 
o|substituted constant variable: r1208924123 
o|substituted constant variable: r1208924123 
o|substituted constant variable: r1207924125 
o|removed side-effect free assignment to unused variable: optargs?2046 
o|substituted constant variable: r1234424182 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:954) chicken.base#void" 
o|substituted constant variable: r1234424183 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:967) chicken.base#void" 
o|substituted constant variable: r1248624237 
o|substituted constant variable: r1268124260 
o|substituted constant variable: r1270424263 
o|substituted constant variable: r1272124266 
o|substituted constant variable: r1287524296 
o|substituted constant variable: r1298524327 
o|substituted constant variable: r1303224340 
o|substituted constant variable: r1303224340 
o|substituted constant variable: r1301224359 
o|substituted constant variable: r1308124378 
o|substituted constant variable: r1312024386 
o|substituted constant variable: r1310824397 
o|substituted constant variable: r1306824398 
o|substituted constant variable: r1317624406 
o|substituted constant variable: r1321224414 
o|substituted constant variable: r1325224422 
o|substituted constant variable: r1328824430 
o|substituted constant variable: r1338324432 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:933) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:1110) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:1108) chicken.base#void" 
o|substituted constant variable: r1354524438 
o|substituted constant variable: r1361824446 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:1166) chicken.base#void" 
o|substituted constant variable: r1472124464 
o|substituted constant variable: r1380124467 
o|substituted constant variable: r1382624470 
o|substituted constant variable: r1413524526 
o|substituted constant variable: r1418024540 
o|substituted constant variable: r1431424548 
o|substituted constant variable: r1431424548 
o|substituted constant variable: r1449024577 
o|substituted constant variable: r1452824585 
o|substituted constant variable: r1455224588 
o|substituted constant variable: r1461724594 
o|substituted constant variable: r1493824622 
o|substituted constant variable: r1497124631 
o|substituted constant variable: r1509124641 
o|substituted constant variable: r1507924642 
o|substituted constant variable: r1513524646 
o|substituted constant variable: r1512324647 
o|substituted constant variable: r1521924658 
o|substituted constant variable: r1527724667 
o|substituted constant variable: r1525924668 
o|substituted constant variable: r1523924669 
o|substituted constant variable: r1529024693 
o|substituted constant variable: r1534724707 
o|substituted constant variable: r1543224709 
o|inlining procedure: k15438 
o|inlining procedure: k15438 
o|substituted constant variable: r1544924711 
o|substituted constant variable: r1578824761 
o|substituted constant variable: r1575524762 
o|substituted constant variable: r1580824763 
o|substituted constant variable: r1584124776 
o|substituted constant variable: r1586724783 
o|substituted constant variable: r1582824784 
o|substituted constant variable: r1594624801 
o|substituted constant variable: r1593124807 
o|substituted constant variable: r1663824924 
o|substituted constant variable: r1663824924 
o|substituted constant variable: r1669524930 
o|substituted constant variable: r1682424966 
o|substituted constant variable: r1719624968 
o|substituted constant variable: r1741324975 
o|substituted constant variable: r1741324975 
o|substituted constant variable: r1741324977 
o|substituted constant variable: r1741324977 
o|substituted constant variable: r1779825012 
o|substituted constant variable: r1788325013 
o|substituted constant variable: r1791125015 
o|substituted constant variable: r1792325017 
o|substituted constant variable: r1794125020 
o|substituted constant variable: r1796425022 
o|substituted constant variable: r1800325026 
o|substituted constant variable: r1807125031 
o|substituted constant variable: r1808325033 
o|substituted constant variable: r1810725038 
o|substituted constant variable: r1818725059 
o|substituted constant variable: r1824325068 
o|substituted constant variable: r1814725081 
o|substituted constant variable: r1836225090 
o|substituted constant variable: r1833825093 
o|substituted constant variable: r1842525096 
o|substituted constant variable: r1844625109 
o|substituted constant variable: r1851825118 
o|substituted constant variable: r1848225129 
o|substituted constant variable: r1848925133 
o|substituted constant variable: r1785525141 
o|substituted constant variable: r1861425145 
o|substituted constant variable: r1864425157 
o|substituted constant variable: r1869125165 
o|substituted constant variable: r1872725170 
o|substituted constant variable: r1881025173 
o|substituted constant variable: r1893425183 
o|substituted constant variable: r1889425184 
o|substituted constant variable: r1888225185 
o|substituted constant variable: r1886425186 
o|substituted constant variable: r1905925196 
o|substituted constant variable: r1904725202 
o|inlining procedure: k19125 
o|substituted constant variable: r1912625205 
o|substituted constant variable: r1912625205 
o|converted assignments to bindings: (fail4140) 
o|substituted constant variable: r1975525301 
o|substituted constant variable: r1974325307 
o|substituted constant variable: r1973125313 
o|substituted constant variable: r1971925314 
o|substituted constant variable: r1970725320 
o|substituted constant variable: r1981525329 
o|substituted constant variable: r1986625335 
o|substituted constant variable: r1989025339 
o|substituted constant variable: r1990525344 
o|substituted constant variable: r1994225363 
o|substituted constant variable: r2009625379 
o|substituted constant variable: r2011225382 
o|substituted constant variable: r2001925383 
o|substituted constant variable: r2008725385 
o|substituted constant variable: r2007525391 
o|substituted constant variable: r2006325402 
o|substituted constant variable: r2018325403 
o|substituted constant variable: r2020425408 
o|substituted constant variable: r2025425410 
o|inlining procedure: k20276 
o|converted assignments to bindings: (derive-result-type4683) 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:2353) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:2342) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:2371) chicken.base#void" 
o|substituted constant variable: r728825419 
o|substituted constant variable: r2072225427 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:2374) chicken.base#void" 
o|substituted constant variable: r2074325429 
o|substituted constant variable: r2074325430 
o|contracted procedure: "(scrutinizer.scm:2433) g50275036" 
o|substituted constant variable: r2114925472 
o|substituted constant variable: r2114925472 
o|substituted constant variable: r2116025474 
o|substituted constant variable: r2116025474 
o|substituted constant variable: r2116025476 
o|substituted constant variable: r2116025476 
o|substituted constant variable: r2117225479 
o|converted assignments to bindings: (R4968) 
o|substituted constant variable: r2144125497 
o|substituted constant variable: r1765325501 
o|substituted constant variable: r2153625508 
o|substituted constant variable: r2153625508 
o|substituted constant variable: r2147425512 
o|substituted constant variable: r2181725536 
o|substituted constant variable: r2180525537 
o|substituted constant variable: r2188825549 
o|converted assignments to bindings: (file-location5348) 
o|converted assignments to bindings: (p5502) 
o|converted assignments to bindings: (p5524) 
o|converted assignments to bindings: (p5572) 
o|substituted constant variable: type4736 
o|substituted constant variable: r2037325565 
o|substituted constant variable: r2036125571 
o|substituted constant variable: r2034925577 
o|substituted constant variable: r2040425584 
o|converted assignments to bindings: (append-special-case4671) 
o|substituted constant variable: r2317125589 
o|substituted constant variable: r2315925595 
o|substituted constant variable: r2332325600 
o|substituted constant variable: r2338825604 
o|substituted constant variable: r2346725609 
o|substituted constant variable: r2350725619 
o|substituted constant variable: r2349525630 
o|substituted constant variable: r2357625636 
o|substituted constant variable: r2356425642 
o|substituted constant variable: r2355225648 
o|simplifications: ((let . 10)) 
o|replaced variables: 995 
o|removed binding forms: 3970 
o|inlining procedure: k8014 
o|contracted procedure: k8196 
o|inlining procedure: "(scrutinizer.scm:2843) chicken.compiler.scrutinizer#report-notice" 
o|contracted procedure: k8799 
o|contracted procedure: k8860 
o|contracted procedure: k8957 
o|inlining procedure: "(scrutinizer.scm:2794) chicken.compiler.scrutinizer#report-notice" 
o|inlining procedure: "(scrutinizer.scm:2819) chicken.compiler.scrutinizer#report-notice" 
o|inlining procedure: k15699 
o|contracted procedure: k9429 
o|contracted procedure: k9551 
o|contracted procedure: k9561 
o|contracted procedure: k9767 
o|contracted procedure: k9894 
o|inlining procedure: k9971 
o|inlining procedure: "(scrutinizer.scm:2859) chicken.compiler.scrutinizer#report-notice" 
o|inlining procedure: k9971 
o|inlining procedure: "(scrutinizer.scm:523) chicken.compiler.scrutinizer#alist-cons" 
o|inlining procedure: "(scrutinizer.scm:522) chicken.compiler.scrutinizer#alist-cons" 
o|contracted procedure: k10202 
o|inlining procedure: "(scrutinizer.scm:542) chicken.compiler.scrutinizer#alist-cons" 
o|contracted procedure: k10399 
o|contracted procedure: k10431 
o|inlining procedure: "(scrutinizer.scm:649) chicken.compiler.scrutinizer#alist-cons" 
o|contracted procedure: k10455 
o|substituted constant variable: r1068025749 
o|folded constant expression: (scheme#not (quote #f)) 
o|inlining procedure: k10694 
o|contracted procedure: k10951 
o|contracted procedure: k10966 
o|contracted procedure: k11001 
o|contracted procedure: k11040 
o|inlining procedure: "(scrutinizer.scm:2960) pp-type5656" 
o|inlining procedure: "(scrutinizer.scm:2959) pp-type5656" 
o|contracted procedure: k11607 
o|contracted procedure: k11763 
o|contracted procedure: k11776 
o|contracted procedure: k11844 
o|contracted procedure: k11857 
o|contracted procedure: k11925 
o|inlining procedure: "(mini-srfi-1.scm:50) a12065" 
o|contracted procedure: k12245 
o|contracted procedure: k12352 
o|contracted procedure: k12436 
o|contracted procedure: k13455 
o|contracted procedure: k13461 
o|inlining procedure: k13636 
o|contracted procedure: k13713 
o|inlining procedure: k13794 
o|inlining procedure: k13794 
o|inlining procedure: k7796 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:1270) chicken.base#void" 
o|removed call to pure procedure with unused result: "(scrutinizer.scm:1270) chicken.base#void" 
o|inlining procedure: k15381 
o|substituted constant variable: r154322470925863 
o|substituted constant variable: r154322470925866 
o|inlining procedure: "(scrutinizer.scm:1800) chicken.compiler.scrutinizer#alist-cons" 
o|consed rest parameter at call site: "(scrutinizer.scm:1854) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1858) validate3751" 2 
o|merged explicitly consed rest parameter: rest37993801 
o|consed rest parameter at call site: "(scrutinizer.scm:1876) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1902) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1897) validate3751" 2 
o|inlining procedure: k18230 
o|inlining procedure: k18230 
o|consed rest parameter at call site: "(scrutinizer.scm:1915) validate3751" 2 
o|inlining procedure: k18499 
o|consed rest parameter at call site: "(scrutinizer.scm:1924) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1937) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1946) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1943) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1952) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1958) validate3751" 2 
o|consed rest parameter at call site: "(scrutinizer.scm:1963) validate3751" 2 
o|inlining procedure: k18921 
o|consed rest parameter at call site: "(scrutinizer.scm:1980) validate3751" 2 
o|substituted constant variable: r1912625963 
o|consed rest parameter at call site: "(scrutinizer.scm:1989) validate3751" 2 
o|inlining procedure: k19805 
o|inlining procedure: k19805 
o|inlining procedure: k19805 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|inlining procedure: k20053 
o|substituted constant variable: r202542541025995 
o|contracted procedure: k20429 
o|contracted procedure: k20460 
o|inlining procedure: "(scrutinizer.scm:2349) chicken.compiler.scrutinizer#alist-cons" 
o|contracted procedure: k20529 
o|contracted procedure: k20614 
o|inlining procedure: k20848 
o|inlining procedure: k21619 
o|inlining procedure: k23140 
o|inlining procedure: k20336 
o|inlining procedure: k20336 
o|inlining procedure: k20336 
o|inlining procedure: k20336 
o|inlining procedure: k20336 
o|inlining procedure: k20336 
o|inlining procedure: k20336 
o|inlining procedure: k23149 
o|inlining procedure: k23149 
o|inlining procedure: k23149 
o|inlining procedure: k23149 
o|inlining procedure: k23149 
o|inlining procedure: k23485 
o|inlining procedure: k23485 
o|inlining procedure: k23485 
o|inlining procedure: k23485 
o|inlining procedure: k23485 
o|inlining procedure: k23485 
o|inlining procedure: k23542 
o|inlining procedure: k23542 
o|inlining procedure: k23542 
o|inlining procedure: k23542 
o|inlining procedure: k23542 
o|inlining procedure: k23542 
o|inlining procedure: k23542 
o|replaced variables: 5 
o|removed binding forms: 1151 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#alist-cons 
o|substituted constant variable: r801526093 
o|substituted constant variable: reason536526105 
o|inlining procedure: k8857 
o|substituted constant variable: reason536526127 
o|substituted constant variable: reason536526133 
o|inlining procedure: "(scrutinizer.scm:305) chicken.compiler.scrutinizer#walked-result" 
o|inlining procedure: k9556 
o|inlining procedure: k9556 
o|inlining procedure: k9556 
o|inlining procedure: k9556 
o|inlining procedure: k9556 
o|inlining procedure: k9556 
o|substituted constant variable: r997226157 
o|substituted constant variable: reason536526159 
o|substituted constant variable: r997226164 
o|substituted constant variable: y33226185 
o|inlining procedure: k9556 
o|inlining procedure: k9556 
o|substituted constant variable: r1069526201 
o|inlining procedure: k9556 
o|inlining procedure: "(scrutinizer.scm:683) chicken.compiler.scrutinizer#walked-result" 
o|inlining procedure: "(scrutinizer.scm:680) chicken.compiler.scrutinizer#walked-result" 
o|inlining procedure: k9556 
o|inlining procedure: k13129 
o|substituted constant variable: r1379526263 
o|substituted constant variable: r1379526264 
o|contracted procedure: k1447224575 
o|contracted procedure: k1447224583 
o|inlining procedure: k15324 
o|inlining procedure: k15525 
o|inlining procedure: k16424 
o|inlining procedure: k17408 
o|inlining procedure: k17408 
o|substituted constant variable: r1823126360 
o|substituted constant variable: r1823126361 
o|substituted constant variable: r1850026366 
o|substituted constant variable: r1850026366 
o|substituted constant variable: r1892226376 
o|inlining procedure: "(scrutinizer.scm:2117) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r1980626391 
o|substituted constant variable: r1980626391 
o|substituted constant variable: r1980626394 
o|substituted constant variable: r1980626394 
o|inlining procedure: "(scrutinizer.scm:2135) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r1980626397 
o|substituted constant variable: r1980626397 
o|substituted constant variable: r2005426410 
o|substituted constant variable: r2005426410 
o|substituted constant variable: r2005426416 
o|substituted constant variable: r2005426416 
o|substituted constant variable: r2005426419 
o|substituted constant variable: r2005426419 
o|substituted constant variable: r2005426422 
o|substituted constant variable: r2005426422 
o|substituted constant variable: r2005426425 
o|substituted constant variable: r2005426425 
o|substituted constant variable: r2005426428 
o|substituted constant variable: r2005426428 
o|substituted constant variable: r2005426431 
o|substituted constant variable: r2005426431 
o|inlining procedure: "(scrutinizer.scm:2205) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r2005426434 
o|substituted constant variable: r2005426434 
o|substituted constant variable: r2005426437 
o|substituted constant variable: r2005426437 
o|inlining procedure: "(scrutinizer.scm:2273) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r2162026489 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#report-notice 
o|substituted constant variable: r2033726493 
o|substituted constant variable: r2033726493 
o|substituted constant variable: r2033726496 
o|substituted constant variable: r2033726496 
o|substituted constant variable: r2033726499 
o|substituted constant variable: r2033726499 
o|substituted constant variable: r2033726502 
o|substituted constant variable: r2033726502 
o|substituted constant variable: r2033726505 
o|substituted constant variable: r2033726505 
o|substituted constant variable: r2033726508 
o|substituted constant variable: r2033726508 
o|inlining procedure: "(scrutinizer.scm:2317) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r2033726511 
o|substituted constant variable: r2033726511 
o|substituted constant variable: r2315026514 
o|substituted constant variable: r2315026514 
o|substituted constant variable: r2315026517 
o|substituted constant variable: r2315026517 
o|substituted constant variable: r2315026520 
o|substituted constant variable: r2315026520 
o|inlining procedure: "(scrutinizer.scm:2257) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r2315026523 
o|substituted constant variable: r2315026523 
o|substituted constant variable: r2315026526 
o|substituted constant variable: r2315026526 
o|inlining procedure: "(scrutinizer.scm:2251) chicken.compiler.scrutinizer#walked-result" 
o|inlining procedure: "(scrutinizer.scm:2247) chicken.compiler.scrutinizer#walked-result" 
o|inlining procedure: "(scrutinizer.scm:2243) chicken.compiler.scrutinizer#walked-result" 
o|inlining procedure: "(scrutinizer.scm:2237) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r2348626540 
o|substituted constant variable: r2348626540 
o|inlining procedure: "(scrutinizer.scm:2150) chicken.compiler.scrutinizer#walked-result" 
o|substituted constant variable: r2348626543 
o|substituted constant variable: r2348626543 
o|substituted constant variable: r2348626546 
o|substituted constant variable: r2348626546 
o|substituted constant variable: r2348626549 
o|substituted constant variable: r2348626549 
o|substituted constant variable: r2348626552 
o|substituted constant variable: r2348626552 
o|substituted constant variable: r2354326558 
o|substituted constant variable: r2354326558 
o|substituted constant variable: r2354326561 
o|substituted constant variable: r2354326561 
o|substituted constant variable: r2354326564 
o|substituted constant variable: r2354326564 
o|substituted constant variable: r2354326567 
o|substituted constant variable: r2354326567 
o|substituted constant variable: r2354326570 
o|substituted constant variable: r2354326570 
o|substituted constant variable: r2354326573 
o|substituted constant variable: r2354326573 
o|replaced variables: 47 
o|removed binding forms: 127 
o|removed conditional forms: 43 
o|substituted constant variable: r955726629 
o|substituted constant variable: r955726633 
o|substituted constant variable: r955726637 
o|substituted constant variable: r955726651 
o|substituted constant variable: r955726663 
o|substituted constant variable: r955726667 
o|substituted constant variable: r955726673 
o|substituted constant variable: r955726701 
o|substituted constant variable: r1313026725 
o|replaced variables: 35 
o|removed binding forms: 113 
o|removed binding forms: 44 
o|simplifications: ((if . 162) (let . 167) (##core#call . 1981)) 
o|  call simplifications:
o|    scheme#cadddr	2
o|    scheme#char-upcase
o|    ##sys#apply
o|    scheme#string=?
o|    scheme#string-ref	2
o|    chicken.fixnum#fx<	2
o|    scheme#<
o|    ##sys#intern-symbol
o|    chicken.base#identity
o|    ##sys#size	4
o|    scheme#list-tail	2
o|    scheme#vector-length
o|    scheme#>=	3
o|    scheme#vector-ref	6
o|    scheme#<=	2
o|    chicken.base#atom?	3
o|    chicken.fixnum#fx>	2
o|    scheme#cdar	4
o|    scheme#list-ref	4
o|    ##sys#call-with-values	12
o|    scheme#=	3
o|    scheme#cdddr	8
o|    chicken.fixnum#fx=	3
o|    scheme#cddr	18
o|    scheme#assoc	2
o|    scheme#set-cdr!	3
o|    scheme#set-car!	7
o|    scheme#values	14
o|    scheme#assq	17
o|    scheme#cadr	112
o|    scheme#list	69
o|    scheme#caar	3
o|    scheme#string?	7
o|    scheme#symbol?	26
o|    chicken.base#fixnum?	4
o|    chicken.base#bignum?
o|    chicken.base#flonum?
o|    chicken.base#ratnum?
o|    chicken.base#cplxnum?
o|    scheme#boolean?
o|    scheme#list?	14
o|    scheme#eof-object?
o|    scheme#vector?	4
o|    ##sys#immediate?
o|    ##sys#generic-structure?
o|    scheme#char?
o|    ##sys#list	65
o|    ##sys#cons	40
o|    scheme#caddr	66
o|    scheme#length	36
o|    scheme#eq?	288
o|    scheme#memq	16
o|    chicken.fixnum#fx>=	2
o|    chicken.fixnum#fx+	3
o|    scheme#equal?	6
o|    scheme#not	80
o|    scheme#null?	78
o|    scheme#apply	5
o|    scheme#cdr	75
o|    ##sys#setslot	51
o|    ##sys#check-list	62
o|    scheme#pair?	175
o|    ##sys#slot	194
o|    chicken.fixnum#fx<=	2
o|    scheme#car	181
o|    chicken.fixnum#fx-	2
o|    scheme#cons	176
o|contracted procedure: k6931 
o|contracted procedure: k6938 
o|contracted procedure: k6948 
o|contracted procedure: k7022 
o|contracted procedure: k7025 
o|contracted procedure: k7037 
o|contracted procedure: k7053 
o|contracted procedure: k7061 
o|contracted procedure: k7068 
o|contracted procedure: k7092 
o|contracted procedure: k7109 
o|contracted procedure: k7131 
o|contracted procedure: k7127 
o|contracted procedure: k7112 
o|contracted procedure: k7115 
o|contracted procedure: k7123 
o|contracted procedure: k7138 
o|contracted procedure: k7146 
o|contracted procedure: k7158 
o|contracted procedure: k7180 
o|contracted procedure: k7176 
o|contracted procedure: k7161 
o|contracted procedure: k7164 
o|contracted procedure: k7172 
o|contracted procedure: k7195 
o|contracted procedure: k7204 
o|contracted procedure: k7217 
o|contracted procedure: k7232 
o|contracted procedure: k7247 
o|contracted procedure: k7393 
o|contracted procedure: k7396 
o|contracted procedure: k7406 
o|contracted procedure: k7318 
o|contracted procedure: k7344 
o|contracted procedure: k7473 
o|contracted procedure: k7485 
o|contracted procedure: k7508 
o|contracted procedure: k7516 
o|contracted procedure: k7538 
o|contracted procedure: k7546 
o|contracted procedure: k7558 
o|contracted procedure: k7580 
o|contracted procedure: k7576 
o|contracted procedure: k7561 
o|contracted procedure: k7564 
o|contracted procedure: k7572 
o|contracted procedure: k7840 
o|contracted procedure: k7855 
o|contracted procedure: k7889 
o|contracted procedure: k7893 
o|contracted procedure: k7876 
o|contracted procedure: k8023 
o|contracted procedure: k8014 
o|contracted procedure: k8156 
o|contracted procedure: k8163 
o|contracted procedure: k8174 
o|contracted procedure: k8181 
o|contracted procedure: k8236 
o|contracted procedure: k8248 
o|contracted procedure: k8263 
o|contracted procedure: k8269 
o|contracted procedure: k8275 
o|contracted procedure: k8281 
o|contracted procedure: k8287 
o|contracted procedure: k8293 
o|contracted procedure: k8302 
o|contracted procedure: k8308 
o|contracted procedure: k8315 
o|contracted procedure: k8327 
o|contracted procedure: k8330 
o|contracted procedure: k8333 
o|contracted procedure: k8341 
o|contracted procedure: k8349 
o|contracted procedure: k8358 
o|contracted procedure: k8365 
o|contracted procedure: k8383 
o|contracted procedure: k8392 
o|contracted procedure: k8403 
o|contracted procedure: k8399 
o|contracted procedure: k8418 
o|contracted procedure: k8421 
o|contracted procedure: k8424 
o|contracted procedure: k8432 
o|contracted procedure: k8440 
o|contracted procedure: k8472 
o|contracted procedure: k8465 
o|contracted procedure: k8449 
o|contracted procedure: k8456 
o|contracted procedure: k8462 
o|contracted procedure: k8553 
o|contracted procedure: k8543 
o|contracted procedure: k7953 
o|contracted procedure: k7969 
o|contracted procedure: k8574 
o|contracted procedure: k8594 
o|contracted procedure: k8585 
o|contracted procedure: k8492 
o|contracted procedure: k8514 
o|contracted procedure: k8501 
o|contracted procedure: k8508 
o|contracted procedure: k8603 
o|contracted procedure: k8625 
o|contracted procedure: k8632 
o|contracted procedure: k8643 
o|contracted procedure: k8654 
o|contracted procedure: k8660 
o|contracted procedure: k8667 
o|contracted procedure: k22757 
o|contracted procedure: k8711 
o|contracted procedure: k8714 
o|contracted procedure: k8720 
o|contracted procedure: k8729 
o|contracted procedure: k8774 
o|contracted procedure: k8777 
o|contracted procedure: k8783 
o|contracted procedure: k8790 
o|contracted procedure: k8793 
o|contracted procedure: k21965 
o|contracted procedure: k21972 
o|contracted procedure: k21982 
o|contracted procedure: k22010 
o|contracted procedure: k22037 
o|contracted procedure: k8866 
o|contracted procedure: k8869 
o|contracted procedure: k8877 
o|contracted procedure: k8889 
o|contracted procedure: k8892 
o|contracted procedure: k8895 
o|contracted procedure: k8903 
o|contracted procedure: k8911 
o|contracted procedure: k8920 
o|contracted procedure: k8932 
o|contracted procedure: k8960 
o|contracted procedure: k8973 
o|contracted procedure: k8984 
o|contracted procedure: k8980 
o|contracted procedure: k9006 
o|contracted procedure: k9010 
o|contracted procedure: k9026 
o|contracted procedure: k9018 
o|contracted procedure: k9022 
o|contracted procedure: k9014 
o|contracted procedure: k9038 
o|contracted procedure: k9042 
o|contracted procedure: k9046 
o|contracted procedure: k22693 
o|contracted procedure: k9073 
o|contracted procedure: k9069 
o|contracted procedure: k9077 
o|contracted procedure: k9093 
o|contracted procedure: k9085 
o|contracted procedure: k9089 
o|contracted procedure: k9081 
o|contracted procedure: k9105 
o|contracted procedure: k9109 
o|contracted procedure: k9113 
o|contracted procedure: k22727 
o|contracted procedure: k9126 
o|contracted procedure: k9120 
o|contracted procedure: k9130 
o|contracted procedure: k9134 
o|contracted procedure: k9157 
o|contracted procedure: k9153 
o|contracted procedure: k9180 
o|contracted procedure: k9184 
o|contracted procedure: k9235 
o|contracted procedure: k9197 
o|contracted procedure: k9231 
o|contracted procedure: k9224 
o|contracted procedure: k9201 
o|contracted procedure: k9204 
o|contracted procedure: k9215 
o|contracted procedure: k9247 
o|contracted procedure: k8760 
o|contracted procedure: k8764 
o|contracted procedure: k9273 
o|contracted procedure: k15629 
o|contracted procedure: k15641 
o|contracted procedure: k15740 
o|contracted procedure: k15650 
o|contracted procedure: k15672 
o|contracted procedure: k15687 
o|contracted procedure: k15716 
o|contracted procedure: k15696 
o|contracted procedure: k15712 
o|contracted procedure: k15699 
o|contracted procedure: k15732 
o|contracted procedure: k15722 
o|contracted procedure: k15729 
o|contracted procedure: k9286 
o|contracted procedure: k9290 
o|contracted procedure: k9299 
o|contracted procedure: k9302 
o|contracted procedure: k9314 
o|contracted procedure: k9328 
o|contracted procedure: k9344 
o|contracted procedure: k9348 
o|contracted procedure: k22071 
o|contracted procedure: k22106 
o|contracted procedure: k22095 
o|inlining procedure: "(scrutinizer.scm:2637) chicken.compiler.scrutinizer#multiples" 
o|inlining procedure: "(scrutinizer.scm:2636) chicken.compiler.scrutinizer#multiples" 
o|contracted procedure: k9357 
o|contracted procedure: k9377 
o|contracted procedure: k9399 
o|contracted procedure: k9395 
o|contracted procedure: k9380 
o|contracted procedure: k9383 
o|contracted procedure: k9391 
o|contracted procedure: k9423 
o|contracted procedure: k9436 
o|contracted procedure: k9440 
o|contracted procedure: k9464 
o|contracted procedure: k9475 
o|contracted procedure: k9487 
o|contracted procedure: k9490 
o|contracted procedure: k9493 
o|contracted procedure: k9501 
o|contracted procedure: k9509 
o|contracted procedure: k9564 
o|contracted procedure: k9571 
o|inlining procedure: k9556 
o|contracted procedure: k9577 
o|inlining procedure: k9556 
o|contracted procedure: k9588 
o|contracted procedure: k9594 
o|contracted procedure: k9600 
o|contracted procedure: k9606 
o|contracted procedure: k9613 
o|contracted procedure: k9619 
o|inlining procedure: k9556 
o|contracted procedure: k9630 
o|contracted procedure: k9636 
o|inlining procedure: k9556 
o|contracted procedure: k9647 
o|contracted procedure: k9653 
o|contracted procedure: k9656 
o|contracted procedure: k9659 
o|contracted procedure: k9666 
o|contracted procedure: k9669 
o|contracted procedure: k9675 
o|contracted procedure: k9695 
o|contracted procedure: k9691 
o|contracted procedure: k9687 
o|contracted procedure: k9725 
o|contracted procedure: k9721 
o|contracted procedure: k9717 
o|contracted procedure: k9740 
o|contracted procedure: k22967 
o|contracted procedure: k22979 
o|contracted procedure: k22991 
o|inlining procedure: "(scrutinizer.scm:2985) chicken.compiler.scrutinizer#multiples" 
o|inlining procedure: "(scrutinizer.scm:2983) chicken.compiler.scrutinizer#multiples" 
o|contracted procedure: k9770 
o|contracted procedure: k9782 
o|contracted procedure: k9785 
o|contracted procedure: k9833 
o|contracted procedure: k9797 
o|contracted procedure: k9800 
o|contracted procedure: k9803 
o|contracted procedure: k9811 
o|contracted procedure: k9815 
o|contracted procedure: k9823 
o|contracted procedure: k9827 
o|contracted procedure: k9779 
o|contracted procedure: k9839 
o|contracted procedure: k9845 
o|contracted procedure: k9856 
o|contracted procedure: k9860 
o|contracted procedure: k9852 
o|contracted procedure: k9874 
o|contracted procedure: k9863 
o|contracted procedure: k9870 
o|contracted procedure: k9877 
o|contracted procedure: k9880 
o|contracted procedure: k9883 
o|contracted procedure: k9910 
o|contracted procedure: k9891 
o|contracted procedure: k9904 
o|contracted procedure: k9913 
o|contracted procedure: k9925 
o|contracted procedure: k9935 
o|contracted procedure: k9939 
o|contracted procedure: k9960 
o|contracted procedure: k9966 
o|contracted procedure: k8696 
o|contracted procedure: k22779 
o|contracted procedure: k9998 
o|contracted procedure: k10010 
o|contracted procedure: k10017 
o|contracted procedure: k10024 
o|contracted procedure: k10027 
o|contracted procedure: k742326171 
o|contracted procedure: k10044 
o|contracted procedure: k10052 
o|contracted procedure: k742326178 
o|contracted procedure: k10062 
o|contracted procedure: k10069 
o|contracted procedure: k10096 
o|contracted procedure: k10099 
o|contracted procedure: k10106 
o|contracted procedure: k10112 
o|contracted procedure: k10124 
o|contracted procedure: k10156 
o|contracted procedure: k10207 
o|contracted procedure: k10199 
o|contracted procedure: k10182 
o|contracted procedure: k10192 
o|contracted procedure: k10196 
o|contracted procedure: k10217 
o|contracted procedure: k10230 
o|contracted procedure: k10237 
o|contracted procedure: k10247 
o|contracted procedure: k10251 
o|contracted procedure: k10259 
o|contracted procedure: k10263 
o|contracted procedure: k742326189 
o|contracted procedure: k10282 
o|contracted procedure: k10293 
o|contracted procedure: k10296 
o|contracted procedure: k10344 
o|contracted procedure: k10308 
o|contracted procedure: k10334 
o|contracted procedure: k10338 
o|contracted procedure: k10330 
o|contracted procedure: k10311 
o|contracted procedure: k10314 
o|contracted procedure: k10322 
o|contracted procedure: k10326 
o|contracted procedure: k10363 
o|contracted procedure: k10366 
o|contracted procedure: k10369 
o|contracted procedure: k10381 
o|contracted procedure: k10393 
o|contracted procedure: k10513 
o|contracted procedure: k10504 
o|contracted procedure: k10407 
o|contracted procedure: k10413 
o|contracted procedure: k10425 
o|contracted procedure: k10439 
o|contracted procedure: k742326198 
o|contracted procedure: k10435 
o|contracted procedure: k10491 
o|contracted procedure: k10487 
o|contracted procedure: k10445 
o|contracted procedure: k10449 
o|contracted procedure: k10458 
o|contracted procedure: k10474 
o|contracted procedure: k10467 
o|contracted procedure: k10478 
o|contracted procedure: k10494 
o|contracted procedure: k10578 
o|contracted procedure: k10534 
o|contracted procedure: k10540 
o|contracted procedure: k10610 
o|contracted procedure: k10585 
o|contracted procedure: k10588 
o|contracted procedure: k10598 
o|contracted procedure: k10616 
o|contracted procedure: k10622 
o|contracted procedure: k10639 
o|contracted procedure: k10628 
o|contracted procedure: k10652 
o|contracted procedure: k23013 
o|contracted procedure: k23047 
o|contracted procedure: k10659 
o|contracted procedure: k10676 
o|contracted procedure: k10685 
o|contracted procedure: k10679 
o|contracted procedure: k10715 
o|contracted procedure: k10719 
o|contracted procedure: k10725 
o|contracted procedure: k10731 
o|contracted procedure: k10737 
o|contracted procedure: k10740 
o|contracted procedure: k10749 
o|contracted procedure: k10753 
o|contracted procedure: k10773 
o|contracted procedure: k11261 
o|contracted procedure: k10779 
o|contracted procedure: k10821 
o|contracted procedure: k10824 
o|contracted procedure: k10833 
o|contracted procedure: k10859 
o|contracted procedure: k10862 
o|contracted procedure: k10870 
o|contracted procedure: k10882 
o|contracted procedure: k10885 
o|contracted procedure: k10888 
o|contracted procedure: k10896 
o|contracted procedure: k10904 
o|contracted procedure: k10913 
o|contracted procedure: k10924 
o|contracted procedure: k10927 
o|contracted procedure: k11070 
o|contracted procedure: k10939 
o|contracted procedure: k10975 
o|contracted procedure: k10979 
o|contracted procedure: k10986 
o|contracted procedure: k11019 
o|contracted procedure: k11023 
o|contracted procedure: k11059 
o|contracted procedure: k11084 
o|contracted procedure: k11087 
o|contracted procedure: k11099 
o|contracted procedure: k11102 
o|contracted procedure: k11110 
o|contracted procedure: k11122 
o|contracted procedure: k11125 
o|contracted procedure: k11128 
o|contracted procedure: k11136 
o|contracted procedure: k11144 
o|contracted procedure: k11181 
o|contracted procedure: k11156 
o|contracted procedure: k11166 
o|contracted procedure: k11170 
o|contracted procedure: k11174 
o|contracted procedure: k11178 
o|contracted procedure: k11220 
o|contracted procedure: k11216 
o|contracted procedure: k11232 
o|contracted procedure: k11254 
o|contracted procedure: k11250 
o|contracted procedure: k11235 
o|contracted procedure: k11238 
o|contracted procedure: k11246 
o|contracted procedure: k11306 
o|contracted procedure: k11270 
o|contracted procedure: k11273 
o|contracted procedure: k11276 
o|contracted procedure: k11284 
o|contracted procedure: k11288 
o|contracted procedure: k11296 
o|contracted procedure: k11300 
o|contracted procedure: k11315 
o|contracted procedure: k11318 
o|contracted procedure: k11324 
o|inlining procedure: k9556 
o|inlining procedure: k9556 
o|contracted procedure: k11336 
o|contracted procedure: k11343 
o|contracted procedure: k22797 
o|contracted procedure: k11362 
o|contracted procedure: k11366 
o|contracted procedure: k22845 
o|inlining procedure: k9556 
o|contracted procedure: k11370 
o|contracted procedure: k11381 
o|contracted procedure: k11395 
o|contracted procedure: k11384 
o|contracted procedure: k11391 
o|contracted procedure: k22819 
o|contracted procedure: k22831 
o|contracted procedure: k11400 
o|contracted procedure: k11406 
o|contracted procedure: k11419 
o|contracted procedure: k11423 
o|contracted procedure: k11432 
o|contracted procedure: k11439 
o|contracted procedure: k11443 
o|contracted procedure: k22905 
o|contracted procedure: k22908 
o|contracted procedure: k22920 
o|contracted procedure: k22923 
o|contracted procedure: k22926 
o|contracted procedure: k22934 
o|contracted procedure: k22942 
o|contracted procedure: k11462 
o|contracted procedure: k11474 
o|contracted procedure: k11480 
o|contracted procedure: k11488 
o|contracted procedure: k11492 
o|contracted procedure: k11496 
o|contracted procedure: k11502 
o|contracted procedure: k11505 
o|contracted procedure: k11516 
o|contracted procedure: k11528 
o|contracted procedure: k11538 
o|contracted procedure: k11542 
o|contracted procedure: k11628 
o|contracted procedure: k11666 
o|contracted procedure: k11678 
o|contracted procedure: k11688 
o|contracted procedure: k11692 
o|contracted procedure: k11663 
o|propagated global variable: g18921894 chicken.compiler.scrutinizer#specialization-statistics 
o|contracted procedure: k11696 
o|contracted procedure: k11700 
o|contracted procedure: k11723 
o|contracted procedure: k11735 
o|contracted procedure: k11753 
o|contracted procedure: k11760 
o|contracted procedure: k11773 
o|contracted procedure: k11788 
o|contracted procedure: k11795 
o|contracted procedure: k11784 
o|contracted procedure: k11807 
o|contracted procedure: k11810 
o|contracted procedure: k11813 
o|contracted procedure: k11821 
o|contracted procedure: k11829 
o|contracted procedure: k11838 
o|contracted procedure: k11841 
o|contracted procedure: k11854 
o|contracted procedure: k11869 
o|contracted procedure: k11876 
o|contracted procedure: k11880 
o|contracted procedure: k13476 
o|contracted procedure: k11913 
o|contracted procedure: k13470 
o|contracted procedure: k11916 
o|contracted procedure: k13464 
o|contracted procedure: k11919 
o|contracted procedure: k11937 
o|contracted procedure: k11943 
o|contracted procedure: k11953 
o|contracted procedure: k11959 
o|contracted procedure: k11969 
o|contracted procedure: k12050 
o|contracted procedure: k11975 
o|contracted procedure: k12046 
o|contracted procedure: k11986 
o|contracted procedure: k11997 
o|contracted procedure: k12012 
o|contracted procedure: k6887 
o|contracted procedure: k6922 
o|contracted procedure: k1207226245 
o|contracted procedure: k6900 
o|contracted procedure: k6909 
o|contracted procedure: k12091 
o|contracted procedure: k12102 
o|contracted procedure: k12119 
o|contracted procedure: k12128 
o|contracted procedure: k12137 
o|contracted procedure: k12146 
o|contracted procedure: k12171 
o|contracted procedure: k12175 
o|contracted procedure: k12180 
o|contracted procedure: k12215 
o|contracted procedure: k12235 
o|contracted procedure: k12239 
o|contracted procedure: k12248 
o|contracted procedure: k13449 
o|contracted procedure: k12254 
o|contracted procedure: k12265 
o|contracted procedure: k12288 
o|contracted procedure: k12274 
o|contracted procedure: k12284 
o|contracted procedure: k12292 
o|contracted procedure: k12377 
o|contracted procedure: k12295 
o|contracted procedure: k12337 
o|contracted procedure: k12303 
o|contracted procedure: k12329 
o|contracted procedure: k12315 
o|contracted procedure: k12325 
o|contracted procedure: k12333 
o|contracted procedure: k12374 
o|contracted procedure: k12346 
o|contracted procedure: k12356 
o|contracted procedure: k12363 
o|contracted procedure: k12359 
o|contracted procedure: k12370 
o|contracted procedure: k13443 
o|contracted procedure: k12386 
o|contracted procedure: k12397 
o|contracted procedure: k12420 
o|contracted procedure: k12406 
o|contracted procedure: k12416 
o|contracted procedure: k12424 
o|contracted procedure: k12458 
o|contracted procedure: k12430 
o|contracted procedure: k12440 
o|contracted procedure: k12447 
o|contracted procedure: k12443 
o|contracted procedure: k12454 
o|contracted procedure: k12464 
o|contracted procedure: k12473 
o|contracted procedure: k12482 
o|contracted procedure: k12488 
o|contracted procedure: k12491 
o|contracted procedure: k12497 
o|contracted procedure: k13435 
o|contracted procedure: k12534 
o|contracted procedure: k12537 
o|contracted procedure: k12561 
o|contracted procedure: k13427 
o|contracted procedure: k12572 
o|contracted procedure: k12578 
o|contracted procedure: k12602 
o|contracted procedure: k13419 
o|contracted procedure: k12613 
o|contracted procedure: k12620 
o|contracted procedure: k13411 
o|contracted procedure: k12632 
o|contracted procedure: k12639 
o|contracted procedure: k13403 
o|contracted procedure: k12651 
o|contracted procedure: k12658 
o|contracted procedure: k13395 
o|contracted procedure: k12664 
o|contracted procedure: k12671 
o|contracted procedure: k12677 
o|contracted procedure: k12683 
o|contracted procedure: k12694 
o|contracted procedure: k12700 
o|contracted procedure: k12706 
o|contracted procedure: k12717 
o|contracted procedure: k12723 
o|contracted procedure: k12729 
o|contracted procedure: k12740 
o|contracted procedure: k12746 
o|contracted procedure: k12760 
o|contracted procedure: k12766 
o|contracted procedure: k12793 
o|contracted procedure: k12802 
o|contracted procedure: k12811 
o|contracted procedure: k12817 
o|contracted procedure: k12820 
o|contracted procedure: k12827 
o|contracted procedure: k12831 
o|contracted procedure: k12837 
o|contracted procedure: k12840 
o|contracted procedure: k12861 
o|contracted procedure: k12865 
o|contracted procedure: k12846 
o|contracted procedure: k12853 
o|contracted procedure: k12857 
o|contracted procedure: k12871 
o|contracted procedure: k12880 
o|contracted procedure: k12890 
o|contracted procedure: k12894 
o|contracted procedure: k12898 
o|contracted procedure: k12902 
o|contracted procedure: k13371 
o|contracted procedure: k12930 
o|contracted procedure: k12936 
o|contracted procedure: k12943 
o|contracted procedure: k13363 
o|contracted procedure: k12949 
o|contracted procedure: k12956 
o|contracted procedure: k13355 
o|contracted procedure: k12962 
o|contracted procedure: k12968 
o|contracted procedure: k12975 
o|contracted procedure: k12981 
o|contracted procedure: k12994 
o|contracted procedure: k12998 
o|contracted procedure: k13002 
o|contracted procedure: k13008 
o|contracted procedure: k13014 
o|contracted procedure: k13027 
o|contracted procedure: k13044 
o|contracted procedure: k13034 
o|contracted procedure: k13031 
o|contracted procedure: k13048 
o|contracted procedure: k13052 
o|contracted procedure: k13347 
o|contracted procedure: k13064 
o|contracted procedure: k13070 
o|contracted procedure: k13077 
o|contracted procedure: k13083 
o|contracted procedure: k13096 
o|contracted procedure: k13100 
o|contracted procedure: k13104 
o|contracted procedure: k13110 
o|contracted procedure: k13116 
o|contracted procedure: k13146 
o|contracted procedure: k13136 
o|contracted procedure: k1313326728 
o|contracted procedure: k13129 
o|contracted procedure: k13133 
o|contracted procedure: k13150 
o|contracted procedure: k13154 
o|contracted procedure: k13339 
o|contracted procedure: k13166 
o|contracted procedure: k13172 
o|contracted procedure: k13178 
o|contracted procedure: k13184 
o|contracted procedure: k13191 
o|contracted procedure: k13195 
o|contracted procedure: k13331 
o|contracted procedure: k13208 
o|contracted procedure: k13214 
o|contracted procedure: k13220 
o|contracted procedure: k13229 
o|contracted procedure: k13323 
o|contracted procedure: k13242 
o|contracted procedure: k13248 
o|contracted procedure: k13254 
o|contracted procedure: k13260 
o|contracted procedure: k13267 
o|contracted procedure: k13271 
o|contracted procedure: k13315 
o|contracted procedure: k13284 
o|contracted procedure: k13290 
o|contracted procedure: k13296 
o|contracted procedure: k13305 
o|contracted procedure: k13379 
o|contracted procedure: k13385 
o|contracted procedure: k13482 
o|contracted procedure: k13489 
o|contracted procedure: k13507 
o|contracted procedure: k13516 
o|contracted procedure: k13519 
o|contracted procedure: k13564 
o|contracted procedure: k13528 
o|contracted procedure: k13541 
o|contracted procedure: k13560 
o|contracted procedure: k13582 
o|contracted procedure: k13589 
o|contracted procedure: k13592 
o|contracted procedure: k13607 
o|contracted procedure: k13620 
o|contracted procedure: k13624 
o|contracted procedure: k13645 
o|contracted procedure: k13657 
o|contracted procedure: k13679 
o|contracted procedure: k13639 
o|contracted procedure: k13629 
o|contracted procedure: k13675 
o|contracted procedure: k13660 
o|contracted procedure: k13663 
o|contracted procedure: k13671 
o|contracted procedure: k13688 
o|contracted procedure: k13697 
o|contracted procedure: k13988 
o|contracted procedure: k13703 
o|contracted procedure: k13983 
o|contracted procedure: k13710 
o|contracted procedure: k13728 
o|contracted procedure: k13732 
o|contracted procedure: k13744 
o|contracted procedure: k13751 
o|contracted procedure: k13810 
o|contracted procedure: k13783 
o|contracted procedure: k14768 
o|contracted procedure: k14723 
o|contracted procedure: k14729 
o|contracted procedure: k14732 
o|contracted procedure: k14758 
o|contracted procedure: k14762 
o|contracted procedure: k14754 
o|contracted procedure: k13794 
o|contracted procedure: k13846 
o|contracted procedure: k13853 
o|contracted procedure: k13864 
o|contracted procedure: k13935 
o|contracted procedure: k13873 
o|contracted procedure: k13907 
o|contracted procedure: k13919 
o|propagated global variable: g25622563 chicken.compiler.scrutinizer#type<=? 
o|contracted procedure: k13929 
o|propagated global variable: g25542555 chicken.compiler.scrutinizer#type<=? 
o|contracted procedure: k13974 
o|contracted procedure: k13947 
o|contracted procedure: k13956 
o|contracted procedure: k13965 
o|contracted procedure: k13992 
o|contracted procedure: k13996 
o|contracted procedure: k14008 
o|contracted procedure: k14011 
o|contracted procedure: k14014 
o|contracted procedure: k14022 
o|contracted procedure: k14030 
o|contracted procedure: k14039 
o|contracted procedure: k14042 
o|contracted procedure: k14051 
o|contracted procedure: k14068 
o|contracted procedure: k14072 
o|contracted procedure: k7743 
o|contracted procedure: k7750 
o|contracted procedure: k7807 
o|contracted procedure: k7756 
o|contracted procedure: k7768 
o|contracted procedure: k7775 
o|contracted procedure: k7800 
o|contracted procedure: k7796 
o|contracted procedure: k14083 
o|contracted procedure: k14089 
o|contracted procedure: k14111 
o|contracted procedure: k14101 
o|contracted procedure: k14108 
o|contracted procedure: k14118 
o|contracted procedure: k14122 
o|contracted procedure: k14128 
o|contracted procedure: k14137 
o|contracted procedure: k14146 
o|contracted procedure: k14152 
o|contracted procedure: k14161 
o|contracted procedure: k14170 
o|contracted procedure: k14176 
o|contracted procedure: k14182 
o|contracted procedure: k14189 
o|contracted procedure: k14193 
o|contracted procedure: k14205 
o|contracted procedure: k14208 
o|contracted procedure: k14211 
o|contracted procedure: k14219 
o|contracted procedure: k14227 
o|contracted procedure: k14238 
o|contracted procedure: k14245 
o|contracted procedure: k14249 
o|contracted procedure: k14261 
o|contracted procedure: k14264 
o|contracted procedure: k14267 
o|contracted procedure: k14275 
o|contracted procedure: k14283 
o|contracted procedure: k14292 
o|contracted procedure: k14295 
o|contracted procedure: k14298 
o|contracted procedure: k14305 
o|contracted procedure: k14363 
o|contracted procedure: k14366 
o|contracted procedure: k14369 
o|contracted procedure: k14309 
o|contracted procedure: k14316 
o|contracted procedure: k14319 
o|contracted procedure: k14322 
o|contracted procedure: k14334 
o|contracted procedure: k14337 
o|contracted procedure: k14340 
o|contracted procedure: k14348 
o|contracted procedure: k14356 
o|contracted procedure: k14381 
o|contracted procedure: k14384 
o|contracted procedure: k14387 
o|contracted procedure: k14395 
o|contracted procedure: k14403 
o|contracted procedure: k14448 
o|contracted procedure: k7657 
o|contracted procedure: k7683 
o|contracted procedure: k7663 
o|contracted procedure: k7677 
o|contracted procedure: k14475 
o|contracted procedure: k14479 
o|contracted procedure: k14521 
o|contracted procedure: k14492 
o|contracted procedure: k14496 
o|contracted procedure: k14512 
o|contracted procedure: k14530 
o|contracted procedure: k14542 
o|contracted procedure: k14548 
o|contracted procedure: k14555 
o|contracted procedure: k14562 
o|contracted procedure: k14702 
o|contracted procedure: k14568 
o|contracted procedure: k14602 
o|contracted procedure: k14574 
o|contracted procedure: k14585 
o|contracted procedure: k14597 
o|contracted procedure: k14613 
o|contracted procedure: k14657 
o|contracted procedure: k14619 
o|contracted procedure: k14626 
o|contracted procedure: k14638 
o|contracted procedure: k14642 
o|contracted procedure: k14650 
o|contracted procedure: k14654 
o|contracted procedure: k14646 
o|contracted procedure: k14669 
o|contracted procedure: k14692 
o|contracted procedure: k14789 
o|contracted procedure: k14796 
o|contracted procedure: k14848 
o|contracted procedure: k14855 
o|contracted procedure: k15167 
o|contracted procedure: k15173 
o|contracted procedure: k15155 
o|contracted procedure: k14904 
o|contracted procedure: k14917 
o|contracted procedure: k14921 
o|contracted procedure: k14925 
o|contracted procedure: k15149 
o|contracted procedure: k14931 
o|contracted procedure: k14944 
o|contracted procedure: k14948 
o|contracted procedure: k14952 
o|contracted procedure: k15111 
o|contracted procedure: k14964 
o|contracted procedure: k14973 
o|contracted procedure: k14986 
o|contracted procedure: k14995 
o|contracted procedure: k14998 
o|contracted procedure: k15001 
o|contracted procedure: k15004 
o|contracted procedure: k15007 
o|contracted procedure: k15066 
o|contracted procedure: k15030 
o|contracted procedure: k15033 
o|contracted procedure: k15036 
o|contracted procedure: k15044 
o|contracted procedure: k15048 
o|contracted procedure: k15056 
o|contracted procedure: k15060 
o|contracted procedure: k14820 
o|contracted procedure: k14827 
o|contracted procedure: k15075 
o|contracted procedure: k15087 
o|contracted procedure: k15093 
o|contracted procedure: k15100 
o|contracted procedure: k15104 
o|contracted procedure: k15119 
o|contracted procedure: k15125 
o|contracted procedure: k15137 
o|contracted procedure: k15180 
o|contracted procedure: k15186 
o|contracted procedure: k15195 
o|contracted procedure: k15202 
o|contracted procedure: k15209 
o|contracted procedure: k15215 
o|contracted procedure: k15221 
o|contracted procedure: k15241 
o|contracted procedure: k15248 
o|contracted procedure: k15255 
o|contracted procedure: k15261 
o|contracted procedure: k15264 
o|contracted procedure: k15270 
o|contracted procedure: k15279 
o|contracted procedure: k15292 
o|contracted procedure: k15299 
o|contracted procedure: k15306 
o|contracted procedure: k15312 
o|contracted procedure: k15315 
o|contracted procedure: k15321 
o|contracted procedure: k15324 
o|contracted procedure: k15349 
o|contracted procedure: k15356 
o|contracted procedure: k15363 
o|contracted procedure: k15369 
o|contracted procedure: k15372 
o|contracted procedure: k15378 
o|contracted procedure: k15381 
o|contracted procedure: k15614 
o|contracted procedure: k15403 
o|contracted procedure: k15606 
o|contracted procedure: k15415 
o|contracted procedure: k15434 
o|contracted procedure: k15519 
o|contracted procedure: k15445 
o|contracted procedure: k15459 
o|contracted procedure: k15478 
o|contracted procedure: k15485 
o|contracted procedure: k15493 
o|contracted procedure: k15542 
o|contracted procedure: k15522 
o|contracted procedure: k15538 
o|contracted procedure: k15525 
o|contracted procedure: k15598 
o|contracted procedure: k15548 
o|contracted procedure: k15555 
o|contracted procedure: k15558 
o|contracted procedure: k15566 
o|contracted procedure: k15572 
o|contracted procedure: k15582 
o|contracted procedure: k15757 
o|contracted procedure: k15764 
o|contracted procedure: k15784 
o|contracted procedure: k15771 
o|contracted procedure: k15774 
o|contracted procedure: k15790 
o|contracted procedure: k15797 
o|contracted procedure: k15810 
o|contracted procedure: k15821 
o|contracted procedure: k15816 
o|contracted procedure: k15830 
o|contracted procedure: k15837 
o|contracted procedure: k15843 
o|contracted procedure: k15863 
o|contracted procedure: k15853 
o|contracted procedure: k15850 
o|contracted procedure: k15869 
o|contracted procedure: k15876 
o|contracted procedure: k15886 
o|contracted procedure: k15895 
o|contracted procedure: k15902 
o|contracted procedure: k15913 
o|contracted procedure: k15920 
o|contracted procedure: k15933 
o|contracted procedure: k15936 
o|contracted procedure: k15942 
o|contracted procedure: k15948 
o|contracted procedure: k15955 
o|contracted procedure: k15986 
o|contracted procedure: k15993 
o|contracted procedure: k16000 
o|contracted procedure: k16006 
o|contracted procedure: k16173 
o|contracted procedure: k16012 
o|contracted procedure: k16018 
o|contracted procedure: k16021 
o|contracted procedure: k16066 
o|contracted procedure: k16030 
o|contracted procedure: k16036 
o|contracted procedure: k16048 
o|contracted procedure: k16058 
o|contracted procedure: k16062 
o|contracted procedure: k16075 
o|contracted procedure: k16085 
o|contracted procedure: k16089 
o|contracted procedure: k16092 
o|contracted procedure: k16095 
o|contracted procedure: k16139 
o|contracted procedure: k16104 
o|contracted procedure: k16109 
o|contracted procedure: k16121 
o|contracted procedure: k16131 
o|contracted procedure: k16135 
o|contracted procedure: k16148 
o|contracted procedure: k16158 
o|contracted procedure: k16162 
o|contracted procedure: k16169 
o|contracted procedure: k16179 
o|contracted procedure: k16190 
o|contracted procedure: k16194 
o|contracted procedure: k16219 
o|contracted procedure: k16222 
o|contracted procedure: k16234 
o|contracted procedure: k16237 
o|contracted procedure: k16240 
o|contracted procedure: k16248 
o|contracted procedure: k16256 
o|contracted procedure: k16202 
o|contracted procedure: k16212 
o|contracted procedure: k16216 
o|contracted procedure: k16265 
o|contracted procedure: k16269 
o|contracted procedure: k16281 
o|contracted procedure: k16291 
o|contracted procedure: k16295 
o|contracted procedure: k16318 
o|contracted procedure: k16337 
o|contracted procedure: k16321 
o|contracted procedure: k16333 
o|contracted procedure: k16324 
o|contracted procedure: k16362 
o|contracted procedure: k16370 
o|contracted procedure: k16376 
o|contracted procedure: k16379 
o|contracted procedure: k16385 
o|contracted procedure: k16392 
o|contracted procedure: k16396 
o|contracted procedure: k16403 
o|contracted procedure: k16811 
o|contracted procedure: k16415 
o|contracted procedure: k16421 
o|contracted procedure: k16424 
o|contracted procedure: k16433 
o|contracted procedure: k16439 
o|contracted procedure: k16446 
o|contracted procedure: k16455 
o|contracted procedure: k16467 
o|contracted procedure: k16470 
o|contracted procedure: k16473 
o|contracted procedure: k16481 
o|contracted procedure: k16489 
o|contracted procedure: k16498 
o|contracted procedure: k16509 
o|contracted procedure: k16515 
o|contracted procedure: k16518 
o|contracted procedure: k16527 
o|contracted procedure: k16535 
o|contracted procedure: k16541 
o|contracted procedure: k16553 
o|contracted procedure: k16562 
o|contracted procedure: k16574 
o|contracted procedure: k16577 
o|contracted procedure: k16580 
o|contracted procedure: k16588 
o|contracted procedure: k16596 
o|contracted procedure: k16605 
o|contracted procedure: k16625 
o|inlining procedure: k16629 
o|contracted procedure: k16640 
o|inlining procedure: k16629 
o|contracted procedure: k16643 
o|contracted procedure: k16651 
o|contracted procedure: k16663 
o|contracted procedure: k16666 
o|contracted procedure: k16669 
o|contracted procedure: k16677 
o|contracted procedure: k16685 
o|contracted procedure: k16697 
o|contracted procedure: k16760 
o|contracted procedure: k16703 
o|contracted procedure: k16709 
o|contracted procedure: k16728 
o|contracted procedure: k16768 
o|contracted procedure: k16774 
o|contracted procedure: k16780 
o|contracted procedure: k17136 
o|contracted procedure: k17148 
o|contracted procedure: k17158 
o|contracted procedure: k17162 
o|contracted procedure: k16842 
o|contracted procedure: k17130 
o|contracted procedure: k17124 
o|contracted procedure: k16848 
o|contracted procedure: k16957 
o|contracted procedure: k16975 
o|contracted procedure: k16984 
o|contracted procedure: k16987 
o|contracted procedure: k16993 
o|contracted procedure: k17007 
o|contracted procedure: k17021 
o|contracted procedure: k17035 
o|contracted procedure: k17049 
o|contracted procedure: k17059 
o|contracted procedure: k17063 
o|contracted procedure: k17090 
o|contracted procedure: k17097 
o|contracted procedure: k17105 
o|contracted procedure: k17110 
o|contracted procedure: k17117 
o|contracted procedure: k17192 
o|contracted procedure: k17204 
o|contracted procedure: k17302 
o|contracted procedure: k17315 
o|contracted procedure: k7262 
o|contracted procedure: k7273 
o|contracted procedure: k17356 
o|contracted procedure: k17363 
o|contracted procedure: k17376 
o|contracted procedure: k17384 
o|contracted procedure: k17392 
o|contracted procedure: k17400 
o|contracted procedure: k17421 
o|contracted procedure: k17428 
o|contracted procedure: k17436 
o|contracted procedure: k17454 
o|contracted procedure: k17469 
o|contracted procedure: k17479 
o|contracted procedure: k17483 
o|contracted procedure: k17497 
o|contracted procedure: k17501 
o|contracted procedure: k17216 
o|contracted procedure: k17228 
o|contracted procedure: k17235 
o|contracted procedure: k17244 
o|contracted procedure: k17256 
o|contracted procedure: k17268 
o|contracted procedure: k17264 
o|contracted procedure: k17260 
o|contracted procedure: k17548 
o|contracted procedure: k17530 
o|contracted procedure: k17539 
o|contracted procedure: k17575 
o|contracted procedure: k17581 
o|contracted procedure: k17593 
o|contracted procedure: k17596 
o|contracted procedure: k17599 
o|contracted procedure: k17607 
o|contracted procedure: k17615 
o|contracted procedure: k17701 
o|contracted procedure: k17726 
o|contracted procedure: k17729 
o|contracted procedure: k742326355 
o|contracted procedure: k17742 
o|contracted procedure: k17756 
o|contracted procedure: k17791 
o|contracted procedure: k17762 
o|contracted procedure: k17787 
o|contracted procedure: k17768 
o|contracted procedure: k17794 
o|contracted procedure: k17819 
o|contracted procedure: k17800 
o|contracted procedure: k17807 
o|contracted procedure: k17814 
o|contracted procedure: k17823 
o|contracted procedure: k17831 
o|contracted procedure: k17904 
o|contracted procedure: k17885 
o|contracted procedure: k17900 
o|contracted procedure: k17891 
o|contracted procedure: k17913 
o|contracted procedure: k17919 
o|contracted procedure: k18034 
o|contracted procedure: k17925 
o|contracted procedure: k18030 
o|contracted procedure: k17931 
o|contracted procedure: k17934 
o|contracted procedure: k17951 
o|contracted procedure: k17954 
o|contracted procedure: k17960 
o|contracted procedure: k17983 
o|contracted procedure: k17966 
o|contracted procedure: k17979 
o|contracted procedure: k17993 
o|contracted procedure: k19101 
o|contracted procedure: k18040 
o|contracted procedure: k18046 
o|contracted procedure: k18052 
o|contracted procedure: k18058 
o|contracted procedure: k18067 
o|contracted procedure: k18073 
o|contracted procedure: k18079 
o|contracted procedure: k18085 
o|contracted procedure: k18091 
o|contracted procedure: k19092 
o|contracted procedure: k18103 
o|contracted procedure: k18109 
o|contracted procedure: k19088 
o|contracted procedure: k18115 
o|contracted procedure: k18137 
o|contracted procedure: k18121 
o|contracted procedure: k18132 
o|contracted procedure: k19084 
o|contracted procedure: k18143 
o|contracted procedure: k18307 
o|contracted procedure: k18149 
o|contracted procedure: k18302 
o|contracted procedure: k18155 
o|contracted procedure: k18176 
o|contracted procedure: k18189 
o|contracted procedure: k18208 
o|contracted procedure: k18212 
o|contracted procedure: k18216 
o|contracted procedure: k18224 
o|contracted procedure: k18239 
o|contracted procedure: k18245 
o|contracted procedure: k18252 
o|contracted procedure: k18230 
o|contracted procedure: k18258 
o|contracted procedure: k18261 
o|contracted procedure: k18273 
o|contracted procedure: k18276 
o|contracted procedure: k18279 
o|contracted procedure: k18287 
o|contracted procedure: k18295 
o|contracted procedure: k18321 
o|contracted procedure: k18325 
o|contracted procedure: k19040 
o|contracted procedure: k18334 
o|contracted procedure: k18340 
o|contracted procedure: k18409 
o|contracted procedure: k18405 
o|contracted procedure: k18346 
o|contracted procedure: k18349 
o|contracted procedure: k18352 
o|contracted procedure: k18355 
o|contracted procedure: k18376 
o|contracted procedure: k18379 
o|contracted procedure: k18382 
o|contracted procedure: k18390 
o|contracted procedure: k18398 
o|contracted procedure: k19036 
o|contracted procedure: k18415 
o|contracted procedure: k18436 
o|contracted procedure: k18421 
o|contracted procedure: k18431 
o|contracted procedure: k18427 
o|contracted procedure: k19032 
o|contracted procedure: k18442 
o|contracted procedure: k18463 
o|contracted procedure: k18448 
o|contracted procedure: k18458 
o|contracted procedure: k18454 
o|contracted procedure: k19028 
o|contracted procedure: k18469 
o|contracted procedure: k18544 
o|contracted procedure: k18475 
o|contracted procedure: k18535 
o|contracted procedure: k18514 
o|contracted procedure: k18527 
o|contracted procedure: k18531 
o|contracted procedure: k18491 
o|contracted procedure: k18499 
o|contracted procedure: k18539 
o|contracted procedure: k18670 
o|contracted procedure: k18558 
o|contracted procedure: k18561 
o|contracted procedure: k18564 
o|contracted procedure: k18576 
o|contracted procedure: k18590 
o|contracted procedure: k18586 
o|contracted procedure: k17857 
o|contracted procedure: k17864 
o|contracted procedure: k18610 
o|contracted procedure: k18621 
o|contracted procedure: k18637 
o|contracted procedure: k18629 
o|contracted procedure: k18633 
o|contracted procedure: k18625 
o|contracted procedure: k18662 
o|contracted procedure: k18640 
o|contracted procedure: k18657 
o|contracted procedure: k18646 
o|contracted procedure: k18653 
o|contracted procedure: k18680 
o|contracted procedure: k18687 
o|contracted procedure: k18715 
o|contracted procedure: k18693 
o|contracted procedure: k18706 
o|contracted procedure: k18710 
o|contracted procedure: k18722 
o|contracted procedure: k18729 
o|contracted procedure: k18736 
o|contracted procedure: k18745 
o|contracted procedure: k18752 
o|contracted procedure: k18771 
o|contracted procedure: k18775 
o|contracted procedure: k18782 
o|contracted procedure: k19021 
o|contracted procedure: k18788 
o|contracted procedure: k18854 
o|contracted procedure: k18794 
o|contracted procedure: k18797 
o|contracted procedure: k18800 
o|contracted procedure: k18803 
o|contracted procedure: k18824 
o|contracted procedure: k18827 
o|contracted procedure: k18830 
o|contracted procedure: k18838 
o|contracted procedure: k18846 
o|contracted procedure: k19017 
o|contracted procedure: k18860 
o|contracted procedure: k19013 
o|contracted procedure: k18866 
o|contracted procedure: k19009 
o|contracted procedure: k19002 
o|contracted procedure: k18869 
o|contracted procedure: k18999 
o|contracted procedure: k18989 
o|contracted procedure: k18872 
o|contracted procedure: k18878 
o|contracted procedure: k18884 
o|contracted procedure: k18918 
o|contracted procedure: k18921 
o|contracted procedure: k18930 
o|contracted procedure: k18936 
o|contracted procedure: k18939 
o|contracted procedure: k18957 
o|contracted procedure: k18960 
o|contracted procedure: k18963 
o|contracted procedure: k18971 
o|contracted procedure: k18979 
o|contracted procedure: k19080 
o|contracted procedure: k19043 
o|contracted procedure: k19076 
o|contracted procedure: k19049 
o|contracted procedure: k19072 
o|contracted procedure: k19055 
o|contracted procedure: k19068 
o|contracted procedure: k19061 
o|contracted procedure: k19095 
o|contracted procedure: k19138 
o|contracted procedure: k19131 
o|contracted procedure: k19125 
o|contracted procedure: k19141 
o|contracted procedure: k19149 
o|contracted procedure: k19157 
o|contracted procedure: k19177 
o|contracted procedure: k19145 
o|contracted procedure: k19189 
o|contracted procedure: k19192 
o|contracted procedure: k19195 
o|contracted procedure: k19203 
o|contracted procedure: k19211 
o|contracted procedure: k19251 
o|contracted procedure: k19226 
o|contracted procedure: k19270 
o|contracted procedure: k19281 
o|contracted procedure: k19304 
o|contracted procedure: k19307 
o|contracted procedure: k19320 
o|contracted procedure: k19326 
o|inlining procedure: k19323 
o|contracted procedure: k19335 
o|contracted procedure: k19435 
o|contracted procedure: k19341 
o|contracted procedure: k19348 
o|contracted procedure: k19371 
o|contracted procedure: k19374 
o|contracted procedure: k19381 
o|inlining procedure: k19323 
o|contracted procedure: k19390 
o|contracted procedure: k19393 
o|contracted procedure: k19396 
o|contracted procedure: k19404 
o|contracted procedure: k19412 
o|contracted procedure: k19431 
o|contracted procedure: k19421 
o|inlining procedure: k19323 
o|contracted procedure: k19455 
o|contracted procedure: k19458 
o|contracted procedure: k19461 
o|contracted procedure: k19469 
o|contracted procedure: k19477 
o|contracted procedure: k19486 
o|contracted procedure: k19493 
o|contracted procedure: k19496 
o|contracted procedure: k19508 
o|contracted procedure: k19511 
o|contracted procedure: k19514 
o|contracted procedure: k19522 
o|contracted procedure: k19530 
o|contracted procedure: k19647 
o|contracted procedure: k19542 
o|contracted procedure: k19643 
o|contracted procedure: k19548 
o|contracted procedure: k19551 
o|contracted procedure: k19554 
o|contracted procedure: k19561 
o|contracted procedure: k19570 
o|contracted procedure: k19590 
o|contracted procedure: k19598 
o|contracted procedure: k19594 
o|contracted procedure: k19619 
o|contracted procedure: k19622 
o|contracted procedure: k19629 
o|contracted procedure: k19632 
o|contracted procedure: k19639 
o|contracted procedure: k19656 
o|contracted procedure: k19668 
o|contracted procedure: k19674 
o|contracted procedure: k19685 
o|contracted procedure: k19692 
o|contracted procedure: k19794 
o|contracted procedure: k19709 
o|contracted procedure: k19790 
o|contracted procedure: k19715 
o|contracted procedure: k19721 
o|contracted procedure: k19786 
o|contracted procedure: k19727 
o|contracted procedure: k19733 
o|contracted procedure: k19739 
o|contracted procedure: k19745 
o|contracted procedure: k19751 
o|contracted procedure: k19757 
o|contracted procedure: k19769 
o|contracted procedure: k19763 
o|contracted procedure: k19850 
o|contracted procedure: k19811 
o|contracted procedure: k19817 
o|contracted procedure: k19834 
o|contracted procedure: k19830 
o|contracted procedure: k19805 
o|contracted procedure: k19842 
o|contracted procedure: k19838 
o|contracted procedure: k19868 
o|contracted procedure: k20012 
o|contracted procedure: k19880 
o|contracted procedure: k19886 
o|contracted procedure: k19892 
o|contracted procedure: k20008 
o|contracted procedure: k19901 
o|contracted procedure: k19938 
o|contracted procedure: k19907 
o|contracted procedure: k19920 
o|contracted procedure: k6989 
o|contracted procedure: k7003 
o|contracted procedure: k7013 
o|contracted procedure: k7007 
o|contracted procedure: k20004 
o|contracted procedure: k19944 
o|contracted procedure: k19956 
o|contracted procedure: k19990 
o|contracted procedure: k19980 
o|contracted procedure: k19984 
o|contracted procedure: k19993 
o|contracted procedure: k20000 
o|contracted procedure: k20135 
o|contracted procedure: k20059 
o|contracted procedure: k20131 
o|contracted procedure: k20065 
o|contracted procedure: k20071 
o|contracted procedure: k20077 
o|contracted procedure: k20083 
o|contracted procedure: k20089 
o|contracted procedure: k20021 
o|contracted procedure: k20037 
o|contracted procedure: k20027 
o|contracted procedure: k20034 
o|contracted procedure: k20176 
o|contracted procedure: k20185 
o|contracted procedure: k20188 
o|contracted procedure: k20191 
o|contracted procedure: k20305 
o|contracted procedure: k20197 
o|contracted procedure: k20222 
o|contracted procedure: k20229 
o|contracted procedure: k20242 
o|contracted procedure: k20238 
o|contracted procedure: k20246 
o|contracted procedure: k20297 
o|contracted procedure: k20256 
o|contracted procedure: k20269 
o|contracted procedure: k20279 
o|contracted procedure: k20441 
o|contracted procedure: k20449 
o|contracted procedure: k20452 
o|contracted procedure: k20481 
o|contracted procedure: k742326450 
o|contracted procedure: k20457 
o|contracted procedure: k20463 
o|contracted procedure: k20475 
o|contracted procedure: k20466 
o|contracted procedure: k20496 
o|contracted procedure: k20511 
o|contracted procedure: k20523 
o|contracted procedure: k20538 
o|contracted procedure: k20541 
o|contracted procedure: k20544 
o|contracted procedure: k20552 
o|contracted procedure: k20560 
o|contracted procedure: k20571 
o|contracted procedure: k20574 
o|contracted procedure: k7290 
o|contracted procedure: k7297 
o|contracted procedure: k20586 
o|contracted procedure: k20589 
o|contracted procedure: k20592 
o|contracted procedure: k20600 
o|contracted procedure: k20608 
o|contracted procedure: k20630 
o|contracted procedure: k20636 
o|contracted procedure: k20669 
o|contracted procedure: k20642 
o|contracted procedure: k20663 
o|contracted procedure: k20649 
o|contracted procedure: k20657 
o|contracted procedure: k20675 
o|contracted procedure: k20687 
o|contracted procedure: k20697 
o|contracted procedure: k20701 
o|contracted procedure: k20736 
o|contracted procedure: k20745 
o|contracted procedure: k20833 
o|contracted procedure: k20751 
o|contracted procedure: k20777 
o|contracted procedure: k20772 
o|contracted procedure: k20763 
o|contracted procedure: k20782 
o|contracted procedure: k20790 
o|contracted procedure: k20805 
o|contracted procedure: k20808 
o|contracted procedure: k20811 
o|contracted procedure: k20819 
o|contracted procedure: k20827 
o|contracted procedure: k21275 
o|contracted procedure: k20868 
o|contracted procedure: k21272 
o|contracted procedure: k20880 
o|contracted procedure: k20918 
o|contracted procedure: k20926 
o|contracted procedure: k20929 
o|contracted procedure: k20932 
o|contracted procedure: k20944 
o|contracted procedure: k20947 
o|contracted procedure: k20950 
o|contracted procedure: k20958 
o|contracted procedure: k20966 
o|contracted procedure: k21267 
o|contracted procedure: k20972 
o|contracted procedure: k20981 
o|contracted procedure: k20993 
o|contracted procedure: k20996 
o|contracted procedure: k21006 
o|contracted procedure: k21015 
o|contracted procedure: k21037 
o|contracted procedure: k21033 
o|contracted procedure: k21018 
o|contracted procedure: k21021 
o|contracted procedure: k21029 
o|contracted procedure: k20862 
o|contracted procedure: k21046 
o|contracted procedure: k21058 
o|contracted procedure: k21061 
o|contracted procedure: k21064 
o|contracted procedure: k21076 
o|contracted procedure: k21079 
o|contracted procedure: k21082 
o|contracted procedure: k21090 
o|contracted procedure: k21098 
o|contracted procedure: k21107 
o|contracted procedure: k21113 
o|contracted procedure: k21116 
o|contracted procedure: k21122 
o|contracted procedure: k21137 
o|contracted procedure: k21144 
o|contracted procedure: k21155 
o|contracted procedure: k21174 
o|contracted procedure: k21177 
o|contracted procedure: k21180 
o|contracted procedure: k21192 
o|contracted procedure: k21195 
o|contracted procedure: k21198 
o|contracted procedure: k21206 
o|contracted procedure: k21214 
o|contracted procedure: k21226 
o|contracted procedure: k21229 
o|contracted procedure: k21232 
o|contracted procedure: k21240 
o|contracted procedure: k21248 
o|contracted procedure: k21257 
o|contracted procedure: k21264 
o|contracted procedure: k21320 
o|contracted procedure: k21329 
o|contracted procedure: k21335 
o|contracted procedure: k21342 
o|contracted procedure: k21351 
o|contracted procedure: k21363 
o|contracted procedure: k21366 
o|contracted procedure: k21369 
o|contracted procedure: k21377 
o|contracted procedure: k21385 
o|contracted procedure: k21391 
o|contracted procedure: k21443 
o|contracted procedure: k17640 
o|contracted procedure: k17669 
o|contracted procedure: k17649 
o|contracted procedure: k17665 
o|contracted procedure: k17655 
o|contracted procedure: k17675 
o|contracted procedure: k21628 
o|contracted procedure: k21467 
o|contracted procedure: k21501 
o|contracted procedure: k21511 
o|contracted procedure: k21625 
o|contracted procedure: k21520 
o|contracted procedure: k21553 
o|inlining procedure: k21615 
o|inlining procedure: k21615 
o|contracted procedure: k21676 
o|contracted procedure: k21646 
o|contracted procedure: k21661 
o|contracted procedure: k21665 
o|contracted procedure: k21679 
o|contracted procedure: k21774 
o|contracted procedure: k21781 
o|contracted procedure: k21795 
o|contracted procedure: k21798 
o|contracted procedure: k21801 
o|contracted procedure: k21807 
o|contracted procedure: k21868 
o|contracted procedure: k21890 
o|contracted procedure: k22120 
o|contracted procedure: k22169 
o|contracted procedure: k22245 
o|contracted procedure: k22214 
o|contracted procedure: k22263 
o|contracted procedure: k22377 
o|contracted procedure: k22373 
o|contracted procedure: k22390 
o|contracted procedure: k22439 
o|contracted procedure: k22408 
o|contracted procedure: k22452 
o|contracted procedure: k22559 
o|contracted procedure: k22474 
o|contracted procedure: k22572 
o|contracted procedure: k22679 
o|contracted procedure: k22594 
o|contracted procedure: k23133 
o|contracted procedure: k23056 
o|contracted procedure: k23082 
o|contracted procedure: k20342 
o|contracted procedure: k20351 
o|contracted procedure: k20357 
o|contracted procedure: k20363 
o|contracted procedure: k20369 
o|contracted procedure: k20385 
o|contracted procedure: k20336 
o|contracted procedure: k20400 
o|contracted procedure: k20406 
o|contracted procedure: k20413 
o|contracted procedure: k23201 
o|contracted procedure: k23155 
o|contracted procedure: k23197 
o|contracted procedure: k23161 
o|contracted procedure: k23167 
o|contracted procedure: k23193 
o|contracted procedure: k23173 
o|contracted procedure: k23183 
o|contracted procedure: k23149 
o|contracted procedure: k23216 
o|contracted procedure: k23219 
o|contracted procedure: k23222 
o|contracted procedure: k23212 
o|contracted procedure: k23234 
o|contracted procedure: k23256 
o|contracted procedure: k23252 
o|contracted procedure: k23237 
o|contracted procedure: k23240 
o|contracted procedure: k23248 
o|contracted procedure: k23273 
o|contracted procedure: k23276 
o|contracted procedure: k23279 
o|contracted procedure: k23269 
o|contracted procedure: k23291 
o|contracted procedure: k23313 
o|contracted procedure: k23309 
o|contracted procedure: k23294 
o|contracted procedure: k23297 
o|contracted procedure: k23305 
o|contracted procedure: k23381 
o|contracted procedure: k23325 
o|contracted procedure: k23336 
o|contracted procedure: k23340 
o|contracted procedure: k23332 
o|contracted procedure: k23352 
o|contracted procedure: k23374 
o|contracted procedure: k23370 
o|contracted procedure: k23355 
o|contracted procedure: k23358 
o|contracted procedure: k23366 
o|contracted procedure: k23446 
o|contracted procedure: k23390 
o|contracted procedure: k23401 
o|contracted procedure: k23405 
o|contracted procedure: k23397 
o|contracted procedure: k23417 
o|contracted procedure: k23439 
o|contracted procedure: k23435 
o|contracted procedure: k23420 
o|contracted procedure: k23423 
o|contracted procedure: k23431 
o|contracted procedure: k23469 
o|contracted procedure: k23476 
o|contracted procedure: k23497 
o|contracted procedure: k23503 
o|contracted procedure: k23533 
o|contracted procedure: k23509 
o|contracted procedure: k23515 
o|contracted procedure: k23526 
o|contracted procedure: k23522 
o|contracted procedure: k23604 
o|contracted procedure: k23548 
o|contracted procedure: k23554 
o|contracted procedure: k23560 
o|contracted procedure: k23566 
o|contracted procedure: k23572 
o|contracted procedure: k23581 
o|contracted procedure: k23588 
o|contracted procedure: k23542 
o|simplifications: ((if . 17) (let . 548)) 
o|removed binding forms: 1713 
o|inlining procedure: "(scrutinizer.scm:2793) chicken.compiler.scrutinizer#call-node-procedure-name" 
o|inlining procedure: "(scrutinizer.scm:2818) chicken.compiler.scrutinizer#call-node-procedure-name" 
o|inlining procedure: "(scrutinizer.scm:2637) chicken.compiler.scrutinizer#multiples" 
o|inlining procedure: "(scrutinizer.scm:2636) chicken.compiler.scrutinizer#multiples" 
o|inlining procedure: "(scrutinizer.scm:2618) chicken.compiler.scrutinizer#call-node-procedure-name" 
o|contracted procedure: k9749 
o|inlining procedure: "(scrutinizer.scm:2985) chicken.compiler.scrutinizer#multiples" 
o|inlining procedure: "(scrutinizer.scm:2983) chicken.compiler.scrutinizer#multiples" 
o|contracted procedure: k12149 
o|inlining procedure: "(scrutinizer.scm:979) chicken.compiler.scrutinizer#maybe-expand-type" 
o|inlining procedure: "(scrutinizer.scm:978) chicken.compiler.scrutinizer#maybe-expand-type" 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest28272830 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest28272830 0 
o|inlining procedure: "(scrutinizer.scm:1342) chicken.compiler.scrutinizer#maybe-expand-type" 
o|inlining procedure: "(scrutinizer.scm:1341) chicken.compiler.scrutinizer#maybe-expand-type" 
o|contracted procedure: k15466 
o|contracted procedure: k16015 
o|contracted procedure: k16963 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest34513454 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest34513454 0 
o|contracted procedure: k17698 
o|inlining procedure: k18914 
o|inlining procedure: k18914 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest41134116 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest41134116 0 
o|contracted procedure: k19278 
o|contracted procedure: k19583 
o|contracted procedure: k19604 
o|inlining procedure: "(scrutinizer.scm:2181) list-or-null4428" 
o|inlining procedure: "(scrutinizer.scm:2180) list-or-null4428" 
o|inlining procedure: "(scrutinizer.scm:2185) list-or-null4428" 
o|contracted procedure: k19973 
o|inlining procedure: k20445 
o|inlining procedure: k20445 
o|inlining procedure: "(scrutinizer.scm:2643) chicken.compiler.scrutinizer#call-node-procedure-name" 
o|inlining procedure: "(scrutinizer.scm:2677) chicken.compiler.scrutinizer#call-node-procedure-name" 
o|inlining procedure: "(scrutinizer.scm:2705) chicken.compiler.scrutinizer#call-node-procedure-name" 
o|removed binding forms: 12 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#maybe-expand-type 
o|substituted constant variable: r1891528434 
o|removed side-effect free assignment to unused variable: list-or-null4428 
o|contracted procedure: "(scrutinizer.scm:2213) split-list-type4429" 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#multiples 
o|removed side-effect free assignment to unused variable: chicken.compiler.scrutinizer#call-node-procedure-name 
o|replaced variables: 43 
o|removed binding forms: 5 
o|inlining procedure: k19934 
o|inlining procedure: k19963 
o|converted assignments to bindings: (list+index-call-result-type-special-case4431) 
o|simplifications: ((let . 1)) 
o|replaced variables: 25 
o|removed binding forms: 40 
o|contracted procedure: k22087 
o|contracted procedure: k22091 
o|contracted procedure: k22983 
o|contracted procedure: k22995 
o|contracted procedure: k19930 
o|removed binding forms: 11 
o|direct leaf routine/allocation: g374375 3 
o|direct leaf routine/allocation: a8537 0 
o|direct leaf routine/allocation: tag815 29 
o|direct leaf routine/allocation: chicken.compiler.scrutinizer#named? 0 
o|direct leaf routine/allocation: chicken.compiler.scrutinizer#rest-type 0 
o|direct leaf routine/allocation: chicken.compiler.scrutinizer#noreturn-procedure-type? 0 
o|direct leaf routine/allocation: chicken.compiler.scrutinizer#refinement-type? 0 
o|direct leaf routine/allocation: doloop32703271 0 
o|direct leaf routine/allocation: loop3763 0 
o|direct leaf routine/allocation: g38743875 3 
o|contracted procedure: "(mini-srfi-1.scm:216) k7959" 
o|contracted procedure: "(scrutinizer.scm:337) k9281" 
o|contracted procedure: "(scrutinizer.scm:458) k9988" 
o|contracted procedure: "(scrutinizer.scm:458) k9992" 
o|contracted procedure: "(scrutinizer.scm:540) k10142" 
o|contracted procedure: "(scrutinizer.scm:804) k11704" 
o|contracted procedure: "(scrutinizer.scm:891) k12004" 
o|contracted procedure: "(scrutinizer.scm:893) k12019" 
o|contracted procedure: "(scrutinizer.scm:905) k12088" 
o|contracted procedure: "(scrutinizer.scm:1214) k14057" 
o|contracted procedure: "(scrutinizer.scm:1242) k14424" 
o|contracted procedure: "(scrutinizer.scm:1291) k14589" 
o|contracted procedure: "(scrutinizer.scm:1292) k14593" 
o|contracted procedure: "(scrutinizer.scm:1442) k15473" 
o|converted assignments to bindings: (doloop32703271) 
o|converted assignments to bindings: (loop3763) 
o|contracted procedure: "(scrutinizer.scm:2426) k20892" 
o|simplifications: ((let . 2)) 
o|removed binding forms: 15 
o|direct leaf routine/allocation: loop537 0 
o|contracted procedure: k8528 
o|converted assignments to bindings: (loop537) 
o|simplifications: ((let . 1)) 
o|removed binding forms: 1 
o|customizable procedures: (list+index-call-result-type-special-case4431 map-loop45214538 map-loop45554572 map-loop45894606 map-loop46234640 k20345 p5572 p5524 p5502 file-location5348 p-expr5310 p-node5311 rec5241 chicken.compiler.scrutinizer#variable-and-module k21527 g51675176 map-loop51615190 walk5150 map-loop50795096 map-loop51065123 k21165 R4968 map-loop50515068 k20990 map-loop50215039 map-loop49835000 conv4947 g49254934 map-loop49194937 restore4777 loop4857 collect4778 g48744881 for-each-loop48734888 map-loop47964813 loop297 g48294838 map-loop48234848 doloop47814782 derive-result-type4683 lp4685 foldl47014705 lp4449 loop181 k20108 g44964497 known-length-vector-index4359 chicken.compiler.scrutinizer#r-index-out-of-range loop4295 rec4275 g41504159 map-loop41444259 g41724181 map-loop41664199 fail4140 g42254234 map-loop42194252 g40614062 g40754084 map-loop40694094 k19115 k18310 map-loop40304047 k18900 map-loop39884005 g39803981 loop3968 g39343935 k18567 memq*3749 k18602 loop3754 k18508 map-loop38833900 g38383847 map-loop38323856 validate3751 validate-llist3750 k17748 subst3712 map-loop36703687 chicken.compiler.scrutinizer#source-node loop23580 loop13577 g35963603 for-each-loop35953640 k17309 wrap3619 loop291 adjust3501 loop3508 k16884 for-each-loop34853564 k16544 loop3405 g34203429 map-loop34143439 g33733382 map-loop33673392 g33213330 map-loop33153340 g32943295 resolve3285 for-each-loop32503260 k16252 map-loop32223240 for-each-loop31873197 for-each-loop32043214 for-each-loop31523162 for-each-loop31693179 loop3135 g30423043 loop13003 k15425 loop3016 k14958 k14992 map-loop28972916 g28662867 g28552856 loop2846 a14842 g27202721 g27022703 loop431 map-loop26512668 map-loop26772694 map-loop26222639 map-loop25932610 chicken.compiler.scrutinizer#canonicalize-list-type foldl485489 foldl469473 map-loop24682485 chicken.compiler.scrutinizer#delete-duplicates chicken.compiler.scrutinizer#lset=/eq? loop2541 k13779 chicken.compiler.scrutinizer#merge-argument-types loop2769 foldl25112515 map-loop24352454 chicken.compiler.scrutinizer#filter-map simplify2418 loop2401 k12757 every-match12049 chicken.compiler.scrutinizer#procedure-arguments chicken.compiler.scrutinizer#procedure-results match-args2044 chicken.compiler.scrutinizer#over-all-instantiations g22152216 g22042205 g21762177 g21432144 g21572158 rawmatch12048 loop2119 match-results2047 loop160 match12050 match-rest2045 loop2054 loop1941 map-loop19561973 doloop19381939 for-each-loop18851905 g18601867 for-each-loop18591870 loop1847 chicken.compiler.scrutinizer#node-source-prefix chicken.compiler.scrutinizer#location-name chicken.compiler.scrutinizer#string-add-indent map-loop56605677 chicken.compiler.scrutinizer#compatible-types? k11352 k11355 g16051615 map-loop15991628 map-loop16461663 g17321740 for-each-loop17311786 g18021811 map-loop17961821 k10942 g17781779 smash1686 g17011710 map-loop16951720 k10812 call-result814 k10665 k10642 k10645 k10516 k10531 chicken.compiler.scrutinizer#smash-component-types! k10410 loop1564 initial-argument-types817 map-loop14141435 k10255 k10170 g14831484 loop1472 k10049 k10033 loop1383 single811 always-true809 k9705 g13161323 for-each-loop13151328 add-to-blist816 k9755 map-loop13441368 walk818 variable-result807 g12151224 map-loop12091237 loop1193 map-loop9941011 chicken.compiler.scrutinizer#make-list k8805 chicken.compiler.scrutinizer#strip-namespace chicken.compiler.scrutinizer#r-proc-call-argument-type-mismatch doloop10501051 k8842 k15663 loop3066 g30613062 loop13053 chicken.compiler.scrutinizer#procedure-name k9163 g11081109 chicken.compiler.scrutinizer#append-map loop1111 g11021103 chicken.compiler.scrutinizer#mutate-node! g10711072 chicken.compiler.scrutinizer#match-argument-types chicken.compiler.scrutinizer#trail-restore chicken.compiler.scrutinizer#fragment chicken.compiler.scrutinizer#specialize-node! k8851 k8917 k8854 g11551164 map-loop11491174 chicken.compiler.scrutinizer#procedure-argument-types chicken.compiler.scrutinizer#describe-expression chicken.compiler.scrutinizer#variable-from-module variable-node-name5376 chicken.compiler.scrutinizer#pp-fragment chicken.compiler.scrutinizer#type->pp-string blist-type806 k8571 g901902 chicken.compiler.scrutinizer#r-deprecated-identifier map-loop864881 chicken.compiler.scrutinizer#simplify-type constant-result804 map-loop832849 chicken.compiler.scrutinizer#list-tabulate chicken.compiler.scrutinizer#every loop509 map-loop387405 foldr359362 g364365 loop304 loop324 loop278 loop265 chicken.compiler.scrutinizer#any map-loop209227 map-loop236254 loop205 foldr194197 g199200 chicken.compiler.scrutinizer#take) 
o|calls to known targets: 946 
o|identified direct recursive calls: f_6926 1 
o|identified direct recursive calls: f_7032 1 
o|identified direct recursive calls: f_7104 1 
o|identified direct recursive calls: f_7153 1 
o|identified direct recursive calls: f_7480 1 
o|identified direct recursive calls: f_7553 1 
o|unused rest argument: _56926095 f26096 
o|unused rest argument: _569 f_8021 
o|identified direct recursive calls: f_8151 1 
o|identified direct recursive calls: f_7948 1 
o|identified direct recursive calls: f_8620 2 
o|identified direct recursive calls: f_15667 1 
o|identified direct recursive calls: f_15624 1 
o|identified direct recursive calls: f_10303 1 
o|identified direct recursive calls: f_10420 1 
o|identified direct recursive calls: f_11748 1 
o|identified direct recursive calls: f_11932 2 
o|identified direct recursive calls: f_6882 1 
o|identified direct recursive calls: f_7652 2 
o|identified direct recursive calls: f_14537 1 
o|unused rest argument: rest28272830 f_14834 
o|identified direct recursive calls: f_15184 1 
o|identified direct recursive calls: f_15236 1 
o|identified direct recursive calls: f_15287 1 
o|identified direct recursive calls: f_15344 1 
o|identified direct recursive calls: f_15429 2 
o|identified direct recursive calls: f_15410 1 
o|identified direct recursive calls: f_15752 1 
o|identified direct recursive calls: f_15825 1 
o|identified direct recursive calls: f_15884 1 
o|identified direct recursive calls: f_15928 1 
o|identified direct recursive calls: f_15981 1 
o|identified direct recursive calls: f_16313 1 
o|identified direct recursive calls: f_16692 2 
o|identified direct recursive calls: f_16360 2 
o|identified direct recursive calls: f_16952 1 
o|unused rest argument: rest34513454 f_16815 
o|identified direct recursive calls: f_7257 1 
o|identified direct recursive calls: f_17351 1 
o|identified direct recursive calls: f_17239 1 
o|identified direct recursive calls: f_17880 1 
o|identified direct recursive calls: f_17908 1 
o|identified direct recursive calls: f_17852 1 
o|unused rest argument: rest41134116 f_19224 
o|identified direct recursive calls: f_19565 1 
o|identified direct recursive calls: f_19663 1 
o|identified direct recursive calls: f_6984 1 
o|identified direct recursive calls: f_19951 1 
o|identified direct recursive calls: f_20217 1 
o|identified direct recursive calls: f_7285 1 
o|identified direct recursive calls: f_21515 1 
o|fast box initializations: 145 
o|fast global references: 387 
o|fast global assignments: 90 
o|dropping unused closure argument: f_11712 
o|dropping unused closure argument: f_13496 
o|dropping unused closure argument: f_13568 
o|dropping unused closure argument: f_14537 
o|dropping unused closure argument: f_14775 
o|dropping unused closure argument: f_15236 
o|dropping unused closure argument: f_15287 
o|dropping unused closure argument: f_15344 
o|dropping unused closure argument: f_15401 
o|dropping unused closure argument: f_15752 
o|dropping unused closure argument: f_15805 
o|dropping unused closure argument: f_15825 
o|dropping unused closure argument: f_15928 
o|dropping unused closure argument: f_16307 
o|dropping unused closure argument: f_17510 
o|dropping unused closure argument: f_17528 
o|dropping unused closure argument: f_17690 
o|dropping unused closure argument: f_17874 
o|dropping unused closure argument: f_19537 
o|dropping unused closure argument: f_19651 
o|dropping unused closure argument: f_19701 
o|dropping unused closure argument: f_20046 
o|dropping unused closure argument: f_20424 
o|dropping unused closure argument: f_20749 
o|dropping unused closure argument: f_20840 
o|dropping unused closure argument: f_21306 
o|dropping unused closure argument: f_21411 
o|dropping unused closure argument: f_21435 
o|dropping unused closure argument: f_21465 
o|dropping unused closure argument: f_21635 
o|dropping unused closure argument: f_21686 
o|dropping unused closure argument: f_21746 
o|dropping unused closure argument: f_21749 
o|dropping unused closure argument: f_22110 
o|dropping unused closure argument: f_22249 
o|dropping unused closure argument: f_23054 
o|dropping unused closure argument: f_6926 
o|dropping unused closure argument: f_7017 
o|dropping unused closure argument: f_7187 
o|dropping unused closure argument: f_7221 
o|dropping unused closure argument: f_7382 
o|dropping unused closure argument: f_7471 
o|dropping unused closure argument: f_7829 
o|dropping unused closure argument: f_7871 
o|dropping unused closure argument: f_8012 
o|dropping unused closure argument: f_8706 
*/
/* end of file */
