/* Generated from library.scm by the CHICKEN compiler
   http://www.call-cc.org
   Version 5.4.0rc1 (prerelease) (rev bc191a47)
   linux-unix-gnu-x86-64 [ 64bit dload ptables ]
   command line: library.scm -optimize-level 2 -include-path . -include-path ./ -inline -ignore-repository -feature chicken-bootstrap -no-warnings -specialize -consult-types-file ./types.db -explicit-use -no-trace -output-file library.c -no-module-registration -emit-import-library chicken.bitwise -emit-import-library chicken.blob -emit-import-library chicken.fixnum -emit-import-library chicken.flonum -emit-import-library chicken.gc -emit-import-library chicken.keyword -emit-import-library chicken.platform -emit-import-library chicken.plist -emit-import-library chicken.process-context
   unit: library
   uses: build-version library
*/
#include "chicken.h"

#include <errno.h>
#include <float.h>

#ifdef HAVE_SYSEXITS_H
# include <sysexits.h>
#endif

#ifndef EX_SOFTWARE
# define EX_SOFTWARE	70
#endif

#define C_close_file(p)	      (C_fclose((C_FILEPTR)(C_port_file(p))), C_SCHEME_UNDEFINED)
#define C_a_f64peek(ptr, c, b, i)  C_flonum(ptr, ((double *)C_data_pointer(b))[ C_unfix(i) ])
#define C_fetch_c_strlen(b, i) C_fix(strlen((C_char *)C_block_item(b, C_unfix(i))))
#define C_asciiz_strlen(str) C_fix(strlen(C_c_string(str)))
#define C_peek_c_string(b, i, to, len) (C_memcpy(C_data_pointer(to), (C_char *)C_block_item(b, C_unfix(i)), C_unfix(len)), C_SCHEME_UNDEFINED)
#define C_free_mptr(p, i)     (C_free((void *)C_block_item(p, C_unfix(i))), C_SCHEME_UNDEFINED)
#define C_free_sptr(p, i)     (C_free((void *)(((C_char **)C_block_item(p, 0))[ C_unfix(i) ])), C_SCHEME_UNDEFINED)

#define C_a_get_current_seconds(ptr, c, dummy)  C_int64_to_num(ptr, time(NULL))
#define C_peek_c_string_at(ptr, i)    ((C_char *)(((C_char **)ptr)[ i ]))

static C_word
fast_read_line_from_file(C_word str, C_word port, C_word size) {
  int n = C_unfix(size);
  int i;
  int c;
  char *buf = C_c_string(str);
  C_FILEPTR fp = C_port_file(port);

  if ((c = C_getc(fp)) == EOF) {
    if (ferror(fp)) {
      clearerr(fp);
      return C_fix(-1);
    } else { /* feof (fp) */
      return C_SCHEME_END_OF_FILE;
    }
  }

  C_ungetc(c, fp);

  for (i = 0; i < n; i++) {
    c = C_getc(fp);

    if(c == EOF && ferror(fp)) {
      clearerr(fp);
      return C_fix(-(i + 1));
    }

    switch (c) {
    case '\r':	if ((c = C_getc(fp)) != '\n') C_ungetc(c, fp);
    case EOF:	clearerr(fp);
    case '\n':	return C_fix(i);
    }
    buf[i] = c;
  }
  return C_SCHEME_FALSE;
}

static C_word
fast_read_string_from_file(C_word dest, C_word port, C_word len, C_word pos)
{
  size_t m;
  int n = C_unfix (len);
  char * buf = ((char *)C_data_pointer (dest) + C_unfix (pos));
  C_FILEPTR fp = C_port_file (port);

  if(feof(fp)) return C_SCHEME_END_OF_FILE;

  m = fread (buf, sizeof (char), n, fp);

  if (m < n) {
    if (ferror(fp)) /* Report to Scheme, which may retry, so clear errors */
      clearerr(fp);
    else if (feof(fp) && 0 == m) /* eof but m > 0? Return data first, below */
      return C_SCHEME_END_OF_FILE; /* Calling again will get us here */
  }

  return C_fix (m);
}

static C_word
shallow_equal(C_word x, C_word y)
{
  /* assumes x and y are non-immediate */
  int i, len = C_header_size(x);

  if(C_header_size(y) != len) return C_SCHEME_FALSE;      
  else return C_mk_bool(!C_memcmp((void *)x, (void *)y, len * sizeof(C_word)));
}

static C_word
signal_debug_event(C_word mode, C_word msg, C_word args)
{
  C_DEBUG_INFO cell;
  C_word av[ 3 ];
  cell.enabled = 1;
  cell.event = C_DEBUG_SIGNAL;
  cell.loc = "";
  cell.val = "";
  av[ 0 ] = mode;
  av[ 1 ] = msg;
  av[ 2 ] = args;
  C_debugger(&cell, 3, av);
  return C_SCHEME_UNDEFINED;
}
                   
static C_word C_i_sleep_until_interrupt(C_word secs)
{
   while(C_i_process_sleep(secs) == C_fix(-1) && errno == EINTR);
   return C_SCHEME_UNDEFINED;
}
                   
#ifdef NO_DLOAD2
# define HAVE_DLOAD 0
#else
# define HAVE_DLOAD 1
#endif

#ifdef C_ENABLE_PTABLES
# define HAVE_PTABLES 1
#else
# define HAVE_PTABLES 0
#endif

#ifdef C_GC_HOOKS
# define HAVE_GCHOOKS 1
#else
# define HAVE_GCHOOKS 0
#endif

#if defined(C_CROSS_CHICKEN) && C_CROSS_CHICKEN
# define IS_CROSS_CHICKEN 1
#else
# define IS_CROSS_CHICKEN 0
#endif


#define C_chdir(str) C_fix(chdir(C_c_string(str)))
#define C_curdir(buf, size) (getcwd(C_c_string(buf), size) ? C_fix(strlen(C_c_string(buf))) : C_SCHEME_FALSE)
#define C_getenventry(i) (environ[ i ])

#ifdef HAVE_CRT_EXTERNS_H
# include <crt_externs.h>
# define environ (*_NSGetEnviron())
#else
extern char **environ;
#endif

#ifdef HAVE_SETENV
# define C_unsetenv(s)    (unsetenv((char *)C_data_pointer(s)), C_SCHEME_TRUE)
# define C_setenv(x, y)   C_fix(setenv((char *)C_data_pointer(x), (char *)C_data_pointer(y), 1))
#else
# if defined(_WIN32) && !defined(__CYGWIN__)
#  define C_unsetenv(s)   C_setenv(s, C_SCHEME_FALSE)
# else
#  define C_unsetenv(s)   C_fix(putenv((char *)C_data_pointer(s)))
# endif
static C_word C_fcall C_setenv(C_word x, C_word y) {
  char *sx = C_c_string(x),
       *sy = (y == C_SCHEME_FALSE ? "" : C_c_string(y));
  int n1 = C_strlen(sx), n2 = C_strlen(sy);
  int buf_len = n1 + n2 + 2;
  char *buf = (char *)C_malloc(buf_len);
  if(buf == NULL) return(C_fix(0));
  else {
    C_strlcpy(buf, sx, buf_len);
    C_strlcat(buf, "=", buf_len);
    C_strlcat(buf, sy, buf_len);
    return(C_fix(putenv(buf)));
  }
}
#endif



static C_PTABLE_ENTRY *create_ptable(void);
C_noret_decl(C_build_2dversion_toplevel)
C_externimport void C_ccall C_build_2dversion_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_library_toplevel)
C_externimport void C_ccall C_library_toplevel(C_word c,C_word *av) C_noret;

static C_TLS C_word lf[1445];
static double C_possibly_force_alignment;
static C_char C_TLS li0[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,110,111,116,32,120,41,0,0};
static C_char C_TLS li1[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,98,111,111,108,101,97,110,63,32,120,41,0,0,0,0,0};
static C_char C_TLS li2[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,101,113,63,32,120,32,121,41};
static C_char C_TLS li3[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,101,113,118,63,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li4[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,101,113,117,97,108,63,32,120,32,121,41,0,0,0,0,0};
static C_char C_TLS li5[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,112,97,105,114,63,32,120,41};
static C_char C_TLS li6[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,111,110,115,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li7[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,99,97,114,32,120,41,0,0};
static C_char C_TLS li8[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,99,100,114,32,120,41,0,0};
static C_char C_TLS li9[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,115,101,116,45,99,97,114,33,32,120,32,121,41,0,0,0};
static C_char C_TLS li10[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,115,101,116,45,99,100,114,33,32,120,32,121,41,0,0,0};
static C_char C_TLS li11[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,99,97,100,114,32,120,41,0};
static C_char C_TLS li12[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,97,100,100,114,32,120,41};
static C_char C_TLS li13[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,100,100,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li14[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,100,100,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li15[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,99,97,97,114,32,120,41,0};
static C_char C_TLS li16[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,99,100,97,114,32,120,41,0};
static C_char C_TLS li17[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,99,100,100,114,32,120,41,0};
static C_char C_TLS li18[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,97,97,97,114,32,120,41};
static C_char C_TLS li19[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,97,97,100,114,32,120,41};
static C_char C_TLS li20[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,97,100,97,114,32,120,41};
static C_char C_TLS li21[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,100,97,97,114,32,120,41};
static C_char C_TLS li22[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,100,97,100,114,32,120,41};
static C_char C_TLS li23[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,100,100,97,114,32,120,41};
static C_char C_TLS li24[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,100,100,100,114,32,120,41};
static C_char C_TLS li25[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,97,97,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li26[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,97,97,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li27[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,97,100,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li28[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,97,100,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li29[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,100,97,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li30[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,100,97,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li31[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,97,100,100,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li32[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,97,97,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li33[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,97,97,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li34[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,97,100,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li35[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,97,100,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li36[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,100,97,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li37[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,100,97,100,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li38[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,99,100,100,100,97,114,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li39[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,110,117,108,108,63,32,120,41};
static C_char C_TLS li40[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,108,105,115,116,32,46,32,108,115,116,41,0,0,0,0,0};
static C_char C_TLS li41[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,108,101,110,103,116,104,32,108,115,116,41,0,0,0,0,0};
static C_char C_TLS li42[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,108,105,115,116,45,116,97,105,108,32,108,115,116,32,105,41};
static C_char C_TLS li43[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,108,105,115,116,45,114,101,102,32,108,115,116,32,105,41,0};
static C_char C_TLS li44[] C_aligned={C_lihdr(0,0,15),40,108,111,111,112,32,108,115,116,32,114,101,115,116,41,0};
static C_char C_TLS li45[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,114,101,118,101,114,115,101,32,108,115,116,48,41,0,0,0};
static C_char C_TLS li46[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,109,101,109,113,32,120,32,108,115,116,41,0,0,0,0,0};
static C_char C_TLS li47[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,109,101,109,118,32,120,32,108,115,116,41,0,0,0,0,0};
static C_char C_TLS li48[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,109,101,109,98,101,114,32,120,32,108,115,116,41,0,0,0};
static C_char C_TLS li49[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,97,115,115,113,32,120,32,108,115,116,41,0,0,0,0,0};
static C_char C_TLS li50[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,97,115,115,118,32,120,32,108,115,116,41,0,0,0,0,0};
static C_char C_TLS li51[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,97,115,115,111,99,32,120,32,108,115,116,41,0,0,0,0};
static C_char C_TLS li52[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,108,105,115,116,63,32,120,41};
static C_char C_TLS li53[] C_aligned={C_lihdr(0,0,18),40,115,99,104,101,109,101,35,115,116,114,105,110,103,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li54[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,108,101,110,103,116,104,32,115,41};
static C_char C_TLS li55[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,114,101,102,32,115,32,105,41,0};
static C_char C_TLS li56[] C_aligned={C_lihdr(0,0,26),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,115,101,116,33,32,115,32,105,32,99,41,0,0,0,0,0,0};
static C_char C_TLS li57[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,115,116,114,105,110,103,61,63,32,120,32,121,41,0,0,0};
static C_char C_TLS li58[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,99,105,61,63,32,120,32,121,41};
static C_char C_TLS li59[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,101,120,97,99,116,45,62,105,110,101,120,97,99,116,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li60[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,97,98,115,32,120,41,0,0};
static C_char C_TLS li61[] C_aligned={C_lihdr(0,0,6),67,95,112,108,117,115,0,0};
static C_char C_TLS li62[] C_aligned={C_lihdr(0,0,7),67,95,109,105,110,117,115,0};
static C_char C_TLS li63[] C_aligned={C_lihdr(0,0,7),67,95,116,105,109,101,115,0};
static C_char C_TLS li64[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,113,117,111,116,105,101,110,116,32,97,32,98,41,0,0,0};
static C_char C_TLS li65[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,114,101,109,97,105,110,100,101,114,32,97,32,98,41,0,0};
static C_char C_TLS li66[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,109,111,100,117,108,111,32,97,32,98,41,0,0,0,0,0};
static C_char C_TLS li67[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,101,118,101,110,63,32,110,41};
static C_char C_TLS li68[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,111,100,100,63,32,110,41,0};
static C_char C_TLS li69[] C_aligned={C_lihdr(0,0,9),67,95,110,101,113,117,97,108,112,0,0,0,0,0,0,0};
static C_char C_TLS li70[] C_aligned={C_lihdr(0,0,10),67,95,103,114,101,97,116,101,114,112,0,0,0,0,0,0};
static C_char C_TLS li71[] C_aligned={C_lihdr(0,0,7),67,95,108,101,115,115,112,0};
static C_char C_TLS li72[] C_aligned={C_lihdr(0,0,20),67,95,103,114,101,97,116,101,114,95,111,114,95,101,113,117,97,108,95,112,0,0,0,0};
static C_char C_TLS li73[] C_aligned={C_lihdr(0,0,17),67,95,108,101,115,115,95,111,114,95,101,113,117,97,108,95,112,0,0,0,0,0,0,0};
static C_char C_TLS li74[] C_aligned={C_lihdr(0,0,18),40,115,99,104,101,109,101,35,110,117,109,98,101,114,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li75[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,114,101,97,108,63,32,120,41};
static C_char C_TLS li76[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,114,97,116,105,111,110,97,108,63,32,110,41,0,0,0,0};
static C_char C_TLS li77[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,105,110,116,101,103,101,114,63,32,120,41,0,0,0,0,0};
static C_char C_TLS li78[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,101,120,97,99,116,63,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li79[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,105,110,101,120,97,99,116,63,32,120,41,0,0,0,0,0};
static C_char C_TLS li80[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,122,101,114,111,63,32,110,41};
static C_char C_TLS li81[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,112,111,115,105,116,105,118,101,63,32,110,41,0,0,0,0};
static C_char C_TLS li82[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,110,101,103,97,116,105,118,101,63,32,110,41,0,0,0,0};
static C_char C_TLS li83[] C_aligned={C_lihdr(0,0,18),67,95,110,117,109,98,101,114,95,116,111,95,115,116,114,105,110,103,0,0,0,0,0,0};
static C_char C_TLS li84[] C_aligned={C_lihdr(0,0,18),40,115,99,104,101,109,101,35,115,121,109,98,111,108,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li85[] C_aligned={C_lihdr(0,0,18),40,115,99,104,101,109,101,35,118,101,99,116,111,114,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li86[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,118,101,99,116,111,114,45,108,101,110,103,116,104,32,118,41};
static C_char C_TLS li87[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,118,101,99,116,111,114,45,114,101,102,32,118,32,105,41,0};
static C_char C_TLS li88[] C_aligned={C_lihdr(0,0,26),40,115,99,104,101,109,101,35,118,101,99,116,111,114,45,115,101,116,33,32,118,32,105,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li89[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,99,104,97,114,63,32,120,41};
static C_char C_TLS li90[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,99,104,97,114,45,62,105,110,116,101,103,101,114,32,99,41};
static C_char C_TLS li91[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,105,110,116,101,103,101,114,45,62,99,104,97,114,32,110,41};
static C_char C_TLS li92[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,99,104,97,114,61,63,32,99,49,32,99,50,41,0,0,0};
static C_char C_TLS li93[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,99,104,97,114,62,63,32,99,49,32,99,50,41,0,0,0};
static C_char C_TLS li94[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,99,104,97,114,60,63,32,99,49,32,99,50,41,0,0,0};
static C_char C_TLS li95[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,99,104,97,114,62,61,63,32,99,49,32,99,50,41,0,0};
static C_char C_TLS li96[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,99,104,97,114,60,61,63,32,99,49,32,99,50,41,0,0};
static C_char C_TLS li97[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,99,104,97,114,45,117,112,99,97,115,101,32,99,41,0,0};
static C_char C_TLS li98[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,99,104,97,114,45,100,111,119,110,99,97,115,101,32,99,41};
static C_char C_TLS li99[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,99,104,97,114,45,117,112,112,101,114,45,99,97,115,101,63,32,99,41,0,0,0,0,0};
static C_char C_TLS li100[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,99,104,97,114,45,108,111,119,101,114,45,99,97,115,101,63,32,99,41,0,0,0,0,0};
static C_char C_TLS li101[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,99,104,97,114,45,110,117,109,101,114,105,99,63,32,99,41};
static C_char C_TLS li102[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,99,104,97,114,45,119,104,105,116,101,115,112,97,99,101,63,32,99,41,0,0,0,0,0};
static C_char C_TLS li103[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,99,104,97,114,45,97,108,112,104,97,98,101,116,105,99,63,32,99,41,0,0,0,0,0};
static C_char C_TLS li104[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,112,114,111,99,101,100,117,114,101,63,32,120,41,0,0,0};
static C_char C_TLS li105[] C_aligned={C_lihdr(0,0,7),67,95,97,112,112,108,121,0};
static C_char C_TLS li106[] C_aligned={C_lihdr(0,0,8),67,95,118,97,108,117,101,115};
static C_char C_TLS li107[] C_aligned={C_lihdr(0,0,18),67,95,99,97,108,108,95,119,105,116,104,95,118,97,108,117,101,115,0,0,0,0,0,0};
static C_char C_TLS li108[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,105,110,112,117,116,45,112,111,114,116,63,32,120,41,0,0};
static C_char C_TLS li109[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,111,117,116,112,117,116,45,112,111,114,116,63,32,120,41,0};
static C_char C_TLS li110[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,101,111,102,45,111,98,106,101,99,116,63,32,120,41,0,0};
static C_char C_TLS li111[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,101,118,97,108,32,120,32,46,32,101,110,118,41,0,0,0};
static C_char C_TLS li112[] C_aligned={C_lihdr(0,0,32),40,115,99,104,101,109,101,35,105,110,116,101,114,97,99,116,105,111,110,45,101,110,118,105,114,111,110,109,101,110,116,41};
static C_char C_TLS li113[] C_aligned={C_lihdr(0,0,36),40,115,99,104,101,109,101,35,115,99,104,101,109,101,45,114,101,112,111,114,116,45,101,110,118,105,114,111,110,109,101,110,116,32,110,41,0,0,0,0};
static C_char C_TLS li114[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,110,117,108,108,45,101,110,118,105,114,111,110,109,101,110,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li115[] C_aligned={C_lihdr(0,0,34),40,115,99,104,101,109,101,35,108,111,97,100,32,102,105,108,101,110,97,109,101,32,46,32,101,118,97,108,117,97,116,111,114,41,0,0,0,0,0,0};
static C_char C_TLS li116[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,105,120,110,117,109,63,32,120,41};
static C_char C_TLS li117[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,108,111,110,117,109,63,32,120,41};
static C_char C_TLS li118[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,98,97,115,101,35,98,105,103,110,117,109,63,32,120,41};
static C_char C_TLS li119[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,98,97,115,101,35,114,97,116,110,117,109,63,32,120,41};
static C_char C_TLS li120[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,112,108,120,110,117,109,63,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li121[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,120,97,99,116,45,105,110,116,101,103,101,114,63,32,120,41,0};
static C_char C_TLS li122[] C_aligned={C_lihdr(0,0,24),67,95,113,117,111,116,105,101,110,116,95,97,110,100,95,114,101,109,97,105,110,100,101,114};
static C_char C_TLS li123[] C_aligned={C_lihdr(0,0,7),40,97,57,52,56,51,41,0};
static C_char C_TLS li124[] C_aligned={C_lihdr(0,0,15),40,97,57,52,56,57,32,100,105,118,32,114,101,109,41,0};
static C_char C_TLS li125[] C_aligned={C_lihdr(0,0,34),40,99,104,105,99,107,101,110,46,98,97,115,101,35,113,117,111,116,105,101,110,116,38,109,111,100,117,108,111,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li126[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,105,110,105,116,101,63,32,120,41};
static C_char C_TLS li127[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,98,97,115,101,35,105,110,102,105,110,105,116,101,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li128[] C_aligned={C_lihdr(0,0,21),40,99,104,105,99,107,101,110,46,98,97,115,101,35,110,97,110,63,32,120,41,0,0,0};
static C_char C_TLS li129[] C_aligned={C_lihdr(0,0,8),67,95,115,105,103,110,117,109};
static C_char C_TLS li130[] C_aligned={C_lihdr(0,0,21),40,99,104,105,99,107,101,110,46,98,97,115,101,35,97,100,100,49,32,110,41,0,0,0};
static C_char C_TLS li131[] C_aligned={C_lihdr(0,0,21),40,99,104,105,99,107,101,110,46,98,97,115,101,35,115,117,98,49,32,110,41,0,0,0};
static C_char C_TLS li132[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,114,114,111,114,32,46,32,97,114,103,115,41,0,0,0,0,0};
static C_char C_TLS li133[] C_aligned={C_lihdr(0,0,23),40,99,104,105,99,107,101,110,46,98,97,115,101,35,118,111,105,100,32,46,32,95,41,0};
static C_char C_TLS li134[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,98,97,115,101,35,112,114,111,109,105,115,101,63,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li135[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,109,97,107,101,45,112,114,111,109,105,115,101,32,112,114,111,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li136[] C_aligned={C_lihdr(0,0,7),40,97,57,54,49,51,41,0};
static C_char C_TLS li137[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,98,97,115,101,35,109,97,107,101,45,112,114,111,109,105,115,101,32,111,98,106,41,0};
static C_char C_TLS li138[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,108,115,116,32,122,41,0,0,0,0};
static C_char C_TLS li139[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,111,108,100,108,32,102,32,122,32,108,115,116,41,0,0,0,0};
static C_char C_TLS li140[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li141[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,111,108,100,114,32,102,32,122,32,108,115,116,41,0,0,0,0};
static C_char C_TLS li142[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,111,110,45,101,120,105,116,32,116,104,117,110,107,41,0,0,0,0};
static C_char C_TLS li143[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,120,105,116,32,46,32,114,101,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li144[] C_aligned={C_lihdr(0,0,36),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,109,101,114,103,101,110,99,121,45,101,120,105,116,32,46,32,114,101,115,116,41,0,0,0,0};
static C_char C_TLS li145[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,98,97,115,101,35,105,100,101,110,116,105,116,121,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li146[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,112,114,101,100,115,41,0,0,0,0};
static C_char C_TLS li147[] C_aligned={C_lihdr(0,0,10),40,102,95,57,55,52,51,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li148[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,111,110,106,111,105,110,32,46,32,112,114,101,100,115,41,0,0};
static C_char C_TLS li149[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,112,114,101,100,115,41,0,0,0,0};
static C_char C_TLS li150[] C_aligned={C_lihdr(0,0,10),40,102,95,57,55,55,54,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li151[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,98,97,115,101,35,100,105,115,106,111,105,110,32,46,32,112,114,101,100,115,41,0,0};
static C_char C_TLS li152[] C_aligned={C_lihdr(0,0,12),40,102,95,57,56,50,50,32,46,32,95,41,0,0,0,0};
static C_char C_TLS li153[] C_aligned={C_lihdr(0,0,12),40,102,95,57,56,50,52,32,46,32,95,41,0,0,0,0};
static C_char C_TLS li154[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,111,110,115,116,97,110,116,108,121,32,46,32,120,115,41,0,0};
static C_char C_TLS li155[] C_aligned={C_lihdr(0,0,12),40,102,95,57,56,51,52,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li156[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,108,105,112,32,112,114,111,99,41};
static C_char C_TLS li157[] C_aligned={C_lihdr(0,0,15),40,102,95,57,56,52,50,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li158[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,111,109,112,108,101,109,101,110,116,32,112,41,0,0,0,0,0};
static C_char C_TLS li159[] C_aligned={C_lihdr(0,0,7),40,97,57,56,54,56,41,0};
static C_char C_TLS li160[] C_aligned={C_lihdr(0,0,15),40,102,95,57,56,54,51,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li161[] C_aligned={C_lihdr(0,0,14),40,114,101,99,32,102,48,32,46,32,102,110,115,41,0,0};
static C_char C_TLS li162[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,111,109,112,111,115,101,32,46,32,102,110,115,41,0,0,0,0};
static C_char C_TLS li163[] C_aligned={C_lihdr(0,0,10),40,102,95,57,57,49,52,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li164[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,102,110,115,41,0,0,0,0,0,0};
static C_char C_TLS li165[] C_aligned={C_lihdr(0,0,22),40,99,104,105,99,107,101,110,46,98,97,115,101,35,111,32,46,32,102,110,115,41,0,0};
static C_char C_TLS li166[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li167[] C_aligned={C_lihdr(0,0,12),40,102,95,57,57,50,57,32,108,115,116,41,0,0,0,0};
static C_char C_TLS li168[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,108,105,115,116,45,111,102,63,32,112,114,101,100,41,0,0,0,0};
static C_char C_TLS li169[] C_aligned={C_lihdr(0,0,12),40,102,95,57,57,55,57,32,46,32,95,41,0,0,0,0};
static C_char C_TLS li170[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,112,114,111,99,115,41,0,0,0,0};
static C_char C_TLS li171[] C_aligned={C_lihdr(0,0,15),40,102,95,57,57,57,51,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li172[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,97,99,104,32,46,32,112,114,111,99,115,41,0,0,0,0,0};
static C_char C_TLS li173[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,98,119,112,45,111,98,106,101,99,116,63,32,120,41,0,0,0,0};
static C_char C_TLS li174[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,119,101,97,107,45,99,111,110,115,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li175[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,97,115,101,35,119,101,97,107,45,112,97,105,114,63,32,120,41,0,0,0,0,0};
static C_char C_TLS li176[] C_aligned={C_lihdr(0,0,22),40,99,104,105,99,107,101,110,46,98,97,115,101,35,97,116,111,109,63,32,120,41,0,0};
static C_char C_TLS li177[] C_aligned={C_lihdr(0,0,6),40,108,111,111,112,41,0,0};
static C_char C_TLS li178[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,98,97,115,101,35,116,97,105,108,63,32,120,32,121,41};
static C_char C_TLS li179[] C_aligned={C_lihdr(0,0,9),40,108,111,111,112,32,110,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li180[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,98,97,115,101,35,105,110,116,101,114,115,112,101,114,115,101,32,108,115,116,32,120,41};
static C_char C_TLS li181[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li182[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,98,97,115,101,35,98,117,116,108,97,115,116,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li183[] C_aligned={C_lihdr(0,0,17),40,108,111,111,112,32,108,105,115,116,115,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li184[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,108,97,116,116,101,110,32,46,32,108,105,115,116,115,48,41,0};
static C_char C_TLS li185[] C_aligned={C_lihdr(0,0,11),40,108,111,111,112,32,108,115,116,115,41,0,0,0,0,0};
static C_char C_TLS li186[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,98,97,115,101,35,106,111,105,110,32,108,115,116,115,32,46,32,108,115,116,41,0,0};
static C_char C_TLS li187[] C_aligned={C_lihdr(0,0,15),40,108,111,111,112,32,98,108,115,116,32,108,115,116,41,0};
static C_char C_TLS li188[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,111,109,112,114,101,115,115,32,98,108,115,116,32,108,115,116,41};
static C_char C_TLS li189[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li190[] C_aligned={C_lihdr(0,0,15),40,102,95,49,48,51,52,57,32,120,32,108,115,116,41,0};
static C_char C_TLS li191[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,98,97,115,101,35,97,108,105,115,116,45,117,112,100,97,116,101,33,32,120,32,121,32,108,115,116,32,46,32,114,101,115,116,41,0,0,0,0,0};
static C_char C_TLS li192[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li193[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,98,97,115,101,35,97,108,105,115,116,45,117,112,100,97,116,101,32,107,32,118,32,108,115,116,32,46,32,114,101,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li194[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li195[] C_aligned={C_lihdr(0,0,15),40,102,95,49,48,53,52,49,32,120,32,108,115,116,41,0};
static C_char C_TLS li196[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,98,97,115,101,35,97,108,105,115,116,45,114,101,102,32,120,32,108,115,116,32,46,32,114,101,115,116,41,0,0,0};
static C_char C_TLS li197[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,108,41};
static C_char C_TLS li198[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,98,97,115,101,35,114,97,115,115,111,99,32,120,32,108,115,116,32,46,32,116,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li199[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,43,32,120,32,121,41};
static C_char C_TLS li200[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,45,32,120,32,121,41};
static C_char C_TLS li201[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,42,32,120,32,121,41};
static C_char C_TLS li202[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,61,32,120,32,121,41};
static C_char C_TLS li203[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,62,32,120,32,121,41};
static C_char C_TLS li204[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,60,32,120,32,121,41};
static C_char C_TLS li205[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,62,61,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li206[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,60,61,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li207[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,109,105,110,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li208[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,109,97,120,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li209[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,110,101,103,32,120,41};
static C_char C_TLS li210[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,97,110,100,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li211[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,105,111,114,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li212[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,120,111,114,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li213[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,110,111,116,32,120,41};
static C_char C_TLS li214[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,115,104,108,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li215[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,115,104,114,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li216[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,111,100,100,63,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li217[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,101,118,101,110,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li218[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,108,101,110,32,120,41};
static C_char C_TLS li219[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,47,32,120,32,121,41};
static C_char C_TLS li220[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,103,99,100,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li221[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,109,111,100,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li222[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,114,101,109,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li223[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,43,63,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li224[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,45,63,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li225[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,42,63,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li226[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,105,120,110,117,109,35,102,120,47,63,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li227[] C_aligned={C_lihdr(0,0,19),40,35,35,115,121,115,35,100,101,98,117,103,45,109,111,100,101,63,41,0,0,0,0,0};
static C_char C_TLS li228[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,98,97,115,101,35,119,97,114,110,105,110,103,32,109,115,103,32,46,32,97,114,103,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li229[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,98,97,115,101,35,110,111,116,105,99,101,32,109,115,103,32,46,32,97,114,103,115,41};
static C_char C_TLS li230[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,110,97,98,108,101,45,119,97,114,110,105,110,103,115,32,46,32,98,111,111,108,41,0,0,0};
static C_char C_TLS li231[] C_aligned={C_lihdr(0,0,30),40,35,35,115,121,115,35,101,114,114,111,114,47,101,114,114,110,111,32,101,114,114,32,46,32,97,114,103,115,41,0,0};
static C_char C_TLS li232[] C_aligned={C_lihdr(0,0,4),67,95,103,99,0,0,0,0};
static C_char C_TLS li233[] C_aligned={C_lihdr(0,0,21),40,35,35,115,121,115,35,115,101,116,115,108,111,116,32,120,32,105,32,121,41,0,0,0};
static C_char C_TLS li234[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,115,101,116,105,115,108,111,116,32,120,32,105,32,121,41,0,0};
static C_char C_TLS li235[] C_aligned={C_lihdr(0,0,17),67,95,97,108,108,111,99,97,116,101,95,118,101,99,116,111,114,0,0,0,0,0,0,0};
static C_char C_TLS li236[] C_aligned={C_lihdr(0,0,16),67,95,109,97,107,101,95,115,116,114,117,99,116,117,114,101};
static C_char C_TLS li237[] C_aligned={C_lihdr(0,0,21),67,95,101,110,115,117,114,101,95,104,101,97,112,95,114,101,115,101,114,118,101,0,0,0};
static C_char C_TLS li238[] C_aligned={C_lihdr(0,0,23),67,95,103,101,116,95,115,121,109,98,111,108,95,116,97,98,108,101,95,105,110,102,111,0};
static C_char C_TLS li239[] C_aligned={C_lihdr(0,0,17),67,95,103,101,116,95,109,101,109,111,114,121,95,105,110,102,111,0,0,0,0,0,0,0};
static C_char C_TLS li240[] C_aligned={C_lihdr(0,0,19),40,35,35,115,121,115,35,115,116,97,114,116,45,116,105,109,101,114,41,0,0,0,0,0};
static C_char C_TLS li241[] C_aligned={C_lihdr(0,0,12),67,95,115,116,111,112,95,116,105,109,101,114,0,0,0,0};
static C_char C_TLS li242[] C_aligned={C_lihdr(0,0,12),67,95,115,116,111,112,95,116,105,109,101,114,0,0,0,0};
static C_char C_TLS li243[] C_aligned={C_lihdr(0,0,18),40,35,35,115,121,115,35,115,116,111,112,45,116,105,109,101,114,41,0,0,0,0,0,0};
static C_char C_TLS li244[] C_aligned={C_lihdr(0,0,20),40,35,35,115,121,115,35,105,109,109,101,100,105,97,116,101,63,32,120,41,0,0,0,0};
static C_char C_TLS li245[] C_aligned={C_lihdr(0,0,19),40,35,35,115,121,115,35,109,101,115,115,97,103,101,32,115,116,114,41,0,0,0,0,0};
static C_char C_TLS li246[] C_aligned={C_lihdr(0,0,16),40,35,35,115,121,115,35,98,121,116,101,32,120,32,105,41};
static C_char C_TLS li247[] C_aligned={C_lihdr(0,0,21),40,35,35,115,121,115,35,115,101,116,98,121,116,101,32,120,32,105,32,110,41,0,0,0};
static C_char C_TLS li248[] C_aligned={C_lihdr(0,0,16),40,35,35,115,121,115,35,104,97,108,116,32,109,115,103,41};
static C_char C_TLS li249[] C_aligned={C_lihdr(0,0,8),67,95,98,101,99,111,109,101};
static C_char C_TLS li250[] C_aligned={C_lihdr(0,0,21),40,35,35,115,121,115,35,98,108,111,99,107,45,114,101,102,32,120,32,105,41,0,0,0};
static C_char C_TLS li251[] C_aligned={C_lihdr(0,0,14),67,95,97,112,112,108,121,95,118,97,108,117,101,115,0,0};
static C_char C_TLS li252[] C_aligned={C_lihdr(0,0,14),67,95,99,111,112,121,95,99,108,111,115,117,114,101,0,0};
static C_char C_TLS li253[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,98,108,111,99,107,45,115,101,116,33,32,120,32,105,32,121,41};
static C_char C_TLS li254[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,116,105,109,101,35,99,117,114,114,101,110,116,45,109,105,108,108,105,115,101,99,111,110,100,115,41,0,0,0,0,0};
static C_char C_TLS li255[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,116,105,109,101,35,99,117,114,114,101,110,116,45,112,114,111,99,101,115,115,45,109,105,108,108,105,115,101,99,111,110,100,115,41,0,0,0,0,0};
static C_char C_TLS li256[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,116,105,109,101,35,99,117,114,114,101,110,116,45,115,101,99,111,110,100,115,41,0,0};
static C_char C_TLS li257[] C_aligned={C_lihdr(0,0,23),40,99,104,105,99,107,101,110,46,116,105,109,101,35,99,112,117,45,116,105,109,101,41,0};
static C_char C_TLS li258[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,99,104,101,99,107,45,115,116,114,117,99,116,117,114,101,32,120,32,121,32,46,32,108,111,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li259[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,99,104,101,99,107,45,98,108,111,98,32,120,32,46,32,108,111,99,41,0,0,0,0,0,0};
static C_char C_TLS li260[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,99,104,101,99,107,45,112,97,105,114,32,120,32,46,32,108,111,99,41,0,0,0,0,0,0};
static C_char C_TLS li261[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,99,104,101,99,107,45,108,105,115,116,32,120,32,46,32,108,111,99,41,0,0,0,0,0,0};
static C_char C_TLS li262[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,99,104,101,99,107,45,115,116,114,105,110,103,32,120,32,46,32,108,111,99,41,0,0,0,0};
static C_char C_TLS li263[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,99,104,101,99,107,45,110,117,109,98,101,114,32,120,32,46,32,108,111,99,41,0,0,0,0};
static C_char C_TLS li264[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,99,104,101,99,107,45,102,105,120,110,117,109,32,120,32,46,32,108,111,99,41,0,0,0,0};
static C_char C_TLS li265[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,99,104,101,99,107,45,101,120,97,99,116,32,120,32,46,32,108,111,99,41,0,0,0,0,0};
static C_char C_TLS li266[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,99,104,101,99,107,45,105,110,101,120,97,99,116,32,120,32,46,32,108,111,99,41,0,0,0};
static C_char C_TLS li267[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,99,104,101,99,107,45,115,121,109,98,111,108,32,120,32,46,32,108,111,99,41,0,0,0,0};
static C_char C_TLS li268[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,99,104,101,99,107,45,107,101,121,119,111,114,100,32,120,32,46,32,108,111,99,41,0,0,0};
static C_char C_TLS li269[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,99,104,101,99,107,45,118,101,99,116,111,114,32,120,32,46,32,108,111,99,41,0,0,0,0};
static C_char C_TLS li270[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,99,104,101,99,107,45,99,104,97,114,32,120,32,46,32,108,111,99,41,0,0,0,0,0,0};
static C_char C_TLS li271[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,99,104,101,99,107,45,98,111,111,108,101,97,110,32,120,32,46,32,108,111,99,41,0,0,0};
static C_char C_TLS li272[] C_aligned={C_lihdr(0,0,30),40,35,35,115,121,115,35,99,104,101,99,107,45,108,111,99,97,116,105,118,101,32,120,32,46,32,108,111,99,41,0,0};
static C_char C_TLS li273[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,99,104,101,99,107,45,105,110,116,101,103,101,114,32,120,32,46,32,108,111,99,41,0,0,0};
static C_char C_TLS li274[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,99,104,101,99,107,45,101,120,97,99,116,45,105,110,116,101,103,101,114,32,120,32,46,32,108,111,99,41,0,0,0,0,0};
static C_char C_TLS li275[] C_aligned={C_lihdr(0,0,36),40,35,35,115,121,115,35,99,104,101,99,107,45,101,120,97,99,116,45,117,105,110,116,101,103,101,114,32,120,32,46,32,108,111,99,41,0,0,0,0};
static C_char C_TLS li276[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,99,104,101,99,107,45,114,101,97,108,32,120,32,46,32,108,111,99,41,0,0,0,0,0,0};
static C_char C_TLS li277[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,99,104,101,99,107,45,114,97,110,103,101,32,105,32,102,114,111,109,32,116,111,32,46,32,108,111,99,41,0,0,0,0,0};
static C_char C_TLS li278[] C_aligned={C_lihdr(0,0,31),40,35,35,115,121,115,35,99,104,101,99,107,45,115,112,101,99,105,97,108,32,112,116,114,32,46,32,108,111,99,41,0};
static C_char C_TLS li279[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,99,104,101,99,107,45,99,108,111,115,117,114,101,32,120,32,46,32,108,111,99,41,0,0,0};
static C_char C_TLS li280[] C_aligned={C_lihdr(0,0,20),40,108,112,32,112,114,111,109,105,115,101,32,102,111,114,119,97,114,100,41,0,0,0,0};
static C_char C_TLS li281[] C_aligned={C_lihdr(0,0,18),40,115,99,104,101,109,101,35,102,111,114,99,101,32,111,98,106,41,0,0,0,0,0,0};
static C_char C_TLS li282[] C_aligned={C_lihdr(0,0,7),67,95,100,108,111,97,100,0};
static C_char C_TLS li283[] C_aligned={C_lihdr(0,0,18),67,95,115,101,116,95,100,108,111,112,101,110,95,102,108,97,103,115,0,0,0,0,0,0};
static C_char C_TLS li284[] C_aligned={C_lihdr(0,0,42),40,35,35,115,121,115,35,101,114,114,111,114,45,110,111,116,45,97,45,112,114,111,112,101,114,45,108,105,115,116,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li285[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,101,114,114,111,114,45,98,97,100,45,110,117,109,98,101,114,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0,0};
static C_char C_TLS li286[] C_aligned={C_lihdr(0,0,36),40,35,35,115,121,115,35,101,114,114,111,114,45,98,97,100,45,105,110,116,101,103,101,114,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0};
static C_char C_TLS li287[] C_aligned={C_lihdr(0,0,42),40,35,35,115,121,115,35,101,114,114,111,114,45,98,97,100,45,101,120,97,99,116,45,105,110,116,101,103,101,114,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li288[] C_aligned={C_lihdr(0,0,43),40,35,35,115,121,115,35,101,114,114,111,114,45,98,97,100,45,101,120,97,99,116,45,117,105,110,116,101,103,101,114,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0,0};
static C_char C_TLS li289[] C_aligned={C_lihdr(0,0,36),40,35,35,115,121,115,35,101,114,114,111,114,45,98,97,100,45,105,110,101,120,97,99,116,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0};
static C_char C_TLS li290[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,101,114,114,111,114,45,98,97,100,45,114,101,97,108,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li291[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,101,114,114,111,114,45,98,97,100,45,98,97,115,101,32,97,114,103,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li292[] C_aligned={C_lihdr(0,0,11),40,99,111,112,121,32,110,111,100,101,41,0,0,0,0,0};
static C_char C_TLS li293[] C_aligned={C_lihdr(0,0,11),40,108,111,111,112,32,108,115,116,115,41,0,0,0,0,0};
static C_char C_TLS li294[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,97,112,112,101,110,100,32,46,32,108,115,116,115,41,0,0};
static C_char C_TLS li295[] C_aligned={C_lihdr(0,0,15),40,108,111,111,112,32,108,115,116,32,114,101,115,116,41,0};
static C_char C_TLS li296[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,102,97,115,116,45,114,101,118,101,114,115,101,32,108,115,116,48,41,0,0,0,0,0,0,0};
static C_char C_TLS li297[] C_aligned={C_lihdr(0,0,31),40,35,35,115,121,115,35,109,97,107,101,45,115,116,114,105,110,103,32,115,105,122,101,32,46,32,114,101,115,116,41,0};
static C_char C_TLS li298[] C_aligned={C_lihdr(0,0,32),40,115,99,104,101,109,101,35,109,97,107,101,45,115,116,114,105,110,103,32,115,105,122,101,32,46,32,102,105,108,108,41};
static C_char C_TLS li299[] C_aligned={C_lihdr(0,0,11),40,108,111,111,112,32,105,32,108,115,41,0,0,0,0,0};
static C_char C_TLS li300[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,62,108,105,115,116,32,115,41,0};
static C_char C_TLS li301[] C_aligned={C_lihdr(0,0,16),40,100,111,108,111,111,112,49,53,51,57,32,108,115,116,41};
static C_char C_TLS li302[] C_aligned={C_lihdr(0,0,26),40,115,99,104,101,109,101,35,108,105,115,116,45,62,115,116,114,105,110,103,32,108,115,116,48,41,0,0,0,0,0,0};
static C_char C_TLS li303[] C_aligned={C_lihdr(0,0,9),40,105,116,101,114,32,110,50,41,0,0,0,0,0,0,0};
static C_char C_TLS li304[] C_aligned={C_lihdr(0,0,30),40,35,35,115,121,115,35,114,101,118,101,114,115,101,45,108,105,115,116,45,62,115,116,114,105,110,103,32,108,41,0,0};
static C_char C_TLS li305[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,102,105,108,108,33,32,115,32,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li306[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,99,111,112,121,32,115,41,0,0};
static C_char C_TLS li307[] C_aligned={C_lihdr(0,0,32),40,115,99,104,101,109,101,35,115,117,98,115,116,114,105,110,103,32,115,32,115,116,97,114,116,32,46,32,101,110,100,41};
static C_char C_TLS li308[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,115,117,98,115,116,114,105,110,103,32,115,32,115,116,97,114,116,32,101,110,100,41,0,0,0};
static C_char C_TLS li309[] C_aligned={C_lihdr(0,0,25),40,99,111,109,112,97,114,101,49,53,57,50,32,115,49,32,115,50,32,108,111,99,32,107,41,0,0,0,0,0,0,0};
static C_char C_TLS li310[] C_aligned={C_lihdr(0,0,22),40,97,49,49,57,48,56,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li311[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,115,116,114,105,110,103,60,63,32,115,49,32,115,50,41,0};
static C_char C_TLS li312[] C_aligned={C_lihdr(0,0,22),40,97,49,49,57,51,50,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li313[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,115,116,114,105,110,103,62,63,32,115,49,32,115,50,41,0};
static C_char C_TLS li314[] C_aligned={C_lihdr(0,0,22),40,97,49,49,57,53,54,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li315[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,115,116,114,105,110,103,60,61,63,32,115,49,32,115,50,41};
static C_char C_TLS li316[] C_aligned={C_lihdr(0,0,22),40,97,49,49,57,55,55,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li317[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,115,116,114,105,110,103,62,61,63,32,115,49,32,115,50,41};
static C_char C_TLS li318[] C_aligned={C_lihdr(0,0,25),40,99,111,109,112,97,114,101,49,54,51,53,32,115,49,32,115,50,32,108,111,99,32,107,41,0,0,0,0,0,0,0};
static C_char C_TLS li319[] C_aligned={C_lihdr(0,0,22),40,97,49,50,48,49,56,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li320[] C_aligned={C_lihdr(0,0,26),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,99,105,60,63,32,115,49,32,115,50,41,0,0,0,0,0,0};
static C_char C_TLS li321[] C_aligned={C_lihdr(0,0,22),40,97,49,50,48,52,50,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li322[] C_aligned={C_lihdr(0,0,26),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,99,105,62,63,32,115,49,32,115,50,41,0,0,0,0,0,0};
static C_char C_TLS li323[] C_aligned={C_lihdr(0,0,22),40,97,49,50,48,54,54,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li324[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,99,105,60,61,63,32,115,49,32,115,50,41,0,0,0,0,0};
static C_char C_TLS li325[] C_aligned={C_lihdr(0,0,22),40,97,49,50,48,56,55,32,108,101,110,49,32,108,101,110,50,32,99,109,112,41,0,0};
static C_char C_TLS li326[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,99,105,62,61,63,32,115,49,32,115,50,41,0,0,0,0,0};
static C_char C_TLS li327[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,115,116,114,105,110,103,45,97,112,112,101,110,100,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li328[] C_aligned={C_lihdr(0,0,13),40,108,111,111,112,32,115,116,114,115,32,110,41,0,0,0};
static C_char C_TLS li329[] C_aligned={C_lihdr(0,0,28),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,97,112,112,101,110,100,32,46,32,97,108,108,41,0,0,0,0};
static C_char C_TLS li330[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,115,116,114,105,110,103,32,46,32,99,104,97,114,115,41,0};
static C_char C_TLS li331[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,112,111,115,41,0,0,0,0,0,0};
static C_char C_TLS li332[] C_aligned={C_lihdr(0,0,34),40,35,35,115,121,115,35,102,114,97,103,109,101,110,116,115,45,62,115,116,114,105,110,103,32,116,111,116,97,108,32,102,115,41,0,0,0,0,0,0};
static C_char C_TLS li333[] C_aligned={C_lihdr(0,0,20),40,100,111,108,111,111,112,49,55,50,48,32,104,100,32,116,108,32,99,41,0,0,0,0};
static C_char C_TLS li334[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,108,115,116,32,105,41,0,0,0,0};
static C_char C_TLS li335[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,104,111,112,32,108,115,116,32,110,41,0,0,0,0,0,0,0};
static C_char C_TLS li336[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,43,32,120,32,121,41};
static C_char C_TLS li337[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,45,32,120,32,121,41};
static C_char C_TLS li338[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,42,32,120,32,121,41};
static C_char C_TLS li339[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,47,32,120,32,121,41};
static C_char C_TLS li340[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,42,43,32,120,32,121,32,122,41,0,0,0,0,0};
static C_char C_TLS li341[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,103,99,100,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li342[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,47,63,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li343[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,61,32,120,32,121,41};
static C_char C_TLS li344[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,62,32,120,32,121,41};
static C_char C_TLS li345[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,60,32,120,32,121,41};
static C_char C_TLS li346[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,62,61,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li347[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,60,61,32,120,32,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li348[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,110,101,103,32,120,41};
static C_char C_TLS li349[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,109,97,120,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li350[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,109,105,110,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li351[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,102,108,111,111,114,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li352[] C_aligned={C_lihdr(0,0,29),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,116,114,117,110,99,97,116,101,32,120,41,0,0,0};
static C_char C_TLS li353[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,114,111,117,110,100,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li354[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,99,101,105,108,105,110,103,32,120,41,0,0,0,0};
static C_char C_TLS li355[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,115,105,110,32,120,41};
static C_char C_TLS li356[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,99,111,115,32,120,41};
static C_char C_TLS li357[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,116,97,110,32,120,41};
static C_char C_TLS li358[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,115,105,110,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li359[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,99,111,115,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li360[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,116,97,110,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li361[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,116,97,110,50,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li362[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,115,105,110,104,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li363[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,99,111,115,104,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li364[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,116,97,110,104,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li365[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,115,105,110,104,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li366[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,99,111,115,104,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li367[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,116,97,110,104,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li368[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,101,120,112,32,120,41};
static C_char C_TLS li369[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,101,120,112,116,32,120,32,121,41,0,0,0,0,0};
static C_char C_TLS li370[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,108,111,103,32,120,41};
static C_char C_TLS li371[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,115,113,114,116,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li372[] C_aligned={C_lihdr(0,0,24),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,97,98,115,32,120,41};
static C_char C_TLS li373[] C_aligned={C_lihdr(0,0,29),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,112,105,110,116,101,103,101,114,63,32,120,41,0,0,0};
static C_char C_TLS li374[] C_aligned={C_lihdr(0,0,46),40,99,104,105,99,107,101,110,46,102,108,111,110,117,109,35,102,108,111,110,117,109,45,112,114,105,110,116,45,112,114,101,99,105,115,105,111,110,32,46,32,114,101,115,116,41,0,0};
static C_char C_TLS li375[] C_aligned={C_lihdr(0,0,18),40,109,97,107,101,45,99,111,109,112,108,101,120,32,114,32,105,41,0,0,0,0,0,0};
static C_char C_TLS li376[] C_aligned={C_lihdr(0,0,29),40,115,99,104,101,109,101,35,109,97,107,101,45,114,101,99,116,97,110,103,117,108,97,114,32,114,32,105,41,0,0,0};
static C_char C_TLS li377[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,109,97,107,101,45,112,111,108,97,114,32,114,32,112,104,105,41,0,0,0,0,0,0,0};
static C_char C_TLS li378[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,114,101,97,108,45,112,97,114,116,32,120,41,0,0,0,0};
static C_char C_TLS li379[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,105,109,97,103,45,112,97,114,116,32,120,41,0,0,0,0};
static C_char C_TLS li380[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,97,110,103,108,101,32,110,41};
static C_char C_TLS li381[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,109,97,103,110,105,116,117,100,101,32,120,41,0,0,0,0};
static C_char C_TLS li382[] C_aligned={C_lihdr(0,0,10),40,114,97,116,110,117,109,32,110,41,0,0,0,0,0,0};
static C_char C_TLS li383[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,110,117,109,101,114,97,116,111,114,32,110,41,0,0,0,0};
static C_char C_TLS li384[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,100,101,110,111,109,105,110,97,116,111,114,32,110,41,0,0};
static C_char C_TLS li385[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,101,120,116,101,110,100,101,100,45,115,105,103,110,117,109,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li386[] C_aligned={C_lihdr(0,0,16),40,100,111,108,111,111,112,50,50,57,52,32,120,32,105,41};
static C_char C_TLS li387[] C_aligned={C_lihdr(0,0,13),40,100,101,108,105,118,101,114,32,121,32,100,41,0,0,0};
static C_char C_TLS li388[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,105,110,101,120,97,99,116,45,62,101,120,97,99,116,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li389[] C_aligned={C_lihdr(0,0,13),67,95,98,105,116,119,105,115,101,95,97,110,100,0,0,0};
static C_char C_TLS li390[] C_aligned={C_lihdr(0,0,13),67,95,98,105,116,119,105,115,101,95,105,111,114,0,0,0};
static C_char C_TLS li391[] C_aligned={C_lihdr(0,0,13),67,95,98,105,116,119,105,115,101,95,120,111,114,0,0,0};
static C_char C_TLS li392[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,98,105,116,119,105,115,101,35,98,105,116,119,105,115,101,45,110,111,116,32,110,41,0};
static C_char C_TLS li393[] C_aligned={C_lihdr(0,0,34),40,99,104,105,99,107,101,110,46,98,105,116,119,105,115,101,35,98,105,116,45,62,98,111,111,108,101,97,110,32,110,32,105,41,0,0,0,0,0,0};
static C_char C_TLS li394[] C_aligned={C_lihdr(0,0,34),40,99,104,105,99,107,101,110,46,98,105,116,119,105,115,101,35,105,110,116,101,103,101,114,45,108,101,110,103,116,104,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li395[] C_aligned={C_lihdr(0,0,38),40,99,104,105,99,107,101,110,46,98,105,116,119,105,115,101,35,97,114,105,116,104,109,101,116,105,99,45,115,104,105,102,116,32,110,32,109,41,0,0};
static C_char C_TLS li396[] C_aligned={C_lihdr(0,0,13),40,108,111,111,112,32,97,114,103,115,32,120,41,0,0,0};
static C_char C_TLS li397[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,47,32,97,114,103,49,32,46,32,97,114,103,115,41,0,0};
static C_char C_TLS li398[] C_aligned={C_lihdr(0,0,15),40,35,35,115,121,115,35,47,45,50,32,120,32,121,41,0};
static C_char C_TLS li399[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,102,108,111,111,114,32,120,41};
static C_char C_TLS li400[] C_aligned={C_lihdr(0,0,18),40,115,99,104,101,109,101,35,99,101,105,108,105,110,103,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li401[] C_aligned={C_lihdr(0,0,19),40,115,99,104,101,109,101,35,116,114,117,110,99,97,116,101,32,120,41,0,0,0,0,0};
static C_char C_TLS li402[] C_aligned={C_lihdr(0,0,16),40,115,99,104,101,109,101,35,114,111,117,110,100,32,120,41};
static C_char C_TLS li403[] C_aligned={C_lihdr(0,0,8),40,115,114,32,120,32,121,41};
static C_char C_TLS li404[] C_aligned={C_lihdr(0,0,24),40,102,105,110,100,45,114,97,116,105,111,45,98,101,116,119,101,101,110,32,120,32,121,41};
static C_char C_TLS li405[] C_aligned={C_lihdr(0,0,24),40,115,99,104,101,109,101,35,114,97,116,105,111,110,97,108,105,122,101,32,120,32,101,41};
static C_char C_TLS li406[] C_aligned={C_lihdr(0,0,13),40,108,111,111,112,32,105,32,109,32,120,115,41,0,0,0};
static C_char C_TLS li407[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,109,97,120,32,120,49,32,46,32,120,115,41,0,0,0,0};
static C_char C_TLS li408[] C_aligned={C_lihdr(0,0,13),40,108,111,111,112,32,105,32,109,32,120,115,41,0,0,0};
static C_char C_TLS li409[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,109,105,110,32,120,49,32,46,32,120,115,41,0,0,0,0};
static C_char C_TLS li410[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,101,120,112,32,110,41,0,0};
static C_char C_TLS li411[] C_aligned={C_lihdr(0,0,15),40,35,35,115,121,115,35,108,111,103,45,49,32,120,41,0};
static C_char C_TLS li412[] C_aligned={C_lihdr(0,0,21),40,115,99,104,101,109,101,35,108,111,103,32,97,32,46,32,114,101,115,116,41,0,0,0};
static C_char C_TLS li413[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,115,105,110,32,110,41,0,0};
static C_char C_TLS li414[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,99,111,115,32,110,41,0,0};
static C_char C_TLS li415[] C_aligned={C_lihdr(0,0,14),40,115,99,104,101,109,101,35,116,97,110,32,110,41,0,0};
static C_char C_TLS li416[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,97,115,105,110,32,110,41,0};
static C_char C_TLS li417[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,97,99,111,115,32,110,41,0};
static C_char C_TLS li418[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,97,116,97,110,32,110,32,46,32,114,101,115,116,41,0,0};
static C_char C_TLS li419[] C_aligned={C_lihdr(0,0,8),40,97,49,52,56,52,49,41};
static C_char C_TLS li420[] C_aligned={C_lihdr(0,0,34),67,95,117,95,105,110,116,101,103,101,114,95,113,117,111,116,105,101,110,116,95,97,110,100,95,114,101,109,97,105,110,100,101,114,0,0,0,0,0,0};
static C_char C_TLS li421[] C_aligned={C_lihdr(0,0,8),40,97,49,52,56,55,50,41};
static C_char C_TLS li422[] C_aligned={C_lihdr(0,0,20),40,97,49,52,56,56,56,32,113,50,54,54,50,32,117,50,54,54,52,41,0,0,0,0};
static C_char C_TLS li423[] C_aligned={C_lihdr(0,0,22),40,97,49,52,56,53,53,32,115,94,50,54,52,50,32,114,94,50,54,52,52,41,0,0};
static C_char C_TLS li424[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,101,120,97,99,116,45,105,110,116,101,103,101,114,45,115,113,114,116,32,97,41,0,0,0,0};
static C_char C_TLS li425[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,120,97,99,116,45,105,110,116,101,103,101,114,45,115,113,114,116,32,120,41,0,0,0,0,0};
static C_char C_TLS li426[] C_aligned={C_lihdr(0,0,8),40,97,49,53,48,50,57,41};
static C_char C_TLS li427[] C_aligned={C_lihdr(0,0,14),40,97,49,53,48,51,53,32,115,94,50,32,114,41,0,0};
static C_char C_TLS li428[] C_aligned={C_lihdr(0,0,8),40,97,49,53,48,53,55,41};
static C_char C_TLS li429[] C_aligned={C_lihdr(0,0,8),40,97,49,53,48,56,49,41};
static C_char C_TLS li430[] C_aligned={C_lihdr(0,0,16),40,97,49,53,48,57,51,32,100,115,94,50,32,100,114,41};
static C_char C_TLS li431[] C_aligned={C_lihdr(0,0,16),40,97,49,53,48,54,57,32,110,115,94,50,32,110,114,41};
static C_char C_TLS li432[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,115,113,114,116,47,108,111,99,32,108,111,99,32,110,41,0,0};
static C_char C_TLS li433[] C_aligned={C_lihdr(0,0,15),40,115,99,104,101,109,101,35,115,113,114,116,32,120,41,0};
static C_char C_TLS li434[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,120,97,99,116,45,105,110,116,101,103,101,114,45,110,116,104,45,114,111,111,116,32,107,32,110,41,0,0,0,0,0,0,0};
static C_char C_TLS li435[] C_aligned={C_lihdr(0,0,10),40,108,112,32,103,48,32,103,49,41,0,0,0,0,0,0};
static C_char C_TLS li436[] C_aligned={C_lihdr(0,0,42),40,35,35,115,121,115,35,101,120,97,99,116,45,105,110,116,101,103,101,114,45,110,116,104,45,114,111,111,116,47,108,111,99,32,108,111,99,32,107,32,110,41,0,0,0,0,0,0};
static C_char C_TLS li437[] C_aligned={C_lihdr(0,0,11),40,108,112,32,114,101,115,32,101,50,41,0,0,0,0,0};
static C_char C_TLS li438[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,105,110,116,101,103,101,114,45,112,111,119,101,114,32,98,97,115,101,32,101,41,0,0,0,0};
static C_char C_TLS li439[] C_aligned={C_lihdr(0,0,14),40,108,111,103,45,101,120,112,116,32,97,32,98,41,0,0};
static C_char C_TLS li440[] C_aligned={C_lihdr(0,0,15),40,115,108,111,119,45,101,120,112,116,32,97,32,98,41,0};
static C_char C_TLS li441[] C_aligned={C_lihdr(0,0,8),40,97,49,53,52,53,48,41};
static C_char C_TLS li442[] C_aligned={C_lihdr(0,0,15),40,97,49,53,52,54,50,32,100,115,94,110,32,114,41,0};
static C_char C_TLS li443[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,101,120,112,116,32,97,32,98,41,0,0,0,0,0,0,0};
static C_char C_TLS li444[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,105,110,116,101,114,110,97,108,45,103,99,100,32,108,111,99,32,97,32,98,41,0,0,0,0};
static C_char C_TLS li445[] C_aligned={C_lihdr(0,0,15),40,35,35,115,121,115,35,103,99,100,32,97,32,98,41,0};
static C_char C_TLS li446[] C_aligned={C_lihdr(0,0,16),40,108,111,111,112,32,104,101,97,100,32,110,101,120,116,41};
static C_char C_TLS li447[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,103,99,100,32,46,32,110,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li448[] C_aligned={C_lihdr(0,0,15),40,35,35,115,121,115,35,108,99,109,32,120,32,121,41,0};
static C_char C_TLS li449[] C_aligned={C_lihdr(0,0,16),40,108,111,111,112,32,104,101,97,100,32,110,101,120,116,41};
static C_char C_TLS li450[] C_aligned={C_lihdr(0,0,17),40,115,99,104,101,109,101,35,108,99,109,32,46,32,110,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li451[] C_aligned={C_lihdr(0,0,34),67,95,117,95,105,110,116,101,103,101,114,95,113,117,111,116,105,101,110,116,95,97,110,100,95,114,101,109,97,105,110,100,101,114,0,0,0,0,0,0};
static C_char C_TLS li452[] C_aligned={C_lihdr(0,0,8),40,97,49,53,56,49,51,41};
static C_char C_TLS li453[] C_aligned={C_lihdr(0,0,22),40,97,49,53,56,49,57,32,104,105,50,56,52,55,32,108,111,50,56,52,57,41,0,0};
static C_char C_TLS li454[] C_aligned={C_lihdr(0,0,61),40,35,35,115,121,115,35,105,110,116,101,103,101,114,45,62,115,116,114,105,110,103,47,114,101,99,117,114,115,105,118,101,32,110,32,98,97,115,101,32,101,120,112,101,99,116,101,100,45,115,116,114,105,110,103,45,115,105,122,101,41,0,0,0};
static C_char C_TLS li455[] C_aligned={C_lihdr(0,0,38),40,35,35,115,121,115,35,101,120,116,101,110,100,101,100,45,110,117,109,98,101,114,45,62,115,116,114,105,110,103,32,110,32,98,97,115,101,41,0,0};
static C_char C_TLS li456[] C_aligned={C_lihdr(0,0,20),40,114,111,117,110,100,45,113,117,111,116,105,101,110,116,32,110,32,100,41,0,0,0,0};
static C_char C_TLS li457[] C_aligned={C_lihdr(0,0,13),40,103,111,45,105,110,101,120,97,99,116,33,41,0,0,0};
static C_char C_TLS li458[] C_aligned={C_lihdr(0,0,23),40,115,97,102,101,45,101,120,112,111,110,101,110,116,32,118,97,108,117,101,32,101,41,0};
static C_char C_TLS li459[] C_aligned={C_lihdr(0,0,6),40,108,112,32,105,41,0,0};
static C_char C_TLS li460[] C_aligned={C_lihdr(0,0,19),40,115,99,97,110,45,100,105,103,105,116,115,32,115,116,97,114,116,41,0,0,0,0,0};
static C_char C_TLS li461[] C_aligned={C_lihdr(0,0,6),40,108,112,32,105,41,0,0};
static C_char C_TLS li462[] C_aligned={C_lihdr(0,0,19),40,115,99,97,110,45,104,97,115,104,101,115,32,115,116,97,114,116,41,0,0,0,0,0};
static C_char C_TLS li463[] C_aligned={C_lihdr(0,0,46),40,115,99,97,110,45,100,105,103,105,116,115,43,104,97,115,104,101,115,32,115,116,97,114,116,32,110,101,103,63,32,97,108,108,45,104,97,115,104,101,115,45,111,107,63,41,0,0};
static C_char C_TLS li464[] C_aligned={C_lihdr(0,0,21),40,115,99,97,110,45,101,120,112,111,110,101,110,116,32,115,116,97,114,116,41,0,0,0};
static C_char C_TLS li465[] C_aligned={C_lihdr(0,0,43),40,115,99,97,110,45,100,101,99,105,109,97,108,45,116,97,105,108,32,115,116,97,114,116,32,110,101,103,63,32,100,101,99,105,109,97,108,45,104,101,97,100,41,0,0,0,0,0};
static C_char C_TLS li466[] C_aligned={C_lihdr(0,0,23),40,115,99,97,110,45,117,114,101,97,108,32,115,116,97,114,116,32,110,101,103,63,41,0};
static C_char C_TLS li467[] C_aligned={C_lihdr(0,0,17),40,115,99,97,110,45,114,101,97,108,32,115,116,97,114,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li468[] C_aligned={C_lihdr(0,0,50),40,35,35,115,121,115,35,115,116,114,105,110,103,45,62,99,111,109,112,110,117,109,32,114,97,100,105,120,32,115,116,114,32,111,102,102,115,101,116,32,101,120,97,99,116,110,101,115,115,41,0,0,0,0,0,0};
static C_char C_TLS li469[] C_aligned={C_lihdr(0,0,32),40,115,99,97,110,45,112,114,101,102,105,120,32,105,32,101,120,110,101,115,115,32,114,97,100,105,120,32,108,101,110,41};
static C_char C_TLS li470[] C_aligned={C_lihdr(0,0,34),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,62,110,117,109,98,101,114,32,115,116,114,32,46,32,114,101,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li471[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,115,116,114,105,110,103,45,62,110,117,109,98,101,114,32,115,116,114,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li472[] C_aligned={C_lihdr(0,0,18),67,95,102,105,120,110,117,109,95,116,111,95,115,116,114,105,110,103,0,0,0,0,0,0};
static C_char C_TLS li473[] C_aligned={C_lihdr(0,0,18),67,95,102,108,111,110,117,109,95,116,111,95,115,116,114,105,110,103,0,0,0,0,0,0};
static C_char C_TLS li474[] C_aligned={C_lihdr(0,0,19),67,95,105,110,116,101,103,101,114,95,116,111,95,115,116,114,105,110,103,0,0,0,0,0};
static C_char C_TLS li475[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li476[] C_aligned={C_lihdr(0,0,25),40,99,111,109,112,97,114,101,45,115,108,111,116,115,32,120,32,121,32,115,116,97,114,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li477[] C_aligned={C_lihdr(0,0,10),40,119,97,108,107,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li478[] C_aligned={C_lihdr(0,0,26),40,99,104,105,99,107,101,110,46,98,97,115,101,35,101,113,117,97,108,61,63,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li479[] C_aligned={C_lihdr(0,0,18),67,95,115,116,114,105,110,103,95,116,111,95,115,121,109,98,111,108,0,0,0,0,0,0};
static C_char C_TLS li480[] C_aligned={C_lihdr(0,0,19),67,95,115,116,114,105,110,103,95,116,111,95,107,101,121,119,111,114,100,0,0,0,0,0};
static C_char C_TLS li481[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,105,110,116,101,114,110,101,100,45,115,121,109,98,111,108,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li482[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,115,116,114,105,110,103,45,62,115,121,109,98,111,108,32,115,116,114,41,0,0,0,0,0,0};
static C_char C_TLS li483[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,115,121,109,98,111,108,45,62,115,116,114,105,110,103,32,115,41};
static C_char C_TLS li484[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,115,121,109,98,111,108,45,62,115,116,114,105,110,103,32,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li485[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,115,116,114,105,110,103,45,62,115,121,109,98,111,108,32,115,116,114,41,0,0,0,0,0};
static C_char C_TLS li486[] C_aligned={C_lihdr(0,0,13),67,95,109,97,107,101,95,115,121,109,98,111,108,0,0,0};
static C_char C_TLS li487[] C_aligned={C_lihdr(0,0,44),40,99,104,105,99,107,101,110,46,98,97,115,101,35,115,116,114,105,110,103,45,62,117,110,105,110,116,101,114,110,101,100,45,115,121,109,98,111,108,32,115,116,114,41,0,0,0,0};
static C_char C_TLS li488[] C_aligned={C_lihdr(0,0,13),67,95,109,97,107,101,95,115,121,109,98,111,108,0,0,0};
static C_char C_TLS li489[] C_aligned={C_lihdr(0,0,34),40,99,104,105,99,107,101,110,46,98,97,115,101,35,103,101,110,115,121,109,32,46,32,115,116,114,45,111,114,45,115,121,109,41,0,0,0,0,0,0};
static C_char C_TLS li490[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,51,52,53,57,32,103,51,52,55,49,41,0,0,0,0};
static C_char C_TLS li491[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,98,97,115,101,35,115,121,109,98,111,108,45,97,112,112,101,110,100,32,46,32,115,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li492[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,107,101,121,119,111,114,100,35,107,101,121,119,111,114,100,63,32,120,41,0,0,0,0};
static C_char C_TLS li493[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,107,101,121,119,111,114,100,35,115,116,114,105,110,103,45,62,107,101,121,119,111,114,100,32,115,41,0,0,0,0,0};
static C_char C_TLS li494[] C_aligned={C_lihdr(0,0,36),40,99,104,105,99,107,101,110,46,107,101,121,119,111,114,100,35,107,101,121,119,111,114,100,45,62,115,116,114,105,110,103,32,107,119,41,0,0,0,0};
static C_char C_TLS li495[] C_aligned={C_lihdr(0,0,45),40,99,104,105,99,107,101,110,46,107,101,121,119,111,114,100,35,103,101,116,45,107,101,121,119,111,114,100,32,107,101,121,32,97,114,103,115,32,46,32,114,101,115,116,41,0,0,0};
static C_char C_TLS li496[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,109,97,107,101,45,98,108,111,98,32,115,105,122,101,41,0,0};
static C_char C_TLS li497[] C_aligned={C_lihdr(0,0,29),40,99,104,105,99,107,101,110,46,98,108,111,98,35,109,97,107,101,45,98,108,111,98,32,115,105,122,101,41,0,0,0};
static C_char C_TLS li498[] C_aligned={C_lihdr(0,0,22),40,99,104,105,99,107,101,110,46,98,108,111,98,35,98,108,111,98,63,32,120,41,0,0};
static C_char C_TLS li499[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,108,111,98,35,98,108,111,98,45,115,105,122,101,32,98,118,41,0,0,0,0,0};
static C_char C_TLS li500[] C_aligned={C_lihdr(0,0,29),40,99,104,105,99,107,101,110,46,98,108,111,98,35,115,116,114,105,110,103,45,62,98,108,111,98,32,115,41,0,0,0};
static C_char C_TLS li501[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,98,108,111,98,35,98,108,111,98,45,62,115,116,114,105,110,103,32,98,118,41,0,0};
static C_char C_TLS li502[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,108,111,98,35,98,108,111,98,61,63,32,98,49,32,98,50,41,0,0,0,0,0};
static C_char C_TLS li503[] C_aligned={C_lihdr(0,0,32),40,115,99,104,101,109,101,35,109,97,107,101,45,118,101,99,116,111,114,32,115,105,122,101,32,46,32,102,105,108,108,41};
static C_char C_TLS li504[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li505[] C_aligned={C_lihdr(0,0,26),40,115,99,104,101,109,101,35,108,105,115,116,45,62,118,101,99,116,111,114,32,108,115,116,48,41,0,0,0,0,0,0};
static C_char C_TLS li506[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li507[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,118,101,99,116,111,114,45,62,108,105,115,116,32,118,41,0};
static C_char C_TLS li508[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,118,101,99,116,111,114,32,46,32,120,115,41,0,0,0,0};
static C_char C_TLS li509[] C_aligned={C_lihdr(0,0,12),40,100,111,108,111,111,112,51,53,57,55,41,0,0,0,0};
static C_char C_TLS li510[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,118,101,99,116,111,114,45,102,105,108,108,33,32,118,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li511[] C_aligned={C_lihdr(0,0,12),40,100,111,108,111,111,112,51,54,48,57,41,0,0,0,0};
static C_char C_TLS li512[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,98,97,115,101,35,118,101,99,116,111,114,45,99,111,112,121,33,32,102,114,111,109,32,116,111,32,46,32,110,41,0};
static C_char C_TLS li513[] C_aligned={C_lihdr(0,0,12),40,100,111,108,111,111,112,51,54,52,48,41,0,0,0,0};
static C_char C_TLS li514[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,98,97,115,101,35,115,117,98,118,101,99,116,111,114,32,118,32,105,32,46,32,114,101,115,116,41,0,0,0,0,0};
static C_char C_TLS li515[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,98,97,115,101,35,118,101,99,116,111,114,45,114,101,115,105,122,101,32,118,32,110,32,46,32,114,101,115,116,41,0};
static C_char C_TLS li516[] C_aligned={C_lihdr(0,0,12),40,100,111,108,111,111,112,51,54,54,56,41,0,0,0,0};
static C_char C_TLS li517[] C_aligned={C_lihdr(0,0,30),40,35,35,115,121,115,35,118,101,99,116,111,114,45,114,101,115,105,122,101,32,118,32,110,32,105,110,105,116,41,0,0};
static C_char C_TLS li518[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,99,104,97,114,45,99,105,61,63,32,120,32,121,41,0,0};
static C_char C_TLS li519[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,99,104,97,114,45,99,105,62,63,32,120,32,121,41,0,0};
static C_char C_TLS li520[] C_aligned={C_lihdr(0,0,22),40,115,99,104,101,109,101,35,99,104,97,114,45,99,105,60,63,32,120,32,121,41,0,0};
static C_char C_TLS li521[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,99,104,97,114,45,99,105,62,61,63,32,120,32,121,41,0};
static C_char C_TLS li522[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,99,104,97,114,45,99,105,60,61,63,32,120,32,121,41,0};
static C_char C_TLS li523[] C_aligned={C_lihdr(0,0,6),40,108,111,111,112,41,0,0};
static C_char C_TLS li524[] C_aligned={C_lihdr(0,0,15),40,108,111,111,107,117,112,45,99,104,97,114,32,99,41,0};
static C_char C_TLS li525[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,104,97,114,45,110,97,109,101,32,120,32,46,32,121,41,0,0};
static C_char C_TLS li526[] C_aligned={C_lihdr(0,0,9),67,95,99,97,108,108,95,99,99,0,0,0,0,0,0,0};
static C_char C_TLS li527[] C_aligned={C_lihdr(0,0,19),67,95,99,97,108,108,95,119,105,116,104,95,99,116,104,117,108,104,117,0,0,0,0,0};
static C_char C_TLS li528[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li529[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,102,111,114,45,101,97,99,104,32,112,32,108,115,116,48,41,0};
static C_char C_TLS li530[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li531[] C_aligned={C_lihdr(0,0,18),40,35,35,115,121,115,35,109,97,112,32,112,32,108,115,116,48,41,0,0,0,0,0,0};
static C_char C_TLS li532[] C_aligned={C_lihdr(0,0,9),40,108,112,32,108,115,116,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li533[] C_aligned={C_lihdr(0,0,14),40,97,49,56,57,55,48,32,101,109,112,116,121,41,0,0};
static C_char C_TLS li534[] C_aligned={C_lihdr(0,0,24),40,109,97,112,115,97,102,101,51,55,52,52,32,112,32,108,115,116,115,32,108,111,99,41};
static C_char C_TLS li535[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,51,55,54,52,32,103,51,55,55,49,41,0,0,0,0,0,0,0};
static C_char C_TLS li536[] C_aligned={C_lihdr(0,0,10),40,97,49,57,48,57,50,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li537[] C_aligned={C_lihdr(0,0,10),40,97,49,57,48,57,56,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li538[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,97,108,108,41,0,0,0,0,0,0};
static C_char C_TLS li539[] C_aligned={C_lihdr(0,0,32),40,115,99,104,101,109,101,35,102,111,114,45,101,97,99,104,32,102,110,32,108,115,116,49,32,46,32,108,115,116,115,41};
static C_char C_TLS li540[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,51,55,57,50,32,103,51,56,48,52,41,0,0,0,0};
static C_char C_TLS li541[] C_aligned={C_lihdr(0,0,10),40,97,49,57,49,57,51,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li542[] C_aligned={C_lihdr(0,0,10),40,97,49,57,49,57,57,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li543[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,97,108,108,41,0,0,0,0,0,0};
static C_char C_TLS li544[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,109,97,112,32,102,110,32,108,115,116,49,32,46,32,108,115,116,115,41,0,0,0,0,0};
static C_char C_TLS li545[] C_aligned={C_lihdr(0,0,18),40,97,49,57,50,49,57,32,46,32,114,101,115,117,108,116,115,41,0,0,0,0,0,0};
static C_char C_TLS li546[] C_aligned={C_lihdr(0,0,40),40,115,99,104,101,109,101,35,100,121,110,97,109,105,99,45,119,105,110,100,32,98,101,102,111,114,101,32,116,104,117,110,107,32,97,102,116,101,114,41};
static C_char C_TLS li547[] C_aligned={C_lihdr(0,0,24),40,99,111,110,116,105,110,117,97,116,105,111,110,32,46,32,114,101,115,117,108,116,115,41};
static C_char C_TLS li548[] C_aligned={C_lihdr(0,0,13),40,97,49,57,50,52,51,32,99,111,110,116,41,0,0,0};
static C_char C_TLS li549[] C_aligned={C_lihdr(0,0,44),40,115,99,104,101,109,101,35,99,97,108,108,45,119,105,116,104,45,99,117,114,114,101,110,116,45,99,111,110,116,105,110,117,97,116,105,111,110,32,112,114,111,99,41,0,0,0,0};
static C_char C_TLS li550[] C_aligned={C_lihdr(0,0,30),40,35,35,115,121,115,35,100,121,110,97,109,105,99,45,117,110,119,105,110,100,32,119,105,110,100,115,32,110,41,0,0};
static C_char C_TLS li551[] C_aligned={C_lihdr(0,0,22),40,99,104,105,99,107,101,110,46,98,97,115,101,35,112,111,114,116,63,32,120,41,0,0};
static C_char C_TLS li552[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,98,97,115,101,35,105,110,112,117,116,45,112,111,114,116,45,111,112,101,110,63,32,112,41,0,0,0,0,0,0,0};
static C_char C_TLS li553[] C_aligned={C_lihdr(0,0,34),40,99,104,105,99,107,101,110,46,98,97,115,101,35,111,117,116,112,117,116,45,112,111,114,116,45,111,112,101,110,63,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li554[] C_aligned={C_lihdr(0,0,29),40,99,104,105,99,107,101,110,46,98,97,115,101,35,112,111,114,116,45,99,108,111,115,101,100,63,32,112,41,0,0,0};
static C_char C_TLS li555[] C_aligned={C_lihdr(0,0,37),40,35,35,115,121,115,35,109,97,107,101,45,112,111,114,116,32,105,47,111,32,99,108,97,115,115,32,110,97,109,101,32,116,121,112,101,41,0,0,0};
static C_char C_TLS li556[] C_aligned={C_lihdr(0,0,6),40,108,111,111,112,41,0,0};
static C_char C_TLS li557[] C_aligned={C_lihdr(0,0,10),40,97,51,51,48,48,50,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li558[] C_aligned={C_lihdr(0,0,6),40,108,111,111,112,41,0,0};
static C_char C_TLS li559[] C_aligned={C_lihdr(0,0,10),40,97,51,51,48,52,49,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li560[] C_aligned={C_lihdr(0,0,12),40,97,51,51,48,56,48,32,112,32,99,41,0,0,0,0};
static C_char C_TLS li561[] C_aligned={C_lihdr(0,0,12),40,97,51,51,48,56,51,32,112,32,115,41,0,0,0,0};
static C_char C_TLS li562[] C_aligned={C_lihdr(0,0,12),40,97,51,51,48,56,54,32,112,32,100,41,0,0,0,0};
static C_char C_TLS li563[] C_aligned={C_lihdr(0,0,10),40,97,51,51,48,57,50,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li564[] C_aligned={C_lihdr(0,0,10),40,97,51,51,48,57,53,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li565[] C_aligned={C_lihdr(0,0,8),40,97,51,51,49,51,53,41};
static C_char C_TLS li566[] C_aligned={C_lihdr(0,0,20),40,108,111,111,112,32,114,101,109,32,97,99,116,32,115,116,97,114,116,41,0,0,0,0};
static C_char C_TLS li567[] C_aligned={C_lihdr(0,0,23),40,97,51,51,48,57,56,32,112,32,110,32,100,101,115,116,32,115,116,97,114,116,41,0};
static C_char C_TLS li568[] C_aligned={C_lihdr(0,0,8),40,97,51,51,50,57,53,41};
static C_char C_TLS li569[] C_aligned={C_lihdr(0,0,32),40,108,111,111,112,32,108,101,110,32,108,105,109,105,116,32,98,117,102,102,101,114,32,114,101,115,117,108,116,32,102,41};
static C_char C_TLS li570[] C_aligned={C_lihdr(0,0,17),40,97,51,51,49,57,54,32,112,32,114,108,105,109,105,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li571[] C_aligned={C_lihdr(0,0,16),67,95,111,112,101,110,95,102,105,108,101,95,112,111,114,116};
static C_char C_TLS li572[] C_aligned={C_lihdr(0,0,37),40,35,35,115,121,115,35,99,104,101,99,107,45,105,110,112,117,116,45,112,111,114,116,32,120,32,111,112,101,110,32,46,32,108,111,99,41,0,0,0};
static C_char C_TLS li573[] C_aligned={C_lihdr(0,0,38),40,35,35,115,121,115,35,99,104,101,99,107,45,111,117,116,112,117,116,45,112,111,114,116,32,120,32,111,112,101,110,32,46,32,108,111,99,41,0,0};
static C_char C_TLS li574[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,99,104,101,99,107,45,112,111,114,116,32,120,32,46,32,108,111,99,41,0,0,0,0,0,0};
static C_char C_TLS li575[] C_aligned={C_lihdr(0,0,31),40,35,35,115,121,115,35,99,104,101,99,107,45,111,112,101,110,45,112,111,114,116,32,120,32,46,32,108,111,99,41,0};
static C_char C_TLS li576[] C_aligned={C_lihdr(0,0,10),40,98,111,100,121,51,57,55,54,41,0,0,0,0,0,0};
static C_char C_TLS li577[] C_aligned={C_lihdr(0,0,34),40,115,99,104,101,109,101,35,99,117,114,114,101,110,116,45,105,110,112,117,116,45,112,111,114,116,32,46,32,97,114,103,115,41,0,0,0,0,0,0};
static C_char C_TLS li578[] C_aligned={C_lihdr(0,0,10),40,98,111,100,121,52,48,48,49,41,0,0,0,0,0,0};
static C_char C_TLS li579[] C_aligned={C_lihdr(0,0,35),40,115,99,104,101,109,101,35,99,117,114,114,101,110,116,45,111,117,116,112,117,116,45,112,111,114,116,32,46,32,97,114,103,115,41,0,0,0,0,0};
static C_char C_TLS li580[] C_aligned={C_lihdr(0,0,10),40,98,111,100,121,52,48,50,54,41,0,0,0,0,0,0};
static C_char C_TLS li581[] C_aligned={C_lihdr(0,0,40),40,99,104,105,99,107,101,110,46,98,97,115,101,35,99,117,114,114,101,110,116,45,101,114,114,111,114,45,112,111,114,116,32,46,32,97,114,103,115,41};
static C_char C_TLS li582[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,116,116,121,45,112,111,114,116,63,32,112,111,114,116,41,0,0};
static C_char C_TLS li583[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,112,111,114,116,45,100,97,116,97,32,112,111,114,116,41,0,0};
static C_char C_TLS li584[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,115,101,116,45,112,111,114,116,45,100,97,116,97,33,32,112,111,114,116,32,100,97,116,97,41};
static C_char C_TLS li585[] C_aligned={C_lihdr(0,0,18),40,100,111,108,111,111,112,52,48,54,51,32,109,111,100,101,115,41,0,0,0,0,0,0};
static C_char C_TLS li586[] C_aligned={C_lihdr(0,0,25),40,111,112,101,110,32,110,97,109,101,32,105,110,112,32,109,111,100,101,115,32,108,111,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li587[] C_aligned={C_lihdr(0,0,20),40,99,108,111,115,101,32,112,111,114,116,32,105,110,112,32,108,111,99,41,0,0,0,0};
static C_char C_TLS li588[] C_aligned={C_lihdr(0,0,36),40,115,99,104,101,109,101,35,111,112,101,110,45,105,110,112,117,116,45,102,105,108,101,32,110,97,109,101,32,46,32,109,111,100,101,41,0,0,0,0};
static C_char C_TLS li589[] C_aligned={C_lihdr(0,0,37),40,115,99,104,101,109,101,35,111,112,101,110,45,111,117,116,112,117,116,45,102,105,108,101,32,110,97,109,101,32,46,32,109,111,100,101,41,0,0,0};
static C_char C_TLS li590[] C_aligned={C_lihdr(0,0,30),40,115,99,104,101,109,101,35,99,108,111,115,101,45,105,110,112,117,116,45,112,111,114,116,32,112,111,114,116,41,0,0};
static C_char C_TLS li591[] C_aligned={C_lihdr(0,0,31),40,115,99,104,101,109,101,35,99,108,111,115,101,45,111,117,116,112,117,116,45,112,111,114,116,32,112,111,114,116,41,0};
static C_char C_TLS li592[] C_aligned={C_lihdr(0,0,8),40,97,49,57,56,51,54,41};
static C_char C_TLS li593[] C_aligned={C_lihdr(0,0,18),40,97,49,57,56,52,50,32,46,32,114,101,115,117,108,116,115,41,0,0,0,0,0,0};
static C_char C_TLS li594[] C_aligned={C_lihdr(0,0,43),40,115,99,104,101,109,101,35,99,97,108,108,45,119,105,116,104,45,105,110,112,117,116,45,102,105,108,101,32,110,97,109,101,32,112,32,46,32,109,111,100,101,41,0,0,0,0,0};
static C_char C_TLS li595[] C_aligned={C_lihdr(0,0,8),40,97,49,57,56,54,48,41};
static C_char C_TLS li596[] C_aligned={C_lihdr(0,0,18),40,97,49,57,56,54,54,32,46,32,114,101,115,117,108,116,115,41,0,0,0,0,0,0};
static C_char C_TLS li597[] C_aligned={C_lihdr(0,0,44),40,115,99,104,101,109,101,35,99,97,108,108,45,119,105,116,104,45,111,117,116,112,117,116,45,102,105,108,101,32,110,97,109,101,32,112,32,46,32,109,111,100,101,41,0,0,0,0};
static C_char C_TLS li598[] C_aligned={C_lihdr(0,0,8),40,97,49,57,56,56,52,41};
static C_char C_TLS li599[] C_aligned={C_lihdr(0,0,18),40,97,49,57,56,57,53,32,46,32,114,101,115,117,108,116,115,41,0,0,0,0,0,0};
static C_char C_TLS li600[] C_aligned={C_lihdr(0,0,8),40,97,49,57,56,56,57,41};
static C_char C_TLS li601[] C_aligned={C_lihdr(0,0,8),40,97,49,57,57,48,52,41};
static C_char C_TLS li602[] C_aligned={C_lihdr(0,0,46),40,115,99,104,101,109,101,35,119,105,116,104,45,105,110,112,117,116,45,102,114,111,109,45,102,105,108,101,32,115,116,114,32,116,104,117,110,107,32,46,32,109,111,100,101,41,0,0};
static C_char C_TLS li603[] C_aligned={C_lihdr(0,0,8),40,97,49,57,57,49,56,41};
static C_char C_TLS li604[] C_aligned={C_lihdr(0,0,18),40,97,49,57,57,50,57,32,46,32,114,101,115,117,108,116,115,41,0,0,0,0,0,0};
static C_char C_TLS li605[] C_aligned={C_lihdr(0,0,8),40,97,49,57,57,50,51,41};
static C_char C_TLS li606[] C_aligned={C_lihdr(0,0,8),40,97,49,57,57,51,56,41};
static C_char C_TLS li607[] C_aligned={C_lihdr(0,0,45),40,115,99,104,101,109,101,35,119,105,116,104,45,111,117,116,112,117,116,45,116,111,45,102,105,108,101,32,115,116,114,32,116,104,117,110,107,32,46,32,109,111,100,101,41,0,0,0};
static C_char C_TLS li608[] C_aligned={C_lihdr(0,0,40),40,35,35,115,121,115,35,102,105,108,101,45,101,120,105,115,116,115,63,32,110,97,109,101,32,102,105,108,101,63,32,100,105,114,63,32,108,111,99,41};
static C_char C_TLS li609[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,102,108,117,115,104,45,111,117,116,112,117,116,32,112,111,114,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li610[] C_aligned={C_lihdr(0,0,34),40,99,104,105,99,107,101,110,46,98,97,115,101,35,102,108,117,115,104,45,111,117,116,112,117,116,32,46,32,114,101,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li611[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,112,111,114,116,45,108,105,110,101,32,112,111,114,116,41,0,0};
static C_char C_TLS li612[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,52,49,57,50,32,105,41,0,0};
static C_char C_TLS li613[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li614[] C_aligned={C_lihdr(0,0,43),40,35,35,115,121,115,35,100,101,99,111,114,97,116,101,45,108,97,109,98,100,97,32,112,114,111,99,32,112,114,101,100,32,100,101,99,111,114,97,116,111,114,41,0,0,0,0,0};
static C_char C_TLS li615[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li616[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,108,97,109,98,100,97,45,100,101,99,111,114,97,116,105,111,110,32,112,114,111,99,32,112,114,101,100,41,0,0,0,0,0};
static C_char C_TLS li617[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,109,97,107,101,45,108,97,109,98,100,97,45,105,110,102,111,32,115,116,114,41,0,0,0,0};
static C_char C_TLS li618[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,108,97,109,98,100,97,45,105,110,102,111,63,32,120,41,0,0};
static C_char C_TLS li619[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,108,97,109,98,100,97,45,105,110,102,111,32,112,114,111,99,41};
static C_char C_TLS li620[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,108,97,109,98,100,97,45,105,110,102,111,45,62,115,116,114,105,110,103,32,105,110,102,111,41};
static C_char C_TLS li621[] C_aligned={C_lihdr(0,0,38),40,99,104,105,99,107,101,110,46,98,97,115,101,35,112,114,111,99,101,100,117,114,101,45,105,110,102,111,114,109,97,116,105,111,110,32,120,41,0,0};
static C_char C_TLS li622[] C_aligned={C_lihdr(0,0,12),40,97,50,48,50,49,54,32,112,32,105,41,0,0,0,0};
static C_char C_TLS li623[] C_aligned={C_lihdr(0,0,10),40,97,50,48,50,50,54,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li624[] C_aligned={C_lihdr(0,0,15),40,97,50,48,50,52,50,32,112,114,111,99,32,105,41,0};
static C_char C_TLS li625[] C_aligned={C_lihdr(0,0,48),40,99,104,105,99,107,101,110,46,98,97,115,101,35,103,101,116,116,101,114,45,119,105,116,104,45,115,101,116,116,101,114,32,103,101,116,32,115,101,116,32,46,32,114,101,115,116,41};
static C_char C_TLS li626[] C_aligned={C_lihdr(0,0,11),40,102,95,50,48,52,57,57,32,120,41,0,0,0,0,0};
static C_char C_TLS li627[] C_aligned={C_lihdr(0,0,28),40,97,115,115,105,103,110,32,118,97,108,32,110,32,99,111,110,118,101,114,116,63,32,115,101,116,63,41,0,0,0,0};
static C_char C_TLS li628[] C_aligned={C_lihdr(0,0,24),40,98,111,100,121,52,51,52,51,32,99,111,110,118,101,114,116,63,32,115,101,116,63,41};
static C_char C_TLS li629[] C_aligned={C_lihdr(0,0,24),40,100,101,102,45,115,101,116,63,52,51,52,54,32,37,99,111,110,118,101,114,116,63,41};
static C_char C_TLS li630[] C_aligned={C_lihdr(0,0,18),40,100,101,102,45,99,111,110,118,101,114,116,63,52,51,52,53,41,0,0,0,0,0,0};
static C_char C_TLS li631[] C_aligned={C_lihdr(0,0,15),40,97,50,48,51,57,48,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li632[] C_aligned={C_lihdr(0,0,12),40,97,50,48,52,55,50,32,118,97,108,41,0,0,0,0};
static C_char C_TLS li633[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,98,97,115,101,35,109,97,107,101,45,112,97,114,97,109,101,116,101,114,32,105,110,105,116,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li634[] C_aligned={C_lihdr(0,0,27),40,115,99,104,101,109,101,35,99,104,97,114,45,114,101,97,100,121,63,32,46,32,114,101,115,116,41,0,0,0,0,0};
static C_char C_TLS li635[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,114,101,97,100,45,99,104,97,114,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li636[] C_aligned={C_lihdr(0,0,21),40,35,35,115,121,115,35,114,101,97,100,45,99,104,97,114,45,48,32,112,41,0,0,0};
static C_char C_TLS li637[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,114,101,97,100,45,99,104,97,114,47,112,111,114,116,32,112,111,114,116,41,0,0,0,0,0};
static C_char C_TLS li638[] C_aligned={C_lihdr(0,0,21),40,35,35,115,121,115,35,112,101,101,107,45,99,104,97,114,45,48,32,112,41,0,0,0};
static C_char C_TLS li639[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,112,101,101,107,45,99,104,97,114,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li640[] C_aligned={C_lihdr(0,0,20),40,115,99,104,101,109,101,35,114,101,97,100,32,46,32,114,101,115,116,41,0,0,0,0};
static C_char C_TLS li641[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,114,101,97,100,45,112,114,111,109,112,116,45,104,111,111,107,41};
static C_char C_TLS li642[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,105,110,102,105,120,45,108,105,115,116,45,104,111,111,107,32,108,115,116,41,0,0,0,0,0};
static C_char C_TLS li643[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,115,104,97,114,112,45,110,117,109,98,101,114,45,104,111,111,107,32,112,111,114,116,32,110,41};
static C_char C_TLS li644[] C_aligned={C_lihdr(0,0,36),40,35,35,115,121,115,35,114,101,97,100,45,119,97,114,110,105,110,103,32,112,111,114,116,32,109,115,103,32,46,32,97,114,103,115,41,0,0,0,0};
static C_char C_TLS li645[] C_aligned={C_lihdr(0,0,34),40,35,35,115,121,115,35,114,101,97,100,45,101,114,114,111,114,32,112,111,114,116,32,109,115,103,32,46,32,97,114,103,115,41,0,0,0,0,0,0};
static C_char C_TLS li646[] C_aligned={C_lihdr(0,0,11),40,102,95,50,48,55,55,54,32,99,41,0,0,0,0,0};
static C_char C_TLS li647[] C_aligned={C_lihdr(0,0,21),40,105,110,102,111,32,99,108,97,115,115,32,100,97,116,97,32,118,97,108,41,0,0,0};
static C_char C_TLS li648[] C_aligned={C_lihdr(0,0,8),40,115,107,105,112,32,99,41};
static C_char C_TLS li649[] C_aligned={C_lihdr(0,0,13),40,115,107,105,112,45,116,111,45,101,111,108,41,0,0,0};
static C_char C_TLS li650[] C_aligned={C_lihdr(0,0,22),40,114,101,115,101,114,118,101,100,45,99,104,97,114,97,99,116,101,114,32,99,41,0,0};
static C_char C_TLS li651[] C_aligned={C_lihdr(0,0,29),40,114,101,97,100,45,117,110,114,101,115,101,114,118,101,100,45,99,104,97,114,45,48,32,112,111,114,116,41,0,0,0};
static C_char C_TLS li652[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,99,41};
static C_char C_TLS li653[] C_aligned={C_lihdr(0,0,10),40,114,45,115,112,97,99,101,115,41,0,0,0,0,0,0};
static C_char C_TLS li654[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,115,101,113,32,110,41,0,0,0,0};
static C_char C_TLS li655[] C_aligned={C_lihdr(0,0,22),40,114,45,117,115,101,113,117,101,110,99,101,32,117,32,110,32,98,97,115,101,41,0,0};
static C_char C_TLS li656[] C_aligned={C_lihdr(0,0,10),40,108,112,32,105,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li657[] C_aligned={C_lihdr(0,0,25),40,114,45,99,111,110,115,45,99,111,100,101,112,111,105,110,116,32,99,112,32,108,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li658[] C_aligned={C_lihdr(0,0,14),40,101,97,116,45,119,115,32,99,32,110,108,63,41,0,0};
static C_char C_TLS li659[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,99,32,108,115,116,41,0,0,0,0};
static C_char C_TLS li660[] C_aligned={C_lihdr(0,0,15),40,114,45,115,116,114,105,110,103,32,116,101,114,109,41,0};
static C_char C_TLS li661[] C_aligned={C_lihdr(0,0,19),40,115,116,97,114,116,105,110,103,45,108,105,110,101,32,109,115,103,41,0,0,0,0,0};
static C_char C_TLS li662[] C_aligned={C_lihdr(0,0,11),40,102,95,50,49,53,57,54,32,99,41,0,0,0,0,0};
static C_char C_TLS li663[] C_aligned={C_lihdr(0,0,15),40,97,50,49,55,49,49,32,116,111,107,32,107,119,41,0};
static C_char C_TLS li664[] C_aligned={C_lihdr(0,0,11),40,108,111,111,112,32,108,97,115,116,41,0,0,0,0,0};
static C_char C_TLS li665[] C_aligned={C_lihdr(0,0,15),40,97,50,49,53,57,50,32,114,101,116,117,114,110,41,0};
static C_char C_TLS li666[] C_aligned={C_lihdr(0,0,18),40,114,45,108,105,115,116,32,115,116,97,114,116,32,101,110,100,41,0,0,0,0,0,0};
static C_char C_TLS li667[] C_aligned={C_lihdr(0,0,10),40,114,45,118,101,99,116,111,114,41,0,0,0,0,0,0};
static C_char C_TLS li668[] C_aligned={C_lihdr(0,0,15),40,97,50,49,56,51,57,32,116,111,107,32,107,119,41,0};
static C_char C_TLS li669[] C_aligned={C_lihdr(0,0,26),40,114,45,110,117,109,98,101,114,32,114,97,100,105,120,32,101,120,97,99,116,110,101,115,115,41,0,0,0,0,0,0};
static C_char C_TLS li670[] C_aligned={C_lihdr(0,0,31),40,114,45,110,117,109,98,101,114,45,119,105,116,104,45,101,120,97,99,116,110,101,115,115,32,114,97,100,105,120,41,0};
static C_char C_TLS li671[] C_aligned={C_lihdr(0,0,31),40,114,45,110,117,109,98,101,114,45,119,105,116,104,45,114,97,100,105,120,32,101,120,97,99,116,110,101,115,115,41,0};
static C_char C_TLS li672[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,99,32,108,115,116,41,0,0,0,0};
static C_char C_TLS li673[] C_aligned={C_lihdr(0,0,9),40,114,45,116,111,107,101,110,41,0,0,0,0,0,0,0};
static C_char C_TLS li674[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,99,32,108,115,116,41,0,0,0,0};
static C_char C_TLS li675[] C_aligned={C_lihdr(0,0,10),40,114,45,100,105,103,105,116,115,41,0,0,0,0,0,0};
static C_char C_TLS li676[] C_aligned={C_lihdr(0,0,15),40,97,50,50,49,51,55,32,115,116,114,32,107,119,41,0};
static C_char C_TLS li677[] C_aligned={C_lihdr(0,0,10),40,114,45,115,121,109,98,111,108,41,0,0,0,0,0,0};
static C_char C_TLS li678[] C_aligned={C_lihdr(0,0,18),40,108,111,111,112,32,108,115,116,32,115,107,119,32,113,116,100,41,0,0,0,0,0,0};
static C_char C_TLS li679[] C_aligned={C_lihdr(0,0,12),40,114,45,120,116,111,107,101,110,32,107,41,0,0,0,0};
static C_char C_TLS li680[] C_aligned={C_lihdr(0,0,8),40,114,45,99,104,97,114,41};
static C_char C_TLS li681[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li682[] C_aligned={C_lihdr(0,0,11),40,114,45,99,111,109,109,101,110,116,41,0,0,0,0,0};
static C_char C_TLS li683[] C_aligned={C_lihdr(0,0,14),40,114,45,101,120,116,45,115,121,109,98,111,108,41,0,0};
static C_char C_TLS li684[] C_aligned={C_lihdr(0,0,11),40,114,45,113,117,111,116,101,32,113,41,0,0,0,0,0};
static C_char C_TLS li685[] C_aligned={C_lihdr(0,0,8),40,97,50,50,55,54,55,41};
static C_char C_TLS li686[] C_aligned={C_lihdr(0,0,13),40,97,50,50,55,55,51,32,46,32,120,115,41,0,0,0};
static C_char C_TLS li687[] C_aligned={C_lihdr(0,0,8),40,97,50,50,56,57,52,41};
static C_char C_TLS li688[] C_aligned={C_lihdr(0,0,13),40,97,50,50,57,48,48,32,46,32,120,115,41,0,0,0};
static C_char C_TLS li689[] C_aligned={C_lihdr(0,0,8),40,97,50,50,57,54,53,41};
static C_char C_TLS li690[] C_aligned={C_lihdr(0,0,13),40,97,50,50,57,55,49,32,46,32,120,115,41,0,0,0};
static C_char C_TLS li691[] C_aligned={C_lihdr(0,0,8),40,97,50,51,48,55,57,41};
static C_char C_TLS li692[] C_aligned={C_lihdr(0,0,8),40,97,50,51,48,56,52,41};
static C_char C_TLS li693[] C_aligned={C_lihdr(0,0,8),40,97,50,51,48,57,48,41};
static C_char C_TLS li694[] C_aligned={C_lihdr(0,0,8),40,97,50,51,50,51,51,41};
static C_char C_TLS li695[] C_aligned={C_lihdr(0,0,15),40,97,50,51,50,52,52,32,115,116,114,32,107,119,41,0};
static C_char C_TLS li696[] C_aligned={C_lihdr(0,0,8),40,97,50,51,50,51,56,41};
static C_char C_TLS li697[] C_aligned={C_lihdr(0,0,8),40,97,50,51,50,55,51,41};
static C_char C_TLS li698[] C_aligned={C_lihdr(0,0,8),40,97,50,51,51,57,50,41};
static C_char C_TLS li699[] C_aligned={C_lihdr(0,0,13),40,97,50,51,51,57,56,32,46,32,120,115,41,0,0,0};
static C_char C_TLS li700[] C_aligned={C_lihdr(0,0,9),40,114,101,97,100,114,101,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li701[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,114,101,97,100,32,112,111,114,116,32,105,110,102,111,104,97,110,100,108,101,114,41,0,0,0};
static C_char C_TLS li702[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,99,104,97,114,45,62,117,116,102,56,45,115,116,114,105,110,103,32,99,41,0,0,0,0,0};
static C_char C_TLS li703[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,117,110,105,99,111,100,101,45,115,117,114,114,111,103,97,116,101,63,32,110,41,0,0,0,0};
static C_char C_TLS li704[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,115,117,114,114,111,103,97,116,101,115,45,62,99,111,100,101,112,111,105,110,116,32,104,105,32,108,111,41,0,0,0,0,0};
static C_char C_TLS li705[] C_aligned={C_lihdr(0,0,7),40,104,101,120,32,99,41,0};
static C_char C_TLS li706[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,108,115,116,32,104,41,0,0,0,0};
static C_char C_TLS li707[] C_aligned={C_lihdr(0,0,36),40,35,35,115,121,115,35,114,101,97,100,45,98,121,116,101,118,101,99,116,111,114,45,108,105,116,101,114,97,108,32,112,111,114,116,41,0,0,0,0};
static C_char C_TLS li708[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,117,115,101,114,45,114,101,97,100,45,104,111,111,107,32,99,104,97,114,32,112,111,114,116,41};
static C_char C_TLS li709[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,119,114,105,116,101,45,99,104,97,114,45,48,32,99,32,112,41};
static C_char C_TLS li710[] C_aligned={C_lihdr(0,0,30),40,35,35,115,121,115,35,119,114,105,116,101,45,99,104,97,114,47,112,111,114,116,32,99,32,112,111,114,116,41,0,0};
static C_char C_TLS li711[] C_aligned={C_lihdr(0,0,28),40,115,99,104,101,109,101,35,119,114,105,116,101,45,99,104,97,114,32,99,32,46,32,114,101,115,116,41,0,0,0,0};
static C_char C_TLS li712[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,110,101,119,108,105,110,101,32,46,32,114,101,115,116,41,0};
static C_char C_TLS li713[] C_aligned={C_lihdr(0,0,23),40,115,99,104,101,109,101,35,119,114,105,116,101,32,120,32,46,32,114,101,115,116,41,0};
static C_char C_TLS li714[] C_aligned={C_lihdr(0,0,25),40,115,99,104,101,109,101,35,100,105,115,112,108,97,121,32,120,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li715[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,49,52,57,32,103,53,49,53,54,41,0,0,0,0,0,0,0};
static C_char C_TLS li716[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,97,115,101,35,112,114,105,110,116,32,46,32,97,114,103,115,41,0,0,0,0,0};
static C_char C_TLS li717[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,49,56,49,32,103,53,49,56,56,41,0,0,0,0,0,0,0};
static C_char C_TLS li718[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,98,97,115,101,35,112,114,105,110,116,42,32,46,32,97,114,103,115,41,0,0,0,0};
static C_char C_TLS li719[] C_aligned={C_lihdr(0,0,17),40,111,117,116,115,116,114,32,112,111,114,116,32,115,116,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li720[] C_aligned={C_lihdr(0,0,17),40,111,117,116,99,104,114,32,112,111,114,116,32,99,104,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li721[] C_aligned={C_lihdr(0,0,17),40,111,117,116,115,121,109,32,112,111,114,116,32,115,121,109,41,0,0,0,0,0,0,0};
static C_char C_TLS li722[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li723[] C_aligned={C_lihdr(0,0,25),40,111,117,116,114,101,97,100,97,98,108,101,115,121,109,32,112,111,114,116,32,115,116,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li724[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li725[] C_aligned={C_lihdr(0,0,22),40,115,121,109,45,105,115,45,114,101,97,100,97,98,108,101,63,32,115,116,114,41,0,0};
static C_char C_TLS li726[] C_aligned={C_lihdr(0,0,10),40,103,53,51,52,55,32,99,110,41,0,0,0,0,0,0};
static C_char C_TLS li727[] C_aligned={C_lihdr(0,0,16),40,100,111,108,111,111,112,53,51,54,56,32,105,32,99,41};
static C_char C_TLS li728[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,53,51,57,56,32,120,41,0,0};
static C_char C_TLS li729[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,53,52,49,50,32,105,41,0,0};
static C_char C_TLS li730[] C_aligned={C_lihdr(0,0,16),40,100,111,108,111,111,112,53,52,51,54,32,105,32,99,41};
static C_char C_TLS li731[] C_aligned={C_lihdr(0,0,7),40,111,117,116,32,120,41,0};
static C_char C_TLS li732[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,112,114,105,110,116,32,120,32,114,101,97,100,97,98,108,101,32,112,111,114,116,41,0,0,0};
static C_char C_TLS li733[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,112,114,111,99,101,100,117,114,101,45,62,115,116,114,105,110,103,32,120,41,0,0,0,0,0};
static C_char C_TLS li734[] C_aligned={C_lihdr(0,0,34),40,99,104,105,99,107,101,110,46,98,97,115,101,35,114,101,99,111,114,100,45,112,114,105,110,116,101,114,32,116,121,112,101,41,0,0,0,0,0,0};
static C_char C_TLS li735[] C_aligned={C_lihdr(0,0,44),40,99,104,105,99,107,101,110,46,98,97,115,101,35,115,101,116,45,114,101,99,111,114,100,45,112,114,105,110,116,101,114,33,32,116,121,112,101,32,112,114,111,99,41,0,0,0,0};
static C_char C_TLS li736[] C_aligned={C_lihdr(0,0,8),40,97,50,53,52,56,50,41};
static C_char C_TLS li737[] C_aligned={C_lihdr(0,0,11),40,97,50,53,52,55,54,32,101,120,41,0,0,0,0,0};
static C_char C_TLS li738[] C_aligned={C_lihdr(0,0,8),40,97,50,53,53,51,51,41};
static C_char C_TLS li739[] C_aligned={C_lihdr(0,0,8),40,97,50,53,53,52,56,41};
static C_char C_TLS li740[] C_aligned={C_lihdr(0,0,15),40,97,50,53,53,52,50,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li741[] C_aligned={C_lihdr(0,0,8),40,97,50,53,53,50,55,41};
static C_char C_TLS li742[] C_aligned={C_lihdr(0,0,10),40,97,50,53,52,55,48,32,107,41,0,0,0,0,0,0};
static C_char C_TLS li743[] C_aligned={C_lihdr(0,0,39),40,35,35,115,121,115,35,117,115,101,114,45,112,114,105,110,116,45,104,111,111,107,32,120,32,114,101,97,100,97,98,108,101,32,112,111,114,116,41,0};
static C_char C_TLS li744[] C_aligned={C_lihdr(0,0,8),40,97,50,53,54,49,53,41};
static C_char C_TLS li745[] C_aligned={C_lihdr(0,0,8),40,97,50,53,54,53,56,41};
static C_char C_TLS li746[] C_aligned={C_lihdr(0,0,8),40,97,50,53,54,54,52,41};
static C_char C_TLS li747[] C_aligned={C_lihdr(0,0,15),40,97,50,53,54,48,57,32,114,101,116,117,114,110,41,0};
static C_char C_TLS li748[] C_aligned={C_lihdr(0,0,43),40,35,35,115,121,115,35,119,105,116,104,45,112,114,105,110,116,45,108,101,110,103,116,104,45,108,105,109,105,116,32,108,105,109,105,116,32,116,104,117,110,107,41,0,0,0,0,0};
static C_char C_TLS li749[] C_aligned={C_lihdr(0,0,15),40,99,104,101,99,107,53,53,53,54,32,112,32,110,41,0};
static C_char C_TLS li750[] C_aligned={C_lihdr(0,0,10),40,97,51,50,52,57,57,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li751[] C_aligned={C_lihdr(0,0,10),40,97,51,50,53,50,52,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li752[] C_aligned={C_lihdr(0,0,12),40,97,51,50,53,52,50,32,112,32,99,41,0,0,0,0};
static C_char C_TLS li753[] C_aligned={C_lihdr(0,0,14),40,97,51,50,53,54,49,32,112,32,115,116,114,41,0,0};
static C_char C_TLS li754[] C_aligned={C_lihdr(0,0,10),40,97,51,50,53,56,48,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li755[] C_aligned={C_lihdr(0,0,10),40,97,51,50,53,56,51,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li756[] C_aligned={C_lihdr(0,0,23),40,97,51,50,53,56,54,32,112,32,110,32,100,101,115,116,32,115,116,97,114,116,41,0};
static C_char C_TLS li757[] C_aligned={C_lihdr(0,0,12),40,97,51,50,54,54,49,32,112,111,115,41,0,0,0,0};
static C_char C_TLS li758[] C_aligned={C_lihdr(0,0,8),40,97,51,50,54,53,49,41};
static C_char C_TLS li759[] C_aligned={C_lihdr(0,0,29),40,97,51,50,54,55,48,32,110,101,120,116,32,108,105,110,101,32,102,117,108,108,45,108,105,110,101,63,41,0,0,0};
static C_char C_TLS li760[] C_aligned={C_lihdr(0,0,16),40,97,51,50,54,50,55,32,112,32,108,105,109,105,116,41};
static C_char C_TLS li761[] C_aligned={C_lihdr(0,0,10),40,97,51,50,55,49,49,32,112,41,0,0,0,0,0,0};
static C_char C_TLS li762[] C_aligned={C_lihdr(0,0,37),40,99,111,112,121,38,97,112,112,101,110,100,32,98,117,102,32,111,102,102,115,101,116,32,112,111,115,32,111,108,100,45,108,105,110,101,41,0,0,0};
static C_char C_TLS li763[] C_aligned={C_lihdr(0,0,8),40,97,50,53,55,56,50,41};
static C_char C_TLS li764[] C_aligned={C_lihdr(0,0,25),40,97,50,53,55,56,56,32,98,117,102,32,111,102,102,115,101,116,32,108,105,109,105,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li765[] C_aligned={C_lihdr(0,0,8),40,97,50,53,56,52,54,41};
static C_char C_TLS li766[] C_aligned={C_lihdr(0,0,25),40,97,50,53,56,53,50,32,98,117,102,32,111,102,102,115,101,116,32,108,105,109,105,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li767[] C_aligned={C_lihdr(0,0,32),40,108,111,111,112,32,98,117,102,32,111,102,102,115,101,116,32,112,111,115,32,108,105,109,105,116,32,108,105,110,101,41};
static C_char C_TLS li768[] C_aligned={C_lihdr(0,0,56),40,35,35,115,121,115,35,115,99,97,110,45,98,117,102,102,101,114,45,108,105,110,101,32,98,117,102,32,108,105,109,105,116,32,115,116,97,114,116,45,112,111,115,32,101,111,115,45,104,97,110,100,108,101,114,41};
static C_char C_TLS li769[] C_aligned={C_lihdr(0,0,39),40,99,104,105,99,107,101,110,46,98,97,115,101,35,111,112,101,110,45,105,110,112,117,116,45,115,116,114,105,110,103,32,115,116,114,105,110,103,41,0};
static C_char C_TLS li770[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,98,97,115,101,35,111,112,101,110,45,111,117,116,112,117,116,45,115,116,114,105,110,103,41,0,0,0,0,0,0,0};
static C_char C_TLS li771[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,98,97,115,101,35,103,101,116,45,111,117,116,112,117,116,45,115,116,114,105,110,103,32,112,111,114,116,41,0,0,0};
static C_char C_TLS li772[] C_aligned={C_lihdr(0,0,9),40,103,53,54,56,54,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li773[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,54,56,53,32,103,53,54,57,50,41,0,0,0,0,0,0,0};
static C_char C_TLS li774[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,112,114,105,110,116,45,116,111,45,115,116,114,105,110,103,32,120,115,41,0,0,0,0,0,0};
static C_char C_TLS li775[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,112,111,105,110,116,101,114,45,62,115,116,114,105,110,103,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li776[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li777[] C_aligned={C_lihdr(0,0,36),40,99,104,105,99,107,101,110,46,98,97,115,101,35,103,101,116,45,99,97,108,108,45,99,104,97,105,110,32,46,32,114,101,115,116,41,0,0,0,0};
static C_char C_TLS li778[] C_aligned={C_lihdr(0,0,8),40,97,50,54,51,48,52,41};
static C_char C_TLS li779[] C_aligned={C_lihdr(0,0,12),40,103,53,55,53,53,32,105,110,102,111,41,0,0,0,0};
static C_char C_TLS li780[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,55,53,52,32,103,53,55,54,49,41,0,0,0,0,0,0,0};
static C_char C_TLS li781[] C_aligned={C_lihdr(0,0,49),40,35,35,115,121,115,35,114,101,97,108,108,121,45,112,114,105,110,116,45,99,97,108,108,45,99,104,97,105,110,32,112,111,114,116,32,99,104,97,105,110,32,104,101,97,100,101,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li782[] C_aligned={C_lihdr(0,0,38),40,99,104,105,99,107,101,110,46,98,97,115,101,35,112,114,105,110,116,45,99,97,108,108,45,99,104,97,105,110,32,46,32,114,101,115,116,41,0,0};
static C_char C_TLS li783[] C_aligned={C_lihdr(0,0,7),40,98,114,101,97,107,41,0};
static C_char C_TLS li784[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,117,115,101,114,45,105,110,116,101,114,114,117,112,116,45,104,111,111,107,41,0,0,0,0,0};
static C_char C_TLS li785[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,56,49,52,32,103,53,56,50,49,41,0,0,0,0,0,0,0};
static C_char C_TLS li786[] C_aligned={C_lihdr(0,0,6),40,108,111,111,112,41,0,0};
static C_char C_TLS li787[] C_aligned={C_lihdr(0,0,21),40,99,108,101,97,110,117,112,45,98,101,102,111,114,101,45,101,120,105,116,41,0,0,0};
static C_char C_TLS li788[] C_aligned={C_lihdr(0,0,8),40,97,50,54,54,51,51,41};
static C_char C_TLS li789[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,56,56,53,32,103,53,56,57,50,41,0,0,0,0,0,0,0};
static C_char C_TLS li790[] C_aligned={C_lihdr(0,0,47),40,35,35,115,121,115,35,115,105,103,110,97,108,45,104,111,111,107,47,101,114,114,110,111,32,109,111,100,101,32,101,114,114,110,111,32,109,115,103,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li791[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,115,105,103,110,97,108,45,104,111,111,107,32,109,111,100,101,32,109,115,103,32,46,32,97,114,103,115,41,0,0,0,0,0};
static C_char C_TLS li792[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,97,98,111,114,116,32,120,41,0,0,0,0,0};
static C_char C_TLS li793[] C_aligned={C_lihdr(0,0,28),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,115,105,103,110,97,108,32,120,41,0,0,0,0};
static C_char C_TLS li794[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,99,117,114,114,101,110,116,45,101,120,99,101,112,116,105,111,110,45,104,97,110,100,108,101,114,32,99,41,0,0,0,0,0};
static C_char C_TLS li795[] C_aligned={C_lihdr(0,0,8),40,97,50,55,48,57,55,41};
static C_char C_TLS li796[] C_aligned={C_lihdr(0,0,8),40,97,50,55,49,48,49,41};
static C_char C_TLS li797[] C_aligned={C_lihdr(0,0,56),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,119,105,116,104,45,101,120,99,101,112,116,105,111,110,45,104,97,110,100,108,101,114,32,104,97,110,100,108,101,114,32,116,104,117,110,107,41};
static C_char C_TLS li798[] C_aligned={C_lihdr(0,0,10),40,98,111,100,121,54,48,52,50,41,0,0,0,0,0,0};
static C_char C_TLS li799[] C_aligned={C_lihdr(0,0,52),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,99,117,114,114,101,110,116,45,101,120,99,101,112,116,105,111,110,45,104,97,110,100,108,101,114,32,46,32,97,114,103,115,41,0,0,0,0};
static C_char C_TLS li800[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,112,114,111,112,115,41,0,0,0,0};
static C_char C_TLS li801[] C_aligned={C_lihdr(0,0,69),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,112,114,111,112,45,108,105,115,116,45,62,107,105,110,100,45,112,114,101,102,105,120,101,100,45,112,114,111,112,45,108,105,115,116,32,108,111,99,32,107,105,110,100,32,112,108,105,115,116,41,0,0,0};
static C_char C_TLS li802[] C_aligned={C_lihdr(0,0,56),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,109,97,107,101,45,112,114,111,112,101,114,116,121,45,99,111,110,100,105,116,105,111,110,32,107,105,110,100,32,46,32,112,114,111,112,115,41};
static C_char C_TLS li803[] C_aligned={C_lihdr(0,0,19),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,48,56,54,41,0,0,0,0,0};
static C_char C_TLS li804[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,54,49,51,49,32,103,54,49,52,51,41,0,0,0,0};
static C_char C_TLS li805[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,54,49,48,52,32,103,54,49,49,54,41,0,0,0,0};
static C_char C_TLS li806[] C_aligned={C_lihdr(0,0,55),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,109,97,107,101,45,99,111,109,112,111,115,105,116,101,45,99,111,110,100,105,116,105,111,110,32,99,49,32,46,32,99,111,110,100,115,41,0};
static C_char C_TLS li807[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,54,49,57,49,32,103,54,50,48,51,41,0,0,0,0};
static C_char C_TLS li808[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,54,49,54,52,32,103,54,49,55,54,41,0,0,0,0};
static C_char C_TLS li809[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,99,111,110,100,105,116,105,111,110,32,97,114,103,49,32,46,32,97,114,103,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li810[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,99,111,110,100,105,116,105,111,110,63,32,120,41};
static C_char C_TLS li811[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,112,114,111,112,115,41,0,0,0,0};
static C_char C_TLS li812[] C_aligned={C_lihdr(0,0,9),40,103,54,50,50,55,32,107,41,0,0,0,0,0,0,0};
static C_char C_TLS li813[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,54,50,50,49,32,103,54,50,51,51,41,0,0,0,0};
static C_char C_TLS li814[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,99,111,110,100,105,116,105,111,110,45,62,108,105,115,116,32,120,41,0,0,0};
static C_char C_TLS li815[] C_aligned={C_lihdr(0,0,11),40,102,95,50,55,54,50,48,32,99,41,0,0,0,0,0};
static C_char C_TLS li816[] C_aligned={C_lihdr(0,0,44),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,99,111,110,100,105,116,105,111,110,45,112,114,101,100,105,99,97,116,101,32,107,105,110,100,41,0,0,0,0};
static C_char C_TLS li817[] C_aligned={C_lihdr(0,0,11),40,102,95,50,55,54,52,55,32,99,41,0,0,0,0,0};
static C_char C_TLS li818[] C_aligned={C_lihdr(0,0,67),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,99,111,110,100,105,116,105,111,110,45,112,114,111,112,101,114,116,121,45,97,99,99,101,115,115,111,114,32,107,105,110,100,32,112,114,111,112,32,46,32,101,114,114,45,100,101,102,41,0,0,0,0,0};
static C_char C_TLS li819[] C_aligned={C_lihdr(0,0,64),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,103,101,116,45,99,111,110,100,105,116,105,111,110,45,112,114,111,112,101,114,116,121,32,99,32,107,105,110,100,32,112,114,111,112,32,46,32,101,114,114,45,100,101,102,41};
static C_char C_TLS li820[] C_aligned={C_lihdr(0,0,8),40,97,50,55,55,49,51,41};
static C_char C_TLS li821[] C_aligned={C_lihdr(0,0,9),40,103,54,50,57,50,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li822[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,54,50,57,49,32,103,54,50,57,56,41,0,0,0,0,0,0,0};
static C_char C_TLS li823[] C_aligned={C_lihdr(0,0,21),40,119,114,105,116,101,97,114,103,115,32,97,114,103,115,32,112,111,114,116,41,0,0,0};
static C_char C_TLS li824[] C_aligned={C_lihdr(0,0,11),40,103,54,51,51,53,32,109,115,103,41,0,0,0,0,0};
static C_char C_TLS li825[] C_aligned={C_lihdr(0,0,22),40,98,111,100,121,54,51,49,50,32,112,111,114,116,32,104,101,97,100,101,114,41,0,0};
static C_char C_TLS li826[] C_aligned={C_lihdr(0,0,22),40,100,101,102,45,104,101,97,100,101,114,54,51,49,53,32,37,112,111,114,116,41,0,0};
static C_char C_TLS li827[] C_aligned={C_lihdr(0,0,14),40,100,101,102,45,112,111,114,116,54,51,49,52,41,0,0};
static C_char C_TLS li828[] C_aligned={C_lihdr(0,0,49),40,99,104,105,99,107,101,110,46,99,111,110,100,105,116,105,111,110,35,112,114,105,110,116,45,101,114,114,111,114,45,109,101,115,115,97,103,101,32,101,120,32,46,32,97,114,103,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li829[] C_aligned={C_lihdr(0,0,47),40,35,35,115,121,115,35,115,104,111,119,45,101,120,99,101,112,116,105,111,110,45,119,97,114,110,105,110,103,32,101,120,110,32,99,97,117,115,101,32,46,32,114,101,115,116,41,0};
static C_char C_TLS li830[] C_aligned={C_lihdr(0,0,34),40,35,35,115,121,115,35,101,114,114,111,114,45,104,111,111,107,32,99,111,100,101,32,108,111,99,32,46,32,97,114,103,115,41,0,0,0,0,0,0};
static C_char C_TLS li831[] C_aligned={C_lihdr(0,0,22),40,35,35,115,121,115,35,115,116,114,117,99,116,117,114,101,63,32,120,32,115,41,0,0};
static C_char C_TLS li832[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,103,101,110,101,114,105,99,45,115,116,114,117,99,116,117,114,101,63,32,120,41,0,0,0,0};
static C_char C_TLS li833[] C_aligned={C_lihdr(0,0,16),40,35,35,115,121,115,35,115,108,111,116,32,120,32,105,41};
static C_char C_TLS li834[] C_aligned={C_lihdr(0,0,14),40,35,35,115,121,115,35,115,105,122,101,32,120,41,0,0};
static C_char C_TLS li835[] C_aligned={C_lihdr(0,0,14),67,95,109,97,107,101,95,112,111,105,110,116,101,114,0,0};
static C_char C_TLS li836[] C_aligned={C_lihdr(0,0,21),67,95,109,97,107,101,95,116,97,103,103,101,100,95,112,111,105,110,116,101,114,0,0,0};
static C_char C_TLS li837[] C_aligned={C_lihdr(0,0,18),40,35,35,115,121,115,35,112,111,105,110,116,101,114,63,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li838[] C_aligned={C_lihdr(0,0,37),40,35,35,115,121,115,35,115,101,116,45,112,111,105,110,116,101,114,45,97,100,100,114,101,115,115,33,32,112,116,114,32,97,100,100,114,41,0,0,0};
static C_char C_TLS li839[] C_aligned={C_lihdr(0,0,21),40,35,35,115,121,115,35,98,121,116,101,118,101,99,116,111,114,63,32,120,41,0,0,0};
static C_char C_TLS li840[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,115,116,114,105,110,103,45,62,112,98,121,116,101,118,101,99,116,111,114,32,115,41,0,0,0};
static C_char C_TLS li841[] C_aligned={C_lihdr(0,0,20),40,35,35,115,121,115,35,112,101,114,109,97,110,101,110,116,63,32,120,41,0,0,0,0};
static C_char C_TLS li842[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,98,108,111,99,107,45,97,100,100,114,101,115,115,32,120,41,0};
static C_char C_TLS li843[] C_aligned={C_lihdr(0,0,19),40,35,35,115,121,115,35,108,111,99,97,116,105,118,101,63,32,120,41,0,0,0,0,0};
static C_char C_TLS li844[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,115,114,102,105,45,52,45,118,101,99,116,111,114,63,32,120,41};
static C_char C_TLS li845[] C_aligned={C_lihdr(0,0,20),40,35,35,115,121,115,35,110,117,108,108,45,112,111,105,110,116,101,114,41,0,0,0,0};
static C_char C_TLS li846[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,110,117,108,108,45,112,111,105,110,116,101,114,63,32,120,41,0};
static C_char C_TLS li847[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,97,100,100,114,101,115,115,45,62,112,111,105,110,116,101,114,32,97,100,100,114,41,0,0,0};
static C_char C_TLS li848[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,112,111,105,110,116,101,114,45,62,97,100,100,114,101,115,115,32,112,116,114,41,0,0,0,0};
static C_char C_TLS li849[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,109,97,107,101,45,99,45,115,116,114,105,110,103,32,115,116,114,32,46,32,114,101,115,116,41};
static C_char C_TLS li850[] C_aligned={C_lihdr(0,0,21),67,95,112,101,101,107,95,115,105,103,110,101,100,95,105,110,116,101,103,101,114,0,0,0};
static C_char C_TLS li851[] C_aligned={C_lihdr(0,0,23),67,95,112,101,101,107,95,117,110,115,105,103,110,101,100,95,105,110,116,101,103,101,114,0};
static C_char C_TLS li852[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,112,101,101,107,45,102,105,120,110,117,109,32,98,32,105,41,0};
static C_char C_TLS li853[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,112,101,101,107,45,98,121,116,101,32,112,116,114,32,105,41,0};
static C_char C_TLS li854[] C_aligned={C_lihdr(0,0,30),40,35,35,115,121,115,35,118,101,99,116,111,114,45,62,115,116,114,117,99,116,117,114,101,33,32,118,101,99,41,0,0};
static C_char C_TLS li855[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,112,101,101,107,45,100,111,117,98,108,101,32,98,32,105,41,0};
static C_char C_TLS li856[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,112,101,101,107,45,99,45,115,116,114,105,110,103,32,98,32,105,41,0,0,0,0,0,0,0};
static C_char C_TLS li857[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,112,101,101,107,45,110,111,110,110,117,108,108,45,99,45,115,116,114,105,110,103,32,98,32,105,41,0,0,0,0,0,0,0};
static C_char C_TLS li858[] C_aligned={C_lihdr(0,0,34),40,35,35,115,121,115,35,112,101,101,107,45,97,110,100,45,102,114,101,101,45,99,45,115,116,114,105,110,103,32,98,32,105,41,0,0,0,0,0,0};
static C_char C_TLS li859[] C_aligned={C_lihdr(0,0,42),40,35,35,115,121,115,35,112,101,101,107,45,97,110,100,45,102,114,101,101,45,110,111,110,110,117,108,108,45,99,45,115,116,114,105,110,103,32,98,32,105,41,0,0,0,0,0,0};
static C_char C_TLS li860[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,112,111,107,101,45,99,45,115,116,114,105,110,103,32,98,32,105,32,115,41,0,0,0,0,0};
static C_char C_TLS li861[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,112,111,107,101,45,105,110,116,101,103,101,114,32,98,32,105,32,110,41,0,0,0,0,0,0};
static C_char C_TLS li862[] C_aligned={C_lihdr(0,0,25),40,35,35,115,121,115,35,112,111,107,101,45,100,111,117,98,108,101,32,98,32,105,32,110,41,0,0,0,0,0,0,0};
static C_char C_TLS li863[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li864[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,112,101,101,107,45,99,45,115,116,114,105,110,103,45,108,105,115,116,32,112,116,114,32,110,41};
static C_char C_TLS li865[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li866[] C_aligned={C_lihdr(0,0,41),40,35,35,115,121,115,35,112,101,101,107,45,97,110,100,45,102,114,101,101,45,99,45,115,116,114,105,110,103,45,108,105,115,116,32,112,116,114,32,110,41,0,0,0,0,0,0,0};
static C_char C_TLS li867[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,118,101,99,116,111,114,45,62,99,108,111,115,117,114,101,33,32,118,101,99,32,97,100,100,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li868[] C_aligned={C_lihdr(0,0,38),40,35,35,115,121,115,35,115,121,109,98,111,108,45,104,97,115,45,116,111,112,108,101,118,101,108,45,98,105,110,100,105,110,103,63,32,115,41,0,0};
static C_char C_TLS li869[] C_aligned={C_lihdr(0,0,48),40,35,35,115,121,115,35,99,111,112,121,45,98,121,116,101,115,32,102,114,111,109,32,116,111,32,111,102,102,115,101,116,49,32,111,102,102,115,101,116,50,32,98,121,116,101,115,41};
static C_char C_TLS li870[] C_aligned={C_lihdr(0,0,48),40,35,35,115,121,115,35,99,111,112,121,45,119,111,114,100,115,32,102,114,111,109,32,116,111,32,111,102,102,115,101,116,49,32,111,102,102,115,101,116,50,32,119,111,114,100,115,41};
static C_char C_TLS li871[] C_aligned={C_lihdr(0,0,51),40,35,35,115,121,115,35,99,111,109,112,97,114,101,45,98,121,116,101,115,32,102,114,111,109,32,116,111,32,111,102,102,115,101,116,49,32,111,102,102,115,101,116,50,32,98,121,116,101,115,41,0,0,0,0,0};
static C_char C_TLS li872[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,98,108,111,99,107,45,112,111,105,110,116,101,114,32,120,41,0};
static C_char C_TLS li873[] C_aligned={C_lihdr(0,0,31),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,99,104,97,114,45,97,114,103,117,109,101,110,116,32,120,41,0};
static C_char C_TLS li874[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,102,105,120,110,117,109,45,97,114,103,117,109,101,110,116,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li875[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,102,108,111,110,117,109,45,97,114,103,117,109,101,110,116,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li876[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,98,108,111,99,107,45,97,114,103,117,109,101,110,116,32,120,41};
static C_char C_TLS li877[] C_aligned={C_lihdr(0,0,43),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,115,116,114,117,99,116,45,119,114,97,112,112,101,114,45,97,114,103,117,109,101,110,116,32,116,32,120,41,0,0,0,0,0};
static C_char C_TLS li878[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,115,116,114,105,110,103,45,97,114,103,117,109,101,110,116,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li879[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,115,121,109,98,111,108,45,97,114,103,117,109,101,110,116,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li880[] C_aligned={C_lihdr(0,0,34),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,112,111,105,110,116,101,114,45,97,114,103,117,109,101,110,116,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li881[] C_aligned={C_lihdr(0,0,44),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,116,97,103,103,101,100,45,112,111,105,110,116,101,114,45,97,114,103,117,109,101,110,116,32,120,32,116,120,41,0,0,0,0};
static C_char C_TLS li882[] C_aligned={C_lihdr(0,0,48),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,114,97,110,103,101,100,45,105,110,116,101,103,101,114,45,97,114,103,117,109,101,110,116,32,111,98,106,32,115,105,122,101,41};
static C_char C_TLS li883[] C_aligned={C_lihdr(0,0,57),40,35,35,115,121,115,35,102,111,114,101,105,103,110,45,117,110,115,105,103,110,101,100,45,114,97,110,103,101,100,45,105,110,116,101,103,101,114,45,97,114,103,117,109,101,110,116,32,111,98,106,32,115,105,122,101,41,0,0,0,0,0,0,0};
static C_char C_TLS li884[] C_aligned={C_lihdr(0,0,37),40,35,35,115,121,115,35,100,101,102,97,117,108,116,45,101,120,99,101,112,116,105,111,110,45,104,97,110,100,108,101,114,32,97,114,103,41,0,0,0};
static C_char C_TLS li885[] C_aligned={C_lihdr(0,0,38),40,35,35,115,121,115,35,109,97,107,101,45,116,104,114,101,97,100,32,116,104,117,110,107,32,115,116,97,116,101,32,110,97,109,101,32,113,41,0,0};
static C_char C_TLS li886[] C_aligned={C_lihdr(0,0,27),40,35,35,115,121,115,35,109,97,107,101,45,109,117,116,101,120,32,105,100,32,111,119,110,101,114,41,0,0,0,0,0};
static C_char C_TLS li887[] C_aligned={C_lihdr(0,0,16),40,35,35,115,121,115,35,115,99,104,101,100,117,108,101,41};
static C_char C_TLS li888[] C_aligned={C_lihdr(0,0,8),40,97,50,57,49,48,51,41};
static C_char C_TLS li889[] C_aligned={C_lihdr(0,0,15),40,97,50,57,48,57,52,32,114,101,116,117,114,110,41,0};
static C_char C_TLS li890[] C_aligned={C_lihdr(0,0,21),40,35,35,115,121,115,35,116,104,114,101,97,100,45,121,105,101,108,100,33,41,0,0,0};
static C_char C_TLS li891[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,107,105,108,108,45,111,116,104,101,114,45,116,104,114,101,97,100,115,32,116,104,117,110,107,41};
static C_char C_TLS li892[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,114,101,115,117,109,101,45,116,104,114,101,97,100,45,111,110,45,101,118,101,110,116,32,116,41};
static C_char C_TLS li893[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,115,117,115,112,101,110,100,45,116,104,114,101,97,100,45,111,110,45,101,118,101,110,116,32,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li894[] C_aligned={C_lihdr(0,0,12),40,97,50,57,49,51,48,32,46,32,95,41,0,0,0,0};
static C_char C_TLS li895[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,115,108,101,101,112,45,117,110,116,105,108,45,105,110,116,101,114,114,117,112,116,41,0,0,0};
static C_char C_TLS li896[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,109,97,107,101,45,101,118,101,110,116,45,113,117,101,117,101,41};
static C_char C_TLS li897[] C_aligned={C_lihdr(0,0,31),40,35,35,115,121,115,35,97,100,100,45,101,118,101,110,116,45,116,111,45,113,117,101,117,101,33,32,113,32,101,41,0};
static C_char C_TLS li898[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,103,101,116,45,110,101,120,116,45,101,118,101,110,116,32,113,41};
static C_char C_TLS li899[] C_aligned={C_lihdr(0,0,7),40,97,103,97,105,110,41,0};
static C_char C_TLS li900[] C_aligned={C_lihdr(0,0,29),40,35,35,115,121,115,35,119,97,105,116,45,102,111,114,45,110,101,120,116,45,101,118,101,110,116,32,113,41,0,0,0};
static C_char C_TLS li901[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,98,97,115,101,35,115,108,101,101,112,45,104,111,111,107,32,110,41,0,0,0,0,0};
static C_char C_TLS li902[] C_aligned={C_lihdr(0,0,22),40,99,104,105,99,107,101,110,46,98,97,115,101,35,115,108,101,101,112,32,110,41,0,0};
static C_char C_TLS li903[] C_aligned={C_lihdr(0,0,16),67,95,99,111,110,116,101,120,116,95,115,119,105,116,99,104};
static C_char C_TLS li904[] C_aligned={C_lihdr(0,0,13),40,108,111,111,112,32,114,101,97,115,111,110,41,0,0,0};
static C_char C_TLS li905[] C_aligned={C_lihdr(0,0,35),40,35,35,115,121,115,35,105,110,116,101,114,114,117,112,116,45,104,111,111,107,32,114,101,97,115,111,110,32,115,116,97,116,101,41,0,0,0,0,0};
static C_char C_TLS li906[] C_aligned={C_lihdr(0,0,28),40,35,35,115,121,115,35,100,105,115,112,97,116,99,104,45,105,110,116,101,114,114,117,112,116,32,107,41,0,0,0,0};
static C_char C_TLS li907[] C_aligned={C_lihdr(0,0,20),40,35,35,115,121,115,35,117,112,100,97,116,101,45,101,114,114,110,111,41,0,0,0,0};
static C_char C_TLS li908[] C_aligned={C_lihdr(0,0,13),40,35,35,115,121,115,35,101,114,114,110,111,41,0,0,0};
static C_char C_TLS li909[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,54,55,54,48,32,99,41,0,0};
static C_char C_TLS li910[] C_aligned={C_lihdr(0,0,13),40,114,101,97,100,108,110,32,112,111,114,116,41,0,0,0};
static C_char C_TLS li911[] C_aligned={C_lihdr(0,0,6),40,108,111,111,112,41,0,0};
static C_char C_TLS li912[] C_aligned={C_lihdr(0,0,36),40,114,101,97,100,45,101,115,99,97,112,101,100,45,115,101,120,112,32,112,111,114,116,32,115,107,105,112,45,98,114,97,99,101,63,41,0,0,0,0};
static C_char C_TLS li913[] C_aligned={C_lihdr(0,0,15),40,100,111,108,111,111,112,54,55,57,53,32,108,110,41,0};
static C_char C_TLS li914[] C_aligned={C_lihdr(0,0,15),40,103,101,116,47,99,108,101,97,114,45,115,116,114,41,0};
static C_char C_TLS li915[] C_aligned={C_lihdr(0,0,27),40,108,111,111,112,50,32,108,115,116,32,110,101,120,116,45,115,116,114,105,110,103,32,97,99,99,41,0,0,0,0,0};
static C_char C_TLS li916[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,108,115,116,41,0,0,0,0,0,0};
static C_char C_TLS li917[] C_aligned={C_lihdr(0,0,32),40,35,35,115,121,115,35,117,115,101,114,45,114,101,97,100,45,104,111,111,107,32,99,104,97,114,32,112,111,114,116,41};
static C_char C_TLS li918[] C_aligned={C_lihdr(0,0,47),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,99,104,97,110,103,101,45,100,105,114,101,99,116,111,114,121,32,110,97,109,101,41,0};
static C_char C_TLS li919[] C_aligned={C_lihdr(0,0,33),40,35,35,115,121,115,35,99,104,97,110,103,101,45,100,105,114,101,99,116,111,114,121,45,104,111,111,107,32,100,105,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li920[] C_aligned={C_lihdr(0,0,71),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,103,101,116,45,101,110,118,105,114,111,110,109,101,110,116,45,118,97,114,105,97,98,108,101,32,110,111,110,110,117,108,108,45,99,45,115,116,114,105,110,103,54,57,49,52,41,0};
static C_char C_TLS li921[] C_aligned={C_lihdr(0,0,59),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,115,101,116,45,101,110,118,105,114,111,110,109,101,110,116,45,118,97,114,105,97,98,108,101,33,32,118,97,114,32,118,97,108,41,0,0,0,0,0};
static C_char C_TLS li922[] C_aligned={C_lihdr(0,0,57),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,117,110,115,101,116,45,101,110,118,105,114,111,110,109,101,110,116,45,118,97,114,105,97,98,108,101,33,32,118,97,114,41,0,0,0,0,0,0,0};
static C_char C_TLS li923[] C_aligned={C_lihdr(0,0,8),40,115,99,97,110,32,106,41};
static C_char C_TLS li924[] C_aligned={C_lihdr(0,0,8),40,108,111,111,112,32,105,41};
static C_char C_TLS li925[] C_aligned={C_lihdr(0,0,51),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,103,101,116,45,101,110,118,105,114,111,110,109,101,110,116,45,118,97,114,105,97,98,108,101,115,41,0,0,0,0,0};
static C_char C_TLS li926[] C_aligned={C_lihdr(0,0,45),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,101,120,101,99,117,116,97,98,108,101,45,112,97,116,104,110,97,109,101,41,0,0,0};
static C_char C_TLS li927[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,97,114,103,99,43,97,114,103,118,41,0,0,0,0,0};
static C_char C_TLS li928[] C_aligned={C_lihdr(0,0,16),40,100,111,108,111,111,112,54,57,53,54,32,105,32,118,41};
static C_char C_TLS li929[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,112,114,111,99,101,115,115,45,99,111,110,116,101,120,116,35,97,114,103,118,41,0,0};
static C_char C_TLS li930[] C_aligned={C_lihdr(0,0,36),40,99,104,105,99,107,101,110,46,103,99,35,99,117,114,114,101,110,116,45,103,99,45,109,105,108,108,105,115,101,99,111,110,100,115,41,0,0,0,0};
static C_char C_TLS li931[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,103,99,35,115,101,116,45,103,99,45,114,101,112,111,114,116,33,32,102,108,97,103,41};
static C_char C_TLS li932[] C_aligned={C_lihdr(0,0,30),40,99,104,105,99,107,101,110,46,103,99,35,109,101,109,111,114,121,45,115,116,97,116,105,115,116,105,99,115,41,0,0};
static C_char C_TLS li933[] C_aligned={C_lihdr(0,0,20),67,95,114,101,103,105,115,116,101,114,95,102,105,110,97,108,105,122,101,114,0,0,0,0};
static C_char C_TLS li934[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,105,110,105,116,45,102,105,110,97,108,105,122,101,114,32,120,32,121,41,0,0,0,0,0,0};
static C_char C_TLS li935[] C_aligned={C_lihdr(0,0,25),40,99,104,105,99,107,101,110,46,103,99,35,102,105,110,97,108,105,122,101,114,63,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li936[] C_aligned={C_lihdr(0,0,11),40,104,97,110,100,108,101,114,32,111,41,0,0,0,0,0};
static C_char C_TLS li937[] C_aligned={C_lihdr(0,0,10),40,104,97,110,100,108,101,32,111,41,0,0,0,0,0,0};
static C_char C_TLS li938[] C_aligned={C_lihdr(0,0,15),40,97,51,48,50,54,52,32,46,32,114,101,115,116,41,0};
static C_char C_TLS li939[] C_aligned={C_lihdr(0,0,15),40,97,51,48,50,56,53,32,112,114,111,99,32,105,41,0};
static C_char C_TLS li940[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,55,48,51,53,32,103,55,48,52,50,41,0,0,0,0,0,0,0};
static C_char C_TLS li941[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,103,99,35,109,97,107,101,45,102,105,110,97,108,105,122,101,114,32,46,32,111,98,106,101,99,116,115,41,0,0,0};
static C_char C_TLS li942[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,55,48,55,55,32,103,55,48,56,52,41,0,0,0,0,0,0,0};
static C_char C_TLS li943[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,103,99,35,97,100,100,45,116,111,45,102,105,110,97,108,105,122,101,114,32,102,32,46,32,111,98,106,101,99,116,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li944[] C_aligned={C_lihdr(0,0,8),40,97,51,48,52,52,57,41};
static C_char C_TLS li945[] C_aligned={C_lihdr(0,0,11),40,97,51,48,52,52,51,32,101,120,41,0,0,0,0,0};
static C_char C_TLS li946[] C_aligned={C_lihdr(0,0,8),40,97,51,48,52,54,49,41};
static C_char C_TLS li947[] C_aligned={C_lihdr(0,0,8),40,97,51,48,52,56,52,41};
static C_char C_TLS li948[] C_aligned={C_lihdr(0,0,15),40,97,51,48,52,55,56,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li949[] C_aligned={C_lihdr(0,0,8),40,97,51,48,52,53,53,41};
static C_char C_TLS li950[] C_aligned={C_lihdr(0,0,10),40,97,51,48,52,51,55,32,107,41,0,0,0,0,0,0};
static C_char C_TLS li951[] C_aligned={C_lihdr(0,0,14),40,100,111,108,111,111,112,55,49,48,57,32,105,41,0,0};
static C_char C_TLS li952[] C_aligned={C_lihdr(0,0,36),40,35,35,115,121,115,35,114,117,110,45,112,101,110,100,105,110,103,45,102,105,110,97,108,105,122,101,114,115,32,115,116,97,116,101,41,0,0,0,0};
static C_char C_TLS li953[] C_aligned={C_lihdr(0,0,6),40,108,111,111,112,41,0,0};
static C_char C_TLS li954[] C_aligned={C_lihdr(0,0,24),40,35,35,115,121,115,35,102,111,114,99,101,45,102,105,110,97,108,105,122,101,114,115,41};
static C_char C_TLS li955[] C_aligned={C_lihdr(0,0,21),40,99,104,105,99,107,101,110,46,103,99,35,103,99,32,46,32,97,114,103,41,0,0,0};
static C_char C_TLS li956[] C_aligned={C_lihdr(0,0,41),40,35,35,115,121,115,35,109,97,107,101,45,108,111,99,97,116,105,118,101,32,111,98,106,32,105,110,100,101,120,32,119,101,97,107,63,32,108,111,99,41,0,0,0,0,0,0,0};
static C_char C_TLS li957[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,112,108,105,115,116,35,112,117,116,33,32,115,121,109,32,112,114,111,112,32,118,97,108,41,0,0,0,0,0,0,0};
static C_char C_TLS li958[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,112,108,105,115,116,35,103,101,116,32,115,121,109,32,112,114,111,112,32,46,32,114,101,115,116,41,0,0,0,0,0};
static C_char C_TLS li959[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,112,116,108,41,0,0,0,0,0,0};
static C_char C_TLS li960[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,112,108,105,115,116,35,114,101,109,112,114,111,112,33,32,115,121,109,32,112,114,111,112,41,0,0,0,0,0,0,0};
static C_char C_TLS li961[] C_aligned={C_lihdr(0,0,12),40,108,111,111,112,32,112,108,105,115,116,41,0,0,0,0};
static C_char C_TLS li962[] C_aligned={C_lihdr(0,0,40),40,99,104,105,99,107,101,110,46,112,108,105,115,116,35,103,101,116,45,112,114,111,112,101,114,116,105,101,115,32,115,121,109,32,112,114,111,112,115,41};
static C_char C_TLS li963[] C_aligned={C_lihdr(0,0,10),40,112,110,117,109,32,110,117,109,41,0,0,0,0,0,0};
static C_char C_TLS li964[] C_aligned={C_lihdr(0,0,14),40,114,111,117,110,100,45,116,111,32,120,32,121,41,0,0};
static C_char C_TLS li965[] C_aligned={C_lihdr(0,0,12),40,112,109,101,109,32,98,121,116,101,115,41,0,0,0,0};
static C_char C_TLS li966[] C_aligned={C_lihdr(0,0,26),40,35,35,115,121,115,35,100,105,115,112,108,97,121,45,116,105,109,101,115,32,105,110,102,111,41,0,0,0,0,0,0};
static C_char C_TLS li967[] C_aligned={C_lihdr(0,0,17),67,95,100,117,109,112,95,104,101,97,112,95,115,116,97,116,101,0,0,0,0,0,0,0};
static C_char C_TLS li968[] C_aligned={C_lihdr(0,0,21),67,95,102,105,108,116,101,114,95,104,101,97,112,95,111,98,106,101,99,116,115,0,0,0};
static C_char C_TLS li969[] C_aligned={C_lihdr(0,0,32),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,115,111,102,116,119,97,114,101,45,116,121,112,101,41};
static C_char C_TLS li970[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,109,97,99,104,105,110,101,45,116,121,112,101,41,0};
static C_char C_TLS li971[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,109,97,99,104,105,110,101,45,98,121,116,101,45,111,114,100,101,114,41,0,0,0};
static C_char C_TLS li972[] C_aligned={C_lihdr(0,0,35),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,115,111,102,116,119,97,114,101,45,118,101,114,115,105,111,110,41,0,0,0,0,0};
static C_char C_TLS li973[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,98,117,105,108,100,45,112,108,97,116,102,111,114,109,41,0,0,0,0,0,0,0};
static C_char C_TLS li974[] C_aligned={C_lihdr(0,0,7),40,115,116,114,32,120,41,0};
static C_char C_TLS li975[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,99,104,105,99,107,101,110,45,118,101,114,115,105,111,110,32,46,32,114,101,115,116,41,0,0,0,0,0,0,0};
static C_char C_TLS li976[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,99,104,105,99,107,101,110,45,104,111,109,101,41,0};
static C_char C_TLS li977[] C_aligned={C_lihdr(0,0,16),40,108,111,111,112,32,115,116,97,114,116,32,112,111,115,41};
static C_char C_TLS li978[] C_aligned={C_lihdr(0,0,23),40,35,35,115,121,115,35,115,112,108,105,116,45,112,97,116,104,32,112,97,116,104,41,0};
static C_char C_TLS li979[] C_aligned={C_lihdr(0,0,37),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,99,104,111,112,45,115,101,112,97,114,97,116,111,114,32,115,116,114,41,0,0,0};
static C_char C_TLS li980[] C_aligned={C_lihdr(0,0,31),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,105,110,99,108,117,100,101,45,112,97,116,104,41,0};
static C_char C_TLS li981[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,45,62,102,101,97,116,117,114,101,45,105,100,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li982[] C_aligned={C_lihdr(0,0,9),40,99,104,101,99,107,32,102,41,0,0,0,0,0,0,0};
static C_char C_TLS li983[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,55,53,54,50,32,103,55,53,54,57,41,0,0,0,0,0,0,0};
static C_char C_TLS li984[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,114,101,103,105,115,116,101,114,45,102,101,97,116,117,114,101,33,32,46,32,102,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li985[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,102,102,115,41,0,0,0,0,0,0};
static C_char C_TLS li986[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,55,53,56,53,32,103,55,53,57,55,41,0,0,0,0};
static C_char C_TLS li987[] C_aligned={C_lihdr(0,0,43),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,117,110,114,101,103,105,115,116,101,114,45,102,101,97,116,117,114,101,33,32,46,32,102,115,41,0,0,0,0,0};
static C_char C_TLS li988[] C_aligned={C_lihdr(0,0,27),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,102,101,97,116,117,114,101,115,41,0,0,0,0,0};
static C_char C_TLS li989[] C_aligned={C_lihdr(0,0,10),40,108,111,111,112,32,105,100,115,41,0,0,0,0,0,0};
static C_char C_TLS li990[] C_aligned={C_lihdr(0,0,33),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,102,101,97,116,117,114,101,63,32,46,32,105,100,115,41,0,0,0,0,0,0,0};
static C_char C_TLS li991[] C_aligned={C_lihdr(0,0,16),67,95,114,101,116,117,114,110,95,116,111,95,104,111,115,116};
static C_char C_TLS li992[] C_aligned={C_lihdr(0,0,42),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,115,121,115,116,101,109,45,99,111,110,102,105,103,45,100,105,114,101,99,116,111,114,121,41,0,0,0,0,0,0};
static C_char C_TLS li993[] C_aligned={C_lihdr(0,0,41),40,99,104,105,99,107,101,110,46,112,108,97,116,102,111,114,109,35,115,121,115,116,101,109,45,99,97,99,104,101,45,100,105,114,101,99,116,111,114,121,41,0,0,0,0,0,0,0};
static C_char C_TLS li994[] C_aligned={C_lihdr(0,0,20),40,109,97,112,45,108,111,111,112,55,53,48,53,32,103,55,53,49,55,41,0,0,0,0};
static C_char C_TLS li995[] C_aligned={C_lihdr(0,0,19),40,102,111,114,45,101,97,99,104,45,108,111,111,112,55,52,54,51,41,0,0,0,0,0};
static C_char C_TLS li996[] C_aligned={C_lihdr(0,0,12),40,97,51,50,48,53,53,32,110,101,119,41,0,0,0,0};
static C_char C_TLS li997[] C_aligned={C_lihdr(0,0,16),67,95,98,117,105,108,100,95,112,108,97,116,102,111,114,109};
static C_char C_TLS li998[] C_aligned={C_lihdr(0,0,18),67,95,115,111,102,116,119,97,114,101,95,118,101,114,115,105,111,110,0,0,0,0,0,0};
static C_char C_TLS li999[] C_aligned={C_lihdr(0,0,20),67,95,109,97,99,104,105,110,101,95,98,121,116,101,95,111,114,100,101,114,0,0,0,0};
static C_char C_TLS li1000[] C_aligned={C_lihdr(0,0,14),67,95,109,97,99,104,105,110,101,95,116,121,112,101,0,0};
static C_char C_TLS li1001[] C_aligned={C_lihdr(0,0,15),67,95,115,111,102,116,119,97,114,101,95,116,121,112,101,0};
static C_char C_TLS li1002[] C_aligned={C_lihdr(0,0,12),40,97,51,50,49,53,52,32,115,121,109,41,0,0,0,0};
static C_char C_TLS li1003[] C_aligned={C_lihdr(0,0,16),40,97,51,50,49,54,51,32,115,121,109,32,108,115,116,41};
static C_char C_TLS li1004[] C_aligned={C_lihdr(0,0,10),40,97,51,50,50,48,51,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li1005[] C_aligned={C_lihdr(0,0,11),40,108,111,111,112,32,97,114,103,115,41,0,0,0,0,0};
static C_char C_TLS li1006[] C_aligned={C_lihdr(0,0,19),40,102,51,56,51,54,56,32,120,54,57,55,55,51,56,51,54,55,41,0,0,0,0,0};
static C_char C_TLS li1007[] C_aligned={C_lihdr(0,0,19),40,102,51,56,51,55,52,32,120,54,57,54,51,51,56,51,55,51,41,0,0,0,0,0};
static C_char C_TLS li1008[] C_aligned={C_lihdr(0,0,19),40,102,51,56,51,56,48,32,120,54,57,54,51,51,56,51,55,57,41,0,0,0,0,0};
static C_char C_TLS li1009[] C_aligned={C_lihdr(0,0,8),40,97,51,50,50,56,55,41};
static C_char C_TLS li1010[] C_aligned={C_lihdr(0,0,12),40,97,51,50,51,49,50,32,100,105,114,41,0,0,0,0};
static C_char C_TLS li1011[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,57,53,51,32,103,53,57,54,48,41,0,0,0,0,0,0,0};
static C_char C_TLS li1012[] C_aligned={C_lihdr(0,0,8),40,97,51,50,51,52,53,41};
static C_char C_TLS li1013[] C_aligned={C_lihdr(0,0,9),40,103,53,57,55,57,32,120,41,0,0,0,0,0,0,0};
static C_char C_TLS li1014[] C_aligned={C_lihdr(0,0,25),40,102,111,114,45,101,97,99,104,45,108,111,111,112,53,57,55,56,32,103,53,57,56,53,41,0,0,0,0,0,0,0};
static C_char C_TLS li1015[] C_aligned={C_lihdr(0,0,15),40,97,51,50,52,53,55,32,46,32,97,114,103,115,41,0};
static C_char C_TLS li1016[] C_aligned={C_lihdr(0,0,19),40,97,51,50,51,49,56,32,109,115,103,32,46,32,97,114,103,115,41,0,0,0,0,0};
static C_char C_TLS li1017[] C_aligned={C_lihdr(0,0,8),40,97,51,50,52,54,48,41};
static C_char C_TLS li1018[] C_aligned={C_lihdr(0,0,8),40,97,51,50,52,54,57,41};
static C_char C_TLS li1019[] C_aligned={C_lihdr(0,0,15),40,97,51,50,52,55,53,32,46,32,114,101,115,116,41,0};
static C_char C_TLS li1020[] C_aligned={C_lihdr(0,0,10),40,97,51,50,55,51,57,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li1021[] C_aligned={C_lihdr(0,0,14),40,97,51,50,55,52,56,32,120,32,105,32,121,41,0,0};
static C_char C_TLS li1022[] C_aligned={C_lihdr(0,0,12),40,97,51,50,55,53,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1023[] C_aligned={C_lihdr(0,0,12),40,97,51,50,55,54,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1024[] C_aligned={C_lihdr(0,0,12),40,97,51,50,55,55,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1025[] C_aligned={C_lihdr(0,0,12),40,97,51,50,55,56,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1026[] C_aligned={C_lihdr(0,0,12),40,97,51,50,55,57,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1027[] C_aligned={C_lihdr(0,0,12),40,97,51,50,56,48,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1028[] C_aligned={C_lihdr(0,0,12),40,97,51,50,56,49,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1029[] C_aligned={C_lihdr(0,0,12),40,97,51,50,56,50,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1030[] C_aligned={C_lihdr(0,0,12),40,97,51,50,56,51,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1031[] C_aligned={C_lihdr(0,0,12),40,97,51,50,56,52,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1032[] C_aligned={C_lihdr(0,0,12),40,97,51,50,56,53,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1033[] C_aligned={C_lihdr(0,0,12),40,97,51,50,56,54,56,32,120,32,121,41,0,0,0,0};
static C_char C_TLS li1034[] C_aligned={C_lihdr(0,0,10),40,97,51,50,57,48,50,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li1035[] C_aligned={C_lihdr(0,0,13),40,97,51,50,56,55,56,32,112,114,111,99,41,0,0,0};
static C_char C_TLS li1036[] C_aligned={C_lihdr(0,0,10),40,97,51,50,57,49,56,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li1037[] C_aligned={C_lihdr(0,0,10),40,97,51,50,57,55,51,32,120,41,0,0,0,0,0,0};
static C_char C_TLS li1038[] C_aligned={C_lihdr(0,0,15),40,97,51,50,57,56,57,32,112,114,111,99,32,105,41,0};
static C_char C_TLS li1039[] C_aligned={C_lihdr(0,0,16),40,97,51,50,57,52,52,32,103,101,116,32,115,101,116,41};
static C_char C_TLS li1040[] C_aligned={C_lihdr(0,0,15),40,97,51,50,57,51,52,32,112,114,111,99,32,105,41,0};
static C_char C_TLS li1041[] C_aligned={C_lihdr(0,0,10),40,116,111,112,108,101,118,101,108,41,0,0,0,0,0,0};


#define return(x) C_cblock C_r = (C_mpointer(&C_a,(void*)(x))); goto C_ret; C_cblockend
C_regparm static C_word C_fcall stub6952(C_word C_buf,C_word C_a0){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
C_word i=(C_word )(C_a0);
C_return(C_main_argv[C_unfix(i)]);
C_ret:
#undef return

return C_r;}

/* from chicken.process-context#executable-pathname in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
C_regparm static C_word C_fcall stub6944(C_word C_buf){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
C_r=C_mpointer(&C_a,(void*)C_executable_pathname());
return C_r;}

/* from k29980 */
C_regparm static C_word C_fcall stub6932(C_word C_buf,C_word C_a0){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
int t0=(int )C_unfix(C_a0);
C_r=C_mpointer(&C_a,(void*)C_getenventry(t0));
return C_r;}

/* from k29938 in chicken.process-context#get-environment-variable in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
C_regparm static C_word C_fcall stub6915(C_word C_buf,C_word C_a0){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
char * t0=(char * )C_c_string(C_a0);
C_r=C_mpointer(&C_a,(void*)C_getenv(t0));
return C_r;}

/* from k28937 */
C_regparm static C_word C_fcall stub6582(C_word C_buf,C_word C_a0){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
void * t0=(void * )C_c_pointer_or_null(C_a0);
C_free(t0);
return C_r;}

/* from k28928 */
C_regparm static C_word C_fcall stub6574(C_word C_buf,C_word C_a0,C_word C_a1){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
void * t0=(void * )C_c_pointer_or_null(C_a0);
int t1=(int )C_unfix(C_a1);
C_r=C_mpointer(&C_a,(void*)C_peek_c_string_at(t0,t1));
return C_r;}

/* from k28876 */
C_regparm static C_word C_fcall stub6555(C_word C_buf,C_word C_a0,C_word C_a1){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
void * t0=(void * )C_c_pointer_or_null(C_a0);
int t1=(int )C_unfix(C_a1);
C_r=C_mpointer(&C_a,(void*)C_peek_c_string_at(t0,t1));
return C_r;}

#define return(x) C_cblock C_r = (C_mpointer(&C_a,(void*)(x))); goto C_ret; C_cblockend
C_regparm static C_word C_fcall stub5708(C_word C_buf,C_word C_a0){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
C_word x=(C_word )(C_a0);
C_return((C_char *)x);
C_ret:
#undef return

return C_r;}

/* from k16025 */
C_regparm static C_word C_fcall stub2905(C_word C_buf,C_word C_a0,C_word C_a1){
C_word C_r=C_SCHEME_UNDEFINED,*C_a=(C_word*)C_buf;
double t0=(double )C_c_double(C_a0);
int t1=(int )C_unfix(C_a1);
C_r=C_flonum(&C_a,ldexp(t0,t1));
return C_r;}

C_noret_decl(f35157)
static void C_ccall f35157(C_word c,C_word *av) C_noret;
C_noret_decl(f35726)
static void C_ccall f35726(C_word c,C_word *av) C_noret;
C_noret_decl(f35941)
static void C_ccall f35941(C_word c,C_word *av) C_noret;
C_noret_decl(f35945)
static void C_ccall f35945(C_word c,C_word *av) C_noret;
C_noret_decl(f38368)
static void C_ccall f38368(C_word c,C_word *av) C_noret;
C_noret_decl(f38374)
static void C_ccall f38374(C_word c,C_word *av) C_noret;
C_noret_decl(f38380)
static void C_ccall f38380(C_word c,C_word *av) C_noret;
C_noret_decl(f_10018)
static void C_ccall f_10018(C_word c,C_word *av) C_noret;
C_noret_decl(f_10027)
static void C_ccall f_10027(C_word c,C_word *av) C_noret;
C_noret_decl(f_10030)
static void C_ccall f_10030(C_word c,C_word *av) C_noret;
C_noret_decl(f_10033)
static void C_ccall f_10033(C_word c,C_word *av) C_noret;
C_noret_decl(f_10036)
static void C_ccall f_10036(C_word c,C_word *av) C_noret;
C_noret_decl(f_10039)
static void C_ccall f_10039(C_word c,C_word *av) C_noret;
C_noret_decl(f_10048)
static C_word C_fcall f_10048(C_word t0,C_word t1);
C_noret_decl(f_10067)
static void C_ccall f_10067(C_word c,C_word *av) C_noret;
C_noret_decl(f_10073)
static void C_fcall f_10073(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10098)
static void C_ccall f_10098(C_word c,C_word *av) C_noret;
C_noret_decl(f_10100)
static void C_ccall f_10100(C_word c,C_word *av) C_noret;
C_noret_decl(f_10109)
static void C_fcall f_10109(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10130)
static void C_ccall f_10130(C_word c,C_word *av) C_noret;
C_noret_decl(f_10132)
static void C_ccall f_10132(C_word c,C_word *av) C_noret;
C_noret_decl(f_10138)
static void C_fcall f_10138(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10164)
static void C_ccall f_10164(C_word c,C_word *av) C_noret;
C_noret_decl(f_10171)
static void C_ccall f_10171(C_word c,C_word *av) C_noret;
C_noret_decl(f_10173)
static void C_ccall f_10173(C_word c,C_word *av) C_noret;
C_noret_decl(f_10185)
static void C_fcall f_10185(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10220)
static void C_ccall f_10220(C_word c,C_word *av) C_noret;
C_noret_decl(f_10230)
static void C_ccall f_10230(C_word c,C_word *av) C_noret;
C_noret_decl(f_10239)
static void C_fcall f_10239(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10281)
static void C_ccall f_10281(C_word c,C_word *av) C_noret;
C_noret_decl(f_10310)
static void C_ccall f_10310(C_word c,C_word *av) C_noret;
C_noret_decl(f_10317)
static void C_fcall f_10317(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10320)
static void C_ccall f_10320(C_word c,C_word *av) C_noret;
C_noret_decl(f_10349)
static void C_ccall f_10349(C_word c,C_word *av) C_noret;
C_noret_decl(f_10355)
static void C_fcall f_10355(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10371)
static void C_ccall f_10371(C_word c,C_word *av) C_noret;
C_noret_decl(f_10396)
static void C_ccall f_10396(C_word c,C_word *av) C_noret;
C_noret_decl(f_10405)
static void C_fcall f_10405(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10446)
static void C_ccall f_10446(C_word c,C_word *av) C_noret;
C_noret_decl(f_10468)
static void C_ccall f_10468(C_word c,C_word *av) C_noret;
C_noret_decl(f_10500)
static void C_ccall f_10500(C_word c,C_word *av) C_noret;
C_noret_decl(f_10516)
static void C_fcall f_10516(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10519)
static void C_ccall f_10519(C_word c,C_word *av) C_noret;
C_noret_decl(f_10541)
static void C_ccall f_10541(C_word c,C_word *av) C_noret;
C_noret_decl(f_10547)
static void C_fcall f_10547(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10572)
static void C_ccall f_10572(C_word c,C_word *av) C_noret;
C_noret_decl(f_10612)
static void C_ccall f_10612(C_word c,C_word *av) C_noret;
C_noret_decl(f_10624)
static void C_fcall f_10624(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10643)
static void C_ccall f_10643(C_word c,C_word *av) C_noret;
C_noret_decl(f_10665)
static void C_ccall f_10665(C_word c,C_word *av) C_noret;
C_noret_decl(f_10668)
static void C_ccall f_10668(C_word c,C_word *av) C_noret;
C_noret_decl(f_10671)
static void C_ccall f_10671(C_word c,C_word *av) C_noret;
C_noret_decl(f_10674)
static void C_ccall f_10674(C_word c,C_word *av) C_noret;
C_noret_decl(f_10680)
static void C_ccall f_10680(C_word c,C_word *av) C_noret;
C_noret_decl(f_10683)
static void C_ccall f_10683(C_word c,C_word *av) C_noret;
C_noret_decl(f_10686)
static void C_ccall f_10686(C_word c,C_word *av) C_noret;
C_noret_decl(f_10689)
static void C_ccall f_10689(C_word c,C_word *av) C_noret;
C_noret_decl(f_10692)
static void C_ccall f_10692(C_word c,C_word *av) C_noret;
C_noret_decl(f_10695)
static void C_ccall f_10695(C_word c,C_word *av) C_noret;
C_noret_decl(f_10698)
static void C_ccall f_10698(C_word c,C_word *av) C_noret;
C_noret_decl(f_10701)
static void C_ccall f_10701(C_word c,C_word *av) C_noret;
C_noret_decl(f_10704)
static void C_ccall f_10704(C_word c,C_word *av) C_noret;
C_noret_decl(f_10707)
static void C_ccall f_10707(C_word c,C_word *av) C_noret;
C_noret_decl(f_10710)
static void C_ccall f_10710(C_word c,C_word *av) C_noret;
C_noret_decl(f_10713)
static void C_ccall f_10713(C_word c,C_word *av) C_noret;
C_noret_decl(f_10716)
static void C_ccall f_10716(C_word c,C_word *av) C_noret;
C_noret_decl(f_10719)
static void C_ccall f_10719(C_word c,C_word *av) C_noret;
C_noret_decl(f_10722)
static void C_ccall f_10722(C_word c,C_word *av) C_noret;
C_noret_decl(f_10725)
static void C_ccall f_10725(C_word c,C_word *av) C_noret;
C_noret_decl(f_10728)
static void C_ccall f_10728(C_word c,C_word *av) C_noret;
C_noret_decl(f_10731)
static void C_ccall f_10731(C_word c,C_word *av) C_noret;
C_noret_decl(f_10734)
static void C_ccall f_10734(C_word c,C_word *av) C_noret;
C_noret_decl(f_10737)
static void C_ccall f_10737(C_word c,C_word *av) C_noret;
C_noret_decl(f_10740)
static void C_ccall f_10740(C_word c,C_word *av) C_noret;
C_noret_decl(f_10743)
static void C_ccall f_10743(C_word c,C_word *av) C_noret;
C_noret_decl(f_10746)
static void C_ccall f_10746(C_word c,C_word *av) C_noret;
C_noret_decl(f_10749)
static void C_ccall f_10749(C_word c,C_word *av) C_noret;
C_noret_decl(f_10753)
static void C_ccall f_10753(C_word c,C_word *av) C_noret;
C_noret_decl(f_10755)
static void C_ccall f_10755(C_word c,C_word *av) C_noret;
C_noret_decl(f_10760)
static void C_ccall f_10760(C_word c,C_word *av) C_noret;
C_noret_decl(f_10769)
static void C_ccall f_10769(C_word c,C_word *av) C_noret;
C_noret_decl(f_10781)
static void C_ccall f_10781(C_word c,C_word *av) C_noret;
C_noret_decl(f_10795)
static void C_ccall f_10795(C_word c,C_word *av) C_noret;
C_noret_decl(f_10811)
static void C_ccall f_10811(C_word c,C_word *av) C_noret;
C_noret_decl(f_10814)
static void C_ccall f_10814(C_word c,C_word *av) C_noret;
C_noret_decl(f_10822)
static void C_ccall f_10822(C_word c,C_word *av) C_noret;
C_noret_decl(f_10826)
static void C_ccall f_10826(C_word c,C_word *av) C_noret;
C_noret_decl(f_10828)
static void C_ccall f_10828(C_word c,C_word *av) C_noret;
C_noret_decl(f_10832)
static void C_ccall f_10832(C_word c,C_word *av) C_noret;
C_noret_decl(f_10835)
static void C_ccall f_10835(C_word c,C_word *av) C_noret;
C_noret_decl(f_10846)
static void C_ccall f_10846(C_word c,C_word *av) C_noret;
C_noret_decl(f_10848)
static void C_ccall f_10848(C_word c,C_word *av) C_noret;
C_noret_decl(f_10855)
static void C_ccall f_10855(C_word c,C_word *av) C_noret;
C_noret_decl(f_10858)
static void C_ccall f_10858(C_word c,C_word *av) C_noret;
C_noret_decl(f_10861)
static void C_ccall f_10861(C_word c,C_word *av) C_noret;
C_noret_decl(f_10866)
static void C_ccall f_10866(C_word c,C_word *av) C_noret;
C_noret_decl(f_10870)
static void C_ccall f_10870(C_word c,C_word *av) C_noret;
C_noret_decl(f_10875)
static void C_ccall f_10875(C_word c,C_word *av) C_noret;
C_noret_decl(f_10879)
static void C_ccall f_10879(C_word c,C_word *av) C_noret;
C_noret_decl(f_10882)
static void C_ccall f_10882(C_word c,C_word *av) C_noret;
C_noret_decl(f_10910)
static void C_ccall f_10910(C_word c,C_word *av) C_noret;
C_noret_decl(f_10913)
static void C_ccall f_10913(C_word c,C_word *av) C_noret;
C_noret_decl(f_10916)
static void C_ccall f_10916(C_word c,C_word *av) C_noret;
C_noret_decl(f_10919)
static void C_ccall f_10919(C_word c,C_word *av) C_noret;
C_noret_decl(f_10936)
static void C_ccall f_10936(C_word c,C_word *av) C_noret;
C_noret_decl(f_10947)
static void C_ccall f_10947(C_word c,C_word *av) C_noret;
C_noret_decl(f_10959)
static void C_ccall f_10959(C_word c,C_word *av) C_noret;
C_noret_decl(f_10970)
static void C_ccall f_10970(C_word c,C_word *av) C_noret;
C_noret_decl(f_10981)
static void C_ccall f_10981(C_word c,C_word *av) C_noret;
C_noret_decl(f_10992)
static void C_ccall f_10992(C_word c,C_word *av) C_noret;
C_noret_decl(f_11003)
static void C_ccall f_11003(C_word c,C_word *av) C_noret;
C_noret_decl(f_11014)
static void C_ccall f_11014(C_word c,C_word *av) C_noret;
C_noret_decl(f_11025)
static void C_ccall f_11025(C_word c,C_word *av) C_noret;
C_noret_decl(f_11036)
static void C_ccall f_11036(C_word c,C_word *av) C_noret;
C_noret_decl(f_11047)
static void C_ccall f_11047(C_word c,C_word *av) C_noret;
C_noret_decl(f_11058)
static void C_ccall f_11058(C_word c,C_word *av) C_noret;
C_noret_decl(f_11069)
static void C_ccall f_11069(C_word c,C_word *av) C_noret;
C_noret_decl(f_11080)
static void C_ccall f_11080(C_word c,C_word *av) C_noret;
C_noret_decl(f_11091)
static void C_ccall f_11091(C_word c,C_word *av) C_noret;
C_noret_decl(f_11102)
static void C_ccall f_11102(C_word c,C_word *av) C_noret;
C_noret_decl(f_11119)
static void C_ccall f_11119(C_word c,C_word *av) C_noret;
C_noret_decl(f_11136)
static void C_ccall f_11136(C_word c,C_word *av) C_noret;
C_noret_decl(f_11160)
static void C_ccall f_11160(C_word c,C_word *av) C_noret;
C_noret_decl(f_11177)
static void C_ccall f_11177(C_word c,C_word *av) C_noret;
C_noret_decl(f_11181)
static void C_ccall f_11181(C_word c,C_word *av) C_noret;
C_noret_decl(f_11207)
static void C_ccall f_11207(C_word c,C_word *av) C_noret;
C_noret_decl(f_11227)
static void C_ccall f_11227(C_word c,C_word *av) C_noret;
C_noret_decl(f_11238)
static void C_ccall f_11238(C_word c,C_word *av) C_noret;
C_noret_decl(f_11250)
static void C_fcall f_11250(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11284)
static void C_ccall f_11284(C_word c,C_word *av) C_noret;
C_noret_decl(f_11299)
static void C_fcall f_11299(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11366)
static void C_ccall f_11366(C_word c,C_word *av) C_noret;
C_noret_decl(f_11382)
static void C_ccall f_11382(C_word c,C_word *av) C_noret;
C_noret_decl(f_11398)
static void C_ccall f_11398(C_word c,C_word *av) C_noret;
C_noret_decl(f_11414)
static void C_ccall f_11414(C_word c,C_word *av) C_noret;
C_noret_decl(f_11430)
static void C_ccall f_11430(C_word c,C_word *av) C_noret;
C_noret_decl(f_11446)
static void C_ccall f_11446(C_word c,C_word *av) C_noret;
C_noret_decl(f_11462)
static void C_ccall f_11462(C_word c,C_word *av) C_noret;
C_noret_decl(f_11478)
static void C_ccall f_11478(C_word c,C_word *av) C_noret;
C_noret_decl(f_11494)
static void C_ccall f_11494(C_word c,C_word *av) C_noret;
C_noret_decl(f_11506)
static void C_fcall f_11506(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11525)
static void C_fcall f_11525(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11556)
static void C_ccall f_11556(C_word c,C_word *av) C_noret;
C_noret_decl(f_11573)
static void C_ccall f_11573(C_word c,C_word *av) C_noret;
C_noret_decl(f_11579)
static void C_fcall f_11579(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11603)
static void C_ccall f_11603(C_word c,C_word *av) C_noret;
C_noret_decl(f_11623)
static void C_ccall f_11623(C_word c,C_word *av) C_noret;
C_noret_decl(f_11627)
static void C_ccall f_11627(C_word c,C_word *av) C_noret;
C_noret_decl(f_11630)
static void C_ccall f_11630(C_word c,C_word *av) C_noret;
C_noret_decl(f_11659)
static void C_ccall f_11659(C_word c,C_word *av) C_noret;
C_noret_decl(f_11675)
static void C_fcall f_11675(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_11697)
static void C_ccall f_11697(C_word c,C_word *av) C_noret;
C_noret_decl(f_11713)
static void C_ccall f_11713(C_word c,C_word *av) C_noret;
C_noret_decl(f_11718)
static C_word C_fcall f_11718(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_11749)
static void C_ccall f_11749(C_word c,C_word *av) C_noret;
C_noret_decl(f_11760)
static void C_ccall f_11760(C_word c,C_word *av) C_noret;
C_noret_decl(f_11769)
static C_word C_fcall f_11769(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_11798)
static void C_ccall f_11798(C_word c,C_word *av) C_noret;
C_noret_decl(f_11811)
static void C_ccall f_11811(C_word c,C_word *av) C_noret;
C_noret_decl(f_11821)
static void C_ccall f_11821(C_word c,C_word *av) C_noret;
C_noret_decl(f_11823)
static void C_ccall f_11823(C_word c,C_word *av) C_noret;
C_noret_decl(f_11830)
static void C_ccall f_11830(C_word c,C_word *av) C_noret;
C_noret_decl(f_11833)
static void C_fcall f_11833(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11842)
static void C_fcall f_11842(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11868)
static void C_ccall f_11868(C_word c,C_word *av) C_noret;
C_noret_decl(f_11873)
static void C_ccall f_11873(C_word c,C_word *av) C_noret;
C_noret_decl(f_11877)
static void C_ccall f_11877(C_word c,C_word *av) C_noret;
C_noret_decl(f_11882)
static void C_ccall f_11882(C_word c,C_word *av) C_noret;
C_noret_decl(f_11903)
static void C_ccall f_11903(C_word c,C_word *av) C_noret;
C_noret_decl(f_11909)
static void C_ccall f_11909(C_word c,C_word *av) C_noret;
C_noret_decl(f_11927)
static void C_ccall f_11927(C_word c,C_word *av) C_noret;
C_noret_decl(f_11933)
static void C_ccall f_11933(C_word c,C_word *av) C_noret;
C_noret_decl(f_11951)
static void C_ccall f_11951(C_word c,C_word *av) C_noret;
C_noret_decl(f_11957)
static void C_ccall f_11957(C_word c,C_word *av) C_noret;
C_noret_decl(f_11972)
static void C_ccall f_11972(C_word c,C_word *av) C_noret;
C_noret_decl(f_11978)
static void C_ccall f_11978(C_word c,C_word *av) C_noret;
C_noret_decl(f_11992)
static void C_ccall f_11992(C_word c,C_word *av) C_noret;
C_noret_decl(f_12013)
static void C_ccall f_12013(C_word c,C_word *av) C_noret;
C_noret_decl(f_12019)
static void C_ccall f_12019(C_word c,C_word *av) C_noret;
C_noret_decl(f_12037)
static void C_ccall f_12037(C_word c,C_word *av) C_noret;
C_noret_decl(f_12043)
static void C_ccall f_12043(C_word c,C_word *av) C_noret;
C_noret_decl(f_12061)
static void C_ccall f_12061(C_word c,C_word *av) C_noret;
C_noret_decl(f_12067)
static void C_ccall f_12067(C_word c,C_word *av) C_noret;
C_noret_decl(f_12082)
static void C_ccall f_12082(C_word c,C_word *av) C_noret;
C_noret_decl(f_12088)
static void C_ccall f_12088(C_word c,C_word *av) C_noret;
C_noret_decl(f_12103)
static void C_ccall f_12103(C_word c,C_word *av) C_noret;
C_noret_decl(f_12113)
static void C_ccall f_12113(C_word c,C_word *av) C_noret;
C_noret_decl(f_12119)
static void C_ccall f_12119(C_word c,C_word *av) C_noret;
C_noret_decl(f_12123)
static void C_ccall f_12123(C_word c,C_word *av) C_noret;
C_noret_decl(f_12125)
static void C_fcall f_12125(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12136)
static void C_ccall f_12136(C_word c,C_word *av) C_noret;
C_noret_decl(f_12148)
static void C_ccall f_12148(C_word c,C_word *av) C_noret;
C_noret_decl(f_12158)
static void C_ccall f_12158(C_word c,C_word *av) C_noret;
C_noret_decl(f_12164)
static void C_ccall f_12164(C_word c,C_word *av) C_noret;
C_noret_decl(f_12168)
static void C_ccall f_12168(C_word c,C_word *av) C_noret;
C_noret_decl(f_12173)
static C_word C_fcall f_12173(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_12199)
static void C_ccall f_12199(C_word c,C_word *av) C_noret;
C_noret_decl(f_12203)
static void C_ccall f_12203(C_word c,C_word *av) C_noret;
C_noret_decl(f_12206)
static void C_ccall f_12206(C_word c,C_word *av) C_noret;
C_noret_decl(f_12214)
static void C_fcall f_12214(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_12235)
static void C_fcall f_12235(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_12249)
static void C_ccall f_12249(C_word c,C_word *av) C_noret;
C_noret_decl(f_12253)
static void C_ccall f_12253(C_word c,C_word *av) C_noret;
C_noret_decl(f_12294)
static void C_ccall f_12294(C_word c,C_word *av) C_noret;
C_noret_decl(f_12316)
static void C_ccall f_12316(C_word c,C_word *av) C_noret;
C_noret_decl(f_12318)
static void C_ccall f_12318(C_word c,C_word *av) C_noret;
C_noret_decl(f_12340)
static void C_ccall f_12340(C_word c,C_word *av) C_noret;
C_noret_decl(f_12342)
static void C_ccall f_12342(C_word c,C_word *av) C_noret;
C_noret_decl(f_12364)
static void C_ccall f_12364(C_word c,C_word *av) C_noret;
C_noret_decl(f_12366)
static void C_ccall f_12366(C_word c,C_word *av) C_noret;
C_noret_decl(f_12388)
static void C_ccall f_12388(C_word c,C_word *av) C_noret;
C_noret_decl(f_12390)
static void C_ccall f_12390(C_word c,C_word *av) C_noret;
C_noret_decl(f_12394)
static void C_ccall f_12394(C_word c,C_word *av) C_noret;
C_noret_decl(f_12397)
static void C_fcall f_12397(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12415)
static void C_ccall f_12415(C_word c,C_word *av) C_noret;
C_noret_decl(f_12437)
static void C_ccall f_12437(C_word c,C_word *av) C_noret;
C_noret_decl(f_12439)
static void C_ccall f_12439(C_word c,C_word *av) C_noret;
C_noret_decl(f_12461)
static void C_ccall f_12461(C_word c,C_word *av) C_noret;
C_noret_decl(f_12463)
static void C_ccall f_12463(C_word c,C_word *av) C_noret;
C_noret_decl(f_12485)
static void C_ccall f_12485(C_word c,C_word *av) C_noret;
C_noret_decl(f_12487)
static void C_ccall f_12487(C_word c,C_word *av) C_noret;
C_noret_decl(f_12509)
static void C_ccall f_12509(C_word c,C_word *av) C_noret;
C_noret_decl(f_12511)
static void C_ccall f_12511(C_word c,C_word *av) C_noret;
C_noret_decl(f_12533)
static void C_ccall f_12533(C_word c,C_word *av) C_noret;
C_noret_decl(f_12535)
static void C_ccall f_12535(C_word c,C_word *av) C_noret;
C_noret_decl(f_12557)
static void C_ccall f_12557(C_word c,C_word *av) C_noret;
C_noret_decl(f_12559)
static void C_ccall f_12559(C_word c,C_word *av) C_noret;
C_noret_decl(f_12581)
static void C_ccall f_12581(C_word c,C_word *av) C_noret;
C_noret_decl(f_12583)
static void C_ccall f_12583(C_word c,C_word *av) C_noret;
C_noret_decl(f_12599)
static void C_ccall f_12599(C_word c,C_word *av) C_noret;
C_noret_decl(f_12601)
static void C_ccall f_12601(C_word c,C_word *av) C_noret;
C_noret_decl(f_12623)
static void C_ccall f_12623(C_word c,C_word *av) C_noret;
C_noret_decl(f_12625)
static void C_ccall f_12625(C_word c,C_word *av) C_noret;
C_noret_decl(f_12647)
static void C_ccall f_12647(C_word c,C_word *av) C_noret;
C_noret_decl(f_12649)
static void C_ccall f_12649(C_word c,C_word *av) C_noret;
C_noret_decl(f_12665)
static void C_ccall f_12665(C_word c,C_word *av) C_noret;
C_noret_decl(f_12667)
static void C_ccall f_12667(C_word c,C_word *av) C_noret;
C_noret_decl(f_12683)
static void C_ccall f_12683(C_word c,C_word *av) C_noret;
C_noret_decl(f_12685)
static void C_ccall f_12685(C_word c,C_word *av) C_noret;
C_noret_decl(f_12701)
static void C_ccall f_12701(C_word c,C_word *av) C_noret;
C_noret_decl(f_12703)
static void C_ccall f_12703(C_word c,C_word *av) C_noret;
C_noret_decl(f_12719)
static void C_ccall f_12719(C_word c,C_word *av) C_noret;
C_noret_decl(f_12721)
static void C_ccall f_12721(C_word c,C_word *av) C_noret;
C_noret_decl(f_12737)
static void C_ccall f_12737(C_word c,C_word *av) C_noret;
C_noret_decl(f_12739)
static void C_ccall f_12739(C_word c,C_word *av) C_noret;
C_noret_decl(f_12755)
static void C_ccall f_12755(C_word c,C_word *av) C_noret;
C_noret_decl(f_12757)
static void C_ccall f_12757(C_word c,C_word *av) C_noret;
C_noret_decl(f_12773)
static void C_ccall f_12773(C_word c,C_word *av) C_noret;
C_noret_decl(f_12775)
static void C_ccall f_12775(C_word c,C_word *av) C_noret;
C_noret_decl(f_12791)
static void C_ccall f_12791(C_word c,C_word *av) C_noret;
C_noret_decl(f_12793)
static void C_ccall f_12793(C_word c,C_word *av) C_noret;
C_noret_decl(f_12809)
static void C_ccall f_12809(C_word c,C_word *av) C_noret;
C_noret_decl(f_12811)
static void C_ccall f_12811(C_word c,C_word *av) C_noret;
C_noret_decl(f_12827)
static void C_ccall f_12827(C_word c,C_word *av) C_noret;
C_noret_decl(f_12829)
static void C_ccall f_12829(C_word c,C_word *av) C_noret;
C_noret_decl(f_12851)
static void C_ccall f_12851(C_word c,C_word *av) C_noret;
C_noret_decl(f_12853)
static void C_ccall f_12853(C_word c,C_word *av) C_noret;
C_noret_decl(f_12869)
static void C_ccall f_12869(C_word c,C_word *av) C_noret;
C_noret_decl(f_12871)
static void C_ccall f_12871(C_word c,C_word *av) C_noret;
C_noret_decl(f_12887)
static void C_ccall f_12887(C_word c,C_word *av) C_noret;
C_noret_decl(f_12889)
static void C_ccall f_12889(C_word c,C_word *av) C_noret;
C_noret_decl(f_12905)
static void C_ccall f_12905(C_word c,C_word *av) C_noret;
C_noret_decl(f_12907)
static void C_ccall f_12907(C_word c,C_word *av) C_noret;
C_noret_decl(f_12923)
static void C_ccall f_12923(C_word c,C_word *av) C_noret;
C_noret_decl(f_12925)
static void C_ccall f_12925(C_word c,C_word *av) C_noret;
C_noret_decl(f_12941)
static void C_ccall f_12941(C_word c,C_word *av) C_noret;
C_noret_decl(f_12943)
static void C_ccall f_12943(C_word c,C_word *av) C_noret;
C_noret_decl(f_12959)
static void C_ccall f_12959(C_word c,C_word *av) C_noret;
C_noret_decl(f_12961)
static void C_ccall f_12961(C_word c,C_word *av) C_noret;
C_noret_decl(f_12977)
static void C_ccall f_12977(C_word c,C_word *av) C_noret;
C_noret_decl(f_12979)
static void C_ccall f_12979(C_word c,C_word *av) C_noret;
C_noret_decl(f_13001)
static void C_ccall f_13001(C_word c,C_word *av) C_noret;
C_noret_decl(f_13003)
static void C_ccall f_13003(C_word c,C_word *av) C_noret;
C_noret_decl(f_13019)
static void C_ccall f_13019(C_word c,C_word *av) C_noret;
C_noret_decl(f_13021)
static void C_ccall f_13021(C_word c,C_word *av) C_noret;
C_noret_decl(f_13037)
static void C_ccall f_13037(C_word c,C_word *av) C_noret;
C_noret_decl(f_13039)
static void C_ccall f_13039(C_word c,C_word *av) C_noret;
C_noret_decl(f_13055)
static void C_ccall f_13055(C_word c,C_word *av) C_noret;
C_noret_decl(f_13057)
static void C_ccall f_13057(C_word c,C_word *av) C_noret;
C_noret_decl(f_13073)
static void C_ccall f_13073(C_word c,C_word *av) C_noret;
C_noret_decl(f_13075)
static void C_ccall f_13075(C_word c,C_word *av) C_noret;
C_noret_decl(f_13085)
static void C_ccall f_13085(C_word c,C_word *av) C_noret;
C_noret_decl(f_13097)
static void C_fcall f_13097(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13107)
static void C_ccall f_13107(C_word c,C_word *av) C_noret;
C_noret_decl(f_13111)
static void C_ccall f_13111(C_word c,C_word *av) C_noret;
C_noret_decl(f_13133)
static void C_ccall f_13133(C_word c,C_word *av) C_noret;
C_noret_decl(f_13137)
static void C_ccall f_13137(C_word c,C_word *av) C_noret;
C_noret_decl(f_13140)
static void C_ccall f_13140(C_word c,C_word *av) C_noret;
C_noret_decl(f_13145)
static void C_ccall f_13145(C_word c,C_word *av) C_noret;
C_noret_decl(f_13149)
static void C_ccall f_13149(C_word c,C_word *av) C_noret;
C_noret_decl(f_13152)
static void C_ccall f_13152(C_word c,C_word *av) C_noret;
C_noret_decl(f_13155)
static void C_ccall f_13155(C_word c,C_word *av) C_noret;
C_noret_decl(f_13168)
static void C_ccall f_13168(C_word c,C_word *av) C_noret;
C_noret_decl(f_13191)
static void C_ccall f_13191(C_word c,C_word *av) C_noret;
C_noret_decl(f_13217)
static void C_ccall f_13217(C_word c,C_word *av) C_noret;
C_noret_decl(f_13226)
static void C_ccall f_13226(C_word c,C_word *av) C_noret;
C_noret_decl(f_13231)
static void C_ccall f_13231(C_word c,C_word *av) C_noret;
C_noret_decl(f_13233)
static void C_ccall f_13233(C_word c,C_word *av) C_noret;
C_noret_decl(f_13277)
static C_word C_fcall f_13277(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_13323)
static void C_ccall f_13323(C_word c,C_word *av) C_noret;
C_noret_decl(f_13347)
static void C_ccall f_13347(C_word c,C_word *av) C_noret;
C_noret_decl(f_13351)
static void C_ccall f_13351(C_word c,C_word *av) C_noret;
C_noret_decl(f_13369)
static void C_ccall f_13369(C_word c,C_word *av) C_noret;
C_noret_decl(f_13393)
static void C_ccall f_13393(C_word c,C_word *av) C_noret;
C_noret_decl(f_13397)
static void C_ccall f_13397(C_word c,C_word *av) C_noret;
C_noret_decl(f_13415)
static void C_ccall f_13415(C_word c,C_word *av) C_noret;
C_noret_decl(f_13456)
static void C_fcall f_13456(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13467)
static void C_ccall f_13467(C_word c,C_word *av) C_noret;
C_noret_decl(f_13473)
static void C_fcall f_13473(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13477)
static void C_ccall f_13477(C_word c,C_word *av) C_noret;
C_noret_decl(f_13491)
static void C_ccall f_13491(C_word c,C_word *av) C_noret;
C_noret_decl(f_13504)
static void C_ccall f_13504(C_word c,C_word *av) C_noret;
C_noret_decl(f_13508)
static void C_ccall f_13508(C_word c,C_word *av) C_noret;
C_noret_decl(f_13525)
static void C_ccall f_13525(C_word c,C_word *av) C_noret;
C_noret_decl(f_13529)
static void C_ccall f_13529(C_word c,C_word *av) C_noret;
C_noret_decl(f_13535)
static void C_ccall f_13535(C_word c,C_word *av) C_noret;
C_noret_decl(f_13539)
static void C_ccall f_13539(C_word c,C_word *av) C_noret;
C_noret_decl(f_13579)
static void C_ccall f_13579(C_word c,C_word *av) C_noret;
C_noret_decl(f_13583)
static void C_ccall f_13583(C_word c,C_word *av) C_noret;
C_noret_decl(f_13605)
static void C_ccall f_13605(C_word c,C_word *av) C_noret;
C_noret_decl(f_13608)
static void C_ccall f_13608(C_word c,C_word *av) C_noret;
C_noret_decl(f_13611)
static void C_ccall f_13611(C_word c,C_word *av) C_noret;
C_noret_decl(f_13614)
static void C_ccall f_13614(C_word c,C_word *av) C_noret;
C_noret_decl(f_13617)
static void C_ccall f_13617(C_word c,C_word *av) C_noret;
C_noret_decl(f_13638)
static void C_ccall f_13638(C_word c,C_word *av) C_noret;
C_noret_decl(f_13640)
static void C_fcall f_13640(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13658)
static void C_ccall f_13658(C_word c,C_word *av) C_noret;
C_noret_decl(f_13668)
static void C_ccall f_13668(C_word c,C_word *av) C_noret;
C_noret_decl(f_13672)
static void C_ccall f_13672(C_word c,C_word *av) C_noret;
C_noret_decl(f_13710)
static void C_ccall f_13710(C_word c,C_word *av) C_noret;
C_noret_decl(f_13713)
static void C_ccall f_13713(C_word c,C_word *av) C_noret;
C_noret_decl(f_13716)
static void C_ccall f_13716(C_word c,C_word *av) C_noret;
C_noret_decl(f_13719)
static void C_ccall f_13719(C_word c,C_word *av) C_noret;
C_noret_decl(f_13725)
static void C_ccall f_13725(C_word c,C_word *av) C_noret;
C_noret_decl(f_13728)
static void C_ccall f_13728(C_word c,C_word *av) C_noret;
C_noret_decl(f_13776)
static void C_ccall f_13776(C_word c,C_word *av) C_noret;
C_noret_decl(f_13780)
static void C_ccall f_13780(C_word c,C_word *av) C_noret;
C_noret_decl(f_13857)
static void C_ccall f_13857(C_word c,C_word *av) C_noret;
C_noret_decl(f_13896)
static void C_ccall f_13896(C_word c,C_word *av) C_noret;
C_noret_decl(f_13951)
static void C_ccall f_13951(C_word c,C_word *av) C_noret;
C_noret_decl(f_13996)
static void C_ccall f_13996(C_word c,C_word *av) C_noret;
C_noret_decl(f_14041)
static void C_ccall f_14041(C_word c,C_word *av) C_noret;
C_noret_decl(f_14078)
static void C_ccall f_14078(C_word c,C_word *av) C_noret;
C_noret_decl(f_14098)
static void C_ccall f_14098(C_word c,C_word *av) C_noret;
C_noret_decl(f_14122)
static void C_fcall f_14122(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14125)
static void C_fcall f_14125(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_14129)
static void C_ccall f_14129(C_word c,C_word *av) C_noret;
C_noret_decl(f_14132)
static void C_ccall f_14132(C_word c,C_word *av) C_noret;
C_noret_decl(f_14150)
static void C_ccall f_14150(C_word c,C_word *av) C_noret;
C_noret_decl(f_14173)
static void C_ccall f_14173(C_word c,C_word *av) C_noret;
C_noret_decl(f_14177)
static void C_ccall f_14177(C_word c,C_word *av) C_noret;
C_noret_decl(f_14200)
static void C_ccall f_14200(C_word c,C_word *av) C_noret;
C_noret_decl(f_14204)
static void C_ccall f_14204(C_word c,C_word *av) C_noret;
C_noret_decl(f_14236)
static void C_ccall f_14236(C_word c,C_word *av) C_noret;
C_noret_decl(f_14272)
static void C_ccall f_14272(C_word c,C_word *av) C_noret;
C_noret_decl(f_14276)
static void C_ccall f_14276(C_word c,C_word *av) C_noret;
C_noret_decl(f_14295)
static void C_ccall f_14295(C_word c,C_word *av) C_noret;
C_noret_decl(f_14297)
static void C_ccall f_14297(C_word c,C_word *av) C_noret;
C_noret_decl(f_14304)
static void C_fcall f_14304(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_14341)
static void C_ccall f_14341(C_word c,C_word *av) C_noret;
C_noret_decl(f_14348)
static void C_fcall f_14348(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_14385)
static void C_ccall f_14385(C_word c,C_word *av) C_noret;
C_noret_decl(f_14403)
static void C_ccall f_14403(C_word c,C_word *av) C_noret;
C_noret_decl(f_14412)
static void C_ccall f_14412(C_word c,C_word *av) C_noret;
C_noret_decl(f_14417)
static void C_ccall f_14417(C_word c,C_word *av) C_noret;
C_noret_decl(f_14430)
static void C_ccall f_14430(C_word c,C_word *av) C_noret;
C_noret_decl(f_14456)
static void C_ccall f_14456(C_word c,C_word *av) C_noret;
C_noret_decl(f_14464)
static void C_ccall f_14464(C_word c,C_word *av) C_noret;
C_noret_decl(f_14468)
static void C_ccall f_14468(C_word c,C_word *av) C_noret;
C_noret_decl(f_14472)
static void C_ccall f_14472(C_word c,C_word *av) C_noret;
C_noret_decl(f_14476)
static void C_ccall f_14476(C_word c,C_word *av) C_noret;
C_noret_decl(f_14479)
static void C_ccall f_14479(C_word c,C_word *av) C_noret;
C_noret_decl(f_14493)
static void C_ccall f_14493(C_word c,C_word *av) C_noret;
C_noret_decl(f_14497)
static void C_ccall f_14497(C_word c,C_word *av) C_noret;
C_noret_decl(f_14508)
static void C_ccall f_14508(C_word c,C_word *av) C_noret;
C_noret_decl(f_14532)
static void C_ccall f_14532(C_word c,C_word *av) C_noret;
C_noret_decl(f_14536)
static void C_ccall f_14536(C_word c,C_word *av) C_noret;
C_noret_decl(f_14542)
static void C_ccall f_14542(C_word c,C_word *av) C_noret;
C_noret_decl(f_14566)
static void C_ccall f_14566(C_word c,C_word *av) C_noret;
C_noret_decl(f_14570)
static void C_ccall f_14570(C_word c,C_word *av) C_noret;
C_noret_decl(f_14576)
static void C_ccall f_14576(C_word c,C_word *av) C_noret;
C_noret_decl(f_14593)
static void C_ccall f_14593(C_word c,C_word *av) C_noret;
C_noret_decl(f_14597)
static void C_ccall f_14597(C_word c,C_word *av) C_noret;
C_noret_decl(f_14601)
static void C_ccall f_14601(C_word c,C_word *av) C_noret;
C_noret_decl(f_14611)
static void C_fcall f_14611(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14617)
static void C_fcall f_14617(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14624)
static void C_ccall f_14624(C_word c,C_word *av) C_noret;
C_noret_decl(f_14636)
static void C_ccall f_14636(C_word c,C_word *av) C_noret;
C_noret_decl(f_14659)
static void C_ccall f_14659(C_word c,C_word *av) C_noret;
C_noret_decl(f_14663)
static void C_ccall f_14663(C_word c,C_word *av) C_noret;
C_noret_decl(f_14673)
static void C_fcall f_14673(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14679)
static void C_fcall f_14679(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14686)
static void C_ccall f_14686(C_word c,C_word *av) C_noret;
C_noret_decl(f_14701)
static void C_ccall f_14701(C_word c,C_word *av) C_noret;
C_noret_decl(f_14705)
static void C_ccall f_14705(C_word c,C_word *av) C_noret;
C_noret_decl(f_14738)
static void C_ccall f_14738(C_word c,C_word *av) C_noret;
C_noret_decl(f_14742)
static void C_ccall f_14742(C_word c,C_word *av) C_noret;
C_noret_decl(f_14759)
static void C_ccall f_14759(C_word c,C_word *av) C_noret;
C_noret_decl(f_14769)
static void C_ccall f_14769(C_word c,C_word *av) C_noret;
C_noret_decl(f_14842)
static void C_ccall f_14842(C_word c,C_word *av) C_noret;
C_noret_decl(f_14856)
static void C_ccall f_14856(C_word c,C_word *av) C_noret;
C_noret_decl(f_14873)
static void C_ccall f_14873(C_word c,C_word *av) C_noret;
C_noret_decl(f_14889)
static void C_ccall f_14889(C_word c,C_word *av) C_noret;
C_noret_decl(f_14960)
static void C_ccall f_14960(C_word c,C_word *av) C_noret;
C_noret_decl(f_14964)
static void C_ccall f_14964(C_word c,C_word *av) C_noret;
C_noret_decl(f_14969)
static void C_ccall f_14969(C_word c,C_word *av) C_noret;
C_noret_decl(f_14979)
static void C_ccall f_14979(C_word c,C_word *av) C_noret;
C_noret_decl(f_14983)
static void C_ccall f_14983(C_word c,C_word *av) C_noret;
C_noret_decl(f_14998)
static void C_ccall f_14998(C_word c,C_word *av) C_noret;
C_noret_decl(f_15002)
static void C_ccall f_15002(C_word c,C_word *av) C_noret;
C_noret_decl(f_15019)
static void C_ccall f_15019(C_word c,C_word *av) C_noret;
C_noret_decl(f_15030)
static void C_ccall f_15030(C_word c,C_word *av) C_noret;
C_noret_decl(f_15036)
static void C_ccall f_15036(C_word c,C_word *av) C_noret;
C_noret_decl(f_15047)
static void C_ccall f_15047(C_word c,C_word *av) C_noret;
C_noret_decl(f_15058)
static void C_ccall f_15058(C_word c,C_word *av) C_noret;
C_noret_decl(f_15070)
static void C_ccall f_15070(C_word c,C_word *av) C_noret;
C_noret_decl(f_15082)
static void C_ccall f_15082(C_word c,C_word *av) C_noret;
C_noret_decl(f_15094)
static void C_ccall f_15094(C_word c,C_word *av) C_noret;
C_noret_decl(f_15111)
static void C_ccall f_15111(C_word c,C_word *av) C_noret;
C_noret_decl(f_15118)
static void C_ccall f_15118(C_word c,C_word *av) C_noret;
C_noret_decl(f_15122)
static void C_ccall f_15122(C_word c,C_word *av) C_noret;
C_noret_decl(f_15124)
static void C_ccall f_15124(C_word c,C_word *av) C_noret;
C_noret_decl(f_15130)
static void C_ccall f_15130(C_word c,C_word *av) C_noret;
C_noret_decl(f_15134)
static void C_ccall f_15134(C_word c,C_word *av) C_noret;
C_noret_decl(f_15137)
static void C_ccall f_15137(C_word c,C_word *av) C_noret;
C_noret_decl(f_15142)
static void C_ccall f_15142(C_word c,C_word *av) C_noret;
C_noret_decl(f_15152)
static void C_fcall f_15152(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15172)
static void C_ccall f_15172(C_word c,C_word *av) C_noret;
C_noret_decl(f_15187)
static void C_fcall f_15187(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15217)
static void C_ccall f_15217(C_word c,C_word *av) C_noret;
C_noret_decl(f_15228)
static void C_ccall f_15228(C_word c,C_word *av) C_noret;
C_noret_decl(f_15244)
static void C_ccall f_15244(C_word c,C_word *av) C_noret;
C_noret_decl(f_15248)
static void C_ccall f_15248(C_word c,C_word *av) C_noret;
C_noret_decl(f_15252)
static void C_ccall f_15252(C_word c,C_word *av) C_noret;
C_noret_decl(f_15268)
static void C_ccall f_15268(C_word c,C_word *av) C_noret;
C_noret_decl(f_15286)
static void C_ccall f_15286(C_word c,C_word *av) C_noret;
C_noret_decl(f_15297)
static void C_fcall f_15297(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15319)
static void C_ccall f_15319(C_word c,C_word *av) C_noret;
C_noret_decl(f_15336)
static void C_ccall f_15336(C_word c,C_word *av) C_noret;
C_noret_decl(f_15339)
static void C_fcall f_15339(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15351)
static void C_ccall f_15351(C_word c,C_word *av) C_noret;
C_noret_decl(f_15353)
static void C_fcall f_15353(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15374)
static void C_ccall f_15374(C_word c,C_word *av) C_noret;
C_noret_decl(f_15405)
static void C_ccall f_15405(C_word c,C_word *av) C_noret;
C_noret_decl(f_15409)
static void C_ccall f_15409(C_word c,C_word *av) C_noret;
C_noret_decl(f_15444)
static void C_ccall f_15444(C_word c,C_word *av) C_noret;
C_noret_decl(f_15451)
static void C_ccall f_15451(C_word c,C_word *av) C_noret;
C_noret_decl(f_15463)
static void C_ccall f_15463(C_word c,C_word *av) C_noret;
C_noret_decl(f_15483)
static void C_ccall f_15483(C_word c,C_word *av) C_noret;
C_noret_decl(f_15487)
static void C_ccall f_15487(C_word c,C_word *av) C_noret;
C_noret_decl(f_15507)
static void C_fcall f_15507(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15527)
static void C_ccall f_15527(C_word c,C_word *av) C_noret;
C_noret_decl(f_15531)
static void C_ccall f_15531(C_word c,C_word *av) C_noret;
C_noret_decl(f_15535)
static void C_ccall f_15535(C_word c,C_word *av) C_noret;
C_noret_decl(f_15542)
static void C_ccall f_15542(C_word c,C_word *av) C_noret;
C_noret_decl(f_15558)
static void C_ccall f_15558(C_word c,C_word *av) C_noret;
C_noret_decl(f_15562)
static void C_ccall f_15562(C_word c,C_word *av) C_noret;
C_noret_decl(f_15603)
static void C_fcall f_15603(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15636)
static void C_ccall f_15636(C_word c,C_word *av) C_noret;
C_noret_decl(f_15665)
static void C_ccall f_15665(C_word c,C_word *av) C_noret;
C_noret_decl(f_15673)
static void C_ccall f_15673(C_word c,C_word *av) C_noret;
C_noret_decl(f_15679)
static void C_ccall f_15679(C_word c,C_word *av) C_noret;
C_noret_decl(f_15699)
static void C_fcall f_15699(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15724)
static void C_ccall f_15724(C_word c,C_word *av) C_noret;
C_noret_decl(f_15730)
static void C_ccall f_15730(C_word c,C_word *av) C_noret;
C_noret_decl(f_15734)
static void C_ccall f_15734(C_word c,C_word *av) C_noret;
C_noret_decl(f_15744)
static void C_ccall f_15744(C_word c,C_word *av) C_noret;
C_noret_decl(f_15764)
static void C_fcall f_15764(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15785)
static void C_ccall f_15785(C_word c,C_word *av) C_noret;
C_noret_decl(f_15802)
static void C_ccall f_15802(C_word c,C_word *av) C_noret;
C_noret_decl(f_15809)
static void C_ccall f_15809(C_word c,C_word *av) C_noret;
C_noret_decl(f_15814)
static void C_ccall f_15814(C_word c,C_word *av) C_noret;
C_noret_decl(f_15820)
static void C_ccall f_15820(C_word c,C_word *av) C_noret;
C_noret_decl(f_15824)
static void C_ccall f_15824(C_word c,C_word *av) C_noret;
C_noret_decl(f_15827)
static void C_ccall f_15827(C_word c,C_word *av) C_noret;
C_noret_decl(f_15834)
static void C_ccall f_15834(C_word c,C_word *av) C_noret;
C_noret_decl(f_15855)
static void C_ccall f_15855(C_word c,C_word *av) C_noret;
C_noret_decl(f_15869)
static void C_ccall f_15869(C_word c,C_word *av) C_noret;
C_noret_decl(f_15873)
static void C_ccall f_15873(C_word c,C_word *av) C_noret;
C_noret_decl(f_15910)
static void C_ccall f_15910(C_word c,C_word *av) C_noret;
C_noret_decl(f_15918)
static void C_ccall f_15918(C_word c,C_word *av) C_noret;
C_noret_decl(f_15947)
static void C_ccall f_15947(C_word c,C_word *av) C_noret;
C_noret_decl(f_15950)
static void C_ccall f_15950(C_word c,C_word *av) C_noret;
C_noret_decl(f_15965)
static void C_ccall f_15965(C_word c,C_word *av) C_noret;
C_noret_decl(f_15968)
static void C_fcall f_15968(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15975)
static void C_ccall f_15975(C_word c,C_word *av) C_noret;
C_noret_decl(f_15986)
static void C_ccall f_15986(C_word c,C_word *av) C_noret;
C_noret_decl(f_16004)
static void C_ccall f_16004(C_word c,C_word *av) C_noret;
C_noret_decl(f_16029)
static void C_fcall f_16029(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16044)
static void C_ccall f_16044(C_word c,C_word *av) C_noret;
C_noret_decl(f_16072)
static void C_fcall f_16072(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_16076)
static C_word C_fcall f_16076(C_word t0,C_word t1);
C_noret_decl(f_16090)
static void C_fcall f_16090(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_16150)
static void C_ccall f_16150(C_word c,C_word *av) C_noret;
C_noret_decl(f_16170)
static void C_fcall f_16170(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16176)
static void C_fcall f_16176(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16239)
static void C_fcall f_16239(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16278)
static void C_fcall f_16278(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16284)
static void C_fcall f_16284(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16328)
static void C_fcall f_16328(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_16332)
static void C_ccall f_16332(C_word c,C_word *av) C_noret;
C_noret_decl(f_16335)
static void C_ccall f_16335(C_word c,C_word *av) C_noret;
C_noret_decl(f_16384)
static void C_fcall f_16384(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16399)
static void C_fcall f_16399(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16408)
static void C_ccall f_16408(C_word c,C_word *av) C_noret;
C_noret_decl(f_16442)
static void C_fcall f_16442(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_16452)
static void C_ccall f_16452(C_word c,C_word *av) C_noret;
C_noret_decl(f_16461)
static void C_fcall f_16461(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16473)
static void C_fcall f_16473(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16482)
static void C_ccall f_16482(C_word c,C_word *av) C_noret;
C_noret_decl(f_16494)
static void C_ccall f_16494(C_word c,C_word *av) C_noret;
C_noret_decl(f_16500)
static void C_fcall f_16500(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16506)
static void C_ccall f_16506(C_word c,C_word *av) C_noret;
C_noret_decl(f_16548)
static void C_ccall f_16548(C_word c,C_word *av) C_noret;
C_noret_decl(f_16656)
static void C_fcall f_16656(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_16663)
static void C_fcall f_16663(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16676)
static void C_ccall f_16676(C_word c,C_word *av) C_noret;
C_noret_decl(f_16734)
static void C_fcall f_16734(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16752)
static void C_ccall f_16752(C_word c,C_word *av) C_noret;
C_noret_decl(f_16762)
static void C_ccall f_16762(C_word c,C_word *av) C_noret;
C_noret_decl(f_16798)
static void C_ccall f_16798(C_word c,C_word *av) C_noret;
C_noret_decl(f_16824)
static void C_ccall f_16824(C_word c,C_word *av) C_noret;
C_noret_decl(f_16835)
static void C_ccall f_16835(C_word c,C_word *av) C_noret;
C_noret_decl(f_17002)
static void C_fcall f_17002(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17017)
static void C_fcall f_17017(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17075)
static void C_fcall f_17075(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17116)
static void C_ccall f_17116(C_word c,C_word *av) C_noret;
C_noret_decl(f_17194)
static void C_ccall f_17194(C_word c,C_word *av) C_noret;
C_noret_decl(f_17242)
static void C_ccall f_17242(C_word c,C_word *av) C_noret;
C_noret_decl(f_17245)
static void C_ccall f_17245(C_word c,C_word *av) C_noret;
C_noret_decl(f_17257)
static void C_ccall f_17257(C_word c,C_word *av) C_noret;
C_noret_decl(f_17344)
static void C_ccall f_17344(C_word c,C_word *av) C_noret;
C_noret_decl(f_17412)
static void C_ccall f_17412(C_word c,C_word *av) C_noret;
C_noret_decl(f_17492)
static void C_ccall f_17492(C_word c,C_word *av) C_noret;
C_noret_decl(f_17502)
static void C_ccall f_17502(C_word c,C_word *av) C_noret;
C_noret_decl(f_17511)
static void C_fcall f_17511(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_17747)
static void C_ccall f_17747(C_word c,C_word *av) C_noret;
C_noret_decl(f_17793)
static void C_ccall f_17793(C_word c,C_word *av) C_noret;
C_noret_decl(f_17796)
static void C_fcall f_17796(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_17823)
static void C_fcall f_17823(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17847)
static void C_ccall f_17847(C_word c,C_word *av) C_noret;
C_noret_decl(f_17864)
static void C_fcall f_17864(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_17965)
static void C_ccall f_17965(C_word c,C_word *av) C_noret;
C_noret_decl(f_17968)
static void C_ccall f_17968(C_word c,C_word *av) C_noret;
C_noret_decl(f_17977)
static void C_ccall f_17977(C_word c,C_word *av) C_noret;
C_noret_decl(f_17983)
static void C_ccall f_17983(C_word c,C_word *av) C_noret;
C_noret_decl(f_17994)
static void C_ccall f_17994(C_word c,C_word *av) C_noret;
C_noret_decl(f_17996)
static void C_ccall f_17996(C_word c,C_word *av) C_noret;
C_noret_decl(f_18007)
static void C_ccall f_18007(C_word c,C_word *av) C_noret;
C_noret_decl(f_18009)
static void C_ccall f_18009(C_word c,C_word *av) C_noret;
C_noret_decl(f_18020)
static void C_ccall f_18020(C_word c,C_word *av) C_noret;
C_noret_decl(f_18022)
static void C_ccall f_18022(C_word c,C_word *av) C_noret;
C_noret_decl(f_18039)
static void C_ccall f_18039(C_word c,C_word *av) C_noret;
C_noret_decl(f_18043)
static void C_ccall f_18043(C_word c,C_word *av) C_noret;
C_noret_decl(f_18047)
static void C_ccall f_18047(C_word c,C_word *av) C_noret;
C_noret_decl(f_18056)
static void C_ccall f_18056(C_word c,C_word *av) C_noret;
C_noret_decl(f_18076)
static void C_ccall f_18076(C_word c,C_word *av) C_noret;
C_noret_decl(f_18084)
static void C_ccall f_18084(C_word c,C_word *av) C_noret;
C_noret_decl(f_18099)
static void C_ccall f_18099(C_word c,C_word *av) C_noret;
C_noret_decl(f_18101)
static void C_fcall f_18101(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18126)
static void C_ccall f_18126(C_word c,C_word *av) C_noret;
C_noret_decl(f_18135)
static void C_ccall f_18135(C_word c,C_word *av) C_noret;
C_noret_decl(f_18138)
static void C_ccall f_18138(C_word c,C_word *av) C_noret;
C_noret_decl(f_18147)
static void C_ccall f_18147(C_word c,C_word *av) C_noret;
C_noret_decl(f_18154)
static void C_ccall f_18154(C_word c,C_word *av) C_noret;
C_noret_decl(f_18165)
static void C_ccall f_18165(C_word c,C_word *av) C_noret;
C_noret_decl(f_18172)
static void C_ccall f_18172(C_word c,C_word *av) C_noret;
C_noret_decl(f_18196)
static void C_ccall f_18196(C_word c,C_word *av) C_noret;
C_noret_decl(f_18200)
static void C_ccall f_18200(C_word c,C_word *av) C_noret;
C_noret_decl(f_18202)
static void C_ccall f_18202(C_word c,C_word *av) C_noret;
C_noret_decl(f_18206)
static void C_ccall f_18206(C_word c,C_word *av) C_noret;
C_noret_decl(f_18211)
static void C_ccall f_18211(C_word c,C_word *av) C_noret;
C_noret_decl(f_18217)
static void C_ccall f_18217(C_word c,C_word *av) C_noret;
C_noret_decl(f_18221)
static void C_ccall f_18221(C_word c,C_word *av) C_noret;
C_noret_decl(f_18226)
static void C_ccall f_18226(C_word c,C_word *av) C_noret;
C_noret_decl(f_18236)
static void C_ccall f_18236(C_word c,C_word *av) C_noret;
C_noret_decl(f_18238)
static void C_ccall f_18238(C_word c,C_word *av) C_noret;
C_noret_decl(f_18242)
static void C_ccall f_18242(C_word c,C_word *av) C_noret;
C_noret_decl(f_18248)
static void C_ccall f_18248(C_word c,C_word *av) C_noret;
C_noret_decl(f_18250)
static void C_ccall f_18250(C_word c,C_word *av) C_noret;
C_noret_decl(f_18254)
static void C_ccall f_18254(C_word c,C_word *av) C_noret;
C_noret_decl(f_18257)
static void C_ccall f_18257(C_word c,C_word *av) C_noret;
C_noret_decl(f_18273)
static void C_ccall f_18273(C_word c,C_word *av) C_noret;
C_noret_decl(f_18277)
static void C_ccall f_18277(C_word c,C_word *av) C_noret;
C_noret_decl(f_18280)
static void C_ccall f_18280(C_word c,C_word *av) C_noret;
C_noret_decl(f_18302)
static void C_ccall f_18302(C_word c,C_word *av) C_noret;
C_noret_decl(f_18318)
static void C_ccall f_18318(C_word c,C_word *av) C_noret;
C_noret_decl(f_18323)
static C_word C_fcall f_18323(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_18354)
static void C_ccall f_18354(C_word c,C_word *av) C_noret;
C_noret_decl(f_18363)
static void C_fcall f_18363(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18381)
static void C_ccall f_18381(C_word c,C_word *av) C_noret;
C_noret_decl(f_18387)
static void C_ccall f_18387(C_word c,C_word *av) C_noret;
C_noret_decl(f_18393)
static void C_ccall f_18393(C_word c,C_word *av) C_noret;
C_noret_decl(f_18402)
static C_word C_fcall f_18402(C_word t0,C_word t1);
C_noret_decl(f_18421)
static void C_ccall f_18421(C_word c,C_word *av) C_noret;
C_noret_decl(f_18440)
static void C_ccall f_18440(C_word c,C_word *av) C_noret;
C_noret_decl(f_18443)
static void C_ccall f_18443(C_word c,C_word *av) C_noret;
C_noret_decl(f_18448)
static C_word C_fcall f_18448(C_word t0,C_word t1);
C_noret_decl(f_18490)
static void C_ccall f_18490(C_word c,C_word *av) C_noret;
C_noret_decl(f_18509)
static void C_ccall f_18509(C_word c,C_word *av) C_noret;
C_noret_decl(f_18512)
static void C_ccall f_18512(C_word c,C_word *av) C_noret;
C_noret_decl(f_18515)
static void C_ccall f_18515(C_word c,C_word *av) C_noret;
C_noret_decl(f_18520)
static C_word C_fcall f_18520(C_word t0,C_word t1);
C_noret_decl(f_18561)
static void C_ccall f_18561(C_word c,C_word *av) C_noret;
C_noret_decl(f_18571)
static void C_ccall f_18571(C_word c,C_word *av) C_noret;
C_noret_decl(f_18582)
static void C_fcall f_18582(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_18586)
static void C_ccall f_18586(C_word c,C_word *av) C_noret;
C_noret_decl(f_18589)
static void C_ccall f_18589(C_word c,C_word *av) C_noret;
C_noret_decl(f_18594)
static C_word C_fcall f_18594(C_word t0,C_word t1);
C_noret_decl(f_18621)
static void C_ccall f_18621(C_word c,C_word *av) C_noret;
C_noret_decl(f_18635)
static void C_ccall f_18635(C_word c,C_word *av) C_noret;
C_noret_decl(f_18646)
static void C_ccall f_18646(C_word c,C_word *av) C_noret;
C_noret_decl(f_18657)
static void C_ccall f_18657(C_word c,C_word *av) C_noret;
C_noret_decl(f_18668)
static void C_ccall f_18668(C_word c,C_word *av) C_noret;
C_noret_decl(f_18681)
static void C_ccall f_18681(C_word c,C_word *av) C_noret;
C_noret_decl(f_18683)
static void C_fcall f_18683(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18696)
static C_word C_fcall f_18696(C_word t0,C_word t1);
C_noret_decl(f_18724)
static void C_ccall f_18724(C_word c,C_word *av) C_noret;
C_noret_decl(f_18737)
static void C_ccall f_18737(C_word c,C_word *av) C_noret;
C_noret_decl(f_18755)
static void C_ccall f_18755(C_word c,C_word *av) C_noret;
C_noret_decl(f_18758)
static void C_ccall f_18758(C_word c,C_word *av) C_noret;
C_noret_decl(f_18841)
static void C_ccall f_18841(C_word c,C_word *av) C_noret;
C_noret_decl(f_18844)
static void C_ccall f_18844(C_word c,C_word *av) C_noret;
C_noret_decl(f_18847)
static void C_ccall f_18847(C_word c,C_word *av) C_noret;
C_noret_decl(f_18850)
static void C_ccall f_18850(C_word c,C_word *av) C_noret;
C_noret_decl(f_18853)
static void C_ccall f_18853(C_word c,C_word *av) C_noret;
C_noret_decl(f_18856)
static void C_ccall f_18856(C_word c,C_word *av) C_noret;
C_noret_decl(f_18859)
static void C_ccall f_18859(C_word c,C_word *av) C_noret;
C_noret_decl(f_18862)
static void C_ccall f_18862(C_word c,C_word *av) C_noret;
C_noret_decl(f_18865)
static void C_ccall f_18865(C_word c,C_word *av) C_noret;
C_noret_decl(f_18868)
static void C_ccall f_18868(C_word c,C_word *av) C_noret;
C_noret_decl(f_18871)
static void C_ccall f_18871(C_word c,C_word *av) C_noret;
C_noret_decl(f_18874)
static void C_ccall f_18874(C_word c,C_word *av) C_noret;
C_noret_decl(f_18877)
static void C_ccall f_18877(C_word c,C_word *av) C_noret;
C_noret_decl(f_18880)
static void C_ccall f_18880(C_word c,C_word *av) C_noret;
C_noret_decl(f_18885)
static void C_ccall f_18885(C_word c,C_word *av) C_noret;
C_noret_decl(f_18891)
static void C_fcall f_18891(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18907)
static void C_ccall f_18907(C_word c,C_word *av) C_noret;
C_noret_decl(f_18923)
static void C_ccall f_18923(C_word c,C_word *av) C_noret;
C_noret_decl(f_18929)
static void C_fcall f_18929(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18949)
static void C_ccall f_18949(C_word c,C_word *av) C_noret;
C_noret_decl(f_18953)
static void C_ccall f_18953(C_word c,C_word *av) C_noret;
C_noret_decl(f_18965)
static void C_ccall f_18965(C_word c,C_word *av) C_noret;
C_noret_decl(f_18971)
static void C_ccall f_18971(C_word c,C_word *av) C_noret;
C_noret_decl(f_18977)
static void C_fcall f_18977(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19009)
static void C_ccall f_19009(C_word c,C_word *av) C_noret;
C_noret_decl(f_19013)
static void C_ccall f_19013(C_word c,C_word *av) C_noret;
C_noret_decl(f_19023)
static void C_ccall f_19023(C_word c,C_word *av) C_noret;
C_noret_decl(f_19038)
static void C_fcall f_19038(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19048)
static void C_ccall f_19048(C_word c,C_word *av) C_noret;
C_noret_decl(f_19068)
static void C_fcall f_19068(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19075)
static void C_ccall f_19075(C_word c,C_word *av) C_noret;
C_noret_decl(f_19084)
static void C_ccall f_19084(C_word c,C_word *av) C_noret;
C_noret_decl(f_19091)
static void C_ccall f_19091(C_word c,C_word *av) C_noret;
C_noret_decl(f_19093)
static void C_ccall f_19093(C_word c,C_word *av) C_noret;
C_noret_decl(f_19099)
static void C_ccall f_19099(C_word c,C_word *av) C_noret;
C_noret_decl(f_19105)
static void C_ccall f_19105(C_word c,C_word *av) C_noret;
C_noret_decl(f_19123)
static void C_fcall f_19123(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19148)
static void C_ccall f_19148(C_word c,C_word *av) C_noret;
C_noret_decl(f_19164)
static void C_fcall f_19164(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19171)
static void C_ccall f_19171(C_word c,C_word *av) C_noret;
C_noret_decl(f_19184)
static void C_ccall f_19184(C_word c,C_word *av) C_noret;
C_noret_decl(f_19188)
static void C_ccall f_19188(C_word c,C_word *av) C_noret;
C_noret_decl(f_19192)
static void C_ccall f_19192(C_word c,C_word *av) C_noret;
C_noret_decl(f_19194)
static void C_ccall f_19194(C_word c,C_word *av) C_noret;
C_noret_decl(f_19200)
static void C_ccall f_19200(C_word c,C_word *av) C_noret;
C_noret_decl(f_19207)
static void C_ccall f_19207(C_word c,C_word *av) C_noret;
C_noret_decl(f_19211)
static void C_ccall f_19211(C_word c,C_word *av) C_noret;
C_noret_decl(f_19220)
static void C_ccall f_19220(C_word c,C_word *av) C_noret;
C_noret_decl(f_19228)
static void C_ccall f_19228(C_word c,C_word *av) C_noret;
C_noret_decl(f_19238)
static void C_ccall f_19238(C_word c,C_word *av) C_noret;
C_noret_decl(f_19244)
static void C_ccall f_19244(C_word c,C_word *av) C_noret;
C_noret_decl(f_19247)
static void C_ccall f_19247(C_word c,C_word *av) C_noret;
C_noret_decl(f_19251)
static void C_ccall f_19251(C_word c,C_word *av) C_noret;
C_noret_decl(f_19278)
static void C_fcall f_19278(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19294)
static void C_ccall f_19294(C_word c,C_word *av) C_noret;
C_noret_decl(f_19300)
static void C_ccall f_19300(C_word c,C_word *av) C_noret;
C_noret_decl(f_19323)
static void C_ccall f_19323(C_word c,C_word *av) C_noret;
C_noret_decl(f_19336)
static void C_ccall f_19336(C_word c,C_word *av) C_noret;
C_noret_decl(f_19342)
static void C_ccall f_19342(C_word c,C_word *av) C_noret;
C_noret_decl(f_19347)
static void C_ccall f_19347(C_word c,C_word *av) C_noret;
C_noret_decl(f_19352)
static void C_ccall f_19352(C_word c,C_word *av) C_noret;
C_noret_decl(f_19356)
static void C_ccall f_19356(C_word c,C_word *av) C_noret;
C_noret_decl(f_19365)
static void C_ccall f_19365(C_word c,C_word *av) C_noret;
C_noret_decl(f_19396)
static void C_ccall f_19396(C_word c,C_word *av) C_noret;
C_noret_decl(f_19400)
static void C_ccall f_19400(C_word c,C_word *av) C_noret;
C_noret_decl(f_19404)
static void C_ccall f_19404(C_word c,C_word *av) C_noret;
C_noret_decl(f_19407)
static void C_ccall f_19407(C_word c,C_word *av) C_noret;
C_noret_decl(f_19410)
static void C_ccall f_19410(C_word c,C_word *av) C_noret;
C_noret_decl(f_19413)
static void C_ccall f_19413(C_word c,C_word *av) C_noret;
C_noret_decl(f_19415)
static void C_ccall f_19415(C_word c,C_word *av) C_noret;
C_noret_decl(f_19426)
static void C_ccall f_19426(C_word c,C_word *av) C_noret;
C_noret_decl(f_19437)
static void C_ccall f_19437(C_word c,C_word *av) C_noret;
C_noret_decl(f_19448)
static void C_ccall f_19448(C_word c,C_word *av) C_noret;
C_noret_decl(f_19459)
static void C_ccall f_19459(C_word c,C_word *av) C_noret;
C_noret_decl(f_19472)
static void C_ccall f_19472(C_word c,C_word *av) C_noret;
C_noret_decl(f_19474)
static C_word C_fcall f_19474(C_word t0,C_word t1);
C_noret_decl(f_19480)
static C_word C_fcall f_19480(C_word t0);
C_noret_decl(f_19485)
static C_word C_fcall f_19485(C_word t0);
C_noret_decl(f_19520)
static void C_ccall f_19520(C_word c,C_word *av) C_noret;
C_noret_decl(f_19533)
static void C_ccall f_19533(C_word c,C_word *av) C_noret;
C_noret_decl(f_19535)
static C_word C_fcall f_19535(C_word t0,C_word t1);
C_noret_decl(f_19541)
static C_word C_fcall f_19541(C_word t0);
C_noret_decl(f_19546)
static C_word C_fcall f_19546(C_word t0);
C_noret_decl(f_19581)
static void C_ccall f_19581(C_word c,C_word *av) C_noret;
C_noret_decl(f_19594)
static void C_ccall f_19594(C_word c,C_word *av) C_noret;
C_noret_decl(f_19596)
static C_word C_fcall f_19596(C_word t0,C_word t1);
C_noret_decl(f_19602)
static C_word C_fcall f_19602(C_word t0);
C_noret_decl(f_19607)
static C_word C_fcall f_19607(C_word t0);
C_noret_decl(f_19642)
static void C_ccall f_19642(C_word c,C_word *av) C_noret;
C_noret_decl(f_19654)
static void C_ccall f_19654(C_word c,C_word *av) C_noret;
C_noret_decl(f_19656)
static void C_ccall f_19656(C_word c,C_word *av) C_noret;
C_noret_decl(f_19662)
static void C_ccall f_19662(C_word c,C_word *av) C_noret;
C_noret_decl(f_19668)
static void C_fcall f_19668(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_19678)
static void C_ccall f_19678(C_word c,C_word *av) C_noret;
C_noret_decl(f_19681)
static void C_ccall f_19681(C_word c,C_word *av) C_noret;
C_noret_decl(f_19684)
static void C_ccall f_19684(C_word c,C_word *av) C_noret;
C_noret_decl(f_19687)
static void C_ccall f_19687(C_word c,C_word *av) C_noret;
C_noret_decl(f_19694)
static void C_ccall f_19694(C_word c,C_word *av) C_noret;
C_noret_decl(f_19698)
static void C_ccall f_19698(C_word c,C_word *av) C_noret;
C_noret_decl(f_19702)
static void C_ccall f_19702(C_word c,C_word *av) C_noret;
C_noret_decl(f_19706)
static void C_ccall f_19706(C_word c,C_word *av) C_noret;
C_noret_decl(f_19712)
static void C_fcall f_19712(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19725)
static void C_ccall f_19725(C_word c,C_word *av) C_noret;
C_noret_decl(f_19767)
static void C_fcall f_19767(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_19771)
static void C_ccall f_19771(C_word c,C_word *av) C_noret;
C_noret_decl(f_19804)
static void C_ccall f_19804(C_word c,C_word *av) C_noret;
C_noret_decl(f_19810)
static void C_ccall f_19810(C_word c,C_word *av) C_noret;
C_noret_decl(f_19816)
static void C_ccall f_19816(C_word c,C_word *av) C_noret;
C_noret_decl(f_19822)
static void C_ccall f_19822(C_word c,C_word *av) C_noret;
C_noret_decl(f_19828)
static void C_ccall f_19828(C_word c,C_word *av) C_noret;
C_noret_decl(f_19832)
static void C_ccall f_19832(C_word c,C_word *av) C_noret;
C_noret_decl(f_19837)
static void C_ccall f_19837(C_word c,C_word *av) C_noret;
C_noret_decl(f_19843)
static void C_ccall f_19843(C_word c,C_word *av) C_noret;
C_noret_decl(f_19847)
static void C_ccall f_19847(C_word c,C_word *av) C_noret;
C_noret_decl(f_19852)
static void C_ccall f_19852(C_word c,C_word *av) C_noret;
C_noret_decl(f_19856)
static void C_ccall f_19856(C_word c,C_word *av) C_noret;
C_noret_decl(f_19861)
static void C_ccall f_19861(C_word c,C_word *av) C_noret;
C_noret_decl(f_19867)
static void C_ccall f_19867(C_word c,C_word *av) C_noret;
C_noret_decl(f_19871)
static void C_ccall f_19871(C_word c,C_word *av) C_noret;
C_noret_decl(f_19876)
static void C_ccall f_19876(C_word c,C_word *av) C_noret;
C_noret_decl(f_19880)
static void C_ccall f_19880(C_word c,C_word *av) C_noret;
C_noret_decl(f_19885)
static void C_ccall f_19885(C_word c,C_word *av) C_noret;
C_noret_decl(f_19890)
static void C_ccall f_19890(C_word c,C_word *av) C_noret;
C_noret_decl(f_19896)
static void C_ccall f_19896(C_word c,C_word *av) C_noret;
C_noret_decl(f_19900)
static void C_ccall f_19900(C_word c,C_word *av) C_noret;
C_noret_decl(f_19905)
static void C_ccall f_19905(C_word c,C_word *av) C_noret;
C_noret_decl(f_19910)
static void C_ccall f_19910(C_word c,C_word *av) C_noret;
C_noret_decl(f_19914)
static void C_ccall f_19914(C_word c,C_word *av) C_noret;
C_noret_decl(f_19919)
static void C_ccall f_19919(C_word c,C_word *av) C_noret;
C_noret_decl(f_19924)
static void C_ccall f_19924(C_word c,C_word *av) C_noret;
C_noret_decl(f_19930)
static void C_ccall f_19930(C_word c,C_word *av) C_noret;
C_noret_decl(f_19934)
static void C_ccall f_19934(C_word c,C_word *av) C_noret;
C_noret_decl(f_19939)
static void C_ccall f_19939(C_word c,C_word *av) C_noret;
C_noret_decl(f_19944)
static void C_ccall f_19944(C_word c,C_word *av) C_noret;
C_noret_decl(f_19949)
static void C_ccall f_19949(C_word c,C_word *av) C_noret;
C_noret_decl(f_19970)
static void C_ccall f_19970(C_word c,C_word *av) C_noret;
C_noret_decl(f_19977)
static void C_ccall f_19977(C_word c,C_word *av) C_noret;
C_noret_decl(f_19983)
static void C_ccall f_19983(C_word c,C_word *av) C_noret;
C_noret_decl(f_20001)
static void C_ccall f_20001(C_word c,C_word *av) C_noret;
C_noret_decl(f_20010)
static void C_ccall f_20010(C_word c,C_word *av) C_noret;
C_noret_decl(f_20023)
static void C_fcall f_20023(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20031)
static void C_ccall f_20031(C_word c,C_word *av) C_noret;
C_noret_decl(f_20036)
static void C_fcall f_20036(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20073)
static void C_ccall f_20073(C_word c,C_word *av) C_noret;
C_noret_decl(f_20085)
static void C_ccall f_20085(C_word c,C_word *av) C_noret;
C_noret_decl(f_20095)
static void C_fcall f_20095(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20111)
static void C_ccall f_20111(C_word c,C_word *av) C_noret;
C_noret_decl(f_20124)
static void C_ccall f_20124(C_word c,C_word *av) C_noret;
C_noret_decl(f_20131)
static void C_ccall f_20131(C_word c,C_word *av) C_noret;
C_noret_decl(f_20133)
static void C_ccall f_20133(C_word c,C_word *av) C_noret;
C_noret_decl(f_20146)
static void C_ccall f_20146(C_word c,C_word *av) C_noret;
C_noret_decl(f_20152)
static void C_ccall f_20152(C_word c,C_word *av) C_noret;
C_noret_decl(f_20159)
static void C_ccall f_20159(C_word c,C_word *av) C_noret;
C_noret_decl(f_20161)
static void C_ccall f_20161(C_word c,C_word *av) C_noret;
C_noret_decl(f_20165)
static void C_ccall f_20165(C_word c,C_word *av) C_noret;
C_noret_decl(f_20168)
static void C_ccall f_20168(C_word c,C_word *av) C_noret;
C_noret_decl(f_20178)
static void C_ccall f_20178(C_word c,C_word *av) C_noret;
C_noret_decl(f_20182)
static void C_ccall f_20182(C_word c,C_word *av) C_noret;
C_noret_decl(f_20190)
static void C_ccall f_20190(C_word c,C_word *av) C_noret;
C_noret_decl(f_20193)
static void C_ccall f_20193(C_word c,C_word *av) C_noret;
C_noret_decl(f_20200)
static void C_ccall f_20200(C_word c,C_word *av) C_noret;
C_noret_decl(f_20203)
static void C_ccall f_20203(C_word c,C_word *av) C_noret;
C_noret_decl(f_20206)
static void C_ccall f_20206(C_word c,C_word *av) C_noret;
C_noret_decl(f_20209)
static void C_ccall f_20209(C_word c,C_word *av) C_noret;
C_noret_decl(f_20217)
static void C_ccall f_20217(C_word c,C_word *av) C_noret;
C_noret_decl(f_20225)
static void C_ccall f_20225(C_word c,C_word *av) C_noret;
C_noret_decl(f_20227)
static void C_ccall f_20227(C_word c,C_word *av) C_noret;
C_noret_decl(f_20243)
static void C_ccall f_20243(C_word c,C_word *av) C_noret;
C_noret_decl(f_20270)
static void C_ccall f_20270(C_word c,C_word *av) C_noret;
C_noret_decl(f_20274)
static void C_ccall f_20274(C_word c,C_word *av) C_noret;
C_noret_decl(f_20278)
static void C_ccall f_20278(C_word c,C_word *av) C_noret;
C_noret_decl(f_20282)
static void C_ccall f_20282(C_word c,C_word *av) C_noret;
C_noret_decl(f_20286)
static void C_ccall f_20286(C_word c,C_word *av) C_noret;
C_noret_decl(f_20290)
static void C_ccall f_20290(C_word c,C_word *av) C_noret;
C_noret_decl(f_20294)
static void C_ccall f_20294(C_word c,C_word *av) C_noret;
C_noret_decl(f_20298)
static void C_ccall f_20298(C_word c,C_word *av) C_noret;
C_noret_decl(f_20302)
static void C_ccall f_20302(C_word c,C_word *av) C_noret;
C_noret_decl(f_20306)
static void C_ccall f_20306(C_word c,C_word *av) C_noret;
C_noret_decl(f_20310)
static void C_ccall f_20310(C_word c,C_word *av) C_noret;
C_noret_decl(f_20314)
static void C_ccall f_20314(C_word c,C_word *av) C_noret;
C_noret_decl(f_20318)
static void C_ccall f_20318(C_word c,C_word *av) C_noret;
C_noret_decl(f_20322)
static void C_ccall f_20322(C_word c,C_word *av) C_noret;
C_noret_decl(f_20326)
static void C_ccall f_20326(C_word c,C_word *av) C_noret;
C_noret_decl(f_20330)
static void C_ccall f_20330(C_word c,C_word *av) C_noret;
C_noret_decl(f_20334)
static void C_ccall f_20334(C_word c,C_word *av) C_noret;
C_noret_decl(f_20341)
static void C_ccall f_20341(C_word c,C_word *av) C_noret;
C_noret_decl(f_20348)
static void C_ccall f_20348(C_word c,C_word *av) C_noret;
C_noret_decl(f_20349)
static void C_fcall f_20349(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_20353)
static void C_fcall f_20353(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20356)
static void C_ccall f_20356(C_word c,C_word *av) C_noret;
C_noret_decl(f_20372)
static void C_ccall f_20372(C_word c,C_word *av) C_noret;
C_noret_decl(f_20383)
static void C_fcall f_20383(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20391)
static void C_ccall f_20391(C_word c,C_word *av) C_noret;
C_noret_decl(f_20403)
static void C_fcall f_20403(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20412)
static void C_fcall f_20412(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20417)
static void C_fcall f_20417(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20473)
static void C_ccall f_20473(C_word c,C_word *av) C_noret;
C_noret_decl(f_20487)
static void C_ccall f_20487(C_word c,C_word *av) C_noret;
C_noret_decl(f_20499)
static void C_ccall f_20499(C_word c,C_word *av) C_noret;
C_noret_decl(f_20505)
static void C_ccall f_20505(C_word c,C_word *av) C_noret;
C_noret_decl(f_20530)
static void C_ccall f_20530(C_word c,C_word *av) C_noret;
C_noret_decl(f_20548)
static void C_ccall f_20548(C_word c,C_word *av) C_noret;
C_noret_decl(f_20552)
static void C_ccall f_20552(C_word c,C_word *av) C_noret;
C_noret_decl(f_20608)
static void C_ccall f_20608(C_word c,C_word *av) C_noret;
C_noret_decl(f_20617)
static void C_ccall f_20617(C_word c,C_word *av) C_noret;
C_noret_decl(f_20630)
static void C_ccall f_20630(C_word c,C_word *av) C_noret;
C_noret_decl(f_20642)
static void C_ccall f_20642(C_word c,C_word *av) C_noret;
C_noret_decl(f_20660)
static void C_ccall f_20660(C_word c,C_word *av) C_noret;
C_noret_decl(f_20680)
static void C_ccall f_20680(C_word c,C_word *av) C_noret;
C_noret_decl(f_20683)
static void C_ccall f_20683(C_word c,C_word *av) C_noret;
C_noret_decl(f_20686)
static void C_ccall f_20686(C_word c,C_word *av) C_noret;
C_noret_decl(f_20694)
static void C_ccall f_20694(C_word c,C_word *av) C_noret;
C_noret_decl(f_20698)
static void C_ccall f_20698(C_word c,C_word *av) C_noret;
C_noret_decl(f_20702)
static void C_ccall f_20702(C_word c,C_word *av) C_noret;
C_noret_decl(f_20706)
static void C_ccall f_20706(C_word c,C_word *av) C_noret;
C_noret_decl(f_20710)
static void C_ccall f_20710(C_word c,C_word *av) C_noret;
C_noret_decl(f_20712)
static void C_ccall f_20712(C_word c,C_word *av) C_noret;
C_noret_decl(f_20720)
static void C_ccall f_20720(C_word c,C_word *av) C_noret;
C_noret_decl(f_20723)
static void C_ccall f_20723(C_word c,C_word *av) C_noret;
C_noret_decl(f_20733)
static void C_ccall f_20733(C_word c,C_word *av) C_noret;
C_noret_decl(f_20735)
static void C_ccall f_20735(C_word c,C_word *av) C_noret;
C_noret_decl(f_20743)
static void C_ccall f_20743(C_word c,C_word *av) C_noret;
C_noret_decl(f_20746)
static void C_ccall f_20746(C_word c,C_word *av) C_noret;
C_noret_decl(f_20756)
static void C_ccall f_20756(C_word c,C_word *av) C_noret;
C_noret_decl(f_20758)
static void C_ccall f_20758(C_word c,C_word *av) C_noret;
C_noret_decl(f_20762)
static void C_ccall f_20762(C_word c,C_word *av) C_noret;
C_noret_decl(f_20765)
static void C_ccall f_20765(C_word c,C_word *av) C_noret;
C_noret_decl(f_20768)
static void C_ccall f_20768(C_word c,C_word *av) C_noret;
C_noret_decl(f_20771)
static void C_ccall f_20771(C_word c,C_word *av) C_noret;
C_noret_decl(f_20774)
static void C_ccall f_20774(C_word c,C_word *av) C_noret;
C_noret_decl(f_20776)
static void C_ccall f_20776(C_word c,C_word *av) C_noret;
C_noret_decl(f_20782)
static void C_fcall f_20782(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_20791)
static void C_fcall f_20791(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20799)
static void C_ccall f_20799(C_word c,C_word *av) C_noret;
C_noret_decl(f_20801)
static void C_fcall f_20801(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20815)
static void C_ccall f_20815(C_word c,C_word *av) C_noret;
C_noret_decl(f_20828)
static void C_fcall f_20828(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20832)
static void C_ccall f_20832(C_word c,C_word *av) C_noret;
C_noret_decl(f_20837)
static void C_fcall f_20837(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20841)
static void C_ccall f_20841(C_word c,C_word *av) C_noret;
C_noret_decl(f_20852)
static void C_fcall f_20852(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20855)
static void C_fcall f_20855(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20863)
static void C_ccall f_20863(C_word c,C_word *av) C_noret;
C_noret_decl(f_20865)
static void C_fcall f_20865(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20878)
static void C_ccall f_20878(C_word c,C_word *av) C_noret;
C_noret_decl(f_20885)
static void C_ccall f_20885(C_word c,C_word *av) C_noret;
C_noret_decl(f_20894)
static void C_ccall f_20894(C_word c,C_word *av) C_noret;
C_noret_decl(f_20901)
static void C_ccall f_20901(C_word c,C_word *av) C_noret;
C_noret_decl(f_20903)
static void C_fcall f_20903(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_20909)
static void C_fcall f_20909(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20919)
static void C_ccall f_20919(C_word c,C_word *av) C_noret;
C_noret_decl(f_20922)
static void C_ccall f_20922(C_word c,C_word *av) C_noret;
C_noret_decl(f_20932)
static void C_ccall f_20932(C_word c,C_word *av) C_noret;
C_noret_decl(f_20935)
static void C_ccall f_20935(C_word c,C_word *av) C_noret;
C_noret_decl(f_20963)
static void C_fcall f_20963(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20967)
static void C_ccall f_20967(C_word c,C_word *av) C_noret;
C_noret_decl(f_20975)
static void C_fcall f_20975(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21000)
static void C_fcall f_21000(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21008)
static void C_ccall f_21008(C_word c,C_word *av) C_noret;
C_noret_decl(f_21010)
static void C_fcall f_21010(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21027)
static void C_ccall f_21027(C_word c,C_word *av) C_noret;
C_noret_decl(f_21040)
static void C_ccall f_21040(C_word c,C_word *av) C_noret;
C_noret_decl(f_21057)
static void C_ccall f_21057(C_word c,C_word *av) C_noret;
C_noret_decl(f_21074)
static void C_ccall f_21074(C_word c,C_word *av) C_noret;
C_noret_decl(f_21091)
static void C_ccall f_21091(C_word c,C_word *av) C_noret;
C_noret_decl(f_21108)
static void C_ccall f_21108(C_word c,C_word *av) C_noret;
C_noret_decl(f_21125)
static void C_ccall f_21125(C_word c,C_word *av) C_noret;
C_noret_decl(f_21142)
static void C_ccall f_21142(C_word c,C_word *av) C_noret;
C_noret_decl(f_21162)
static void C_ccall f_21162(C_word c,C_word *av) C_noret;
C_noret_decl(f_21170)
static void C_ccall f_21170(C_word c,C_word *av) C_noret;
C_noret_decl(f_21179)
static void C_ccall f_21179(C_word c,C_word *av) C_noret;
C_noret_decl(f_21185)
static void C_ccall f_21185(C_word c,C_word *av) C_noret;
C_noret_decl(f_21191)
static void C_fcall f_21191(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21194)
static void C_ccall f_21194(C_word c,C_word *av) C_noret;
C_noret_decl(f_21197)
static void C_ccall f_21197(C_word c,C_word *av) C_noret;
C_noret_decl(f_21207)
static void C_ccall f_21207(C_word c,C_word *av) C_noret;
C_noret_decl(f_21211)
static void C_ccall f_21211(C_word c,C_word *av) C_noret;
C_noret_decl(f_21228)
static void C_ccall f_21228(C_word c,C_word *av) C_noret;
C_noret_decl(f_21233)
static void C_ccall f_21233(C_word c,C_word *av) C_noret;
C_noret_decl(f_21240)
static void C_ccall f_21240(C_word c,C_word *av) C_noret;
C_noret_decl(f_21244)
static void C_ccall f_21244(C_word c,C_word *av) C_noret;
C_noret_decl(f_21253)
static void C_ccall f_21253(C_word c,C_word *av) C_noret;
C_noret_decl(f_21259)
static void C_ccall f_21259(C_word c,C_word *av) C_noret;
C_noret_decl(f_21269)
static void C_ccall f_21269(C_word c,C_word *av) C_noret;
C_noret_decl(f_21273)
static void C_ccall f_21273(C_word c,C_word *av) C_noret;
C_noret_decl(f_21282)
static void C_fcall f_21282(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21289)
static void C_ccall f_21289(C_word c,C_word *av) C_noret;
C_noret_decl(f_21302)
static void C_fcall f_21302(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21307)
static void C_fcall f_21307(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21324)
static void C_ccall f_21324(C_word c,C_word *av) C_noret;
C_noret_decl(f_21339)
static void C_ccall f_21339(C_word c,C_word *av) C_noret;
C_noret_decl(f_21352)
static void C_ccall f_21352(C_word c,C_word *av) C_noret;
C_noret_decl(f_21374)
static void C_ccall f_21374(C_word c,C_word *av) C_noret;
C_noret_decl(f_21377)
static void C_ccall f_21377(C_word c,C_word *av) C_noret;
C_noret_decl(f_21406)
static void C_fcall f_21406(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21416)
static void C_ccall f_21416(C_word c,C_word *av) C_noret;
C_noret_decl(f_21432)
static void C_ccall f_21432(C_word c,C_word *av) C_noret;
C_noret_decl(f_21443)
static void C_ccall f_21443(C_word c,C_word *av) C_noret;
C_noret_decl(f_21450)
static void C_ccall f_21450(C_word c,C_word *av) C_noret;
C_noret_decl(f_21548)
static void C_ccall f_21548(C_word c,C_word *av) C_noret;
C_noret_decl(f_21554)
static void C_fcall f_21554(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21563)
static void C_fcall f_21563(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21577)
static void C_ccall f_21577(C_word c,C_word *av) C_noret;
C_noret_decl(f_21580)
static void C_ccall f_21580(C_word c,C_word *av) C_noret;
C_noret_decl(f_21591)
static void C_ccall f_21591(C_word c,C_word *av) C_noret;
C_noret_decl(f_21593)
static void C_ccall f_21593(C_word c,C_word *av) C_noret;
C_noret_decl(f_21596)
static void C_ccall f_21596(C_word c,C_word *av) C_noret;
C_noret_decl(f_21613)
static void C_ccall f_21613(C_word c,C_word *av) C_noret;
C_noret_decl(f_21618)
static void C_fcall f_21618(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21622)
static void C_ccall f_21622(C_word c,C_word *av) C_noret;
C_noret_decl(f_21625)
static void C_fcall f_21625(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21628)
static void C_ccall f_21628(C_word c,C_word *av) C_noret;
C_noret_decl(f_21638)
static void C_ccall f_21638(C_word c,C_word *av) C_noret;
C_noret_decl(f_21656)
static void C_ccall f_21656(C_word c,C_word *av) C_noret;
C_noret_decl(f_21659)
static void C_ccall f_21659(C_word c,C_word *av) C_noret;
C_noret_decl(f_21668)
static void C_fcall f_21668(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21671)
static void C_ccall f_21671(C_word c,C_word *av) C_noret;
C_noret_decl(f_21674)
static void C_ccall f_21674(C_word c,C_word *av) C_noret;
C_noret_decl(f_21680)
static void C_ccall f_21680(C_word c,C_word *av) C_noret;
C_noret_decl(f_21693)
static void C_ccall f_21693(C_word c,C_word *av) C_noret;
C_noret_decl(f_21697)
static void C_ccall f_21697(C_word c,C_word *av) C_noret;
C_noret_decl(f_21701)
static void C_ccall f_21701(C_word c,C_word *av) C_noret;
C_noret_decl(f_21712)
static void C_ccall f_21712(C_word c,C_word *av) C_noret;
C_noret_decl(f_21716)
static void C_ccall f_21716(C_word c,C_word *av) C_noret;
C_noret_decl(f_21719)
static void C_ccall f_21719(C_word c,C_word *av) C_noret;
C_noret_decl(f_21747)
static void C_ccall f_21747(C_word c,C_word *av) C_noret;
C_noret_decl(f_21803)
static void C_ccall f_21803(C_word c,C_word *av) C_noret;
C_noret_decl(f_21807)
static void C_ccall f_21807(C_word c,C_word *av) C_noret;
C_noret_decl(f_21814)
static void C_ccall f_21814(C_word c,C_word *av) C_noret;
C_noret_decl(f_21816)
static void C_fcall f_21816(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21820)
static void C_ccall f_21820(C_word c,C_word *av) C_noret;
C_noret_decl(f_21834)
static void C_fcall f_21834(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21840)
static void C_ccall f_21840(C_word c,C_word *av) C_noret;
C_noret_decl(f_21847)
static void C_ccall f_21847(C_word c,C_word *av) C_noret;
C_noret_decl(f_21854)
static void C_ccall f_21854(C_word c,C_word *av) C_noret;
C_noret_decl(f_21875)
static void C_ccall f_21875(C_word c,C_word *av) C_noret;
C_noret_decl(f_21904)
static void C_fcall f_21904(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21914)
static void C_ccall f_21914(C_word c,C_word *av) C_noret;
C_noret_decl(f_21917)
static void C_ccall f_21917(C_word c,C_word *av) C_noret;
C_noret_decl(f_21953)
static void C_ccall f_21953(C_word c,C_word *av) C_noret;
C_noret_decl(f_21955)
static void C_fcall f_21955(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21965)
static void C_ccall f_21965(C_word c,C_word *av) C_noret;
C_noret_decl(f_21968)
static void C_ccall f_21968(C_word c,C_word *av) C_noret;
C_noret_decl(f_22020)
static void C_ccall f_22020(C_word c,C_word *av) C_noret;
C_noret_decl(f_22022)
static void C_fcall f_22022(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22030)
static void C_ccall f_22030(C_word c,C_word *av) C_noret;
C_noret_decl(f_22032)
static void C_fcall f_22032(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22042)
static void C_fcall f_22042(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22057)
static void C_ccall f_22057(C_word c,C_word *av) C_noret;
C_noret_decl(f_22064)
static void C_ccall f_22064(C_word c,C_word *av) C_noret;
C_noret_decl(f_22086)
static void C_fcall f_22086(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22094)
static void C_ccall f_22094(C_word c,C_word *av) C_noret;
C_noret_decl(f_22096)
static void C_fcall f_22096(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_22112)
static void C_ccall f_22112(C_word c,C_word *av) C_noret;
C_noret_decl(f_22119)
static void C_ccall f_22119(C_word c,C_word *av) C_noret;
C_noret_decl(f_22132)
static void C_fcall f_22132(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22138)
static void C_ccall f_22138(C_word c,C_word *av) C_noret;
C_noret_decl(f_22142)
static void C_ccall f_22142(C_word c,C_word *av) C_noret;
C_noret_decl(f_22149)
static void C_ccall f_22149(C_word c,C_word *av) C_noret;
C_noret_decl(f_22157)
static void C_fcall f_22157(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22162)
static void C_fcall f_22162(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22167)
static void C_fcall f_22167(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_22171)
static void C_ccall f_22171(C_word c,C_word *av) C_noret;
C_noret_decl(f_22180)
static void C_fcall f_22180(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22186)
static void C_fcall f_22186(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22193)
static void C_ccall f_22193(C_word c,C_word *av) C_noret;
C_noret_decl(f_22210)
static void C_ccall f_22210(C_word c,C_word *av) C_noret;
C_noret_decl(f_22216)
static void C_fcall f_22216(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22226)
static void C_ccall f_22226(C_word c,C_word *av) C_noret;
C_noret_decl(f_22277)
static void C_ccall f_22277(C_word c,C_word *av) C_noret;
C_noret_decl(f_22286)
static void C_ccall f_22286(C_word c,C_word *av) C_noret;
C_noret_decl(f_22293)
static void C_ccall f_22293(C_word c,C_word *av) C_noret;
C_noret_decl(f_22297)
static void C_ccall f_22297(C_word c,C_word *av) C_noret;
C_noret_decl(f_22301)
static void C_ccall f_22301(C_word c,C_word *av) C_noret;
C_noret_decl(f_22310)
static void C_ccall f_22310(C_word c,C_word *av) C_noret;
C_noret_decl(f_22321)
static void C_ccall f_22321(C_word c,C_word *av) C_noret;
C_noret_decl(f_22343)
static void C_ccall f_22343(C_word c,C_word *av) C_noret;
C_noret_decl(f_22402)
static void C_ccall f_22402(C_word c,C_word *av) C_noret;
C_noret_decl(f_22406)
static void C_ccall f_22406(C_word c,C_word *av) C_noret;
C_noret_decl(f_22408)
static void C_fcall f_22408(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22412)
static void C_ccall f_22412(C_word c,C_word *av) C_noret;
C_noret_decl(f_22415)
static void C_ccall f_22415(C_word c,C_word *av) C_noret;
C_noret_decl(f_22427)
static void C_ccall f_22427(C_word c,C_word *av) C_noret;
C_noret_decl(f_22447)
static void C_fcall f_22447(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22453)
static void C_ccall f_22453(C_word c,C_word *av) C_noret;
C_noret_decl(f_22463)
static void C_ccall f_22463(C_word c,C_word *av) C_noret;
C_noret_decl(f_22592)
static void C_fcall f_22592(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22599)
static void C_ccall f_22599(C_word c,C_word *av) C_noret;
C_noret_decl(f_22617)
static void C_fcall f_22617(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22623)
static void C_fcall f_22623(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22627)
static void C_ccall f_22627(C_word c,C_word *av) C_noret;
C_noret_decl(f_22663)
static void C_ccall f_22663(C_word c,C_word *av) C_noret;
C_noret_decl(f_22686)
static void C_ccall f_22686(C_word c,C_word *av) C_noret;
C_noret_decl(f_22704)
static void C_fcall f_22704(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22708)
static void C_ccall f_22708(C_word c,C_word *av) C_noret;
C_noret_decl(f_22715)
static void C_ccall f_22715(C_word c,C_word *av) C_noret;
C_noret_decl(f_22717)
static void C_fcall f_22717(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22721)
static void C_ccall f_22721(C_word c,C_word *av) C_noret;
C_noret_decl(f_22732)
static void C_ccall f_22732(C_word c,C_word *av) C_noret;
C_noret_decl(f_22748)
static void C_ccall f_22748(C_word c,C_word *av) C_noret;
C_noret_decl(f_22751)
static void C_ccall f_22751(C_word c,C_word *av) C_noret;
C_noret_decl(f_22754)
static void C_ccall f_22754(C_word c,C_word *av) C_noret;
C_noret_decl(f_22768)
static void C_ccall f_22768(C_word c,C_word *av) C_noret;
C_noret_decl(f_22774)
static void C_ccall f_22774(C_word c,C_word *av) C_noret;
C_noret_decl(f_22796)
static void C_ccall f_22796(C_word c,C_word *av) C_noret;
C_noret_decl(f_22808)
static void C_ccall f_22808(C_word c,C_word *av) C_noret;
C_noret_decl(f_22820)
static void C_ccall f_22820(C_word c,C_word *av) C_noret;
C_noret_decl(f_22829)
static void C_ccall f_22829(C_word c,C_word *av) C_noret;
C_noret_decl(f_22839)
static void C_ccall f_22839(C_word c,C_word *av) C_noret;
C_noret_decl(f_22848)
static void C_ccall f_22848(C_word c,C_word *av) C_noret;
C_noret_decl(f_22851)
static void C_ccall f_22851(C_word c,C_word *av) C_noret;
C_noret_decl(f_22869)
static void C_ccall f_22869(C_word c,C_word *av) C_noret;
C_noret_decl(f_22872)
static void C_ccall f_22872(C_word c,C_word *av) C_noret;
C_noret_decl(f_22895)
static void C_ccall f_22895(C_word c,C_word *av) C_noret;
C_noret_decl(f_22901)
static void C_ccall f_22901(C_word c,C_word *av) C_noret;
C_noret_decl(f_22929)
static void C_ccall f_22929(C_word c,C_word *av) C_noret;
C_noret_decl(f_22952)
static void C_ccall f_22952(C_word c,C_word *av) C_noret;
C_noret_decl(f_22966)
static void C_ccall f_22966(C_word c,C_word *av) C_noret;
C_noret_decl(f_22972)
static void C_ccall f_22972(C_word c,C_word *av) C_noret;
C_noret_decl(f_22997)
static void C_ccall f_22997(C_word c,C_word *av) C_noret;
C_noret_decl(f_23009)
static void C_ccall f_23009(C_word c,C_word *av) C_noret;
C_noret_decl(f_23021)
static void C_ccall f_23021(C_word c,C_word *av) C_noret;
C_noret_decl(f_23033)
static void C_ccall f_23033(C_word c,C_word *av) C_noret;
C_noret_decl(f_23045)
static void C_ccall f_23045(C_word c,C_word *av) C_noret;
C_noret_decl(f_23057)
static void C_ccall f_23057(C_word c,C_word *av) C_noret;
C_noret_decl(f_23069)
static void C_ccall f_23069(C_word c,C_word *av) C_noret;
C_noret_decl(f_23072)
static void C_ccall f_23072(C_word c,C_word *av) C_noret;
C_noret_decl(f_23075)
static void C_ccall f_23075(C_word c,C_word *av) C_noret;
C_noret_decl(f_23080)
static void C_ccall f_23080(C_word c,C_word *av) C_noret;
C_noret_decl(f_23085)
static void C_ccall f_23085(C_word c,C_word *av) C_noret;
C_noret_decl(f_23091)
static void C_ccall f_23091(C_word c,C_word *av) C_noret;
C_noret_decl(f_23133)
static void C_ccall f_23133(C_word c,C_word *av) C_noret;
C_noret_decl(f_23145)
static void C_ccall f_23145(C_word c,C_word *av) C_noret;
C_noret_decl(f_23148)
static void C_ccall f_23148(C_word c,C_word *av) C_noret;
C_noret_decl(f_23160)
static void C_ccall f_23160(C_word c,C_word *av) C_noret;
C_noret_decl(f_23172)
static void C_ccall f_23172(C_word c,C_word *av) C_noret;
C_noret_decl(f_23175)
static void C_ccall f_23175(C_word c,C_word *av) C_noret;
C_noret_decl(f_23187)
static void C_ccall f_23187(C_word c,C_word *av) C_noret;
C_noret_decl(f_23199)
static void C_ccall f_23199(C_word c,C_word *av) C_noret;
C_noret_decl(f_23202)
static void C_ccall f_23202(C_word c,C_word *av) C_noret;
C_noret_decl(f_23211)
static void C_ccall f_23211(C_word c,C_word *av) C_noret;
C_noret_decl(f_23226)
static void C_ccall f_23226(C_word c,C_word *av) C_noret;
C_noret_decl(f_23229)
static void C_ccall f_23229(C_word c,C_word *av) C_noret;
C_noret_decl(f_23234)
static void C_ccall f_23234(C_word c,C_word *av) C_noret;
C_noret_decl(f_23239)
static void C_ccall f_23239(C_word c,C_word *av) C_noret;
C_noret_decl(f_23245)
static void C_ccall f_23245(C_word c,C_word *av) C_noret;
C_noret_decl(f_23274)
static void C_ccall f_23274(C_word c,C_word *av) C_noret;
C_noret_decl(f_23286)
static void C_ccall f_23286(C_word c,C_word *av) C_noret;
C_noret_decl(f_23289)
static void C_ccall f_23289(C_word c,C_word *av) C_noret;
C_noret_decl(f_23292)
static void C_ccall f_23292(C_word c,C_word *av) C_noret;
C_noret_decl(f_23307)
static void C_ccall f_23307(C_word c,C_word *av) C_noret;
C_noret_decl(f_23316)
static void C_ccall f_23316(C_word c,C_word *av) C_noret;
C_noret_decl(f_23319)
static void C_ccall f_23319(C_word c,C_word *av) C_noret;
C_noret_decl(f_23325)
static void C_fcall f_23325(C_word t0,C_word t1) C_noret;
C_noret_decl(f_23328)
static void C_ccall f_23328(C_word c,C_word *av) C_noret;
C_noret_decl(f_23334)
static void C_ccall f_23334(C_word c,C_word *av) C_noret;
C_noret_decl(f_23358)
static void C_ccall f_23358(C_word c,C_word *av) C_noret;
C_noret_decl(f_23377)
static void C_ccall f_23377(C_word c,C_word *av) C_noret;
C_noret_decl(f_23393)
static void C_ccall f_23393(C_word c,C_word *av) C_noret;
C_noret_decl(f_23399)
static void C_ccall f_23399(C_word c,C_word *av) C_noret;
C_noret_decl(f_23471)
static void C_ccall f_23471(C_word c,C_word *av) C_noret;
C_noret_decl(f_23483)
static void C_ccall f_23483(C_word c,C_word *av) C_noret;
C_noret_decl(f_23561)
static void C_ccall f_23561(C_word c,C_word *av) C_noret;
C_noret_decl(f_23637)
static void C_ccall f_23637(C_word c,C_word *av) C_noret;
C_noret_decl(f_23802)
static void C_ccall f_23802(C_word c,C_word *av) C_noret;
C_noret_decl(f_23814)
static void C_ccall f_23814(C_word c,C_word *av) C_noret;
C_noret_decl(f_23876)
static void C_ccall f_23876(C_word c,C_word *av) C_noret;
C_noret_decl(f_23879)
static void C_fcall f_23879(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_23925)
static void C_fcall f_23925(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_23929)
static void C_ccall f_23929(C_word c,C_word *av) C_noret;
C_noret_decl(f_23947)
static void C_ccall f_23947(C_word c,C_word *av) C_noret;
C_noret_decl(f_24011)
static void C_ccall f_24011(C_word c,C_word *av) C_noret;
C_noret_decl(f_24022)
static void C_ccall f_24022(C_word c,C_word *av) C_noret;
C_noret_decl(f_24024)
static void C_ccall f_24024(C_word c,C_word *av) C_noret;
C_noret_decl(f_24037)
static void C_ccall f_24037(C_word c,C_word *av) C_noret;
C_noret_decl(f_24049)
static void C_ccall f_24049(C_word c,C_word *av) C_noret;
C_noret_decl(f_24069)
static void C_ccall f_24069(C_word c,C_word *av) C_noret;
C_noret_decl(f_24076)
static void C_ccall f_24076(C_word c,C_word *av) C_noret;
C_noret_decl(f_24085)
static void C_ccall f_24085(C_word c,C_word *av) C_noret;
C_noret_decl(f_24097)
static void C_ccall f_24097(C_word c,C_word *av) C_noret;
C_noret_decl(f_24118)
static void C_ccall f_24118(C_word c,C_word *av) C_noret;
C_noret_decl(f_24133)
static void C_ccall f_24133(C_word c,C_word *av) C_noret;
C_noret_decl(f_24151)
static void C_ccall f_24151(C_word c,C_word *av) C_noret;
C_noret_decl(f_24169)
static void C_ccall f_24169(C_word c,C_word *av) C_noret;
C_noret_decl(f_24188)
static void C_fcall f_24188(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_24198)
static void C_ccall f_24198(C_word c,C_word *av) C_noret;
C_noret_decl(f_24212)
static void C_ccall f_24212(C_word c,C_word *av) C_noret;
C_noret_decl(f_24215)
static void C_ccall f_24215(C_word c,C_word *av) C_noret;
C_noret_decl(f_24220)
static void C_ccall f_24220(C_word c,C_word *av) C_noret;
C_noret_decl(f_24239)
static void C_fcall f_24239(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_24249)
static void C_ccall f_24249(C_word c,C_word *av) C_noret;
C_noret_decl(f_24263)
static void C_ccall f_24263(C_word c,C_word *av) C_noret;
C_noret_decl(f_24266)
static void C_ccall f_24266(C_word c,C_word *av) C_noret;
C_noret_decl(f_24273)
static void C_ccall f_24273(C_word c,C_word *av) C_noret;
C_noret_decl(f_24277)
static void C_ccall f_24277(C_word c,C_word *av) C_noret;
C_noret_decl(f_24281)
static void C_ccall f_24281(C_word c,C_word *av) C_noret;
C_noret_decl(f_24283)
static void C_ccall f_24283(C_word c,C_word *av) C_noret;
C_noret_decl(f_24290)
static void C_ccall f_24290(C_word c,C_word *av) C_noret;
C_noret_decl(f_24293)
static void C_ccall f_24293(C_word c,C_word *av) C_noret;
C_noret_decl(f_24296)
static void C_ccall f_24296(C_word c,C_word *av) C_noret;
C_noret_decl(f_24298)
static void C_fcall f_24298(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_24308)
static void C_ccall f_24308(C_word c,C_word *av) C_noret;
C_noret_decl(f_24314)
static void C_ccall f_24314(C_word c,C_word *av) C_noret;
C_noret_decl(f_24326)
static void C_ccall f_24326(C_word c,C_word *av) C_noret;
C_noret_decl(f_24329)
static void C_ccall f_24329(C_word c,C_word *av) C_noret;
C_noret_decl(f_24332)
static void C_ccall f_24332(C_word c,C_word *av) C_noret;
C_noret_decl(f_24349)
static void C_ccall f_24349(C_word c,C_word *av) C_noret;
C_noret_decl(f_24370)
static void C_fcall f_24370(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_24374)
static void C_ccall f_24374(C_word c,C_word *av) C_noret;
C_noret_decl(f_24387)
static void C_ccall f_24387(C_word c,C_word *av) C_noret;
C_noret_decl(f_24390)
static void C_ccall f_24390(C_word c,C_word *av) C_noret;
C_noret_decl(f_24399)
static void C_ccall f_24399(C_word c,C_word *av) C_noret;
C_noret_decl(f_24402)
static void C_ccall f_24402(C_word c,C_word *av) C_noret;
C_noret_decl(f_24430)
static void C_fcall f_24430(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_24434)
static void C_ccall f_24434(C_word c,C_word *av) C_noret;
C_noret_decl(f_24443)
static void C_ccall f_24443(C_word c,C_word *av) C_noret;
C_noret_decl(f_24454)
static void C_fcall f_24454(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_24461)
static void C_ccall f_24461(C_word c,C_word *av) C_noret;
C_noret_decl(f_24466)
static void C_fcall f_24466(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_24488)
static void C_ccall f_24488(C_word c,C_word *av) C_noret;
C_noret_decl(f_24494)
static void C_ccall f_24494(C_word c,C_word *av) C_noret;
C_noret_decl(f_24497)
static void C_ccall f_24497(C_word c,C_word *av) C_noret;
C_noret_decl(f_24508)
static void C_ccall f_24508(C_word c,C_word *av) C_noret;
C_noret_decl(f_24517)
static void C_ccall f_24517(C_word c,C_word *av) C_noret;
C_noret_decl(f_24520)
static void C_ccall f_24520(C_word c,C_word *av) C_noret;
C_noret_decl(f_24543)
static void C_fcall f_24543(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_24592)
static void C_fcall f_24592(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_24608)
static void C_fcall f_24608(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24615)
static void C_ccall f_24615(C_word c,C_word *av) C_noret;
C_noret_decl(f_24627)
static void C_fcall f_24627(C_word t0,C_word t1) C_noret;
C_noret_decl(f_24732)
static void C_ccall f_24732(C_word c,C_word *av) C_noret;
C_noret_decl(f_24737)
static void C_fcall f_24737(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_24792)
static void C_ccall f_24792(C_word c,C_word *av) C_noret;
C_noret_decl(f_24798)
static void C_ccall f_24798(C_word c,C_word *av) C_noret;
C_noret_decl(f_24802)
static void C_fcall f_24802(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_24825)
static void C_ccall f_24825(C_word c,C_word *av) C_noret;
C_noret_decl(f_24832)
static void C_ccall f_24832(C_word c,C_word *av) C_noret;
C_noret_decl(f_24851)
static void C_ccall f_24851(C_word c,C_word *av) C_noret;
C_noret_decl(f_24887)
static void C_ccall f_24887(C_word c,C_word *av) C_noret;
C_noret_decl(f_24899)
static void C_ccall f_24899(C_word c,C_word *av) C_noret;
C_noret_decl(f_24905)
static void C_ccall f_24905(C_word c,C_word *av) C_noret;
C_noret_decl(f_24927)
static void C_ccall f_24927(C_word c,C_word *av) C_noret;
C_noret_decl(f_24934)
static void C_ccall f_24934(C_word c,C_word *av) C_noret;
C_noret_decl(f_24944)
static void C_ccall f_24944(C_word c,C_word *av) C_noret;
C_noret_decl(f_24953)
static void C_ccall f_24953(C_word c,C_word *av) C_noret;
C_noret_decl(f_24959)
static void C_fcall f_24959(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_24972)
static void C_ccall f_24972(C_word c,C_word *av) C_noret;
C_noret_decl(f_25010)
static void C_ccall f_25010(C_word c,C_word *av) C_noret;
C_noret_decl(f_25076)
static void C_ccall f_25076(C_word c,C_word *av) C_noret;
C_noret_decl(f_25079)
static void C_ccall f_25079(C_word c,C_word *av) C_noret;
C_noret_decl(f_25086)
static void C_ccall f_25086(C_word c,C_word *av) C_noret;
C_noret_decl(f_25126)
static void C_ccall f_25126(C_word c,C_word *av) C_noret;
C_noret_decl(f_25129)
static void C_ccall f_25129(C_word c,C_word *av) C_noret;
C_noret_decl(f_25138)
static void C_fcall f_25138(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_25151)
static void C_ccall f_25151(C_word c,C_word *av) C_noret;
C_noret_decl(f_25160)
static void C_ccall f_25160(C_word c,C_word *av) C_noret;
C_noret_decl(f_25170)
static void C_ccall f_25170(C_word c,C_word *av) C_noret;
C_noret_decl(f_25173)
static void C_ccall f_25173(C_word c,C_word *av) C_noret;
C_noret_decl(f_25199)
static void C_ccall f_25199(C_word c,C_word *av) C_noret;
C_noret_decl(f_25205)
static void C_ccall f_25205(C_word c,C_word *av) C_noret;
C_noret_decl(f_25210)
static void C_fcall f_25210(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_25223)
static void C_ccall f_25223(C_word c,C_word *av) C_noret;
C_noret_decl(f_25226)
static void C_ccall f_25226(C_word c,C_word *av) C_noret;
C_noret_decl(f_25237)
static void C_ccall f_25237(C_word c,C_word *av) C_noret;
C_noret_decl(f_25259)
static void C_ccall f_25259(C_word c,C_word *av) C_noret;
C_noret_decl(f_25271)
static void C_ccall f_25271(C_word c,C_word *av) C_noret;
C_noret_decl(f_25274)
static void C_ccall f_25274(C_word c,C_word *av) C_noret;
C_noret_decl(f_25281)
static void C_ccall f_25281(C_word c,C_word *av) C_noret;
C_noret_decl(f_25290)
static void C_ccall f_25290(C_word c,C_word *av) C_noret;
C_noret_decl(f_25293)
static void C_ccall f_25293(C_word c,C_word *av) C_noret;
C_noret_decl(f_25337)
static void C_ccall f_25337(C_word c,C_word *av) C_noret;
C_noret_decl(f_25340)
static void C_ccall f_25340(C_word c,C_word *av) C_noret;
C_noret_decl(f_25349)
static void C_fcall f_25349(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_25362)
static void C_ccall f_25362(C_word c,C_word *av) C_noret;
C_noret_decl(f_25365)
static void C_ccall f_25365(C_word c,C_word *av) C_noret;
C_noret_decl(f_25390)
static void C_ccall f_25390(C_word c,C_word *av) C_noret;
C_noret_decl(f_25394)
static void C_ccall f_25394(C_word c,C_word *av) C_noret;
C_noret_decl(f_25404)
static void C_ccall f_25404(C_word c,C_word *av) C_noret;
C_noret_decl(f_25407)
static void C_ccall f_25407(C_word c,C_word *av) C_noret;
C_noret_decl(f_25422)
static void C_ccall f_25422(C_word c,C_word *av) C_noret;
C_noret_decl(f_25429)
static void C_ccall f_25429(C_word c,C_word *av) C_noret;
C_noret_decl(f_25451)
static void C_ccall f_25451(C_word c,C_word *av) C_noret;
C_noret_decl(f_25453)
static void C_ccall f_25453(C_word c,C_word *av) C_noret;
C_noret_decl(f_25466)
static void C_ccall f_25466(C_word c,C_word *av) C_noret;
C_noret_decl(f_25471)
static void C_ccall f_25471(C_word c,C_word *av) C_noret;
C_noret_decl(f_25477)
static void C_ccall f_25477(C_word c,C_word *av) C_noret;
C_noret_decl(f_25483)
static void C_ccall f_25483(C_word c,C_word *av) C_noret;
C_noret_decl(f_25487)
static void C_ccall f_25487(C_word c,C_word *av) C_noret;
C_noret_decl(f_25490)
static void C_ccall f_25490(C_word c,C_word *av) C_noret;
C_noret_decl(f_25505)
static void C_ccall f_25505(C_word c,C_word *av) C_noret;
C_noret_decl(f_25508)
static void C_ccall f_25508(C_word c,C_word *av) C_noret;
C_noret_decl(f_25526)
static void C_ccall f_25526(C_word c,C_word *av) C_noret;
C_noret_decl(f_25528)
static void C_ccall f_25528(C_word c,C_word *av) C_noret;
C_noret_decl(f_25534)
static void C_ccall f_25534(C_word c,C_word *av) C_noret;
C_noret_decl(f_25543)
static void C_ccall f_25543(C_word c,C_word *av) C_noret;
C_noret_decl(f_25549)
static void C_ccall f_25549(C_word c,C_word *av) C_noret;
C_noret_decl(f_25556)
static void C_ccall f_25556(C_word c,C_word *av) C_noret;
C_noret_decl(f_25559)
static void C_ccall f_25559(C_word c,C_word *av) C_noret;
C_noret_decl(f_25562)
static void C_ccall f_25562(C_word c,C_word *av) C_noret;
C_noret_decl(f_25571)
static void C_ccall f_25571(C_word c,C_word *av) C_noret;
C_noret_decl(f_25587)
static void C_ccall f_25587(C_word c,C_word *av) C_noret;
C_noret_decl(f_25602)
static void C_ccall f_25602(C_word c,C_word *av) C_noret;
C_noret_decl(f_25604)
static void C_ccall f_25604(C_word c,C_word *av) C_noret;
C_noret_decl(f_25610)
static void C_ccall f_25610(C_word c,C_word *av) C_noret;
C_noret_decl(f_25616)
static void C_ccall f_25616(C_word c,C_word *av) C_noret;
C_noret_decl(f_25620)
static void C_ccall f_25620(C_word c,C_word *av) C_noret;
C_noret_decl(f_25623)
static void C_ccall f_25623(C_word c,C_word *av) C_noret;
C_noret_decl(f_25626)
static void C_ccall f_25626(C_word c,C_word *av) C_noret;
C_noret_decl(f_25630)
static void C_ccall f_25630(C_word c,C_word *av) C_noret;
C_noret_decl(f_25634)
static void C_ccall f_25634(C_word c,C_word *av) C_noret;
C_noret_decl(f_25638)
static void C_ccall f_25638(C_word c,C_word *av) C_noret;
C_noret_decl(f_25641)
static void C_ccall f_25641(C_word c,C_word *av) C_noret;
C_noret_decl(f_25644)
static void C_ccall f_25644(C_word c,C_word *av) C_noret;
C_noret_decl(f_25647)
static void C_ccall f_25647(C_word c,C_word *av) C_noret;
C_noret_decl(f_25659)
static void C_ccall f_25659(C_word c,C_word *av) C_noret;
C_noret_decl(f_25665)
static void C_ccall f_25665(C_word c,C_word *av) C_noret;
C_noret_decl(f_25669)
static void C_ccall f_25669(C_word c,C_word *av) C_noret;
C_noret_decl(f_25672)
static void C_ccall f_25672(C_word c,C_word *av) C_noret;
C_noret_decl(f_25675)
static void C_ccall f_25675(C_word c,C_word *av) C_noret;
C_noret_decl(f_25678)
static void C_ccall f_25678(C_word c,C_word *av) C_noret;
C_noret_decl(f_25681)
static void C_ccall f_25681(C_word c,C_word *av) C_noret;
C_noret_decl(f_25684)
static void C_ccall f_25684(C_word c,C_word *av) C_noret;
C_noret_decl(f_25689)
static void C_ccall f_25689(C_word c,C_word *av) C_noret;
C_noret_decl(f_25711)
static void C_ccall f_25711(C_word c,C_word *av) C_noret;
C_noret_decl(f_25717)
static void C_ccall f_25717(C_word c,C_word *av) C_noret;
C_noret_decl(f_25720)
static void C_ccall f_25720(C_word c,C_word *av) C_noret;
C_noret_decl(f_25745)
static void C_ccall f_25745(C_word c,C_word *av) C_noret;
C_noret_decl(f_25748)
static void C_fcall f_25748(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_25755)
static void C_ccall f_25755(C_word c,C_word *av) C_noret;
C_noret_decl(f_25768)
static void C_fcall f_25768(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_25778)
static void C_ccall f_25778(C_word c,C_word *av) C_noret;
C_noret_decl(f_25783)
static void C_ccall f_25783(C_word c,C_word *av) C_noret;
C_noret_decl(f_25789)
static void C_ccall f_25789(C_word c,C_word *av) C_noret;
C_noret_decl(f_25816)
static void C_ccall f_25816(C_word c,C_word *av) C_noret;
C_noret_decl(f_25822)
static void C_fcall f_25822(C_word t0,C_word t1) C_noret;
C_noret_decl(f_25833)
static void C_ccall f_25833(C_word c,C_word *av) C_noret;
C_noret_decl(f_25842)
static void C_ccall f_25842(C_word c,C_word *av) C_noret;
C_noret_decl(f_25847)
static void C_ccall f_25847(C_word c,C_word *av) C_noret;
C_noret_decl(f_25853)
static void C_ccall f_25853(C_word c,C_word *av) C_noret;
C_noret_decl(f_25877)
static void C_ccall f_25877(C_word c,C_word *av) C_noret;
C_noret_decl(f_25885)
static void C_ccall f_25885(C_word c,C_word *av) C_noret;
C_noret_decl(f_25902)
static void C_ccall f_25902(C_word c,C_word *av) C_noret;
C_noret_decl(f_25942)
static void C_ccall f_25942(C_word c,C_word *av) C_noret;
C_noret_decl(f_25949)
static void C_ccall f_25949(C_word c,C_word *av) C_noret;
C_noret_decl(f_25961)
static void C_ccall f_25961(C_word c,C_word *av) C_noret;
C_noret_decl(f_25965)
static void C_ccall f_25965(C_word c,C_word *av) C_noret;
C_noret_decl(f_25978)
static void C_ccall f_25978(C_word c,C_word *av) C_noret;
C_noret_decl(f_25980)
static void C_ccall f_25980(C_word c,C_word *av) C_noret;
C_noret_decl(f_26014)
static void C_ccall f_26014(C_word c,C_word *av) C_noret;
C_noret_decl(f_26018)
static void C_ccall f_26018(C_word c,C_word *av) C_noret;
C_noret_decl(f_26019)
static void C_fcall f_26019(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26029)
static void C_ccall f_26029(C_word c,C_word *av) C_noret;
C_noret_decl(f_26034)
static void C_fcall f_26034(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26044)
static void C_ccall f_26044(C_word c,C_word *av) C_noret;
C_noret_decl(f_26057)
static void C_ccall f_26057(C_word c,C_word *av) C_noret;
C_noret_decl(f_26068)
static void C_ccall f_26068(C_word c,C_word *av) C_noret;
C_noret_decl(f_26072)
static void C_ccall f_26072(C_word c,C_word *av) C_noret;
C_noret_decl(f_26076)
static void C_ccall f_26076(C_word c,C_word *av) C_noret;
C_noret_decl(f_26098)
static void C_ccall f_26098(C_word c,C_word *av) C_noret;
C_noret_decl(f_26102)
static void C_ccall f_26102(C_word c,C_word *av) C_noret;
C_noret_decl(f_26110)
static void C_ccall f_26110(C_word c,C_word *av) C_noret;
C_noret_decl(f_26126)
static void C_ccall f_26126(C_word c,C_word *av) C_noret;
C_noret_decl(f_26137)
static void C_fcall f_26137(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26156)
static void C_fcall f_26156(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26167)
static void C_ccall f_26167(C_word c,C_word *av) C_noret;
C_noret_decl(f_26178)
static void C_ccall f_26178(C_word c,C_word *av) C_noret;
C_noret_decl(f_26264)
static void C_ccall f_26264(C_word c,C_word *av) C_noret;
C_noret_decl(f_26274)
static void C_ccall f_26274(C_word c,C_word *av) C_noret;
C_noret_decl(f_26275)
static void C_fcall f_26275(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26288)
static void C_ccall f_26288(C_word c,C_word *av) C_noret;
C_noret_decl(f_26291)
static void C_ccall f_26291(C_word c,C_word *av) C_noret;
C_noret_decl(f_26294)
static void C_ccall f_26294(C_word c,C_word *av) C_noret;
C_noret_decl(f_26297)
static void C_ccall f_26297(C_word c,C_word *av) C_noret;
C_noret_decl(f_26305)
static void C_ccall f_26305(C_word c,C_word *av) C_noret;
C_noret_decl(f_26312)
static void C_fcall f_26312(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26315)
static void C_ccall f_26315(C_word c,C_word *av) C_noret;
C_noret_decl(f_26318)
static void C_ccall f_26318(C_word c,C_word *av) C_noret;
C_noret_decl(f_26341)
static void C_ccall f_26341(C_word c,C_word *av) C_noret;
C_noret_decl(f_26346)
static void C_fcall f_26346(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26356)
static void C_ccall f_26356(C_word c,C_word *av) C_noret;
C_noret_decl(f_26369)
static void C_ccall f_26369(C_word c,C_word *av) C_noret;
C_noret_decl(f_26400)
static void C_ccall f_26400(C_word c,C_word *av) C_noret;
C_noret_decl(f_26410)
static void C_ccall f_26410(C_word c,C_word *av) C_noret;
C_noret_decl(f_26460)
static void C_ccall f_26460(C_word c,C_word *av) C_noret;
C_noret_decl(f_26463)
static void C_ccall f_26463(C_word c,C_word *av) C_noret;
C_noret_decl(f_26482)
static void C_fcall f_26482(C_word t0) C_noret;
C_noret_decl(f_26487)
static void C_ccall f_26487(C_word c,C_word *av) C_noret;
C_noret_decl(f_26493)
static void C_ccall f_26493(C_word c,C_word *av) C_noret;
C_noret_decl(f_26496)
static void C_ccall f_26496(C_word c,C_word *av) C_noret;
C_noret_decl(f_26505)
static void C_ccall f_26505(C_word c,C_word *av) C_noret;
C_noret_decl(f_26511)
static void C_ccall f_26511(C_word c,C_word *av) C_noret;
C_noret_decl(f_26530)
static void C_fcall f_26530(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26549)
static void C_ccall f_26549(C_word c,C_word *av) C_noret;
C_noret_decl(f_26554)
static void C_fcall f_26554(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26564)
static void C_ccall f_26564(C_word c,C_word *av) C_noret;
C_noret_decl(f_26578)
static void C_ccall f_26578(C_word c,C_word *av) C_noret;
C_noret_decl(f_26585)
static void C_ccall f_26585(C_word c,C_word *av) C_noret;
C_noret_decl(f_26589)
static void C_ccall f_26589(C_word c,C_word *av) C_noret;
C_noret_decl(f_26593)
static void C_ccall f_26593(C_word c,C_word *av) C_noret;
C_noret_decl(f_26595)
static void C_ccall f_26595(C_word c,C_word *av) C_noret;
C_noret_decl(f_26621)
static void C_ccall f_26621(C_word c,C_word *av) C_noret;
C_noret_decl(f_26624)
static void C_ccall f_26624(C_word c,C_word *av) C_noret;
C_noret_decl(f_26627)
static void C_ccall f_26627(C_word c,C_word *av) C_noret;
C_noret_decl(f_26634)
static void C_ccall f_26634(C_word c,C_word *av) C_noret;
C_noret_decl(f_26638)
static void C_ccall f_26638(C_word c,C_word *av) C_noret;
C_noret_decl(f_26644)
static void C_ccall f_26644(C_word c,C_word *av) C_noret;
C_noret_decl(f_26649)
static void C_fcall f_26649(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_26659)
static void C_ccall f_26659(C_word c,C_word *av) C_noret;
C_noret_decl(f_26697)
static void C_fcall f_26697(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26700)
static void C_fcall f_26700(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26720)
static void C_fcall f_26720(C_word t0,C_word t1) C_noret;
C_noret_decl(f_26738)
static void C_ccall f_26738(C_word c,C_word *av) C_noret;
C_noret_decl(f_26872)
static void C_ccall f_26872(C_word c,C_word *av) C_noret;
C_noret_decl(f_26889)
static void C_ccall f_26889(C_word c,C_word *av) C_noret;
C_noret_decl(f_26904)
static void C_ccall f_26904(C_word c,C_word *av) C_noret;
C_noret_decl(f_26908)
static void C_ccall f_26908(C_word c,C_word *av) C_noret;
C_noret_decl(f_26921)
static void C_ccall f_26921(C_word c,C_word *av) C_noret;
C_noret_decl(f_26929)
static void C_ccall f_26929(C_word c,C_word *av) C_noret;
C_noret_decl(f_26932)
static void C_ccall f_26932(C_word c,C_word *av) C_noret;
C_noret_decl(f_26936)
static void C_ccall f_26936(C_word c,C_word *av) C_noret;
C_noret_decl(f_26975)
static void C_ccall f_26975(C_word c,C_word *av) C_noret;
C_noret_decl(f_26978)
static void C_ccall f_26978(C_word c,C_word *av) C_noret;
C_noret_decl(f_26985)
static void C_ccall f_26985(C_word c,C_word *av) C_noret;
C_noret_decl(f_26989)
static void C_ccall f_26989(C_word c,C_word *av) C_noret;
C_noret_decl(f_27015)
static void C_ccall f_27015(C_word c,C_word *av) C_noret;
C_noret_decl(f_27046)
static void C_ccall f_27046(C_word c,C_word *av) C_noret;
C_noret_decl(f_27049)
static void C_ccall f_27049(C_word c,C_word *av) C_noret;
C_noret_decl(f_27061)
static void C_ccall f_27061(C_word c,C_word *av) C_noret;
C_noret_decl(f_27064)
static void C_ccall f_27064(C_word c,C_word *av) C_noret;
C_noret_decl(f_27067)
static void C_ccall f_27067(C_word c,C_word *av) C_noret;
C_noret_decl(f_27092)
static void C_ccall f_27092(C_word c,C_word *av) C_noret;
C_noret_decl(f_27098)
static void C_ccall f_27098(C_word c,C_word *av) C_noret;
C_noret_decl(f_27102)
static void C_ccall f_27102(C_word c,C_word *av) C_noret;
C_noret_decl(f_27106)
static void C_ccall f_27106(C_word c,C_word *av) C_noret;
C_noret_decl(f_27119)
static void C_ccall f_27119(C_word c,C_word *av) C_noret;
C_noret_decl(f_27121)
static C_word C_fcall f_27121(C_word t0,C_word t1);
C_noret_decl(f_27127)
static C_word C_fcall f_27127(C_word t0);
C_noret_decl(f_27132)
static C_word C_fcall f_27132(C_word t0);
C_noret_decl(f_27167)
static void C_fcall f_27167(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_27173)
static void C_fcall f_27173(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27189)
static void C_fcall f_27189(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27211)
static void C_ccall f_27211(C_word c,C_word *av) C_noret;
C_noret_decl(f_27235)
static void C_ccall f_27235(C_word c,C_word *av) C_noret;
C_noret_decl(f_27247)
static void C_ccall f_27247(C_word c,C_word *av) C_noret;
C_noret_decl(f_27249)
static void C_ccall f_27249(C_word c,C_word *av) C_noret;
C_noret_decl(f_27268)
static void C_ccall f_27268(C_word c,C_word *av) C_noret;
C_noret_decl(f_27272)
static void C_ccall f_27272(C_word c,C_word *av) C_noret;
C_noret_decl(f_27284)
static void C_ccall f_27284(C_word c,C_word *av) C_noret;
C_noret_decl(f_27286)
static void C_fcall f_27286(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27330)
static void C_ccall f_27330(C_word c,C_word *av) C_noret;
C_noret_decl(f_27332)
static void C_fcall f_27332(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27366)
static C_word C_fcall f_27366(C_word t0);
C_noret_decl(f_27389)
static void C_ccall f_27389(C_word c,C_word *av) C_noret;
C_noret_decl(f_27396)
static void C_ccall f_27396(C_word c,C_word *av) C_noret;
C_noret_decl(f_27406)
static void C_ccall f_27406(C_word c,C_word *av) C_noret;
C_noret_decl(f_27408)
static void C_fcall f_27408(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27458)
static void C_ccall f_27458(C_word c,C_word *av) C_noret;
C_noret_decl(f_27460)
static void C_fcall f_27460(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27485)
static void C_ccall f_27485(C_word c,C_word *av) C_noret;
C_noret_decl(f_27494)
static void C_ccall f_27494(C_word c,C_word *av) C_noret;
C_noret_decl(f_27500)
static void C_ccall f_27500(C_word c,C_word *av) C_noret;
C_noret_decl(f_27504)
static void C_ccall f_27504(C_word c,C_word *av) C_noret;
C_noret_decl(f_27508)
static void C_fcall f_27508(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27516)
static void C_ccall f_27516(C_word c,C_word *av) C_noret;
C_noret_decl(f_27522)
static void C_fcall f_27522(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27553)
static void C_ccall f_27553(C_word c,C_word *av) C_noret;
C_noret_decl(f_27578)
static void C_fcall f_27578(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27603)
static void C_ccall f_27603(C_word c,C_word *av) C_noret;
C_noret_decl(f_27613)
static void C_ccall f_27613(C_word c,C_word *av) C_noret;
C_noret_decl(f_27618)
static void C_ccall f_27618(C_word c,C_word *av) C_noret;
C_noret_decl(f_27620)
static void C_ccall f_27620(C_word c,C_word *av) C_noret;
C_noret_decl(f_27627)
static void C_ccall f_27627(C_word c,C_word *av) C_noret;
C_noret_decl(f_27639)
static void C_ccall f_27639(C_word c,C_word *av) C_noret;
C_noret_decl(f_27647)
static void C_ccall f_27647(C_word c,C_word *av) C_noret;
C_noret_decl(f_27685)
static void C_ccall f_27685(C_word c,C_word *av) C_noret;
C_noret_decl(f_27689)
static void C_ccall f_27689(C_word c,C_word *av) C_noret;
C_noret_decl(f_27696)
static void C_ccall f_27696(C_word c,C_word *av) C_noret;
C_noret_decl(f_27699)
static void C_ccall f_27699(C_word c,C_word *av) C_noret;
C_noret_decl(f_27702)
static void C_ccall f_27702(C_word c,C_word *av) C_noret;
C_noret_decl(f_27703)
static void C_fcall f_27703(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27705)
static void C_fcall f_27705(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27709)
static void C_ccall f_27709(C_word c,C_word *av) C_noret;
C_noret_decl(f_27714)
static void C_ccall f_27714(C_word c,C_word *av) C_noret;
C_noret_decl(f_27726)
static void C_fcall f_27726(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27736)
static void C_ccall f_27736(C_word c,C_word *av) C_noret;
C_noret_decl(f_27748)
static void C_ccall f_27748(C_word c,C_word *av) C_noret;
C_noret_decl(f_27750)
static void C_fcall f_27750(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_27757)
static void C_ccall f_27757(C_word c,C_word *av) C_noret;
C_noret_decl(f_27760)
static void C_ccall f_27760(C_word c,C_word *av) C_noret;
C_noret_decl(f_27769)
static void C_ccall f_27769(C_word c,C_word *av) C_noret;
C_noret_decl(f_27772)
static void C_ccall f_27772(C_word c,C_word *av) C_noret;
C_noret_decl(f_27775)
static void C_ccall f_27775(C_word c,C_word *av) C_noret;
C_noret_decl(f_27790)
static void C_ccall f_27790(C_word c,C_word *av) C_noret;
C_noret_decl(f_27796)
static void C_ccall f_27796(C_word c,C_word *av) C_noret;
C_noret_decl(f_27804)
static void C_fcall f_27804(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27808)
static void C_ccall f_27808(C_word c,C_word *av) C_noret;
C_noret_decl(f_27811)
static void C_ccall f_27811(C_word c,C_word *av) C_noret;
C_noret_decl(f_27814)
static void C_ccall f_27814(C_word c,C_word *av) C_noret;
C_noret_decl(f_27827)
static void C_ccall f_27827(C_word c,C_word *av) C_noret;
C_noret_decl(f_27831)
static void C_ccall f_27831(C_word c,C_word *av) C_noret;
C_noret_decl(f_27852)
static void C_ccall f_27852(C_word c,C_word *av) C_noret;
C_noret_decl(f_27868)
static void C_ccall f_27868(C_word c,C_word *av) C_noret;
C_noret_decl(f_27871)
static void C_ccall f_27871(C_word c,C_word *av) C_noret;
C_noret_decl(f_27877)
static void C_ccall f_27877(C_word c,C_word *av) C_noret;
C_noret_decl(f_27899)
static void C_fcall f_27899(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_27904)
static void C_fcall f_27904(C_word t0,C_word t1) C_noret;
C_noret_decl(f_27939)
static void C_ccall f_27939(C_word c,C_word *av) C_noret;
C_noret_decl(f_27949)
static void C_ccall f_27949(C_word c,C_word *av) C_noret;
C_noret_decl(f_27952)
static void C_ccall f_27952(C_word c,C_word *av) C_noret;
C_noret_decl(f_27955)
static void C_ccall f_27955(C_word c,C_word *av) C_noret;
C_noret_decl(f_27958)
static void C_ccall f_27958(C_word c,C_word *av) C_noret;
C_noret_decl(f_27961)
static void C_ccall f_27961(C_word c,C_word *av) C_noret;
C_noret_decl(f_27964)
static void C_ccall f_27964(C_word c,C_word *av) C_noret;
C_noret_decl(f_27971)
static void C_ccall f_27971(C_word c,C_word *av) C_noret;
C_noret_decl(f_27974)
static void C_ccall f_27974(C_word c,C_word *av) C_noret;
C_noret_decl(f_27977)
static void C_ccall f_27977(C_word c,C_word *av) C_noret;
C_noret_decl(f_27988)
static void C_ccall f_27988(C_word c,C_word *av) C_noret;
C_noret_decl(f_28011)
static void C_ccall f_28011(C_word c,C_word *av) C_noret;
C_noret_decl(f_28022)
static void C_ccall f_28022(C_word c,C_word *av) C_noret;
C_noret_decl(f_28026)
static void C_ccall f_28026(C_word c,C_word *av) C_noret;
C_noret_decl(f_28048)
static void C_ccall f_28048(C_word c,C_word *av) C_noret;
C_noret_decl(f_28059)
static void C_ccall f_28059(C_word c,C_word *av) C_noret;
C_noret_decl(f_28063)
static void C_ccall f_28063(C_word c,C_word *av) C_noret;
C_noret_decl(f_28562)
static void C_ccall f_28562(C_word c,C_word *av) C_noret;
C_noret_decl(f_28573)
static void C_ccall f_28573(C_word c,C_word *av) C_noret;
C_noret_decl(f_28577)
static void C_ccall f_28577(C_word c,C_word *av) C_noret;
C_noret_decl(f_28694)
static void C_ccall f_28694(C_word c,C_word *av) C_noret;
C_noret_decl(f_28697)
static void C_ccall f_28697(C_word c,C_word *av) C_noret;
C_noret_decl(f_28700)
static void C_ccall f_28700(C_word c,C_word *av) C_noret;
C_noret_decl(f_28703)
static void C_ccall f_28703(C_word c,C_word *av) C_noret;
C_noret_decl(f_28708)
static void C_ccall f_28708(C_word c,C_word *av) C_noret;
C_noret_decl(f_28711)
static void C_ccall f_28711(C_word c,C_word *av) C_noret;
C_noret_decl(f_28714)
static void C_ccall f_28714(C_word c,C_word *av) C_noret;
C_noret_decl(f_28717)
static void C_ccall f_28717(C_word c,C_word *av) C_noret;
C_noret_decl(f_28720)
static void C_ccall f_28720(C_word c,C_word *av) C_noret;
C_noret_decl(f_28723)
static void C_ccall f_28723(C_word c,C_word *av) C_noret;
C_noret_decl(f_28726)
static void C_ccall f_28726(C_word c,C_word *av) C_noret;
C_noret_decl(f_28729)
static void C_ccall f_28729(C_word c,C_word *av) C_noret;
C_noret_decl(f_28732)
static void C_ccall f_28732(C_word c,C_word *av) C_noret;
C_noret_decl(f_28736)
static void C_ccall f_28736(C_word c,C_word *av) C_noret;
C_noret_decl(f_28738)
static void C_ccall f_28738(C_word c,C_word *av) C_noret;
C_noret_decl(f_28746)
static void C_ccall f_28746(C_word c,C_word *av) C_noret;
C_noret_decl(f_28748)
static void C_ccall f_28748(C_word c,C_word *av) C_noret;
C_noret_decl(f_28752)
static void C_ccall f_28752(C_word c,C_word *av) C_noret;
C_noret_decl(f_28754)
static void C_ccall f_28754(C_word c,C_word *av) C_noret;
C_noret_decl(f_28761)
static void C_ccall f_28761(C_word c,C_word *av) C_noret;
C_noret_decl(f_28771)
static void C_ccall f_28771(C_word c,C_word *av) C_noret;
C_noret_decl(f_28796)
static void C_ccall f_28796(C_word c,C_word *av) C_noret;
C_noret_decl(f_28799)
static void C_ccall f_28799(C_word c,C_word *av) C_noret;
C_noret_decl(f_28802)
static void C_ccall f_28802(C_word c,C_word *av) C_noret;
C_noret_decl(f_28805)
static void C_ccall f_28805(C_word c,C_word *av) C_noret;
C_noret_decl(f_28808)
static void C_ccall f_28808(C_word c,C_word *av) C_noret;
C_noret_decl(f_28818)
static void C_ccall f_28818(C_word c,C_word *av) C_noret;
C_noret_decl(f_28824)
static void C_ccall f_28824(C_word c,C_word *av) C_noret;
C_noret_decl(f_28828)
static void C_ccall f_28828(C_word c,C_word *av) C_noret;
C_noret_decl(f_28830)
static void C_ccall f_28830(C_word c,C_word *av) C_noret;
C_noret_decl(f_28840)
static void C_ccall f_28840(C_word c,C_word *av) C_noret;
C_noret_decl(f_28846)
static void C_ccall f_28846(C_word c,C_word *av) C_noret;
C_noret_decl(f_28850)
static void C_ccall f_28850(C_word c,C_word *av) C_noret;
C_noret_decl(f_28852)
static void C_ccall f_28852(C_word c,C_word *av) C_noret;
C_noret_decl(f_28857)
static void C_ccall f_28857(C_word c,C_word *av) C_noret;
C_noret_decl(f_28859)
static void C_ccall f_28859(C_word c,C_word *av) C_noret;
C_noret_decl(f_28862)
static void C_ccall f_28862(C_word c,C_word *av) C_noret;
C_noret_decl(f_28882)
static void C_ccall f_28882(C_word c,C_word *av) C_noret;
C_noret_decl(f_28888)
static void C_fcall f_28888(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_28898)
static void C_ccall f_28898(C_word c,C_word *av) C_noret;
C_noret_decl(f_28908)
static void C_ccall f_28908(C_word c,C_word *av) C_noret;
C_noret_decl(f_28943)
static void C_ccall f_28943(C_word c,C_word *av) C_noret;
C_noret_decl(f_28947)
static void C_ccall f_28947(C_word c,C_word *av) C_noret;
C_noret_decl(f_28952)
static void C_fcall f_28952(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_28962)
static void C_ccall f_28962(C_word c,C_word *av) C_noret;
C_noret_decl(f_28972)
static void C_ccall f_28972(C_word c,C_word *av) C_noret;
C_noret_decl(f_28981)
static void C_ccall f_28981(C_word c,C_word *av) C_noret;
C_noret_decl(f_28984)
static void C_ccall f_28984(C_word c,C_word *av) C_noret;
C_noret_decl(f_28987)
static void C_ccall f_28987(C_word c,C_word *av) C_noret;
C_noret_decl(f_28994)
static void C_ccall f_28994(C_word c,C_word *av) C_noret;
C_noret_decl(f_29001)
static void C_ccall f_29001(C_word c,C_word *av) C_noret;
C_noret_decl(f_29004)
static void C_ccall f_29004(C_word c,C_word *av) C_noret;
C_noret_decl(f_29008)
static void C_ccall f_29008(C_word c,C_word *av) C_noret;
C_noret_decl(f_29010)
static void C_ccall f_29010(C_word c,C_word *av) C_noret;
C_noret_decl(f_29013)
static void C_ccall f_29013(C_word c,C_word *av) C_noret;
C_noret_decl(f_29016)
static void C_ccall f_29016(C_word c,C_word *av) C_noret;
C_noret_decl(f_29019)
static void C_ccall f_29019(C_word c,C_word *av) C_noret;
C_noret_decl(f_29022)
static void C_ccall f_29022(C_word c,C_word *av) C_noret;
C_noret_decl(f_29025)
static void C_ccall f_29025(C_word c,C_word *av) C_noret;
C_noret_decl(f_29028)
static void C_ccall f_29028(C_word c,C_word *av) C_noret;
C_noret_decl(f_29031)
static void C_ccall f_29031(C_word c,C_word *av) C_noret;
C_noret_decl(f_29034)
static void C_ccall f_29034(C_word c,C_word *av) C_noret;
C_noret_decl(f_29037)
static void C_ccall f_29037(C_word c,C_word *av) C_noret;
C_noret_decl(f_29040)
static void C_ccall f_29040(C_word c,C_word *av) C_noret;
C_noret_decl(f_29044)
static void C_ccall f_29044(C_word c,C_word *av) C_noret;
C_noret_decl(f_29047)
static void C_ccall f_29047(C_word c,C_word *av) C_noret;
C_noret_decl(f_29063)
static void C_ccall f_29063(C_word c,C_word *av) C_noret;
C_noret_decl(f_29071)
static void C_ccall f_29071(C_word c,C_word *av) C_noret;
C_noret_decl(f_29074)
static void C_ccall f_29074(C_word c,C_word *av) C_noret;
C_noret_decl(f_29080)
static void C_ccall f_29080(C_word c,C_word *av) C_noret;
C_noret_decl(f_29089)
static void C_ccall f_29089(C_word c,C_word *av) C_noret;
C_noret_decl(f_29095)
static void C_ccall f_29095(C_word c,C_word *av) C_noret;
C_noret_decl(f_29104)
static void C_ccall f_29104(C_word c,C_word *av) C_noret;
C_noret_decl(f_29110)
static void C_ccall f_29110(C_word c,C_word *av) C_noret;
C_noret_decl(f_29116)
static void C_ccall f_29116(C_word c,C_word *av) C_noret;
C_noret_decl(f_29119)
static void C_ccall f_29119(C_word c,C_word *av) C_noret;
C_noret_decl(f_29125)
static void C_ccall f_29125(C_word c,C_word *av) C_noret;
C_noret_decl(f_29131)
static void C_ccall f_29131(C_word c,C_word *av) C_noret;
C_noret_decl(f_29134)
static void C_ccall f_29134(C_word c,C_word *av) C_noret;
C_noret_decl(f_29140)
static void C_ccall f_29140(C_word c,C_word *av) C_noret;
C_noret_decl(f_29179)
static void C_ccall f_29179(C_word c,C_word *av) C_noret;
C_noret_decl(f_29222)
static void C_ccall f_29222(C_word c,C_word *av) C_noret;
C_noret_decl(f_29229)
static void C_ccall f_29229(C_word c,C_word *av) C_noret;
C_noret_decl(f_29234)
static void C_fcall f_29234(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29250)
static void C_ccall f_29250(C_word c,C_word *av) C_noret;
C_noret_decl(f_29276)
static void C_ccall f_29276(C_word c,C_word *av) C_noret;
C_noret_decl(f_29279)
static void C_ccall f_29279(C_word c,C_word *av) C_noret;
C_noret_decl(f_29283)
static void C_ccall f_29283(C_word c,C_word *av) C_noret;
C_noret_decl(f_29286)
static void C_ccall f_29286(C_word c,C_word *av) C_noret;
C_noret_decl(f_29291)
static void C_ccall f_29291(C_word c,C_word *av) C_noret;
C_noret_decl(f_29293)
static void C_ccall f_29293(C_word c,C_word *av) C_noret;
C_noret_decl(f_29297)
static void C_ccall f_29297(C_word c,C_word *av) C_noret;
C_noret_decl(f_29324)
static void C_fcall f_29324(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29334)
static void C_ccall f_29334(C_word c,C_word *av) C_noret;
C_noret_decl(f_29343)
static void C_ccall f_29343(C_word c,C_word *av) C_noret;
C_noret_decl(f_29350)
static void C_ccall f_29350(C_word c,C_word *av) C_noret;
C_noret_decl(f_29354)
static void C_ccall f_29354(C_word c,C_word *av) C_noret;
C_noret_decl(f_29368)
static void C_fcall f_29368(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29372)
static void C_ccall f_29372(C_word c,C_word *av) C_noret;
C_noret_decl(f_29379)
static void C_ccall f_29379(C_word c,C_word *av) C_noret;
C_noret_decl(f_29381)
static void C_fcall f_29381(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29403)
static void C_ccall f_29403(C_word c,C_word *av) C_noret;
C_noret_decl(f_29410)
static void C_ccall f_29410(C_word c,C_word *av) C_noret;
C_noret_decl(f_29415)
static void C_fcall f_29415(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29419)
static void C_ccall f_29419(C_word c,C_word *av) C_noret;
C_noret_decl(f_29422)
static void C_ccall f_29422(C_word c,C_word *av) C_noret;
C_noret_decl(f_29425)
static void C_ccall f_29425(C_word c,C_word *av) C_noret;
C_noret_decl(f_29430)
static void C_fcall f_29430(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29434)
static void C_ccall f_29434(C_word c,C_word *av) C_noret;
C_noret_decl(f_29460)
static void C_ccall f_29460(C_word c,C_word *av) C_noret;
C_noret_decl(f_29473)
static void C_ccall f_29473(C_word c,C_word *av) C_noret;
C_noret_decl(f_29476)
static void C_ccall f_29476(C_word c,C_word *av) C_noret;
C_noret_decl(f_29485)
static void C_ccall f_29485(C_word c,C_word *av) C_noret;
C_noret_decl(f_29488)
static void C_ccall f_29488(C_word c,C_word *av) C_noret;
C_noret_decl(f_29491)
static void C_ccall f_29491(C_word c,C_word *av) C_noret;
C_noret_decl(f_29497)
static void C_ccall f_29497(C_word c,C_word *av) C_noret;
C_noret_decl(f_29504)
static void C_ccall f_29504(C_word c,C_word *av) C_noret;
C_noret_decl(f_29506)
static void C_fcall f_29506(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29519)
static void C_ccall f_29519(C_word c,C_word *av) C_noret;
C_noret_decl(f_29532)
static void C_ccall f_29532(C_word c,C_word *av) C_noret;
C_noret_decl(f_29535)
static void C_ccall f_29535(C_word c,C_word *av) C_noret;
C_noret_decl(f_29538)
static void C_ccall f_29538(C_word c,C_word *av) C_noret;
C_noret_decl(f_29545)
static void C_ccall f_29545(C_word c,C_word *av) C_noret;
C_noret_decl(f_29598)
static void C_ccall f_29598(C_word c,C_word *av) C_noret;
C_noret_decl(f_29601)
static void C_ccall f_29601(C_word c,C_word *av) C_noret;
C_noret_decl(f_29604)
static void C_ccall f_29604(C_word c,C_word *av) C_noret;
C_noret_decl(f_29606)
static void C_fcall f_29606(C_word t0,C_word t1) C_noret;
C_noret_decl(f_29610)
static void C_ccall f_29610(C_word c,C_word *av) C_noret;
C_noret_decl(f_29614)
static void C_ccall f_29614(C_word c,C_word *av) C_noret;
C_noret_decl(f_29620)
static void C_ccall f_29620(C_word c,C_word *av) C_noret;
C_noret_decl(f_29625)
static void C_fcall f_29625(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29629)
static void C_ccall f_29629(C_word c,C_word *av) C_noret;
C_noret_decl(f_29641)
static void C_ccall f_29641(C_word c,C_word *av) C_noret;
C_noret_decl(f_29653)
static void C_ccall f_29653(C_word c,C_word *av) C_noret;
C_noret_decl(f_29660)
static void C_ccall f_29660(C_word c,C_word *av) C_noret;
C_noret_decl(f_29666)
static void C_fcall f_29666(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_29680)
static void C_ccall f_29680(C_word c,C_word *av) C_noret;
C_noret_decl(f_29719)
static void C_ccall f_29719(C_word c,C_word *av) C_noret;
C_noret_decl(f_29738)
static void C_ccall f_29738(C_word c,C_word *av) C_noret;
C_noret_decl(f_29761)
static void C_ccall f_29761(C_word c,C_word *av) C_noret;
C_noret_decl(f_29770)
static void C_ccall f_29770(C_word c,C_word *av) C_noret;
C_noret_decl(f_29777)
static void C_ccall f_29777(C_word c,C_word *av) C_noret;
C_noret_decl(f_29794)
static void C_ccall f_29794(C_word c,C_word *av) C_noret;
C_noret_decl(f_29802)
static void C_ccall f_29802(C_word c,C_word *av) C_noret;
C_noret_decl(f_29813)
static void C_ccall f_29813(C_word c,C_word *av) C_noret;
C_noret_decl(f_29821)
static void C_ccall f_29821(C_word c,C_word *av) C_noret;
C_noret_decl(f_29828)
static void C_ccall f_29828(C_word c,C_word *av) C_noret;
C_noret_decl(f_29890)
static void C_ccall f_29890(C_word c,C_word *av) C_noret;
C_noret_decl(f_29897)
static void C_ccall f_29897(C_word c,C_word *av) C_noret;
C_noret_decl(f_29900)
static void C_ccall f_29900(C_word c,C_word *av) C_noret;
C_noret_decl(f_29910)
static void C_ccall f_29910(C_word c,C_word *av) C_noret;
C_noret_decl(f_29914)
static void C_ccall f_29914(C_word c,C_word *av) C_noret;
C_noret_decl(f_29918)
static void C_ccall f_29918(C_word c,C_word *av) C_noret;
C_noret_decl(f_29921)
static void C_ccall f_29921(C_word c,C_word *av) C_noret;
C_noret_decl(f_29929)
static void C_ccall f_29929(C_word c,C_word *av) C_noret;
C_noret_decl(f_29931)
static void C_ccall f_29931(C_word c,C_word *av) C_noret;
C_noret_decl(f_29940)
static void C_ccall f_29940(C_word c,C_word *av) C_noret;
C_noret_decl(f_29946)
static void C_ccall f_29946(C_word c,C_word *av) C_noret;
C_noret_decl(f_29957)
static void C_ccall f_29957(C_word c,C_word *av) C_noret;
C_noret_decl(f_29961)
static void C_ccall f_29961(C_word c,C_word *av) C_noret;
C_noret_decl(f_29963)
static void C_ccall f_29963(C_word c,C_word *av) C_noret;
C_noret_decl(f_29971)
static void C_ccall f_29971(C_word c,C_word *av) C_noret;
C_noret_decl(f_29983)
static void C_ccall f_29983(C_word c,C_word *av) C_noret;
C_noret_decl(f_29989)
static void C_fcall f_29989(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_29993)
static void C_ccall f_29993(C_word c,C_word *av) C_noret;
C_noret_decl(f_30001)
static void C_fcall f_30001(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_30019)
static void C_ccall f_30019(C_word c,C_word *av) C_noret;
C_noret_decl(f_30027)
static void C_ccall f_30027(C_word c,C_word *av) C_noret;
C_noret_decl(f_30031)
static void C_ccall f_30031(C_word c,C_word *av) C_noret;
C_noret_decl(f_30049)
static void C_ccall f_30049(C_word c,C_word *av) C_noret;
C_noret_decl(f_30056)
static void C_ccall f_30056(C_word c,C_word *av) C_noret;
C_noret_decl(f_30068)
static void C_ccall f_30068(C_word c,C_word *av) C_noret;
C_noret_decl(f_30076)
static void C_ccall f_30076(C_word c,C_word *av) C_noret;
C_noret_decl(f_30082)
static void C_fcall f_30082(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_30104)
static void C_ccall f_30104(C_word c,C_word *av) C_noret;
C_noret_decl(f_30108)
static void C_ccall f_30108(C_word c,C_word *av) C_noret;
C_noret_decl(f_30112)
static void C_ccall f_30112(C_word c,C_word *av) C_noret;
C_noret_decl(f_30114)
static void C_ccall f_30114(C_word c,C_word *av) C_noret;
C_noret_decl(f_30117)
static void C_ccall f_30117(C_word c,C_word *av) C_noret;
C_noret_decl(f_30120)
static void C_ccall f_30120(C_word c,C_word *av) C_noret;
C_noret_decl(f_30124)
static void C_ccall f_30124(C_word c,C_word *av) C_noret;
C_noret_decl(f_30127)
static void C_ccall f_30127(C_word c,C_word *av) C_noret;
C_noret_decl(f_30149)
static void C_ccall f_30149(C_word c,C_word *av) C_noret;
C_noret_decl(f_30155)
static void C_ccall f_30155(C_word c,C_word *av) C_noret;
C_noret_decl(f_30159)
static void C_ccall f_30159(C_word c,C_word *av) C_noret;
C_noret_decl(f_30176)
static void C_ccall f_30176(C_word c,C_word *av) C_noret;
C_noret_decl(f_30186)
static void C_ccall f_30186(C_word c,C_word *av) C_noret;
C_noret_decl(f_30190)
static void C_ccall f_30190(C_word c,C_word *av) C_noret;
C_noret_decl(f_30194)
static void C_ccall f_30194(C_word c,C_word *av) C_noret;
C_noret_decl(f_30206)
static void C_ccall f_30206(C_word c,C_word *av) C_noret;
C_noret_decl(f_30216)
static void C_ccall f_30216(C_word c,C_word *av) C_noret;
C_noret_decl(f_30225)
static void C_ccall f_30225(C_word c,C_word *av) C_noret;
C_noret_decl(f_30241)
static void C_ccall f_30241(C_word c,C_word *av) C_noret;
C_noret_decl(f_30245)
static void C_ccall f_30245(C_word c,C_word *av) C_noret;
C_noret_decl(f_30247)
static void C_ccall f_30247(C_word c,C_word *av) C_noret;
C_noret_decl(f_30253)
static void C_ccall f_30253(C_word c,C_word *av) C_noret;
C_noret_decl(f_30260)
static void C_ccall f_30260(C_word c,C_word *av) C_noret;
C_noret_decl(f_30265)
static void C_ccall f_30265(C_word c,C_word *av) C_noret;
C_noret_decl(f_30286)
static void C_ccall f_30286(C_word c,C_word *av) C_noret;
C_noret_decl(f_30296)
static void C_fcall f_30296(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_30306)
static void C_ccall f_30306(C_word c,C_word *av) C_noret;
C_noret_decl(f_30319)
static void C_ccall f_30319(C_word c,C_word *av) C_noret;
C_noret_decl(f_30323)
static void C_ccall f_30323(C_word c,C_word *av) C_noret;
C_noret_decl(f_30326)
static void C_ccall f_30326(C_word c,C_word *av) C_noret;
C_noret_decl(f_30334)
static void C_fcall f_30334(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_30344)
static void C_ccall f_30344(C_word c,C_word *av) C_noret;
C_noret_decl(f_30366)
static void C_ccall f_30366(C_word c,C_word *av) C_noret;
C_noret_decl(f_30370)
static void C_ccall f_30370(C_word c,C_word *av) C_noret;
C_noret_decl(f_30401)
static void C_ccall f_30401(C_word c,C_word *av) C_noret;
C_noret_decl(f_30404)
static void C_ccall f_30404(C_word c,C_word *av) C_noret;
C_noret_decl(f_30407)
static void C_ccall f_30407(C_word c,C_word *av) C_noret;
C_noret_decl(f_30413)
static void C_fcall f_30413(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_30426)
static void C_ccall f_30426(C_word c,C_word *av) C_noret;
C_noret_decl(f_30429)
static void C_ccall f_30429(C_word c,C_word *av) C_noret;
C_noret_decl(f_30438)
static void C_ccall f_30438(C_word c,C_word *av) C_noret;
C_noret_decl(f_30444)
static void C_ccall f_30444(C_word c,C_word *av) C_noret;
C_noret_decl(f_30450)
static void C_ccall f_30450(C_word c,C_word *av) C_noret;
C_noret_decl(f_30456)
static void C_ccall f_30456(C_word c,C_word *av) C_noret;
C_noret_decl(f_30462)
static void C_ccall f_30462(C_word c,C_word *av) C_noret;
C_noret_decl(f_30479)
static void C_ccall f_30479(C_word c,C_word *av) C_noret;
C_noret_decl(f_30485)
static void C_ccall f_30485(C_word c,C_word *av) C_noret;
C_noret_decl(f_30500)
static void C_ccall f_30500(C_word c,C_word *av) C_noret;
C_noret_decl(f_30504)
static void C_ccall f_30504(C_word c,C_word *av) C_noret;
C_noret_decl(f_30508)
static void C_ccall f_30508(C_word c,C_word *av) C_noret;
C_noret_decl(f_30512)
static void C_ccall f_30512(C_word c,C_word *av) C_noret;
C_noret_decl(f_30533)
static void C_ccall f_30533(C_word c,C_word *av) C_noret;
C_noret_decl(f_30535)
static void C_ccall f_30535(C_word c,C_word *av) C_noret;
C_noret_decl(f_30541)
static void C_fcall f_30541(C_word t0,C_word t1) C_noret;
C_noret_decl(f_30545)
static void C_ccall f_30545(C_word c,C_word *av) C_noret;
C_noret_decl(f_30554)
static void C_ccall f_30554(C_word c,C_word *av) C_noret;
C_noret_decl(f_30563)
static void C_ccall f_30563(C_word c,C_word *av) C_noret;
C_noret_decl(f_30606)
static void C_ccall f_30606(C_word c,C_word *av) C_noret;
C_noret_decl(f_30628)
static void C_ccall f_30628(C_word c,C_word *av) C_noret;
C_noret_decl(f_30641)
static void C_ccall f_30641(C_word c,C_word *av) C_noret;
C_noret_decl(f_30666)
static void C_ccall f_30666(C_word c,C_word *av) C_noret;
C_noret_decl(f_30682)
static void C_ccall f_30682(C_word c,C_word *av) C_noret;
C_noret_decl(f_30698)
static void C_ccall f_30698(C_word c,C_word *av) C_noret;
C_noret_decl(f_30714)
static void C_ccall f_30714(C_word c,C_word *av) C_noret;
C_noret_decl(f_30730)
static void C_ccall f_30730(C_word c,C_word *av) C_noret;
C_noret_decl(f_30746)
static void C_ccall f_30746(C_word c,C_word *av) C_noret;
C_noret_decl(f_30762)
static void C_ccall f_30762(C_word c,C_word *av) C_noret;
C_noret_decl(f_30778)
static void C_ccall f_30778(C_word c,C_word *av) C_noret;
C_noret_decl(f_30794)
static void C_ccall f_30794(C_word c,C_word *av) C_noret;
C_noret_decl(f_30810)
static void C_ccall f_30810(C_word c,C_word *av) C_noret;
C_noret_decl(f_30817)
static void C_ccall f_30817(C_word c,C_word *av) C_noret;
C_noret_decl(f_30858)
static void C_ccall f_30858(C_word c,C_word *av) C_noret;
C_noret_decl(f_30870)
static void C_ccall f_30870(C_word c,C_word *av) C_noret;
C_noret_decl(f_30876)
static void C_ccall f_30876(C_word c,C_word *av) C_noret;
C_noret_decl(f_30895)
static void C_ccall f_30895(C_word c,C_word *av) C_noret;
C_noret_decl(f_30897)
static void C_ccall f_30897(C_word c,C_word *av) C_noret;
C_noret_decl(f_30920)
static C_word C_fcall f_30920(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_30966)
static void C_ccall f_30966(C_word c,C_word *av) C_noret;
C_noret_decl(f_30968)
static void C_ccall f_30968(C_word c,C_word *av) C_noret;
C_noret_decl(f_30975)
static void C_fcall f_30975(C_word t0,C_word t1) C_noret;
C_noret_decl(f_30987)
static void C_fcall f_30987(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_31031)
static void C_ccall f_31031(C_word c,C_word *av) C_noret;
C_noret_decl(f_31046)
static void C_fcall f_31046(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31054)
static void C_ccall f_31054(C_word c,C_word *av) C_noret;
C_noret_decl(f_31060)
static void C_fcall f_31060(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_31068)
static void C_ccall f_31068(C_word c,C_word *av) C_noret;
C_noret_decl(f_31072)
static void C_ccall f_31072(C_word c,C_word *av) C_noret;
C_noret_decl(f_31080)
static void C_ccall f_31080(C_word c,C_word *av) C_noret;
C_noret_decl(f_31082)
static void C_fcall f_31082(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_31092)
static void C_ccall f_31092(C_word c,C_word *av) C_noret;
C_noret_decl(f_31099)
static void C_ccall f_31099(C_word c,C_word *av) C_noret;
C_noret_decl(f_31103)
static void C_ccall f_31103(C_word c,C_word *av) C_noret;
C_noret_decl(f_31114)
static void C_ccall f_31114(C_word c,C_word *av) C_noret;
C_noret_decl(f_31121)
static void C_ccall f_31121(C_word c,C_word *av) C_noret;
C_noret_decl(f_31125)
static void C_ccall f_31125(C_word c,C_word *av) C_noret;
C_noret_decl(f_31136)
static void C_ccall f_31136(C_word c,C_word *av) C_noret;
C_noret_decl(f_31143)
static void C_ccall f_31143(C_word c,C_word *av) C_noret;
C_noret_decl(f_31147)
static void C_ccall f_31147(C_word c,C_word *av) C_noret;
C_noret_decl(f_31152)
static void C_ccall f_31152(C_word c,C_word *av) C_noret;
C_noret_decl(f_31158)
static void C_ccall f_31158(C_word c,C_word *av) C_noret;
C_noret_decl(f_31161)
static void C_ccall f_31161(C_word c,C_word *av) C_noret;
C_noret_decl(f_31164)
static void C_ccall f_31164(C_word c,C_word *av) C_noret;
C_noret_decl(f_31170)
static void C_ccall f_31170(C_word c,C_word *av) C_noret;
C_noret_decl(f_31179)
static void C_ccall f_31179(C_word c,C_word *av) C_noret;
C_noret_decl(f_31188)
static void C_ccall f_31188(C_word c,C_word *av) C_noret;
C_noret_decl(f_31194)
static void C_ccall f_31194(C_word c,C_word *av) C_noret;
C_noret_decl(f_31197)
static void C_ccall f_31197(C_word c,C_word *av) C_noret;
C_noret_decl(f_31200)
static void C_ccall f_31200(C_word c,C_word *av) C_noret;
C_noret_decl(f_31212)
static void C_ccall f_31212(C_word c,C_word *av) C_noret;
C_noret_decl(f_31215)
static void C_ccall f_31215(C_word c,C_word *av) C_noret;
C_noret_decl(f_31218)
static void C_ccall f_31218(C_word c,C_word *av) C_noret;
C_noret_decl(f_31221)
static void C_ccall f_31221(C_word c,C_word *av) C_noret;
C_noret_decl(f_31233)
static void C_ccall f_31233(C_word c,C_word *av) C_noret;
C_noret_decl(f_31236)
static void C_ccall f_31236(C_word c,C_word *av) C_noret;
C_noret_decl(f_31239)
static void C_ccall f_31239(C_word c,C_word *av) C_noret;
C_noret_decl(f_31242)
static void C_ccall f_31242(C_word c,C_word *av) C_noret;
C_noret_decl(f_31251)
static void C_ccall f_31251(C_word c,C_word *av) C_noret;
C_noret_decl(f_31254)
static void C_ccall f_31254(C_word c,C_word *av) C_noret;
C_noret_decl(f_31267)
static void C_ccall f_31267(C_word c,C_word *av) C_noret;
C_noret_decl(f_31268)
static void C_ccall f_31268(C_word c,C_word *av) C_noret;
C_noret_decl(f_31273)
static void C_ccall f_31273(C_word c,C_word *av) C_noret;
C_noret_decl(f_31274)
static void C_ccall f_31274(C_word c,C_word *av) C_noret;
C_noret_decl(f_31279)
static void C_ccall f_31279(C_word c,C_word *av) C_noret;
C_noret_decl(f_31280)
static void C_ccall f_31280(C_word c,C_word *av) C_noret;
C_noret_decl(f_31285)
static void C_ccall f_31285(C_word c,C_word *av) C_noret;
C_noret_decl(f_31286)
static void C_ccall f_31286(C_word c,C_word *av) C_noret;
C_noret_decl(f_31291)
static void C_ccall f_31291(C_word c,C_word *av) C_noret;
C_noret_decl(f_31292)
static void C_ccall f_31292(C_word c,C_word *av) C_noret;
C_noret_decl(f_31297)
static void C_fcall f_31297(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31299)
static void C_ccall f_31299(C_word c,C_word *av) C_noret;
C_noret_decl(f_31309)
static void C_ccall f_31309(C_word c,C_word *av) C_noret;
C_noret_decl(f_31312)
static void C_ccall f_31312(C_word c,C_word *av) C_noret;
C_noret_decl(f_31315)
static void C_ccall f_31315(C_word c,C_word *av) C_noret;
C_noret_decl(f_31318)
static void C_ccall f_31318(C_word c,C_word *av) C_noret;
C_noret_decl(f_31320)
static void C_fcall f_31320(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31334)
static void C_ccall f_31334(C_word c,C_word *av) C_noret;
C_noret_decl(f_31342)
static void C_ccall f_31342(C_word c,C_word *av) C_noret;
C_noret_decl(f_31346)
static void C_ccall f_31346(C_word c,C_word *av) C_noret;
C_noret_decl(f_31350)
static void C_ccall f_31350(C_word c,C_word *av) C_noret;
C_noret_decl(f_31354)
static void C_ccall f_31354(C_word c,C_word *av) C_noret;
C_noret_decl(f_31360)
static void C_ccall f_31360(C_word c,C_word *av) C_noret;
C_noret_decl(f_31367)
static void C_ccall f_31367(C_word c,C_word *av) C_noret;
C_noret_decl(f_31371)
static void C_ccall f_31371(C_word c,C_word *av) C_noret;
C_noret_decl(f_31375)
static void C_ccall f_31375(C_word c,C_word *av) C_noret;
C_noret_decl(f_31379)
static void C_ccall f_31379(C_word c,C_word *av) C_noret;
C_noret_decl(f_31399)
static void C_ccall f_31399(C_word c,C_word *av) C_noret;
C_noret_decl(f_31418)
static void C_ccall f_31418(C_word c,C_word *av) C_noret;
C_noret_decl(f_31421)
static void C_ccall f_31421(C_word c,C_word *av) C_noret;
C_noret_decl(f_31424)
static void C_ccall f_31424(C_word c,C_word *av) C_noret;
C_noret_decl(f_31427)
static void C_ccall f_31427(C_word c,C_word *av) C_noret;
C_noret_decl(f_31436)
static void C_ccall f_31436(C_word c,C_word *av) C_noret;
C_noret_decl(f_31446)
static void C_ccall f_31446(C_word c,C_word *av) C_noret;
C_noret_decl(f_31468)
static void C_ccall f_31468(C_word c,C_word *av) C_noret;
C_noret_decl(f_31474)
static void C_fcall f_31474(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_31494)
static void C_ccall f_31494(C_word c,C_word *av) C_noret;
C_noret_decl(f_31509)
static void C_ccall f_31509(C_word c,C_word *av) C_noret;
C_noret_decl(f_31513)
static void C_ccall f_31513(C_word c,C_word *av) C_noret;
C_noret_decl(f_31536)
static void C_ccall f_31536(C_word c,C_word *av) C_noret;
C_noret_decl(f_31540)
static void C_ccall f_31540(C_word c,C_word *av) C_noret;
C_noret_decl(f_31542)
static void C_ccall f_31542(C_word c,C_word *av) C_noret;
C_noret_decl(f_31572)
static void C_ccall f_31572(C_word c,C_word *av) C_noret;
C_noret_decl(f_31575)
static void C_ccall f_31575(C_word c,C_word *av) C_noret;
C_noret_decl(f_31577)
static void C_ccall f_31577(C_word c,C_word *av) C_noret;
C_noret_decl(f_31595)
static void C_ccall f_31595(C_word c,C_word *av) C_noret;
C_noret_decl(f_31602)
static void C_ccall f_31602(C_word c,C_word *av) C_noret;
C_noret_decl(f_31624)
static void C_ccall f_31624(C_word c,C_word *av) C_noret;
C_noret_decl(f_31629)
static void C_fcall f_31629(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31644)
static void C_ccall f_31644(C_word c,C_word *av) C_noret;
C_noret_decl(f_31647)
static void C_ccall f_31647(C_word c,C_word *av) C_noret;
C_noret_decl(f_31650)
static void C_ccall f_31650(C_word c,C_word *av) C_noret;
C_noret_decl(f_31653)
static void C_ccall f_31653(C_word c,C_word *av) C_noret;
C_noret_decl(f_31656)
static void C_ccall f_31656(C_word c,C_word *av) C_noret;
C_noret_decl(f_31659)
static void C_ccall f_31659(C_word c,C_word *av) C_noret;
C_noret_decl(f_31662)
static void C_fcall f_31662(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31665)
static void C_fcall f_31665(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31668)
static void C_fcall f_31668(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31671)
static void C_fcall f_31671(C_word t0,C_word t1) C_noret;
C_noret_decl(f_31679)
static void C_ccall f_31679(C_word c,C_word *av) C_noret;
C_noret_decl(f_31682)
static void C_ccall f_31682(C_word c,C_word *av) C_noret;
C_noret_decl(f_31687)
static void C_ccall f_31687(C_word c,C_word *av) C_noret;
C_noret_decl(f_31693)
static void C_ccall f_31693(C_word c,C_word *av) C_noret;
C_noret_decl(f_31706)
static void C_ccall f_31706(C_word c,C_word *av) C_noret;
C_noret_decl(f_31708)
static void C_fcall f_31708(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_31731)
static void C_ccall f_31731(C_word c,C_word *av) C_noret;
C_noret_decl(f_31738)
static void C_ccall f_31738(C_word c,C_word *av) C_noret;
C_noret_decl(f_31742)
static void C_ccall f_31742(C_word c,C_word *av) C_noret;
C_noret_decl(f_31744)
static void C_fcall f_31744(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_31773)
static void C_ccall f_31773(C_word c,C_word *av) C_noret;
C_noret_decl(f_31775)
static void C_fcall f_31775(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_31800)
static void C_ccall f_31800(C_word c,C_word *av) C_noret;
C_noret_decl(f_31809)
static void C_ccall f_31809(C_word c,C_word *av) C_noret;
C_noret_decl(f_31812)
static void C_ccall f_31812(C_word c,C_word *av) C_noret;
C_noret_decl(f_31818)
static void C_fcall f_31818(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_31842)
static void C_ccall f_31842(C_word c,C_word *av) C_noret;
C_noret_decl(f_31849)
static void C_ccall f_31849(C_word c,C_word *av) C_noret;
C_noret_decl(f_31853)
static void C_ccall f_31853(C_word c,C_word *av) C_noret;
C_noret_decl(f_31865)
static void C_ccall f_31865(C_word c,C_word *av) C_noret;
C_noret_decl(f_31873)
static void C_ccall f_31873(C_word c,C_word *av) C_noret;
C_noret_decl(f_31877)
static void C_ccall f_31877(C_word c,C_word *av) C_noret;
C_noret_decl(f_31886)
static void C_ccall f_31886(C_word c,C_word *av) C_noret;
C_noret_decl(f_31895)
static void C_ccall f_31895(C_word c,C_word *av) C_noret;
C_noret_decl(f_31905)
static void C_ccall f_31905(C_word c,C_word *av) C_noret;
C_noret_decl(f_31913)
static void C_ccall f_31913(C_word c,C_word *av) C_noret;
C_noret_decl(f_31917)
static void C_ccall f_31917(C_word c,C_word *av) C_noret;
C_noret_decl(f_31921)
static void C_ccall f_31921(C_word c,C_word *av) C_noret;
C_noret_decl(f_31927)
static void C_ccall f_31927(C_word c,C_word *av) C_noret;
C_noret_decl(f_31931)
static void C_ccall f_31931(C_word c,C_word *av) C_noret;
C_noret_decl(f_31935)
static void C_ccall f_31935(C_word c,C_word *av) C_noret;
C_noret_decl(f_31957)
static void C_ccall f_31957(C_word c,C_word *av) C_noret;
C_noret_decl(f_31961)
static void C_ccall f_31961(C_word c,C_word *av) C_noret;
C_noret_decl(f_31965)
static void C_ccall f_31965(C_word c,C_word *av) C_noret;
C_noret_decl(f_31969)
static void C_ccall f_31969(C_word c,C_word *av) C_noret;
C_noret_decl(f_31973)
static void C_ccall f_31973(C_word c,C_word *av) C_noret;
C_noret_decl(f_31981)
static void C_ccall f_31981(C_word c,C_word *av) C_noret;
C_noret_decl(f_31989)
static void C_fcall f_31989(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_32014)
static void C_ccall f_32014(C_word c,C_word *av) C_noret;
C_noret_decl(f_32031)
static void C_ccall f_32031(C_word c,C_word *av) C_noret;
C_noret_decl(f_32035)
static void C_ccall f_32035(C_word c,C_word *av) C_noret;
C_noret_decl(f_32038)
static void C_ccall f_32038(C_word c,C_word *av) C_noret;
C_noret_decl(f_32041)
static void C_ccall f_32041(C_word c,C_word *av) C_noret;
C_noret_decl(f_32051)
static void C_ccall f_32051(C_word c,C_word *av) C_noret;
C_noret_decl(f_32054)
static void C_ccall f_32054(C_word c,C_word *av) C_noret;
C_noret_decl(f_32056)
static void C_ccall f_32056(C_word c,C_word *av) C_noret;
C_noret_decl(f_32073)
static C_word C_fcall f_32073(C_word t0);
C_noret_decl(f_32100)
static void C_ccall f_32100(C_word c,C_word *av) C_noret;
C_noret_decl(f_32109)
static void C_ccall f_32109(C_word c,C_word *av) C_noret;
C_noret_decl(f_32129)
static void C_ccall f_32129(C_word c,C_word *av) C_noret;
C_noret_decl(f_32133)
static void C_ccall f_32133(C_word c,C_word *av) C_noret;
C_noret_decl(f_32137)
static void C_ccall f_32137(C_word c,C_word *av) C_noret;
C_noret_decl(f_32141)
static void C_ccall f_32141(C_word c,C_word *av) C_noret;
C_noret_decl(f_32145)
static void C_ccall f_32145(C_word c,C_word *av) C_noret;
C_noret_decl(f_32149)
static void C_ccall f_32149(C_word c,C_word *av) C_noret;
C_noret_decl(f_32153)
static void C_ccall f_32153(C_word c,C_word *av) C_noret;
C_noret_decl(f_32155)
static void C_ccall f_32155(C_word c,C_word *av) C_noret;
C_noret_decl(f_32164)
static void C_ccall f_32164(C_word c,C_word *av) C_noret;
C_noret_decl(f_32174)
static void C_ccall f_32174(C_word c,C_word *av) C_noret;
C_noret_decl(f_32199)
static void C_ccall f_32199(C_word c,C_word *av) C_noret;
C_noret_decl(f_32202)
static void C_ccall f_32202(C_word c,C_word *av) C_noret;
C_noret_decl(f_32204)
static void C_ccall f_32204(C_word c,C_word *av) C_noret;
C_noret_decl(f_32220)
static void C_fcall f_32220(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_32258)
static void C_ccall f_32258(C_word c,C_word *av) C_noret;
C_noret_decl(f_32282)
static void C_ccall f_32282(C_word c,C_word *av) C_noret;
C_noret_decl(f_32286)
static void C_ccall f_32286(C_word c,C_word *av) C_noret;
C_noret_decl(f_32288)
static void C_ccall f_32288(C_word c,C_word *av) C_noret;
C_noret_decl(f_32292)
static void C_ccall f_32292(C_word c,C_word *av) C_noret;
C_noret_decl(f_32295)
static void C_ccall f_32295(C_word c,C_word *av) C_noret;
C_noret_decl(f_32308)
static void C_ccall f_32308(C_word c,C_word *av) C_noret;
C_noret_decl(f_32313)
static void C_ccall f_32313(C_word c,C_word *av) C_noret;
C_noret_decl(f_32319)
static void C_ccall f_32319(C_word c,C_word *av) C_noret;
C_noret_decl(f_32323)
static void C_ccall f_32323(C_word c,C_word *av) C_noret;
C_noret_decl(f_32332)
static void C_ccall f_32332(C_word c,C_word *av) C_noret;
C_noret_decl(f_32335)
static void C_ccall f_32335(C_word c,C_word *av) C_noret;
C_noret_decl(f_32338)
static void C_ccall f_32338(C_word c,C_word *av) C_noret;
C_noret_decl(f_32341)
static void C_ccall f_32341(C_word c,C_word *av) C_noret;
C_noret_decl(f_32344)
static void C_ccall f_32344(C_word c,C_word *av) C_noret;
C_noret_decl(f_32346)
static void C_ccall f_32346(C_word c,C_word *av) C_noret;
C_noret_decl(f_32356)
static void C_ccall f_32356(C_word c,C_word *av) C_noret;
C_noret_decl(f_32368)
static void C_ccall f_32368(C_word c,C_word *av) C_noret;
C_noret_decl(f_32376)
static void C_fcall f_32376(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_32386)
static void C_ccall f_32386(C_word c,C_word *av) C_noret;
C_noret_decl(f_32402)
static void C_ccall f_32402(C_word c,C_word *av) C_noret;
C_noret_decl(f_32408)
static void C_ccall f_32408(C_word c,C_word *av) C_noret;
C_noret_decl(f_32411)
static void C_ccall f_32411(C_word c,C_word *av) C_noret;
C_noret_decl(f_32414)
static void C_ccall f_32414(C_word c,C_word *av) C_noret;
C_noret_decl(f_32415)
static void C_fcall f_32415(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_32419)
static void C_ccall f_32419(C_word c,C_word *av) C_noret;
C_noret_decl(f_32425)
static void C_ccall f_32425(C_word c,C_word *av) C_noret;
C_noret_decl(f_32429)
static void C_ccall f_32429(C_word c,C_word *av) C_noret;
C_noret_decl(f_32431)
static void C_fcall f_32431(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_32441)
static void C_ccall f_32441(C_word c,C_word *av) C_noret;
C_noret_decl(f_32458)
static void C_ccall f_32458(C_word c,C_word *av) C_noret;
C_noret_decl(f_32461)
static void C_ccall f_32461(C_word c,C_word *av) C_noret;
C_noret_decl(f_32465)
static void C_ccall f_32465(C_word c,C_word *av) C_noret;
C_noret_decl(f_32470)
static void C_ccall f_32470(C_word c,C_word *av) C_noret;
C_noret_decl(f_32476)
static void C_ccall f_32476(C_word c,C_word *av) C_noret;
C_noret_decl(f_32483)
static void C_ccall f_32483(C_word c,C_word *av) C_noret;
C_noret_decl(f_32492)
static void C_ccall f_32492(C_word c,C_word *av) C_noret;
C_noret_decl(f_32500)
static void C_ccall f_32500(C_word c,C_word *av) C_noret;
C_noret_decl(f_32525)
static void C_ccall f_32525(C_word c,C_word *av) C_noret;
C_noret_decl(f_32543)
static void C_ccall f_32543(C_word c,C_word *av) C_noret;
C_noret_decl(f_32547)
static void C_ccall f_32547(C_word c,C_word *av) C_noret;
C_noret_decl(f_32562)
static void C_ccall f_32562(C_word c,C_word *av) C_noret;
C_noret_decl(f_32566)
static void C_ccall f_32566(C_word c,C_word *av) C_noret;
C_noret_decl(f_32581)
static void C_ccall f_32581(C_word c,C_word *av) C_noret;
C_noret_decl(f_32584)
static void C_ccall f_32584(C_word c,C_word *av) C_noret;
C_noret_decl(f_32587)
static void C_ccall f_32587(C_word c,C_word *av) C_noret;
C_noret_decl(f_32597)
static void C_fcall f_32597(C_word t0,C_word t1) C_noret;
C_noret_decl(f_32628)
static void C_ccall f_32628(C_word c,C_word *av) C_noret;
C_noret_decl(f_32652)
static void C_ccall f_32652(C_word c,C_word *av) C_noret;
C_noret_decl(f_32662)
static void C_ccall f_32662(C_word c,C_word *av) C_noret;
C_noret_decl(f_32671)
static void C_ccall f_32671(C_word c,C_word *av) C_noret;
C_noret_decl(f_32712)
static void C_ccall f_32712(C_word c,C_word *av) C_noret;
C_noret_decl(f_32731)
static void C_ccall f_32731(C_word c,C_word *av) C_noret;
C_noret_decl(f_32740)
static void C_ccall f_32740(C_word c,C_word *av) C_noret;
C_noret_decl(f_32744)
static void C_ccall f_32744(C_word c,C_word *av) C_noret;
C_noret_decl(f_32749)
static void C_ccall f_32749(C_word c,C_word *av) C_noret;
C_noret_decl(f_32759)
static void C_ccall f_32759(C_word c,C_word *av) C_noret;
C_noret_decl(f_32769)
static void C_ccall f_32769(C_word c,C_word *av) C_noret;
C_noret_decl(f_32779)
static void C_ccall f_32779(C_word c,C_word *av) C_noret;
C_noret_decl(f_32789)
static void C_ccall f_32789(C_word c,C_word *av) C_noret;
C_noret_decl(f_32799)
static void C_ccall f_32799(C_word c,C_word *av) C_noret;
C_noret_decl(f_32809)
static void C_ccall f_32809(C_word c,C_word *av) C_noret;
C_noret_decl(f_32819)
static void C_ccall f_32819(C_word c,C_word *av) C_noret;
C_noret_decl(f_32829)
static void C_ccall f_32829(C_word c,C_word *av) C_noret;
C_noret_decl(f_32839)
static void C_ccall f_32839(C_word c,C_word *av) C_noret;
C_noret_decl(f_32849)
static void C_ccall f_32849(C_word c,C_word *av) C_noret;
C_noret_decl(f_32859)
static void C_ccall f_32859(C_word c,C_word *av) C_noret;
C_noret_decl(f_32869)
static void C_ccall f_32869(C_word c,C_word *av) C_noret;
C_noret_decl(f_32879)
static void C_ccall f_32879(C_word c,C_word *av) C_noret;
C_noret_decl(f_32895)
static void C_ccall f_32895(C_word c,C_word *av) C_noret;
C_noret_decl(f_32903)
static void C_ccall f_32903(C_word c,C_word *av) C_noret;
C_noret_decl(f_32919)
static void C_ccall f_32919(C_word c,C_word *av) C_noret;
C_noret_decl(f_32935)
static void C_ccall f_32935(C_word c,C_word *av) C_noret;
C_noret_decl(f_32945)
static void C_ccall f_32945(C_word c,C_word *av) C_noret;
C_noret_decl(f_32955)
static void C_ccall f_32955(C_word c,C_word *av) C_noret;
C_noret_decl(f_32974)
static void C_ccall f_32974(C_word c,C_word *av) C_noret;
C_noret_decl(f_32990)
static void C_ccall f_32990(C_word c,C_word *av) C_noret;
C_noret_decl(f_33003)
static void C_ccall f_33003(C_word c,C_word *av) C_noret;
C_noret_decl(f_33009)
static void C_ccall f_33009(C_word c,C_word *av) C_noret;
C_noret_decl(f_33019)
static void C_ccall f_33019(C_word c,C_word *av) C_noret;
C_noret_decl(f_33035)
static void C_ccall f_33035(C_word c,C_word *av) C_noret;
C_noret_decl(f_33039)
static void C_ccall f_33039(C_word c,C_word *av) C_noret;
C_noret_decl(f_33042)
static void C_ccall f_33042(C_word c,C_word *av) C_noret;
C_noret_decl(f_33048)
static void C_ccall f_33048(C_word c,C_word *av) C_noret;
C_noret_decl(f_33058)
static void C_ccall f_33058(C_word c,C_word *av) C_noret;
C_noret_decl(f_33074)
static void C_ccall f_33074(C_word c,C_word *av) C_noret;
C_noret_decl(f_33078)
static void C_ccall f_33078(C_word c,C_word *av) C_noret;
C_noret_decl(f_33081)
static void C_ccall f_33081(C_word c,C_word *av) C_noret;
C_noret_decl(f_33084)
static void C_ccall f_33084(C_word c,C_word *av) C_noret;
C_noret_decl(f_33087)
static void C_ccall f_33087(C_word c,C_word *av) C_noret;
C_noret_decl(f_33093)
static void C_ccall f_33093(C_word c,C_word *av) C_noret;
C_noret_decl(f_33096)
static void C_ccall f_33096(C_word c,C_word *av) C_noret;
C_noret_decl(f_33099)
static void C_ccall f_33099(C_word c,C_word *av) C_noret;
C_noret_decl(f_33109)
static void C_fcall f_33109(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_33125)
static void C_ccall f_33125(C_word c,C_word *av) C_noret;
C_noret_decl(f_33136)
static void C_ccall f_33136(C_word c,C_word *av) C_noret;
C_noret_decl(f_33159)
static void C_ccall f_33159(C_word c,C_word *av) C_noret;
C_noret_decl(f_33163)
static void C_ccall f_33163(C_word c,C_word *av) C_noret;
C_noret_decl(f_33197)
static void C_ccall f_33197(C_word c,C_word *av) C_noret;
C_noret_decl(f_33201)
static void C_ccall f_33201(C_word c,C_word *av) C_noret;
C_noret_decl(f_33204)
static void C_fcall f_33204(C_word t0,C_word t1) C_noret;
C_noret_decl(f_33217)
static void C_fcall f_33217(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_33250)
static void C_ccall f_33250(C_word c,C_word *av) C_noret;
C_noret_decl(f_33265)
static void C_ccall f_33265(C_word c,C_word *av) C_noret;
C_noret_decl(f_33269)
static void C_ccall f_33269(C_word c,C_word *av) C_noret;
C_noret_decl(f_33282)
static void C_ccall f_33282(C_word c,C_word *av) C_noret;
C_noret_decl(f_33296)
static void C_ccall f_33296(C_word c,C_word *av) C_noret;
C_noret_decl(f_33304)
static void C_ccall f_33304(C_word c,C_word *av) C_noret;
C_noret_decl(f_33308)
static void C_ccall f_33308(C_word c,C_word *av) C_noret;
C_noret_decl(f_33319)
static void C_ccall f_33319(C_word c,C_word *av) C_noret;
C_noret_decl(f_33323)
static void C_ccall f_33323(C_word c,C_word *av) C_noret;
C_noret_decl(f_33337)
static void C_ccall f_33337(C_word c,C_word *av) C_noret;
C_noret_decl(f_33369)
static void C_ccall f_33369(C_word c,C_word *av) C_noret;
C_noret_decl(f_8836)
static void C_ccall f_8836(C_word c,C_word *av) C_noret;
C_noret_decl(f_8838)
static void C_ccall f_8838(C_word c,C_word *av) C_noret;
C_noret_decl(f_8841)
static void C_ccall f_8841(C_word c,C_word *av) C_noret;
C_noret_decl(f_8844)
static void C_ccall f_8844(C_word c,C_word *av) C_noret;
C_noret_decl(f_8847)
static void C_ccall f_8847(C_word c,C_word *av) C_noret;
C_noret_decl(f_8850)
static void C_ccall f_8850(C_word c,C_word *av) C_noret;
C_noret_decl(f_8853)
static void C_ccall f_8853(C_word c,C_word *av) C_noret;
C_noret_decl(f_8856)
static void C_ccall f_8856(C_word c,C_word *av) C_noret;
C_noret_decl(f_8859)
static void C_ccall f_8859(C_word c,C_word *av) C_noret;
C_noret_decl(f_8862)
static void C_ccall f_8862(C_word c,C_word *av) C_noret;
C_noret_decl(f_8865)
static void C_ccall f_8865(C_word c,C_word *av) C_noret;
C_noret_decl(f_8868)
static void C_ccall f_8868(C_word c,C_word *av) C_noret;
C_noret_decl(f_8871)
static void C_ccall f_8871(C_word c,C_word *av) C_noret;
C_noret_decl(f_8874)
static void C_ccall f_8874(C_word c,C_word *av) C_noret;
C_noret_decl(f_8877)
static void C_ccall f_8877(C_word c,C_word *av) C_noret;
C_noret_decl(f_8880)
static void C_ccall f_8880(C_word c,C_word *av) C_noret;
C_noret_decl(f_8883)
static void C_ccall f_8883(C_word c,C_word *av) C_noret;
C_noret_decl(f_8886)
static void C_ccall f_8886(C_word c,C_word *av) C_noret;
C_noret_decl(f_8889)
static void C_ccall f_8889(C_word c,C_word *av) C_noret;
C_noret_decl(f_8892)
static void C_ccall f_8892(C_word c,C_word *av) C_noret;
C_noret_decl(f_8906)
static void C_ccall f_8906(C_word c,C_word *av) C_noret;
C_noret_decl(f_8913)
static void C_ccall f_8913(C_word c,C_word *av) C_noret;
C_noret_decl(f_8920)
static void C_ccall f_8920(C_word c,C_word *av) C_noret;
C_noret_decl(f_8934)
static void C_ccall f_8934(C_word c,C_word *av) C_noret;
C_noret_decl(f_8941)
static void C_ccall f_8941(C_word c,C_word *av) C_noret;
C_noret_decl(f_8955)
static void C_ccall f_8955(C_word c,C_word *av) C_noret;
C_noret_decl(f_8969)
static void C_ccall f_8969(C_word c,C_word *av) C_noret;
C_noret_decl(f_8987)
static void C_ccall f_8987(C_word c,C_word *av) C_noret;
C_noret_decl(f_8998)
static void C_ccall f_8998(C_word c,C_word *av) C_noret;
C_noret_decl(f_9009)
static void C_ccall f_9009(C_word c,C_word *av) C_noret;
C_noret_decl(f_9016)
static void C_ccall f_9016(C_word c,C_word *av) C_noret;
C_noret_decl(f_9027)
static void C_ccall f_9027(C_word c,C_word *av) C_noret;
C_noret_decl(f_9031)
static void C_ccall f_9031(C_word c,C_word *av) C_noret;
C_noret_decl(f_9038)
static void C_ccall f_9038(C_word c,C_word *av) C_noret;
C_noret_decl(f_9056)
static void C_ccall f_9056(C_word c,C_word *av) C_noret;
C_noret_decl(f_9067)
static void C_ccall f_9067(C_word c,C_word *av) C_noret;
C_noret_decl(f_9078)
static void C_ccall f_9078(C_word c,C_word *av) C_noret;
C_noret_decl(f_9085)
static void C_ccall f_9085(C_word c,C_word *av) C_noret;
C_noret_decl(f_9103)
static void C_ccall f_9103(C_word c,C_word *av) C_noret;
C_noret_decl(f_9114)
static void C_ccall f_9114(C_word c,C_word *av) C_noret;
C_noret_decl(f_9132)
static void C_ccall f_9132(C_word c,C_word *av) C_noret;
C_noret_decl(f_9138)
static void C_ccall f_9138(C_word c,C_word *av) C_noret;
C_noret_decl(f_9141)
static void C_ccall f_9141(C_word c,C_word *av) C_noret;
C_noret_decl(f_9144)
static void C_ccall f_9144(C_word c,C_word *av) C_noret;
C_noret_decl(f_9147)
static void C_ccall f_9147(C_word c,C_word *av) C_noret;
C_noret_decl(f_9150)
static void C_ccall f_9150(C_word c,C_word *av) C_noret;
C_noret_decl(f_9156)
static void C_fcall f_9156(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9189)
static void C_ccall f_9189(C_word c,C_word *av) C_noret;
C_noret_decl(f_9192)
static void C_ccall f_9192(C_word c,C_word *av) C_noret;
C_noret_decl(f_9195)
static void C_ccall f_9195(C_word c,C_word *av) C_noret;
C_noret_decl(f_9198)
static void C_ccall f_9198(C_word c,C_word *av) C_noret;
C_noret_decl(f_9201)
static void C_ccall f_9201(C_word c,C_word *av) C_noret;
C_noret_decl(f_9204)
static void C_ccall f_9204(C_word c,C_word *av) C_noret;
C_noret_decl(f_9207)
static void C_ccall f_9207(C_word c,C_word *av) C_noret;
C_noret_decl(f_9210)
static void C_ccall f_9210(C_word c,C_word *av) C_noret;
C_noret_decl(f_9213)
static void C_ccall f_9213(C_word c,C_word *av) C_noret;
C_noret_decl(f_9216)
static void C_ccall f_9216(C_word c,C_word *av) C_noret;
C_noret_decl(f_9219)
static void C_ccall f_9219(C_word c,C_word *av) C_noret;
C_noret_decl(f_9222)
static void C_ccall f_9222(C_word c,C_word *av) C_noret;
C_noret_decl(f_9225)
static void C_ccall f_9225(C_word c,C_word *av) C_noret;
C_noret_decl(f_9229)
static void C_ccall f_9229(C_word c,C_word *av) C_noret;
C_noret_decl(f_9232)
static void C_ccall f_9232(C_word c,C_word *av) C_noret;
C_noret_decl(f_9238)
static void C_ccall f_9238(C_word c,C_word *av) C_noret;
C_noret_decl(f_9241)
static void C_ccall f_9241(C_word c,C_word *av) C_noret;
C_noret_decl(f_9244)
static void C_ccall f_9244(C_word c,C_word *av) C_noret;
C_noret_decl(f_9247)
static void C_ccall f_9247(C_word c,C_word *av) C_noret;
C_noret_decl(f_9250)
static void C_ccall f_9250(C_word c,C_word *av) C_noret;
C_noret_decl(f_9258)
static void C_ccall f_9258(C_word c,C_word *av) C_noret;
C_noret_decl(f_9262)
static void C_ccall f_9262(C_word c,C_word *av) C_noret;
C_noret_decl(f_9265)
static void C_ccall f_9265(C_word c,C_word *av) C_noret;
C_noret_decl(f_9268)
static void C_ccall f_9268(C_word c,C_word *av) C_noret;
C_noret_decl(f_9271)
static void C_ccall f_9271(C_word c,C_word *av) C_noret;
C_noret_decl(f_9274)
static void C_ccall f_9274(C_word c,C_word *av) C_noret;
C_noret_decl(f_9277)
static void C_ccall f_9277(C_word c,C_word *av) C_noret;
C_noret_decl(f_9280)
static void C_ccall f_9280(C_word c,C_word *av) C_noret;
C_noret_decl(f_9283)
static void C_ccall f_9283(C_word c,C_word *av) C_noret;
C_noret_decl(f_9287)
static void C_ccall f_9287(C_word c,C_word *av) C_noret;
C_noret_decl(f_9290)
static void C_ccall f_9290(C_word c,C_word *av) C_noret;
C_noret_decl(f_9293)
static void C_ccall f_9293(C_word c,C_word *av) C_noret;
C_noret_decl(f_9296)
static void C_ccall f_9296(C_word c,C_word *av) C_noret;
C_noret_decl(f_9299)
static void C_ccall f_9299(C_word c,C_word *av) C_noret;
C_noret_decl(f_9307)
static void C_ccall f_9307(C_word c,C_word *av) C_noret;
C_noret_decl(f_9310)
static void C_ccall f_9310(C_word c,C_word *av) C_noret;
C_noret_decl(f_9317)
static void C_ccall f_9317(C_word c,C_word *av) C_noret;
C_noret_decl(f_9321)
static void C_ccall f_9321(C_word c,C_word *av) C_noret;
C_noret_decl(f_9324)
static void C_ccall f_9324(C_word c,C_word *av) C_noret;
C_noret_decl(f_9327)
static void C_ccall f_9327(C_word c,C_word *av) C_noret;
C_noret_decl(f_9330)
static void C_ccall f_9330(C_word c,C_word *av) C_noret;
C_noret_decl(f_9333)
static void C_ccall f_9333(C_word c,C_word *av) C_noret;
C_noret_decl(f_9336)
static void C_ccall f_9336(C_word c,C_word *av) C_noret;
C_noret_decl(f_9339)
static void C_ccall f_9339(C_word c,C_word *av) C_noret;
C_noret_decl(f_9345)
static void C_ccall f_9345(C_word c,C_word *av) C_noret;
C_noret_decl(f_9356)
static void C_ccall f_9356(C_word c,C_word *av) C_noret;
C_noret_decl(f_9362)
static void C_ccall f_9362(C_word c,C_word *av) C_noret;
C_noret_decl(f_9368)
static void C_ccall f_9368(C_word c,C_word *av) C_noret;
C_noret_decl(f_9374)
static void C_ccall f_9374(C_word c,C_word *av) C_noret;
C_noret_decl(f_9380)
static void C_ccall f_9380(C_word c,C_word *av) C_noret;
C_noret_decl(f_9386)
static void C_ccall f_9386(C_word c,C_word *av) C_noret;
C_noret_decl(f_9393)
static void C_ccall f_9393(C_word c,C_word *av) C_noret;
C_noret_decl(f_9399)
static void C_ccall f_9399(C_word c,C_word *av) C_noret;
C_noret_decl(f_9415)
static void C_ccall f_9415(C_word c,C_word *av) C_noret;
C_noret_decl(f_9426)
static void C_ccall f_9426(C_word c,C_word *av) C_noret;
C_noret_decl(f_9432)
static void C_ccall f_9432(C_word c,C_word *av) C_noret;
C_noret_decl(f_9438)
static void C_ccall f_9438(C_word c,C_word *av) C_noret;
C_noret_decl(f_9444)
static void C_ccall f_9444(C_word c,C_word *av) C_noret;
C_noret_decl(f_9450)
static void C_ccall f_9450(C_word c,C_word *av) C_noret;
C_noret_decl(f_9459)
static void C_ccall f_9459(C_word c,C_word *av) C_noret;
C_noret_decl(f_9462)
static void C_ccall f_9462(C_word c,C_word *av) C_noret;
C_noret_decl(f_9465)
static void C_ccall f_9465(C_word c,C_word *av) C_noret;
C_noret_decl(f_9468)
static void C_ccall f_9468(C_word c,C_word *av) C_noret;
C_noret_decl(f_9471)
static void C_ccall f_9471(C_word c,C_word *av) C_noret;
C_noret_decl(f_9474)
static void C_ccall f_9474(C_word c,C_word *av) C_noret;
C_noret_decl(f_9478)
static void C_ccall f_9478(C_word c,C_word *av) C_noret;
C_noret_decl(f_9484)
static void C_ccall f_9484(C_word c,C_word *av) C_noret;
C_noret_decl(f_9490)
static void C_ccall f_9490(C_word c,C_word *av) C_noret;
C_noret_decl(f_9525)
static void C_ccall f_9525(C_word c,C_word *av) C_noret;
C_noret_decl(f_9528)
static void C_ccall f_9528(C_word c,C_word *av) C_noret;
C_noret_decl(f_9531)
static void C_ccall f_9531(C_word c,C_word *av) C_noret;
C_noret_decl(f_9539)
static void C_ccall f_9539(C_word c,C_word *av) C_noret;
C_noret_decl(f_9545)
static void C_ccall f_9545(C_word c,C_word *av) C_noret;
C_noret_decl(f_9552)
static void C_ccall f_9552(C_word c,C_word *av) C_noret;
C_noret_decl(f_9567)
static void C_ccall f_9567(C_word c,C_word *av) C_noret;
C_noret_decl(f_9590)
static void C_ccall f_9590(C_word c,C_word *av) C_noret;
C_noret_decl(f_9596)
static void C_ccall f_9596(C_word c,C_word *av) C_noret;
C_noret_decl(f_9602)
static void C_ccall f_9602(C_word c,C_word *av) C_noret;
C_noret_decl(f_9609)
static void C_ccall f_9609(C_word c,C_word *av) C_noret;
C_noret_decl(f_9614)
static void C_ccall f_9614(C_word c,C_word *av) C_noret;
C_noret_decl(f_9617)
static void C_ccall f_9617(C_word c,C_word *av) C_noret;
C_noret_decl(f_9626)
static void C_fcall f_9626(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9644)
static void C_ccall f_9644(C_word c,C_word *av) C_noret;
C_noret_decl(f_9654)
static void C_ccall f_9654(C_word c,C_word *av) C_noret;
C_noret_decl(f_9663)
static void C_fcall f_9663(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9681)
static void C_ccall f_9681(C_word c,C_word *av) C_noret;
C_noret_decl(f_9694)
static void C_ccall f_9694(C_word c,C_word *av) C_noret;
C_noret_decl(f_9701)
static void C_ccall f_9701(C_word c,C_word *av) C_noret;
C_noret_decl(f_9708)
static void C_ccall f_9708(C_word c,C_word *av) C_noret;
C_noret_decl(f_9719)
static void C_ccall f_9719(C_word c,C_word *av) C_noret;
C_noret_decl(f_9726)
static void C_ccall f_9726(C_word c,C_word *av) C_noret;
C_noret_decl(f_9738)
static void C_ccall f_9738(C_word c,C_word *av) C_noret;
C_noret_decl(f_9741)
static void C_ccall f_9741(C_word c,C_word *av) C_noret;
C_noret_decl(f_9743)
static void C_ccall f_9743(C_word c,C_word *av) C_noret;
C_noret_decl(f_9749)
static void C_fcall f_9749(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9765)
static void C_ccall f_9765(C_word c,C_word *av) C_noret;
C_noret_decl(f_9774)
static void C_ccall f_9774(C_word c,C_word *av) C_noret;
C_noret_decl(f_9776)
static void C_ccall f_9776(C_word c,C_word *av) C_noret;
C_noret_decl(f_9782)
static void C_fcall f_9782(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9795)
static void C_ccall f_9795(C_word c,C_word *av) C_noret;
C_noret_decl(f_9811)
static void C_ccall f_9811(C_word c,C_word *av) C_noret;
C_noret_decl(f_9822)
static void C_ccall f_9822(C_word c,C_word *av) C_noret;
C_noret_decl(f_9824)
static void C_ccall f_9824(C_word c,C_word *av) C_noret;
C_noret_decl(f_9832)
static void C_ccall f_9832(C_word c,C_word *av) C_noret;
C_noret_decl(f_9834)
static void C_ccall f_9834(C_word c,C_word *av) C_noret;
C_noret_decl(f_9840)
static void C_ccall f_9840(C_word c,C_word *av) C_noret;
C_noret_decl(f_9842)
static void C_ccall f_9842(C_word c,C_word *av) C_noret;
C_noret_decl(f_9850)
static void C_ccall f_9850(C_word c,C_word *av) C_noret;
C_noret_decl(f_9852)
static void C_ccall f_9852(C_word c,C_word *av) C_noret;
C_noret_decl(f_9855)
static void C_ccall f_9855(C_word c,C_word *av) C_noret;
C_noret_decl(f_9863)
static void C_ccall f_9863(C_word c,C_word *av) C_noret;
C_noret_decl(f_9869)
static void C_ccall f_9869(C_word c,C_word *av) C_noret;
C_noret_decl(f_9877)
static void C_ccall f_9877(C_word c,C_word *av) C_noret;
C_noret_decl(f_9888)
static void C_ccall f_9888(C_word c,C_word *av) C_noret;
C_noret_decl(f_9900)
static void C_fcall f_9900(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9914)
static void C_ccall f_9914(C_word c,C_word *av) C_noret;
C_noret_decl(f_9922)
static void C_ccall f_9922(C_word c,C_word *av) C_noret;
C_noret_decl(f_9925)
static void C_ccall f_9925(C_word c,C_word *av) C_noret;
C_noret_decl(f_9927)
static void C_ccall f_9927(C_word c,C_word *av) C_noret;
C_noret_decl(f_9929)
static void C_ccall f_9929(C_word c,C_word *av) C_noret;
C_noret_decl(f_9935)
static void C_fcall f_9935(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9954)
static void C_ccall f_9954(C_word c,C_word *av) C_noret;
C_noret_decl(f_9971)
static void C_ccall f_9971(C_word c,C_word *av) C_noret;
C_noret_decl(f_9979)
static void C_ccall f_9979(C_word c,C_word *av) C_noret;
C_noret_decl(f_9993)
static void C_ccall f_9993(C_word c,C_word *av) C_noret;
C_noret_decl(f_9999)
static void C_fcall f_9999(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(C_library_toplevel)
C_externexport void C_ccall C_library_toplevel(C_word c,C_word *av) C_noret;

C_noret_decl(trf_10073)
static void C_ccall trf_10073(C_word c,C_word *av) C_noret;
static void C_ccall trf_10073(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10073(t0,t1,t2);}

C_noret_decl(trf_10109)
static void C_ccall trf_10109(C_word c,C_word *av) C_noret;
static void C_ccall trf_10109(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10109(t0,t1,t2);}

C_noret_decl(trf_10138)
static void C_ccall trf_10138(C_word c,C_word *av) C_noret;
static void C_ccall trf_10138(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10138(t0,t1,t2,t3);}

C_noret_decl(trf_10185)
static void C_ccall trf_10185(C_word c,C_word *av) C_noret;
static void C_ccall trf_10185(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10185(t0,t1,t2);}

C_noret_decl(trf_10239)
static void C_ccall trf_10239(C_word c,C_word *av) C_noret;
static void C_ccall trf_10239(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10239(t0,t1,t2,t3);}

C_noret_decl(trf_10317)
static void C_ccall trf_10317(C_word c,C_word *av) C_noret;
static void C_ccall trf_10317(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10317(t0,t1);}

C_noret_decl(trf_10355)
static void C_ccall trf_10355(C_word c,C_word *av) C_noret;
static void C_ccall trf_10355(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10355(t0,t1,t2);}

C_noret_decl(trf_10405)
static void C_ccall trf_10405(C_word c,C_word *av) C_noret;
static void C_ccall trf_10405(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10405(t0,t1,t2);}

C_noret_decl(trf_10516)
static void C_ccall trf_10516(C_word c,C_word *av) C_noret;
static void C_ccall trf_10516(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10516(t0,t1);}

C_noret_decl(trf_10547)
static void C_ccall trf_10547(C_word c,C_word *av) C_noret;
static void C_ccall trf_10547(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10547(t0,t1,t2);}

C_noret_decl(trf_10624)
static void C_ccall trf_10624(C_word c,C_word *av) C_noret;
static void C_ccall trf_10624(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10624(t0,t1,t2);}

C_noret_decl(trf_11250)
static void C_ccall trf_11250(C_word c,C_word *av) C_noret;
static void C_ccall trf_11250(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11250(t0,t1,t2,t3);}

C_noret_decl(trf_11299)
static void C_ccall trf_11299(C_word c,C_word *av) C_noret;
static void C_ccall trf_11299(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11299(t0,t1);}

C_noret_decl(trf_11506)
static void C_ccall trf_11506(C_word c,C_word *av) C_noret;
static void C_ccall trf_11506(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11506(t0,t1,t2);}

C_noret_decl(trf_11525)
static void C_ccall trf_11525(C_word c,C_word *av) C_noret;
static void C_ccall trf_11525(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11525(t0,t1,t2);}

C_noret_decl(trf_11579)
static void C_ccall trf_11579(C_word c,C_word *av) C_noret;
static void C_ccall trf_11579(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11579(t0,t1,t2,t3);}

C_noret_decl(trf_11675)
static void C_ccall trf_11675(C_word c,C_word *av) C_noret;
static void C_ccall trf_11675(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_11675(t0,t1,t2,t3);}

C_noret_decl(trf_11833)
static void C_ccall trf_11833(C_word c,C_word *av) C_noret;
static void C_ccall trf_11833(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11833(t0,t1);}

C_noret_decl(trf_11842)
static void C_ccall trf_11842(C_word c,C_word *av) C_noret;
static void C_ccall trf_11842(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11842(t0,t1);}

C_noret_decl(trf_12125)
static void C_ccall trf_12125(C_word c,C_word *av) C_noret;
static void C_ccall trf_12125(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12125(t0,t1,t2,t3);}

C_noret_decl(trf_12214)
static void C_ccall trf_12214(C_word c,C_word *av) C_noret;
static void C_ccall trf_12214(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_12214(t0,t1,t2,t3);}

C_noret_decl(trf_12235)
static void C_ccall trf_12235(C_word c,C_word *av) C_noret;
static void C_ccall trf_12235(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_12235(t0,t1,t2,t3,t4);}

C_noret_decl(trf_12397)
static void C_ccall trf_12397(C_word c,C_word *av) C_noret;
static void C_ccall trf_12397(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12397(t0,t1);}

C_noret_decl(trf_13097)
static void C_ccall trf_13097(C_word c,C_word *av) C_noret;
static void C_ccall trf_13097(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13097(t0,t1,t2);}

C_noret_decl(trf_13456)
static void C_ccall trf_13456(C_word c,C_word *av) C_noret;
static void C_ccall trf_13456(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13456(t0,t1,t2,t3);}

C_noret_decl(trf_13473)
static void C_ccall trf_13473(C_word c,C_word *av) C_noret;
static void C_ccall trf_13473(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13473(t0,t1,t2,t3);}

C_noret_decl(trf_13640)
static void C_ccall trf_13640(C_word c,C_word *av) C_noret;
static void C_ccall trf_13640(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13640(t0,t1,t2,t3);}

C_noret_decl(trf_14122)
static void C_ccall trf_14122(C_word c,C_word *av) C_noret;
static void C_ccall trf_14122(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14122(t0,t1,t2);}

C_noret_decl(trf_14125)
static void C_ccall trf_14125(C_word c,C_word *av) C_noret;
static void C_ccall trf_14125(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_14125(t0,t1,t2,t3);}

C_noret_decl(trf_14304)
static void C_ccall trf_14304(C_word c,C_word *av) C_noret;
static void C_ccall trf_14304(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_14304(t0,t1,t2,t3,t4);}

C_noret_decl(trf_14348)
static void C_ccall trf_14348(C_word c,C_word *av) C_noret;
static void C_ccall trf_14348(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_14348(t0,t1,t2,t3,t4);}

C_noret_decl(trf_14611)
static void C_ccall trf_14611(C_word c,C_word *av) C_noret;
static void C_ccall trf_14611(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14611(t0,t1);}

C_noret_decl(trf_14617)
static void C_ccall trf_14617(C_word c,C_word *av) C_noret;
static void C_ccall trf_14617(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14617(t0,t1);}

C_noret_decl(trf_14673)
static void C_ccall trf_14673(C_word c,C_word *av) C_noret;
static void C_ccall trf_14673(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14673(t0,t1);}

C_noret_decl(trf_14679)
static void C_ccall trf_14679(C_word c,C_word *av) C_noret;
static void C_ccall trf_14679(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14679(t0,t1);}

C_noret_decl(trf_15152)
static void C_ccall trf_15152(C_word c,C_word *av) C_noret;
static void C_ccall trf_15152(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15152(t0,t1);}

C_noret_decl(trf_15187)
static void C_ccall trf_15187(C_word c,C_word *av) C_noret;
static void C_ccall trf_15187(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15187(t0,t1,t2,t3);}

C_noret_decl(trf_15297)
static void C_ccall trf_15297(C_word c,C_word *av) C_noret;
static void C_ccall trf_15297(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15297(t0,t1,t2,t3);}

C_noret_decl(trf_15339)
static void C_ccall trf_15339(C_word c,C_word *av) C_noret;
static void C_ccall trf_15339(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15339(t0,t1,t2);}

C_noret_decl(trf_15353)
static void C_ccall trf_15353(C_word c,C_word *av) C_noret;
static void C_ccall trf_15353(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15353(t0,t1,t2);}

C_noret_decl(trf_15507)
static void C_ccall trf_15507(C_word c,C_word *av) C_noret;
static void C_ccall trf_15507(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15507(t0,t1);}

C_noret_decl(trf_15603)
static void C_ccall trf_15603(C_word c,C_word *av) C_noret;
static void C_ccall trf_15603(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15603(t0,t1,t2,t3);}

C_noret_decl(trf_15699)
static void C_ccall trf_15699(C_word c,C_word *av) C_noret;
static void C_ccall trf_15699(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15699(t0,t1,t2,t3);}

C_noret_decl(trf_15764)
static void C_ccall trf_15764(C_word c,C_word *av) C_noret;
static void C_ccall trf_15764(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15764(t0,t1,t2,t3);}

C_noret_decl(trf_15968)
static void C_ccall trf_15968(C_word c,C_word *av) C_noret;
static void C_ccall trf_15968(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15968(t0,t1);}

C_noret_decl(trf_16029)
static void C_ccall trf_16029(C_word c,C_word *av) C_noret;
static void C_ccall trf_16029(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16029(t0,t1,t2);}

C_noret_decl(trf_16072)
static void C_ccall trf_16072(C_word c,C_word *av) C_noret;
static void C_ccall trf_16072(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_16072(t0,t1,t2,t3,t4);}

C_noret_decl(trf_16090)
static void C_ccall trf_16090(C_word c,C_word *av) C_noret;
static void C_ccall trf_16090(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_16090(t0,t1,t2,t3);}

C_noret_decl(trf_16170)
static void C_ccall trf_16170(C_word c,C_word *av) C_noret;
static void C_ccall trf_16170(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16170(t0,t1,t2);}

C_noret_decl(trf_16176)
static void C_ccall trf_16176(C_word c,C_word *av) C_noret;
static void C_ccall trf_16176(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16176(t0,t1,t2);}

C_noret_decl(trf_16239)
static void C_ccall trf_16239(C_word c,C_word *av) C_noret;
static void C_ccall trf_16239(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16239(t0,t1);}

C_noret_decl(trf_16278)
static void C_ccall trf_16278(C_word c,C_word *av) C_noret;
static void C_ccall trf_16278(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16278(t0,t1,t2);}

C_noret_decl(trf_16284)
static void C_ccall trf_16284(C_word c,C_word *av) C_noret;
static void C_ccall trf_16284(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16284(t0,t1,t2);}

C_noret_decl(trf_16328)
static void C_ccall trf_16328(C_word c,C_word *av) C_noret;
static void C_ccall trf_16328(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_16328(t0,t1,t2,t3,t4);}

C_noret_decl(trf_16384)
static void C_ccall trf_16384(C_word c,C_word *av) C_noret;
static void C_ccall trf_16384(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16384(t0,t1,t2);}

C_noret_decl(trf_16399)
static void C_ccall trf_16399(C_word c,C_word *av) C_noret;
static void C_ccall trf_16399(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16399(t0,t1);}

C_noret_decl(trf_16442)
static void C_ccall trf_16442(C_word c,C_word *av) C_noret;
static void C_ccall trf_16442(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_16442(t0,t1,t2,t3,t4);}

C_noret_decl(trf_16461)
static void C_ccall trf_16461(C_word c,C_word *av) C_noret;
static void C_ccall trf_16461(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16461(t0,t1);}

C_noret_decl(trf_16473)
static void C_ccall trf_16473(C_word c,C_word *av) C_noret;
static void C_ccall trf_16473(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16473(t0,t1);}

C_noret_decl(trf_16500)
static void C_ccall trf_16500(C_word c,C_word *av) C_noret;
static void C_ccall trf_16500(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16500(t0,t1);}

C_noret_decl(trf_16656)
static void C_ccall trf_16656(C_word c,C_word *av) C_noret;
static void C_ccall trf_16656(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_16656(t0,t1,t2,t3);}

C_noret_decl(trf_16663)
static void C_ccall trf_16663(C_word c,C_word *av) C_noret;
static void C_ccall trf_16663(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16663(t0,t1);}

C_noret_decl(trf_16734)
static void C_ccall trf_16734(C_word c,C_word *av) C_noret;
static void C_ccall trf_16734(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16734(t0,t1);}

C_noret_decl(trf_17002)
static void C_ccall trf_17002(C_word c,C_word *av) C_noret;
static void C_ccall trf_17002(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17002(t0,t1,t2);}

C_noret_decl(trf_17017)
static void C_ccall trf_17017(C_word c,C_word *av) C_noret;
static void C_ccall trf_17017(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17017(t0,t1);}

C_noret_decl(trf_17075)
static void C_ccall trf_17075(C_word c,C_word *av) C_noret;
static void C_ccall trf_17075(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17075(t0,t1);}

C_noret_decl(trf_17511)
static void C_ccall trf_17511(C_word c,C_word *av) C_noret;
static void C_ccall trf_17511(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_17511(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_17796)
static void C_ccall trf_17796(C_word c,C_word *av) C_noret;
static void C_ccall trf_17796(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_17796(t0,t1,t2,t3,t4);}

C_noret_decl(trf_17823)
static void C_ccall trf_17823(C_word c,C_word *av) C_noret;
static void C_ccall trf_17823(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17823(t0,t1,t2);}

C_noret_decl(trf_17864)
static void C_ccall trf_17864(C_word c,C_word *av) C_noret;
static void C_ccall trf_17864(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_17864(t0,t1,t2,t3);}

C_noret_decl(trf_18101)
static void C_ccall trf_18101(C_word c,C_word *av) C_noret;
static void C_ccall trf_18101(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18101(t0,t1,t2);}

C_noret_decl(trf_18363)
static void C_ccall trf_18363(C_word c,C_word *av) C_noret;
static void C_ccall trf_18363(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18363(t0,t1,t2);}

C_noret_decl(trf_18582)
static void C_ccall trf_18582(C_word c,C_word *av) C_noret;
static void C_ccall trf_18582(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_18582(t0,t1,t2,t3);}

C_noret_decl(trf_18683)
static void C_ccall trf_18683(C_word c,C_word *av) C_noret;
static void C_ccall trf_18683(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18683(t0,t1,t2);}

C_noret_decl(trf_18891)
static void C_ccall trf_18891(C_word c,C_word *av) C_noret;
static void C_ccall trf_18891(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18891(t0,t1,t2);}

C_noret_decl(trf_18929)
static void C_ccall trf_18929(C_word c,C_word *av) C_noret;
static void C_ccall trf_18929(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18929(t0,t1,t2);}

C_noret_decl(trf_18977)
static void C_ccall trf_18977(C_word c,C_word *av) C_noret;
static void C_ccall trf_18977(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18977(t0,t1,t2);}

C_noret_decl(trf_19038)
static void C_ccall trf_19038(C_word c,C_word *av) C_noret;
static void C_ccall trf_19038(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19038(t0,t1,t2);}

C_noret_decl(trf_19068)
static void C_ccall trf_19068(C_word c,C_word *av) C_noret;
static void C_ccall trf_19068(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19068(t0,t1,t2);}

C_noret_decl(trf_19123)
static void C_ccall trf_19123(C_word c,C_word *av) C_noret;
static void C_ccall trf_19123(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19123(t0,t1,t2);}

C_noret_decl(trf_19164)
static void C_ccall trf_19164(C_word c,C_word *av) C_noret;
static void C_ccall trf_19164(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19164(t0,t1,t2);}

C_noret_decl(trf_19278)
static void C_ccall trf_19278(C_word c,C_word *av) C_noret;
static void C_ccall trf_19278(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19278(t0,t1,t2);}

C_noret_decl(trf_19668)
static void C_ccall trf_19668(C_word c,C_word *av) C_noret;
static void C_ccall trf_19668(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_19668(t0,t1,t2,t3,t4);}

C_noret_decl(trf_19712)
static void C_ccall trf_19712(C_word c,C_word *av) C_noret;
static void C_ccall trf_19712(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19712(t0,t1,t2);}

C_noret_decl(trf_19767)
static void C_ccall trf_19767(C_word c,C_word *av) C_noret;
static void C_ccall trf_19767(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_19767(t0,t1,t2,t3);}

C_noret_decl(trf_20023)
static void C_ccall trf_20023(C_word c,C_word *av) C_noret;
static void C_ccall trf_20023(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20023(t0,t1,t2);}

C_noret_decl(trf_20036)
static void C_ccall trf_20036(C_word c,C_word *av) C_noret;
static void C_ccall trf_20036(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20036(t0,t1,t2);}

C_noret_decl(trf_20095)
static void C_ccall trf_20095(C_word c,C_word *av) C_noret;
static void C_ccall trf_20095(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20095(t0,t1,t2);}

C_noret_decl(trf_20349)
static void C_ccall trf_20349(C_word c,C_word *av) C_noret;
static void C_ccall trf_20349(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_20349(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_20353)
static void C_ccall trf_20353(C_word c,C_word *av) C_noret;
static void C_ccall trf_20353(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20353(t0,t1);}

C_noret_decl(trf_20383)
static void C_ccall trf_20383(C_word c,C_word *av) C_noret;
static void C_ccall trf_20383(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20383(t0,t1);}

C_noret_decl(trf_20403)
static void C_ccall trf_20403(C_word c,C_word *av) C_noret;
static void C_ccall trf_20403(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20403(t0,t1,t2,t3);}

C_noret_decl(trf_20412)
static void C_ccall trf_20412(C_word c,C_word *av) C_noret;
static void C_ccall trf_20412(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20412(t0,t1,t2);}

C_noret_decl(trf_20417)
static void C_ccall trf_20417(C_word c,C_word *av) C_noret;
static void C_ccall trf_20417(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20417(t0,t1);}

C_noret_decl(trf_20782)
static void C_ccall trf_20782(C_word c,C_word *av) C_noret;
static void C_ccall trf_20782(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_20782(t0,t1,t2,t3,t4);}

C_noret_decl(trf_20791)
static void C_ccall trf_20791(C_word c,C_word *av) C_noret;
static void C_ccall trf_20791(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20791(t0,t1);}

C_noret_decl(trf_20801)
static void C_ccall trf_20801(C_word c,C_word *av) C_noret;
static void C_ccall trf_20801(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20801(t0,t1,t2);}

C_noret_decl(trf_20828)
static void C_ccall trf_20828(C_word c,C_word *av) C_noret;
static void C_ccall trf_20828(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20828(t0,t1,t2);}

C_noret_decl(trf_20837)
static void C_ccall trf_20837(C_word c,C_word *av) C_noret;
static void C_ccall trf_20837(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20837(t0,t1,t2);}

C_noret_decl(trf_20852)
static void C_ccall trf_20852(C_word c,C_word *av) C_noret;
static void C_ccall trf_20852(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20852(t0,t1);}

C_noret_decl(trf_20855)
static void C_ccall trf_20855(C_word c,C_word *av) C_noret;
static void C_ccall trf_20855(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20855(t0,t1);}

C_noret_decl(trf_20865)
static void C_ccall trf_20865(C_word c,C_word *av) C_noret;
static void C_ccall trf_20865(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20865(t0,t1,t2);}

C_noret_decl(trf_20903)
static void C_ccall trf_20903(C_word c,C_word *av) C_noret;
static void C_ccall trf_20903(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_20903(t0,t1,t2,t3,t4);}

C_noret_decl(trf_20909)
static void C_ccall trf_20909(C_word c,C_word *av) C_noret;
static void C_ccall trf_20909(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20909(t0,t1,t2,t3);}

C_noret_decl(trf_20963)
static void C_ccall trf_20963(C_word c,C_word *av) C_noret;
static void C_ccall trf_20963(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20963(t0,t1,t2);}

C_noret_decl(trf_20975)
static void C_ccall trf_20975(C_word c,C_word *av) C_noret;
static void C_ccall trf_20975(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20975(t0,t1,t2,t3);}

C_noret_decl(trf_21000)
static void C_ccall trf_21000(C_word c,C_word *av) C_noret;
static void C_ccall trf_21000(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21000(t0,t1,t2);}

C_noret_decl(trf_21010)
static void C_ccall trf_21010(C_word c,C_word *av) C_noret;
static void C_ccall trf_21010(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21010(t0,t1,t2,t3);}

C_noret_decl(trf_21191)
static void C_ccall trf_21191(C_word c,C_word *av) C_noret;
static void C_ccall trf_21191(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21191(t0,t1);}

C_noret_decl(trf_21282)
static void C_ccall trf_21282(C_word c,C_word *av) C_noret;
static void C_ccall trf_21282(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21282(t0,t1);}

C_noret_decl(trf_21302)
static void C_ccall trf_21302(C_word c,C_word *av) C_noret;
static void C_ccall trf_21302(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21302(t0,t1);}

C_noret_decl(trf_21307)
static void C_ccall trf_21307(C_word c,C_word *av) C_noret;
static void C_ccall trf_21307(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21307(t0,t1,t2,t3);}

C_noret_decl(trf_21406)
static void C_ccall trf_21406(C_word c,C_word *av) C_noret;
static void C_ccall trf_21406(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21406(t0,t1);}

C_noret_decl(trf_21554)
static void C_ccall trf_21554(C_word c,C_word *av) C_noret;
static void C_ccall trf_21554(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21554(t0,t1,t2,t3);}

C_noret_decl(trf_21563)
static void C_ccall trf_21563(C_word c,C_word *av) C_noret;
static void C_ccall trf_21563(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21563(t0,t1,t2);}

C_noret_decl(trf_21618)
static void C_ccall trf_21618(C_word c,C_word *av) C_noret;
static void C_ccall trf_21618(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21618(t0,t1,t2);}

C_noret_decl(trf_21625)
static void C_ccall trf_21625(C_word c,C_word *av) C_noret;
static void C_ccall trf_21625(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21625(t0,t1);}

C_noret_decl(trf_21668)
static void C_ccall trf_21668(C_word c,C_word *av) C_noret;
static void C_ccall trf_21668(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21668(t0,t1);}

C_noret_decl(trf_21816)
static void C_ccall trf_21816(C_word c,C_word *av) C_noret;
static void C_ccall trf_21816(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21816(t0,t1);}

C_noret_decl(trf_21834)
static void C_ccall trf_21834(C_word c,C_word *av) C_noret;
static void C_ccall trf_21834(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21834(t0,t1,t2,t3);}

C_noret_decl(trf_21904)
static void C_ccall trf_21904(C_word c,C_word *av) C_noret;
static void C_ccall trf_21904(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21904(t0,t1,t2);}

C_noret_decl(trf_21955)
static void C_ccall trf_21955(C_word c,C_word *av) C_noret;
static void C_ccall trf_21955(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21955(t0,t1,t2);}

C_noret_decl(trf_22022)
static void C_ccall trf_22022(C_word c,C_word *av) C_noret;
static void C_ccall trf_22022(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22022(t0,t1);}

C_noret_decl(trf_22032)
static void C_ccall trf_22032(C_word c,C_word *av) C_noret;
static void C_ccall trf_22032(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22032(t0,t1,t2,t3);}

C_noret_decl(trf_22042)
static void C_ccall trf_22042(C_word c,C_word *av) C_noret;
static void C_ccall trf_22042(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22042(t0,t1);}

C_noret_decl(trf_22086)
static void C_ccall trf_22086(C_word c,C_word *av) C_noret;
static void C_ccall trf_22086(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22086(t0,t1);}

C_noret_decl(trf_22096)
static void C_ccall trf_22096(C_word c,C_word *av) C_noret;
static void C_ccall trf_22096(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_22096(t0,t1,t2,t3);}

C_noret_decl(trf_22132)
static void C_ccall trf_22132(C_word c,C_word *av) C_noret;
static void C_ccall trf_22132(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22132(t0,t1);}

C_noret_decl(trf_22157)
static void C_ccall trf_22157(C_word c,C_word *av) C_noret;
static void C_ccall trf_22157(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22157(t0,t1,t2);}

C_noret_decl(trf_22162)
static void C_ccall trf_22162(C_word c,C_word *av) C_noret;
static void C_ccall trf_22162(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22162(t0,t1);}

C_noret_decl(trf_22167)
static void C_ccall trf_22167(C_word c,C_word *av) C_noret;
static void C_ccall trf_22167(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_22167(t0,t1,t2,t3,t4);}

C_noret_decl(trf_22180)
static void C_ccall trf_22180(C_word c,C_word *av) C_noret;
static void C_ccall trf_22180(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22180(t0,t1);}

C_noret_decl(trf_22186)
static void C_ccall trf_22186(C_word c,C_word *av) C_noret;
static void C_ccall trf_22186(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22186(t0,t1);}

C_noret_decl(trf_22216)
static void C_ccall trf_22216(C_word c,C_word *av) C_noret;
static void C_ccall trf_22216(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22216(t0,t1);}

C_noret_decl(trf_22408)
static void C_ccall trf_22408(C_word c,C_word *av) C_noret;
static void C_ccall trf_22408(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22408(t0,t1);}

C_noret_decl(trf_22447)
static void C_ccall trf_22447(C_word c,C_word *av) C_noret;
static void C_ccall trf_22447(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22447(t0,t1);}

C_noret_decl(trf_22592)
static void C_ccall trf_22592(C_word c,C_word *av) C_noret;
static void C_ccall trf_22592(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22592(t0,t1);}

C_noret_decl(trf_22617)
static void C_ccall trf_22617(C_word c,C_word *av) C_noret;
static void C_ccall trf_22617(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22617(t0,t1);}

C_noret_decl(trf_22623)
static void C_ccall trf_22623(C_word c,C_word *av) C_noret;
static void C_ccall trf_22623(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22623(t0,t1,t2);}

C_noret_decl(trf_22704)
static void C_ccall trf_22704(C_word c,C_word *av) C_noret;
static void C_ccall trf_22704(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22704(t0,t1);}

C_noret_decl(trf_22717)
static void C_ccall trf_22717(C_word c,C_word *av) C_noret;
static void C_ccall trf_22717(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22717(t0,t1,t2);}

C_noret_decl(trf_23325)
static void C_ccall trf_23325(C_word c,C_word *av) C_noret;
static void C_ccall trf_23325(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_23325(t0,t1);}

C_noret_decl(trf_23879)
static void C_ccall trf_23879(C_word c,C_word *av) C_noret;
static void C_ccall trf_23879(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_23879(t0,t1,t2);}

C_noret_decl(trf_23925)
static void C_ccall trf_23925(C_word c,C_word *av) C_noret;
static void C_ccall trf_23925(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_23925(t0,t1,t2,t3);}

C_noret_decl(trf_24188)
static void C_ccall trf_24188(C_word c,C_word *av) C_noret;
static void C_ccall trf_24188(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_24188(t0,t1,t2);}

C_noret_decl(trf_24239)
static void C_ccall trf_24239(C_word c,C_word *av) C_noret;
static void C_ccall trf_24239(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_24239(t0,t1,t2);}

C_noret_decl(trf_24298)
static void C_ccall trf_24298(C_word c,C_word *av) C_noret;
static void C_ccall trf_24298(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_24298(t0,t1,t2,t3);}

C_noret_decl(trf_24370)
static void C_ccall trf_24370(C_word c,C_word *av) C_noret;
static void C_ccall trf_24370(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_24370(t0,t1,t2,t3);}

C_noret_decl(trf_24430)
static void C_ccall trf_24430(C_word c,C_word *av) C_noret;
static void C_ccall trf_24430(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_24430(t0,t1,t2,t3);}

C_noret_decl(trf_24454)
static void C_ccall trf_24454(C_word c,C_word *av) C_noret;
static void C_ccall trf_24454(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_24454(t0,t1,t2,t3);}

C_noret_decl(trf_24466)
static void C_ccall trf_24466(C_word c,C_word *av) C_noret;
static void C_ccall trf_24466(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_24466(t0,t1,t2);}

C_noret_decl(trf_24543)
static void C_ccall trf_24543(C_word c,C_word *av) C_noret;
static void C_ccall trf_24543(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_24543(t0,t1,t2);}

C_noret_decl(trf_24592)
static void C_ccall trf_24592(C_word c,C_word *av) C_noret;
static void C_ccall trf_24592(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_24592(t0,t1,t2);}

C_noret_decl(trf_24608)
static void C_ccall trf_24608(C_word c,C_word *av) C_noret;
static void C_ccall trf_24608(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_24608(t0,t1);}

C_noret_decl(trf_24627)
static void C_ccall trf_24627(C_word c,C_word *av) C_noret;
static void C_ccall trf_24627(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_24627(t0,t1);}

C_noret_decl(trf_24737)
static void C_ccall trf_24737(C_word c,C_word *av) C_noret;
static void C_ccall trf_24737(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_24737(t0,t1,t2);}

C_noret_decl(trf_24802)
static void C_ccall trf_24802(C_word c,C_word *av) C_noret;
static void C_ccall trf_24802(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_24802(t0,t1,t2);}

C_noret_decl(trf_24959)
static void C_ccall trf_24959(C_word c,C_word *av) C_noret;
static void C_ccall trf_24959(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_24959(t0,t1,t2,t3);}

C_noret_decl(trf_25138)
static void C_ccall trf_25138(C_word c,C_word *av) C_noret;
static void C_ccall trf_25138(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_25138(t0,t1,t2);}

C_noret_decl(trf_25210)
static void C_ccall trf_25210(C_word c,C_word *av) C_noret;
static void C_ccall trf_25210(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_25210(t0,t1,t2);}

C_noret_decl(trf_25349)
static void C_ccall trf_25349(C_word c,C_word *av) C_noret;
static void C_ccall trf_25349(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_25349(t0,t1,t2,t3);}

C_noret_decl(trf_25748)
static void C_ccall trf_25748(C_word c,C_word *av) C_noret;
static void C_ccall trf_25748(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_25748(t0,t1,t2,t3,t4);}

C_noret_decl(trf_25768)
static void C_ccall trf_25768(C_word c,C_word *av) C_noret;
static void C_ccall trf_25768(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_25768(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_25822)
static void C_ccall trf_25822(C_word c,C_word *av) C_noret;
static void C_ccall trf_25822(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_25822(t0,t1);}

C_noret_decl(trf_26019)
static void C_ccall trf_26019(C_word c,C_word *av) C_noret;
static void C_ccall trf_26019(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26019(t0,t1,t2);}

C_noret_decl(trf_26034)
static void C_ccall trf_26034(C_word c,C_word *av) C_noret;
static void C_ccall trf_26034(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26034(t0,t1,t2);}

C_noret_decl(trf_26137)
static void C_ccall trf_26137(C_word c,C_word *av) C_noret;
static void C_ccall trf_26137(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26137(t0,t1,t2);}

C_noret_decl(trf_26156)
static void C_ccall trf_26156(C_word c,C_word *av) C_noret;
static void C_ccall trf_26156(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26156(t0,t1);}

C_noret_decl(trf_26275)
static void C_ccall trf_26275(C_word c,C_word *av) C_noret;
static void C_ccall trf_26275(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26275(t0,t1,t2);}

C_noret_decl(trf_26312)
static void C_ccall trf_26312(C_word c,C_word *av) C_noret;
static void C_ccall trf_26312(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26312(t0,t1);}

C_noret_decl(trf_26346)
static void C_ccall trf_26346(C_word c,C_word *av) C_noret;
static void C_ccall trf_26346(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26346(t0,t1,t2);}

C_noret_decl(trf_26482)
static void C_ccall trf_26482(C_word c,C_word *av) C_noret;
static void C_ccall trf_26482(C_word c,C_word *av){
C_word t0=av[0];
f_26482(t0);}

C_noret_decl(trf_26530)
static void C_ccall trf_26530(C_word c,C_word *av) C_noret;
static void C_ccall trf_26530(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26530(t0,t1);}

C_noret_decl(trf_26554)
static void C_ccall trf_26554(C_word c,C_word *av) C_noret;
static void C_ccall trf_26554(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26554(t0,t1,t2);}

C_noret_decl(trf_26649)
static void C_ccall trf_26649(C_word c,C_word *av) C_noret;
static void C_ccall trf_26649(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_26649(t0,t1,t2);}

C_noret_decl(trf_26697)
static void C_ccall trf_26697(C_word c,C_word *av) C_noret;
static void C_ccall trf_26697(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26697(t0,t1);}

C_noret_decl(trf_26700)
static void C_ccall trf_26700(C_word c,C_word *av) C_noret;
static void C_ccall trf_26700(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26700(t0,t1);}

C_noret_decl(trf_26720)
static void C_ccall trf_26720(C_word c,C_word *av) C_noret;
static void C_ccall trf_26720(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_26720(t0,t1);}

C_noret_decl(trf_27167)
static void C_ccall trf_27167(C_word c,C_word *av) C_noret;
static void C_ccall trf_27167(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_27167(t0,t1,t2,t3);}

C_noret_decl(trf_27173)
static void C_ccall trf_27173(C_word c,C_word *av) C_noret;
static void C_ccall trf_27173(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27173(t0,t1,t2);}

C_noret_decl(trf_27189)
static void C_ccall trf_27189(C_word c,C_word *av) C_noret;
static void C_ccall trf_27189(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27189(t0,t1);}

C_noret_decl(trf_27286)
static void C_ccall trf_27286(C_word c,C_word *av) C_noret;
static void C_ccall trf_27286(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27286(t0,t1,t2);}

C_noret_decl(trf_27332)
static void C_ccall trf_27332(C_word c,C_word *av) C_noret;
static void C_ccall trf_27332(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27332(t0,t1,t2);}

C_noret_decl(trf_27408)
static void C_ccall trf_27408(C_word c,C_word *av) C_noret;
static void C_ccall trf_27408(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27408(t0,t1,t2);}

C_noret_decl(trf_27460)
static void C_ccall trf_27460(C_word c,C_word *av) C_noret;
static void C_ccall trf_27460(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27460(t0,t1,t2);}

C_noret_decl(trf_27508)
static void C_ccall trf_27508(C_word c,C_word *av) C_noret;
static void C_ccall trf_27508(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27508(t0,t1,t2);}

C_noret_decl(trf_27522)
static void C_ccall trf_27522(C_word c,C_word *av) C_noret;
static void C_ccall trf_27522(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27522(t0,t1,t2);}

C_noret_decl(trf_27578)
static void C_ccall trf_27578(C_word c,C_word *av) C_noret;
static void C_ccall trf_27578(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27578(t0,t1,t2);}

C_noret_decl(trf_27703)
static void C_ccall trf_27703(C_word c,C_word *av) C_noret;
static void C_ccall trf_27703(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27703(t0,t1,t2);}

C_noret_decl(trf_27705)
static void C_ccall trf_27705(C_word c,C_word *av) C_noret;
static void C_ccall trf_27705(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27705(t0,t1,t2);}

C_noret_decl(trf_27726)
static void C_ccall trf_27726(C_word c,C_word *av) C_noret;
static void C_ccall trf_27726(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27726(t0,t1,t2);}

C_noret_decl(trf_27750)
static void C_ccall trf_27750(C_word c,C_word *av) C_noret;
static void C_ccall trf_27750(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_27750(t0,t1,t2,t3);}

C_noret_decl(trf_27804)
static void C_ccall trf_27804(C_word c,C_word *av) C_noret;
static void C_ccall trf_27804(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27804(t0,t1,t2);}

C_noret_decl(trf_27899)
static void C_ccall trf_27899(C_word c,C_word *av) C_noret;
static void C_ccall trf_27899(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_27899(t0,t1,t2);}

C_noret_decl(trf_27904)
static void C_ccall trf_27904(C_word c,C_word *av) C_noret;
static void C_ccall trf_27904(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_27904(t0,t1);}

C_noret_decl(trf_28888)
static void C_ccall trf_28888(C_word c,C_word *av) C_noret;
static void C_ccall trf_28888(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_28888(t0,t1,t2);}

C_noret_decl(trf_28952)
static void C_ccall trf_28952(C_word c,C_word *av) C_noret;
static void C_ccall trf_28952(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_28952(t0,t1,t2);}

C_noret_decl(trf_29234)
static void C_ccall trf_29234(C_word c,C_word *av) C_noret;
static void C_ccall trf_29234(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29234(t0,t1);}

C_noret_decl(trf_29324)
static void C_ccall trf_29324(C_word c,C_word *av) C_noret;
static void C_ccall trf_29324(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29324(t0,t1,t2);}

C_noret_decl(trf_29368)
static void C_ccall trf_29368(C_word c,C_word *av) C_noret;
static void C_ccall trf_29368(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29368(t0,t1);}

C_noret_decl(trf_29381)
static void C_ccall trf_29381(C_word c,C_word *av) C_noret;
static void C_ccall trf_29381(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29381(t0,t1,t2);}

C_noret_decl(trf_29415)
static void C_ccall trf_29415(C_word c,C_word *av) C_noret;
static void C_ccall trf_29415(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29415(t0,t1,t2);}

C_noret_decl(trf_29430)
static void C_ccall trf_29430(C_word c,C_word *av) C_noret;
static void C_ccall trf_29430(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29430(t0,t1);}

C_noret_decl(trf_29506)
static void C_ccall trf_29506(C_word c,C_word *av) C_noret;
static void C_ccall trf_29506(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29506(t0,t1,t2);}

C_noret_decl(trf_29606)
static void C_ccall trf_29606(C_word c,C_word *av) C_noret;
static void C_ccall trf_29606(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_29606(t0,t1);}

C_noret_decl(trf_29625)
static void C_ccall trf_29625(C_word c,C_word *av) C_noret;
static void C_ccall trf_29625(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29625(t0,t1,t2);}

C_noret_decl(trf_29666)
static void C_ccall trf_29666(C_word c,C_word *av) C_noret;
static void C_ccall trf_29666(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_29666(t0,t1,t2,t3,t4);}

C_noret_decl(trf_29989)
static void C_ccall trf_29989(C_word c,C_word *av) C_noret;
static void C_ccall trf_29989(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_29989(t0,t1,t2);}

C_noret_decl(trf_30001)
static void C_ccall trf_30001(C_word c,C_word *av) C_noret;
static void C_ccall trf_30001(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_30001(t0,t1,t2);}

C_noret_decl(trf_30082)
static void C_ccall trf_30082(C_word c,C_word *av) C_noret;
static void C_ccall trf_30082(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_30082(t0,t1,t2,t3);}

C_noret_decl(trf_30296)
static void C_ccall trf_30296(C_word c,C_word *av) C_noret;
static void C_ccall trf_30296(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_30296(t0,t1,t2);}

C_noret_decl(trf_30334)
static void C_ccall trf_30334(C_word c,C_word *av) C_noret;
static void C_ccall trf_30334(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_30334(t0,t1,t2);}

C_noret_decl(trf_30413)
static void C_ccall trf_30413(C_word c,C_word *av) C_noret;
static void C_ccall trf_30413(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_30413(t0,t1,t2);}

C_noret_decl(trf_30541)
static void C_ccall trf_30541(C_word c,C_word *av) C_noret;
static void C_ccall trf_30541(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_30541(t0,t1);}

C_noret_decl(trf_30975)
static void C_ccall trf_30975(C_word c,C_word *av) C_noret;
static void C_ccall trf_30975(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_30975(t0,t1);}

C_noret_decl(trf_30987)
static void C_ccall trf_30987(C_word c,C_word *av) C_noret;
static void C_ccall trf_30987(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_30987(t0,t1,t2);}

C_noret_decl(trf_31046)
static void C_ccall trf_31046(C_word c,C_word *av) C_noret;
static void C_ccall trf_31046(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31046(t0,t1);}

C_noret_decl(trf_31060)
static void C_ccall trf_31060(C_word c,C_word *av) C_noret;
static void C_ccall trf_31060(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_31060(t0,t1,t2);}

C_noret_decl(trf_31082)
static void C_ccall trf_31082(C_word c,C_word *av) C_noret;
static void C_ccall trf_31082(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_31082(t0,t1,t2);}

C_noret_decl(trf_31297)
static void C_ccall trf_31297(C_word c,C_word *av) C_noret;
static void C_ccall trf_31297(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31297(t0,t1);}

C_noret_decl(trf_31320)
static void C_ccall trf_31320(C_word c,C_word *av) C_noret;
static void C_ccall trf_31320(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31320(t0,t1);}

C_noret_decl(trf_31474)
static void C_ccall trf_31474(C_word c,C_word *av) C_noret;
static void C_ccall trf_31474(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_31474(t0,t1,t2,t3);}

C_noret_decl(trf_31629)
static void C_ccall trf_31629(C_word c,C_word *av) C_noret;
static void C_ccall trf_31629(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31629(t0,t1);}

C_noret_decl(trf_31662)
static void C_ccall trf_31662(C_word c,C_word *av) C_noret;
static void C_ccall trf_31662(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31662(t0,t1);}

C_noret_decl(trf_31665)
static void C_ccall trf_31665(C_word c,C_word *av) C_noret;
static void C_ccall trf_31665(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31665(t0,t1);}

C_noret_decl(trf_31668)
static void C_ccall trf_31668(C_word c,C_word *av) C_noret;
static void C_ccall trf_31668(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31668(t0,t1);}

C_noret_decl(trf_31671)
static void C_ccall trf_31671(C_word c,C_word *av) C_noret;
static void C_ccall trf_31671(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_31671(t0,t1);}

C_noret_decl(trf_31708)
static void C_ccall trf_31708(C_word c,C_word *av) C_noret;
static void C_ccall trf_31708(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_31708(t0,t1,t2);}

C_noret_decl(trf_31744)
static void C_ccall trf_31744(C_word c,C_word *av) C_noret;
static void C_ccall trf_31744(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_31744(t0,t1,t2);}

C_noret_decl(trf_31775)
static void C_ccall trf_31775(C_word c,C_word *av) C_noret;
static void C_ccall trf_31775(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_31775(t0,t1,t2);}

C_noret_decl(trf_31818)
static void C_ccall trf_31818(C_word c,C_word *av) C_noret;
static void C_ccall trf_31818(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_31818(t0,t1,t2);}

C_noret_decl(trf_31989)
static void C_ccall trf_31989(C_word c,C_word *av) C_noret;
static void C_ccall trf_31989(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_31989(t0,t1,t2);}

C_noret_decl(trf_32220)
static void C_ccall trf_32220(C_word c,C_word *av) C_noret;
static void C_ccall trf_32220(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_32220(t0,t1,t2);}

C_noret_decl(trf_32376)
static void C_ccall trf_32376(C_word c,C_word *av) C_noret;
static void C_ccall trf_32376(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_32376(t0,t1,t2);}

C_noret_decl(trf_32415)
static void C_ccall trf_32415(C_word c,C_word *av) C_noret;
static void C_ccall trf_32415(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_32415(t0,t1,t2);}

C_noret_decl(trf_32431)
static void C_ccall trf_32431(C_word c,C_word *av) C_noret;
static void C_ccall trf_32431(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_32431(t0,t1,t2);}

C_noret_decl(trf_32597)
static void C_ccall trf_32597(C_word c,C_word *av) C_noret;
static void C_ccall trf_32597(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_32597(t0,t1);}

C_noret_decl(trf_33109)
static void C_ccall trf_33109(C_word c,C_word *av) C_noret;
static void C_ccall trf_33109(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_33109(t0,t1,t2,t3,t4);}

C_noret_decl(trf_33204)
static void C_ccall trf_33204(C_word c,C_word *av) C_noret;
static void C_ccall trf_33204(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_33204(t0,t1);}

C_noret_decl(trf_33217)
static void C_ccall trf_33217(C_word c,C_word *av) C_noret;
static void C_ccall trf_33217(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_33217(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_9156)
static void C_ccall trf_9156(C_word c,C_word *av) C_noret;
static void C_ccall trf_9156(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9156(t0,t1,t2,t3);}

C_noret_decl(trf_9626)
static void C_ccall trf_9626(C_word c,C_word *av) C_noret;
static void C_ccall trf_9626(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9626(t0,t1,t2,t3);}

C_noret_decl(trf_9663)
static void C_ccall trf_9663(C_word c,C_word *av) C_noret;
static void C_ccall trf_9663(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9663(t0,t1,t2);}

C_noret_decl(trf_9749)
static void C_ccall trf_9749(C_word c,C_word *av) C_noret;
static void C_ccall trf_9749(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9749(t0,t1,t2);}

C_noret_decl(trf_9782)
static void C_ccall trf_9782(C_word c,C_word *av) C_noret;
static void C_ccall trf_9782(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9782(t0,t1,t2);}

C_noret_decl(trf_9900)
static void C_ccall trf_9900(C_word c,C_word *av) C_noret;
static void C_ccall trf_9900(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9900(t0,t1,t2);}

C_noret_decl(trf_9935)
static void C_ccall trf_9935(C_word c,C_word *av) C_noret;
static void C_ccall trf_9935(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9935(t0,t1,t2);}

C_noret_decl(trf_9999)
static void C_ccall trf_9999(C_word c,C_word *av) C_noret;
static void C_ccall trf_9999(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9999(t0,t1,t2);}

/* f35157 in chicken.base#emergency-exit in k8834 */
static void C_ccall f35157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f35157,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_exit_runtime(C_fix(0));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f35726 in chicken.base#exit in k8834 */
static void C_ccall f35726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f35726,c,av);}
/* library.scm:731: g673 */
t2=t1;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* f35941 in chicken.base#gensym in k10751 in k8834 */
static void C_ccall f35941(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f35941,c,av);}
/* library.scm:2771: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[660];
av2[3]=t1;
tp(4,av2);}}

/* f35945 in k18054 in chicken.base#gensym in k10751 in k8834 */
static void C_ccall f35945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f35945,c,av);}
/* library.scm:2771: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* f38368 in k32197 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f38368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f38368,c,av);}
t3=C_i_check_list_2(t2,lf[1407]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* f38374 in k32284 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f38374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f38374,c,av);}
t3=C_i_check_string_2(t2,lf[1410]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* f38380 in k32280 in k32284 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f38380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f38380,c,av);}
t3=C_i_check_string_2(t2,lf[1410]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10016 in loop */
static void C_ccall f_10018(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10018,c,av);}
/* library.scm:817: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9999(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* chicken.base#bwp-object? in k8834 */
static void C_ccall f_10027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10027,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_bwpp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#weak-cons in k8834 */
static void C_ccall f_10030(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10030,c,av);}
a=C_alloc(3);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_weak_cons(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.base#weak-pair? in k8834 */
static void C_ccall f_10033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10033,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_weak_pairp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#atom? in k8834 */
static void C_ccall f_10036(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10036,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_not_pair_p(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#tail? in k8834 */
static void C_ccall f_10039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_10039,c,av);}
a=C_alloc(4);
t4=C_i_check_list_2(t3,lf[252]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10048,a[2]=t2,a[3]=((C_word)li177),tmp=(C_word)a,a+=4,tmp);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=(
  f_10048(t5,t3)
);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* loop in chicken.base#tail? in k8834 */
static C_word C_fcall f_10048(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
if(C_truep(C_eqp(((C_word*)t0)[2],t1))){
return(C_SCHEME_TRUE);}
else{
t2=(C_truep(C_blockp(t1))?C_pairp(t1):C_SCHEME_FALSE);
if(C_truep(t2)){
t4=C_slot(t1,C_fix(1));
t1=t4;
goto loop;}
else{
return(C_SCHEME_FALSE);}}}

/* chicken.base#intersperse in k8834 */
static void C_ccall f_10067(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_10067,c,av);}
a=C_alloc(7);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10073,a[2]=t3,a[3]=t5,a[4]=((C_word)li179),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_10073(t7,t1,t2);}

/* loop in chicken.base#intersperse in k8834 */
static void C_fcall f_10073(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_10073,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_eqp(t2,C_SCHEME_END_OF_LIST))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_cdr(t2);
if(C_truep(C_eqp(t3,C_SCHEME_END_OF_LIST))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10098,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* library.scm:846: loop */
t7=t5;
t8=t3;
t1=t7;
t2=t8;
goto loop;}}}

/* k10096 in loop in chicken.base#intersperse in k8834 */
static void C_ccall f_10098(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10098,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#butlast in k8834 */
static void C_ccall f_10100(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_10100,c,av);}
a=C_alloc(6);
t3=C_i_check_pair_2(t2,lf[255]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10109,a[2]=t5,a[3]=((C_word)li181),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_10109(t7,t1,t2);}

/* loop in chicken.base#butlast in k8834 */
static void C_fcall f_10109(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_10109,3,t0,t1,t2);}
a=C_alloc(4);
t3=C_slot(t2,C_fix(1));
t4=(C_truep(C_blockp(t3))?C_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_slot(t2,C_fix(0));
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10130,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:853: loop */
t8=t6;
t9=t3;
t1=t8;
t2=t9;
goto loop;}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k10128 in loop in chicken.base#butlast in k8834 */
static void C_ccall f_10130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10130,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#flatten in k8834 */
static void C_ccall f_10132(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_10132,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10138,a[2]=t4,a[3]=((C_word)li183),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_10138(t6,t1,t2,C_SCHEME_END_OF_LIST);}

/* loop in chicken.base#flatten in k8834 */
static void C_fcall f_10138(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_10138,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=C_slot(t2,C_fix(1));
if(C_truep(C_i_listp(t4))){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10164,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* library.scm:863: loop */
t8=t6;
t9=t5;
t10=t3;
t1=t8;
t2=t9;
t3=t10;
goto loop;}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10171,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:864: loop */
t8=t6;
t9=t5;
t10=t3;
t1=t8;
t2=t9;
t3=t10;
goto loop;}}}

/* k10162 in loop in chicken.base#flatten in k8834 */
static void C_ccall f_10164(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10164,c,av);}
/* library.scm:863: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_10138(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k10169 in loop in chicken.base#flatten in k8834 */
static void C_ccall f_10171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10171,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#join in k8834 */
static void C_ccall f_10173(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +7,c,3)))){
C_save_and_reclaim((void*)f_10173,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+7);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
t4=C_i_pairp(t3);
t5=(C_truep(t4)?C_get_rest_arg(c,3,av,3,t0):C_SCHEME_END_OF_LIST);
t6=C_i_check_list_2(t5,lf[258]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10185,a[2]=t5,a[3]=t8,a[4]=((C_word)li185),tmp=(C_word)a,a+=5,tmp));
t10=((C_word*)t8)[1];
f_10185(t10,t1,t2);}

/* loop in chicken.base#join in k8834 */
static void C_fcall f_10185(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_10185,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
/* library.scm:874: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=C_slot(t2,C_fix(1));
if(C_truep(C_i_nullp(t5))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10220,a[2]=t1,a[3]=t4,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:880: loop */
t8=t6;
t9=t5;
t1=t8;
t2=t9;
goto loop;}}}}

/* k10218 in loop in chicken.base#join in k8834 */
static void C_ccall f_10220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10220,c,av);}
/* library.scm:880: ##sys#append */
t2=*((C_word*)lf[259]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.base#compress in k8834 */
static void C_ccall f_10230(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_10230,c,av);}
a=C_alloc(7);
t4=lf[261];
t5=C_i_check_list_2(t3,lf[262]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10239,a[2]=t4,a[3]=t7,a[4]=((C_word)li187),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_10239(t9,t1,t2,t3);}

/* loop in chicken.base#compress in k8834 */
static void C_fcall f_10239(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,5)))){
C_save_and_reclaim_args((void *)trf_10239,4,t0,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_pairp(t2);
if(C_truep(C_i_not(t4))){
/* library.scm:889: ##sys#signal-hook */
t5=C_fast_retrieve(lf[194]);{
C_word av2[6];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=lf[262];
av2[4]=((C_word*)t0)[2];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}
else{
t5=C_i_pairp(t3);
if(C_truep(C_i_not(t5))){
/* library.scm:891: ##sys#signal-hook */
t6=C_fast_retrieve(lf[194]);{
C_word av2[6];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=lf[262];
av2[4]=((C_word*)t0)[2];
av2[5]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(6,av2);}}
else{
if(C_truep(C_slot(t2,C_fix(0)))){
t6=C_slot(t3,C_fix(0));
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10281,a[2]=t1,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* library.scm:893: loop */
t9=t7;
t10=C_slot(t2,C_fix(1));
t11=C_slot(t3,C_fix(1));
t1=t9;
t2=t10;
t3=t11;
goto loop;}
else{
/* library.scm:894: loop */
t9=t1;
t10=C_slot(t2,C_fix(1));
t11=C_slot(t3,C_fix(1));
t1=t9;
t2=t10;
t3=t11;
goto loop;}}}}}

/* k10279 in loop in chicken.base#compress in k8834 */
static void C_ccall f_10281(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10281,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#alist-update! in k8834 */
static void C_ccall f_10310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(c<5) C_bad_min_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_10310,c,av);}
a=C_alloc(10);
t5=C_rest_nullp(c,5);
t6=(C_truep(t5)?*((C_word*)lf[5]+1):C_get_rest_arg(c,5,av,5,t0));
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10317,a[2]=t3,a[3]=t1,a[4]=t4,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t8=C_eqp(*((C_word*)lf[4]+1),t6);
if(C_truep(t8)){
t9=t7;
f_10317(t9,*((C_word*)lf[52]+1));}
else{
t9=C_eqp(*((C_word*)lf[5]+1),t6);
if(C_truep(t9)){
t10=t7;
f_10317(t10,*((C_word*)lf[53]+1));}
else{
t10=C_eqp(*((C_word*)lf[6]+1),t6);
t11=t7;
f_10317(t11,(C_truep(t10)?*((C_word*)lf[54]+1):(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10349,a[2]=t6,a[3]=((C_word)li190),tmp=(C_word)a,a+=4,tmp)));}}}

/* k10315 in chicken.base#alist-update! in k8834 */
static void C_fcall f_10317(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_10317,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10320,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:911: aq */
t3=t1;{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k10318 in k10315 in chicken.base#alist-update! in k8834 */
static void C_ccall f_10320(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10320,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_setslot(t1,C_fix(1),((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=C_a_i_cons(&a,2,((C_word*)t0)[5],((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* f_10349 in chicken.base#alist-update! in k8834 */
static void C_ccall f_10349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10349,c,av);}
a=C_alloc(8);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10355,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word)li189),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_10355(t7,t1,t3);}

/* loop */
static void C_fcall f_10355(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_10355,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10371,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(t3))){
/* library.scm:908: cmp */
t5=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
av2[3]=C_slot(t3,C_fix(0));
((C_proc)C_fast_retrieve_proc(t5))(4,av2);}}
else{
/* library.scm:910: loop */
t6=t1;
t7=C_slot(t2,C_fix(1));
t1=t6;
t2=t7;
goto loop;}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10369 in loop */
static void C_ccall f_10371(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10371,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* library.scm:910: loop */
t2=((C_word*)((C_word*)t0)[4])[1];
f_10355(t2,((C_word*)t0)[2],C_slot(((C_word*)t0)[5],C_fix(1)));}}

/* chicken.base#alist-update in k8834 */
static void C_ccall f_10396(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c<5) C_bad_min_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_10396,c,av);}
a=C_alloc(9);
t5=C_rest_nullp(c,5);
t6=(C_truep(t5)?*((C_word*)lf[5]+1):C_get_rest_arg(c,5,av,5,t0));
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10405,a[2]=t2,a[3]=t3,a[4]=t8,a[5]=t6,a[6]=((C_word)li192),tmp=(C_word)a,a+=7,tmp));
t10=((C_word*)t8)[1];
f_10405(t10,t1,t4);}

/* loop in chicken.base#alist-update in k8834 */
static void C_fcall f_10405(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_10405,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_a_i_list1(&a,1,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
/* library.scm:923: chicken.base#error */
t4=*((C_word*)lf[193]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[266];
av2[3]=lf[267];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=C_i_pairp(t4);
if(C_truep(C_i_not(t5))){
/* library.scm:927: chicken.base#error */
t6=*((C_word*)lf[193]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[266];
av2[3]=lf[268];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10446,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=t1,a[6]=t4,a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
/* library.scm:928: cmp */
t7=((C_word*)t0)[5];{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[2];
av2[3]=C_slot(t4,C_fix(0));
((C_proc)C_fast_retrieve_proc(t7))(4,av2);}}}}}

/* k10444 in loop in chicken.base#alist-update in k8834 */
static void C_ccall f_10446(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10446,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_slot(((C_word*)t0)[4],C_fix(1));
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=C_slot(((C_word*)t0)[6],C_fix(0));
t3=C_slot(((C_word*)t0)[6],C_fix(1));
t4=C_a_i_cons(&a,2,t2,t3);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10468,a[2]=((C_word*)t0)[5],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:932: loop */
t6=((C_word*)((C_word*)t0)[7])[1];
f_10405(t6,t5,C_slot(((C_word*)t0)[4],C_fix(1)));}}

/* k10466 in k10444 in loop in chicken.base#alist-update in k8834 */
static void C_ccall f_10468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10468,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#alist-ref in k8834 */
static void C_ccall f_10500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_10500,c,av);}
a=C_alloc(10);
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?*((C_word*)lf[5]+1):C_get_rest_arg(c,4,av,4,t0));
t6=C_rest_nullp(c,4);
t7=C_rest_nullp(c,5);
t8=(C_truep(t7)?C_SCHEME_FALSE:C_get_rest_arg(c,5,av,4,t0));
t9=C_rest_nullp(c,5);
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10516,a[2]=t1,a[3]=t8,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t11=C_eqp(*((C_word*)lf[4]+1),t5);
if(C_truep(t11)){
t12=t10;
f_10516(t12,*((C_word*)lf[52]+1));}
else{
t12=C_eqp(*((C_word*)lf[5]+1),t5);
if(C_truep(t12)){
t13=t10;
f_10516(t13,*((C_word*)lf[53]+1));}
else{
t13=C_eqp(*((C_word*)lf[6]+1),t5);
t14=t10;
f_10516(t14,(C_truep(t13)?*((C_word*)lf[54]+1):(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10541,a[2]=t5,a[3]=((C_word)li195),tmp=(C_word)a,a+=4,tmp)));}}}

/* k10514 in chicken.base#alist-ref in k8834 */
static void C_fcall f_10516(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_10516,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10519,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:950: aq */
t3=t1;{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k10517 in k10514 in chicken.base#alist-ref in k8834 */
static void C_ccall f_10519(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10519,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_slot(t1,C_fix(1)):((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_10541 in chicken.base#alist-ref in k8834 */
static void C_ccall f_10541(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10541,c,av);}
a=C_alloc(8);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10547,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word)li194),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_10547(t7,t1,t3);}

/* loop */
static void C_fcall f_10547(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_10547,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_check_pair_2(t3,lf[270]);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10572,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:946: cmp */
t6=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
av2[3]=C_slot(t3,C_fix(0));
((C_proc)C_fast_retrieve_proc(t6))(4,av2);}}
else{
/* library.scm:949: chicken.base#error */
t3=*((C_word*)lf[193]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[270];
av2[3]=lf[271];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}}

/* k10570 in loop */
static void C_ccall f_10572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10572,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* library.scm:948: loop */
t2=((C_word*)((C_word*)t0)[4])[1];
f_10547(t2,((C_word*)t0)[2],C_slot(((C_word*)t0)[5],C_fix(1)));}}

/* chicken.base#rassoc in k8834 */
static void C_ccall f_10612(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +8,c,3)))){
C_save_and_reclaim((void*)f_10612,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+8);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
t5=C_i_check_list_2(t3,lf[273]);
t6=C_i_pairp(t4);
t7=(C_truep(t6)?C_get_rest_arg(c,4,av,4,t0):*((C_word*)lf[5]+1));
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10624,a[2]=t9,a[3]=t7,a[4]=t2,a[5]=((C_word)li197),tmp=(C_word)a,a+=6,tmp));
t11=((C_word*)t9)[1];
f_10624(t11,t1,t3);}

/* loop in chicken.base#rassoc in k8834 */
static void C_fcall f_10624(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_10624,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_check_pair_2(t3,lf[273]);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10643,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:963: tst */
t6=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
av2[3]=C_slot(t3,C_fix(1));
((C_proc)C_fast_retrieve_proc(t6))(4,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10641 in loop in chicken.base#rassoc in k8834 */
static void C_ccall f_10643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10643,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* library.scm:965: loop */
t2=((C_word*)((C_word*)t0)[4])[1];
f_10624(t2,((C_word*)t0)[2],C_slot(((C_word*)t0)[5],C_fix(1)));}}

/* chicken.fixnum#fx+ in k8834 */
static void C_ccall f_10665(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10665,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_plus(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx- in k8834 */
static void C_ccall f_10668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10668,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_difference(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx* in k8834 */
static void C_ccall f_10671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10671,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_times(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx= in k8834 */
static void C_ccall f_10674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10674,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_eqp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx> in k8834 */
static void C_ccall f_10680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10680,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_greaterp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx< in k8834 */
static void C_ccall f_10683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10683,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_lessp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx>= in k8834 */
static void C_ccall f_10686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10686,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_greater_or_equal_p(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx<= in k8834 */
static void C_ccall f_10689(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10689,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_less_or_equal_p(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxmin in k8834 */
static void C_ccall f_10692(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10692,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_fixnum_min(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxmax in k8834 */
static void C_ccall f_10695(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10695,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_fixnum_max(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxneg in k8834 */
static void C_ccall f_10698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10698,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fixnum_negate(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.fixnum#fxand in k8834 */
static void C_ccall f_10701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10701,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_and(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxior in k8834 */
static void C_ccall f_10704(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10704,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_or(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxxor in k8834 */
static void C_ccall f_10707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10707,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_xor(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxnot in k8834 */
static void C_ccall f_10710(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10710,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fixnum_not(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.fixnum#fxshl in k8834 */
static void C_ccall f_10713(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10713,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_shift_left(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxshr in k8834 */
static void C_ccall f_10716(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10716,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_shift_right(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxodd? in k8834 */
static void C_ccall f_10719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10719,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_fixnumoddp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.fixnum#fxeven? in k8834 */
static void C_ccall f_10722(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10722,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_fixnumevenp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.fixnum#fxlen in k8834 */
static void C_ccall f_10725(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10725,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_fixnum_length(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.fixnum#fx/ in k8834 */
static void C_ccall f_10728(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10728,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_divide(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxgcd in k8834 */
static void C_ccall f_10731(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10731,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_fixnum_gcd(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxmod in k8834 */
static void C_ccall f_10734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10734,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fixnum_modulo(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fxrem in k8834 */
static void C_ccall f_10737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10737,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_fixnum_remainder_checked(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx+? in k8834 */
static void C_ccall f_10740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10740,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_o_fixnum_plus(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx-? in k8834 */
static void C_ccall f_10743(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10743,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_o_fixnum_difference(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx*? in k8834 */
static void C_ccall f_10746(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10746,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_o_fixnum_times(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.fixnum#fx/? in k8834 */
static void C_ccall f_10749(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10749,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_o_fixnum_quotient(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10751 in k8834 */
static void C_ccall f_10753(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word t69;
C_word t70;
C_word t71;
C_word t72;
C_word t73;
C_word t74;
C_word t75;
C_word t76;
C_word t77;
C_word t78;
C_word t79;
C_word t80;
C_word t81;
C_word t82;
C_word t83;
C_word t84;
C_word t85;
C_word t86;
C_word t87;
C_word t88;
C_word t89;
C_word t90;
C_word t91;
C_word t92;
C_word t93;
C_word t94;
C_word t95;
C_word t96;
C_word t97;
C_word t98;
C_word t99;
C_word t100;
C_word t101;
C_word t102;
C_word t103;
C_word t104;
C_word t105;
C_word t106;
C_word t107;
C_word t108;
C_word t109;
C_word t110;
C_word t111;
C_word t112;
C_word t113;
C_word t114;
C_word t115;
C_word t116;
C_word t117;
C_word t118;
C_word t119;
C_word t120;
C_word t121;
C_word t122;
C_word t123;
C_word t124;
C_word t125;
C_word t126;
C_word t127;
C_word t128;
C_word t129;
C_word t130;
C_word t131;
C_word t132;
C_word t133;
C_word t134;
C_word t135;
C_word t136;
C_word t137;
C_word t138;
C_word t139;
C_word t140;
C_word t141;
C_word t142;
C_word t143;
C_word t144;
C_word t145;
C_word t146;
C_word t147;
C_word t148;
C_word t149;
C_word t150;
C_word t151;
C_word t152;
C_word t153;
C_word t154;
C_word t155;
C_word t156;
C_word t157;
C_word t158;
C_word t159;
C_word t160;
C_word t161;
C_word t162;
C_word t163;
C_word t164;
C_word t165;
C_word t166;
C_word t167;
C_word t168;
C_word t169;
C_word t170;
C_word t171;
C_word t172;
C_word t173;
C_word t174;
C_word t175;
C_word t176;
C_word t177;
C_word t178;
C_word t179;
C_word t180;
C_word t181;
C_word t182;
C_word t183;
C_word t184;
C_word t185;
C_word t186;
C_word t187;
C_word t188;
C_word t189;
C_word t190;
C_word t191;
C_word t192;
C_word t193;
C_word t194;
C_word t195;
C_word t196;
C_word t197;
C_word t198;
C_word t199;
C_word t200;
C_word t201;
C_word t202;
C_word t203;
C_word t204;
C_word t205;
C_word t206;
C_word t207;
C_word t208;
C_word t209;
C_word t210;
C_word t211;
C_word t212;
C_word t213;
C_word t214;
C_word t215;
C_word t216;
C_word t217;
C_word t218;
C_word t219;
C_word t220;
C_word t221;
C_word t222;
C_word t223;
C_word t224;
C_word t225;
C_word t226;
C_word t227;
C_word t228;
C_word t229;
C_word t230;
C_word t231;
C_word t232;
C_word t233;
C_word t234;
C_word t235;
C_word t236;
C_word t237;
C_word t238;
C_word t239;
C_word t240;
C_word t241;
C_word t242;
C_word t243;
C_word t244;
C_word t245;
C_word t246;
C_word t247;
C_word t248;
C_word t249;
C_word t250;
C_word t251;
C_word t252;
C_word t253;
C_word t254;
C_word t255;
C_word t256;
C_word t257;
C_word t258;
C_word t259;
C_word t260;
C_word t261;
C_word t262;
C_word t263;
C_word t264;
C_word t265;
C_word t266;
C_word t267;
C_word t268;
C_word t269;
C_word t270;
C_word t271;
C_word t272;
C_word t273;
C_word t274;
C_word t275;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(752,c,6)))){
C_save_and_reclaim((void *)f_10753,c,av);}
a=C_alloc(752);
t2=C_mutate((C_word*)lf[308]+1 /* (set! ##sys#debug-mode? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10755,a[2]=((C_word)li227),tmp=(C_word)a,a+=3,tmp));
t3=C_set_block_item(lf[309] /* ##sys#warnings-enabled */,0,C_SCHEME_TRUE);
t4=C_set_block_item(lf[310] /* ##sys#notices-enabled */,0,C_i_debug_modep());
t5=C_mutate((C_word*)lf[311]+1 /* (set! chicken.base#warning ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10760,a[2]=((C_word)li228),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[313]+1 /* (set! chicken.base#notice ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10769,a[2]=((C_word)li229),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[315]+1 /* (set! chicken.base#enable-warnings ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10781,a[2]=((C_word)li230),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[155]+1 /* (set! ##sys#error ...) */,*((C_word*)lf[193]+1));
t9=C_mutate((C_word*)lf[316]+1 /* (set! ##sys#warn ...) */,*((C_word*)lf[311]+1));
t10=C_mutate((C_word*)lf[317]+1 /* (set! ##sys#notice ...) */,*((C_word*)lf[313]+1));
t11=C_mutate((C_word*)lf[318]+1 /* (set! ##sys#error/errno ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10795,a[2]=((C_word)li231),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate((C_word*)lf[320]+1 /* (set! ##sys#gc ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_gc,a[2]=((C_word)li232),tmp=(C_word)a,a+=3,tmp));
t13=C_mutate((C_word*)lf[321]+1 /* (set! ##sys#setslot ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10811,a[2]=((C_word)li233),tmp=(C_word)a,a+=3,tmp));
t14=C_mutate((C_word*)lf[322]+1 /* (set! ##sys#setislot ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10814,a[2]=((C_word)li234),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[323]+1 /* (set! ##sys#allocate-vector ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_allocate_vector,a[2]=((C_word)li235),tmp=(C_word)a,a+=3,tmp));
t16=C_mutate((C_word*)lf[324]+1 /* (set! ##sys#make-structure ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_make_structure,a[2]=((C_word)li236),tmp=(C_word)a,a+=3,tmp));
t17=C_mutate((C_word*)lf[325]+1 /* (set! ##sys#ensure-heap-reserve ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_ensure_heap_reserve,a[2]=((C_word)li237),tmp=(C_word)a,a+=3,tmp));
t18=C_mutate((C_word*)lf[326]+1 /* (set! ##sys#symbol-table-info ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_get_symbol_table_info,a[2]=((C_word)li238),tmp=(C_word)a,a+=3,tmp));
t19=C_mutate((C_word*)lf[327]+1 /* (set! ##sys#memory-info ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_get_memory_info,a[2]=((C_word)li239),tmp=(C_word)a,a+=3,tmp));
t20=C_mutate((C_word*)lf[328]+1 /* (set! ##sys#start-timer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10822,a[2]=((C_word)li240),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate((C_word*)lf[329]+1 /* (set! ##sys#stop-timer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10828,a[2]=((C_word)li243),tmp=(C_word)a,a+=3,tmp));
t22=C_mutate((C_word*)lf[330]+1 /* (set! ##sys#immediate? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10848,a[2]=((C_word)li244),tmp=(C_word)a,a+=3,tmp));
t23=C_mutate((C_word*)lf[331]+1 /* (set! ##sys#message ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10855,a[2]=((C_word)li245),tmp=(C_word)a,a+=3,tmp));
t24=C_mutate((C_word*)lf[332]+1 /* (set! ##sys#byte ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10858,a[2]=((C_word)li246),tmp=(C_word)a,a+=3,tmp));
t25=C_mutate((C_word*)lf[333]+1 /* (set! ##sys#setbyte ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10861,a[2]=((C_word)li247),tmp=(C_word)a,a+=3,tmp));
t26=C_mutate((C_word*)lf[334]+1 /* (set! ##sys#void ...) */,*((C_word*)lf[196]+1));
t27=C_set_block_item(lf[246] /* ##sys#undefined-value */,0,C_SCHEME_UNDEFINED);
t28=C_mutate((C_word*)lf[335]+1 /* (set! ##sys#halt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10866,a[2]=((C_word)li248),tmp=(C_word)a,a+=3,tmp));
t29=C_mutate((C_word*)lf[336]+1 /* (set! ##sys#become! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_become,a[2]=((C_word)li249),tmp=(C_word)a,a+=3,tmp));
t30=C_mutate((C_word*)lf[337]+1 /* (set! ##sys#block-ref ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10870,a[2]=((C_word)li250),tmp=(C_word)a,a+=3,tmp));
t31=C_mutate((C_word*)lf[338]+1 /* (set! ##sys#apply-values ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_apply_values,a[2]=((C_word)li251),tmp=(C_word)a,a+=3,tmp));
t32=C_mutate((C_word*)lf[339]+1 /* (set! ##sys#copy-closure ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_copy_closure,a[2]=((C_word)li252),tmp=(C_word)a,a+=3,tmp));
t33=C_mutate((C_word*)lf[340]+1 /* (set! ##sys#block-set! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10875,a[2]=((C_word)li253),tmp=(C_word)a,a+=3,tmp));
t34=C_a_i_provide(&a,1,lf[343]);
t35=C_mutate((C_word*)lf[344]+1 /* (set! chicken.time#current-milliseconds ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10910,a[2]=((C_word)li254),tmp=(C_word)a,a+=3,tmp));
t36=C_mutate((C_word*)lf[345]+1 /* (set! chicken.time#current-process-milliseconds ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10913,a[2]=((C_word)li255),tmp=(C_word)a,a+=3,tmp));
t37=C_mutate((C_word*)lf[346]+1 /* (set! chicken.time#current-seconds ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10916,a[2]=((C_word)li256),tmp=(C_word)a,a+=3,tmp));
t38=C_mutate((C_word*)lf[347]+1 /* (set! chicken.time#cpu-time ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10919,a[2]=((C_word)li257),tmp=(C_word)a,a+=3,tmp));
t39=C_mutate((C_word*)lf[348]+1 /* (set! ##sys#check-structure ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10936,a[2]=((C_word)li258),tmp=(C_word)a,a+=3,tmp));
t40=C_mutate((C_word*)lf[349]+1 /* (set! ##sys#check-blob ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10947,a[2]=((C_word)li259),tmp=(C_word)a,a+=3,tmp));
t41=C_mutate((C_word*)lf[350]+1 /* (set! ##sys#check-byte-vector ...) */,*((C_word*)lf[349]+1));
t42=C_mutate((C_word*)lf[351]+1 /* (set! ##sys#check-pair ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10959,a[2]=((C_word)li260),tmp=(C_word)a,a+=3,tmp));
t43=C_mutate((C_word*)lf[352]+1 /* (set! ##sys#check-list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10970,a[2]=((C_word)li261),tmp=(C_word)a,a+=3,tmp));
t44=C_mutate((C_word*)lf[353]+1 /* (set! ##sys#check-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10981,a[2]=((C_word)li262),tmp=(C_word)a,a+=3,tmp));
t45=C_mutate((C_word*)lf[354]+1 /* (set! ##sys#check-number ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10992,a[2]=((C_word)li263),tmp=(C_word)a,a+=3,tmp));
t46=C_mutate((C_word*)lf[102]+1 /* (set! ##sys#check-fixnum ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11003,a[2]=((C_word)li264),tmp=(C_word)a,a+=3,tmp));
t47=C_mutate((C_word*)lf[355]+1 /* (set! ##sys#check-exact ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11014,a[2]=((C_word)li265),tmp=(C_word)a,a+=3,tmp));
t48=C_mutate((C_word*)lf[356]+1 /* (set! ##sys#check-inexact ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11025,a[2]=((C_word)li266),tmp=(C_word)a,a+=3,tmp));
t49=C_mutate((C_word*)lf[357]+1 /* (set! ##sys#check-symbol ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11036,a[2]=((C_word)li267),tmp=(C_word)a,a+=3,tmp));
t50=C_mutate((C_word*)lf[358]+1 /* (set! ##sys#check-keyword ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11047,a[2]=((C_word)li268),tmp=(C_word)a,a+=3,tmp));
t51=C_mutate((C_word*)lf[359]+1 /* (set! ##sys#check-vector ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11058,a[2]=((C_word)li269),tmp=(C_word)a,a+=3,tmp));
t52=C_mutate((C_word*)lf[360]+1 /* (set! ##sys#check-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11069,a[2]=((C_word)li270),tmp=(C_word)a,a+=3,tmp));
t53=C_mutate((C_word*)lf[361]+1 /* (set! ##sys#check-boolean ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11080,a[2]=((C_word)li271),tmp=(C_word)a,a+=3,tmp));
t54=C_mutate((C_word*)lf[362]+1 /* (set! ##sys#check-locative ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11091,a[2]=((C_word)li272),tmp=(C_word)a,a+=3,tmp));
t55=C_mutate((C_word*)lf[363]+1 /* (set! ##sys#check-integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11102,a[2]=((C_word)li273),tmp=(C_word)a,a+=3,tmp));
t56=C_mutate((C_word*)lf[365]+1 /* (set! ##sys#check-exact-integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11119,a[2]=((C_word)li274),tmp=(C_word)a,a+=3,tmp));
t57=C_mutate((C_word*)lf[367]+1 /* (set! ##sys#check-exact-uinteger ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11136,a[2]=((C_word)li275),tmp=(C_word)a,a+=3,tmp));
t58=C_mutate((C_word*)lf[369]+1 /* (set! ##sys#check-real ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11160,a[2]=((C_word)li276),tmp=(C_word)a,a+=3,tmp));
t59=C_mutate((C_word*)lf[341]+1 /* (set! ##sys#check-range ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11177,a[2]=((C_word)li277),tmp=(C_word)a,a+=3,tmp));
t60=C_mutate((C_word*)lf[372]+1 /* (set! ##sys#check-special ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11207,a[2]=((C_word)li278),tmp=(C_word)a,a+=3,tmp));
t61=C_mutate((C_word*)lf[374]+1 /* (set! ##sys#check-closure ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11227,a[2]=((C_word)li279),tmp=(C_word)a,a+=3,tmp));
t62=C_mutate((C_word*)lf[375]+1 /* (set! scheme#force ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11238,a[2]=((C_word)li281),tmp=(C_word)a,a+=3,tmp));
t63=C_mutate((C_word*)lf[377]+1 /* (set! ##sys#dload ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_dload,a[2]=((C_word)li282),tmp=(C_word)a,a+=3,tmp));
t64=C_mutate((C_word*)lf[378]+1 /* (set! ##sys#set-dlopen-flags! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_set_dlopen_flags,a[2]=((C_word)li283),tmp=(C_word)a,a+=3,tmp));
t65=C_mutate((C_word*)lf[47]+1 /* (set! ##sys#error-not-a-proper-list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11366,a[2]=((C_word)li284),tmp=(C_word)a,a+=3,tmp));
t66=C_mutate((C_word*)lf[379]+1 /* (set! ##sys#error-bad-number ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11382,a[2]=((C_word)li285),tmp=(C_word)a,a+=3,tmp));
t67=C_mutate((C_word*)lf[364]+1 /* (set! ##sys#error-bad-integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11398,a[2]=((C_word)li286),tmp=(C_word)a,a+=3,tmp));
t68=C_mutate((C_word*)lf[366]+1 /* (set! ##sys#error-bad-exact-integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11414,a[2]=((C_word)li287),tmp=(C_word)a,a+=3,tmp));
t69=C_mutate((C_word*)lf[368]+1 /* (set! ##sys#error-bad-exact-uinteger ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11430,a[2]=((C_word)li288),tmp=(C_word)a,a+=3,tmp));
t70=C_mutate((C_word*)lf[380]+1 /* (set! ##sys#error-bad-inexact ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11446,a[2]=((C_word)li289),tmp=(C_word)a,a+=3,tmp));
t71=C_mutate((C_word*)lf[370]+1 /* (set! ##sys#error-bad-real ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11462,a[2]=((C_word)li290),tmp=(C_word)a,a+=3,tmp));
t72=C_mutate((C_word*)lf[381]+1 /* (set! ##sys#error-bad-base ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11478,a[2]=((C_word)li291),tmp=(C_word)a,a+=3,tmp));
t73=C_mutate((C_word*)lf[382]+1 /* (set! scheme#append ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11494,a[2]=((C_word)li294),tmp=(C_word)a,a+=3,tmp));
t74=C_mutate((C_word*)lf[384]+1 /* (set! ##sys#fast-reverse ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11573,a[2]=((C_word)li296),tmp=(C_word)a,a+=3,tmp));
t75=C_mutate((C_word*)lf[385]+1 /* (set! ##sys#make-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11603,a[2]=((C_word)li297),tmp=(C_word)a,a+=3,tmp));
t76=C_mutate((C_word*)lf[386]+1 /* (set! scheme#make-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11623,a[2]=((C_word)li298),tmp=(C_word)a,a+=3,tmp));
t77=C_mutate((C_word*)lf[390]+1 /* (set! scheme#string->list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11659,a[2]=((C_word)li300),tmp=(C_word)a,a+=3,tmp));
t78=C_mutate((C_word*)lf[392]+1 /* (set! ##sys#string->list ...) */,*((C_word*)lf[390]+1));
t79=C_mutate((C_word*)lf[393]+1 /* (set! scheme#list->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11697,a[2]=((C_word)li302),tmp=(C_word)a,a+=3,tmp));
t80=C_mutate((C_word*)lf[395]+1 /* (set! ##sys#list->string ...) */,*((C_word*)lf[393]+1));
t81=C_mutate((C_word*)lf[396]+1 /* (set! ##sys#reverse-list->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11749,a[2]=((C_word)li304),tmp=(C_word)a,a+=3,tmp));
t82=C_mutate((C_word*)lf[398]+1 /* (set! scheme#string-fill! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11798,a[2]=((C_word)li305),tmp=(C_word)a,a+=3,tmp));
t83=C_mutate((C_word*)lf[400]+1 /* (set! scheme#string-copy ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11811,a[2]=((C_word)li306),tmp=(C_word)a,a+=3,tmp));
t84=C_mutate((C_word*)lf[402]+1 /* (set! scheme#substring ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11823,a[2]=((C_word)li307),tmp=(C_word)a,a+=3,tmp));
t85=C_mutate((C_word*)lf[404]+1 /* (set! ##sys#substring ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11873,a[2]=((C_word)li308),tmp=(C_word)a,a+=3,tmp));
t86=C_SCHEME_UNDEFINED;
t87=(*a=C_VECTOR_TYPE|1,a[1]=t86,tmp=(C_word)a,a+=2,tmp);
t88=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11882,a[2]=((C_word)li309),tmp=(C_word)a,a+=3,tmp);
t89=C_set_block_item(t87,0,t88);
t90=C_mutate((C_word*)lf[405]+1 /* (set! scheme#string<? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11903,a[2]=t87,a[3]=((C_word)li311),tmp=(C_word)a,a+=4,tmp));
t91=C_mutate((C_word*)lf[407]+1 /* (set! scheme#string>? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11927,a[2]=t87,a[3]=((C_word)li313),tmp=(C_word)a,a+=4,tmp));
t92=C_mutate((C_word*)lf[409]+1 /* (set! scheme#string<=? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11951,a[2]=t87,a[3]=((C_word)li315),tmp=(C_word)a,a+=4,tmp));
t93=C_mutate((C_word*)lf[411]+1 /* (set! scheme#string>=? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11972,a[2]=t87,a[3]=((C_word)li317),tmp=(C_word)a,a+=4,tmp));
t94=C_SCHEME_UNDEFINED;
t95=(*a=C_VECTOR_TYPE|1,a[1]=t94,tmp=(C_word)a,a+=2,tmp);
t96=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11992,a[2]=((C_word)li318),tmp=(C_word)a,a+=3,tmp);
t97=C_set_block_item(t95,0,t96);
t98=C_mutate((C_word*)lf[413]+1 /* (set! scheme#string-ci<? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12013,a[2]=t95,a[3]=((C_word)li320),tmp=(C_word)a,a+=4,tmp));
t99=C_mutate((C_word*)lf[415]+1 /* (set! scheme#string-ci>? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12037,a[2]=t95,a[3]=((C_word)li322),tmp=(C_word)a,a+=4,tmp));
t100=C_mutate((C_word*)lf[417]+1 /* (set! scheme#string-ci<=? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12061,a[2]=t95,a[3]=((C_word)li324),tmp=(C_word)a,a+=4,tmp));
t101=C_mutate((C_word*)lf[419]+1 /* (set! scheme#string-ci>=? ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12082,a[2]=t95,a[3]=((C_word)li326),tmp=(C_word)a,a+=4,tmp));
t102=C_mutate((C_word*)lf[421]+1 /* (set! ##sys#string-append ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12103,a[2]=((C_word)li327),tmp=(C_word)a,a+=3,tmp));
t103=C_mutate((C_word*)lf[422]+1 /* (set! scheme#string-append ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12119,a[2]=((C_word)li329),tmp=(C_word)a,a+=3,tmp));
t104=C_mutate((C_word*)lf[424]+1 /* (set! scheme#string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12158,a[2]=((C_word)li330),tmp=(C_word)a,a+=3,tmp));
t105=C_mutate((C_word*)lf[425]+1 /* (set! ##sys#fragments->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12164,a[2]=((C_word)li332),tmp=(C_word)a,a+=3,tmp));
t106=C_mutate((C_word*)lf[426]+1 /* (set! chicken.base#chop ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12199,a[2]=((C_word)li335),tmp=(C_word)a,a+=3,tmp));
t107=C_a_i_provide(&a,1,lf[429]);
t108=C_mutate((C_word*)lf[430]+1 /* (set! chicken.flonum#maximum-flonum ...) */,C_flonum(&a,DBL_MAX));
t109=C_mutate((C_word*)lf[431]+1 /* (set! chicken.flonum#minimum-flonum ...) */,C_flonum(&a,DBL_MIN));
t110=C_set_block_item(lf[432] /* chicken.flonum#flonum-radix */,0,C_fix((C_word)FLT_RADIX));
t111=C_mutate((C_word*)lf[433]+1 /* (set! chicken.flonum#flonum-epsilon ...) */,C_flonum(&a,DBL_EPSILON));
t112=C_set_block_item(lf[434] /* chicken.flonum#flonum-precision */,0,C_fix((C_word)DBL_MANT_DIG));
t113=C_set_block_item(lf[435] /* chicken.flonum#flonum-decimal-precision */,0,C_fix((C_word)DBL_DIG));
t114=C_set_block_item(lf[436] /* chicken.flonum#flonum-maximum-exponent */,0,C_fix((C_word)DBL_MAX_EXP));
t115=C_set_block_item(lf[437] /* chicken.flonum#flonum-minimum-exponent */,0,C_fix((C_word)DBL_MIN_EXP));
t116=C_set_block_item(lf[438] /* chicken.flonum#flonum-maximum-decimal-exponent */,0,C_fix((C_word)DBL_MAX_10_EXP));
t117=C_set_block_item(lf[439] /* chicken.flonum#flonum-minimum-decimal-exponent */,0,C_fix((C_word)DBL_MIN_10_EXP));
t118=C_mutate((C_word*)lf[440]+1 /* (set! chicken.flonum#fp+ ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12294,a[2]=((C_word)li336),tmp=(C_word)a,a+=3,tmp));
t119=C_mutate((C_word*)lf[442]+1 /* (set! chicken.flonum#fp- ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12318,a[2]=((C_word)li337),tmp=(C_word)a,a+=3,tmp));
t120=C_mutate((C_word*)lf[444]+1 /* (set! chicken.flonum#fp* ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12342,a[2]=((C_word)li338),tmp=(C_word)a,a+=3,tmp));
t121=C_mutate((C_word*)lf[446]+1 /* (set! chicken.flonum#fp/ ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12366,a[2]=((C_word)li339),tmp=(C_word)a,a+=3,tmp));
t122=C_mutate((C_word*)lf[448]+1 /* (set! chicken.flonum#fp*+ ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12390,a[2]=((C_word)li340),tmp=(C_word)a,a+=3,tmp));
t123=C_mutate((C_word*)lf[450]+1 /* (set! chicken.flonum#fpgcd ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12415,a[2]=((C_word)li341),tmp=(C_word)a,a+=3,tmp));
t124=C_mutate((C_word*)lf[452]+1 /* (set! chicken.flonum#fp/? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12439,a[2]=((C_word)li342),tmp=(C_word)a,a+=3,tmp));
t125=C_mutate((C_word*)lf[454]+1 /* (set! chicken.flonum#fp= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12463,a[2]=((C_word)li343),tmp=(C_word)a,a+=3,tmp));
t126=C_mutate((C_word*)lf[456]+1 /* (set! chicken.flonum#fp> ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12487,a[2]=((C_word)li344),tmp=(C_word)a,a+=3,tmp));
t127=C_mutate((C_word*)lf[458]+1 /* (set! chicken.flonum#fp< ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12511,a[2]=((C_word)li345),tmp=(C_word)a,a+=3,tmp));
t128=C_mutate((C_word*)lf[460]+1 /* (set! chicken.flonum#fp>= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12535,a[2]=((C_word)li346),tmp=(C_word)a,a+=3,tmp));
t129=C_mutate((C_word*)lf[462]+1 /* (set! chicken.flonum#fp<= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12559,a[2]=((C_word)li347),tmp=(C_word)a,a+=3,tmp));
t130=C_mutate((C_word*)lf[464]+1 /* (set! chicken.flonum#fpneg ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12583,a[2]=((C_word)li348),tmp=(C_word)a,a+=3,tmp));
t131=C_mutate((C_word*)lf[466]+1 /* (set! chicken.flonum#fpmax ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12601,a[2]=((C_word)li349),tmp=(C_word)a,a+=3,tmp));
t132=C_mutate((C_word*)lf[468]+1 /* (set! chicken.flonum#fpmin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12625,a[2]=((C_word)li350),tmp=(C_word)a,a+=3,tmp));
t133=C_mutate((C_word*)lf[470]+1 /* (set! chicken.flonum#fpfloor ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12649,a[2]=((C_word)li351),tmp=(C_word)a,a+=3,tmp));
t134=C_mutate((C_word*)lf[472]+1 /* (set! chicken.flonum#fptruncate ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12667,a[2]=((C_word)li352),tmp=(C_word)a,a+=3,tmp));
t135=C_mutate((C_word*)lf[474]+1 /* (set! chicken.flonum#fpround ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12685,a[2]=((C_word)li353),tmp=(C_word)a,a+=3,tmp));
t136=C_mutate((C_word*)lf[476]+1 /* (set! chicken.flonum#fpceiling ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12703,a[2]=((C_word)li354),tmp=(C_word)a,a+=3,tmp));
t137=C_mutate((C_word*)lf[478]+1 /* (set! chicken.flonum#fpsin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12721,a[2]=((C_word)li355),tmp=(C_word)a,a+=3,tmp));
t138=C_mutate((C_word*)lf[480]+1 /* (set! chicken.flonum#fpcos ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12739,a[2]=((C_word)li356),tmp=(C_word)a,a+=3,tmp));
t139=C_mutate((C_word*)lf[482]+1 /* (set! chicken.flonum#fptan ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12757,a[2]=((C_word)li357),tmp=(C_word)a,a+=3,tmp));
t140=C_mutate((C_word*)lf[484]+1 /* (set! chicken.flonum#fpasin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12775,a[2]=((C_word)li358),tmp=(C_word)a,a+=3,tmp));
t141=C_mutate((C_word*)lf[486]+1 /* (set! chicken.flonum#fpacos ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12793,a[2]=((C_word)li359),tmp=(C_word)a,a+=3,tmp));
t142=C_mutate((C_word*)lf[488]+1 /* (set! chicken.flonum#fpatan ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12811,a[2]=((C_word)li360),tmp=(C_word)a,a+=3,tmp));
t143=C_mutate((C_word*)lf[490]+1 /* (set! chicken.flonum#fpatan2 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12829,a[2]=((C_word)li361),tmp=(C_word)a,a+=3,tmp));
t144=C_mutate((C_word*)lf[492]+1 /* (set! chicken.flonum#fpsinh ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12853,a[2]=((C_word)li362),tmp=(C_word)a,a+=3,tmp));
t145=C_mutate((C_word*)lf[494]+1 /* (set! chicken.flonum#fpcosh ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12871,a[2]=((C_word)li363),tmp=(C_word)a,a+=3,tmp));
t146=C_mutate((C_word*)lf[496]+1 /* (set! chicken.flonum#fptanh ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12889,a[2]=((C_word)li364),tmp=(C_word)a,a+=3,tmp));
t147=C_mutate((C_word*)lf[498]+1 /* (set! chicken.flonum#fpasinh ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12907,a[2]=((C_word)li365),tmp=(C_word)a,a+=3,tmp));
t148=C_mutate((C_word*)lf[500]+1 /* (set! chicken.flonum#fpacosh ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12925,a[2]=((C_word)li366),tmp=(C_word)a,a+=3,tmp));
t149=C_mutate((C_word*)lf[502]+1 /* (set! chicken.flonum#fpatanh ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12943,a[2]=((C_word)li367),tmp=(C_word)a,a+=3,tmp));
t150=C_mutate((C_word*)lf[504]+1 /* (set! chicken.flonum#fpexp ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12961,a[2]=((C_word)li368),tmp=(C_word)a,a+=3,tmp));
t151=C_mutate((C_word*)lf[506]+1 /* (set! chicken.flonum#fpexpt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12979,a[2]=((C_word)li369),tmp=(C_word)a,a+=3,tmp));
t152=C_mutate((C_word*)lf[508]+1 /* (set! chicken.flonum#fplog ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13003,a[2]=((C_word)li370),tmp=(C_word)a,a+=3,tmp));
t153=C_mutate((C_word*)lf[510]+1 /* (set! chicken.flonum#fpsqrt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13021,a[2]=((C_word)li371),tmp=(C_word)a,a+=3,tmp));
t154=C_mutate((C_word*)lf[512]+1 /* (set! chicken.flonum#fpabs ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13039,a[2]=((C_word)li372),tmp=(C_word)a,a+=3,tmp));
t155=C_mutate((C_word*)lf[514]+1 /* (set! chicken.flonum#fpinteger? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13057,a[2]=((C_word)li373),tmp=(C_word)a,a+=3,tmp));
t156=C_mutate((C_word*)lf[516]+1 /* (set! chicken.flonum#flonum-print-precision ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13075,a[2]=((C_word)li374),tmp=(C_word)a,a+=3,tmp));
t157=C_mutate((C_word*)lf[518]+1 /* (set! ##sys#number? ...) */,*((C_word*)lf[77]+1));
t158=C_mutate((C_word*)lf[519]+1 /* (set! ##sys#integer? ...) */,*((C_word*)lf[81]+1));
t159=C_mutate((C_word*)lf[520]+1 /* (set! ##sys#exact? ...) */,*((C_word*)lf[82]+1));
t160=C_mutate((C_word*)lf[521]+1 /* (set! ##sys#inexact? ...) */,*((C_word*)lf[83]+1));
t161=C_mutate(&lf[522] /* (set! make-complex ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13097,a[2]=((C_word)li375),tmp=(C_word)a,a+=3,tmp));
t162=C_mutate((C_word*)lf[524]+1 /* (set! scheme#make-rectangular ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13133,a[2]=((C_word)li376),tmp=(C_word)a,a+=3,tmp));
t163=C_mutate((C_word*)lf[526]+1 /* (set! scheme#make-polar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13145,a[2]=((C_word)li377),tmp=(C_word)a,a+=3,tmp));
t164=C_mutate((C_word*)lf[528]+1 /* (set! scheme#real-part ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13168,a[2]=((C_word)li378),tmp=(C_word)a,a+=3,tmp));
t165=C_mutate((C_word*)lf[530]+1 /* (set! scheme#imag-part ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13191,a[2]=((C_word)li379),tmp=(C_word)a,a+=3,tmp));
t166=C_mutate((C_word*)lf[532]+1 /* (set! scheme#angle ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13217,a[2]=((C_word)li380),tmp=(C_word)a,a+=3,tmp));
t167=C_mutate((C_word*)lf[534]+1 /* (set! scheme#magnitude ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13233,a[2]=((C_word)li381),tmp=(C_word)a,a+=3,tmp));
t168=C_mutate(&lf[537] /* (set! ratnum ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13277,a[2]=((C_word)li382),tmp=(C_word)a,a+=3,tmp));
t169=C_mutate((C_word*)lf[538]+1 /* (set! scheme#numerator ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13323,a[2]=((C_word)li383),tmp=(C_word)a,a+=3,tmp));
t170=C_mutate((C_word*)lf[542]+1 /* (set! scheme#denominator ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13369,a[2]=((C_word)li384),tmp=(C_word)a,a+=3,tmp));
t171=C_mutate((C_word*)lf[546]+1 /* (set! ##sys#extended-signum ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13415,a[2]=((C_word)li385),tmp=(C_word)a,a+=3,tmp));
t172=C_mutate((C_word*)lf[540]+1 /* (set! scheme#inexact->exact ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13539,a[2]=((C_word)li388),tmp=(C_word)a,a+=3,tmp));
t173=C_mutate((C_word*)lf[553]+1 /* (set! ##sys#exact->inexact ...) */,*((C_word*)lf[62]+1));
t174=C_mutate((C_word*)lf[554]+1 /* (set! ##sys#inexact->exact ...) */,*((C_word*)lf[540]+1));
t175=C_a_i_provide(&a,1,lf[555]);
t176=C_mutate((C_word*)lf[556]+1 /* (set! chicken.bitwise#bitwise-and ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_bitwise_and,a[2]=((C_word)li389),tmp=(C_word)a,a+=3,tmp));
t177=C_mutate((C_word*)lf[557]+1 /* (set! chicken.bitwise#bitwise-ior ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_bitwise_ior,a[2]=((C_word)li390),tmp=(C_word)a,a+=3,tmp));
t178=C_mutate((C_word*)lf[558]+1 /* (set! chicken.bitwise#bitwise-xor ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_bitwise_xor,a[2]=((C_word)li391),tmp=(C_word)a,a+=3,tmp));
t179=C_mutate((C_word*)lf[559]+1 /* (set! chicken.bitwise#bitwise-not ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13605,a[2]=((C_word)li392),tmp=(C_word)a,a+=3,tmp));
t180=C_mutate((C_word*)lf[560]+1 /* (set! chicken.bitwise#bit->boolean ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13608,a[2]=((C_word)li393),tmp=(C_word)a,a+=3,tmp));
t181=C_mutate((C_word*)lf[561]+1 /* (set! chicken.bitwise#integer-length ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13611,a[2]=((C_word)li394),tmp=(C_word)a,a+=3,tmp));
t182=C_mutate((C_word*)lf[562]+1 /* (set! chicken.bitwise#arithmetic-shift ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13614,a[2]=((C_word)li395),tmp=(C_word)a,a+=3,tmp));
t183=C_mutate((C_word*)lf[563]+1 /* (set! scheme#/ ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13617,a[2]=((C_word)li397),tmp=(C_word)a,a+=3,tmp));
t184=C_mutate((C_word*)lf[548]+1 /* (set! ##sys#/-2 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13668,a[2]=((C_word)li398),tmp=(C_word)a,a+=3,tmp));
t185=C_mutate((C_word*)lf[566]+1 /* (set! scheme#floor ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13951,a[2]=((C_word)li399),tmp=(C_word)a,a+=3,tmp));
t186=C_mutate((C_word*)lf[568]+1 /* (set! scheme#ceiling ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13996,a[2]=((C_word)li400),tmp=(C_word)a,a+=3,tmp));
t187=C_mutate((C_word*)lf[570]+1 /* (set! scheme#truncate ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14041,a[2]=((C_word)li401),tmp=(C_word)a,a+=3,tmp));
t188=C_mutate((C_word*)lf[572]+1 /* (set! scheme#round ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14078,a[2]=((C_word)li402),tmp=(C_word)a,a+=3,tmp));
t189=C_mutate(&lf[574] /* (set! find-ratio-between ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14122,a[2]=((C_word)li404),tmp=(C_word)a,a+=3,tmp));
t190=C_mutate((C_word*)lf[576]+1 /* (set! scheme#rationalize ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14272,a[2]=((C_word)li405),tmp=(C_word)a,a+=3,tmp));
t191=C_mutate((C_word*)lf[577]+1 /* (set! scheme#max ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14297,a[2]=((C_word)li407),tmp=(C_word)a,a+=3,tmp));
t192=C_mutate((C_word*)lf[579]+1 /* (set! scheme#min ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14341,a[2]=((C_word)li409),tmp=(C_word)a,a+=3,tmp));
t193=C_mutate((C_word*)lf[581]+1 /* (set! scheme#exp ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14385,a[2]=((C_word)li410),tmp=(C_word)a,a+=3,tmp));
t194=C_mutate((C_word*)lf[583]+1 /* (set! ##sys#log-1 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14430,a[2]=((C_word)li411),tmp=(C_word)a,a+=3,tmp));
t195=C_mutate((C_word*)lf[587]+1 /* (set! scheme#log ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14479,a[2]=((C_word)li412),tmp=(C_word)a,a+=3,tmp));
t196=C_mutate((C_word*)lf[588]+1 /* (set! scheme#sin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14508,a[2]=((C_word)li413),tmp=(C_word)a,a+=3,tmp));
t197=C_mutate((C_word*)lf[592]+1 /* (set! scheme#cos ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14542,a[2]=((C_word)li414),tmp=(C_word)a,a+=3,tmp));
t198=C_mutate((C_word*)lf[594]+1 /* (set! scheme#tan ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14576,a[2]=((C_word)li415),tmp=(C_word)a,a+=3,tmp));
t199=C_mutate((C_word*)lf[596]+1 /* (set! scheme#asin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14601,a[2]=((C_word)li416),tmp=(C_word)a,a+=3,tmp));
t200=C_a_i_asin(&a,1,C_fix(1));
t201=C_mutate((C_word*)lf[601]+1 /* (set! scheme#acos ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14663,a[2]=t200,a[3]=((C_word)li417),tmp=(C_word)a,a+=4,tmp));
t202=C_mutate((C_word*)lf[603]+1 /* (set! scheme#atan ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14705,a[2]=((C_word)li418),tmp=(C_word)a,a+=3,tmp));
t203=C_mutate((C_word*)lf[605]+1 /* (set! ##sys#exact-integer-sqrt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14769,a[2]=((C_word)li424),tmp=(C_word)a,a+=3,tmp));
t204=C_mutate((C_word*)lf[607]+1 /* (set! chicken.base#exact-integer-sqrt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14960,a[2]=((C_word)li425),tmp=(C_word)a,a+=3,tmp));
t205=C_mutate((C_word*)lf[599]+1 /* (set! ##sys#sqrt/loc ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14969,a[2]=((C_word)li432),tmp=(C_word)a,a+=3,tmp));
t206=C_mutate((C_word*)lf[535]+1 /* (set! scheme#sqrt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15124,a[2]=((C_word)li433),tmp=(C_word)a,a+=3,tmp));
t207=C_mutate((C_word*)lf[610]+1 /* (set! chicken.base#exact-integer-nth-root ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15130,a[2]=((C_word)li434),tmp=(C_word)a,a+=3,tmp));
t208=C_mutate((C_word*)lf[611]+1 /* (set! ##sys#exact-integer-nth-root/loc ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15142,a[2]=((C_word)li436),tmp=(C_word)a,a+=3,tmp));
t209=C_mutate((C_word*)lf[550]+1 /* (set! ##sys#integer-power ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15268,a[2]=((C_word)li438),tmp=(C_word)a,a+=3,tmp));
t210=C_mutate((C_word*)lf[552]+1 /* (set! scheme#expt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15336,a[2]=((C_word)li443),tmp=(C_word)a,a+=3,tmp));
t211=C_mutate(&lf[564] /* (set! ##sys#internal-gcd ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15603,a[2]=((C_word)li444),tmp=(C_word)a,a+=3,tmp));
t212=C_mutate((C_word*)lf[615]+1 /* (set! ##sys#gcd ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15673,a[2]=((C_word)li445),tmp=(C_word)a,a+=3,tmp));
t213=C_mutate((C_word*)lf[617]+1 /* (set! scheme#gcd ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15679,a[2]=((C_word)li447),tmp=(C_word)a,a+=3,tmp));
t214=C_mutate((C_word*)lf[618]+1 /* (set! ##sys#lcm ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15730,a[2]=((C_word)li448),tmp=(C_word)a,a+=3,tmp));
t215=C_mutate((C_word*)lf[620]+1 /* (set! scheme#lcm ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15744,a[2]=((C_word)li450),tmp=(C_word)a,a+=3,tmp));
t216=C_mutate((C_word*)lf[621]+1 /* (set! ##sys#integer->string/recursive ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15802,a[2]=((C_word)li454),tmp=(C_word)a,a+=3,tmp));
t217=C_mutate((C_word*)lf[623]+1 /* (set! ##sys#extended-number->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15855,a[2]=((C_word)li455),tmp=(C_word)a,a+=3,tmp));
t218=C_mutate(&lf[629] /* (set! round-quotient ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16029,a[2]=((C_word)li456),tmp=(C_word)a,a+=3,tmp));
t219=C_mutate(&lf[630] /* (set! ##sys#string->compnum ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16072,a[2]=((C_word)li468),tmp=(C_word)a,a+=3,tmp));
t220=C_mutate((C_word*)lf[639]+1 /* (set! scheme#string->number ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17492,a[2]=((C_word)li470),tmp=(C_word)a,a+=3,tmp));
t221=C_mutate((C_word*)lf[641]+1 /* (set! ##sys#string->number ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17747,a[2]=((C_word)li471),tmp=(C_word)a,a+=3,tmp));
t222=C_mutate((C_word*)lf[642]+1 /* (set! ##sys#fixnum->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_fixnum_to_string,a[2]=((C_word)li472),tmp=(C_word)a,a+=3,tmp));
t223=C_mutate((C_word*)lf[643]+1 /* (set! ##sys#flonum->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_flonum_to_string,a[2]=((C_word)li473),tmp=(C_word)a,a+=3,tmp));
t224=C_mutate((C_word*)lf[644]+1 /* (set! ##sys#integer->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_integer_to_string,a[2]=((C_word)li474),tmp=(C_word)a,a+=3,tmp));
t225=C_mutate((C_word*)lf[622]+1 /* (set! ##sys#number->string ...) */,*((C_word*)lf[87]+1));
t226=C_mutate((C_word*)lf[645]+1 /* (set! chicken.base#equal=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17793,a[2]=((C_word)li478),tmp=(C_word)a,a+=3,tmp));
t227=C_mutate((C_word*)lf[646]+1 /* (set! ##sys#snafu ...) */,lf[647]);
t228=C_mutate((C_word*)lf[648]+1 /* (set! ##sys#intern-symbol ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_string_to_symbol,a[2]=((C_word)li479),tmp=(C_word)a,a+=3,tmp));
t229=C_mutate((C_word*)lf[649]+1 /* (set! ##sys#intern-keyword ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_string_to_keyword,a[2]=((C_word)li480),tmp=(C_word)a,a+=3,tmp));
t230=C_mutate((C_word*)lf[650]+1 /* (set! ##sys#interned-symbol? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17965,a[2]=((C_word)li481),tmp=(C_word)a,a+=3,tmp));
t231=C_mutate((C_word*)lf[651]+1 /* (set! ##sys#string->symbol ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17968,a[2]=((C_word)li482),tmp=(C_word)a,a+=3,tmp));
t232=C_mutate((C_word*)lf[652]+1 /* (set! ##sys#symbol->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17977,a[2]=((C_word)li483),tmp=(C_word)a,a+=3,tmp));
t233=C_mutate((C_word*)lf[653]+1 /* (set! scheme#symbol->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17983,a[2]=((C_word)li484),tmp=(C_word)a,a+=3,tmp));
t234=*((C_word*)lf[400]+1);
t235=C_mutate((C_word*)lf[655]+1 /* (set! scheme#string->symbol ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17996,a[2]=t234,a[3]=((C_word)li485),tmp=(C_word)a,a+=4,tmp));
t236=*((C_word*)lf[400]+1);
t237=C_mutate((C_word*)lf[657]+1 /* (set! chicken.base#string->uninterned-symbol ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18009,a[2]=t236,a[3]=((C_word)li487),tmp=(C_word)a,a+=4,tmp));
t238=C_fix(-1);
t239=(*a=C_VECTOR_TYPE|1,a[1]=t238,tmp=(C_word)a,a+=2,tmp);
t240=C_mutate((C_word*)lf[659]+1 /* (set! chicken.base#gensym ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18022,a[2]=t239,a[3]=((C_word)li489),tmp=(C_word)a,a+=4,tmp));
t241=*((C_word*)lf[422]+1);
t242=C_mutate((C_word*)lf[663]+1 /* (set! chicken.base#symbol-append ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18076,a[2]=t241,a[3]=((C_word)li491),tmp=(C_word)a,a+=4,tmp));
t243=C_a_i_provide(&a,1,lf[665]);
t244=C_mutate((C_word*)lf[666]+1 /* (set! chicken.keyword#keyword? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18135,a[2]=((C_word)li492),tmp=(C_word)a,a+=3,tmp));
t245=C_mutate((C_word*)lf[667]+1 /* (set! chicken.keyword#string->keyword ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18138,a[2]=((C_word)li493),tmp=(C_word)a,a+=3,tmp));
t246=*((C_word*)lf[666]+1);
t247=C_mutate((C_word*)lf[669]+1 /* (set! chicken.keyword#keyword->string ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18147,a[2]=t246,a[3]=((C_word)li494),tmp=(C_word)a,a+=4,tmp));
t248=C_a_i_list1(&a,1,lf[672]);
t249=C_mutate((C_word*)lf[673]+1 /* (set! chicken.keyword#get-keyword ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18165,a[2]=t248,a[3]=((C_word)li495),tmp=(C_word)a,a+=4,tmp));
t250=C_mutate((C_word*)lf[675]+1 /* (set! ##sys#get-keyword ...) */,*((C_word*)lf[673]+1));
t251=C_a_i_provide(&a,1,lf[676]);
t252=C_mutate((C_word*)lf[677]+1 /* (set! ##sys#make-blob ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18196,a[2]=((C_word)li496),tmp=(C_word)a,a+=3,tmp));
t253=C_mutate((C_word*)lf[678]+1 /* (set! chicken.blob#make-blob ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18202,a[2]=((C_word)li497),tmp=(C_word)a,a+=3,tmp));
t254=C_mutate((C_word*)lf[680]+1 /* (set! chicken.blob#blob? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18211,a[2]=((C_word)li498),tmp=(C_word)a,a+=3,tmp));
t255=C_mutate((C_word*)lf[681]+1 /* (set! chicken.blob#blob-size ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18217,a[2]=((C_word)li499),tmp=(C_word)a,a+=3,tmp));
t256=C_mutate((C_word*)lf[683]+1 /* (set! chicken.blob#string->blob ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18226,a[2]=((C_word)li500),tmp=(C_word)a,a+=3,tmp));
t257=C_mutate((C_word*)lf[685]+1 /* (set! chicken.blob#blob->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18238,a[2]=((C_word)li501),tmp=(C_word)a,a+=3,tmp));
t258=C_mutate((C_word*)lf[687]+1 /* (set! chicken.blob#blob=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18250,a[2]=((C_word)li502),tmp=(C_word)a,a+=3,tmp));
t259=C_mutate((C_word*)lf[93]+1 /* (set! scheme#make-vector ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18273,a[2]=((C_word)li503),tmp=(C_word)a,a+=3,tmp));
t260=C_mutate((C_word*)lf[691]+1 /* (set! ##sys#make-vector ...) */,*((C_word*)lf[93]+1));
t261=C_mutate((C_word*)lf[94]+1 /* (set! scheme#list->vector ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18302,a[2]=((C_word)li505),tmp=(C_word)a,a+=3,tmp));
t262=C_mutate((C_word*)lf[95]+1 /* (set! scheme#vector->list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18354,a[2]=((C_word)li507),tmp=(C_word)a,a+=3,tmp));
t263=C_mutate((C_word*)lf[96]+1 /* (set! scheme#vector ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18387,a[2]=((C_word)li508),tmp=(C_word)a,a+=3,tmp));
t264=C_mutate((C_word*)lf[97]+1 /* (set! scheme#vector-fill! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18393,a[2]=((C_word)li510),tmp=(C_word)a,a+=3,tmp));
t265=C_mutate((C_word*)lf[206]+1 /* (set! chicken.base#vector-copy! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18421,a[2]=((C_word)li512),tmp=(C_word)a,a+=3,tmp));
t266=C_mutate((C_word*)lf[207]+1 /* (set! chicken.base#subvector ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18490,a[2]=((C_word)li514),tmp=(C_word)a,a+=3,tmp));
t267=C_mutate((C_word*)lf[208]+1 /* (set! chicken.base#vector-resize ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18561,a[2]=((C_word)li515),tmp=(C_word)a,a+=3,tmp));
t268=C_mutate(&lf[699] /* (set! ##sys#vector-resize ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18582,a[2]=((C_word)li517),tmp=(C_word)a,a+=3,tmp));
t269=C_mutate((C_word*)lf[113]+1 /* (set! scheme#char-ci=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18621,a[2]=((C_word)li518),tmp=(C_word)a,a+=3,tmp));
t270=C_mutate((C_word*)lf[114]+1 /* (set! scheme#char-ci>? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18635,a[2]=((C_word)li519),tmp=(C_word)a,a+=3,tmp));
t271=C_mutate((C_word*)lf[115]+1 /* (set! scheme#char-ci<? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18646,a[2]=((C_word)li520),tmp=(C_word)a,a+=3,tmp));
t272=C_mutate((C_word*)lf[116]+1 /* (set! scheme#char-ci>=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18657,a[2]=((C_word)li521),tmp=(C_word)a,a+=3,tmp));
t273=C_mutate((C_word*)lf[117]+1 /* (set! scheme#char-ci<=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18668,a[2]=((C_word)li522),tmp=(C_word)a,a+=3,tmp));
t274=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18681,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:2994: scheme#make-vector */
t275=*((C_word*)lf[93]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t275;
av2[1]=t274;
av2[2]=C_fix(37);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t275+1)))(4,av2);}}

/* ##sys#debug-mode? in k10751 in k8834 */
static void C_ccall f_10755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10755,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_debug_modep();
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#warning in k10751 in k8834 */
static void C_ccall f_10760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,5)))){
C_save_and_reclaim((void*)f_10760,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
if(C_truep(*((C_word*)lf[309]+1))){{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[312];
av2[4]=t2;
av2[5]=t3;
C_apply(6,av2);}}
else{
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* chicken.base#notice in k10751 in k8834 */
static void C_ccall f_10769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,5)))){
C_save_and_reclaim((void*)f_10769,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
t4=(C_truep(*((C_word*)lf[310]+1))?*((C_word*)lf[309]+1):C_SCHEME_FALSE);
if(C_truep(t4)){{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[314];
av2[4]=t2;
av2[5]=t3;
C_apply(6,av2);}}
else{
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* chicken.base#enable-warnings in k10751 in k8834 */
static void C_ccall f_10781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_10781,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
if(C_truep(C_i_pairp(t2))){
t3=C_mutate((C_word*)lf[309]+1 /* (set! ##sys#warnings-enabled ...) */,C_get_rest_arg(c,2,av,2,t0));
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=*((C_word*)lf[309]+1);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=*((C_word*)lf[309]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* ##sys#error/errno in k10751 in k8834 */
static void C_ccall f_10795(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,6)))){
C_save_and_reclaim((void*)f_10795,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
if(C_truep(C_i_pairp(t3))){{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[319]);
av2[3]=lf[195];
av2[4]=t2;
av2[5]=C_SCHEME_FALSE;
av2[6]=t3;
C_apply(7,av2);}}
else{
/* library.scm:1055: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=t1;
av2[2]=lf[195];
av2[3]=t2;
av2[4]=C_SCHEME_FALSE;
tp(5,av2);}}}

/* ##sys#setslot in k10751 in k8834 */
static void C_ccall f_10811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10811,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_setslot(t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#setislot in k10751 in k8834 */
static void C_ccall f_10814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10814,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_set_i_slot(t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#start-timer in k10751 in k8834 */
static void C_ccall f_10822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10822,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10826,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:1069: ##sys#gc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[320]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[320]+1);
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
tp(3,av2);}}

/* k10824 in ##sys#start-timer in k10751 in k8834 */
static void C_ccall f_10826(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10826,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_start_timer();
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#stop-timer in k10751 in k8834 */
static void C_ccall f_10828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_10828,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_stop_timer,a[2]=((C_word)li241),tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10832,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:1073: g1217 */
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)C_fast_retrieve_proc(t4))(2,av2);}}

/* k10830 in ##sys#stop-timer in k10751 in k8834 */
static void C_ccall f_10832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_10832,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10835,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:1076: ##sys#gc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[320]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[320]+1);
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
tp(3,av2);}}

/* k10833 in k10830 in ##sys#stop-timer in k10751 in k8834 */
static void C_ccall f_10835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10835,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_stop_timer,a[2]=((C_word)li242),tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10846,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:1077: g1219 */
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)C_fast_retrieve_proc(t4))(2,av2);}}

/* k10844 in k10833 in k10830 in ##sys#stop-timer in k10751 in k8834 */
static void C_ccall f_10846(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10846,c,av);}
t2=C_slot(t1,C_fix(6));
t3=C_i_setslot(((C_word*)t0)[2],C_fix(6),t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#immediate? in k10751 in k8834 */
static void C_ccall f_10848(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10848,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_not(C_blockp(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#message in k10751 in k8834 */
static void C_ccall f_10855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10855,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_message(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#byte in k10751 in k8834 */
static void C_ccall f_10858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10858,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_subbyte(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#setbyte in k10751 in k8834 */
static void C_ccall f_10861(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10861,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_setbyte(t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#halt in k10751 in k8834 */
static void C_ccall f_10866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10866,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_halt(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#block-ref in k10751 in k8834 */
static void C_ccall f_10870(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10870,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#block-set! in k10751 in k8834 */
static void C_ccall f_10875(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_10875,c,av);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10879,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=C_i_not(C_blockp(t2));
if(C_truep(t6)){
if(C_truep(t6)){
/* library.scm:1096: ##sys#signal-hook */
t7=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=lf[263];
av2[3]=lf[340];
av2[4]=lf[342];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(6,av2);}}
else{
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_10879(2,av2);}}}
else{
t7=(C_truep(C_specialp(t2))?C_eqp(t3,C_fix(0)):C_SCHEME_FALSE);
if(C_truep(t7)){
if(C_truep(t7)){
/* library.scm:1096: ##sys#signal-hook */
t8=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t8;
av2[1]=t5;
av2[2]=lf[263];
av2[3]=lf[340];
av2[4]=lf[342];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(6,av2);}}
else{
t8=t5;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_10879(2,av2);}}}
else{
if(C_truep(C_byteblockp(t2))){
/* library.scm:1096: ##sys#signal-hook */
t8=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t8;
av2[1]=t5;
av2[2]=lf[263];
av2[3]=lf[340];
av2[4]=lf[342];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(6,av2);}}
else{
t8=t5;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_10879(2,av2);}}}}}

/* k10877 in ##sys#block-set! in k10751 in k8834 */
static void C_ccall f_10879(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_10879,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10882,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:1097: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_fix(0);
av2[4]=C_block_size(((C_word*)t0)[3]);
av2[5]=lf[340];
tp(6,av2);}}

/* k10880 in k10877 in ##sys#block-set! in k10751 in k8834 */
static void C_ccall f_10882(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10882,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_setslot(((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.time#current-milliseconds in k10751 in k8834 */
static void C_ccall f_10910(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,1)))){
C_save_and_reclaim((void *)f_10910,c,av);}
a=C_alloc(7);
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_current_milliseconds(&a,1,C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.time#current-process-milliseconds in k10751 in k8834 */
static void C_ccall f_10913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,1)))){
C_save_and_reclaim((void *)f_10913,c,av);}
a=C_alloc(7);
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_current_process_milliseconds(&a,1,C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.time#current-seconds in k10751 in k8834 */
static void C_ccall f_10916(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,1)))){
C_save_and_reclaim((void *)f_10916,c,av);}
a=C_alloc(7);
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_get_current_seconds(&a,1,C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.time#cpu-time in k10751 in k8834 */
static void C_ccall f_10919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_10919,c,av);}
a=C_alloc(11);
t2=C_a_i_vector2(&a,2,C_SCHEME_FALSE,C_SCHEME_FALSE);
t3=C_a_i_cpu_time(&a,1,t2);
/* library.scm:1130: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_slot(t2,C_fix(0));
av2[3]=C_slot(t2,C_fix(1));
C_values(4,av2);}}

/* ##sys#check-structure in k10751 in k8834 */
static void C_ccall f_10936(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_10936,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+0);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=C_i_pairp(t4);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t5)?C_i_check_structure_2(t2,t3,C_get_rest_arg(c,4,av,4,t0)):C_i_check_structure(t2,t3));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* ##sys#check-blob in k10751 in k8834 */
static void C_ccall f_10947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_10947,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_bytevector_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_bytevector(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-pair in k10751 in k8834 */
static void C_ccall f_10959(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_10959,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_pair_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_pair(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-list in k10751 in k8834 */
static void C_ccall f_10970(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_10970,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_list_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_list(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-string in k10751 in k8834 */
static void C_ccall f_10981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_10981,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_string_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_string(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-number in k10751 in k8834 */
static void C_ccall f_10992(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_10992,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_number_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_number(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-fixnum in k10751 in k8834 */
static void C_ccall f_11003(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11003,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_fixnum_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_fixnum(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-exact in k10751 in k8834 */
static void C_ccall f_11014(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11014,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_exact_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_exact(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-inexact in k10751 in k8834 */
static void C_ccall f_11025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11025,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_inexact_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_inexact(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-symbol in k10751 in k8834 */
static void C_ccall f_11036(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11036,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_symbol_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_symbol(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-keyword in k10751 in k8834 */
static void C_ccall f_11047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11047,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_keyword_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_keyword(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-vector in k10751 in k8834 */
static void C_ccall f_11058(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11058,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_vector_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_vector(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-char in k10751 in k8834 */
static void C_ccall f_11069(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11069,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_char_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_char(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-boolean in k10751 in k8834 */
static void C_ccall f_11080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11080,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_boolean_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_boolean(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-locative in k10751 in k8834 */
static void C_ccall f_11091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11091,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_locative_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_locative(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-integer in k10751 in k8834 */
static void C_ccall f_11102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,3)))){
C_save_and_reclaim((void*)f_11102,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
if(C_truep(C_i_integerp(t2))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t3))){
/* library.scm:1213: ##sys#error-bad-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[364]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[364]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_get_rest_arg(c,3,av,3,t0);
tp(4,av2);}}
else{
/* library.scm:1213: ##sys#error-bad-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[364]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[364]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
tp(4,av2);}}}}

/* ##sys#check-exact-integer in k10751 in k8834 */
static void C_ccall f_11119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,3)))){
C_save_and_reclaim((void*)f_11119,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
if(C_truep(C_i_exact_integerp(t2))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t3))){
/* library.scm:1217: ##sys#error-bad-exact-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[366]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[366]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_get_rest_arg(c,3,av,3,t0);
tp(4,av2);}}
else{
/* library.scm:1217: ##sys#error-bad-exact-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[366]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[366]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
tp(4,av2);}}}}

/* ##sys#check-exact-uinteger in k10751 in k8834 */
static void C_ccall f_11136(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,3)))){
C_save_and_reclaim((void*)f_11136,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
t4=C_i_not(C_i_exact_integerp(t2));
t5=(C_truep(t4)?t4:C_i_integer_negativep(t2));
if(C_truep(t5)){
if(C_truep(C_i_pairp(t3))){
/* library.scm:1222: ##sys#error-bad-exact-uinteger */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[368]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[368]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_get_rest_arg(c,3,av,3,t0);
tp(4,av2);}}
else{
/* library.scm:1222: ##sys#error-bad-exact-uinteger */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[368]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[368]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
tp(4,av2);}}}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* ##sys#check-real in k10751 in k8834 */
static void C_ccall f_11160(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,3)))){
C_save_and_reclaim((void*)f_11160,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
if(C_truep(C_i_realp(t2))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t3))){
/* library.scm:1226: ##sys#error-bad-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[370]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_get_rest_arg(c,3,av,3,t0);
tp(4,av2);}}
else{
/* library.scm:1226: ##sys#error-bad-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[370]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
tp(4,av2);}}}}

/* ##sys#check-range in k10751 in k8834 */
static void C_ccall f_11177(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c<5) C_bad_min_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-5)*C_SIZEOF_PAIR +7,c,3)))){
C_save_and_reclaim((void*)f_11177,c,av);}
a=C_alloc((c-5)*C_SIZEOF_PAIR+7);
t5=C_build_rest(&a,c,5,av);
C_word t6;
C_word t7;
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11181,a[2]=t3,a[3]=t2,a[4]=t4,a[5]=t1,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
/* library.scm:1229: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t6;
av2[2]=t2;
av2[3]=t5;
tp(4,av2);}}

/* k11179 in ##sys#check-range in k10751 in k8834 */
static void C_ccall f_11181(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_11181,c,av);}
t2=C_fixnum_less_or_equal_p(((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(C_truep(t2)?C_fixnum_lessp(((C_word*)t0)[3],((C_word*)t0)[4]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_SCHEME_UNDEFINED;
t5=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_OUT_OF_RANGE_ERROR);
if(C_truep(C_i_pairp(((C_word*)t0)[6]))){
/* library.scm:1231: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=((C_word*)t0)[5];
av2[2]=t4;
av2[3]=C_u_i_car(((C_word*)t0)[6]);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[2];
av2[6]=((C_word*)t0)[4];
tp(7,av2);}}
else{
/* library.scm:1231: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=((C_word*)t0)[5];
av2[2]=t4;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[2];
av2[6]=((C_word*)t0)[4];
tp(7,av2);}}}}

/* ##sys#check-special in k10751 in k8834 */
static void C_ccall f_11207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,5)))){
C_save_and_reclaim((void*)f_11207,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
t4=(C_truep(C_blockp(t2))?C_specialp(t2):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t3))){
/* library.scm:1237: ##sys#signal-hook */
t5=C_fast_retrieve(lf[194]);{
C_word av2[6];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=C_get_rest_arg(c,3,av,3,t0);
av2[4]=lf[373];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}
else{
/* library.scm:1237: ##sys#signal-hook */
t5=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=C_SCHEME_FALSE;
av2[4]=lf[373];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}}}

/* ##sys#check-closure in k10751 in k8834 */
static void C_ccall f_11227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_11227,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_closure_2(t2,C_get_rest_arg(c,3,av,3,t0)):C_i_check_closure(t2));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#force in k10751 in k8834 */
static void C_ccall f_11238(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_11238,c,av);}
a=C_alloc(6);
if(C_truep(C_i_structurep(t2,lf[218]))){
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11250,a[2]=t4,a[3]=((C_word)li280),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_11250(t6,t1,t2,C_SCHEME_FALSE);}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* lp in scheme#force in k10751 in k8834 */
static void C_fcall f_11250(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_11250,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_slot(t2,C_fix(1));
if(C_truep(C_i_nullp(t4))){
/* library.scm:1250: ##sys#values */{
C_word av2[2];
av2[0]=0;
av2[1]=t1;
C_values(2,av2);}}
else{
if(C_truep(C_i_pairp(t4))){{
C_word av2[3];
av2[0]=0;
av2[1]=t1;
av2[2]=t4;
C_apply_values(3,av2);}}
else{
if(C_truep(C_i_closurep(t4))){
t5=(C_truep(t3)?C_i_setslot(t3,C_fix(1),t2):C_SCHEME_UNDEFINED);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11284,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* library.scm:1254: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=t6;
av2[2]=t4;
av2[3]=*((C_word*)lf[376]+1);
C_call_with_values(4,av2);}}
else{
if(C_truep(C_i_structurep(t4,lf[218]))){
/* library.scm:1266: lp */
t8=t1;
t9=t4;
t10=t3;
t1=t8;
t2=t9;
t3=t10;
goto loop;}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}}}}

/* k11282 in lp in scheme#force in k10751 in k8834 */
static void C_ccall f_11284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_11284,c,av);}
a=C_alloc(6);
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_i_closurep(t2);
if(C_truep(C_i_not(t3))){
/* library.scm:1256: lp */
t4=((C_word*)((C_word*)t0)[3])[1];
f_11250(t4,((C_word*)t0)[4],((C_word*)t0)[2],((C_word*)t0)[5]);}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11299,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t5=C_i_nullp(t1);
if(C_truep(C_i_not(t5))){
t6=C_i_cdr(t1);
t7=C_i_nullp(t6);
t8=t4;
f_11299(t8,(C_truep(t7)?C_i_structurep(C_slot(t1,C_fix(0)),lf[218]):C_SCHEME_FALSE));}
else{
t6=t4;
f_11299(t6,C_SCHEME_FALSE);}}}

/* k11297 in k11282 in lp in scheme#force in k10751 in k8834 */
static void C_fcall f_11299(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_11299,2,t0,t1);}
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(0));
t3=C_slot(t2,C_fix(1));
t4=C_i_setslot(((C_word*)t0)[3],C_fix(1),t3);
/* library.scm:1261: lp */
t5=((C_word*)((C_word*)t0)[4])[1];
f_11250(t5,((C_word*)t0)[5],((C_word*)t0)[3],t2);}
else{
t2=C_i_setslot(((C_word*)t0)[3],C_fix(1),((C_word*)t0)[2]);{
C_word av2[3];
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[2];
C_apply_values(3,av2);}}}

/* ##sys#error-not-a-proper-list in k10751 in k8834 */
static void C_ccall f_11366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11366,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_NOT_A_PROPER_LIST_ERROR);
/* library.scm:1276: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_NOT_A_PROPER_LIST_ERROR);
/* library.scm:1276: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* ##sys#error-bad-number in k10751 in k8834 */
static void C_ccall f_11382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11382,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_NUMBER_ERROR);
/* library.scm:1280: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_NUMBER_ERROR);
/* library.scm:1280: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* ##sys#error-bad-integer in k10751 in k8834 */
static void C_ccall f_11398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11398,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_INTEGER_ERROR);
/* library.scm:1284: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_INTEGER_ERROR);
/* library.scm:1284: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* ##sys#error-bad-exact-integer in k10751 in k8834 */
static void C_ccall f_11414(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11414,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_INTEGER_ERROR);
/* library.scm:1288: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_INTEGER_ERROR);
/* library.scm:1288: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* ##sys#error-bad-exact-uinteger in k10751 in k8834 */
static void C_ccall f_11430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11430,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_UINTEGER_ERROR);
/* library.scm:1292: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_UINTEGER_ERROR);
/* library.scm:1292: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* ##sys#error-bad-inexact in k10751 in k8834 */
static void C_ccall f_11446(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11446,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_CANT_REPRESENT_INEXACT_ERROR);
/* library.scm:1296: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_CANT_REPRESENT_INEXACT_ERROR);
/* library.scm:1296: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* ##sys#error-bad-real in k10751 in k8834 */
static void C_ccall f_11462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11462,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_REAL_ERROR);
/* library.scm:1300: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_REAL_ERROR);
/* library.scm:1300: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* ##sys#error-bad-base in k10751 in k8834 */
static void C_ccall f_11478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11478,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=C_fix((C_word)C_BAD_ARGUMENT_TYPE_BAD_BASE_ERROR);
/* library.scm:1304: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
tp(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_BAD_BASE_ERROR);
/* library.scm:1304: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[5];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t3;
av2[4]=t2;
tp(5,av2);}}}

/* scheme#append in k10751 in k8834 */
static void C_ccall f_11494(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,3)))){
C_save_and_reclaim((void*)f_11494,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
t3=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t3)){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11506,a[2]=t5,a[3]=((C_word)li293),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_11506(t7,t1,t2);}}

/* loop in scheme#append in k10751 in k8834 */
static void C_fcall f_11506(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_11506,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_slot(t2,C_fix(1));
t4=C_eqp(t3,C_SCHEME_END_OF_LIST);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_slot(t2,C_fix(0));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11525,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t7,a[5]=((C_word)li292),tmp=(C_word)a,a+=6,tmp));
t9=((C_word*)t7)[1];
f_11525(t9,t1,t5);}}

/* copy in loop in scheme#append in k10751 in k8834 */
static void C_fcall f_11525(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_11525,3,t0,t1,t2);}
a=C_alloc(4);
t3=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t3)){
/* library.scm:1315: loop */
t4=((C_word*)((C_word*)t0)[2])[1];
f_11506(t4,t1,C_slot(((C_word*)t0)[3],C_fix(1)));}
else{
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11556,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1317: copy */
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
/* library.scm:1319: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=C_slot(((C_word*)t0)[3],C_fix(0));
av2[3]=lf[383];
tp(4,av2);}}}}

/* k11554 in copy in loop in scheme#append in k10751 in k8834 */
static void C_ccall f_11556(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_11556,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#fast-reverse in k10751 in k8834 */
static void C_ccall f_11573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_11573,c,av);}
a=C_alloc(6);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11579,a[2]=t4,a[3]=((C_word)li295),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_11579(t6,t1,t2,C_SCHEME_END_OF_LIST);}

/* loop in ##sys#fast-reverse in k10751 in k8834 */
static void C_fcall f_11579(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_11579,4,t0,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=C_slot(t2,C_fix(0));
t6=C_a_i_cons(&a,2,t5,t3);
/* library.scm:1325: loop */
t8=t1;
t9=t4;
t10=t6;
t1=t8;
t2=t9;
t3=t10;
goto loop;}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* ##sys#make-string in k10751 in k8834 */
static void C_ccall f_11603(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11603,c,av);}
if(C_truep(C_rest_nullp(c,3))){
/* library.scm:1332: ##sys#allocate-vector */
t3=*((C_word*)lf[323]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_TRUE;
av2[4]=C_make_character(32);
av2[5]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
/* library.scm:1332: ##sys#allocate-vector */
t3=*((C_word*)lf[323]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_TRUE;
av2[4]=C_get_rest_arg(c,3,av,3,t0);
av2[5]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}}

/* scheme#make-string in k10751 in k8834 */
static void C_ccall f_11623(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_11623,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+5);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11627,a[2]=t3,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1339: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[387];
tp(4,av2);}}

/* k11625 in scheme#make-string in k10751 in k8834 */
static void C_ccall f_11627(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_11627,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11630,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnum_lessp(((C_word*)t0)[4],C_fix(0)))){
/* library.scm:1341: ##sys#signal-hook */
t3=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[388];
av2[3]=lf[387];
av2[4]=lf[389];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_11630(2,av2);}}}

/* k11628 in k11625 in scheme#make-string in k10751 in k8834 */
static void C_ccall f_11630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_11630,c,av);}
if(C_truep(C_i_nullp(((C_word*)t0)[2]))){
/* library.scm:1332: ##sys#allocate-vector */
t2=*((C_word*)lf[323]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_make_character(32);
av2[5]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_check_char_2(t2,lf[387]);
/* library.scm:1332: ##sys#allocate-vector */
t4=*((C_word*)lf[323]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=t2;
av2[5]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}}

/* scheme#string->list in k10751 in k8834 */
static void C_ccall f_11659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_11659,c,av);}
a=C_alloc(7);
t3=C_i_check_string_2(t2,lf[391]);
t4=C_block_size(t2);
t5=C_fixnum_difference(t4,C_fix(1));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11675,a[2]=t2,a[3]=t7,a[4]=((C_word)li299),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_11675(t9,t1,t5,C_SCHEME_END_OF_LIST);}

/* loop in scheme#string->list in k10751 in k8834 */
static void C_fcall f_11675(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_11675,4,t0,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_fixnum_lessp(t2,C_fix(0)))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fixnum_difference(t2,C_fix(1));
t5=C_subchar(((C_word*)t0)[2],t2);
t6=C_a_i_cons(&a,2,t5,t3);
/* library.scm:1357: loop */
t8=t1;
t9=t4;
t10=t6;
t1=t8;
t2=t9;
t3=t10;
goto loop;}}

/* scheme#list->string in k10751 in k8834 */
static void C_ccall f_11697(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11697,c,av);}
a=C_alloc(5);
t3=C_i_listp(t2);
if(C_truep(C_i_not(t3))){
/* library.scm:1365: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[394];
tp(4,av2);}}
else{
t4=C_i_length(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11713,a[2]=t4,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1367: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}}

/* k11711 in scheme#list->string in k10751 in k8834 */
static void C_ccall f_11713(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11713,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11718,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li301),tmp=(C_word)a,a+=5,tmp);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
  f_11718(t2,C_fix(0),((C_word*)t0)[4])
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* doloop1539 in k11711 in scheme#list->string in k10751 in k8834 */
static C_word C_fcall f_11718(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;
loop:{}
if(C_truep(C_fixnum_greater_or_equal_p(t1,((C_word*)t0)[2]))){
return(((C_word*)t0)[3]);}
else{
t3=C_slot(t2,C_fix(0));
t4=C_i_check_char_2(t3,lf[394]);
t5=C_setsubchar(((C_word*)t0)[3],t1,t3);
t7=C_fixnum_plus(t1,C_fix(1));
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}}

/* ##sys#reverse-list->string in k10751 in k8834 */
static void C_ccall f_11749(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11749,c,av);}
a=C_alloc(5);
if(C_truep(C_i_listp(t2))){
t3=C_u_i_length(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11760,a[2]=t3,a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1382: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}
else{
/* library.scm:1390: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[397];
tp(4,av2);}}}

/* k11758 in ##sys#reverse-list->string in k10751 in k8834 */
static void C_ccall f_11760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_11760,c,av);}
a=C_alloc(4);
t2=C_fixnum_difference(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11769,a[2]=t1,a[3]=((C_word)li303),tmp=(C_word)a,a+=4,tmp);
t4=(
  f_11769(t3,((C_word*)t0)[3],t2)
);
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* iter in k11758 in ##sys#reverse-list->string in k10751 in k8834 */
static C_word C_fcall f_11769(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;
loop:{}
if(C_truep(C_fixnum_greater_or_equal_p(t2,C_fix(0)))){
t3=C_slot(t1,C_fix(0));
t4=C_i_check_char_2(t3,lf[397]);
t5=C_setsubchar(((C_word*)t0)[2],t2,t3);
t7=C_slot(t1,C_fix(1));
t8=C_fixnum_difference(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=C_SCHEME_UNDEFINED;
return(t3);}}

/* scheme#string-fill! in k10751 in k8834 */
static void C_ccall f_11798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11798,c,av);}
t4=C_i_check_string_2(t2,lf[399]);
t5=C_i_check_char_2(t3,lf[399]);
t6=C_block_size(t2);
t7=C_set_memory(t2,t3,t6);
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}

/* scheme#string-copy in k10751 in k8834 */
static void C_ccall f_11811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11811,c,av);}
a=C_alloc(5);
t3=C_i_check_string_2(t2,lf[401]);
t4=C_block_size(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11821,a[2]=t2,a[3]=t4,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1403: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}

/* k11819 in scheme#string-copy in k10751 in k8834 */
static void C_ccall f_11821(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11821,c,av);}
t2=C_copy_memory(t1,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#substring in k10751 in k8834 */
static void C_ccall f_11823(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +6,c,3)))){
C_save_and_reclaim((void*)f_11823,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+6);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=C_i_check_string_2(t2,lf[403]);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11830,a[2]=t2,a[3]=t1,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:1410: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t6;
av2[2]=t3;
av2[3]=lf[403];
tp(4,av2);}}

/* k11828 in scheme#substring in k10751 in k8834 */
static void C_ccall f_11830(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_11830,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11833,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[5]))){
t3=C_u_i_car(((C_word*)t0)[5]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11868,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1413: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t4;
av2[2]=t3;
av2[3]=lf[403];
tp(4,av2);}}
else{
t3=t2;
f_11833(t3,C_block_size(((C_word*)t0)[2]));}}

/* k11831 in k11828 in scheme#substring in k10751 in k8834 */
static void C_fcall f_11833(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11833,2,t0,t1);}
a=C_alloc(6);
t2=C_block_size(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11842,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fixnum_less_or_equal_p(((C_word*)t0)[4],t1))){
t4=C_fixnum_greater_or_equal_p(((C_word*)t0)[4],C_fix(0));
t5=t3;
f_11842(t5,(C_truep(t4)?C_fixnum_less_or_equal_p(t1,t2):C_SCHEME_FALSE));}
else{
t4=t3;
f_11842(t4,C_SCHEME_FALSE);}}

/* k11840 in k11831 in k11828 in scheme#substring in k10751 in k8834 */
static void C_fcall f_11842(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_11842,2,t0,t1);}
if(C_truep(t1)){
/* library.scm:1420: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[404]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
tp(5,av2);}}
else{
t2=C_fix((C_word)C_OUT_OF_RANGE_ERROR);
/* library.scm:1421: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[6];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
av2[3]=lf[403];
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
tp(6,av2);}}}

/* k11866 in k11828 in scheme#substring in k10751 in k8834 */
static void C_ccall f_11868(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11868,c,av);}
t2=((C_word*)t0)[2];
f_11833(t2,((C_word*)t0)[3]);}

/* ##sys#substring in k10751 in k8834 */
static void C_ccall f_11873(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_11873,c,av);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11877,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:1426: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t5;
av2[2]=C_fixnum_difference(t4,t3);
tp(3,av2);}}

/* k11875 in ##sys#substring in k10751 in k8834 */
static void C_ccall f_11877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11877,c,av);}
t2=C_substring_copy(((C_word*)t0)[2],t1,((C_word*)t0)[3],((C_word*)t0)[4],C_fix(0));
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* compare1592 in k10751 in k8834 */
static void C_ccall f_11882(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11882,c,av);}
t6=C_i_check_string_2(t2,t4);
t7=C_i_check_string_2(t3,t4);
t8=C_block_size(t2);
t9=C_block_size(t3);
if(C_truep(C_fixnum_lessp(t8,t9))){
/* library.scm:1436: k */
t10=t5;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
av2[2]=t8;
av2[3]=t9;
av2[4]=C_string_compare(t2,t3,t8);
((C_proc)C_fast_retrieve_proc(t10))(5,av2);}}
else{
/* library.scm:1436: k */
t10=t5;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
av2[2]=t8;
av2[3]=t9;
av2[4]=C_string_compare(t2,t3,t9);
((C_proc)C_fast_retrieve_proc(t10))(5,av2);}}}

/* scheme#string<? in k10751 in k8834 */
static void C_ccall f_11903(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_11903,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11909,a[2]=((C_word)li310),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1444: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[406];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a11908 in scheme#string<? in k10751 in k8834 */
static void C_ccall f_11909(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11909,c,av);}
t5=C_fixnum_lessp(t4,C_fix(0));
if(C_truep(t5)){
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_fixnum_lessp(t2,t3);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t6)?C_eqp(t4,C_fix(0)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* scheme#string>? in k10751 in k8834 */
static void C_ccall f_11927(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_11927,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11933,a[2]=((C_word)li312),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1451: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[408];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a11932 in scheme#string>? in k10751 in k8834 */
static void C_ccall f_11933(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11933,c,av);}
t5=C_fixnum_greaterp(t4,C_fix(0));
if(C_truep(t5)){
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_fixnum_lessp(t3,t2);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t6)?C_eqp(t4,C_fix(0)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* scheme#string<=? in k10751 in k8834 */
static void C_ccall f_11951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_11951,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11957,a[2]=((C_word)li314),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1458: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[410];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a11956 in scheme#string<=? in k10751 in k8834 */
static void C_ccall f_11957(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11957,c,av);}
t5=C_eqp(t4,C_fix(0));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=(C_truep(t5)?C_fixnum_less_or_equal_p(t2,t3):C_fixnum_lessp(t4,C_fix(0)));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* scheme#string>=? in k10751 in k8834 */
static void C_ccall f_11972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_11972,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11978,a[2]=((C_word)li316),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1465: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[412];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a11977 in scheme#string>=? in k10751 in k8834 */
static void C_ccall f_11978(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11978,c,av);}
t5=C_eqp(t4,C_fix(0));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=(C_truep(t5)?C_fixnum_greater_or_equal_p(t2,t3):C_fixnum_greaterp(t4,C_fix(0)));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* compare1635 in k10751 in k8834 */
static void C_ccall f_11992(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11992,c,av);}
t6=C_i_check_string_2(t2,t4);
t7=C_i_check_string_2(t3,t4);
t8=C_block_size(t2);
t9=C_block_size(t3);
if(C_truep(C_fixnum_lessp(t8,t9))){
/* library.scm:1478: k */
t10=t5;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
av2[2]=t8;
av2[3]=t9;
av2[4]=C_string_compare_case_insensitive(t2,t3,t8);
((C_proc)C_fast_retrieve_proc(t10))(5,av2);}}
else{
/* library.scm:1478: k */
t10=t5;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t1;
av2[2]=t8;
av2[3]=t9;
av2[4]=C_string_compare_case_insensitive(t2,t3,t9);
((C_proc)C_fast_retrieve_proc(t10))(5,av2);}}}

/* scheme#string-ci<? in k10751 in k8834 */
static void C_ccall f_12013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_12013,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12019,a[2]=((C_word)li319),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1486: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[414];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a12018 in scheme#string-ci<? in k10751 in k8834 */
static void C_ccall f_12019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12019,c,av);}
t5=C_fixnum_lessp(t4,C_fix(0));
if(C_truep(t5)){
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_fixnum_lessp(t2,t3);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t6)?C_eqp(t4,C_fix(0)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* scheme#string-ci>? in k10751 in k8834 */
static void C_ccall f_12037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_12037,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12043,a[2]=((C_word)li321),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1493: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[416];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a12042 in scheme#string-ci>? in k10751 in k8834 */
static void C_ccall f_12043(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12043,c,av);}
t5=C_fixnum_greaterp(t4,C_fix(0));
if(C_truep(t5)){
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_fixnum_lessp(t3,t2);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t6)?C_eqp(t4,C_fix(0)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* scheme#string-ci<=? in k10751 in k8834 */
static void C_ccall f_12061(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_12061,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12067,a[2]=((C_word)li323),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1500: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[418];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a12066 in scheme#string-ci<=? in k10751 in k8834 */
static void C_ccall f_12067(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12067,c,av);}
t5=C_eqp(t4,C_fix(0));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=(C_truep(t5)?C_fixnum_less_or_equal_p(t2,t3):C_fixnum_lessp(t4,C_fix(0)));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* scheme#string-ci>=? in k10751 in k8834 */
static void C_ccall f_12082(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_12082,c,av);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12088,a[2]=((C_word)li325),tmp=(C_word)a,a+=3,tmp);
/* library.scm:1507: compare */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=lf[420];
av2[5]=t4;
((C_proc)C_fast_retrieve_proc(t5))(6,av2);}}

/* a12087 in scheme#string-ci>=? in k10751 in k8834 */
static void C_ccall f_12088(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12088,c,av);}
t5=C_eqp(t4,C_fix(0));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=(C_truep(t5)?C_fixnum_greater_or_equal_p(t2,t3):C_fixnum_greaterp(t4,C_fix(0)));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* ##sys#string-append in k10751 in k8834 */
static void C_ccall f_12103(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_12103,c,av);}
a=C_alloc(7);
t4=C_block_size(t2);
t5=C_block_size(t3);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12113,a[2]=t2,a[3]=t4,a[4]=t3,a[5]=t5,a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* library.scm:1517: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t6;
av2[2]=C_fixnum_plus(t4,t5);
tp(3,av2);}}

/* k12111 in ##sys#string-append in k10751 in k8834 */
static void C_ccall f_12113(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12113,c,av);}
t2=C_substring_copy(((C_word*)t0)[2],t1,C_fix(0),((C_word*)t0)[3],C_fix(0));
t3=C_substring_copy(((C_word*)t0)[4],t1,C_fix(0),((C_word*)t0)[5],((C_word*)t0)[3]);
t4=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#string-append in k10751 in k8834 */
static void C_ccall f_12119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +13,c,4)))){
C_save_and_reclaim((void*)f_12119,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+13);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
t3=C_SCHEME_FALSE;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12123,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12125,a[2]=t4,a[3]=t7,a[4]=((C_word)li328),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_12125(t9,t5,t2,C_fix(0));}

/* k12121 in scheme#string-append in k10751 in k8834 */
static void C_ccall f_12123(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12123,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in scheme#string-append in k10751 in k8834 */
static void C_fcall f_12125(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_12125,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12136,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1527: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t5;
av2[2]=t3;
tp(3,av2);}}
else{
t5=C_slot(t2,C_fix(0));
t6=C_i_check_string_2(t5,lf[423]);
t7=C_block_size(t5);
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12148,a[2]=t1,a[3]=t5,a[4]=((C_word*)t0)[2],a[5]=t7,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* library.scm:1531: loop */
t10=t8;
t11=C_slot(t2,C_fix(1));
t12=C_fixnum_plus(t3,t7);
t1=t10;
t2=t11;
t3=t12;
goto loop;}}

/* k12134 in loop in scheme#string-append in k10751 in k8834 */
static void C_ccall f_12136(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12136,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12146 in loop in scheme#string-append in k10751 in k8834 */
static void C_ccall f_12148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12148,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_substring_copy(((C_word*)t0)[3],((C_word*)((C_word*)t0)[4])[1],C_fix(0),((C_word*)t0)[5],((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* scheme#string in k10751 in k8834 */
static void C_ccall f_12158(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,2)))){
C_save_and_reclaim((void*)f_12158,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
/* ##sys#list->string */
t3=*((C_word*)lf[395]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* ##sys#fragments->string in k10751 in k8834 */
static void C_ccall f_12164(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_12164,c,av);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12168,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1540: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}

/* k12166 in ##sys#fragments->string in k10751 in k8834 */
static void C_ccall f_12168(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12168,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12173,a[2]=t1,a[3]=((C_word)li331),tmp=(C_word)a,a+=4,tmp);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
  f_12173(t2,((C_word*)t0)[3],C_fix(0))
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* loop in k12166 in ##sys#fragments->string in k10751 in k8834 */
static C_word C_fcall f_12173(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_nullp(t1))){
return(((C_word*)t0)[2]);}
else{
t3=C_slot(t1,C_fix(0));
t4=C_block_size(t3);
t5=C_substring_copy(t3,((C_word*)t0)[2],C_fix(0),t4,t2);
t7=C_slot(t1,C_fix(1));
t8=C_fixnum_plus(t2,t4);
t1=t7;
t2=t8;
goto loop;}}

/* chicken.base#chop in k10751 in k8834 */
static void C_ccall f_12199(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12199,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12203,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1551: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t4;
av2[2]=t3;
av2[3]=lf[427];
tp(4,av2);}}

/* k12201 in chicken.base#chop in k10751 in k8834 */
static void C_ccall f_12203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12203,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12206,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnum_less_or_equal_p(((C_word*)t0)[3],C_fix(0)))){
/* library.scm:1552: ##sys#error */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[427];
av2[3]=lf[428];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_12206(2,av2);}}}

/* k12204 in k12201 in chicken.base#chop in k10751 in k8834 */
static void C_ccall f_12206(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_12206,c,av);}
a=C_alloc(7);
t2=C_i_length(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12214,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word)li334),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_12214(t6,((C_word*)t0)[4],((C_word*)t0)[2],t2);}

/* loop in k12204 in k12201 in chicken.base#chop in k10751 in k8834 */
static void C_fcall f_12214(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_12214,4,t0,t1,t2,t3);}
a=C_alloc(9);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_lessp(t3,((C_word*)t0)[2]))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_a_i_list1(&a,1,t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12235,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t5,a[6]=((C_word)li333),tmp=(C_word)a,a+=7,tmp));
t7=((C_word*)t5)[1];
f_12235(t7,t1,C_SCHEME_END_OF_LIST,t2,((C_word*)t0)[2]);}}}

/* doloop1720 in loop in k12204 in k12201 in chicken.base#chop in k10751 in k8834 */
static void C_fcall f_12235(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_12235,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
t5=C_eqp(t4,C_fix(0));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12249,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* library.scm:1562: scheme#reverse */
t7=*((C_word*)lf[46]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t6=C_slot(t3,C_fix(0));
t7=C_a_i_cons(&a,2,t6,t2);
t9=t1;
t10=t7;
t11=C_slot(t3,C_fix(1));
t12=C_fixnum_difference(t4,C_fix(1));
t1=t9;
t2=t10;
t3=t11;
t4=t12;
goto loop;}}

/* k12247 in doloop1720 in loop in k12204 in k12201 in chicken.base#chop in k10751 in k8834 */
static void C_ccall f_12249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_12249,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12253,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1562: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_12214(t3,t2,((C_word*)t0)[4],C_fixnum_difference(((C_word*)t0)[5],((C_word*)t0)[6]));}

/* k12251 in k12247 in doloop1720 in loop in k12204 in k12201 in chicken.base#chop in k10751 in k8834 */
static void C_ccall f_12253(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_12253,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp+ in k10751 in k8834 */
static void C_ccall f_12294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12294,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12316,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_flonum(&a,C_ub_i_flonum_plus(C_flonum_magnitude(t2),C_flonum_magnitude(t3)));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[441];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12314 in chicken.flonum#fp+ in k10751 in k8834 */
static void C_ccall f_12316(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12316,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_ub_i_flonum_plus(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp- in k10751 in k8834 */
static void C_ccall f_12318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12318,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12340,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_flonum(&a,C_ub_i_flonum_difference(C_flonum_magnitude(t2),C_flonum_magnitude(t3)));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[443];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12338 in chicken.flonum#fp- in k10751 in k8834 */
static void C_ccall f_12340(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12340,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_ub_i_flonum_difference(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp* in k10751 in k8834 */
static void C_ccall f_12342(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12342,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12364,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_flonum(&a,C_ub_i_flonum_times(C_flonum_magnitude(t2),C_flonum_magnitude(t3)));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[445];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12362 in chicken.flonum#fp* in k10751 in k8834 */
static void C_ccall f_12364(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12364,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_ub_i_flonum_times(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp/ in k10751 in k8834 */
static void C_ccall f_12366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12366,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12388,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_flonum(&a,C_ub_i_flonum_quotient(C_flonum_magnitude(t2),C_flonum_magnitude(t3)));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[447];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12386 in chicken.flonum#fp/ in k10751 in k8834 */
static void C_ccall f_12388(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12388,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_ub_i_flonum_quotient(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp*+ in k10751 in k8834 */
static void C_ccall f_12390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_12390,c,av);}
a=C_alloc(13);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12394,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12397,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_flonump(t2))){
t7=C_i_flonump(t3);
t8=t6;
f_12397(t8,(C_truep(t7)?C_i_flonump(t4):C_SCHEME_FALSE));}
else{
t7=t6;
f_12397(t7,C_SCHEME_FALSE);}}

/* k12392 in chicken.flonum#fp*+ in k10751 in k8834 */
static void C_ccall f_12394(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12394,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_ub_i_flonum_multiply_add(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4]),C_flonum_magnitude(((C_word*)t0)[5])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12395 in chicken.flonum#fp*+ in k10751 in k8834 */
static void C_fcall f_12397(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,6)))){
C_save_and_reclaim_args((void *)trf_12397,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_flonum(&a,C_ub_i_flonum_multiply_add(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4]),C_flonum_magnitude(((C_word*)t0)[5])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1613: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word av2[7];
av2[0]=*((C_word*)lf[371]+1);
av2[1]=((C_word*)t0)[6];
av2[2]=t2;
av2[3]=lf[449];
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
tp(7,av2);}}}

/* chicken.flonum#fpgcd in k10751 in k8834 */
static void C_ccall f_12415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12415,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12437,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_a_i_flonum_gcd(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[451];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12435 in chicken.flonum#fpgcd in k10751 in k8834 */
static void C_ccall f_12437(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12437,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_flonum_gcd(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp/? in k10751 in k8834 */
static void C_ccall f_12439(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12439,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12461,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_a_i_flonum_quotient_checked(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[453];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12459 in chicken.flonum#fp/? in k10751 in k8834 */
static void C_ccall f_12461(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12461,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_flonum_quotient_checked(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp= in k10751 in k8834 */
static void C_ccall f_12463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12463,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12485,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_ub_i_flonum_equalp(C_flonum_magnitude(t2),C_flonum_magnitude(t3));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[455];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12483 in chicken.flonum#fp= in k10751 in k8834 */
static void C_ccall f_12485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12485,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_ub_i_flonum_equalp(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp> in k10751 in k8834 */
static void C_ccall f_12487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12487,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12509,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_ub_i_flonum_greaterp(C_flonum_magnitude(t2),C_flonum_magnitude(t3));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[457];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12507 in chicken.flonum#fp> in k10751 in k8834 */
static void C_ccall f_12509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12509,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_ub_i_flonum_greaterp(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp< in k10751 in k8834 */
static void C_ccall f_12511(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12511,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12533,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_ub_i_flonum_lessp(C_flonum_magnitude(t2),C_flonum_magnitude(t3));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[459];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12531 in chicken.flonum#fp< in k10751 in k8834 */
static void C_ccall f_12533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12533,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_ub_i_flonum_lessp(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp>= in k10751 in k8834 */
static void C_ccall f_12535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12535,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12557,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_ub_i_flonum_greater_or_equal_p(C_flonum_magnitude(t2),C_flonum_magnitude(t3));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[461];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12555 in chicken.flonum#fp>= in k10751 in k8834 */
static void C_ccall f_12557(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12557,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_ub_i_flonum_greater_or_equal_p(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fp<= in k10751 in k8834 */
static void C_ccall f_12559(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12559,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12581,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_ub_i_flonum_less_or_equal_p(C_flonum_magnitude(t2),C_flonum_magnitude(t3));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[463];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12579 in chicken.flonum#fp<= in k10751 in k8834 */
static void C_ccall f_12581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12581,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_ub_i_flonum_less_or_equal_p(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpneg in k10751 in k8834 */
static void C_ccall f_12583(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12583,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12599,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_flonum_negate(&a,1,t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[465];
av2[4]=t2;
tp(5,av2);}}}

/* k12597 in chicken.flonum#fpneg in k10751 in k8834 */
static void C_ccall f_12599(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12599,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_flonum_negate(&a,1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpmax in k10751 in k8834 */
static void C_ccall f_12601(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12601,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12623,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_i_flonum_max(t2,t3);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[467];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12621 in chicken.flonum#fpmax in k10751 in k8834 */
static void C_ccall f_12623(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12623,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_flonum_max(((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpmin in k10751 in k8834 */
static void C_ccall f_12625(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12625,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12647,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_i_flonum_min(t2,t3);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[469];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12645 in chicken.flonum#fpmin in k10751 in k8834 */
static void C_ccall f_12647(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12647,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_flonum_min(((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpfloor in k10751 in k8834 */
static void C_ccall f_12649(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12649,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12665,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_floor(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[471];
av2[4]=t2;
tp(5,av2);}}}

/* k12663 in chicken.flonum#fpfloor in k10751 in k8834 */
static void C_ccall f_12665(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12665,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_floor(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fptruncate in k10751 in k8834 */
static void C_ccall f_12667(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12667,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12683,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_trunc(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[473];
av2[4]=t2;
tp(5,av2);}}}

/* k12681 in chicken.flonum#fptruncate in k10751 in k8834 */
static void C_ccall f_12683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12683,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_trunc(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpround in k10751 in k8834 */
static void C_ccall f_12685(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12685,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12701,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_round(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[475];
av2[4]=t2;
tp(5,av2);}}}

/* k12699 in chicken.flonum#fpround in k10751 in k8834 */
static void C_ccall f_12701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12701,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_round(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpceiling in k10751 in k8834 */
static void C_ccall f_12703(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12703,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12719,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_ceil(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[477];
av2[4]=t2;
tp(5,av2);}}}

/* k12717 in chicken.flonum#fpceiling in k10751 in k8834 */
static void C_ccall f_12719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12719,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_ceil(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpsin in k10751 in k8834 */
static void C_ccall f_12721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12721,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12737,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_sin(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[479];
av2[4]=t2;
tp(5,av2);}}}

/* k12735 in chicken.flonum#fpsin in k10751 in k8834 */
static void C_ccall f_12737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12737,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_sin(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpcos in k10751 in k8834 */
static void C_ccall f_12739(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12739,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12755,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_cos(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[481];
av2[4]=t2;
tp(5,av2);}}}

/* k12753 in chicken.flonum#fpcos in k10751 in k8834 */
static void C_ccall f_12755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12755,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_cos(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fptan in k10751 in k8834 */
static void C_ccall f_12757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12757,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12773,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_tan(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[483];
av2[4]=t2;
tp(5,av2);}}}

/* k12771 in chicken.flonum#fptan in k10751 in k8834 */
static void C_ccall f_12773(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12773,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_tan(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpasin in k10751 in k8834 */
static void C_ccall f_12775(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12775,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12791,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_asin(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[485];
av2[4]=t2;
tp(5,av2);}}}

/* k12789 in chicken.flonum#fpasin in k10751 in k8834 */
static void C_ccall f_12791(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12791,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_asin(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpacos in k10751 in k8834 */
static void C_ccall f_12793(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12793,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12809,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_acos(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[487];
av2[4]=t2;
tp(5,av2);}}}

/* k12807 in chicken.flonum#fpacos in k10751 in k8834 */
static void C_ccall f_12809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12809,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_acos(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpatan in k10751 in k8834 */
static void C_ccall f_12811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12811,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12827,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_atan(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[489];
av2[4]=t2;
tp(5,av2);}}}

/* k12825 in chicken.flonum#fpatan in k10751 in k8834 */
static void C_ccall f_12827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12827,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_atan(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpatan2 in k10751 in k8834 */
static void C_ccall f_12829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12829,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12851,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_flonum(&a,C_atan2(C_flonum_magnitude(t2),C_flonum_magnitude(t3)));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[491];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12849 in chicken.flonum#fpatan2 in k10751 in k8834 */
static void C_ccall f_12851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12851,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_atan2(C_flonum_magnitude(((C_word*)t0)[3]),C_flonum_magnitude(((C_word*)t0)[4])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpsinh in k10751 in k8834 */
static void C_ccall f_12853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12853,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12869,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_sinh(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[493];
av2[4]=t2;
tp(5,av2);}}}

/* k12867 in chicken.flonum#fpsinh in k10751 in k8834 */
static void C_ccall f_12869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12869,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_sinh(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpcosh in k10751 in k8834 */
static void C_ccall f_12871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12871,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12887,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_cosh(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[495];
av2[4]=t2;
tp(5,av2);}}}

/* k12885 in chicken.flonum#fpcosh in k10751 in k8834 */
static void C_ccall f_12887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12887,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_cosh(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fptanh in k10751 in k8834 */
static void C_ccall f_12889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12889,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12905,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_tanh(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[497];
av2[4]=t2;
tp(5,av2);}}}

/* k12903 in chicken.flonum#fptanh in k10751 in k8834 */
static void C_ccall f_12905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12905,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_tanh(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpasinh in k10751 in k8834 */
static void C_ccall f_12907(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12907,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12923,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_asinh(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[499];
av2[4]=t2;
tp(5,av2);}}}

/* k12921 in chicken.flonum#fpasinh in k10751 in k8834 */
static void C_ccall f_12923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12923,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_asinh(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpacosh in k10751 in k8834 */
static void C_ccall f_12925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12925,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12941,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_acosh(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[501];
av2[4]=t2;
tp(5,av2);}}}

/* k12939 in chicken.flonum#fpacosh in k10751 in k8834 */
static void C_ccall f_12941(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12941,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_acosh(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpatanh in k10751 in k8834 */
static void C_ccall f_12943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12943,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12959,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_atanh(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[503];
av2[4]=t2;
tp(5,av2);}}}

/* k12957 in chicken.flonum#fpatanh in k10751 in k8834 */
static void C_ccall f_12959(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12959,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_atanh(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpexp in k10751 in k8834 */
static void C_ccall f_12961(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_12961,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12977,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_exp(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[505];
av2[4]=t2;
tp(5,av2);}}}

/* k12975 in chicken.flonum#fpexp in k10751 in k8834 */
static void C_ccall f_12977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_12977,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_exp(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpexpt in k10751 in k8834 */
static void C_ccall f_12979(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_12979,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13001,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=C_i_flonump(t2);
t6=(C_truep(t5)?C_i_flonump(t3):C_SCHEME_FALSE);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_a_i_flonum_expt(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1593: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t7;
av2[3]=lf[507];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}}

/* k12999 in chicken.flonum#fpexpt in k10751 in k8834 */
static void C_ccall f_13001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_13001,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_flonum_expt(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fplog in k10751 in k8834 */
static void C_ccall f_13003(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13003,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13019,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_log(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[509];
av2[4]=t2;
tp(5,av2);}}}

/* k13017 in chicken.flonum#fplog in k10751 in k8834 */
static void C_ccall f_13019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_13019,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_log(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpsqrt in k10751 in k8834 */
static void C_ccall f_13021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13021,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13037,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_sqrt(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[511];
av2[4]=t2;
tp(5,av2);}}}

/* k13035 in chicken.flonum#fpsqrt in k10751 in k8834 */
static void C_ccall f_13037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_13037,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_sqrt(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpabs in k10751 in k8834 */
static void C_ccall f_13039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13039,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13055,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_flonum(&a,C_fabs(C_flonum_magnitude(t2)));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[513];
av2[4]=t2;
tp(5,av2);}}}

/* k13053 in chicken.flonum#fpabs in k10751 in k8834 */
static void C_ccall f_13055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_13055,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_flonum(&a,C_fabs(C_flonum_magnitude(((C_word*)t0)[3])));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#fpinteger? in k10751 in k8834 */
static void C_ccall f_13057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_13057,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13073,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_fpintegerp(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fix((C_word)C_BAD_ARGUMENT_TYPE_NO_FLONUM_ERROR);
/* library.scm:1589: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[515];
av2[4]=t2;
tp(5,av2);}}}

/* k13071 in chicken.flonum#fpinteger? in k10751 in k8834 */
static void C_ccall f_13073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13073,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_u_i_fpintegerp(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.flonum#flonum-print-precision in k10751 in k8834 */
static void C_ccall f_13075(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13075,c,av);}
a=C_alloc(5);
t2=C_rest_nullp(c,2);
t3=(C_truep(t2)?C_SCHEME_FALSE:C_get_rest_arg(c,2,av,2,t0));
t4=C_get_print_precision();
if(C_truep(t3)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13085,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1752: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t5;
av2[2]=t3;
av2[3]=lf[517];
tp(4,av2);}}
else{
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k13083 in chicken.flonum#flonum-print-precision in k10751 in k8834 */
static void C_ccall f_13085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13085,c,av);}
t2=C_set_print_precision(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* make-complex in k10751 in k8834 */
static void C_fcall f_13097(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_13097,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_eqp(t3,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13107,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t4)){
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=t4;
f_13107(2,av2);}}
else{
if(C_truep(C_i_flonump(t3))){
/* library.scm:1772: chicken.flonum#fp= */
t6=*((C_word*)lf[454]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
av2[3]=lf[523];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_13107(2,av2);}}}}

/* k13105 in make-complex in k10751 in k8834 */
static void C_ccall f_13107(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_13107,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13111,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_inexactp(((C_word*)t0)[4]))){
/* library.scm:1775: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
f_13111(2,av2);}}}}

/* k13109 in k13105 in make-complex in k10751 in k8834 */
static void C_ccall f_13111(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,1)))){
C_save_and_reclaim((void *)f_13111,c,av);}
a=C_alloc(14);
if(C_truep(C_i_inexactp(((C_word*)t0)[2]))){
t2=C_a_i_exact_to_inexact(&a,1,((C_word*)t0)[3]);
t3=C_a_i_cplxnum(&a,2,t1,t2);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=C_a_i_cplxnum(&a,2,t1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* scheme#make-rectangular in k10751 in k8834 */
static void C_ccall f_13133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13133,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13137,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1780: ##sys#check-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[369]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[369]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[525];
tp(4,av2);}}

/* k13135 in scheme#make-rectangular in k10751 in k8834 */
static void C_ccall f_13137(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13137,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13140,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:1781: ##sys#check-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[369]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[369]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[525];
tp(4,av2);}}

/* k13138 in k13135 in scheme#make-rectangular in k10751 in k8834 */
static void C_ccall f_13140(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13140,c,av);}
/* library.scm:1782: make-complex */
f_13097(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);}

/* scheme#make-polar in k10751 in k8834 */
static void C_ccall f_13145(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13145,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13149,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1786: ##sys#check-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[369]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[369]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[527];
tp(4,av2);}}

/* k13147 in scheme#make-polar in k10751 in k8834 */
static void C_ccall f_13149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13149,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13152,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:1787: ##sys#check-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[369]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[369]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[527];
tp(4,av2);}}

/* k13150 in k13147 in scheme#make-polar in k10751 in k8834 */
static void C_ccall f_13152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13152,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13155,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:1788: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13153 in k13150 in k13147 in scheme#make-polar in k10751 in k8834 */
static void C_ccall f_13155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(74,c,3)))){
C_save_and_reclaim((void *)f_13155,c,av);}
a=C_alloc(74);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],C_a_i_cos(&a,1,t1));
t3=C_s_a_i_times(&a,2,((C_word*)t0)[2],C_a_i_sin(&a,1,t1));
/* library.scm:1789: make-complex */
f_13097(((C_word*)t0)[3],t2,t3);}

/* scheme#real-part in k10751 in k8834 */
static void C_ccall f_13168(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13168,c,av);}
if(C_truep(C_i_cplxnump(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_cplxnum_real(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_numberp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* library.scm:1797: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[529];
tp(4,av2);}}}}

/* scheme#imag-part in k10751 in k8834 */
static void C_ccall f_13191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13191,c,av);}
if(C_truep(C_i_cplxnump(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_cplxnum_imag(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[523];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_numberp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* library.scm:1804: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[531];
tp(4,av2);}}}}}

/* scheme#angle in k10751 in k8834 */
static void C_ccall f_13217(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13217,c,av);}
a=C_alloc(4);
t3=C_i_check_number_2(t2,lf[533]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13226,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1810: scheme#imag-part */
t5=*((C_word*)lf[530]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k13224 in scheme#angle in k10751 in k8834 */
static void C_ccall f_13226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_13226,c,av);}
a=C_alloc(15);
t2=C_a_i_exact_to_inexact(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13231,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1811: scheme#real-part */
t4=*((C_word*)lf[528]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k13229 in k13224 in scheme#angle in k10751 in k8834 */
static void C_ccall f_13231(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,1)))){
C_save_and_reclaim((void *)f_13231,c,av);}
a=C_alloc(15);
t2=C_a_i_exact_to_inexact(&a,1,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_atan2(&a,2,((C_word*)t0)[3],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#magnitude in k10751 in k8834 */
static void C_ccall f_13233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(95,c,3)))){
C_save_and_reclaim((void *)f_13233,c,av);}
a=C_alloc(95);
if(C_truep(C_i_cplxnump(t2))){
t3=C_u_i_cplxnum_real(t2);
t4=C_u_i_cplxnum_imag(t2);
t5=C_s_a_i_times(&a,2,t3,t3);
t6=C_s_a_i_times(&a,2,t4,t4);
t7=C_s_a_i_plus(&a,2,t5,t6);
/* library.scm:1818: scheme#sqrt */
t8=*((C_word*)lf[535]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t1;
av2[2]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
if(C_truep(C_i_numberp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_i_abs(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* library.scm:1820: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[536];
tp(4,av2);}}}}

/* ratnum in k10751 in k8834 */
static C_word C_fcall f_13277(C_word *a,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;{}
switch(t2){
case C_fix(1):
return(t1);
case C_fix(-1):
return(C_s_a_u_i_integer_negate(&a,1,t1));
default:
if(C_truep(C_i_negativep(t2))){
t3=C_s_a_u_i_integer_negate(&a,1,t1);
t4=C_s_a_u_i_integer_negate(&a,1,t2);
return(C_a_i_ratnum(&a,2,t3,t4));}
else{
return(C_a_i_ratnum(&a,2,t1,t2));}}}

/* scheme#numerator in k10751 in k8834 */
static void C_ccall f_13323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_13323,c,av);}
a=C_alloc(6);
if(C_truep(C_i_exact_integerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
if(C_truep(C_i_not(C_i_finitep(t2)))){
/* library.scm:1840: ##sys#error-bad-inexact */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[380]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[380]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[539];
tp(4,av2);}}
else{
if(C_truep(C_u_i_fpintegerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13347,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13351,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:1842: scheme#inexact->exact */
t5=*((C_word*)lf[540]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}}
else{
if(C_truep(C_i_ratnump(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_ratnum_num(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* library.scm:1844: ##sys#signal-hook */
t3=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=lf[539];
av2[4]=lf[541];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}}}}

/* k13345 in scheme#numerator in k10751 in k8834 */
static void C_ccall f_13347(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,1)))){
C_save_and_reclaim((void *)f_13347,c,av);}
a=C_alloc(11);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_exact_to_inexact(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k13349 in scheme#numerator in k10751 in k8834 */
static void C_ccall f_13351(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13351,c,av);}
/* library.scm:1842: scheme#numerator */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* scheme#denominator in k10751 in k8834 */
static void C_ccall f_13369(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_13369,c,av);}
a=C_alloc(6);
if(C_truep(C_i_exact_integerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fix(1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
if(C_truep(C_i_not(C_i_finitep(t2)))){
/* library.scm:1852: ##sys#error-bad-inexact */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[380]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[380]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[543];
tp(4,av2);}}
else{
if(C_truep(C_u_i_fpintegerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[544];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13393,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13397,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:1854: scheme#inexact->exact */
t5=*((C_word*)lf[540]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}}
else{
if(C_truep(C_i_ratnump(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_ratnum_denom(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* library.scm:1856: ##sys#signal-hook */
t3=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=lf[539];
av2[4]=lf[545];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}}}}

/* k13391 in scheme#denominator in k10751 in k8834 */
static void C_ccall f_13393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,1)))){
C_save_and_reclaim((void *)f_13393,c,av);}
a=C_alloc(11);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_exact_to_inexact(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k13395 in scheme#denominator in k10751 in k8834 */
static void C_ccall f_13397(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13397,c,av);}
/* library.scm:1854: scheme#denominator */
t2=*((C_word*)lf[542]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* ##sys#extended-signum in k10751 in k8834 */
static void C_ccall f_13415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_13415,c,av);}
a=C_alloc(26);
if(C_truep(C_i_ratnump(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_u_i_integer_signum(C_u_i_ratnum_num(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_cplxnump(t2))){
t3=C_u_i_cplxnum_imag(t2);
t4=C_a_i_exact_to_inexact(&a,1,t3);
t5=C_u_i_cplxnum_real(t2);
t6=C_a_i_exact_to_inexact(&a,1,t5);
t7=C_flonum(&a,C_atan2(C_flonum_magnitude(t4),C_flonum_magnitude(t6)));
/* library.scm:1863: scheme#make-polar */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[526]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[526]+1);
av2[1]=t1;
av2[2]=C_fix(1);
av2[3]=t7;
tp(4,av2);}}
else{
/* library.scm:1864: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[547];
tp(4,av2);}}}}

/* doloop2294 in deliver in scheme#inexact->exact in k10751 in k8834 */
static void C_fcall f_13456(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_13456,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_u_i_fpintegerp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13467,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1872: chicken.flonum#fp* */
t5=*((C_word*)lf[444]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[551];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k13465 in doloop2294 in deliver in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13467(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13467,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_13456(t2,((C_word*)t0)[3],t1,C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* deliver in scheme#inexact->exact in k10751 in k8834 */
static void C_fcall f_13473(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,4)))){
C_save_and_reclaim_args((void *)trf_13473,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13477,a[2]=t2,a[3]=t1,a[4]=t3,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13508,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13456,a[2]=t7,a[3]=((C_word)li386),tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_13456(t9,t5,t2,C_fix(0));}

/* k13475 in deliver in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13477(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_13477,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13504,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:1878: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13489 in k13502 in k13475 in deliver in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13491(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13491,c,av);}
/* library.scm:1880: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k13502 in k13475 in deliver in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(42,c,3)))){
C_save_and_reclaim((void *)f_13504,c,av);}
a=C_alloc(42);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
if(C_truep(C_i_finitep(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13491,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=C_s_a_u_i_flo_to_int(&a,1,t2);
/* library.scm:1880: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=((C_word*)t0)[5];
tp(4,av2);}}
else{
/* library.scm:1881: ##sys#error-bad-inexact */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[380]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[380]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[6];
av2[3]=lf[549];
tp(4,av2);}}}

/* k13506 in deliver in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13508,c,av);}
/* library.scm:1877: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[550]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=C_fix(2);
av2[3]=t1;
tp(4,av2);}}

/* k13523 in k13527 in k13533 in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13525(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13525,c,av);}
/* library.scm:1885: deliver */
t2=((C_word*)t0)[2];
f_13473(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k13527 in k13533 in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13529(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(38,c,3)))){
C_save_and_reclaim((void *)f_13529,c,av);}
a=C_alloc(38);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13525,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1888: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t3;
av2[2]=C_fix(2);
av2[3]=*((C_word*)lf[434]+1);
tp(4,av2);}}

/* k13533 in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13535,c,av);}
a=C_alloc(5);
t2=(C_truep(t1)?C_ub_i_flonum_greaterp(C_flonum_magnitude(((C_word*)t0)[2]),(double)-1.0):C_SCHEME_FALSE);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13529,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:1885: scheme#expt */
t4=*((C_word*)lf[552]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[551];
av2[3]=*((C_word*)lf[434]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
/* library.scm:1889: deliver */
t3=((C_word*)t0)[3];
f_13473(t3,((C_word*)t0)[4],((C_word*)t0)[2],C_fix(1));}}

/* scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13539(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_13539,c,av);}
a=C_alloc(9);
if(C_truep(C_i_exactp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
if(C_truep(C_u_i_fpintegerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_u_i_flo_to_int(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_u_i_flonum_finitep(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13473,a[2]=t2,a[3]=((C_word)li387),tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13535,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1883: chicken.flonum#fp< */
t5=*((C_word*)lf[458]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[544];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
/* library.scm:1897: ##sys#error-bad-inexact */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[380]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[380]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[549];
tp(4,av2);}}}}
else{
if(C_truep(C_i_cplxnump(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13579,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1899: scheme#inexact->exact */
t4=*((C_word*)lf[540]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=C_u_i_cplxnum_real(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
/* library.scm:1901: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[549];
tp(4,av2);}}}}}

/* k13577 in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13579,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13583,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1900: scheme#inexact->exact */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_cplxnum_imag(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13581 in k13577 in scheme#inexact->exact in k10751 in k8834 */
static void C_ccall f_13583(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13583,c,av);}
/* library.scm:1899: make-complex */
f_13097(((C_word*)t0)[2],((C_word*)t0)[3],t1);}

/* chicken.bitwise#bitwise-not in k10751 in k8834 */
static void C_ccall f_13605(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_13605,c,av);}
a=C_alloc(5);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_i_bitwise_not(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.bitwise#bit->boolean in k10751 in k8834 */
static void C_ccall f_13608(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13608,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_bit_to_bool(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.bitwise#integer-length in k10751 in k8834 */
static void C_ccall f_13611(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13611,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_integer_length(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.bitwise#arithmetic-shift in k10751 in k8834 */
static void C_ccall f_13614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_13614,c,av);}
a=C_alloc(5);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_s_a_i_arithmetic_shift(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#/ in k10751 in k8834 */
static void C_ccall f_13617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +4,c,3)))){
C_save_and_reclaim((void*)f_13617,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+4);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
if(C_truep(C_rest_nullp(c,3))){
/* library.scm:1936: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t1;
av2[2]=C_fix(1);
av2[3]=t2;
tp(4,av2);}}
else{
t4=C_slot(t3,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13638,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1938: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=t2;
av2[3]=C_slot(t3,C_fix(0));
tp(4,av2);}}}

/* k13636 in scheme#/ in k10751 in k8834 */
static void C_ccall f_13638(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_13638,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13640,a[2]=t3,a[3]=((C_word)li396),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_13640(t5,((C_word*)t0)[2],((C_word*)t0)[3],t1);}

/* loop in k13636 in scheme#/ in k10751 in k8834 */
static void C_fcall f_13640(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_13640,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13658,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* library.scm:1942: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=t3;
av2[3]=C_slot(t2,C_fix(0));
tp(4,av2);}}}

/* k13656 in loop in k13636 in scheme#/ in k10751 in k8834 */
static void C_ccall f_13658(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13658,c,av);}
/* library.scm:1941: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13640(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_13668,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13672,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t5=C_eqp(t3,C_fix(0));
if(C_truep(t5)){
t6=C_fix((C_word)C_DIVISION_BY_ZERO_ERROR);
/* library.scm:1949: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=t4;
av2[2]=t6;
av2[3]=lf[565];
av2[4]=t2;
av2[5]=t3;
tp(6,av2);}}
else{
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_13672(2,av2);}}}

/* k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13672(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(117,c,4)))){
C_save_and_reclaim((void *)f_13672,c,av);}
a=C_alloc(117);
t2=(C_truep(C_i_exact_integerp(((C_word*)t0)[2]))?C_i_exact_integerp(((C_word*)t0)[3]):C_SCHEME_FALSE);
if(C_truep(t2)){
t3=C_s_a_u_i_integer_gcd(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t4=C_s_a_u_i_integer_quotient(&a,2,((C_word*)t0)[2],t3);
t5=C_s_a_u_i_integer_quotient(&a,2,((C_word*)t0)[3],t3);
/* library.scm:1952: ratnum */
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=(
/* library.scm:1952: ratnum */
  f_13277(C_a_i(&a,21),t4,t5)
);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t3=C_i_cplxnump(((C_word*)t0)[2]);
t4=(C_truep(t3)?t3:C_i_cplxnump(((C_word*)t0)[3]));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13710,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:1955: scheme#real-part */
t6=*((C_word*)lf[528]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_i_flonump(((C_word*)t0)[2]);
t6=(C_truep(t5)?t5:C_i_flonump(((C_word*)t0)[3]));
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13776,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:1963: scheme#exact->inexact */
t8=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
if(C_truep(C_i_ratnump(((C_word*)t0)[2]))){
if(C_truep(C_i_ratnump(((C_word*)t0)[3]))){
t7=C_u_i_ratnum_num(((C_word*)t0)[2]);
t8=C_u_i_ratnum_denom(((C_word*)t0)[2]);
t9=C_u_i_ratnum_num(((C_word*)t0)[3]);
t10=C_u_i_ratnum_denom(((C_word*)t0)[3]);
t11=C_s_a_u_i_integer_gcd(&a,2,t7,t9);
t12=C_s_a_u_i_integer_gcd(&a,2,t8,t10);
t13=C_s_a_i_quotient(&a,2,t7,t11);
t14=C_s_a_i_quotient(&a,2,t10,t12);
t15=C_s_a_i_times(&a,2,t13,t14);
t16=C_s_a_i_quotient(&a,2,t8,t12);
t17=C_s_a_i_quotient(&a,2,t9,t11);
t18=C_s_a_i_times(&a,2,t16,t17);
/* library.scm:1973: ratnum */
t19=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t19;
av2[1]=(
/* library.scm:1973: ratnum */
  f_13277(C_a_i(&a,21),t15,t18)
);
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}
else{
t7=C_u_i_ratnum_num(((C_word*)t0)[2]);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13857,a[2]=t7,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:1979: ##sys#internal-gcd */
f_15603(t8,lf[565],t7,((C_word*)t0)[3]);}}
else{
if(C_truep(C_i_ratnump(((C_word*)t0)[3]))){
t7=C_u_i_ratnum_num(((C_word*)t0)[3]);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13896,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t7,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:1990: ##sys#internal-gcd */
f_15603(t8,lf[565],((C_word*)t0)[2],t7);}
else{
t7=C_i_numberp(((C_word*)t0)[2]);
if(C_truep(C_i_not(t7))){
/* library.scm:1996: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[379]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[2];
av2[3]=lf[565];
tp(4,av2);}}
else{
/* library.scm:1997: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[379]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[565];
tp(4,av2);}}}}}}}}

/* k13708 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13710(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_13710,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13713,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:1955: scheme#imag-part */
t3=*((C_word*)lf[530]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13711 in k13708 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13713(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_13713,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13716,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:1956: scheme#real-part */
t3=*((C_word*)lf[528]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13714 in k13711 in k13708 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13716(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_13716,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13719,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:1956: scheme#imag-part */
t3=*((C_word*)lf[530]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13717 in k13714 in k13711 in k13708 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(198,c,3)))){
C_save_and_reclaim((void *)f_13719,c,av);}
a=C_alloc(198);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],((C_word*)t0)[2]);
t3=C_s_a_i_times(&a,2,t1,t1);
t4=C_s_a_i_plus(&a,2,t2,t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13725,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
t6=C_s_a_i_times(&a,2,((C_word*)t0)[5],((C_word*)t0)[2]);
t7=C_s_a_i_times(&a,2,((C_word*)t0)[4],t1);
t8=C_s_a_i_plus(&a,2,t6,t7);
/* library.scm:1958: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=t8;
av2[3]=t4;
tp(4,av2);}}

/* k13723 in k13717 in k13714 in k13711 in k13708 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13725(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(99,c,3)))){
C_save_and_reclaim((void *)f_13725,c,av);}
a=C_alloc(99);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13728,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_s_a_i_times(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t4=C_s_a_i_times(&a,2,((C_word*)t0)[5],((C_word*)t0)[6]);
t5=C_s_a_i_minus(&a,2,t3,t4);
/* library.scm:1959: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t2;
av2[2]=t5;
av2[3]=((C_word*)t0)[7];
tp(4,av2);}}

/* k13726 in k13723 in k13717 in k13714 in k13711 in k13708 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13728(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13728,c,av);}
/* library.scm:1960: make-complex */
f_13097(((C_word*)t0)[2],((C_word*)t0)[3],t1);}

/* k13774 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13776,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13780,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:1963: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13778 in k13774 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13780,c,av);}
/* library.scm:1963: chicken.flonum#fp/ */
t2=*((C_word*)lf[446]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13855 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13857(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(64,c,3)))){
C_save_and_reclaim((void *)f_13857,c,av);}
a=C_alloc(64);
t2=C_s_a_i_quotient(&a,2,((C_word*)t0)[2],t1);
t3=C_u_i_ratnum_denom(((C_word*)t0)[3]);
t4=C_s_a_i_quotient(&a,2,((C_word*)t0)[4],t1);
t5=C_s_a_i_times(&a,2,t3,t4);
if(C_truep(C_i_flonump(t5))){
/* library.scm:1983: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[5];
av2[2]=t2;
av2[3]=t5;
tp(4,av2);}}
else{
/* library.scm:1984: ratnum */
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=(
/* library.scm:1984: ratnum */
  f_13277(C_a_i(&a,21),t2,t5)
);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k13894 in k13670 in ##sys#/-2 in k10751 in k8834 */
static void C_ccall f_13896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(64,c,3)))){
C_save_and_reclaim((void *)f_13896,c,av);}
a=C_alloc(64);
t2=C_s_a_i_quotient(&a,2,((C_word*)t0)[2],t1);
t3=C_u_i_ratnum_denom(((C_word*)t0)[3]);
t4=C_s_a_i_times(&a,2,t2,t3);
t5=C_s_a_i_quotient(&a,2,((C_word*)t0)[4],t1);
if(C_truep(C_i_flonump(t5))){
/* library.scm:1994: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[5];
av2[2]=t4;
av2[3]=t5;
tp(4,av2);}}
else{
/* library.scm:1995: ratnum */
t6=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t6;
av2[1]=(
/* library.scm:1995: ratnum */
  f_13277(C_a_i(&a,21),t4,t5)
);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* scheme#floor in k10751 in k8834 */
static void C_ccall f_13951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(34,c,3)))){
C_save_and_reclaim((void *)f_13951,c,av);}
a=C_alloc(34);
if(C_truep(C_i_exact_integerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
/* library.scm:2002: chicken.flonum#fpfloor */
t3=*((C_word*)lf[470]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
if(C_truep(C_i_ratnump(t2))){
t3=C_u_i_ratnum_num(t2);
t4=C_u_i_ratnum_denom(t2);
t5=C_s_a_i_quotient(&a,2,t3,t4);
t6=C_i_greater_or_equalp(t3,C_fix(0));
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t6)?t5:C_s_a_i_minus(&a,2,t5,C_fix(1)));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* library.scm:2007: ##sys#error-bad-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[370]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[567];
tp(4,av2);}}}}}

/* scheme#ceiling in k10751 in k8834 */
static void C_ccall f_13996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(34,c,3)))){
C_save_and_reclaim((void *)f_13996,c,av);}
a=C_alloc(34);
if(C_truep(C_i_exact_integerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
/* library.scm:2012: chicken.flonum#fpceiling */
t3=*((C_word*)lf[476]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
if(C_truep(C_i_ratnump(t2))){
t3=C_u_i_ratnum_num(t2);
t4=C_u_i_ratnum_denom(t2);
t5=C_s_a_i_quotient(&a,2,t3,t4);
t6=C_i_greater_or_equalp(t3,C_fix(0));
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t6)?C_s_a_i_plus(&a,2,t5,C_fix(1)):t5);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* library.scm:2017: ##sys#error-bad-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[370]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[569];
tp(4,av2);}}}}}

/* scheme#truncate in k10751 in k8834 */
static void C_ccall f_14041(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14041,c,av);}
a=C_alloc(5);
if(C_truep(C_i_exact_integerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
/* library.scm:2022: chicken.flonum#fptruncate */
t3=*((C_word*)lf[472]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
if(C_truep(C_i_ratnump(t2))){
t3=C_u_i_ratnum_num(t2);
t4=C_u_i_ratnum_denom(t2);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_s_a_i_quotient(&a,2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* library.scm:2026: ##sys#error-bad-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[370]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[571];
tp(4,av2);}}}}}

/* scheme#round in k10751 in k8834 */
static void C_ccall f_14078(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(36,c,3)))){
C_save_and_reclaim((void *)f_14078,c,av);}
a=C_alloc(36);
if(C_truep(C_i_exact_integerp(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_flonump(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_flonum_round_proper(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_ratnump(t2))){
t3=C_a_i_ratnum(&a,2,C_fix(1),C_fix(2));
t4=C_s_a_i_plus(&a,2,t2,t3);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14098,a[2]=t4,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2035: scheme#floor */
t6=*((C_word*)lf[566]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
/* library.scm:2037: ##sys#error-bad-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[370]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[573];
tp(4,av2);}}}}}

/* k14096 in scheme#round in k10751 in k8834 */
static void C_ccall f_14098(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_14098,c,av);}
a=C_alloc(29);
t2=C_i_nequalp(t1,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?(C_truep(C_i_oddp(t1))?C_s_a_i_minus(&a,2,t1,C_fix(1)):t1):t1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* find-ratio-between in k10751 in k8834 */
static void C_fcall f_14122(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(67,0,4)))){
C_save_and_reclaim_args((void *)trf_14122,3,t1,t2,t3);}
a=C_alloc(67);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14125,a[2]=t5,a[3]=((C_word)li403),tmp=(C_word)a,a+=4,tmp));
if(C_truep(C_i_lessp(t3,t2))){
/* library.scm:2050: find-ratio-between */
t12=t1;
t13=t3;
t14=t2;
t1=t12;
t2=t13;
t3=t14;
goto loop;}
else{
t7=C_i_lessp(t2,t3);
if(C_truep(C_i_not(t7))){
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_a_i_list2(&a,2,t2,C_fix(1));
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
if(C_truep(C_i_positivep(t2))){
/* library.scm:2052: sr */
t8=((C_word*)t5)[1];
f_14125(t8,t1,t2,t3);}
else{
if(C_truep(C_i_negativep(t3))){
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14236,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t9=C_s_a_i_negate(&a,1,t3);
t10=C_s_a_i_negate(&a,1,t2);
/* library.scm:2053: sr */
t11=((C_word*)t5)[1];
f_14125(t11,t8,t9,t10);}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=lf[575];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}}}

/* sr in find-ratio-between in k10751 in k8834 */
static void C_fcall f_14125(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_14125,4,t0,t1,t2,t3);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14129,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14204,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2041: scheme#floor */
t6=*((C_word*)lf[566]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k14127 in sr in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14129(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_14129,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14132,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14200,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2042: scheme#floor */
t4=*((C_word*)lf[566]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k14130 in k14127 in sr in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14132(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,3)))){
C_save_and_reclaim((void *)f_14132,c,av);}
a=C_alloc(39);
t2=C_i_lessp(((C_word*)t0)[2],((C_word*)t0)[3]);
if(C_truep(C_i_not(t2))){
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list2(&a,2,((C_word*)t0)[2],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_nequalp(((C_word*)t0)[2],t1))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14150,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14173,a[2]=((C_word*)t0)[5],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t5=C_s_a_i_minus(&a,2,((C_word*)t0)[6],t1);
/* library.scm:2045: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t4;
av2[2]=C_fix(1);
av2[3]=t5;
tp(4,av2);}}
else{
t3=C_s_a_i_plus(&a,2,C_fix(1),((C_word*)t0)[2]);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list2(&a,2,t3,C_fix(1));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* k14148 in k14130 in k14127 in sr in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14150(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(68,c,1)))){
C_save_and_reclaim((void *)f_14150,c,av);}
a=C_alloc(68);
t2=C_i_cadr(t1);
t3=C_u_i_car(t1);
t4=C_s_a_i_times(&a,2,((C_word*)t0)[2],t3);
t5=C_s_a_i_plus(&a,2,t2,t4);
t6=C_u_i_car(t1);
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_a_i_list2(&a,2,t5,t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* k14171 in k14130 in k14127 in sr in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14173(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(34,c,3)))){
C_save_and_reclaim((void *)f_14173,c,av);}
a=C_alloc(34);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14177,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]);
/* library.scm:2046: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t2;
av2[2]=C_fix(1);
av2[3]=t3;
tp(4,av2);}}

/* k14175 in k14171 in k14130 in k14127 in sr in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14177(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14177,c,av);}
/* library.scm:2045: sr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_14125(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k14198 in k14127 in sr in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14200,c,av);}
/* library.scm:2042: scheme#inexact->exact */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k14202 in sr in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14204,c,av);}
/* library.scm:2041: scheme#inexact->exact */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k14234 in find-ratio-between in k10751 in k8834 */
static void C_ccall f_14236(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(35,c,1)))){
C_save_and_reclaim((void *)f_14236,c,av);}
a=C_alloc(35);
t2=C_i_car(t1);
t3=C_s_a_i_negate(&a,1,t2);
t4=C_i_cadr(t1);
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_a_i_list2(&a,2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#rationalize in k10751 in k8834 */
static void C_ccall f_14272(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(66,c,3)))){
C_save_and_reclaim((void *)f_14272,c,av);}
a=C_alloc(66);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14276,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14295,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=C_s_a_i_minus(&a,2,t2,t3);
t7=C_s_a_i_plus(&a,2,t2,t3);
/* library.scm:2057: find-ratio-between */
f_14122(t5,t6,t7);}

/* k14274 in scheme#rationalize in k10751 in k8834 */
static void C_ccall f_14276(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14276,c,av);}
t2=C_i_inexactp(((C_word*)t0)[2]);
if(C_truep(t2)){
if(C_truep(t2)){
/* library.scm:2063: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
if(C_truep(C_i_inexactp(((C_word*)t0)[4]))){
/* library.scm:2063: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k14293 in scheme#rationalize in k10751 in k8834 */
static void C_ccall f_14295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14295,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[548]+1);
av2[3]=t1;
C_apply(4,av2);}}

/* scheme#max in k10751 in k8834 */
static void C_ccall f_14297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +6,c,5)))){
C_save_and_reclaim((void*)f_14297,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+6);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
t4=C_i_flonump(t2);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14304,a[2]=t6,a[3]=((C_word)li406),tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_14304(t8,t1,t4,t2,t3);}

/* loop in scheme#max in k10751 in k8834 */
static void C_fcall f_14304(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_14304,5,t0,t1,t2,t3,t4);}
a=C_alloc(11);
t5=C_i_check_number_2(t3,lf[578]);
if(C_truep(C_i_nullp(t4))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t2)?C_a_i_exact_to_inexact(&a,1,t3):t3);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_slot(t4,C_fix(0));
t7=(C_truep(t2)?t2:C_i_flonump(t6));
t8=C_i_greaterp(t6,t3);
t9=(C_truep(t8)?t6:t3);
/* library.scm:2073: loop */
t11=t1;
t12=t7;
t13=t9;
t14=C_slot(t4,C_fix(1));
t1=t11;
t2=t12;
t3=t13;
t4=t14;
goto loop;}}

/* scheme#min in k10751 in k8834 */
static void C_ccall f_14341(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +6,c,5)))){
C_save_and_reclaim((void*)f_14341,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+6);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
t4=C_i_flonump(t2);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14348,a[2]=t6,a[3]=((C_word)li408),tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_14348(t8,t1,t4,t2,t3);}

/* loop in scheme#min in k10751 in k8834 */
static void C_fcall f_14348(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_14348,5,t0,t1,t2,t3,t4);}
a=C_alloc(11);
t5=C_i_check_number_2(t3,lf[580]);
if(C_truep(C_i_nullp(t4))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t2)?C_a_i_exact_to_inexact(&a,1,t3):t3);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_slot(t4,C_fix(0));
t7=(C_truep(t2)?t2:C_i_flonump(t6));
t8=C_i_lessp(t6,t3);
t9=(C_truep(t8)?t6:t3);
/* library.scm:2084: loop */
t11=t1;
t12=t7;
t13=t9;
t14=C_slot(t4,C_fix(1));
t1=t11;
t2=t12;
t3=t13;
t4=t14;
goto loop;}}

/* scheme#exp in k10751 in k8834 */
static void C_ccall f_14385(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_14385,c,av);}
a=C_alloc(15);
t3=C_i_check_number_2(t2,lf[582]);
if(C_truep(C_i_cplxnump(t2))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14403,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2093: scheme#exact->inexact */
t5=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=C_u_i_cplxnum_real(t2);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_a_i_exact_to_inexact(&a,1,t2);
t5=C_flonum(&a,C_exp(C_flonum_magnitude(t4)));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k14401 in scheme#exp in k10751 in k8834 */
static void C_ccall f_14403(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_14403,c,av);}
a=C_alloc(12);
t2=C_a_i_exp(&a,1,t1);
t3=C_u_i_cplxnum_imag(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14412,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14417,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2096: scheme#exact->inexact */
t6=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k14410 in k14401 in scheme#exp in k10751 in k8834 */
static void C_ccall f_14412(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,1)))){
C_save_and_reclaim((void *)f_14412,c,av);}
a=C_alloc(33);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_times(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k14415 in k14401 in scheme#exp in k10751 in k8834 */
static void C_ccall f_14417(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_14417,c,av);}
a=C_alloc(19);
t2=C_a_i_cos(&a,1,t1);
t3=C_a_i_exact_to_inexact(&a,1,((C_word*)t0)[2]);
t4=C_a_i_sin(&a,1,t3);
/* library.scm:2095: make-complex */
f_13097(((C_word*)t0)[3],t2,t4);}

/* ##sys#log-1 in k10751 in k8834 */
static void C_ccall f_14430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_14430,c,av);}
a=C_alloc(7);
t3=C_eqp(t2,C_fix(0));
if(C_truep(t3)){
/* library.scm:2103: ##sys#signal-hook */
t4=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[584];
av2[3]=lf[585];
av2[4]=lf[586];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
t4=C_i_cplxnump(t2);
t5=(C_truep(t4)?t4:C_i_negativep(t2));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14456,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14472,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2106: scheme#magnitude */
t8=*((C_word*)lf[534]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14476,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2109: scheme#exact->inexact */
t7=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}}

/* k14454 in ##sys#log-1 in k10751 in k8834 */
static void C_ccall f_14456(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14456,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14464,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2107: make-complex */
f_13097(t2,C_fix(0),C_fix(1));}

/* k14462 in k14454 in ##sys#log-1 in k10751 in k8834 */
static void C_ccall f_14464(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_14464,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14468,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2107: scheme#angle */
t3=*((C_word*)lf[532]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k14466 in k14462 in k14454 in ##sys#log-1 in k10751 in k8834 */
static void C_ccall f_14468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(62,c,1)))){
C_save_and_reclaim((void *)f_14468,c,av);}
a=C_alloc(62);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_i_plus(&a,2,((C_word*)t0)[4],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14470 in ##sys#log-1 in k10751 in k8834 */
static void C_ccall f_14472(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14472,c,av);}
/* library.scm:2106: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[583]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k14474 in ##sys#log-1 in k10751 in k8834 */
static void C_ccall f_14476(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_14476,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_log(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* scheme#log in k10751 in k8834 */
static void C_ccall f_14479(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14479,c,av);}
a=C_alloc(4);
t3=C_rest_nullp(c,3);
t4=(C_truep(t3)?C_SCHEME_FALSE:C_get_rest_arg(c,3,av,3,t0));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14493,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2113: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[583]+1);
av2[1]=t5;
av2[2]=t2;
tp(3,av2);}}
else{
/* library.scm:2113: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[583]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}}

/* k14491 in scheme#log in k10751 in k8834 */
static void C_ccall f_14493(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14493,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14497,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2113: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[583]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k14495 in k14491 in scheme#log in k10751 in k8834 */
static void C_ccall f_14497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14497,c,av);}
/* library.scm:2113: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* scheme#sin in k10751 in k8834 */
static void C_ccall f_14508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(37,c,2)))){
C_save_and_reclaim((void *)f_14508,c,av);}
a=C_alloc(37);
t3=C_i_check_number_2(t2,lf[589]);
if(C_truep(C_i_cplxnump(t2))){
t4=C_s_a_i_times(&a,2,lf[590],t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14532,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2120: scheme#exp */
t6=*((C_word*)lf[581]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=C_a_i_exact_to_inexact(&a,1,t2);
t5=C_a_i_sin(&a,1,t4);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k14530 in scheme#sin in k10751 in k8834 */
static void C_ccall f_14532(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_14532,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14536,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=C_s_a_i_negate(&a,1,((C_word*)t0)[3]);
/* library.scm:2120: scheme#exp */
t4=*((C_word*)lf[581]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k14534 in k14530 in scheme#sin in k10751 in k8834 */
static void C_ccall f_14536(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_14536,c,av);}
a=C_alloc(29);
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2120: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
av2[3]=lf[591];
tp(4,av2);}}

/* scheme#cos in k10751 in k8834 */
static void C_ccall f_14542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(37,c,2)))){
C_save_and_reclaim((void *)f_14542,c,av);}
a=C_alloc(37);
t3=C_i_check_number_2(t2,lf[593]);
if(C_truep(C_i_cplxnump(t2))){
t4=C_s_a_i_times(&a,2,lf[590],t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14566,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2128: scheme#exp */
t6=*((C_word*)lf[581]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=C_a_i_exact_to_inexact(&a,1,t2);
t5=C_a_i_cos(&a,1,t4);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k14564 in scheme#cos in k10751 in k8834 */
static void C_ccall f_14566(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_14566,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14570,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=C_s_a_i_negate(&a,1,((C_word*)t0)[3]);
/* library.scm:2128: scheme#exp */
t4=*((C_word*)lf[581]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k14568 in k14564 in scheme#cos in k10751 in k8834 */
static void C_ccall f_14570(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_14570,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2128: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
av2[3]=C_fix(2);
tp(4,av2);}}

/* scheme#tan in k10751 in k8834 */
static void C_ccall f_14576(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_14576,c,av);}
a=C_alloc(15);
t3=C_i_check_number_2(t2,lf[595]);
if(C_truep(C_i_cplxnump(t2))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14593,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2135: scheme#sin */
t5=*((C_word*)lf[588]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_a_i_exact_to_inexact(&a,1,t2);
t5=C_a_i_tan(&a,1,t4);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k14591 in scheme#tan in k10751 in k8834 */
static void C_ccall f_14593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14593,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14597,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2135: scheme#cos */
t3=*((C_word*)lf[592]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k14595 in k14591 in scheme#tan in k10751 in k8834 */
static void C_ccall f_14597(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14597,c,av);}
/* library.scm:2135: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* scheme#asin in k10751 in k8834 */
static void C_ccall f_14601(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_14601,c,av);}
a=C_alloc(8);
t3=C_i_check_number_2(t2,lf[597]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14611,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_flonump(t2))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14659,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2142: chicken.flonum#fp>= */
t6=*((C_word*)lf[460]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
av2[3]=lf[600];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t5=t4;
f_14611(t5,C_SCHEME_FALSE);}}

/* k14609 in scheme#asin in k10751 in k8834 */
static void C_fcall f_14611(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_14611,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=C_a_i_asin(&a,1,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14617,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_fixnump(((C_word*)t0)[2]))){
t3=C_fixnum_greater_or_equal_p(((C_word*)t0)[2],C_fix(-1));
t4=t2;
f_14617(t4,(C_truep(t3)?C_fixnum_less_or_equal_p(((C_word*)t0)[2],C_fix(1)):C_SCHEME_FALSE));}
else{
t3=t2;
f_14617(t3,C_SCHEME_FALSE);}}}

/* k14615 in k14609 in scheme#asin in k10751 in k8834 */
static void C_fcall f_14617(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(102,0,3)))){
C_save_and_reclaim_args((void *)trf_14617,2,t0,t1);}
a=C_alloc(102);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_a_i_asin(&a,1,C_a_i_fix_to_flo(&a,1,((C_word*)t0)[3]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14624,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_s_a_i_times(&a,2,lf[590],((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14636,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t5=C_s_a_i_times(&a,2,((C_word*)t0)[3],((C_word*)t0)[3]);
t6=C_s_a_i_minus(&a,2,C_fix(1),t5);
/* library.scm:2151: ##sys#sqrt/loc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[599]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[599]+1);
av2[1]=t4;
av2[2]=lf[597];
av2[3]=t6;
tp(4,av2);}}}

/* k14622 in k14615 in k14609 in scheme#asin in k10751 in k8834 */
static void C_ccall f_14624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,1)))){
C_save_and_reclaim((void *)f_14624,c,av);}
a=C_alloc(33);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_times(&a,2,lf[598],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k14634 in k14615 in k14609 in scheme#asin in k10751 in k8834 */
static void C_ccall f_14636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_14636,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2149: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[583]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
tp(3,av2);}}

/* k14657 in scheme#asin in k10751 in k8834 */
static void C_ccall f_14659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14659,c,av);}
t2=((C_word*)t0)[2];
f_14611(t2,(C_truep(t1)?C_ub_i_flonum_less_or_equal_p(C_flonum_magnitude(((C_word*)t0)[3]),(double)1.0):C_SCHEME_FALSE));}

/* scheme#acos in k10751 in k8834 */
static void C_ccall f_14663(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_14663,c,av);}
a=C_alloc(9);
t3=C_i_check_number_2(t2,lf[602]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14673,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_flonump(t2))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14701,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2159: chicken.flonum#fp>= */
t6=*((C_word*)lf[460]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
av2[3]=lf[600];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t5=t4;
f_14673(t5,C_SCHEME_FALSE);}}

/* k14671 in scheme#acos in k10751 in k8834 */
static void C_fcall f_14673(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_14673,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=C_a_i_acos(&a,1,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14679,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnump(((C_word*)t0)[2]))){
t3=C_fixnum_greater_or_equal_p(((C_word*)t0)[2],C_fix(-1));
t4=t2;
f_14679(t4,(C_truep(t3)?C_fixnum_less_or_equal_p(((C_word*)t0)[2],C_fix(1)):C_SCHEME_FALSE));}
else{
t3=t2;
f_14679(t3,C_SCHEME_FALSE);}}}

/* k14677 in k14671 in scheme#acos in k10751 in k8834 */
static void C_fcall f_14679(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_14679,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_a_i_acos(&a,1,C_a_i_fix_to_flo(&a,1,((C_word*)t0)[3]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14686,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2166: scheme#asin */
t3=*((C_word*)lf[596]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k14684 in k14677 in k14671 in scheme#acos in k10751 in k8834 */
static void C_ccall f_14686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_14686,c,av);}
a=C_alloc(29);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_minus(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k14699 in scheme#acos in k10751 in k8834 */
static void C_ccall f_14701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14701,c,av);}
t2=((C_word*)t0)[2];
f_14673(t2,(C_truep(t1)?C_ub_i_flonum_less_or_equal_p(C_flonum_magnitude(((C_word*)t0)[3]),(double)1.0):C_SCHEME_FALSE));}

/* scheme#atan in k10751 in k8834 */
static void C_ccall f_14705(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(66,c,3)))){
C_save_and_reclaim((void *)f_14705,c,av);}
a=C_alloc(66);
t3=C_rest_nullp(c,3);
t4=(C_truep(t3)?C_SCHEME_FALSE:C_get_rest_arg(c,3,av,3,t0));
t5=C_i_check_number_2(t2,lf[604]);
if(C_truep(C_i_cplxnump(t2))){
if(C_truep(t4)){
/* library.scm:2173: ##sys#error-bad-real */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[370]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[370]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[604];
tp(4,av2);}}
else{
t6=C_s_a_i_times(&a,2,lf[590],t2);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14738,a[2]=t1,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t8=C_s_a_i_plus(&a,2,C_fix(1),t6);
/* library.scm:2175: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[583]+1);
av2[1]=t7;
av2[2]=t8;
tp(3,av2);}}}
else{
if(C_truep(t4)){
t6=C_a_i_exact_to_inexact(&a,1,t2);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14759,a[2]=t1,a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2179: scheme#exact->inexact */
t8=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t6=C_a_i_exact_to_inexact(&a,1,t2);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_a_i_atan(&a,1,t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}}

/* k14736 in scheme#atan in k10751 in k8834 */
static void C_ccall f_14738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_14738,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14742,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=C_s_a_i_minus(&a,2,C_fix(1),((C_word*)t0)[3]);
/* library.scm:2176: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[583]+1);
av2[1]=t2;
av2[2]=t3;
tp(3,av2);}}

/* k14740 in k14736 in scheme#atan in k10751 in k8834 */
static void C_ccall f_14742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_14742,c,av);}
a=C_alloc(29);
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2175: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
av2[3]=lf[591];
tp(4,av2);}}

/* k14757 in scheme#atan in k10751 in k8834 */
static void C_ccall f_14759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_14759,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_atan2(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#exact-integer-sqrt in k10751 in k8834 */
static void C_ccall f_14769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_14769,c,av);}
a=C_alloc(10);
t3=C_fixnump(t2);
t4=(C_truep(t3)?C_fixnum_less_or_equal_p(t2,C_fix(4)):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=C_eqp(t2,C_fix(0));
t6=(C_truep(t5)?t5:C_eqp(t2,C_fix(1)));
if(C_truep(t6)){
/* library.scm:2191: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_fix(0);
C_values(4,av2);}}
else{
switch(t2){
case C_fix(2):
/* library.scm:2192: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fix(1);
av2[3]=C_fix(1);
C_values(4,av2);}
case C_fix(3):
/* library.scm:2193: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fix(1);
av2[3]=C_fix(2);
C_values(4,av2);}
case C_fix(4):
/* library.scm:2194: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fix(2);
av2[3]=C_fix(0);
C_values(4,av2);}
default:
/* library.scm:2195: chicken.base#error */
t7=*((C_word*)lf[193]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[606];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}}
else{
t5=C_fixnum_plus(C_i_integer_length(t2),C_fix(1));
t6=C_fixnum_shift_right(t5,C_fix(2));
t7=C_fixnum_shift_left(t6,C_fix(1));
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14842,a[2]=t7,a[3]=t2,a[4]=((C_word)li419),tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14856,a[2]=t6,a[3]=t2,a[4]=((C_word)li423),tmp=(C_word)a,a+=5,tmp);
/* library.scm:2196: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=t8;
av2[3]=t9;
C_call_with_values(4,av2);}}}

/* a14841 in ##sys#exact-integer-sqrt in k10751 in k8834 */
static void C_ccall f_14842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_14842,c,av);}
a=C_alloc(5);
t2=C_fixnum_negate(((C_word*)t0)[2]);
t3=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[3],t2);
/* library.scm:2199: ##sys#exact-integer-sqrt */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[605]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[605]+1);
av2[1]=t1;
av2[2]=t3;
tp(3,av2);}}

/* a14855 in ##sys#exact-integer-sqrt in k10751 in k8834 */
static void C_ccall f_14856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(38,c,4)))){
C_save_and_reclaim((void *)f_14856,c,av);}
a=C_alloc(38);
t4=C_s_a_i_arithmetic_shift(&a,2,C_fix(1),((C_word*)t0)[2]);
t5=C_s_a_u_i_integer_minus(&a,2,t4,C_fix(1));
t6=C_s_a_i_bitwise_and(&a,2,((C_word*)t0)[3],t5);
t7=C_fixnum_negate(((C_word*)t0)[2]);
t8=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[3],t7);
t9=C_s_a_i_bitwise_and(&a,2,t8,t5);
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14873,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t9,a[5]=t2,a[6]=((C_word)li421),tmp=(C_word)a,a+=7,tmp);
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14889,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t6,a[5]=((C_word)li422),tmp=(C_word)a,a+=6,tmp);
/* library.scm:2196: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t10;
av2[3]=t11;
C_call_with_values(4,av2);}}

/* a14872 in a14855 in ##sys#exact-integer-sqrt in k10751 in k8834 */
static void C_ccall f_14873(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_14873,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_u_integer_quotient_and_remainder,a[2]=((C_word)li420),tmp=(C_word)a,a+=3,tmp);
t3=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t4=C_s_a_u_i_integer_plus(&a,2,t3,((C_word*)t0)[4]);
t5=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[5],C_fix(1));
/* library.scm:2196: g2666 */
t6=t2;{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t1;
av2[2]=t4;
av2[3]=t5;
((C_proc)C_fast_retrieve_proc(t6))(4,av2);}}

/* a14888 in a14855 in ##sys#exact-integer-sqrt in k10751 in k8834 */
static void C_ccall f_14889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(222,c,3)))){
C_save_and_reclaim((void *)f_14889,c,av);}
a=C_alloc(222);
t4=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t5=C_s_a_i_plus(&a,2,t4,t2);
t6=C_s_a_i_arithmetic_shift(&a,2,t3,((C_word*)t0)[3]);
t7=C_s_a_i_times(&a,2,t2,t2);
t8=C_s_a_i_minus(&a,2,((C_word*)t0)[4],t7);
t9=C_s_a_i_plus(&a,2,t6,t8);
if(C_truep(C_i_negativep(t9))){
t10=C_s_a_i_minus(&a,2,t5,C_fix(1));
t11=C_s_a_i_arithmetic_shift(&a,2,t5,C_fix(1));
t12=C_s_a_i_plus(&a,2,t9,t11);
t13=C_s_a_i_minus(&a,2,t12,C_fix(1));
/* library.scm:2210: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t10;
av2[3]=t13;
C_values(4,av2);}}
else{
/* library.scm:2212: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t5;
av2[3]=t9;
C_values(4,av2);}}}

/* chicken.base#exact-integer-sqrt in k10751 in k8834 */
static void C_ccall f_14960(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_14960,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14964,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2216: ##sys#check-exact-uinteger */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[367]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[367]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[608];
tp(4,av2);}}

/* k14962 in chicken.base#exact-integer-sqrt in k10751 in k8834 */
static void C_ccall f_14964(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14964,c,av);}
/* library.scm:2217: ##sys#exact-integer-sqrt */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[605]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[605]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_14969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(32,c,4)))){
C_save_and_reclaim((void *)f_14969,c,av);}
a=C_alloc(32);
if(C_truep(C_i_cplxnump(t3))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14979,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=C_u_i_cplxnum_imag(t3);
t6=C_a_i_exact_to_inexact(&a,1,t5);
t7=C_u_i_cplxnum_real(t3);
t8=C_a_i_exact_to_inexact(&a,1,t7);
t9=C_flonum(&a,C_atan2(C_flonum_magnitude(t6),C_flonum_magnitude(t8)));
/* library.scm:2223: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t4;
av2[2]=t9;
av2[3]=C_fix(2);
tp(4,av2);}}
else{
if(C_truep(C_i_negativep(t3))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15019,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=C_s_a_i_negate(&a,1,t3);
/* library.scm:2228: scheme#exact->inexact */
t6=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
if(C_truep(C_i_exact_integerp(t3))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15030,a[2]=t3,a[3]=((C_word)li426),tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15036,a[2]=t3,a[3]=((C_word)li427),tmp=(C_word)a,a+=4,tmp);
/* library.scm:2230: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t4;
av2[3]=t5;
C_call_with_values(4,av2);}}
else{
if(C_truep(C_i_ratnump(t3))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15058,a[2]=t3,a[3]=((C_word)li428),tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15070,a[2]=t3,a[3]=t2,a[4]=((C_word)li431),tmp=(C_word)a,a+=5,tmp);
/* library.scm:2235: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t4;
av2[3]=t5;
C_call_with_values(4,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15122,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2243: scheme#exact->inexact */
t5=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}}}}

/* k14977 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_14979(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14979,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14983,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2224: scheme#magnitude */
t3=*((C_word*)lf[534]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k14981 in k14977 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_14983(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_14983,c,av);}
a=C_alloc(9);
t2=C_a_i_sqrt(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15002,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2225: scheme#cos */
t4=*((C_word*)lf[592]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k14996 in k15000 in k14981 in k14977 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_14998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,3)))){
C_save_and_reclaim((void *)f_14998,c,av);}
a=C_alloc(33);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2225: make-complex */
f_13097(((C_word*)t0)[3],((C_word*)t0)[4],t2);}

/* k15000 in k14981 in k14977 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15002(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(38,c,2)))){
C_save_and_reclaim((void *)f_15002,c,av);}
a=C_alloc(38);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14998,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2225: scheme#sin */
t4=*((C_word*)lf[588]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k15017 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_15019,c,av);}
a=C_alloc(4);
t2=C_a_i_sqrt(&a,1,t1);
/* library.scm:2227: make-complex */
f_13097(((C_word*)t0)[2],lf[523],t2);}

/* a15029 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15030(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15030,c,av);}
/* library.scm:2230: ##sys#exact-integer-sqrt */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[605]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[605]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* a15035 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15036(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_15036,c,av);}
a=C_alloc(3);
t4=C_eqp(C_fix(0),t3);
if(C_truep(t4)){
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15047,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2233: scheme#exact->inexact */
t6=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k15045 in a15035 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_15047,c,av);}
a=C_alloc(4);
t2=C_a_i_sqrt(&a,1,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a15057 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15058(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15058,c,av);}
/* library.scm:2235: ##sys#exact-integer-sqrt */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[605]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[605]+1);
av2[1]=t1;
av2[2]=C_u_i_ratnum_num(((C_word*)t0)[2]);
tp(3,av2);}}

/* a15069 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15070(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_15070,c,av);}
a=C_alloc(10);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15082,a[2]=((C_word*)t0)[2],a[3]=((C_word)li429),tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15094,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],a[5]=((C_word)li430),tmp=(C_word)a,a+=6,tmp);
/* library.scm:2237: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t5;
av2[3]=t6;
C_call_with_values(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15118,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2242: scheme#exact->inexact */
t6=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* a15081 in a15069 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15082(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15082,c,av);}
/* library.scm:2238: ##sys#exact-integer-sqrt */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[605]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[605]+1);
av2[1]=t1;
av2[2]=C_u_i_ratnum_denom(((C_word*)t0)[2]);
tp(3,av2);}}

/* a15093 in a15069 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15094(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_15094,c,av);}
a=C_alloc(4);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
/* library.scm:2240: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
tp(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15111,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2241: scheme#exact->inexact */
t6=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k15109 in a15093 in a15069 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15111(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15111,c,av);}
/* library.scm:2241: ##sys#sqrt/loc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[599]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[599]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k15116 in a15069 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15118(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15118,c,av);}
/* library.scm:2242: ##sys#sqrt/loc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[599]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[599]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k15120 in ##sys#sqrt/loc in k10751 in k8834 */
static void C_ccall f_15122(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_15122,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_sqrt(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* scheme#sqrt in k10751 in k8834 */
static void C_ccall f_15124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15124,c,av);}
/* library.scm:2245: ##sys#sqrt/loc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[599]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[599]+1);
av2[1]=t1;
av2[2]=lf[609];
av2[3]=t2;
tp(4,av2);}}

/* chicken.base#exact-integer-nth-root in k10751 in k8834 */
static void C_ccall f_15130(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15130,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15134,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2249: ##sys#check-exact-uinteger */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[367]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[367]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[612];
tp(4,av2);}}

/* k15132 in chicken.base#exact-integer-nth-root in k10751 in k8834 */
static void C_ccall f_15134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15134,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15137,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2250: ##sys#check-exact-uinteger */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[367]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[367]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[612];
tp(4,av2);}}

/* k15135 in k15132 in chicken.base#exact-integer-nth-root in k10751 in k8834 */
static void C_ccall f_15137(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_15137,c,av);}
/* library.scm:2251: ##sys#exact-integer-nth-root/loc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[611]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[611]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[612];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}

/* ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_ccall f_15142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_15142,c,av);}
a=C_alloc(5);
t5=C_eqp(C_fix(0),t3);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15152,a[2]=t1,a[3]=t3,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t5)){
t7=t6;
f_15152(t7,t5);}
else{
t7=C_eqp(C_fix(1),t3);
t8=t6;
f_15152(t8,(C_truep(t7)?t7:C_eqp(C_fix(1),t4)));}}

/* k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_fcall f_15152(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,3)))){
C_save_and_reclaim_args((void *)trf_15152,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
/* library.scm:2257: scheme#values */{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_fix(0);
C_values(4,av2);}}
else{
t2=C_i_integer_length(((C_word*)t0)[3]);
if(C_truep(C_i_lessp(t2,((C_word*)t0)[4]))){
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[3],C_fix(1));
/* library.scm:2260: scheme#values */{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fix(1);
av2[3]=t3;
C_values(4,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15172,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15248,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15252,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=C_fixnum_plus(t2,C_fix(1));
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}}}

/* k15170 in k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_ccall f_15172(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(75,c,3)))){
C_save_and_reclaim((void *)f_15172,c,av);}
a=C_alloc(75);
t2=C_s_a_i_arithmetic_shift(&a,2,C_fix(1),t1);
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[2],C_fix(1));
t4=C_s_a_i_times(&a,2,t3,t2);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15244,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[2],a[5]=t3,a[6]=((C_word*)t0)[4],a[7]=t2,tmp=(C_word)a,a+=8,tmp);
/* library.scm:2268: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t5;
av2[2]=t2;
av2[3]=t3;
tp(4,av2);}}

/* lp in k15242 in k15170 in k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_fcall f_15187(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(41,0,3)))){
C_save_and_reclaim_args((void *)trf_15187,4,t0,t1,t2,t3);}
a=C_alloc(41);
if(C_truep(C_i_lessp(t3,t2))){
t4=C_s_a_i_times(&a,2,((C_word*)t0)[2],t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15217,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=t3,tmp=(C_word)a,a+=8,tmp);
/* library.scm:2273: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t5;
av2[2]=t3;
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15228,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2275: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}}

/* k15215 in lp in k15242 in k15170 in k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_ccall f_15217(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,3)))){
C_save_and_reclaim((void *)f_15217,c,av);}
a=C_alloc(39);
t2=C_s_a_i_quotient(&a,2,((C_word*)t0)[2],t1);
t3=C_s_a_i_plus(&a,2,((C_word*)t0)[3],t2);
t4=C_s_a_i_quotient(&a,2,t3,((C_word*)t0)[4]);
/* library.scm:2271: lp */
t5=((C_word*)((C_word*)t0)[5])[1];
f_15187(t5,((C_word*)t0)[6],((C_word*)t0)[7],t4);}

/* k15226 in lp in k15242 in k15170 in k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_ccall f_15228(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_15228,c,av);}
a=C_alloc(29);
t2=C_s_a_i_minus(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2275: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
C_values(4,av2);}}

/* k15242 in k15170 in k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_ccall f_15244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(48,c,4)))){
C_save_and_reclaim((void *)f_15244,c,av);}
a=C_alloc(48);
t2=C_s_a_i_quotient(&a,2,((C_word*)t0)[2],t1);
t3=C_s_a_i_plus(&a,2,((C_word*)t0)[3],t2);
t4=C_s_a_i_quotient(&a,2,t3,((C_word*)t0)[4]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15187,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=t6,a[6]=((C_word)li435),tmp=(C_word)a,a+=7,tmp));
t8=((C_word*)t6)[1];
f_15187(t8,((C_word*)t0)[6],((C_word*)t0)[7],t4);}

/* k15246 in k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_ccall f_15248(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15248,c,av);}
/* library.scm:2262: scheme#inexact->exact */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k15250 in k15150 in ##sys#exact-integer-nth-root/loc in k10751 in k8834 */
static void C_ccall f_15252(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15252,c,av);}
/* library.scm:2262: scheme#ceiling */
t2=*((C_word*)lf[568]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* ##sys#integer-power in k10751 in k8834 */
static void C_ccall f_15268(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_15268,c,av);}
a=C_alloc(8);
if(C_truep(C_i_negativep(t3))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15286,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=C_s_a_u_i_integer_negate(&a,1,t3);
/* library.scm:2280: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=t5;
tp(4,av2);}}
else{
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15297,a[2]=t5,a[3]=t2,a[4]=((C_word)li437),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_15297(t7,t1,C_fix(1),t3);}}

/* k15284 in ##sys#integer-power in k10751 in k8834 */
static void C_ccall f_15286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15286,c,av);}
/* library.scm:2280: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=C_fix(1);
av2[3]=t1;
tp(4,av2);}}

/* lp in ##sys#integer-power in k10751 in k8834 */
static void C_fcall f_15297(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(62,0,3)))){
C_save_and_reclaim_args((void *)trf_15297,4,t0,t1,t2,t3);}
a=C_alloc(62);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_evenp(t3))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15319,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t6=C_s_a_i_arithmetic_shift(&a,2,t3,C_fix(-1));
/* library.scm:2285: lp */
t8=t5;
t9=C_fix(1);
t10=t6;
t1=t8;
t2=t9;
t3=t10;
goto loop;}
else{
t5=C_s_a_i_times(&a,2,t2,((C_word*)t0)[3]);
t6=C_s_a_i_minus(&a,2,t3,C_fix(1));
/* library.scm:2287: lp */
t8=t1;
t9=t5;
t10=t6;
t1=t8;
t2=t9;
t3=t10;
goto loop;}}}

/* k15317 in lp in ##sys#integer-power in k10751 in k8834 */
static void C_ccall f_15319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(66,c,1)))){
C_save_and_reclaim((void *)f_15319,c,av);}
a=C_alloc(66);
t2=C_s_a_i_times(&a,2,t1,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_i_times(&a,2,((C_word*)t0)[3],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#expt in k10751 in k8834 */
static void C_ccall f_15336(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(21,c,4)))){
C_save_and_reclaim((void *)f_15336,c,av);}
a=C_alloc(21);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15339,a[2]=((C_word)li439),tmp=(C_word)a,a+=3,tmp));
t9=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15353,a[2]=((C_word)li440),tmp=(C_word)a,a+=3,tmp));
t10=C_i_numberp(t2);
if(C_truep(C_i_not(t10))){
/* library.scm:2299: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[613];
tp(4,av2);}}
else{
t11=C_i_numberp(t3);
if(C_truep(C_i_not(t11))){
/* library.scm:2300: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=lf[613];
tp(4,av2);}}
else{
t12=C_i_ratnump(t2);
t13=(C_truep(t12)?C_i_not(C_i_inexactp(t3)):C_SCHEME_FALSE);
if(C_truep(t13)){
t14=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15405,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2304: scheme#expt */
t15=*((C_word*)lf[552]+1);{
C_word *av2=av;
av2[0]=t15;
av2[1]=t14;
av2[2]=C_u_i_ratnum_num(t2);
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t15+1)))(4,av2);}}
else{
if(C_truep(C_i_ratnump(t3))){
if(C_truep(C_i_exact_integerp(t2))){
if(C_truep(C_i_negativep(t2))){
t14=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15444,a[2]=t3,a[3]=t5,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2311: scheme#exact->inexact */
t15=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t15;
av2[1]=t14;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t15+1)))(3,av2);}}
else{
t14=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15451,a[2]=t2,a[3]=t3,a[4]=((C_word)li441),tmp=(C_word)a,a+=5,tmp);
t15=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15463,a[2]=t3,a[3]=t2,a[4]=((C_word)li442),tmp=(C_word)a,a+=5,tmp);
/* library.scm:2312: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t14;
av2[3]=t15;
C_call_with_values(4,av2);}}}
else{
if(C_truep(C_i_flonump(t2))){
t14=C_a_i_exact_to_inexact(&a,1,t3);
/* library.scm:2321: log-expt */
f_15339(t1,t2,t14);}
else{
/* library.scm:2322: slow-expt */
f_15353(t1,t2,t3);}}}
else{
t14=C_i_cplxnump(t3);
t15=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15507,a[2]=t7,a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
if(C_truep(t14)){
t16=t15;
f_15507(t16,t14);}
else{
t16=C_i_cplxnump(t2);
t17=t15;
f_15507(t17,(C_truep(t16)?C_i_not(C_i_integerp(t3)):C_SCHEME_FALSE));}}}}}}

/* log-expt in scheme#expt in k10751 in k8834 */
static void C_fcall f_15339(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_15339,3,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15351,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2292: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[583]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}

/* k15349 in log-expt in scheme#expt in k10751 in k8834 */
static void C_ccall f_15351(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_15351,c,av);}
a=C_alloc(33);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2292: scheme#exp */
t3=*((C_word*)lf[581]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* slow-expt in scheme#expt in k10751 in k8834 */
static void C_fcall f_15353(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,6)))){
C_save_and_reclaim_args((void *)trf_15353,3,t1,t2,t3);}
a=C_alloc(4);
t4=C_eqp(C_fix(0),t2);
if(C_truep(t4)){
/* library.scm:2295: ##sys#signal-hook */
t5=C_fast_retrieve(lf[194]);{
C_word av2[7];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[584];
av2[3]=lf[613];
av2[4]=lf[614];
av2[5]=t2;
av2[6]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(7,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15374,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2298: ##sys#log-1 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[583]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[583]+1);
av2[1]=t5;
av2[2]=t2;
tp(3,av2);}}}

/* k15372 in slow-expt in scheme#expt in k10751 in k8834 */
static void C_ccall f_15374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_15374,c,av);}
a=C_alloc(33);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2298: scheme#exp */
t3=*((C_word*)lf[581]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15403 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15405(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,3)))){
C_save_and_reclaim((void *)f_15405,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15409,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_u_i_ratnum_denom(((C_word*)t0)[3]);
t4=C_s_a_i_negate(&a,1,((C_word*)t0)[4]);
/* library.scm:2305: scheme#expt */
t5=*((C_word*)lf[552]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=t3;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k15407 in k15403 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,1)))){
C_save_and_reclaim((void *)f_15409,c,av);}
a=C_alloc(33);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_times(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k15442 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15444(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_15444,c,av);}
a=C_alloc(11);
t2=C_a_i_exact_to_inexact(&a,1,((C_word*)t0)[2]);
/* library.scm:2311: log-expt */
f_15339(((C_word*)t0)[4],t1,t2);}

/* a15450 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15451(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_15451,c,av);}
/* library.scm:2313: ##sys#exact-integer-nth-root/loc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[611]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[611]+1);
av2[1]=t1;
av2[2]=lf[613];
av2[3]=((C_word*)t0)[2];
av2[4]=C_u_i_ratnum_denom(((C_word*)t0)[3]);
tp(5,av2);}}

/* a15462 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_15463,c,av);}
a=C_alloc(4);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
/* library.scm:2316: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_u_i_ratnum_num(((C_word*)t0)[2]);
tp(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15483,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2318: scheme#exact->inexact */
t6=*((C_word*)lf[62]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k15481 in a15462 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_15483,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15487,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2319: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15485 in k15481 in a15462 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_15487,c,av);}
a=C_alloc(4);
t2=C_a_i_flonum_expt(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k15505 in scheme#expt in k10751 in k8834 */
static void C_fcall f_15507(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_15507,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
/* library.scm:2324: slow-expt */
f_15353(((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
t2=(C_truep(C_i_flonump(((C_word*)t0)[5]))?C_i_not(C_u_i_fpintegerp(((C_word*)t0)[5])):C_SCHEME_FALSE);
if(C_truep(t2)){
if(C_truep(C_i_negativep(((C_word*)t0)[4]))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15527,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2328: scheme#exact->inexact */
t4=*((C_word*)lf[62]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15535,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2330: scheme#exact->inexact */
t4=*((C_word*)lf[62]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}
else{
if(C_truep(C_i_flonump(((C_word*)t0)[4]))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15542,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2332: scheme#exact->inexact */
t4=*((C_word*)lf[62]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_i_inexactp(((C_word*)t0)[4]);
t4=(C_truep(t3)?t3:C_i_inexactp(((C_word*)t0)[5]));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15558,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15562,a[2]=t5,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2336: scheme#inexact->exact */
t7=*((C_word*)lf[540]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
/* library.scm:2337: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[550]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
tp(4,av2);}}}}}}

/* k15525 in k15505 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15527(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_15527,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15531,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2328: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15529 in k15525 in k15505 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15531(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15531,c,av);}
/* library.scm:2328: log-expt */
f_15339(((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k15533 in k15505 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_15535,c,av);}
a=C_alloc(4);
t2=C_a_i_flonum_expt(&a,2,t1,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k15540 in k15505 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_15542,c,av);}
a=C_alloc(4);
t2=C_a_i_flonum_expt(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k15556 in k15505 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15558(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15558,c,av);}
/* library.scm:2336: scheme#exact->inexact */
t2=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k15560 in k15505 in scheme#expt in k10751 in k8834 */
static void C_ccall f_15562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15562,c,av);}
/* library.scm:2336: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[550]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* ##sys#internal-gcd in k10751 in k8834 */
static void C_fcall f_15603(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_15603,4,t1,t2,t3,t4);}
a=C_alloc(5);
if(C_truep(C_i_exact_integerp(t3))){
if(C_truep(C_i_exact_integerp(t4))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_s_a_u_i_integer_gcd(&a,2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(C_truep(C_i_flonump(t4))?C_u_i_fpintegerp(t4):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15636,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2345: scheme#inexact->exact */
t7=*((C_word*)lf[540]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
/* library.scm:2346: ##sys#error-bad-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[364]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[364]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t2;
tp(4,av2);}}}}
else{
t5=(C_truep(C_i_flonump(t3))?C_u_i_fpintegerp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
if(C_truep(C_i_flonump(t4))){
t6=C_a_i_flonum_gcd(&a,2,t3,t4);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
if(C_truep(C_i_exact_integerp(t4))){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15665,a[2]=t4,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2352: scheme#inexact->exact */
t7=*((C_word*)lf[540]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
/* library.scm:2353: ##sys#error-bad-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[364]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[364]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=t2;
tp(4,av2);}}}}
else{
/* library.scm:2354: ##sys#error-bad-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[364]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[364]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=t2;
tp(4,av2);}}}}

/* k15634 in ##sys#internal-gcd in k10751 in k8834 */
static void C_ccall f_15636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_15636,c,av);}
a=C_alloc(5);
t2=C_s_a_u_i_integer_gcd(&a,2,((C_word*)t0)[2],t1);
/* library.scm:2345: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15663 in ##sys#internal-gcd in k10751 in k8834 */
static void C_ccall f_15665(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_15665,c,av);}
a=C_alloc(5);
t2=C_s_a_u_i_integer_gcd(&a,2,t1,((C_word*)t0)[2]);
/* library.scm:2352: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* ##sys#gcd in k10751 in k8834 */
static void C_ccall f_15673(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_15673,c,av);}
/* library.scm:2356: ##sys#internal-gcd */
f_15603(t1,lf[616],t2,t3);}

/* scheme#gcd in k10751 in k8834 */
static void C_ccall f_15679(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_15679,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
t3=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t3)){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=C_slot(t2,C_fix(1));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15699,a[2]=t7,a[3]=((C_word)li446),tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_15699(t9,t1,t4,t5);}}

/* loop in scheme#gcd in k10751 in k8834 */
static void C_fcall f_15699(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_15699,4,t0,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t3))){
if(C_truep(C_i_integerp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_s_a_i_abs(&a,1,t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* library.scm:2365: ##sys#error-bad-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[364]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[364]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[616];
tp(4,av2);}}}
else{
t4=C_slot(t3,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15724,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2367: ##sys#internal-gcd */
f_15603(t5,lf[616],t2,t4);}}

/* k15722 in loop in scheme#gcd in k10751 in k8834 */
static void C_ccall f_15724(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15724,c,av);}
/* library.scm:2367: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_15699(t2,((C_word*)t0)[3],t1,C_slot(((C_word*)t0)[4],C_fix(1)));}

/* ##sys#lcm in k10751 in k8834 */
static void C_ccall f_15730(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_15730,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15734,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2371: ##sys#internal-gcd */
f_15603(t4,lf[619],t2,t3);}

/* k15732 in ##sys#lcm in k10751 in k8834 */
static void C_ccall f_15734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(45,c,1)))){
C_save_and_reclaim((void *)f_15734,c,av);}
a=C_alloc(45);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_s_a_i_quotient(&a,2,t2,t1);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_s_a_i_abs(&a,1,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#lcm in k10751 in k8834 */
static void C_ccall f_15744(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,4)))){
C_save_and_reclaim((void*)f_15744,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
if(C_truep(C_rest_nullp(c,2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fix(1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_slot(t2,C_fix(0));
t4=C_slot(t2,C_fix(1));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15764,a[2]=t6,a[3]=((C_word)li449),tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_15764(t8,t1,t3,t4);}}

/* loop in scheme#lcm in k10751 in k8834 */
static void C_fcall f_15764(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_15764,4,t0,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t3))){
if(C_truep(C_i_integerp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_s_a_i_abs(&a,1,t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* library.scm:2381: ##sys#error-bad-integer */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[364]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[364]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[619];
tp(4,av2);}}}
else{
t4=C_slot(t3,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15785,a[2]=t2,a[3]=t4,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* library.scm:2383: ##sys#internal-gcd */
f_15603(t5,lf[619],t2,t4);}}

/* k15783 in loop in scheme#lcm in k10751 in k8834 */
static void C_ccall f_15785(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(38,c,3)))){
C_save_and_reclaim((void *)f_15785,c,av);}
a=C_alloc(38);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_s_a_i_quotient(&a,2,t2,t1);
/* library.scm:2384: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_15764(t4,((C_word*)t0)[5],t3,C_slot(((C_word*)t0)[6],C_fix(1)));}

/* ##sys#integer->string/recursive in k10751 in k8834 */
static void C_ccall f_15802(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_15802,c,av);}
a=C_alloc(6);
t5=C_fixnum_plus(t4,C_fix(1));
t6=C_fixnum_shift_right(t5,C_fix(1));
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15809,a[2]=t2,a[3]=t6,a[4]=t3,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:2391: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t7;
av2[2]=t3;
av2[3]=t6;
tp(4,av2);}}

/* k15807 in ##sys#integer->string/recursive in k10751 in k8834 */
static void C_ccall f_15809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_15809,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15814,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li452),tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15820,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word)li453),tmp=(C_word)a,a+=5,tmp);
/* library.scm:2390: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a15813 in k15807 in ##sys#integer->string/recursive in k10751 in k8834 */
static void C_ccall f_15814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_15814,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_u_integer_quotient_and_remainder,a[2]=((C_word)li451),tmp=(C_word)a,a+=3,tmp);
/* library.scm:2390: g2851 */
t3=t2;{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t3))(4,av2);}}

/* a15819 in k15807 in ##sys#integer->string/recursive in k10751 in k8834 */
static void C_ccall f_15820(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_15820,c,av);}
a=C_alloc(6);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15824,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k15822 in a15819 in k15807 in ##sys#integer->string/recursive in k10751 in k8834 */
static void C_ccall f_15824(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_15824,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15827,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_s_a_i_abs(&a,1,((C_word*)t0)[4]);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=t3;
av2[3]=((C_word*)t0)[5];
tp(4,av2);}}

/* k15825 in k15822 in a15819 in k15807 in ##sys#integer->string/recursive in k10751 in k8834 */
static void C_ccall f_15827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15827,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15834,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=C_block_size(t1);
/* ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t2;
av2[2]=C_fixnum_difference(((C_word*)t0)[4],t3);
av2[3]=C_make_character(48);
tp(4,av2);}}

/* k15832 in k15825 in k15822 in a15819 in k15807 in ##sys#integer->string/recursive in k10751 in k8834 */
static void C_ccall f_15834(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_15834,c,av);}
/* library.scm:2396: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* ##sys#extended-number->string in k10751 in k8834 */
static void C_ccall f_15855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15855,c,av);}
a=C_alloc(5);
if(C_truep(C_i_ratnump(t2))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15869,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t4;
av2[2]=C_u_i_ratnum_num(t2);
av2[3]=t3;
tp(4,av2);}}
else{
if(C_truep(C_i_cplxnump(t2))){
t4=C_u_i_cplxnum_real(t2);
t5=C_u_i_cplxnum_imag(t2);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15910,a[2]=t5,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t6;
av2[2]=t4;
av2[3]=t3;
tp(4,av2);}}
else{
/* library.scm:2418: ##sys#error-bad-number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[379]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[379]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[628];
tp(4,av2);}}}}

/* k15867 in ##sys#extended-number->string in k10751 in k8834 */
static void C_ccall f_15869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_15869,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15873,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=C_u_i_ratnum_denom(((C_word*)t0)[3]);
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}

/* k15871 in k15867 in ##sys#extended-number->string in k10751 in k8834 */
static void C_ccall f_15873(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_15873,c,av);}
/* library.scm:2406: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[624];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k15908 in ##sys#extended-number->string in k10751 in k8834 */
static void C_ccall f_15910(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15910,c,av);}
a=C_alloc(5);
t2=(C_truep(C_i_finitep(((C_word*)t0)[2]))?(C_truep(C_i_positivep(((C_word*)t0)[2]))?lf[625]:lf[626]):lf[626]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15918,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}

/* k15916 in k15908 in ##sys#extended-number->string in k10751 in k8834 */
static void C_ccall f_15918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_15918,c,av);}
/* library.scm:2413: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
av2[5]=lf[627];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k15945 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_15947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(44,c,1)))){
C_save_and_reclaim((void *)f_15947,c,av);}
a=C_alloc(44);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_exact_to_inexact(&a,1,t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k15948 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_15950(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_15950,c,av);}
a=C_alloc(13);
t2=C_fixnum_difference(C_i_integer_length(((C_word*)t0)[2]),C_i_integer_length(t1));
t3=C_fixnum_difference(t2,*((C_word*)lf[434]+1));
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
if(C_truep(C_fixnum_lessp(((C_word*)t5)[1],C_fix(0)))){
t6=C_fixnum_negate(((C_word*)t5)[1]);
t7=C_s_a_i_arithmetic_shift(&a,2,((C_word*)t0)[2],t6);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15965,a[2]=t5,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t7,tmp=(C_word)a,a+=6,tmp);
/* library.scm:2437: round-quotient */
f_16029(t8,t7,t1);}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16004,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2444: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t6;
av2[2]=C_fix(10);
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}}

/* k15963 in k15948 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_15965(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(44,c,3)))){
C_save_and_reclaim((void *)f_15965,c,av);}
a=C_alloc(44);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15968,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t5=((C_word*)t3)[1];
t6=C_i_integer_length(t5);
t7=*((C_word*)lf[434]+1);
if(C_truep(C_fixnum_greaterp(t6,*((C_word*)lf[434]+1)))){
t8=C_fixnum_plus(C_fix(1),((C_word*)((C_word*)t0)[2])[1]);
t9=C_set_block_item(((C_word*)t0)[2],0,t8);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15986,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t11=C_s_a_i_times(&a,2,((C_word*)t0)[4],C_fix(2));
/* library.scm:2441: round-quotient */
f_16029(t10,((C_word*)t0)[5],t11);}
else{
t8=t4;
f_15968(t8,C_SCHEME_UNDEFINED);}}

/* k15966 in k15963 in k15948 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_15968(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_15968,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15975,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2442: scheme#exact->inexact */
t3=*((C_word*)lf[62]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15973 in k15966 in k15963 in k15948 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_15975(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_15975,c,av);}
a=C_alloc(6);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_bytevector(&a,1,C_fix(4));
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=stub2905(t3,C_i_foreign_flonum_argumentp(t1),C_i_foreign_fixnum_argumentp(t2));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k15984 in k15963 in k15948 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_15986(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15986,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];
f_15968(t3,t2);}

/* k16002 in k15948 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16004(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,1)))){
C_save_and_reclaim((void *)f_16004,c,av);}
a=C_alloc(33);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_times(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* round-quotient in k10751 in k8834 */
static void C_fcall f_16029(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(63,0,3)))){
C_save_and_reclaim_args((void *)trf_16029,3,t1,t2,t3);}
a=C_alloc(63);
t4=C_s_a_u_i_integer_quotient(&a,2,t2,t3);
t5=(C_truep(C_i_evenp(t4))?*((C_word*)lf[73]+1):*((C_word*)lf[75]+1));
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16044,a[2]=t2,a[3]=t3,a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t7=C_s_a_i_remainder(&a,2,t2,t3);
t8=C_s_a_i_abs(&a,1,t7);
t9=C_s_a_i_times(&a,2,t8,C_fix(2));
t10=C_s_a_i_abs(&a,1,t3);
/* library.scm:2451: g2918 */
t11=t5;{
C_word av2[4];
av2[0]=t11;
av2[1]=t6;
av2[2]=t9;
av2[3]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(4,av2);}}

/* k16042 in round-quotient in k10751 in k8834 */
static void C_ccall f_16044(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_16044,c,av);}
a=C_alloc(29);
if(C_truep(t1)){
t2=C_eqp(C_i_negativep(((C_word*)t0)[2]),C_i_negativep(((C_word*)t0)[3]));
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?C_s_a_i_plus(&a,2,((C_word*)t0)[5],C_fix(1)):C_s_a_i_plus(&a,2,((C_word*)t0)[5],C_fix(-1)));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16072(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(87,0,5)))){
C_save_and_reclaim_args((void *)trf_16072,5,t1,t2,t3,t4,t5);}
a=C_alloc(87);
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t8,0,C_SCHEME_FALSE);
t14=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16076,a[2]=t6,a[3]=t8,a[4]=((C_word)li457),tmp=(C_word)a,a+=5,tmp));
t15=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16090,a[2]=t6,a[3]=((C_word)li458),tmp=(C_word)a,a+=4,tmp));
t16=C_block_size(t3);
t17=C_fixnum_difference(t2,C_fix(1));
t18=C_fixnum_plus(C_fix(48),t17);
t19=C_make_character(C_unfix(t18));
t20=C_fixnum_difference(t2,C_fix(11));
t21=C_fixnum_plus(C_fix(97),t20);
t22=C_make_character(C_unfix(t21));
t23=C_fixnum_difference(t2,C_fix(11));
t24=C_fixnum_plus(C_fix(65),t23);
t25=C_make_character(C_unfix(t24));
t26=C_SCHEME_FALSE;
t27=(*a=C_VECTOR_TYPE|1,a[1]=t26,tmp=(C_word)a,a+=2,tmp);
t28=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_16170,a[2]=t16,a[3]=t3,a[4]=t2,a[5]=t19,a[6]=t22,a[7]=t25,a[8]=((C_word)li460),tmp=(C_word)a,a+=9,tmp);
t29=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16278,a[2]=t16,a[3]=t3,a[4]=((C_word)li462),tmp=(C_word)a,a+=5,tmp);
t30=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_16328,a[2]=t3,a[3]=t2,a[4]=t27,a[5]=t10,a[6]=t29,a[7]=t28,a[8]=((C_word)li463),tmp=(C_word)a,a+=9,tmp);
t31=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16384,a[2]=t16,a[3]=t3,a[4]=t2,a[5]=t28,a[6]=((C_word)li464),tmp=(C_word)a,a+=7,tmp);
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16442,a[2]=t16,a[3]=t3,a[4]=t12,a[5]=t31,a[6]=t30,a[7]=((C_word)li465),tmp=(C_word)a,a+=8,tmp);
t33=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_16656,a[2]=t10,a[3]=t32,a[4]=t3,a[5]=t2,a[6]=t16,a[7]=t12,a[8]=t31,a[9]=t27,a[10]=t6,a[11]=t30,a[12]=((C_word)li466),tmp=(C_word)a,a+=13,tmp);
t34=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17002,a[2]=t16,a[3]=t3,a[4]=t33,a[5]=t10,a[6]=((C_word)li467),tmp=(C_word)a,a+=7,tmp);
t35=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17242,a[2]=t6,a[3]=t8,a[4]=t1,a[5]=t3,a[6]=t16,a[7]=t4,a[8]=t27,a[9]=t34,tmp=(C_word)a,a+=10,tmp);
/* library.scm:2637: scan-real */
t36=t34;
f_17002(t36,t35,t4);}

/* go-inexact! in ##sys#string->compnum in k10751 in k8834 */
static C_word C_fcall f_16076(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;{}
t2=C_eqp(((C_word*)((C_word*)t0)[2])[1],lf[631]);
if(C_truep(t2)){
t3=C_SCHEME_UNDEFINED;
return(t3);}
else{
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,lf[632]);
t4=((C_word*)((C_word*)t0)[3])[1];
if(C_truep(t4)){
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,t4);
return(t5);}
else{
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,t1);
return(t5);}}}

/* safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16090(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_16090,4,t0,t1,t2,t3);}
a=C_alloc(12);
if(C_truep(t3)){
if(C_truep(C_i_not(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_fix(0);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_i_greaterp(t3,C_fix(10000)))){
t4=C_eqp(((C_word*)((C_word*)t0)[2])[1],lf[632]);
if(C_truep(t4)){
if(C_truep(C_i_zerop(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[523];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_i_greaterp(t2,lf[523]);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t5)?lf[633]:lf[634]);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t4=C_fixnum_negate(C_fix(10000));
if(C_truep(C_i_lessp(t3,t4))){
t5=C_eqp(((C_word*)((C_word*)t0)[2])[1],lf[632]);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t5)?lf[523]:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=C_eqp(((C_word*)((C_word*)t0)[2])[1],lf[632]);
if(C_truep(t5)){
if(C_truep(C_i_not(C_i_negativep(t3)))){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15947,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2430: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t6;
av2[2]=C_fix(10);
av2[3]=t3;
tp(4,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15950,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t7=C_s_a_i_abs(&a,1,t3);
/* library.scm:2431: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t6;
av2[2]=C_fix(10);
av2[3]=t7;
tp(4,av2);}}}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16150,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2476: ##sys#integer-power */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[550]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[550]+1);
av2[1]=t6;
av2[2]=C_fix(10);
av2[3]=t3;
tp(4,av2);}}}}}}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k16148 in safe-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16150(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,1)))){
C_save_and_reclaim((void *)f_16150,c,av);}
a=C_alloc(33);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_s_a_i_times(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* scan-digits in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16170(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_16170,3,t0,t1,t2);}
a=C_alloc(13);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_16176,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t4,a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word)li459),tmp=(C_word)a,a+=11,tmp));
t6=((C_word*)t4)[1];
f_16176(t6,t1,t2);}

/* lp in scan-digits in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16176(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_16176,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=C_fixnum_greaterp(t2,((C_word*)t0)[3]);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_a_i_cons(&a,2,t2,C_SCHEME_FALSE):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=C_subchar(((C_word*)t0)[4],t2);
if(C_truep(C_fixnum_less_or_equal_p(((C_word*)t0)[5],C_fix(10)))){
t5=C_i_char_greater_or_equal_p(t4,C_make_character(48));
t6=(C_truep(t5)?C_u_i_char_less_or_equal_p(t4,((C_word*)t0)[6]):C_SCHEME_FALSE);
if(C_truep(t6)){
/* library.scm:2500: lp */
t10=t1;
t11=C_fixnum_plus(t2,C_fix(1));
t1=t10;
t2=t11;
goto loop;}
else{
t7=C_fixnum_greaterp(t2,((C_word*)t0)[3]);
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=(C_truep(t7)?C_a_i_cons(&a,2,t2,t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}
else{
t5=C_i_char_greater_or_equal_p(t4,C_make_character(48));
t6=(C_truep(t5)?C_u_i_char_less_or_equal_p(t4,C_make_character(57)):C_SCHEME_FALSE);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16239,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t6)){
t8=t7;
f_16239(t8,t6);}
else{
t8=(C_truep(C_u_i_char_greater_or_equal_p(t4,C_make_character(97)))?C_u_i_char_less_or_equal_p(t4,((C_word*)t0)[8]):C_SCHEME_FALSE);
t9=t7;
f_16239(t9,(C_truep(t8)?t8:(C_truep(C_u_i_char_greater_or_equal_p(t4,C_make_character(65)))?C_u_i_char_less_or_equal_p(t4,((C_word*)t0)[9]):C_SCHEME_FALSE)));}}}}

/* k16237 in lp in scan-digits in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16239(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16239,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
/* library.scm:2505: lp */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16176(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}
else{
t2=C_fixnum_greaterp(((C_word*)t0)[4],((C_word*)t0)[5]);
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=(C_truep(t2)?C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[4]):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* scan-hashes in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16278(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_16278,3,t0,t1,t2);}
a=C_alloc(9);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16284,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=t4,a[6]=((C_word)li461),tmp=(C_word)a,a+=7,tmp));
t6=((C_word*)t4)[1];
f_16284(t6,t1,t2);}

/* lp in scan-hashes in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16284(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16284,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=C_fixnum_greaterp(t2,((C_word*)t0)[3]);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_a_i_cons(&a,2,t2,C_SCHEME_FALSE):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=C_subchar(((C_word*)t0)[4],t2);
t5=C_eqp(t4,C_make_character(35));
if(C_truep(t5)){
/* library.scm:2514: lp */
t8=t1;
t9=C_fixnum_plus(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t6=C_fixnum_greaterp(t2,((C_word*)t0)[3]);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=(C_truep(t6)?C_a_i_cons(&a,2,t2,t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}}

/* scan-digits+hashes in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16328(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_16328,5,t0,t1,t2,t3,t4);}
a=C_alloc(11);
t5=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_16332,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=t3,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=t1,a[9]=((C_word*)t0)[6],a[10]=t4,tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[4])[1]))){
/* library.scm:2518: scan-digits */
t6=((C_word*)t0)[7];
f_16170(t6,t5,t2);}
else{
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_16332(2,av2);}}}

/* k16330 in scan-digits+hashes in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16332(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_16332,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_16335,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t1)){
if(C_truep(C_i_cdr(t1))){
/* library.scm:2520: scan-hashes */
t3=((C_word*)t0)[9];
f_16278(t3,t2,C_u_i_cdr(t1));}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_16335(2,av2);}}}
else{
if(C_truep(((C_word*)t0)[10])){
/* library.scm:2521: scan-hashes */
t3=((C_word*)t0)[9];
f_16278(t3,t2,((C_word*)t0)[3]);}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_16335(2,av2);}}}}

/* k16333 in k16330 in scan-digits+hashes in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_16335,c,av);}
a=C_alloc(9);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
if(C_truep(t2)){
t3=C_i_car(t2);
t4=C_s_a_i_digits_to_integer(&a,5,((C_word*)t0)[3],((C_word*)t0)[4],t3,((C_word*)t0)[5],((C_word*)t0)[6]);
if(C_truep(t4)){
if(C_truep(t1)){
t5=C_set_block_item(((C_word*)t0)[7],0,C_SCHEME_TRUE);
t6=(
/* library.scm:2529: go-inexact! */
  f_16076(((C_word*)((C_word*)t0)[8])[1],((C_word*)t0)[6])
);
t7=C_u_i_cdr(t2);
t8=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_a_i_cons(&a,2,t4,t7);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t5=C_u_i_cdr(t2);
t6=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_cons(&a,2,t4,t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t5=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* scan-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16384(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_16384,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_fixnum_lessp(t2,((C_word*)t0)[2]))){
t3=C_subchar(((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16399,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t5=C_eqp(t3,C_make_character(43));
if(C_truep(t5)){
t6=t4;
f_16399(t6,lf[636]);}
else{
t6=C_eqp(t3,C_make_character(45));
t7=t4;
f_16399(t7,(C_truep(t6)?lf[635]:C_SCHEME_FALSE));}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16397 in scan-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16399(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_16399,2,t0,t1);}
a=C_alloc(7);
t2=(C_truep(t1)?C_fixnum_plus(((C_word*)t0)[2],C_fix(1)):((C_word*)t0)[2]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16408,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:2537: scan-digits */
t4=((C_word*)t0)[6];
f_16170(t4,t3,t2);}
else{
t3=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16406 in k16397 in scan-exponent in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16408(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_16408,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_i_car(t1);
t3=C_eqp(((C_word*)t0)[2],lf[635]);
t4=C_s_a_i_digits_to_integer(&a,5,((C_word*)t0)[3],((C_word*)t0)[4],t2,((C_word*)t0)[5],t3);
t5=C_u_i_cdr(t1);
t6=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_cons(&a,2,t4,t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t2=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16442(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_16442,5,t0,t1,t2,t3,t4);}
a=C_alloc(9);
if(C_truep(C_fixnum_lessp(t2,((C_word*)t0)[2]))){
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_16452,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=t4,a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* library.scm:2545: scan-digits+hashes */
t6=((C_word*)t0)[6];
f_16328(t6,t5,t2,t3,t4);}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_16452,c,av);}
a=C_alloc(11);
t2=(C_truep(t1)?C_i_cdr(t1):((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_16461,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)t0)[7])){
t4=t3;
f_16461(t4,((C_word*)t0)[7]);}
else{
t4=C_i_not(t2);
t5=t3;
f_16461(t5,(C_truep(t4)?t4:C_fixnum_greaterp(t2,((C_word*)t0)[2])));}}

/* k16459 in k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16461(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_16461,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(C_truep(((C_word*)t0)[2])?C_subchar(((C_word*)t0)[3],((C_word*)t0)[2]):C_SCHEME_FALSE);
t3=C_eqp(t2,C_make_character(101));
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_16473,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t3)){
t5=t4;
f_16473(t5,t3);}
else{
t5=C_eqp(t2,C_make_character(115));
if(C_truep(t5)){
t6=t4;
f_16473(t6,t5);}
else{
t6=C_eqp(t2,C_make_character(102));
if(C_truep(t6)){
t7=t4;
f_16473(t7,t6);}
else{
t7=C_eqp(t2,C_make_character(100));
if(C_truep(t7)){
t8=t4;
f_16473(t8,t7);}
else{
t8=C_eqp(t2,C_make_character(108));
if(C_truep(t8)){
t9=t4;
f_16473(t9,t8);}
else{
t9=C_eqp(t2,C_make_character(69));
if(C_truep(t9)){
t10=t4;
f_16473(t10,t9);}
else{
t10=C_eqp(t2,C_make_character(83));
if(C_truep(t10)){
t11=t4;
f_16473(t11,t10);}
else{
t11=C_eqp(t2,C_make_character(70));
if(C_truep(t11)){
t12=t4;
f_16473(t12,t11);}
else{
t12=C_eqp(t2,C_make_character(68));
t13=t4;
f_16473(t13,(C_truep(t12)?t12:C_eqp(t2,C_make_character(76))));}}}}}}}}}
else{
t2=((C_word*)t0)[6];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16471 in k16459 in k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16473(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_16473,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[2],((C_word*)t0)[3]))){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16482,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],tmp=(C_word)a,a+=7,tmp);
/* library.scm:2553: scan-exponent */
t3=((C_word*)t0)[9];
f_16384(t3,t2,C_fixnum_plus(((C_word*)t0)[3],C_fix(1)));}
else{
t2=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=(C_truep(((C_word*)t0)[3])?((C_word*)t0)[3]:((C_word*)t0)[2]);
t3=(C_truep(((C_word*)t0)[4])?C_fixnum_difference(((C_word*)t0)[7],t2):C_SCHEME_FALSE);
t4=(C_truep(((C_word*)t0)[4])?C_i_car(((C_word*)t0)[4]):C_SCHEME_FALSE);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16548,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2563: safe-exponent */
t6=((C_word*)((C_word*)t0)[6])[1];
f_16090(t6,t5,t4,t3);}}

/* k16480 in k16471 in k16459 in k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16482(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_16482,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_i_car(t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16494,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t2,a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* library.scm:2555: safe-exponent */
t4=((C_word*)((C_word*)t0)[4])[1];
f_16090(t4,t3,((C_word*)t0)[6],t2);}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16492 in k16480 in k16471 in k16459 in k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16494(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_16494,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16500,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[2])){
t3=C_i_cdr(((C_word*)t0)[2]);
t4=t2;
f_16500(t4,C_fixnum_difference(((C_word*)t0)[6],C_fixnum_difference(t3,((C_word*)t0)[7])));}
else{
t3=t2;
f_16500(t3,C_SCHEME_FALSE);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16498 in k16492 in k16480 in k16471 in k16459 in k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16500(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_16500,2,t0,t1);}
a=C_alloc(5);
t2=(C_truep(((C_word*)t0)[2])?C_i_car(((C_word*)t0)[2]):C_SCHEME_FALSE);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16506,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2558: safe-exponent */
t4=((C_word*)((C_word*)t0)[6])[1];
f_16090(t4,t3,t2,t1);}

/* k16504 in k16498 in k16492 in k16480 in k16471 in k16459 in k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16506(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_16506,c,av);}
a=C_alloc(32);
if(C_truep(t1)){
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],t1);
t3=C_u_i_cdr(((C_word*)t0)[3]);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=C_u_i_cdr(((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[2],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16546 in k16471 in k16459 in k16450 in scan-decimal-tail in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16548(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_16548,c,av);}
a=C_alloc(32);
t2=(C_truep(((C_word*)t0)[2])?((C_word*)t0)[2]:C_fix(0));
if(C_truep(t1)){
t3=C_s_a_i_plus(&a,2,t2,t1);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,t3,((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16656(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,2)))){
C_save_and_reclaim_args((void *)trf_16656,4,t0,t1,t2,t3);}
a=C_alloc(15);
t4=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_16663,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t2,a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[8],a[12]=((C_word*)t0)[9],a[13]=((C_word*)t0)[10],a[14]=((C_word*)t0)[11],tmp=(C_word)a,a+=15,tmp);
t5=C_fixnum_plus(t2,C_fix(1));
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[6],t5))){
t6=C_eqp(((C_word*)t0)[5],C_fix(10));
t7=t4;
f_16663(t7,(C_truep(t6)?C_eqp(C_subchar(((C_word*)t0)[4],t2),C_make_character(46)):C_SCHEME_FALSE));}
else{
t6=t4;
f_16663(t6,C_SCHEME_FALSE);}}

/* k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16663(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,4)))){
C_save_and_reclaim_args((void *)trf_16663,2,t0,t1);}
a=C_alloc(14);
if(C_truep(t1)){
t2=(
/* library.scm:2571: go-inexact! */
  f_16076(((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3])
);
/* library.scm:2572: scan-decimal-tail */
t3=((C_word*)t0)[4];
f_16442(t3,((C_word*)t0)[5],C_fixnum_plus(((C_word*)t0)[6],C_fix(1)),((C_word*)t0)[3],C_SCHEME_FALSE);}
else{
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_16676,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],tmp=(C_word)a,a+=14,tmp);
/* library.scm:2573: scan-digits+hashes */
t3=((C_word*)t0)[14];
f_16328(t3,t2,((C_word*)t0)[6],((C_word*)t0)[3],C_SCHEME_FALSE);}}

/* k16674 in k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16676(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_16676,c,av);}
a=C_alloc(14);
if(C_truep(t1)){
t2=C_i_cdr(t1);
t3=(C_truep(t2)?C_subchar(((C_word*)t0)[2],C_u_i_cdr(t1)):C_SCHEME_FALSE);
t4=C_eqp(t3,C_make_character(46));
if(C_truep(t4)){
t5=(
/* library.scm:2576: go-inexact! */
  f_16076(((C_word*)((C_word*)t0)[3])[1],((C_word*)t0)[4])
);
t6=C_eqp(((C_word*)t0)[5],C_fix(10));
if(C_truep(t6)){
t7=C_fixnum_plus(C_u_i_cdr(t1),C_fix(1));
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[6],t7))){
/* library.scm:2579: scan-decimal-tail */
t8=((C_word*)t0)[7];
f_16442(t8,((C_word*)t0)[8],C_fixnum_plus(C_u_i_cdr(t1),C_fix(1)),((C_word*)t0)[4],C_u_i_car(t1));}
else{
t8=C_u_i_car(t1);
t9=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_a_i_cons(&a,2,t8,C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t7=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
t5=C_eqp(t3,C_make_character(101));
t6=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_16734,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=t3,a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t5)){
t7=t6;
f_16734(t7,t5);}
else{
t7=C_eqp(t3,C_make_character(115));
if(C_truep(t7)){
t8=t6;
f_16734(t8,t7);}
else{
t8=C_eqp(t3,C_make_character(102));
if(C_truep(t8)){
t9=t6;
f_16734(t9,t8);}
else{
t9=C_eqp(t3,C_make_character(100));
if(C_truep(t9)){
t10=t6;
f_16734(t10,t9);}
else{
t10=C_eqp(t3,C_make_character(108));
if(C_truep(t10)){
t11=t6;
f_16734(t11,t10);}
else{
t11=C_eqp(t3,C_make_character(69));
if(C_truep(t11)){
t12=t6;
f_16734(t12,t11);}
else{
t12=C_eqp(t3,C_make_character(83));
if(C_truep(t12)){
t13=t6;
f_16734(t13,t12);}
else{
t13=C_eqp(t3,C_make_character(70));
if(C_truep(t13)){
t14=t6;
f_16734(t14,t13);}
else{
t14=C_eqp(t3,C_make_character(68));
t15=t6;
f_16734(t15,(C_truep(t14)?t14:C_eqp(t3,C_make_character(76))));}}}}}}}}}}
else{
t2=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16732 in k16674 in k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_16734(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_16734,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(
/* library.scm:2583: go-inexact! */
  f_16076(((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3])
);
t3=C_eqp(((C_word*)t0)[4],C_fix(10));
if(C_truep(t3)){
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[5],C_u_i_cdr(((C_word*)t0)[6])))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16752,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2586: scan-exponent */
t5=((C_word*)t0)[9];
f_16384(t5,t4,C_fixnum_plus(C_u_i_cdr(((C_word*)t0)[6]),C_fix(1)));}
else{
t4=((C_word*)t0)[7];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=((C_word*)t0)[7];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t2=C_eqp(((C_word*)t0)[10],C_make_character(47));
if(C_truep(t2)){
t3=C_set_block_item(((C_word*)t0)[11],0,C_SCHEME_FALSE);
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[5],C_u_i_cdr(((C_word*)t0)[6])))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16798,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[12],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2593: scan-digits+hashes */
t5=((C_word*)t0)[13];
f_16328(t5,t4,C_fixnum_plus(C_u_i_cdr(((C_word*)t0)[6]),C_fix(1)),C_SCHEME_FALSE,C_SCHEME_FALSE);}
else{
t4=((C_word*)t0)[7];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[7];{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k16750 in k16732 in k16674 in k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16752(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_16752,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=C_u_i_car(((C_word*)t0)[2]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16762,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2588: safe-exponent */
t4=((C_word*)((C_word*)t0)[4])[1];
f_16090(t4,t3,t2,C_i_car(t1));}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16760 in k16750 in k16732 in k16674 in k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16762,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16796 in k16732 in k16674 in k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_16798,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=C_u_i_car(((C_word*)t0)[2]);
if(C_truep(t2)){
t3=C_i_car(t1);
if(C_truep(t3)){
t4=C_eqp(t3,C_fix(0));
if(C_truep(C_i_not(t4))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16824,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2597: ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=t2;
av2[3]=t3;
tp(4,av2);}}
else{
t5=C_eqp(((C_word*)((C_word*)t0)[4])[1],lf[631]);
if(C_truep(C_i_not(t5))){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16835,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2601: chicken.base#signum */
t7=*((C_word*)lf[185]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k16822 in k16796 in k16732 in k16674 in k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16824(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_16824,c,av);}
a=C_alloc(3);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,t1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k16833 in k16796 in k16732 in k16674 in k16661 in scan-ureal in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_16835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,1)))){
C_save_and_reclaim((void *)f_16835,c,av);}
a=C_alloc(7);
switch(t1){
case C_fix(-1):
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[634],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
case C_fix(0):
t2=C_flonum(&a,C_ub_i_flonum_quotient((double)0.0,(double)0.0));
t3=C_u_i_cdr(((C_word*)t0)[2]);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}
case C_fix(1):
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[633],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
default:
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* scan-real in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_17002(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_17002,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_fixnum_lessp(t2,((C_word*)t0)[2]))){
t3=C_subchar(((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17017,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
t5=C_eqp(t3,C_make_character(43));
if(C_truep(t5)){
t6=t4;
f_17017(t6,lf[636]);}
else{
t6=C_eqp(t3,C_make_character(45));
t7=t4;
f_17017(t7,(C_truep(t6)?lf[635]:C_SCHEME_FALSE));}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k17015 in scan-real in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_17017(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_17017,2,t0,t1);}
a=C_alloc(11);
t2=(C_truep(t1)?C_fixnum_plus(((C_word*)t0)[2],C_fix(1)):((C_word*)t0)[2]);
if(C_truep(C_fixnum_lessp(t2,((C_word*)t0)[3]))){
t3=C_subchar(((C_word*)t0)[4],t2);
t4=C_eqp(t3,C_make_character(105));
t5=(C_truep(t4)?t4:C_eqp(t3,C_make_character(73)));
if(C_truep(t5)){
if(C_truep(t1)){
t6=C_fixnum_plus(t2,C_fix(1));
t7=C_eqp(t6,((C_word*)t0)[3]);
if(C_truep(t7)){
t8=C_eqp(t1,lf[635]);
t9=(C_truep(t8)?C_a_i_cons(&a,2,C_fix(-1),t2):C_a_i_cons(&a,2,C_fix(1),t2));
if(C_truep(t9)){
t10=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
/* library.scm:2626: scan-ureal */
t10=((C_word*)t0)[6];
f_16656(t10,((C_word*)t0)[5],t2,C_eqp(t1,lf[635]));}}
else{
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17075,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t9=C_fixnum_plus(t2,C_fix(5));
if(C_truep(C_fixnum_less_or_equal_p(t9,((C_word*)t0)[3]))){
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17116,a[2]=t8,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2620: scheme#substring */
t11=*((C_word*)lf[402]+1);{
C_word av2[5];
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
av2[4]=C_fixnum_plus(t2,C_fix(5));
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}
else{
t10=t8;
f_17075(t10,C_SCHEME_FALSE);}}}
else{
/* library.scm:2626: scan-ureal */
t6=((C_word*)t0)[6];
f_16656(t6,((C_word*)t0)[5],t2,C_eqp(t1,lf[635]));}}
else{
t6=C_eqp(t3,C_make_character(110));
t7=(C_truep(t6)?t6:C_eqp(t3,C_make_character(78)));
if(C_truep(t7)){
if(C_truep(t1)){
t8=C_fixnum_plus(t2,C_fix(5));
if(C_truep(C_fixnum_less_or_equal_p(t8,((C_word*)t0)[3]))){
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17194,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:2630: scheme#substring */
t10=*((C_word*)lf[402]+1);{
C_word av2[5];
av2[0]=t10;
av2[1]=t9;
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
av2[4]=C_fixnum_plus(t2,C_fix(5));
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
/* library.scm:2635: scan-ureal */
t9=((C_word*)t0)[6];
f_16656(t9,((C_word*)t0)[5],t2,C_eqp(t1,lf[635]));}}
else{
/* library.scm:2635: scan-ureal */
t8=((C_word*)t0)[6];
f_16656(t8,((C_word*)t0)[5],t2,C_eqp(t1,lf[635]));}}
else{
/* library.scm:2636: scan-ureal */
t8=((C_word*)t0)[6];
f_16656(t8,((C_word*)t0)[5],t2,C_eqp(t1,lf[635]));}}}
else{
t3=((C_word*)t0)[5];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k17073 in k17015 in scan-real in ##sys#string->compnum in k10751 in k8834 */
static void C_fcall f_17075(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_17075,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(
/* library.scm:2621: go-inexact! */
  f_16076(((C_word*)((C_word*)t0)[2])[1],C_eqp(((C_word*)t0)[3],lf[635]))
);
t3=C_eqp(((C_word*)t0)[3],lf[635]);
t4=(C_truep(t3)?lf[634]:lf[633]);
t5=C_fixnum_plus(((C_word*)t0)[4],C_fix(5));
if(C_truep(C_fixnum_lessp(t5,((C_word*)t0)[5]))){
t6=C_fixnum_plus(((C_word*)t0)[4],C_fix(5));
t7=C_a_i_cons(&a,2,t4,t6);
if(C_truep(t7)){
t8=((C_word*)t0)[6];{
C_word av2[2];
av2[0]=t8;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
/* library.scm:2626: scan-ureal */
t8=((C_word*)t0)[7];
f_16656(t8,((C_word*)t0)[6],((C_word*)t0)[4],C_eqp(((C_word*)t0)[3],lf[635]));}}
else{
t6=C_a_i_cons(&a,2,t4,C_SCHEME_FALSE);
if(C_truep(t6)){
t7=((C_word*)t0)[6];{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* library.scm:2626: scan-ureal */
t7=((C_word*)t0)[7];
f_16656(t7,((C_word*)t0)[6],((C_word*)t0)[4],C_eqp(((C_word*)t0)[3],lf[635]));}}}
else{
/* library.scm:2626: scan-ureal */
t2=((C_word*)t0)[7];
f_16656(t2,((C_word*)t0)[6],((C_word*)t0)[4],C_eqp(((C_word*)t0)[3],lf[635]));}}

/* k17114 in k17015 in scan-real in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_17116(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17116,c,av);}
t2=((C_word*)t0)[2];
f_17075(t2,C_i_string_ci_equal_p(t1,lf[637]));}

/* k17192 in k17015 in scan-real in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_17194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_17194,c,av);}
a=C_alloc(7);
if(C_truep(C_i_string_ci_equal_p(t1,lf[638]))){
t2=(
/* library.scm:2631: go-inexact! */
  f_16076(((C_word*)((C_word*)t0)[2])[1],C_eqp(((C_word*)t0)[3],lf[635]))
);
t3=C_flonum(&a,C_ub_i_flonum_quotient((double)0.0,(double)0.0));
t4=C_fixnum_plus(((C_word*)t0)[4],C_fix(5));
if(C_truep(C_fixnum_lessp(t4,((C_word*)t0)[5]))){
t5=C_fixnum_plus(((C_word*)t0)[4],C_fix(5));
t6=C_a_i_cons(&a,2,t3,t5);
if(C_truep(t6)){
t7=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* library.scm:2635: scan-ureal */
t7=((C_word*)t0)[7];
f_16656(t7,((C_word*)t0)[6],((C_word*)t0)[4],C_eqp(((C_word*)t0)[3],lf[635]));}}
else{
t5=C_a_i_cons(&a,2,t3,C_SCHEME_FALSE);
if(C_truep(t5)){
t6=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* library.scm:2635: scan-ureal */
t6=((C_word*)t0)[7];
f_16656(t6,((C_word*)t0)[6],((C_word*)t0)[4],C_eqp(((C_word*)t0)[3],lf[635]));}}}
else{
/* library.scm:2635: scan-ureal */
t2=((C_word*)t0)[7];
f_16656(t2,((C_word*)t0)[6],((C_word*)t0)[4],C_eqp(((C_word*)t0)[3],lf[635]));}}

/* k17240 in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_17242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_17242,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17245,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t1)){
t3=C_i_cdr(t1);
t4=(C_truep(t3)?C_subchar(((C_word*)t0)[5],C_u_i_cdr(t1)):C_SCHEME_FALSE);
t5=C_eqp(t4,C_SCHEME_FALSE);
if(C_truep(t5)){
t6=t2;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_u_i_car(t1);
f_17245(2,av2);}}
else{
t6=C_eqp(t4,C_make_character(105));
t7=(C_truep(t6)?t6:C_eqp(t4,C_make_character(73)));
if(C_truep(t7)){
t8=C_fixnum_plus(C_u_i_cdr(t1),C_fix(1));
t9=C_eqp(((C_word*)t0)[6],t8);
if(C_truep(t9)){
t10=C_eqp(C_subchar(((C_word*)t0)[5],((C_word*)t0)[7]),C_make_character(43));
if(C_truep(t10)){
if(C_truep(t10)){
/* library.scm:2643: scheme#make-rectangular */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[524]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[524]+1);
av2[1]=t2;
av2[2]=C_fix(0);
av2[3]=C_u_i_car(t1);
tp(4,av2);}}
else{
t11=t2;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}
else{
t11=C_eqp(C_subchar(((C_word*)t0)[5],((C_word*)t0)[7]),C_make_character(45));
if(C_truep(t11)){
/* library.scm:2643: scheme#make-rectangular */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[524]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[524]+1);
av2[1]=t2;
av2[2]=C_fix(0);
av2[3]=C_u_i_car(t1);
tp(4,av2);}}
else{
t12=t2;{
C_word *av2=av;
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}}
else{
t10=t2;{
C_word *av2=av;
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}
else{
t8=C_eqp(t4,C_make_character(43));
t9=(C_truep(t8)?t8:C_eqp(t4,C_make_character(45)));
if(C_truep(t9)){
t10=C_set_block_item(((C_word*)t0)[8],0,C_SCHEME_FALSE);
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17344,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],a[4]=t2,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:2646: scan-real */
t12=((C_word*)t0)[9];
f_17002(t12,t11,C_u_i_cdr(t1));}
else{
t10=C_eqp(t4,C_make_character(64));
if(C_truep(t10)){
t11=C_set_block_item(((C_word*)t0)[8],0,C_SCHEME_FALSE);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17412,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2654: scan-real */
t13=((C_word*)t0)[9];
f_17002(t13,t12,C_fixnum_plus(C_u_i_cdr(t1),C_fix(1)));}
else{
t11=t2;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}}}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}

/* k17243 in k17240 in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_17245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17245,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=C_eqp(((C_word*)((C_word*)t0)[2])[1],lf[632]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17257,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* library.scm:2659: scheme#exact->inexact */
t4=*((C_word*)lf[62]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(C_i_finitep(t1))?t1:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k17255 in k17243 in k17240 in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_17257(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17257,c,av);}
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
if(C_truep(C_u_i_zerop2(t1))){
/* library.scm:2662: chicken.flonum#fpneg */
t2=*((C_word*)lf[464]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k17342 in k17240 in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_17344(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17344,c,av);}
if(C_truep(t1)){
if(C_truep(C_i_cdr(t1))){
t2=C_fixnum_plus(C_u_i_cdr(t1),C_fix(1));
t3=C_eqp(((C_word*)t0)[2],t2);
if(C_truep(t3)){
t4=C_u_i_cdr(t1);
t5=C_eqp(C_subchar(((C_word*)t0)[3],t4),C_make_character(105));
if(C_truep(t5)){
if(C_truep(t5)){
/* library.scm:2651: scheme#make-rectangular */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[524]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[524]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=C_u_i_car(((C_word*)t0)[5]);
av2[3]=C_u_i_car(t1);
tp(4,av2);}}
else{
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}
else{
t6=C_u_i_cdr(t1);
t7=C_eqp(C_subchar(((C_word*)t0)[3],t6),C_make_character(73));
if(C_truep(t7)){
/* library.scm:2651: scheme#make-rectangular */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[524]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[524]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=C_u_i_car(((C_word*)t0)[5]);
av2[3]=C_u_i_car(t1);
tp(4,av2);}}
else{
t8=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}

/* k17410 in k17240 in ##sys#string->compnum in k10751 in k8834 */
static void C_ccall f_17412(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17412,c,av);}
if(C_truep(t1)){
t2=C_i_cdr(t1);
if(C_truep(C_i_not(t2))){
/* library.scm:2656: scheme#make-polar */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[526]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[526]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=C_u_i_car(((C_word*)t0)[3]);
av2[3]=C_u_i_car(t1);
tp(4,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_17245(2,av2);}}}

/* scheme#string->number in k10751 in k8834 */
static void C_ccall f_17492(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_17492,c,av);}
a=C_alloc(5);
t3=C_rest_nullp(c,3);
t4=(C_truep(t3)?C_fix(10):C_get_rest_arg(c,3,av,3,t0));
t5=C_i_check_string_2(t2,lf[640]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17502,a[2]=t2,a[3]=t4,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnump(t4))){
if(C_truep(C_fixnum_lessp(C_fix(1),t4))){
if(C_truep(C_fixnum_lessp(t4,C_fix(37)))){
t7=t6;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_17502(2,av2);}}
else{
/* library.scm:2671: ##sys#error-bad-base */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[381]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[381]+1);
av2[1]=t6;
av2[2]=t4;
av2[3]=lf[640];
tp(4,av2);}}}
else{
/* library.scm:2671: ##sys#error-bad-base */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[381]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[381]+1);
av2[1]=t6;
av2[2]=t4;
av2[3]=lf[640];
tp(4,av2);}}}
else{
/* library.scm:2671: ##sys#error-bad-base */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[381]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[381]+1);
av2[1]=t6;
av2[2]=t4;
av2[3]=lf[640];
tp(4,av2);}}}

/* k17500 in scheme#string->number in k10751 in k8834 */
static void C_ccall f_17502(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,6)))){
C_save_and_reclaim((void *)f_17502,c,av);}
a=C_alloc(8);
t2=C_block_size(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17511,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=((C_word)li469),tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_17511(t6,((C_word*)t0)[4],C_fix(0),C_SCHEME_FALSE,C_SCHEME_FALSE,t2);}

/* scan-prefix in k17500 in scheme#string->number in k10751 in k8834 */
static void C_fcall f_17511(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_17511,6,t0,t1,t2,t3,t4,t5);}
t6=C_fixnum_plus(t2,C_fix(2));
t7=C_fixnum_lessp(t6,t5);
t8=(C_truep(t7)?C_eqp(C_subchar(((C_word*)t0)[2],t2),C_make_character(35)):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=C_fixnum_plus(t2,C_fix(1));
t10=C_subchar(((C_word*)t0)[2],t9);
t11=C_eqp(t10,C_make_character(105));
t12=(C_truep(t11)?t11:C_eqp(t10,C_make_character(73)));
if(C_truep(t12)){
if(C_truep(C_i_not(t3))){
/* library.scm:2678: scan-prefix */
t24=t1;
t25=C_fixnum_plus(t2,C_fix(2));
t26=lf[632];
t27=t4;
t28=t5;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
t5=t28;
goto loop;}
else{
t13=t1;{
C_word av2[2];
av2[0]=t13;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}}
else{
t13=C_eqp(t10,C_make_character(101));
t14=(C_truep(t13)?t13:C_eqp(t10,C_make_character(69)));
if(C_truep(t14)){
if(C_truep(C_i_not(t3))){
/* library.scm:2679: scan-prefix */
t24=t1;
t25=C_fixnum_plus(t2,C_fix(2));
t26=lf[631];
t27=t4;
t28=t5;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
t5=t28;
goto loop;}
else{
t15=t1;{
C_word av2[2];
av2[0]=t15;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}}
else{
t15=C_eqp(t10,C_make_character(98));
t16=(C_truep(t15)?t15:C_eqp(t10,C_make_character(66)));
if(C_truep(t16)){
if(C_truep(C_i_not(t4))){
/* library.scm:2680: scan-prefix */
t24=t1;
t25=C_fixnum_plus(t2,C_fix(2));
t26=t3;
t27=C_fix(2);
t28=t5;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
t5=t28;
goto loop;}
else{
t17=t1;{
C_word av2[2];
av2[0]=t17;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}}
else{
t17=C_eqp(t10,C_make_character(111));
t18=(C_truep(t17)?t17:C_eqp(t10,C_make_character(79)));
if(C_truep(t18)){
if(C_truep(C_i_not(t4))){
/* library.scm:2681: scan-prefix */
t24=t1;
t25=C_fixnum_plus(t2,C_fix(2));
t26=t3;
t27=C_fix(8);
t28=t5;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
t5=t28;
goto loop;}
else{
t19=t1;{
C_word av2[2];
av2[0]=t19;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}}
else{
t19=C_eqp(t10,C_make_character(100));
t20=(C_truep(t19)?t19:C_eqp(t10,C_make_character(68)));
if(C_truep(t20)){
if(C_truep(C_i_not(t4))){
/* library.scm:2682: scan-prefix */
t24=t1;
t25=C_fixnum_plus(t2,C_fix(2));
t26=t3;
t27=C_fix(10);
t28=t5;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
t5=t28;
goto loop;}
else{
t21=t1;{
C_word av2[2];
av2[0]=t21;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t21+1)))(2,av2);}}}
else{
t21=C_eqp(t10,C_make_character(120));
t22=(C_truep(t21)?t21:C_eqp(t10,C_make_character(88)));
if(C_truep(t22)){
if(C_truep(C_i_not(t4))){
/* library.scm:2683: scan-prefix */
t24=t1;
t25=C_fixnum_plus(t2,C_fix(2));
t26=t3;
t27=C_fix(16);
t28=t5;
t1=t24;
t2=t25;
t3=t26;
t4=t27;
t5=t28;
goto loop;}
else{
t23=t1;{
C_word av2[2];
av2[0]=t23;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t23+1)))(2,av2);}}}
else{
t23=t1;{
C_word av2[2];
av2[0]=t23;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t23+1)))(2,av2);}}}}}}}}
else{
if(C_truep(t4)){
/* library.scm:2685: ##sys#string->compnum */
f_16072(t1,t4,((C_word*)t0)[2],t2,t3);}
else{
/* library.scm:2685: ##sys#string->compnum */
f_16072(t1,((C_word*)t0)[4],((C_word*)t0)[2],t2,t3);}}}

/* ##sys#string->number in k10751 in k8834 */
static void C_ccall f_17747(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17747,c,av);}
t3=C_rest_nullp(c,3);
t4=(C_truep(t3)?C_fix(10):C_get_rest_arg(c,3,av,3,t0));
t5=C_rest_nullp(c,3);
t6=C_rest_nullp(c,4);
t7=(C_truep(t6)?C_SCHEME_FALSE:C_get_rest_arg(c,4,av,3,t0));
if(C_truep(C_rest_nullp(c,4))){
/* library.scm:2688: ##sys#string->compnum */
f_16072(t1,t4,t2,C_fix(0),t7);}
else{
/* library.scm:2688: ##sys#string->compnum */
f_16072(t1,t4,t2,C_fix(0),t7);}}

/* chicken.base#equal=? in k10751 in k8834 */
static void C_ccall f_17793(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(12,c,5)))){
C_save_and_reclaim((void *)f_17793,c,av);}
a=C_alloc(12);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17796,a[2]=t7,a[3]=((C_word)li476),tmp=(C_word)a,a+=4,tmp));
t9=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17864,a[2]=t5,a[3]=((C_word)li477),tmp=(C_word)a,a+=4,tmp));
/* library.scm:2731: walk */
t10=((C_word*)t7)[1];
f_17864(t10,t1,t2,t3);}

/* compare-slots in chicken.base#equal=? in k10751 in k8834 */
static void C_fcall f_17796(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_17796,5,t0,t1,t2,t3,t4);}
a=C_alloc(10);
t5=C_block_size(t2);
t6=C_block_size(t3);
t7=C_eqp(t5,t6);
if(C_truep(t7)){
t8=C_fixnum_less_or_equal_p(t5,t4);
if(C_truep(t8)){
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_fixnum_difference(t5,C_fix(1));
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17823,a[2]=t9,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=t3,a[6]=t11,a[7]=((C_word)li475),tmp=(C_word)a,a+=8,tmp));
t13=((C_word*)t11)[1];
f_17823(t13,t1,t4);}}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}

/* loop in compare-slots in chicken.base#equal=? in k10751 in k8834 */
static void C_fcall f_17823(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_17823,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
/* library.scm:2705: walk */
t4=((C_word*)((C_word*)t0)[3])[1];
f_17864(t4,t1,C_slot(((C_word*)t0)[4],t2),C_slot(((C_word*)t0)[5],t2));}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17847,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2706: walk */
t5=((C_word*)((C_word*)t0)[3])[1];
f_17864(t5,t4,C_slot(((C_word*)t0)[4],t2),C_slot(((C_word*)t0)[5],t2));}}

/* k17845 in loop in compare-slots in chicken.base#equal=? in k10751 in k8834 */
static void C_ccall f_17847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17847,c,av);}
if(C_truep(t1)){
/* library.scm:2707: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17823(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* walk in chicken.base#equal=? in k10751 in k8834 */
static void C_fcall f_17864(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_17864,4,t0,t1,t2,t3);}
t4=C_eqp(t2,t3);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_numberp(t2))){
t5=C_i_numberp(t3);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t5)?C_i_nequalp(t2,t3):C_eqp(t2,t3));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
if(C_truep(C_i_not(C_blockp(t2)))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_not(C_blockp(t3)))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_not(C_sametypep(t2,t3)))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_specialp(t2))){
if(C_truep(C_specialp(t3))){
if(C_truep(C_closurep(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=shallow_equal(t2,t3);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* library.scm:2721: compare-slots */
t5=((C_word*)((C_word*)t0)[2])[1];
f_17796(t5,t1,t2,t3,C_fix(1));}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
if(C_truep(C_byteblockp(t2))){
if(C_truep(C_byteblockp(t3))){
t5=C_block_size(t2);
t6=C_block_size(t3);
t7=C_eqp(t5,t6);
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=(C_truep(t7)?C_substring_compare(t2,t3,C_fix(0),C_fix(0),t5):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t5=C_block_size(t2);
t6=C_block_size(t3);
t7=C_eqp(t5,t6);
if(C_truep(t7)){
/* library.scm:2730: compare-slots */
t8=((C_word*)((C_word*)t0)[2])[1];
f_17796(t8,t1,t2,t3,C_fix(0));}
else{
t8=t1;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}}}}}}}

/* ##sys#interned-symbol? in k10751 in k8834 */
static void C_ccall f_17965(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17965,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_lookup_symbol(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#string->symbol in k10751 in k8834 */
static void C_ccall f_17968(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17968,c,av);}
t3=C_i_check_string(t2);
/* library.scm:2743: ##sys#intern-symbol */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
C_string_to_symbol(3,av2);}}

/* ##sys#symbol->string in k10751 in k8834 */
static void C_ccall f_17977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17977,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_slot(t2,C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#symbol->string in k10751 in k8834 */
static void C_ccall f_17983(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_17983,c,av);}
a=C_alloc(3);
t3=C_i_check_symbol_2(t2,lf[654]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17994,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2751: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}

/* k17992 in scheme#symbol->string in k10751 in k8834 */
static void C_ccall f_17994(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17994,c,av);}
/* library.scm:2751: scheme#string-copy */
t2=*((C_word*)lf[400]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* scheme#string->symbol in k10751 in k8834 */
static void C_ccall f_17996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_17996,c,av);}
a=C_alloc(3);
t3=C_i_check_string_2(t2,lf[656]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18007,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2757: string-copy */
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k18005 in scheme#string->symbol in k10751 in k8834 */
static void C_ccall f_18007(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18007,c,av);}
/* library.scm:2757: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
C_string_to_symbol(3,av2);}}

/* chicken.base#string->uninterned-symbol in k10751 in k8834 */
static void C_ccall f_18009(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_18009,c,av);}
a=C_alloc(7);
t3=C_i_check_string_2(t2,lf[658]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_make_symbol,a[2]=((C_word)li486),tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18020,a[2]=t4,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2763: string-copy */
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k18018 in chicken.base#string->uninterned-symbol in k10751 in k8834 */
static void C_ccall f_18020(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18020,c,av);}
/* library.scm:2761: g3436 */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* chicken.base#gensym in k10751 in k8834 */
static void C_ccall f_18022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +17,c,5)))){
C_save_and_reclaim((void*)f_18022,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+17);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
t3=C_fixnum_plus(((C_word*)((C_word*)t0)[2])[1],C_fix(1));
t4=C_set_block_item(((C_word*)t0)[2],0,t3);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_make_symbol,a[2]=((C_word)li488),tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18039,a[2]=t5,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18043,a[2]=t6,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t8=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f35941,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2780: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t9;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
tp(3,av2);}}
else{
t9=C_get_rest_arg(c,2,av,2,t0);
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18056,a[2]=t6,a[3]=((C_word*)t0)[2],a[4]=t7,a[5]=t9,tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_blockp(t9))){
if(C_truep(C_stringp(t9))){
t11=t10;{
C_word *av2=av;
av2[0]=t11;
av2[1]=t9;
f_18056(2,av2);}}
else{
if(C_truep(C_symbolp(t9))){
/* library.scm:2777: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t10;
av2[2]=t9;
tp(3,av2);}}
else{
/* library.scm:2768: ##sys#signal-hook */
t11=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=lf[263];
av2[3]=lf[661];
av2[4]=lf[662];
av2[5]=t9;
((C_proc)(void*)(*((C_word*)t11+1)))(6,av2);}}}}
else{
t11=t10;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_SCHEME_FALSE;
f_18056(2,av2);}}}}

/* k18037 in chicken.base#gensym in k10751 in k8834 */
static void C_ccall f_18039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18039,c,av);}
/* library.scm:2768: g3443 */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* k18041 in chicken.base#gensym in k10751 in k8834 */
static void C_ccall f_18043(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_18043,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18047,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2780: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[3])[1];
tp(3,av2);}}

/* k18045 in k18041 in chicken.base#gensym in k10751 in k8834 */
static void C_ccall f_18047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_18047,c,av);}
/* library.scm:2771: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k18054 in chicken.base#gensym in k10751 in k8834 */
static void C_ccall f_18056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_18056,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f35945,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2780: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[3])[1];
tp(3,av2);}}
else{
/* library.scm:2768: ##sys#signal-hook */
t2=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[263];
av2[3]=lf[661];
av2[4]=lf[662];
av2[5]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* chicken.base#symbol-append in k10751 in k8834 */
static void C_ccall f_18076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +20,c,3)))){
C_save_and_reclaim((void*)f_18076,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+20);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18084,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t5=t4;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)t6)[1];
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18099,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18101,a[2]=t6,a[3]=t10,a[4]=t7,a[5]=((C_word)li490),tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_18101(t12,t8,t2);}

/* k18082 in chicken.base#symbol-append in k10751 in k8834 */
static void C_ccall f_18084(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18084,c,av);}
/* library.scm:2785: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
C_string_to_symbol(3,av2);}}

/* k18097 in chicken.base#symbol-append in k10751 in k8834 */
static void C_ccall f_18099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_18099,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop3459 in chicken.base#symbol-append in k10751 in k8834 */
static void C_fcall f_18101(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_18101,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18126,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
t5=C_i_check_symbol_2(t4,lf[664]);
/* library.scm:2790: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t3;
av2[2]=t4;
tp(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18124 in map-loop3459 in chicken.base#symbol-append in k10751 in k8834 */
static void C_ccall f_18126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_18126,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_18101(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* chicken.keyword#keyword? in k10751 in k8834 */
static void C_ccall f_18135(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18135,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_keywordp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.keyword#string->keyword in k10751 in k8834 */
static void C_ccall f_18138(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18138,c,av);}
t3=C_i_check_string_2(t2,lf[668]);
/* library.scm:2807: ##sys#intern-keyword */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[649]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[649]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}

/* chicken.keyword#keyword->string in k10751 in k8834 */
static void C_ccall f_18147(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_18147,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18154,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2812: keyword? */
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k18152 in chicken.keyword#keyword->string in k10751 in k8834 */
static void C_ccall f_18154(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_18154,c,av);}
if(C_truep(t1)){
/* library.scm:2813: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
/* library.scm:2814: ##sys#signal-hook */
t2=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[263];
av2[3]=lf[670];
av2[4]=lf[671];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* chicken.keyword#get-keyword in k10751 in k8834 */
static void C_ccall f_18165(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_18165,c,av);}
a=C_alloc(7);
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?C_SCHEME_FALSE:C_get_rest_arg(c,4,av,4,t0));
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18172,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t5,a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* library.scm:2819: ##sys#check-keyword */
t7=*((C_word*)lf[358]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
av2[3]=lf[674];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k18170 in chicken.keyword#get-keyword in k10751 in k8834 */
static void C_ccall f_18172(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18172,c,av);}
t2=C_i_check_list_2(((C_word*)t0)[2],lf[674]);
t3=C_i_get_keyword(((C_word*)t0)[3],((C_word*)t0)[2],((C_word*)t0)[4]);
t4=C_eqp(t3,((C_word*)t0)[4]);
if(C_truep(t4)){
if(C_truep(((C_word*)t0)[5])){
/* library.scm:2823: thunk */
t5=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t5;
av2[1]=((C_word*)t0)[6];
((C_proc)C_fast_retrieve_proc(t5))(2,av2);}}
else{
t5=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t5=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* ##sys#make-blob in k10751 in k8834 */
static void C_ccall f_18196(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_18196,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18200,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:2839: ##sys#allocate-vector */
t4=*((C_word*)lf[323]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k18198 in ##sys#make-blob in k10751 in k8834 */
static void C_ccall f_18200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18200,c,av);}
t2=C_string_to_bytevector(t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.blob#make-blob in k10751 in k8834 */
static void C_ccall f_18202(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18202,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18206,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2844: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[679];
tp(4,av2);}}

/* k18204 in chicken.blob#make-blob in k10751 in k8834 */
static void C_ccall f_18206(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18206,c,av);}
/* library.scm:2845: ##sys#make-blob */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[677]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[677]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* chicken.blob#blob? in k10751 in k8834 */
static void C_ccall f_18211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18211,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(C_blockp(t2))?C_bytevectorp(t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.blob#blob-size in k10751 in k8834 */
static void C_ccall f_18217(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18217,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18221,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2852: ##sys#check-blob */
t4=*((C_word*)lf[349]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[682];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k18219 in chicken.blob#blob-size in k10751 in k8834 */
static void C_ccall f_18221(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18221,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_block_size(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.blob#string->blob in k10751 in k8834 */
static void C_ccall f_18226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_18226,c,av);}
a=C_alloc(5);
t3=C_i_check_string_2(t2,lf[684]);
t4=C_block_size(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18236,a[2]=t2,a[3]=t4,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2858: ##sys#make-blob */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[677]);
C_word *av2=av;
av2[0]=*((C_word*)lf[677]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}

/* k18234 in chicken.blob#string->blob in k10751 in k8834 */
static void C_ccall f_18236(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18236,c,av);}
t2=C_copy_memory(t1,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.blob#blob->string in k10751 in k8834 */
static void C_ccall f_18238(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18238,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18242,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2863: ##sys#check-blob */
t4=*((C_word*)lf[349]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[686];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k18240 in chicken.blob#blob->string in k10751 in k8834 */
static void C_ccall f_18242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_18242,c,av);}
a=C_alloc(5);
t2=C_block_size(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18248,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2865: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k18246 in k18240 in chicken.blob#blob->string in k10751 in k8834 */
static void C_ccall f_18248(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18248,c,av);}
t2=C_copy_memory(t1,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.blob#blob=? in k10751 in k8834 */
static void C_ccall f_18250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_18250,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18254,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2870: ##sys#check-blob */
t5=*((C_word*)lf[349]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[688];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k18252 in chicken.blob#blob=? in k10751 in k8834 */
static void C_ccall f_18254(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_18254,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18257,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2871: ##sys#check-blob */
t3=*((C_word*)lf[349]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[688];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18255 in k18252 in chicken.blob#blob=? in k10751 in k8834 */
static void C_ccall f_18257(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18257,c,av);}
t2=C_block_size(((C_word*)t0)[2]);
t3=C_block_size(((C_word*)t0)[3]);
t4=C_eqp(t3,t2);
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_zerop(C_string_compare(((C_word*)t0)[2],((C_word*)t0)[3],t2)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#make-vector in k10751 in k8834 */
static void C_ccall f_18273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_18273,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+5);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18277,a[2]=t3,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2883: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[689];
tp(4,av2);}}

/* k18275 in scheme#make-vector in k10751 in k8834 */
static void C_ccall f_18277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_18277,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18280,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnum_lessp(((C_word*)t0)[4],C_fix(0)))){
/* library.scm:2884: ##sys#error */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[689];
av2[3]=lf[690];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_18280(2,av2);}}}

/* k18278 in k18275 in scheme#make-vector in k10751 in k8834 */
static void C_ccall f_18280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_18280,c,av);}
if(C_truep(C_i_nullp(((C_word*)t0)[2]))){
t2=C_SCHEME_UNDEFINED;
/* library.scm:2885: ##sys#allocate-vector */
t3=*((C_word*)lf[323]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
av2[5]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
/* library.scm:2885: ##sys#allocate-vector */
t2=*((C_word*)lf[323]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_i_car(((C_word*)t0)[2]);
av2[5]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* scheme#list->vector in k10751 in k8834 */
static void C_ccall f_18302(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18302,c,av);}
a=C_alloc(4);
t3=C_i_listp(t2);
if(C_truep(C_i_not(t3))){
/* library.scm:2897: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[692];
tp(4,av2);}}
else{
t4=C_i_length(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18318,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2899: ##sys#make-vector */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[691]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[691]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}}

/* k18316 in scheme#list->vector in k10751 in k8834 */
static void C_ccall f_18318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18318,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18323,a[2]=t1,a[3]=((C_word)li504),tmp=(C_word)a,a+=4,tmp);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
  f_18323(t2,((C_word*)t0)[3],C_fix(0))
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* loop in k18316 in scheme#list->vector in k10751 in k8834 */
static C_word C_fcall f_18323(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_nullp(t1))){
return(((C_word*)t0)[2]);}
else{
t3=C_slot(t1,C_fix(0));
t4=C_i_setslot(((C_word*)t0)[2],t2,t3);
t6=C_slot(t1,C_fix(1));
t7=C_fixnum_plus(t2,C_fix(1));
t1=t6;
t2=t7;
goto loop;}}

/* scheme#vector->list in k10751 in k8834 */
static void C_ccall f_18354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_18354,c,av);}
a=C_alloc(8);
t3=C_i_check_vector_2(t2,lf[693]);
t4=C_block_size(t2);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18363,a[2]=t4,a[3]=t2,a[4]=t6,a[5]=((C_word)li506),tmp=(C_word)a,a+=6,tmp));
t8=((C_word*)t6)[1];
f_18363(t8,t1,C_fix(0));}

/* loop in scheme#vector->list in k10751 in k8834 */
static void C_fcall f_18363(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_18363,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_slot(((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18381,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:2916: loop */
t6=t4;
t7=C_fixnum_plus(t2,C_fix(1));
t1=t6;
t2=t7;
goto loop;}}

/* k18379 in loop in scheme#vector->list in k10751 in k8834 */
static void C_ccall f_18381(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18381,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* scheme#vector in k10751 in k8834 */
static void C_ccall f_18387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,2)))){
C_save_and_reclaim((void*)f_18387,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
/* library.scm:2918: scheme#list->vector */
t3=*((C_word*)lf[94]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* scheme#vector-fill! in k10751 in k8834 */
static void C_ccall f_18393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18393,c,av);}
a=C_alloc(6);
t4=C_i_check_vector_2(t2,lf[694]);
t5=C_block_size(t2);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18402,a[2]=t5,a[3]=t2,a[4]=t3,a[5]=((C_word)li509),tmp=(C_word)a,a+=6,tmp);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(
  f_18402(t6,C_fix(0))
);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* doloop3597 in scheme#vector-fill! in k10751 in k8834 */
static C_word C_fcall f_18402(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
if(C_truep(C_fixnum_greater_or_equal_p(t1,((C_word*)t0)[2]))){
t2=C_SCHEME_UNDEFINED;
return(t2);}
else{
t2=C_i_setslot(((C_word*)t0)[3],t1,((C_word*)t0)[4]);
t4=C_fixnum_plus(t1,C_fix(1));
t1=t4;
goto loop;}}

/* chicken.base#vector-copy! in k10751 in k8834 */
static void C_ccall f_18421(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +8,c,3)))){
C_save_and_reclaim((void*)f_18421,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+8);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
t5=C_i_check_vector_2(t2,lf[695]);
t6=C_i_check_vector_2(t3,lf[695]);
t7=C_block_size(t2);
t8=C_block_size(t3);
t9=C_i_pairp(t4);
t10=(C_truep(t9)?C_get_rest_arg(c,4,av,4,t0):C_i_fixnum_min(t8,t7));
t11=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18440,a[2]=t10,a[3]=t2,a[4]=t3,a[5]=t1,a[6]=t8,a[7]=t7,tmp=(C_word)a,a+=8,tmp);
/* library.scm:2935: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t11;
av2[2]=t10;
av2[3]=lf[695];
tp(4,av2);}}

/* k18438 in chicken.base#vector-copy! in k10751 in k8834 */
static void C_ccall f_18440(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,7)))){
C_save_and_reclaim((void *)f_18440,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18443,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_fixnum_greaterp(((C_word*)t0)[2],((C_word*)t0)[6]);
t4=(C_truep(t3)?t3:C_fixnum_greaterp(((C_word*)t0)[2],((C_word*)t0)[7]));
if(C_truep(t4)){
/* library.scm:2937: ##sys#signal-hook */
t5=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[388];
av2[3]=lf[695];
av2[4]=lf[696];
av2[5]=((C_word*)t0)[3];
av2[6]=((C_word*)t0)[4];
av2[7]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(8,av2);}}
else{
t5=t2;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_18443(2,av2);}}}

/* k18441 in k18438 in chicken.base#vector-copy! in k10751 in k8834 */
static void C_ccall f_18443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18443,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18448,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word)li511),tmp=(C_word)a,a+=6,tmp);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
  f_18448(t2,C_fix(0))
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* doloop3609 in k18441 in k18438 in chicken.base#vector-copy! in k10751 in k8834 */
static C_word C_fcall f_18448(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;
loop:{}
if(C_truep(C_fixnum_greater_or_equal_p(t1,((C_word*)t0)[2]))){
t2=C_SCHEME_UNDEFINED;
return(t2);}
else{
t2=C_slot(((C_word*)t0)[3],t1);
t3=C_i_setslot(((C_word*)t0)[4],t1,t2);
t5=C_fixnum_plus(t1,C_fix(1));
t1=t5;
goto loop;}}

/* chicken.base#subvector in k10751 in k8834 */
static void C_ccall f_18490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_18490,c,av);}
a=C_alloc(8);
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?C_SCHEME_FALSE:C_get_rest_arg(c,4,av,4,t0));
t6=C_i_check_vector_2(t2,lf[697]);
t7=C_block_size(t2);
t8=(C_truep(t5)?t5:t7);
t9=C_fixnum_difference(t8,t3);
t10=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18509,a[2]=t9,a[3]=t3,a[4]=t2,a[5]=t1,a[6]=t8,a[7]=t7,tmp=(C_word)a,a+=8,tmp);
/* library.scm:2950: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word av2[6];
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t10;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_fixnum_plus(t7,C_fix(1));
av2[5]=lf[697];
tp(6,av2);}}

/* k18507 in chicken.base#subvector in k10751 in k8834 */
static void C_ccall f_18509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_18509,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18512,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:2951: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=C_fix(0);
av2[4]=C_fixnum_plus(((C_word*)t0)[7],C_fix(1));
av2[5]=lf[697];
tp(6,av2);}}

/* k18510 in k18507 in chicken.base#subvector in k10751 in k8834 */
static void C_ccall f_18512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18512,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18515,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:2952: scheme#make-vector */
t3=*((C_word*)lf[93]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k18513 in k18510 in k18507 in chicken.base#subvector in k10751 in k8834 */
static void C_ccall f_18515(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_18515,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18520,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word)li513),tmp=(C_word)a,a+=7,tmp);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
  f_18520(t2,C_fix(0))
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* doloop3640 in k18513 in k18510 in k18507 in chicken.base#subvector in k10751 in k8834 */
static C_word C_fcall f_18520(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;
loop:{}
if(C_truep(C_fixnum_greater_or_equal_p(t1,((C_word*)t0)[2]))){
return(((C_word*)t0)[3]);}
else{
t2=C_fixnum_plus(t1,((C_word*)t0)[4]);
t3=C_slot(((C_word*)t0)[5],t2);
t4=C_i_setslot(((C_word*)t0)[3],t1,t3);
t6=C_fixnum_plus(t1,C_fix(1));
t1=t6;
goto loop;}}

/* chicken.base#vector-resize in k10751 in k8834 */
static void C_ccall f_18561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_18561,c,av);}
a=C_alloc(6);
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?C_SCHEME_FALSE:C_get_rest_arg(c,4,av,4,t0));
t6=C_i_check_vector_2(t2,lf[698]);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18571,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* library.scm:2960: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t7;
av2[2]=t3;
av2[3]=lf[698];
tp(4,av2);}}

/* k18569 in chicken.base#vector-resize in k10751 in k8834 */
static void C_ccall f_18571(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18571,c,av);}
/* library.scm:2961: ##sys#vector-resize */
f_18582(((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* ##sys#vector-resize in k10751 in k8834 */
static void C_fcall f_18582(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_18582,4,t1,t2,t3,t4);}
a=C_alloc(5);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18586,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:2964: ##sys#make-vector */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[691]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[691]+1);
av2[1]=t5;
av2[2]=t3;
av2[3]=t4;
tp(4,av2);}}

/* k18584 in ##sys#vector-resize in k10751 in k8834 */
static void C_ccall f_18586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_18586,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18589,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:2965: scheme#min */
t3=*((C_word*)lf[579]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_block_size(((C_word*)t0)[2]);
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18587 in k18584 in ##sys#vector-resize in k10751 in k8834 */
static void C_ccall f_18589(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18589,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18594,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word)li516),tmp=(C_word)a,a+=6,tmp);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
  f_18594(t2,C_fix(0))
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* doloop3668 in k18587 in k18584 in ##sys#vector-resize in k10751 in k8834 */
static C_word C_fcall f_18594(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;
loop:{}
if(C_truep(C_fixnum_greater_or_equal_p(t1,((C_word*)t0)[2]))){
return(((C_word*)t0)[3]);}
else{
t2=C_slot(((C_word*)t0)[4],t1);
t3=C_i_setslot(((C_word*)t0)[3],t1,t2);
t5=C_fixnum_plus(t1,C_fix(1));
t1=t5;
goto loop;}}

/* scheme#char-ci=? in k10751 in k8834 */
static void C_ccall f_18621(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18621,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_eqp(C_u_i_char_downcase(t2),C_u_i_char_downcase(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-ci>? in k10751 in k8834 */
static void C_ccall f_18635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18635,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_greaterp(C_u_i_char_downcase(t2),C_u_i_char_downcase(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-ci<? in k10751 in k8834 */
static void C_ccall f_18646(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18646,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_lessp(C_u_i_char_downcase(t2),C_u_i_char_downcase(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-ci>=? in k10751 in k8834 */
static void C_ccall f_18657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18657,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_greater_or_equal_p(C_u_i_char_downcase(t2),C_u_i_char_downcase(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-ci<=? in k10751 in k8834 */
static void C_ccall f_18668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18668,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_less_or_equal_p(C_u_i_char_downcase(t2),C_u_i_char_downcase(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k18679 in k10751 in k8834 */
static void C_ccall f_18681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_18681,c,av);}
a=C_alloc(15);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18683,a[2]=t1,a[3]=((C_word)li524),tmp=(C_word)a,a+=4,tmp);
t5=C_mutate((C_word*)lf[199]+1 /* (set! chicken.base#char-name ...) */,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18724,a[2]=t4,a[3]=t3,a[4]=t1,a[5]=((C_word)li525),tmp=(C_word)a,a+=6,tmp));
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18841,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3034: chicken.base#char-name */
t7=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[1444];
av2[3]=C_make_character(32);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* lookup-char in k18679 in k10751 in k8834 */
static void C_fcall f_18683(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_18683,3,t0,t1,t2);}
a=C_alloc(4);
t3=C_fix(C_character_code(t2));
t4=C_fixnum_modulo(t3,C_fix(37));
t5=C_slot(((C_word*)t0)[2],t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18696,a[2]=t2,a[3]=((C_word)li523),tmp=(C_word)a,a+=4,tmp);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=(
  f_18696(t6,t5)
);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* loop in lookup-char in k18679 in k10751 in k8834 */
static C_word C_fcall f_18696(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_slot(t1,C_fix(0));
t3=C_slot(t2,C_fix(0));
t4=C_eqp(t3,((C_word*)t0)[2]);
if(C_truep(t4)){
return(t2);}
else{
t6=C_slot(t1,C_fix(1));
t1=t6;
goto loop;}}
else{
return(C_SCHEME_FALSE);}}

/* chicken.base#char-name in k18679 in k10751 in k8834 */
static void C_ccall f_18724(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +8,c,5)))){
C_save_and_reclaim((void*)f_18724,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+8);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
t4=C_i_pairp(t3);
t5=(C_truep(t4)?C_get_rest_arg(c,3,av,3,t0):C_SCHEME_FALSE);
if(C_truep(C_charp(t2))){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18737,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:3008: lookup-char */
t7=((C_word*)t0)[2];
f_18683(t7,t6,t2);}
else{
if(C_truep(t5)){
t6=C_i_check_symbol_2(t2,lf[700]);
t7=C_i_check_char_2(t5,lf[700]);
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18755,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t5,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[2],tmp=(C_word)a,a+=8,tmp);
t9=C_slot(t2,C_fix(1));
t10=C_block_size(t9);
if(C_truep(C_fixnum_lessp(t10,C_fix(2)))){
/* library.scm:3014: ##sys#signal-hook */
t11=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t11;
av2[1]=t8;
av2[2]=lf[263];
av2[3]=lf[700];
av2[4]=lf[701];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t11+1)))(6,av2);}}
else{
t11=t8;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_SCHEME_UNDEFINED;
f_18755(2,av2);}}}
else{
t6=C_i_check_symbol_2(t2,lf[700]);
t7=C_i_assq(t2,((C_word*)((C_word*)t0)[3])[1]);
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=(C_truep(t7)?C_slot(t7,C_fix(1)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}}}

/* k18735 in chicken.base#char-name in k18679 in k10751 in k8834 */
static void C_ccall f_18737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18737,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_slot(t1,C_fix(1)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k18753 in chicken.base#char-name in k18679 in k10751 in k8834 */
static void C_ccall f_18755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_18755,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18758,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3015: lookup-char */
t3=((C_word*)t0)[7];
f_18683(t3,t2,((C_word*)t0)[5]);}

/* k18756 in k18753 in chicken.base#char-name in k18679 in k10751 in k8834 */
static void C_ccall f_18758(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_18758,c,av);}
a=C_alloc(12);
if(C_truep(t1)){
t2=C_i_assq(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);
t3=C_i_setslot(t1,C_fix(1),((C_word*)t0)[2]);
if(C_truep(t2)){
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_i_slot(t2,C_fix(1),((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[5]);
t5=C_a_i_cons(&a,2,t4,((C_word*)((C_word*)t0)[3])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[3])+1,t5);
t7=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}
else{
t2=C_fix(C_character_code(((C_word*)t0)[5]));
t3=C_fixnum_modulo(t2,C_fix(37));
t4=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[5]);
t5=C_a_i_cons(&a,2,t4,((C_word*)((C_word*)t0)[3])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[3])+1,t5);
t7=C_a_i_cons(&a,2,((C_word*)t0)[5],((C_word*)t0)[2]);
t8=C_slot(((C_word*)t0)[6],t3);
t9=C_a_i_cons(&a,2,t7,t8);
t10=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t10;
av2[1]=C_i_setslot(((C_word*)t0)[6],t3,t9);
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}

/* k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18841,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18844,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3035: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1443];
av2[3]=C_make_character(9);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18844(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18844,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18847,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3036: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1442];
av2[3]=C_make_character(10);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18847,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18850,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3037: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1441];
av2[3]=C_make_character(10);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18850,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18853,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3038: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1440];
av2[3]=C_make_character(11);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18853,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18856,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3039: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1439];
av2[3]=C_make_character(127);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18856,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18859,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3040: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1438];
av2[3]=C_make_character(27);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18859,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18862,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3041: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1437];
av2[3]=C_make_character(27);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18862,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18865,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3042: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1436];
av2[3]=C_make_character(7);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18865(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18865,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18868,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3043: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1435];
av2[3]=C_make_character(0);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18868(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18868,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18871,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3044: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1434];
av2[3]=C_make_character(0);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18871,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18874,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3045: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1433];
av2[3]=C_make_character(13);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18874(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18874,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18877,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3046: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1432];
av2[3]=C_make_character(12);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18877,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18880,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3047: chicken.base#char-name */
t3=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1431];
av2[3]=C_make_character(8);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18880(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(93,c,6)))){
C_save_and_reclaim((void *)f_18880,c,av);}
a=C_alloc(93);
t2=C_mutate((C_word*)lf[702]+1 /* (set! ##sys#call-with-current-continuation ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_call_cc,a[2]=((C_word)li526),tmp=(C_word)a,a+=3,tmp));
t3=C_mutate((C_word*)lf[703]+1 /* (set! ##sys#call-with-cthulhu ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_call_with_cthulhu,a[2]=((C_word)li527),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[704]+1 /* (set! ##sys#call-with-values ...) */,*((C_word*)lf[131]+1));
t5=C_mutate((C_word*)lf[705]+1 /* (set! ##sys#for-each ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18885,a[2]=((C_word)li529),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[707]+1 /* (set! ##sys#map ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18923,a[2]=((C_word)li531),tmp=(C_word)a,a+=3,tmp));
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18965,a[2]=((C_word)li534),tmp=(C_word)a,a+=3,tmp);
t10=C_set_block_item(t8,0,t9);
t11=C_mutate((C_word*)lf[170]+1 /* (set! scheme#for-each ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19023,a[2]=t8,a[3]=((C_word)li539),tmp=(C_word)a,a+=4,tmp));
t12=C_mutate((C_word*)lf[171]+1 /* (set! scheme#map ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19105,a[2]=t8,a[3]=((C_word)li544),tmp=(C_word)a,a+=4,tmp));
t13=C_set_block_item(lf[709] /* ##sys#dynamic-winds */,0,C_SCHEME_END_OF_LIST);
t14=C_mutate((C_word*)lf[172]+1 /* (set! scheme#dynamic-wind ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19207,a[2]=((C_word)li546),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[710]+1 /* (set! ##sys#dynamic-wind ...) */,*((C_word*)lf[172]+1));
t16=C_mutate((C_word*)lf[132]+1 /* (set! scheme#call-with-current-continuation ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19238,a[2]=((C_word)li549),tmp=(C_word)a,a+=3,tmp));
t17=C_mutate((C_word*)lf[198]+1 /* (set! chicken.base#call/cc ...) */,*((C_word*)lf[132]+1));
t18=C_mutate(&lf[711] /* (set! ##sys#dynamic-unwind ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19278,a[2]=((C_word)li550),tmp=(C_word)a,a+=3,tmp));
t19=C_mutate((C_word*)lf[209]+1 /* (set! chicken.base#port? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19336,a[2]=((C_word)li551),tmp=(C_word)a,a+=3,tmp));
t20=C_mutate((C_word*)lf[211]+1 /* (set! chicken.base#input-port-open? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19342,a[2]=((C_word)li552),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate((C_word*)lf[212]+1 /* (set! chicken.base#output-port-open? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19347,a[2]=((C_word)li553),tmp=(C_word)a,a+=3,tmp));
t22=C_mutate((C_word*)lf[210]+1 /* (set! chicken.base#port-closed? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19352,a[2]=((C_word)li554),tmp=(C_word)a,a+=3,tmp));
t23=C_mutate((C_word*)lf[716]+1 /* (set! ##sys#make-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19365,a[2]=((C_word)li555),tmp=(C_word)a,a+=3,tmp));
t24=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33003,a[2]=((C_word)li557),tmp=(C_word)a,a+=3,tmp);
t25=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33042,a[2]=((C_word)li559),tmp=(C_word)a,a+=3,tmp);
t26=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33081,a[2]=((C_word)li560),tmp=(C_word)a,a+=3,tmp);
t27=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33084,a[2]=((C_word)li561),tmp=(C_word)a,a+=3,tmp);
t28=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33087,a[2]=((C_word)li562),tmp=(C_word)a,a+=3,tmp);
t29=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33093,a[2]=((C_word)li563),tmp=(C_word)a,a+=3,tmp);
t30=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33096,a[2]=((C_word)li564),tmp=(C_word)a,a+=3,tmp);
t31=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33099,a[2]=((C_word)li567),tmp=(C_word)a,a+=3,tmp);
t32=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33197,a[2]=((C_word)li570),tmp=(C_word)a,a+=3,tmp);
t33=C_a_i_vector(&a,10,t24,t25,t26,t27,t28,t29,t30,t31,t32,C_SCHEME_FALSE);
t34=C_mutate((C_word*)lf[730]+1 /* (set! ##sys#stream-port-class ...) */,t33);
t35=C_mutate((C_word*)lf[731]+1 /* (set! ##sys#open-file-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_open_file_port,a[2]=((C_word)li571),tmp=(C_word)a,a+=3,tmp));
t36=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19396,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3329: ##sys#make-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[716]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[716]+1);
av2[1]=t36;
av2[2]=C_fix(1);
av2[3]=C_fast_retrieve(lf[730]);
av2[4]=lf[1430];
av2[5]=lf[749];
tp(6,av2);}}

/* ##sys#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_18885,c,av);}
a=C_alloc(8);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18891,a[2]=t5,a[3]=t2,a[4]=t3,a[5]=((C_word)li528),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_18891(t7,t1,t3);}

/* loop in ##sys#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_18891(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_18891,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t3)){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t2))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18907,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3060: p */
t5=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)C_fast_retrieve_proc(t5))(3,av2);}}
else{
/* library.scm:3062: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[706];
tp(4,av2);}}}}

/* k18905 in loop in ##sys#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18907(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18907,c,av);}
/* library.scm:3061: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_18891(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* ##sys#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_18923,c,av);}
a=C_alloc(8);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18929,a[2]=t5,a[3]=t2,a[4]=t3,a[5]=((C_word)li530),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_18929(t7,t1,t3);}

/* loop in ##sys#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_18929(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_18929,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t2))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18949,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3068: p */
t5=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)C_fast_retrieve_proc(t5))(3,av2);}}
else{
/* library.scm:3069: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[708];
tp(4,av2);}}}}

/* k18947 in loop in ##sys#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_18949,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18953,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3068: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_18929(t3,t2,C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k18951 in k18947 in loop in ##sys#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18953(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_18953,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* mapsafe3744 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18965(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_18965,c,av);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18971,a[2]=t2,a[3]=t4,a[4]=t3,a[5]=((C_word)li533),tmp=(C_word)a,a+=6,tmp);
/* library.scm:3073: scheme#call-with-current-continuation */
t6=*((C_word*)lf[132]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* a18970 in mapsafe3744 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_18971(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_18971,c,av);}
a=C_alloc(9);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18977,a[2]=t2,a[3]=t4,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word)li532),tmp=(C_word)a,a+=7,tmp));
t6=((C_word*)t4)[1];
f_18977(t6,t1,((C_word*)t0)[4]);}

/* lp in a18970 in mapsafe3744 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_18977(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_18977,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=C_eqp(t4,C_SCHEME_END_OF_LIST);
if(C_truep(t5)){
/* library.scm:3079: empty */
t6=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t6;
av2[1]=t1;
av2[2]=C_SCHEME_END_OF_LIST;
((C_proc)C_fast_retrieve_proc(t6))(3,av2);}}
else{
if(C_truep(C_i_pairp(t4))){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19009,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3081: p */
t7=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
((C_proc)C_fast_retrieve_proc(t7))(3,av2);}}
else{
/* library.scm:3082: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=((C_word*)t0)[5];
tp(4,av2);}}}}}

/* k19007 in lp in a18970 in mapsafe3744 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19009(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_19009,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19013,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3081: lp */
t3=((C_word*)((C_word*)t0)[3])[1];
f_18977(t3,t2,C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k19011 in k19007 in lp in a18970 in mapsafe3744 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_19013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_19013,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19023(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +11,c,3)))){
C_save_and_reclaim((void*)f_19023,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+11);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
if(C_truep(C_rest_nullp(c,4))){
t5=C_i_check_list_2(t3,lf[706]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19038,a[2]=t7,a[3]=t2,a[4]=((C_word)li535),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_19038(t9,t1,t3);}
else{
t5=C_a_i_cons(&a,2,t3,t4);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19068,a[2]=t7,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word)li538),tmp=(C_word)a,a+=6,tmp));
t9=((C_word*)t7)[1];
f_19068(t9,t1,t5);}}

/* for-each-loop3764 in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_19038(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_19038,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19048,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3087: g3765 */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k19046 in for-each-loop3764 in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19048(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19048,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_19038(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* loop in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_19068(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_19068,3,t0,t1,t2);}
a=C_alloc(10);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19075,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19099,a[2]=((C_word)li537),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3090: mapsafe */
t5=((C_word*)((C_word*)t0)[3])[1];{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
av2[3]=t2;
av2[4]=lf[706];
((C_proc)C_fast_retrieve_proc(t5))(5,av2);}}

/* k19073 in loop in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19075(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_19075,c,av);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t1))){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19084,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=t1;
C_apply(4,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19082 in k19073 in loop in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19084(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_19084,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19091,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19093,a[2]=((C_word)li536),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3093: mapsafe */
t4=((C_word*)((C_word*)t0)[4])[1];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
av2[3]=((C_word*)t0)[5];
av2[4]=lf[706];
((C_proc)C_fast_retrieve_proc(t4))(5,av2);}}

/* k19089 in k19082 in k19073 in loop in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_19091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19091,c,av);}
/* library.scm:3093: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19068(t2,((C_word*)t0)[3],t1);}

/* a19092 in k19082 in k19073 in loop in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_19093(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19093,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a19098 in loop in scheme#for-each in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19099,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19105(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +14,c,3)))){
C_save_and_reclaim((void*)f_19105,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+14);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
if(C_truep(C_rest_nullp(c,4))){
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=C_i_check_list_2(t3,lf[708]);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19123,a[2]=t7,a[3]=t11,a[4]=t2,a[5]=t8,a[6]=((C_word)li540),tmp=(C_word)a,a+=7,tmp));
t13=((C_word*)t11)[1];
f_19123(t13,t1,t3);}
else{
t5=C_a_i_cons(&a,2,t3,t4);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19164,a[2]=t7,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word)li543),tmp=(C_word)a,a+=6,tmp));
t9=((C_word*)t7)[1];
f_19164(t9,t1,t5);}}

/* map-loop3792 in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_19123(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19123,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19148,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:3098: g3798 */
t4=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19146 in map-loop3792 in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19148,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_19123(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* loop in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_19164(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_19164,3,t0,t1,t2);}
a=C_alloc(10);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19171,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19200,a[2]=((C_word)li542),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3101: mapsafe */
t5=((C_word*)((C_word*)t0)[3])[1];{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
av2[3]=t2;
av2[4]=lf[708];
((C_proc)C_fast_retrieve_proc(t5))(5,av2);}}

/* k19169 in loop in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_19171,c,av);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t1))){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19184,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=t1;
C_apply(4,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19182 in k19169 in loop in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19184(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_19184,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19188,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19192,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19194,a[2]=((C_word)li541),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3104: mapsafe */
t5=((C_word*)((C_word*)t0)[4])[1];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
av2[3]=((C_word*)t0)[5];
av2[4]=lf[708];
((C_proc)C_fast_retrieve_proc(t5))(5,av2);}}

/* k19186 in k19182 in k19169 in loop in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_19188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_19188,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k19190 in k19182 in k19169 in loop in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_19192(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19192,c,av);}
/* library.scm:3104: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19164(t2,((C_word*)t0)[3],t1);}

/* a19193 in k19182 in k19169 in loop in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_19194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19194,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a19199 in loop in scheme#map in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19200,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#dynamic-wind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_19207,c,av);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19211,a[2]=t2,a[3]=t4,a[4]=t1,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* library.scm:3124: before */
t6=t2;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)C_fast_retrieve_proc(t6))(2,av2);}}

/* k19209 in scheme#dynamic-wind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_19211,c,av);}
a=C_alloc(10);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,t2,C_fast_retrieve(lf[709]));
t4=C_mutate((C_word*)lf[709]+1 /* (set! ##sys#dynamic-winds ...) */,t3);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19220,a[2]=((C_word*)t0)[3],a[3]=((C_word)li545),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3126: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=t5;
C_call_with_values(4,av2);}}

/* a19219 in k19209 in scheme#dynamic-wind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_19220,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
t3=C_slot(C_fast_retrieve(lf[709]),C_fix(1));
t4=C_mutate((C_word*)lf[709]+1 /* (set! ##sys#dynamic-winds ...) */,t3);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19228,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3130: after */
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)C_fast_retrieve_proc(t6))(2,av2);}}

/* k19226 in a19219 in k19209 in scheme#dynamic-wind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19228(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19228,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
C_apply_values(3,av2);}}

/* scheme#call-with-current-continuation in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19238(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_19238,c,av);}
a=C_alloc(5);
t3=C_fast_retrieve(lf[709]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19244,a[2]=t3,a[3]=t2,a[4]=((C_word)li548),tmp=(C_word)a,a+=5,tmp);
/* library.scm:3138: ##sys#call-with-current-continuation */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t4;
C_call_cc(3,av2);}}

/* a19243 in scheme#call-with-current-continuation in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_19244,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19247,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word)li547),tmp=(C_word)a,a+=5,tmp);
/* library.scm:3144: proc */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}

/* continuation in a19243 in scheme#call-with-current-continuation in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_19247,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+5);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19251,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_eqp(C_fast_retrieve(lf[709]),((C_word*)t0)[3]);
if(C_truep(t4)){{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
C_apply(4,av2);}}
else{
t5=C_i_length(C_fast_retrieve(lf[709]));
t6=C_i_length(((C_word*)t0)[3]);
/* library.scm:3142: ##sys#dynamic-unwind */
f_19278(t3,((C_word*)t0)[3],C_fixnum_difference(t5,t6));}}

/* k19249 in continuation in a19243 in scheme#call-with-current-continuation in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19251(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19251,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
C_apply(4,av2);}}

/* ##sys#dynamic-unwind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_19278(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_19278,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_eqp(C_fast_retrieve(lf[709]),t2);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_lessp(t3,C_fix(0)))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19294,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3151: ##sys#dynamic-unwind */
t11=t5;
t12=C_slot(t2,C_fix(1));
t13=C_fixnum_plus(t3,C_fix(1));
t1=t11;
t2=t12;
t3=t13;
goto loop;}
else{
t5=C_slot(C_fast_retrieve(lf[709]),C_fix(0));
t6=C_slot(t5,C_fix(1));
t7=C_slot(C_fast_retrieve(lf[709]),C_fix(1));
t8=C_mutate((C_word*)lf[709]+1 /* (set! ##sys#dynamic-winds ...) */,t7);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19323,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3157: after */
t10=t6;{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)C_fast_retrieve_proc(t10))(2,av2);}}}}

/* k19292 in ##sys#dynamic-unwind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_19294,c,av);}
a=C_alloc(4);
t2=C_slot(((C_word*)t0)[2],C_fix(0));
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19300,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3149: g3852 */
t5=t3;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)C_fast_retrieve_proc(t5))(2,av2);}}

/* k19298 in k19292 in ##sys#dynamic-unwind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19300(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19300,c,av);}
t2=C_mutate((C_word*)lf[709]+1 /* (set! ##sys#dynamic-winds ...) */,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k19321 in ##sys#dynamic-unwind in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19323,c,av);}
/* library.scm:3158: ##sys#dynamic-unwind */
f_19278(((C_word*)t0)[2],((C_word*)t0)[3],C_fixnum_difference(((C_word*)t0)[4],C_fix(1)));}

/* chicken.base#port? in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19336(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19336,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(C_blockp(t2))?C_portp(t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#input-port-open? in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19342(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19342,c,av);}
t3=C_i_check_port(t2,C_fix(1),lf[712]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_input_port_openp(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.base#output-port-open? in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19347(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19347,c,av);}
t3=C_i_check_port(t2,C_fix(2),lf[713]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_output_port_openp(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.base#port-closed? in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19352(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_19352,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19356,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3180: ##sys#check-port */
t4=*((C_word*)lf[714]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[715];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k19354 in chicken.base#port-closed? in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19356(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19356,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_eqp(C_slot(((C_word*)t0)[3],C_fix(8)),C_fix(0));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#make-port in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19365(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(17,c,1)))){
C_save_and_reclaim((void *)f_19365,c,av);}
a=C_alloc(17);
t6=C_a_i_port(&a,0);
t7=C_i_set_i_slot(t6,C_fix(1),t2);
t8=C_i_setslot(t6,C_fix(2),t3);
t9=C_i_setslot(t6,C_fix(3),t4);
t10=C_i_set_i_slot(t6,C_fix(4),C_fix(1));
t11=C_i_set_i_slot(t6,C_fix(5),C_fix(0));
t12=C_i_setslot(t6,C_fix(7),t5);
t13=C_i_setslot(t6,C_fix(8),t2);
t14=t1;{
C_word *av2=av;
av2[0]=t14;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}

/* k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19396(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_19396,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[732]+1 /* (set! ##sys#standard-input ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19400,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3330: ##sys#make-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[716]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[716]+1);
av2[1]=t3;
av2[2]=C_fix(2);
av2[3]=C_fast_retrieve(lf[730]);
av2[4]=lf[1429];
av2[5]=lf[749];
tp(6,av2);}}

/* k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_19400,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[733]+1 /* (set! ##sys#standard-output ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19404,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3331: ##sys#make-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[716]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[716]+1);
av2[1]=t3;
av2[2]=C_fix(2);
av2[3]=C_fast_retrieve(lf[730]);
av2[4]=lf[1428];
av2[5]=lf[749];
tp(6,av2);}}

/* k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19404(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_19404,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[734]+1 /* (set! ##sys#standard-error ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19407,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3333: ##sys#open-file-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[731]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[731]+1);
av2[1]=t3;
av2[2]=*((C_word*)lf[732]+1);
av2[3]=C_fix(0);
av2[4]=C_SCHEME_FALSE;
tp(5,av2);}}

/* k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_19407(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_19407,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19410,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3334: ##sys#open-file-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[731]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[731]+1);
av2[1]=t2;
av2[2]=*((C_word*)lf[733]+1);
av2[3]=C_fix(1);
av2[4]=C_SCHEME_FALSE;
tp(5,av2);}}

/* k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_19410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_19410,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19413,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3335: ##sys#open-file-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[731]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[731]+1);
av2[1]=t2;
av2[2]=*((C_word*)lf[734]+1);
av2[3]=C_fix(2);
av2[4]=C_SCHEME_FALSE;
tp(5,av2);}}

/* k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in ... */
static void C_ccall f_19413(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(119,c,6)))){
C_save_and_reclaim((void *)f_19413,c,av);}
a=C_alloc(119);
t2=C_mutate((C_word*)lf[735]+1 /* (set! ##sys#check-input-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19415,a[2]=((C_word)li572),tmp=(C_word)a,a+=3,tmp));
t3=C_mutate((C_word*)lf[736]+1 /* (set! ##sys#check-output-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19426,a[2]=((C_word)li573),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[714]+1 /* (set! ##sys#check-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19437,a[2]=((C_word)li574),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[737]+1 /* (set! ##sys#check-open-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19448,a[2]=((C_word)li575),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[135]+1 /* (set! scheme#current-input-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19459,a[2]=((C_word)li577),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[136]+1 /* (set! scheme#current-output-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19520,a[2]=((C_word)li579),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[192]+1 /* (set! chicken.base#current-error-port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19581,a[2]=((C_word)li581),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[741]+1 /* (set! ##sys#tty-port? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19642,a[2]=((C_word)li582),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[743]+1 /* (set! ##sys#port-data ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19656,a[2]=((C_word)li583),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[744]+1 /* (set! ##sys#set-port-data! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19662,a[2]=((C_word)li584),tmp=(C_word)a,a+=3,tmp));
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19668,a[2]=((C_word)li586),tmp=(C_word)a,a+=3,tmp));
t17=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19767,a[2]=((C_word)li587),tmp=(C_word)a,a+=3,tmp));
t18=C_mutate((C_word*)lf[137]+1 /* (set! scheme#open-input-file ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19804,a[2]=t13,a[3]=((C_word)li588),tmp=(C_word)a,a+=4,tmp));
t19=C_mutate((C_word*)lf[138]+1 /* (set! scheme#open-output-file ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19810,a[2]=t13,a[3]=((C_word)li589),tmp=(C_word)a,a+=4,tmp));
t20=C_mutate((C_word*)lf[139]+1 /* (set! scheme#close-input-port ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19816,a[2]=t15,a[3]=((C_word)li590),tmp=(C_word)a,a+=4,tmp));
t21=C_mutate((C_word*)lf[140]+1 /* (set! scheme#close-output-port ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19822,a[2]=t15,a[3]=((C_word)li591),tmp=(C_word)a,a+=4,tmp));
t22=*((C_word*)lf[137]+1);
t23=C_mutate((C_word*)lf[141]+1 /* (set! scheme#call-with-input-file ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19828,a[2]=t22,a[3]=((C_word)li594),tmp=(C_word)a,a+=4,tmp));
t24=*((C_word*)lf[138]+1);
t25=C_mutate((C_word*)lf[142]+1 /* (set! scheme#call-with-output-file ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19852,a[2]=t24,a[3]=((C_word)li597),tmp=(C_word)a,a+=4,tmp));
t26=*((C_word*)lf[137]+1);
t27=C_mutate((C_word*)lf[143]+1 /* (set! scheme#with-input-from-file ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19876,a[2]=t26,a[3]=((C_word)li602),tmp=(C_word)a,a+=4,tmp));
t28=*((C_word*)lf[138]+1);
t29=C_mutate((C_word*)lf[144]+1 /* (set! scheme#with-output-to-file ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19910,a[2]=t28,a[3]=((C_word)li607),tmp=(C_word)a,a+=4,tmp));
t30=C_mutate((C_word*)lf[762]+1 /* (set! ##sys#file-exists? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19944,a[2]=((C_word)li608),tmp=(C_word)a,a+=3,tmp));
t31=C_mutate((C_word*)lf[765]+1 /* (set! ##sys#flush-output ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19970,a[2]=((C_word)li609),tmp=(C_word)a,a+=3,tmp));
t32=C_mutate((C_word*)lf[216]+1 /* (set! chicken.base#flush-output ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19983,a[2]=((C_word)li610),tmp=(C_word)a,a+=3,tmp));
t33=C_mutate((C_word*)lf[767]+1 /* (set! ##sys#port-line ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20001,a[2]=((C_word)li611),tmp=(C_word)a,a+=3,tmp));
t34=C_mutate((C_word*)lf[768]+1 /* (set! ##sys#decorate-lambda ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20010,a[2]=((C_word)li614),tmp=(C_word)a,a+=3,tmp));
t35=C_mutate((C_word*)lf[769]+1 /* (set! ##sys#lambda-decoration ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20085,a[2]=((C_word)li616),tmp=(C_word)a,a+=3,tmp));
t36=C_mutate((C_word*)lf[770]+1 /* (set! ##sys#make-lambda-info ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20124,a[2]=((C_word)li617),tmp=(C_word)a,a+=3,tmp));
t37=C_mutate((C_word*)lf[771]+1 /* (set! ##sys#lambda-info? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20133,a[2]=((C_word)li618),tmp=(C_word)a,a+=3,tmp));
t38=C_mutate((C_word*)lf[772]+1 /* (set! ##sys#lambda-info ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20146,a[2]=((C_word)li619),tmp=(C_word)a,a+=3,tmp));
t39=C_mutate((C_word*)lf[773]+1 /* (set! ##sys#lambda-info->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20152,a[2]=((C_word)li620),tmp=(C_word)a,a+=3,tmp));
t40=C_mutate((C_word*)lf[202]+1 /* (set! chicken.base#procedure-information ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20161,a[2]=((C_word)li621),tmp=(C_word)a,a+=3,tmp));
t41=C_a_i_vector1(&a,1,lf[776]);
t42=C_mutate(&lf[777] /* (set! setter-tag ...) */,t41);
t43=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20190,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t44=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32879,a[2]=((C_word)li1035),tmp=(C_word)a,a+=3,tmp);
t45=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32919,a[2]=((C_word)li1036),tmp=(C_word)a,a+=3,tmp);
t46=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32935,a[2]=((C_word)li1040),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3565: ##sys#decorate-lambda */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[768]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[768]+1);
av2[1]=t43;
av2[2]=t44;
av2[3]=t45;
av2[4]=t46;
tp(5,av2);}}

/* ##sys#check-input-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_19415,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+0);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=C_i_pairp(t4);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t5)?C_i_check_port_2(t2,C_fix(1),t3,C_get_rest_arg(c,4,av,4,t0)):C_i_check_port(t2,C_fix(1),t3));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* ##sys#check-output-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_19426,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+0);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=C_i_pairp(t4);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=(C_truep(t5)?C_i_check_port_2(t2,C_fix(2),t3,C_get_rest_arg(c,4,av,4,t0)):C_i_check_port(t2,C_fix(2),t3));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* ##sys#check-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19437(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_19437,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_port_2(t2,C_fix(0),C_SCHEME_FALSE,C_get_rest_arg(c,3,av,3,t0)):C_i_check_port(t2,C_fix(0),C_SCHEME_FALSE));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#check-open-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19448(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_19448,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=C_i_pairp(t3);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_check_port_2(t2,C_fix(0),C_SCHEME_TRUE,C_get_rest_arg(c,3,av,3,t0)):C_i_check_port(t2,C_fix(0),C_SCHEME_TRUE));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#current-input-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_19459,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+5);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
if(C_truep(C_i_nullp(t2))){
t3=*((C_word*)lf[732]+1);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=*((C_word*)lf[732]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19472,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3362: ##sys#check-port */
t5=*((C_word*)lf[714]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
av2[3]=lf[738];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k19470 in scheme#current-input-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19472(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_19472,c,av);}
a=C_alloc(10);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19474,a[2]=((C_word*)t0)[3],a[3]=((C_word)li576),tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19480,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19485,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_nullp(t2))){
t6=(
/* library.scm:3363: def-convert?3978 */
  f_19485(t5)
);
t7=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=C_i_car(t2);
t7=C_u_i_cdr(t2);
if(C_truep(C_i_nullp(t7))){
t8=(
/* library.scm:3363: def-set?3979 */
  f_19480(t4)
);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=C_i_car(t7);
t9=C_u_i_cdr(t7);
t10=(
/* library.scm:3363: body3976 */
  f_19474(t3,t8)
);
t11=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t11;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}

/* body3976 in k19470 in scheme#current-input-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19474(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
if(C_truep(t1)){
t2=C_mutate((C_word*)lf[732]+1 /* (set! ##sys#standard-input ...) */,((C_word*)t0)[2]);
return(t2);}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* def-set?3979 in k19470 in scheme#current-input-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19480(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:3363: body3976 */
  f_19474(((C_word*)t0)[2],C_SCHEME_TRUE)
));}

/* def-convert?3978 in k19470 in scheme#current-input-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19485(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:3363: def-set?3979 */
  f_19480(((C_word*)t0)[2])
));}

/* scheme#current-output-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_19520,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+5);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
if(C_truep(C_i_nullp(t2))){
t3=*((C_word*)lf[733]+1);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=*((C_word*)lf[733]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19533,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3372: ##sys#check-port */
t5=*((C_word*)lf[714]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
av2[3]=lf[739];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k19531 in scheme#current-output-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_19533,c,av);}
a=C_alloc(10);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19535,a[2]=((C_word*)t0)[3],a[3]=((C_word)li578),tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19541,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19546,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_nullp(t2))){
t6=(
/* library.scm:3373: def-convert?4003 */
  f_19546(t5)
);
t7=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=C_i_car(t2);
t7=C_u_i_cdr(t2);
if(C_truep(C_i_nullp(t7))){
t8=(
/* library.scm:3373: def-set?4004 */
  f_19541(t4)
);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=C_i_car(t7);
t9=C_u_i_cdr(t7);
t10=(
/* library.scm:3373: body4001 */
  f_19535(t3,t8)
);
t11=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t11;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}

/* body4001 in k19531 in scheme#current-output-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19535(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
if(C_truep(t1)){
t2=C_mutate((C_word*)lf[733]+1 /* (set! ##sys#standard-output ...) */,((C_word*)t0)[2]);
return(t2);}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* def-set?4004 in k19531 in scheme#current-output-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19541(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:3373: body4001 */
  f_19535(((C_word*)t0)[2],C_SCHEME_TRUE)
));}

/* def-convert?4003 in k19531 in scheme#current-output-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19546(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:3373: def-set?4004 */
  f_19541(((C_word*)t0)[2])
));}

/* chicken.base#current-error-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_19581,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+5);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
if(C_truep(C_i_nullp(t2))){
t3=*((C_word*)lf[734]+1);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19594,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3382: ##sys#check-port */
t5=*((C_word*)lf[714]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
av2[3]=lf[740];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k19592 in chicken.base#current-error-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19594(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_19594,c,av);}
a=C_alloc(10);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19596,a[2]=((C_word*)t0)[3],a[3]=((C_word)li580),tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19602,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19607,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_nullp(t2))){
t6=(
/* library.scm:3383: def-convert?4028 */
  f_19607(t5)
);
t7=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=C_i_car(t2);
t7=C_u_i_cdr(t2);
if(C_truep(C_i_nullp(t7))){
t8=(
/* library.scm:3383: def-set?4029 */
  f_19602(t4)
);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=C_i_car(t7);
t9=C_u_i_cdr(t7);
t10=(
/* library.scm:3383: body4026 */
  f_19596(t3,t8)
);
t11=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t11;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}

/* body4026 in k19592 in chicken.base#current-error-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19596(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
if(C_truep(t1)){
t2=C_mutate((C_word*)lf[734]+1 /* (set! ##sys#standard-error ...) */,((C_word*)t0)[2]);
return(t2);}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* def-set?4029 in k19592 in chicken.base#current-error-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19602(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:3383: body4026 */
  f_19596(((C_word*)t0)[2],C_SCHEME_TRUE)
));}

/* def-convert?4028 in k19592 in chicken.base#current-error-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static C_word C_fcall f_19607(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:3383: def-set?4029 */
  f_19602(((C_word*)t0)[2])
));}

/* ##sys#tty-port? in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_19642,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19654,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3388: ##sys#peek-unsigned-integer */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[742]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[742]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=C_fix(0);
tp(4,av2);}}

/* k19652 in ##sys#tty-port? in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19654(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19654,c,av);}
t2=C_i_not(C_i_zerop(t1));
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?C_tty_portp(((C_word*)t0)[3]):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#port-data in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19656,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_slot(t2,C_fix(9));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#set-port-data! in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19662(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19662,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_setslot(t2,C_fix(9),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_fcall f_19668(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,0,3)))){
C_save_and_reclaim_args((void *)trf_19668,5,t1,t2,t3,t4,t5);}
a=C_alloc(22);
t6=C_i_check_string_2(t2,t5);
t7=(C_truep(t3)?lf[745]:lf[746]);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=lf[747];
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19678,a[2]=t1,a[3]=t5,a[4]=t2,a[5]=t9,a[6]=t11,a[7]=t3,tmp=(C_word)a,a+=8,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19712,a[2]=t14,a[3]=t11,a[4]=t3,a[5]=t5,a[6]=t9,a[7]=((C_word)li585),tmp=(C_word)a,a+=8,tmp));
t16=((C_word*)t14)[1];
f_19712(t16,t12,t4);}

/* k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19678(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_19678,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19681,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[7])){
/* library.scm:3410: ##sys#make-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[716]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[716]+1);
av2[1]=t2;
av2[2]=C_fix(1);
av2[3]=C_fast_retrieve(lf[730]);
av2[4]=((C_word*)t0)[4];
av2[5]=lf[749];
tp(6,av2);}}
else{
/* library.scm:3410: ##sys#make-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[716]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[716]+1);
av2[1]=t2;
av2[2]=C_fix(2);
av2[3]=C_fast_retrieve(lf[730]);
av2[4]=((C_word*)t0)[4];
av2[5]=lf[749];
tp(6,av2);}}}

/* k19679 in k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_19681,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19684,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19687,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19706,a[2]=t3,a[3]=t1,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3411: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
av2[3]=((C_word*)((C_word*)t0)[6])[1];
tp(4,av2);}}

/* k19682 in k19679 in k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_19684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19684,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k19685 in k19679 in k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_19687(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_19687,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19694,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3412: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word *av2=av;
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t2;
tp(2,av2);}}}

/* k19692 in k19685 in k19679 in k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in ... */
static void C_ccall f_19694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_19694,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19698,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19702,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t4=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_mpointer(&a,(void*)strerror(errno));
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k19696 in k19692 in k19685 in k19679 in k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in ... */
static void C_ccall f_19698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_19698,c,av);}
/* library.scm:3412: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[718];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
av2[5]=t1;
av2[6]=((C_word*)t0)[5];
tp(7,av2);}}

/* k19700 in k19692 in k19685 in k19679 in k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in ... */
static void C_ccall f_19702(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19702,c,av);}
/* library.scm:3413: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[748];
av2[3]=t1;
tp(4,av2);}}

/* k19704 in k19679 in k19676 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_19706(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19706,c,av);}
/* library.scm:3411: ##sys#open-file-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[731]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[731]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
tp(5,av2);}}

/* doloop4063 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_fcall f_19712(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_19712,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19725,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=C_eqp(t3,lf[750]);
if(C_truep(t5)){
t6=C_mutate(((C_word *)((C_word*)t0)[3])+1,lf[751]);
t10=t1;
t11=C_slot(t2,C_fix(1));
t1=t10;
t2=t11;
goto loop;}
else{
t6=C_eqp(t3,lf[752]);
if(C_truep(t6)){
t7=C_mutate(((C_word *)((C_word*)t0)[3])+1,lf[753]);
t10=t1;
t11=C_slot(t2,C_fix(1));
t1=t10;
t2=t11;
goto loop;}
else{
t7=C_eqp(t3,lf[754]);
if(C_truep(t7)){
if(C_truep(((C_word*)t0)[4])){
/* library.scm:3407: ##sys#error */
t8=*((C_word*)lf[155]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[755];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
t8=C_mutate(((C_word *)((C_word*)t0)[6])+1,lf[756]);
t10=t1;
t11=C_slot(t2,C_fix(1));
t1=t10;
t2=t11;
goto loop;}}
else{
/* library.scm:3409: ##sys#error */
t8=*((C_word*)lf[155]+1);{
C_word av2[5];
av2[0]=t8;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[757];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}}}}}

/* k19723 in doloop4063 in open in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19725(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19725,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_19712(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* close in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_fcall f_19767(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_19767,4,t1,t2,t3,t4);}
a=C_alloc(5);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19771,a[2]=t3,a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3418: ##sys#check-port */
t6=*((C_word*)lf[714]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k19769 in close in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19771,c,av);}
t2=(C_truep(((C_word*)t0)[2])?C_fix(1):C_fix(2));
if(C_truep(C_port_openp(((C_word*)t0)[3],t2))){
t3=C_slot(((C_word*)t0)[3],C_fix(8));
t4=C_fixnum_not(t2);
t5=C_fixnum_and(t3,t4);
t6=C_i_set_i_slot(((C_word*)t0)[3],C_fix(8),t5);
t7=C_slot(((C_word*)t0)[3],C_fix(2));
/* library.scm:3421: g4083 */
t8=C_slot(t7,C_fix(4));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t8;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)C_fast_retrieve_proc(t8))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* scheme#open-input-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19804(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,5)))){
C_save_and_reclaim((void*)f_19804,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
/* library.scm:3425: open */
f_19668(t1,t2,C_SCHEME_TRUE,t3,lf[758]);}

/* scheme#open-output-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19810(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +0,c,5)))){
C_save_and_reclaim((void*)f_19810,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+0);
t3=C_build_rest(&a,c,3,av);
C_word t4;
/* library.scm:3426: open */
f_19668(t1,t2,C_SCHEME_FALSE,t3,lf[759]);}

/* scheme#close-input-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19816(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19816,c,av);}
/* library.scm:3427: close */
f_19767(t1,t2,C_SCHEME_TRUE,lf[760]);}

/* scheme#close-output-port in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19822,c,av);}
/* library.scm:3428: close */
f_19767(t1,t2,C_SCHEME_FALSE,lf[761]);}

/* scheme#call-with-input-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_19828,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+4);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19832,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t4;
C_apply(5,av2);}}

/* k19830 in scheme#call-with-input-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_19832,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19837,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li592),tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19843,a[2]=t1,a[3]=((C_word)li593),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3435: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a19836 in k19830 in scheme#call-with-input-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19837(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19837,c,av);}
/* library.scm:3436: p */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* a19842 in k19830 in scheme#call-with-input-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_19843,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19847,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3438: close-input-port */
t4=*((C_word*)lf[139]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19845 in a19842 in k19830 in scheme#call-with-input-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_19847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19847,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
C_apply_values(3,av2);}}

/* scheme#call-with-output-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_19852,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+4);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19856,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t4;
C_apply(5,av2);}}

/* k19854 in scheme#call-with-output-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_19856,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19861,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word)li595),tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19867,a[2]=t1,a[3]=((C_word)li596),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3446: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a19860 in k19854 in scheme#call-with-output-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19861(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19861,c,av);}
/* library.scm:3447: p */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* a19866 in k19854 in scheme#call-with-output-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19867(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_19867,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19871,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3449: close-output-port */
t4=*((C_word*)lf[140]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19869 in a19866 in k19854 in scheme#call-with-output-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_19871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19871,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
C_apply_values(3,av2);}}

/* scheme#with-input-from-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19876(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_19876,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+4);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19880,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t4;
C_apply(5,av2);}}

/* k19878 in scheme#with-input-from-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19880(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,4)))){
C_save_and_reclaim((void *)f_19880,c,av);}
a=C_alloc(19);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19885,a[2]=t5,a[3]=t3,a[4]=((C_word)li598),tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19890,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word)li600),tmp=(C_word)a,a+=5,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19905,a[2]=t3,a[3]=t5,a[4]=((C_word)li601),tmp=(C_word)a,a+=5,tmp);
/* library.scm:3457: ##sys#dynamic-wind */
t9=*((C_word*)lf[710]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a19884 in k19878 in scheme#with-input-from-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19885,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[732]+1));
t3=C_mutate((C_word*)lf[732]+1 /* (set! ##sys#standard-input ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a19889 in k19878 in scheme#with-input-from-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19890(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_19890,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19896,a[2]=((C_word*)t0)[2],a[3]=((C_word)li599),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3458: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
C_call_with_values(4,av2);}}

/* a19895 in a19889 in k19878 in scheme#with-input-from-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_19896(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_19896,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19900,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3460: close-input-port */
t4=*((C_word*)lf[139]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19898 in a19895 in a19889 in k19878 in scheme#with-input-from-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in ... */
static void C_ccall f_19900(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19900,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
C_apply_values(3,av2);}}

/* a19904 in k19878 in scheme#with-input-from-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19905,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[732]+1));
t3=C_mutate((C_word*)lf[732]+1 /* (set! ##sys#standard-input ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#with-output-to-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19910(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +4,c,4)))){
C_save_and_reclaim((void*)f_19910,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+4);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19914,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t4;
C_apply(5,av2);}}

/* k19912 in scheme#with-output-to-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,4)))){
C_save_and_reclaim((void *)f_19914,c,av);}
a=C_alloc(19);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19919,a[2]=t5,a[3]=t3,a[4]=((C_word)li603),tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19924,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word)li605),tmp=(C_word)a,a+=5,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19939,a[2]=t3,a[3]=t5,a[4]=((C_word)li606),tmp=(C_word)a,a+=5,tmp);
/* library.scm:3468: ##sys#dynamic-wind */
t9=*((C_word*)lf[710]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a19918 in k19912 in scheme#with-output-to-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19919,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[733]+1));
t3=C_mutate((C_word*)lf[733]+1 /* (set! ##sys#standard-output ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a19923 in k19912 in scheme#with-output-to-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_19924,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19930,a[2]=((C_word*)t0)[2],a[3]=((C_word)li604),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3469: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
C_call_with_values(4,av2);}}

/* a19929 in a19923 in k19912 in scheme#with-output-to-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_19930(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_19930,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19934,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3471: close-output-port */
t4=*((C_word*)lf[140]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19932 in a19929 in a19923 in k19912 in scheme#with-output-to-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in ... */
static void C_ccall f_19934(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19934,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
C_apply_values(3,av2);}}

/* a19938 in k19912 in scheme#with-output-to-file in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_19939(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19939,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[733]+1));
t3=C_mutate((C_word*)lf[733]+1 /* (set! ##sys#standard-output ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#file-exists? in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_19944,c,av);}
a=C_alloc(7);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19949,a[2]=t3,a[3]=t4,a[4]=t1,a[5]=t5,a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* library.scm:3475: ##sys#make-c-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[764]);
C_word *av2=av;
av2[0]=*((C_word*)lf[764]+1);
av2[1]=t6;
av2[2]=t2;
av2[3]=t5;
tp(4,av2);}}

/* k19947 in ##sys#file-exists? in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_19949,c,av);}
t2=C_i_file_exists_p(t1,((C_word*)t0)[2],((C_word*)t0)[3]);
switch(t2){
case C_SCHEME_FALSE:
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
case C_SCHEME_TRUE:
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}
default:
/* library.scm:3479: ##sys#signal-hook */
t3=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[718];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[763];
av2[5]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}}

/* ##sys#flush-output in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19970(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19970,c,av);}
a=C_alloc(3);
t3=C_slot(t2,C_fix(2));
t4=C_slot(t3,C_fix(5));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19977,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:3483: g4163 */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)C_fast_retrieve_proc(t6))(3,av2);}}

/* k19975 in ##sys#flush-output in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_19977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19977,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#flush-output in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_19983(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19983,c,av);}
if(C_truep(C_rest_nullp(c,2))){
t2=*((C_word*)lf[733]+1);
t3=C_i_check_port_2(*((C_word*)lf[733]+1),C_fix(2),C_SCHEME_TRUE,lf[766]);
/* library.scm:3490: ##sys#flush-output */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[765]);
C_word av2[3];
av2[0]=*((C_word*)lf[765]+1);
av2[1]=t1;
av2[2]=*((C_word*)lf[733]+1);
tp(3,av2);}}
else{
t2=C_get_rest_arg(c,2,av,2,t0);
t3=C_i_check_port_2(t2,C_fix(2),C_SCHEME_TRUE,lf[766]);
/* library.scm:3490: ##sys#flush-output */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[765]);
C_word av2[3];
av2[0]=*((C_word*)lf[765]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}}

/* ##sys#port-line in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20001,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(C_input_portp(t2))?C_slot(t2,C_fix(4)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#decorate-lambda in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_20010,c,av);}
a=C_alloc(10);
t5=C_block_size(t2);
t6=C_fixnum_difference(t5,C_fix(1));
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20023,a[2]=t5,a[3]=t2,a[4]=t4,a[5]=t8,a[6]=t3,a[7]=((C_word)li613),tmp=(C_word)a,a+=8,tmp));
t10=((C_word*)t8)[1];
f_20023(t10,t1,t6);}

/* loop in ##sys#decorate-lambda in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_fcall f_20023(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_20023,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_zerop(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20031,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:3504: scheme#make-vector */
t4=*((C_word*)lf[93]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_fixnum_plus(((C_word*)t0)[2],C_fix(1));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_slot(((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20073,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3513: pred */
t5=((C_word*)t0)[6];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t5))(3,av2);}}}

/* k20029 in loop in ##sys#decorate-lambda in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_20031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_20031,c,av);}
a=C_alloc(10);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20036,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t3,a[7]=((C_word)li612),tmp=(C_word)a,a+=8,tmp));
t5=((C_word*)t3)[1];
f_20036(t5,((C_word*)t0)[5],C_fix(1));}

/* doloop4192 in k20029 in loop in ##sys#decorate-lambda in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_fcall f_20036(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_20036,3,t0,t1,t2);}
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=C_vector_to_closure(((C_word*)t0)[3]);
t4=C_copy_pointer(((C_word*)t0)[4],((C_word*)t0)[3]);
/* library.scm:3509: decorator */
t5=((C_word*)t0)[5];{
C_word av2[4];
av2[0]=t5;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)C_fast_retrieve_proc(t5))(4,av2);}}
else{
t3=C_slot(((C_word*)t0)[4],t2);
t4=C_i_setslot(((C_word*)t0)[3],t2,t3);
t6=t1;
t7=C_fixnum_plus(t2,C_fix(1));
t1=t6;
t2=t7;
goto loop;}}

/* k20071 in loop in ##sys#decorate-lambda in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_20073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20073,c,av);}
if(C_truep(t1)){
/* library.scm:3514: decorator */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}
else{
/* library.scm:3515: loop */
t2=((C_word*)((C_word*)t0)[6])[1];
f_20023(t2,((C_word*)t0)[3],C_fixnum_difference(((C_word*)t0)[5],C_fix(1)));}}

/* ##sys#lambda-decoration in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_20085,c,av);}
a=C_alloc(8);
t4=C_block_size(t2);
t5=C_fixnum_difference(t4,C_fix(1));
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20095,a[2]=t2,a[3]=t7,a[4]=t3,a[5]=((C_word)li615),tmp=(C_word)a,a+=6,tmp));
t9=((C_word*)t7)[1];
f_20095(t9,t1,t5);}

/* loop in ##sys#lambda-decoration in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_fcall f_20095(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20095,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_fixnum_greaterp(t2,C_fix(0)))){
t3=C_slot(((C_word*)t0)[2],t2);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20111,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:3521: pred */
t5=((C_word*)t0)[4];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t5))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20109 in loop in ##sys#lambda-decoration in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_20111(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20111,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* library.scm:3523: loop */
t2=((C_word*)((C_word*)t0)[4])[1];
f_20095(t2,((C_word*)t0)[2],C_fixnum_difference(((C_word*)t0)[5],C_fix(1)));}}

/* ##sys#make-lambda-info in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_20124,c,av);}
a=C_alloc(5);
t3=C_block_size(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20131,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3530: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}

/* k20129 in ##sys#make-lambda-info in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_20131(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20131,c,av);}
t2=C_copy_memory(t1,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_string_to_lambdainfo(t1);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#lambda-info? in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20133,c,av);}
t3=C_immp(t2);
t4=C_i_not(t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?C_lambdainfop(t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#lambda-info in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20146(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20146,c,av);}
/* library.scm:3542: ##sys#lambda-decoration */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[769]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[769]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_fast_retrieve(lf[771]);
tp(4,av2);}}

/* ##sys#lambda-info->string in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_20152,c,av);}
a=C_alloc(5);
t3=C_block_size(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20159,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3546: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}

/* k20157 in ##sys#lambda-info->string in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_20159(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20159,c,av);}
t2=C_copy_memory(t1,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#procedure-information in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_20161,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20165,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3552: ##sys#check-closure */
t4=*((C_word*)lf[374]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[775];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k20163 in chicken.base#procedure-information in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_20165(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20165,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20168,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3553: ##sys#lambda-info */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[772]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[772]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k20166 in k20163 in chicken.base#procedure-information in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_20168(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_20168,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20178,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20182,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:3554: ##sys#lambda-info->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[773]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[773]+1);
av2[1]=t3;
av2[2]=t1;
tp(3,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20176 in k20166 in k20163 in chicken.base#procedure-information in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_20178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20178,c,av);}
/* library.scm:3554: ##sys#read */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[774]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[774]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
tp(4,av2);}}

/* k20180 in k20166 in k20163 in chicken.base#procedure-information in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_20182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20182,c,av);}
/* library.scm:3554: chicken.base#open-input-string */
t2=*((C_word*)lf[214]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_20190(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20190,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[203]+1 /* (set! chicken.base#setter ...) */,t1);
t3=C_mutate((C_word*)lf[778]+1 /* (set! ##sys#setter ...) */,*((C_word*)lf[203]+1));
t4=C_mutate((C_word*)lf[200]+1 /* (set! chicken.base#getter-with-setter ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20193,a[2]=((C_word)li625),tmp=(C_word)a,a+=3,tmp));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20270,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3614: chicken.base#getter-with-setter */
t6=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=*((C_word*)lf[9]+1);
av2[3]=*((C_word*)lf[11]+1);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_20193(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_20193,c,av);}
a=C_alloc(6);
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?C_SCHEME_FALSE:C_get_rest_arg(c,4,av,4,t0));
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20200,a[2]=t1,a[3]=t3,a[4]=t2,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
/* library.scm:3593: ##sys#check-closure */
t7=*((C_word*)lf[374]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
av2[3]=lf[779];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_20200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_20200,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20203,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3594: ##sys#check-closure */
t3=*((C_word*)lf[374]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[779];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k20201 in k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_20203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_20203,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20206,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[5])){
t3=C_i_check_string_2(((C_word*)t0)[5],lf[779]);
/* library.scm:3597: ##sys#make-lambda-info */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[770]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[770]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}
else{
/* library.scm:3598: ##sys#lambda-info */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[772]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[772]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}}

/* k20204 in k20201 in k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in ... */
static void C_ccall f_20206(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_20206,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20209,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20225,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3600: ##sys#copy-closure */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[339]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[339]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k20207 in k20204 in k20201 in k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in ... */
static void C_ccall f_20209(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_20209,c,av);}
a=C_alloc(4);
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20217,a[2]=((C_word*)t0)[2],a[3]=((C_word)li622),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3606: ##sys#decorate-lambda */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[768]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[768]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=C_fast_retrieve(lf[771]);
av2[4]=t2;
tp(5,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* a20216 in k20207 in k20204 in k20201 in k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in ... */
static void C_ccall f_20217(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20217,c,av);}
t4=C_i_setslot(t2,t3,((C_word*)t0)[2]);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k20223 in k20204 in k20201 in k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in ... */
static void C_ccall f_20225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_20225,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20227,a[2]=((C_word)li623),tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20243,a[2]=((C_word*)t0)[2],a[3]=((C_word)li624),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3599: ##sys#decorate-lambda */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[768]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[768]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=t2;
av2[4]=t3;
tp(5,av2);}}

/* a20226 in k20223 in k20204 in k20201 in k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in ... */
static void C_ccall f_20227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20227,c,av);}
t3=C_i_pairp(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_eqp(C_retrieve2(lf[777],C_text("setter-tag")),C_slot(t2,C_fix(0))):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a20242 in k20223 in k20204 in k20201 in k20198 in chicken.base#getter-with-setter in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in ... */
static void C_ccall f_20243(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_20243,c,av);}
a=C_alloc(3);
t4=C_a_i_cons(&a,2,C_retrieve2(lf[777],C_text("setter-tag")),((C_word*)t0)[2]);
t5=C_i_setslot(t2,t3,t4);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_20270(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_20270,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[9]+1 /* (set! scheme#car ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20274,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3615: chicken.base#getter-with-setter */
t4=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[10]+1);
av2[3]=*((C_word*)lf[12]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_20274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20274,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[10]+1 /* (set! scheme#cdr ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20278,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32869,a[2]=((C_word)li1033),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3616: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[17]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_20278(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20278,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[17]+1 /* (set! scheme#caar ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20282,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32859,a[2]=((C_word)li1032),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3617: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[13]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in ... */
static void C_ccall f_20282(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20282,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[13]+1 /* (set! scheme#cadr ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20286,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32849,a[2]=((C_word)li1031),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3618: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[18]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in ... */
static void C_ccall f_20286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20286,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[18]+1 /* (set! scheme#cdar ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20290,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32839,a[2]=((C_word)li1030),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3619: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[19]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in ... */
static void C_ccall f_20290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20290,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[19]+1 /* (set! scheme#cddr ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20294,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32829,a[2]=((C_word)li1029),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3620: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[20]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in ... */
static void C_ccall f_20294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20294,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[20]+1 /* (set! scheme#caaar ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20298,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32819,a[2]=((C_word)li1028),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3621: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[21]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in ... */
static void C_ccall f_20298(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20298,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[21]+1 /* (set! scheme#caadr ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20302,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32809,a[2]=((C_word)li1027),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3622: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[22]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in ... */
static void C_ccall f_20302(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20302,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[22]+1 /* (set! scheme#cadar ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20306,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32799,a[2]=((C_word)li1026),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3623: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[14]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in ... */
static void C_ccall f_20306(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20306,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[14]+1 /* (set! scheme#caddr ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20310,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32789,a[2]=((C_word)li1025),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3624: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[23]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in ... */
static void C_ccall f_20310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20310,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[23]+1 /* (set! scheme#cdaar ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20314,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32779,a[2]=((C_word)li1024),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3625: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[24]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in ... */
static void C_ccall f_20314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20314,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[24]+1 /* (set! scheme#cdadr ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20318,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32769,a[2]=((C_word)li1023),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3626: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[25]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in ... */
static void C_ccall f_20318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20318,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[25]+1 /* (set! scheme#cddar ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20322,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32759,a[2]=((C_word)li1022),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3627: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[26]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in ... */
static void C_ccall f_20322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_20322,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[26]+1 /* (set! scheme#cdddr ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20326,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3628: chicken.base#getter-with-setter */
t4=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[58]+1);
av2[3]=*((C_word*)lf[59]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in ... */
static void C_ccall f_20326(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_20326,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[58]+1 /* (set! scheme#string-ref ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20330,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3629: chicken.base#getter-with-setter */
t4=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[91]+1);
av2[3]=*((C_word*)lf[92]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in ... */
static void C_ccall f_20330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_20330,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[91]+1 /* (set! scheme#vector-ref ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20334,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32749,a[2]=((C_word)li1021),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3632: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=*((C_word*)lf[45]+1);
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in ... */
static void C_ccall f_20334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(56,c,4)))){
C_save_and_reclaim((void *)f_20334,c,av);}
a=C_alloc(56);
t2=C_mutate((C_word*)lf[45]+1 /* (set! scheme#list-ref ...) */,t1);
t3=C_SCHEME_UNDEFINED;
t4=C_a_i_vector(&a,16,t3,t3,t3,t3,t3,t3,t3,t3,t3,t3,t3,t3,t3,t3,t3,t3);
t5=C_mutate(&lf[780] /* (set! ##sys#default-parameter-vector ...) */,t4);
t6=C_mutate((C_word*)lf[781]+1 /* (set! ##sys#current-parameter-vector ...) */,lf[782]);
t7=C_fix(0);
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_mutate((C_word*)lf[201]+1 /* (set! chicken.base#make-parameter ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20341,a[2]=t8,a[3]=((C_word)li633),tmp=(C_word)a,a+=4,tmp));
t10=C_mutate((C_word*)lf[146]+1 /* (set! scheme#char-ready? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20505,a[2]=((C_word)li634),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[147]+1 /* (set! scheme#read-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20530,a[2]=((C_word)li635),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate((C_word*)lf[784]+1 /* (set! ##sys#read-char-0 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20548,a[2]=((C_word)li636),tmp=(C_word)a,a+=3,tmp));
t13=C_mutate((C_word*)lf[785]+1 /* (set! ##sys#read-char/port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20608,a[2]=((C_word)li637),tmp=(C_word)a,a+=3,tmp));
t14=C_mutate((C_word*)lf[786]+1 /* (set! ##sys#peek-char-0 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20617,a[2]=((C_word)li638),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[148]+1 /* (set! scheme#peek-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20642,a[2]=((C_word)li639),tmp=(C_word)a,a+=3,tmp));
t16=C_mutate((C_word*)lf[149]+1 /* (set! scheme#read ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20660,a[2]=((C_word)li640),tmp=(C_word)a,a+=3,tmp));
t17=C_set_block_item(lf[788] /* ##sys#default-read-info-hook */,0,C_SCHEME_FALSE);
t18=C_set_block_item(lf[789] /* ##sys#read-error-with-line-number */,0,C_SCHEME_FALSE);
t19=C_mutate((C_word*)lf[790]+1 /* (set! ##sys#read-prompt-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20680,a[2]=((C_word)li641),tmp=(C_word)a,a+=3,tmp));
t20=C_mutate((C_word*)lf[791]+1 /* (set! ##sys#infix-list-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20683,a[2]=((C_word)li642),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate((C_word*)lf[792]+1 /* (set! ##sys#sharp-number-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20686,a[2]=((C_word)li643),tmp=(C_word)a,a+=3,tmp));
t22=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20694,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3742: chicken.base#make-parameter */
t23=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t23;
av2[1]=t22;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t23+1)))(3,av2);}}

/* chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20341(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_20341,c,av);}
a=C_alloc(8);
t3=C_rest_nullp(c,3);
t4=(C_truep(t3)?(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20499,a[2]=((C_word)li626),tmp=(C_word)a,a+=3,tmp):C_get_rest_arg(c,3,av,3,t0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20348,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3645: guard */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)C_fast_retrieve_proc(t6))(3,av2);}}

/* k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in ... */
static void C_ccall f_20348(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,6)))){
C_save_and_reclaim((void *)f_20348,c,av);}
a=C_alloc(14);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20349,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word)li627),tmp=(C_word)a,a+=5,tmp);
t4=C_fixnum_plus(((C_word*)((C_word*)t0)[2])[1],C_fix(1));
t5=C_set_block_item(((C_word*)t0)[2],0,t4);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20383,a[2]=t2,a[3]=t1,a[4]=t3,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t7=C_block_size(C_retrieve2(lf[780],C_text("##sys#default-parameter-vector")));
if(C_truep(C_fixnum_greater_or_equal_p(t2,t7))){
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20487,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* library.scm:3662: ##sys#vector-resize */
f_18582(t8,C_retrieve2(lf[780],C_text("##sys#default-parameter-vector")),C_fixnum_plus(t2,C_fix(1)),C_SCHEME_UNDEFINED);}
else{
t8=t6;
f_20383(t8,C_SCHEME_UNDEFINED);}}

/* assign in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in ... */
static void C_fcall f_20349(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_20349,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(11);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20353,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t4,a[6]=((C_word*)t0)[3],a[7]=t2,tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[2],t3))){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20372,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* library.scm:3650: ##sys#vector-resize */
f_18582(t7,C_fast_retrieve(lf[781]),C_fixnum_plus(((C_word*)t0)[2],C_fix(1)),*((C_word*)lf[646]+1));}
else{
t7=t6;
f_20353(t7,C_SCHEME_UNDEFINED);}}

/* k20351 in assign in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in ... */
static void C_fcall f_20353(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20353,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20356,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[5])){
/* library.scm:3654: guard */
t3=((C_word*)t0)[6];{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)C_fast_retrieve_proc(t3))(3,av2);}}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[7];
f_20356(2,av2);}}}

/* k20354 in k20351 in assign in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in ... */
static void C_ccall f_20356(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20356,c,av);}
if(C_truep(((C_word*)t0)[2])){
t2=C_i_setslot(C_fast_retrieve(lf[781]),((C_word*)t0)[3],t1);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k20370 in assign in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in ... */
static void C_ccall f_20372(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20372,c,av);}
t2=C_mutate((C_word*)lf[781]+1 /* (set! ##sys#current-parameter-vector ...) */,t1);
t3=((C_word*)t0)[2];
f_20353(t3,t2);}

/* k20381 in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in ... */
static void C_fcall f_20383(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_20383,2,t0,t1);}
a=C_alloc(9);
t2=C_i_setslot(C_retrieve2(lf[780],C_text("##sys#default-parameter-vector")),((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20391,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word)li631),tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20473,a[2]=((C_word*)t0)[4],a[3]=((C_word)li632),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3668: chicken.base#getter-with-setter */
t5=*((C_word*)lf[200]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=((C_word*)t0)[5];
av2[2]=t3;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* a20390 in k20381 in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in ... */
static void C_ccall f_20391(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +14,c,4)))){
C_save_and_reclaim((void*)f_20391,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+14);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
t3=C_block_size(C_fast_retrieve(lf[781]));
if(C_truep(C_i_pairp(t2))){
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20403,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t3,a[5]=((C_word)li628),tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20412,a[2]=t5,a[3]=((C_word)li629),tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20417,a[2]=t6,a[3]=((C_word)li630),tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_nullp(t4))){
/* library.scm:3672: def-convert?4345 */
t8=t7;
f_20417(t8,t1);}
else{
t8=C_i_car(t4);
t9=C_u_i_cdr(t4);
if(C_truep(C_i_nullp(t9))){
/* library.scm:3672: def-set?4346 */
t10=t6;
f_20412(t10,t1,t8);}
else{
t10=C_i_car(t9);
t11=C_u_i_cdr(t9);
/* library.scm:3672: body4343 */
t12=t5;
f_20403(t12,t1,t8,t10);}}}
else{
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[3],t3))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(C_retrieve2(lf[780],C_text("##sys#default-parameter-vector")),((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(C_fast_retrieve(lf[781]),((C_word*)t0)[3]);
t5=C_eqp(t4,*((C_word*)lf[646]+1));
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=(C_truep(t5)?C_slot(C_retrieve2(lf[780],C_text("##sys#default-parameter-vector")),((C_word*)t0)[3]):t4);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}

/* body4343 in a20390 in k20381 in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in ... */
static void C_fcall f_20403(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_20403,4,t0,t1,t2,t3);}
/* library.scm:3674: assign */
t4=((C_word*)t0)[2];
f_20349(t4,t1,C_i_car(((C_word*)t0)[3]),((C_word*)t0)[4],t2,t3);}

/* def-set?4346 in a20390 in k20381 in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in ... */
static void C_fcall f_20412(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_20412,3,t0,t1,t2);}
/* library.scm:3672: body4343 */
t3=((C_word*)t0)[2];
f_20403(t3,t1,t2,C_SCHEME_TRUE);}

/* def-convert?4345 in a20390 in k20381 in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in ... */
static void C_fcall f_20417(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,2)))){
C_save_and_reclaim_args((void *)trf_20417,2,t0,t1);}
/* library.scm:3672: def-set?4346 */
t2=((C_word*)t0)[2];
f_20412(t2,t1,C_SCHEME_TRUE);}

/* a20472 in k20381 in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in ... */
static void C_ccall f_20473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_20473,c,av);}
/* library.scm:3684: assign */
t3=((C_word*)t0)[2];
f_20349(t3,t1,t2,C_block_size(C_fast_retrieve(lf[781])),C_SCHEME_FALSE,C_SCHEME_TRUE);}

/* k20485 in k20346 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in ... */
static void C_ccall f_20487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20487,c,av);}
t2=C_mutate(&lf[780] /* (set! ##sys#default-parameter-vector ...) */,t1);
t3=((C_word*)t0)[2];
f_20383(t3,t2);}

/* f_20499 in chicken.base#make-parameter in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in ... */
static void C_ccall f_20499(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20499,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#char-ready? in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20505(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20505,c,av);}
t2=C_rest_nullp(c,2);
t3=(C_truep(t2)?*((C_word*)lf[732]+1):C_get_rest_arg(c,2,av,2,t0));
t4=C_i_check_port_2(t3,C_fix(1),C_SCHEME_TRUE,lf[783]);
t5=C_slot(t3,C_fix(2));
/* library.scm:3690: g4378 */
t6=C_slot(t5,C_fix(6));{
C_word av2[3];
av2[0]=t6;
av2[1]=t1;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t6))(3,av2);}}

/* scheme#read-char in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20530(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20530,c,av);}
if(C_truep(C_rest_nullp(c,2))){
t2=*((C_word*)lf[732]+1);
t3=C_i_check_port_2(*((C_word*)lf[732]+1),C_fix(1),C_SCHEME_TRUE,lf[719]);
/* library.scm:3697: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t1;
av2[2]=*((C_word*)lf[732]+1);
tp(3,av2);}}
else{
t2=C_get_rest_arg(c,2,av,2,t0);
t3=C_i_check_port_2(t2,C_fix(1),C_SCHEME_TRUE,lf[719]);
/* library.scm:3697: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}}

/* ##sys#read-char-0 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20548(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_20548,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20552,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_slot(t2,C_fix(6)))){
t4=C_i_set_i_slot(t2,C_fix(6),C_SCHEME_FALSE);
t5=t3;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_END_OF_FILE;
f_20552(2,av2);}}
else{
t4=C_slot(t2,C_fix(2));
/* library.scm:3700: g4396 */
t5=C_slot(t4,C_fix(0));{
C_word *av2=av;
av2[0]=t5;
av2[1]=t3;
av2[2]=t2;
((C_proc)C_fast_retrieve_proc(t5))(3,av2);}}}

/* k20550 in ##sys#read-char-0 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in ... */
static void C_ccall f_20552(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20552,c,av);}
t2=C_eqp(t1,C_make_character(10));
if(C_truep(t2)){
t3=C_slot(((C_word*)t0)[2],C_fix(4));
t4=C_fixnum_plus(t3,C_fix(1));
t5=C_i_set_i_slot(((C_word*)t0)[2],C_fix(4),t4);
t6=C_i_set_i_slot(((C_word*)t0)[2],C_fix(5),C_fix(0));
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
if(C_truep(C_i_not(C_eofp(t1)))){
t3=C_slot(((C_word*)t0)[2],C_fix(5));
t4=C_fixnum_plus(t3,C_fix(1));
t5=C_i_set_i_slot(((C_word*)t0)[2],C_fix(5),t4);
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* ##sys#read-char/port in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20608(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20608,c,av);}
t3=C_i_check_port_2(t2,C_fix(1),C_SCHEME_TRUE,lf[719]);
/* library.scm:3714: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2=av;
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}

/* ##sys#peek-char-0 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_20617,c,av);}
a=C_alloc(4);
if(C_truep(C_slot(t2,C_fix(6)))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_FILE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_slot(t2,C_fix(2));
t4=C_slot(t3,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20630,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3719: g4410 */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)C_fast_retrieve_proc(t6))(3,av2);}}}

/* k20628 in ##sys#peek-char-0 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in ... */
static void C_ccall f_20630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20630,c,av);}
if(C_truep(C_eofp(t1))){
t2=C_i_set_i_slot(((C_word*)t0)[2],C_fix(6),C_SCHEME_TRUE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* scheme#peek-char in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20642,c,av);}
if(C_truep(C_rest_nullp(c,2))){
t2=*((C_word*)lf[732]+1);
t3=C_i_check_port_2(*((C_word*)lf[732]+1),C_fix(1),C_SCHEME_TRUE,lf[723]);
/* library.scm:3727: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t1;
av2[2]=*((C_word*)lf[732]+1);
tp(3,av2);}}
else{
t2=C_get_rest_arg(c,2,av,2,t0);
t3=C_i_check_port_2(t2,C_fix(1),C_SCHEME_TRUE,lf[723]);
/* library.scm:3727: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}}

/* scheme#read in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20660,c,av);}
if(C_truep(C_rest_nullp(c,2))){
t2=*((C_word*)lf[732]+1);
t3=C_i_check_port_2(*((C_word*)lf[732]+1),C_fix(1),C_SCHEME_TRUE,lf[787]);
/* library.scm:3732: ##sys#read */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[774]);
C_word av2[4];
av2[0]=*((C_word*)lf[774]+1);
av2[1]=t1;
av2[2]=*((C_word*)lf[732]+1);
av2[3]=C_fast_retrieve(lf[788]);
tp(4,av2);}}
else{
t2=C_get_rest_arg(c,2,av,2,t0);
t3=C_i_check_port_2(t2,C_fix(1),C_SCHEME_TRUE,lf[787]);
/* library.scm:3732: ##sys#read */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[774]);
C_word av2[4];
av2[0]=*((C_word*)lf[774]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_fast_retrieve(lf[788]);
tp(4,av2);}}}

/* ##sys#read-prompt-hook in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20680,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#infix-list-hook in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_20683,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#sharp-number-hook in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20686,c,av);}
/* library.scm:3740: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=lf[794];
av2[4]=t3;
tp(5,av2);}}

/* k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in ... */
static void C_ccall f_20694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20694,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[232]+1 /* (set! chicken.base#case-sensitive ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20698,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3743: chicken.base#make-parameter */
t4=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in ... */
static void C_ccall f_20698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20698,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[234]+1 /* (set! chicken.base#parentheses-synonyms ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20702,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3744: chicken.base#make-parameter */
t4=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in ... */
static void C_ccall f_20702(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_20702,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[235]+1 /* (set! chicken.base#symbol-escape ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20706,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32740,a[2]=((C_word)li1020),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3747: chicken.base#make-parameter */
t5=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[830];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in ... */
static void C_ccall f_20706(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_20706,c,av);}
a=C_alloc(8);
t2=C_mutate((C_word*)lf[233]+1 /* (set! chicken.base#keyword-style ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20710,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_a_i_record4(&a,4,lf[1424],C_SCHEME_FALSE,C_SCHEME_FALSE,C_SCHEME_FALSE);
/* library.scm:3749: chicken.base#make-parameter */
t5=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in ... */
static void C_ccall f_20710(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(56,c,4)))){
C_save_and_reclaim((void *)f_20710,c,av);}
a=C_alloc(56);
t2=C_mutate((C_word*)lf[795]+1 /* (set! ##sys#current-read-table ...) */,t1);
t3=C_mutate((C_word*)lf[796]+1 /* (set! ##sys#read-warning ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20712,a[2]=((C_word)li644),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[793]+1 /* (set! ##sys#read-error ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20735,a[2]=((C_word)li645),tmp=(C_word)a,a+=3,tmp));
t5=*((C_word*)lf[233]+1);
t6=*((C_word*)lf[232]+1);
t7=*((C_word*)lf[234]+1);
t8=*((C_word*)lf[235]+1);
t9=C_fast_retrieve(lf[795]);
t10=C_mutate((C_word*)lf[774]+1 /* (set! ##sys#read ...) */,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20758,a[2]=t9,a[3]=t8,a[4]=t7,a[5]=t5,a[6]=t6,a[7]=((C_word)li701),tmp=(C_word)a,a+=8,tmp));
t11=C_mutate((C_word*)lf[808]+1 /* (set! ##sys#char->utf8-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23637,a[2]=((C_word)li702),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate((C_word*)lf[815]+1 /* (set! ##sys#unicode-surrogate? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23802,a[2]=((C_word)li703),tmp=(C_word)a,a+=3,tmp));
t13=C_mutate((C_word*)lf[812]+1 /* (set! ##sys#surrogates->codepoint ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23814,a[2]=((C_word)li704),tmp=(C_word)a,a+=3,tmp));
t14=C_mutate((C_word*)lf[863]+1 /* (set! ##sys#read-bytevector-literal ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23876,a[2]=((C_word)li707),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[876]+1 /* (set! ##sys#user-read-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24024,a[2]=((C_word)li708),tmp=(C_word)a,a+=3,tmp));
t16=C_set_block_item(lf[874] /* ##sys#read-marks */,0,C_SCHEME_END_OF_LIST);
t17=C_mutate((C_word*)lf[883]+1 /* (set! ##sys#write-char-0 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24069,a[2]=((C_word)li709),tmp=(C_word)a,a+=3,tmp));
t18=C_mutate((C_word*)lf[884]+1 /* (set! ##sys#write-char/port ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24085,a[2]=((C_word)li710),tmp=(C_word)a,a+=3,tmp));
t19=C_mutate((C_word*)lf[150]+1 /* (set! scheme#write-char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24097,a[2]=((C_word)li711),tmp=(C_word)a,a+=3,tmp));
t20=C_mutate((C_word*)lf[151]+1 /* (set! scheme#newline ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24118,a[2]=((C_word)li712),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate((C_word*)lf[152]+1 /* (set! scheme#write ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24133,a[2]=((C_word)li713),tmp=(C_word)a,a+=3,tmp));
t22=C_mutate((C_word*)lf[153]+1 /* (set! scheme#display ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24151,a[2]=((C_word)li714),tmp=(C_word)a,a+=3,tmp));
t23=C_mutate((C_word*)lf[188]+1 /* (set! chicken.base#print ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24169,a[2]=((C_word)li716),tmp=(C_word)a,a+=3,tmp));
t24=C_mutate((C_word*)lf[189]+1 /* (set! chicken.base#print* ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24220,a[2]=((C_word)li718),tmp=(C_word)a,a+=3,tmp));
t25=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24273,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4493: chicken.base#make-parameter */
t26=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t26;
av2[1]=t25;
av2[2]=C_fix(0);
((C_proc)(void*)(*((C_word*)t26+1)))(3,av2);}}

/* ##sys#read-warning in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_20712(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +5,c,2)))){
C_save_and_reclaim((void*)f_20712,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+5);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20720,a[2]=t1,a[3]=t4,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3756: ##sys#port-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[767]);
C_word *av2=av;
av2[0]=*((C_word*)lf[767]+1);
av2[1]=t5;
av2[2]=t2;
tp(3,av2);}}

/* k20718 in ##sys#read-warning in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_20720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_20720,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20723,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(C_truep(C_fast_retrieve(lf[789]))?t1:C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20733,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3758: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t4;
av2[2]=t1;
tp(3,av2);}}
else{{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[316]+1);
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[3];
C_apply(5,av2);}}}

/* k20721 in k20718 in ##sys#read-warning in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_20723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20723,c,av);}{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[316]+1);
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
C_apply(5,av2);}}

/* k20731 in k20718 in ##sys#read-warning in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_20733(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_20733,c,av);}
/* library.scm:3758: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[797];
av2[3]=t1;
av2[4]=lf[798];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* ##sys#read-error in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_20735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +5,c,2)))){
C_save_and_reclaim((void*)f_20735,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+5);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20743,a[2]=t1,a[3]=t4,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3768: ##sys#port-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[767]);
C_word *av2=av;
av2[0]=*((C_word*)lf[767]+1);
av2[1]=t5;
av2[2]=t2;
tp(3,av2);}}

/* k20741 in ##sys#read-error in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_20743(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_20743,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20746,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(C_truep(C_fast_retrieve(lf[789]))?t1:C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20756,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3770: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t4;
av2[2]=t1;
tp(3,av2);}}
else{{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[799];
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[3];
C_apply(6,av2);}}}

/* k20744 in k20741 in ##sys#read-error in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_20746(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_20746,c,av);}{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[799];
av2[4]=t1;
av2[5]=((C_word*)t0)[3];
C_apply(6,av2);}}

/* k20754 in k20741 in ##sys#read-error in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_20756(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_20756,c,av);}
/* library.scm:3770: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[800];
av2[3]=t1;
av2[4]=lf[801];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_20758(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20758,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20762,a[2]=t2,a[3]=t3,a[4]=t1,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3782: case-sensitive */
t5=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_20762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_20762,c,av);}
a=C_alloc(11);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20765,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3783: keyword-style */
t5=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_20765(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_20765,c,av);}
a=C_alloc(11);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20768,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3784: parentheses-synonyms */
t5=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_20768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20768,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20771,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3785: symbol-escape */
t3=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_20771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20771,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20774,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3786: current-read-table */
t3=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)C_fast_retrieve_proc(t3))(2,av2);}}

/* k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_20774(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(52,c,5)))){
C_save_and_reclaim((void *)f_20774,c,av);}
a=C_alloc(52);
t2=lf[802];
t3=C_SCHEME_FALSE;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20776,a[2]=((C_word*)t0)[2],a[3]=((C_word)li646),tmp=(C_word)a,a+=4,tmp));
t18=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20782,a[2]=((C_word*)t0)[3],a[3]=((C_word)li647),tmp=(C_word)a,a+=4,tmp));
t19=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20791,a[2]=((C_word*)t0)[2],a[3]=((C_word)li649),tmp=(C_word)a,a+=4,tmp));
t20=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20828,a[2]=((C_word*)t0)[2],a[3]=((C_word)li650),tmp=(C_word)a,a+=4,tmp));
t21=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20837,a[2]=t4,a[3]=t12,a[4]=((C_word)li651),tmp=(C_word)a,a+=5,tmp));
t22=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_20852,a[2]=((C_word*)t0)[2],a[3]=t10,a[4]=t6,a[5]=t8,a[6]=t16,a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=t14,a[10]=t2,a[11]=t4,a[12]=t12,a[13]=t1,a[14]=((C_word*)t0)[6],a[15]=((C_word*)t0)[7],a[16]=((C_word)li700),tmp=(C_word)a,a+=17,tmp));
/* library.scm:4360: readrec */
t23=((C_word*)t16)[1];
f_20852(t23,((C_word*)t0)[8]);}

/* f_20776 in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_20776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20776,c,av);}
/* library.scm:3792: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[803];
av2[4]=t2;
tp(5,av2);}}

/* info in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_20782(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_20782,5,t0,t1,t2,t3,t4);}
if(C_truep(((C_word*)t0)[2])){
/* library.scm:3796: infohandler */
t5=((C_word*)t0)[2];{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
av2[4]=t4;
((C_proc)C_fast_retrieve_proc(t5))(5,av2);}}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* skip-to-eol in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_20791(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_20791,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20799,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3800: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k20797 in skip-to-eol in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_20799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_20799,c,av);}
a=C_alloc(7);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20801,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word)li648),tmp=(C_word)a,a+=5,tmp));
t5=((C_word*)t3)[1];
f_20801(t5,((C_word*)t0)[3],t1);}

/* skip in k20797 in skip-to-eol in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_fcall f_20801(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_20801,3,t0,t1,t2);}
a=C_alloc(4);
t3=C_i_not(C_eofp(t2));
t4=(C_truep(t3)?C_i_not(C_eqp(C_make_character(10),t2)):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20815,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3802: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k20813 in skip in k20797 in skip-to-eol in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_20815(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20815,c,av);}
/* library.scm:3802: skip */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20801(t2,((C_word*)t0)[3],t1);}

/* reserved-character in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_20828(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20828,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20832,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3805: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k20830 in reserved-character in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_20832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20832,c,av);}
/* library.scm:3806: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[804];
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}

/* read-unreserved-char-0 in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_20837(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20837,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20841,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3809: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k20839 in read-unreserved-char-0 in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_20841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20841,c,av);}
if(C_truep(C_i_memq(t1,((C_word*)((C_word*)t0)[2])[1]))){
/* library.scm:3811: reserved-character */
t2=((C_word*)((C_word*)t0)[3])[1];
f_20828(t2,((C_word*)t0)[4],t1);}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_20852(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(158,0,5)))){
C_save_and_reclaim_args((void *)trf_20852,2,t0,t1);}
a=C_alloc(158);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_SCHEME_UNDEFINED;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_SCHEME_UNDEFINED;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=C_SCHEME_UNDEFINED;
t23=(*a=C_VECTOR_TYPE|1,a[1]=t22,tmp=(C_word)a,a+=2,tmp);
t24=C_SCHEME_UNDEFINED;
t25=(*a=C_VECTOR_TYPE|1,a[1]=t24,tmp=(C_word)a,a+=2,tmp);
t26=C_SCHEME_UNDEFINED;
t27=(*a=C_VECTOR_TYPE|1,a[1]=t26,tmp=(C_word)a,a+=2,tmp);
t28=C_SCHEME_UNDEFINED;
t29=(*a=C_VECTOR_TYPE|1,a[1]=t28,tmp=(C_word)a,a+=2,tmp);
t30=C_SCHEME_UNDEFINED;
t31=(*a=C_VECTOR_TYPE|1,a[1]=t30,tmp=(C_word)a,a+=2,tmp);
t32=C_SCHEME_UNDEFINED;
t33=(*a=C_VECTOR_TYPE|1,a[1]=t32,tmp=(C_word)a,a+=2,tmp);
t34=C_SCHEME_UNDEFINED;
t35=(*a=C_VECTOR_TYPE|1,a[1]=t34,tmp=(C_word)a,a+=2,tmp);
t36=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20855,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li653),tmp=(C_word)a,a+=5,tmp));
t37=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20903,a[2]=((C_word*)t0)[2],a[3]=((C_word)li655),tmp=(C_word)a,a+=4,tmp));
t38=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20963,a[2]=((C_word)li657),tmp=(C_word)a,a+=3,tmp));
t39=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21000,a[2]=((C_word*)t0)[2],a[3]=t5,a[4]=t7,a[5]=((C_word)li660),tmp=(C_word)a,a+=6,tmp));
t40=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_21554,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=t3,a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t27,a[9]=((C_word)li666),tmp=(C_word)a,a+=10,tmp));
t41=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21816,a[2]=((C_word*)t0)[2],a[3]=t11,a[4]=((C_word)li667),tmp=(C_word)a,a+=5,tmp));
t42=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21834,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=t27,a[5]=((C_word)li669),tmp=(C_word)a,a+=6,tmp));
t43=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21904,a[2]=((C_word*)t0)[2],a[3]=t15,a[4]=((C_word)li670),tmp=(C_word)a,a+=5,tmp));
t44=C_set_block_item(t19,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21955,a[2]=((C_word*)t0)[2],a[3]=t15,a[4]=((C_word)li671),tmp=(C_word)a,a+=5,tmp));
t45=C_set_block_item(t21,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22022,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[10],a[6]=((C_word)li673),tmp=(C_word)a,a+=7,tmp));
t46=C_set_block_item(t23,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22086,a[2]=((C_word*)t0)[2],a[3]=((C_word)li675),tmp=(C_word)a,a+=4,tmp));
t47=C_set_block_item(t25,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22132,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=t27,a[5]=((C_word)li677),tmp=(C_word)a,a+=6,tmp));
t48=C_set_block_item(t27,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22157,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[12],a[5]=t9,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[10],a[9]=((C_word)li679),tmp=(C_word)a,a+=10,tmp));
t49=C_set_block_item(t29,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22408,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[10],a[4]=t21,a[5]=((C_word)li680),tmp=(C_word)a,a+=6,tmp));
t50=C_set_block_item(t31,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22617,a[2]=((C_word*)t0)[2],a[3]=((C_word)li682),tmp=(C_word)a,a+=4,tmp));
t51=C_set_block_item(t33,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22704,a[2]=t21,a[3]=((C_word)li683),tmp=(C_word)a,a+=4,tmp));
t52=C_set_block_item(t35,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22717,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],a[5]=((C_word)li684),tmp=(C_word)a,a+=6,tmp));
t53=(*a=C_CLOSURE_TYPE|27,a[1]=(C_word)f_22748,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[13],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=t35,a[8]=t23,a[9]=t17,a[10]=t19,a[11]=((C_word*)t0)[8],a[12]=t13,a[13]=t29,a[14]=t31,a[15]=t33,a[16]=((C_word*)t0)[7],a[17]=t27,a[18]=((C_word*)t0)[5],a[19]=((C_word*)t0)[3],a[20]=t21,a[21]=t11,a[22]=((C_word*)t0)[4],a[23]=t9,a[24]=t15,a[25]=((C_word*)t0)[12],a[26]=t25,a[27]=t3,tmp=(C_word)a,a+=28,tmp);
t54=C_i_not(((C_word*)t0)[14]);
t55=(C_truep(t54)?lf[877]:C_SCHEME_END_OF_LIST);
if(C_truep(C_i_not(((C_word*)t0)[15]))){
/* library.scm:4198: scheme#append */
t56=*((C_word*)lf[382]+1);{
C_word av2[4];
av2[0]=t56;
av2[1]=t53;
av2[2]=t55;
av2[3]=lf[878];
((C_proc)(void*)(*((C_word*)t56+1)))(4,av2);}}
else{
/* library.scm:4198: scheme#append */
t56=*((C_word*)lf[382]+1);{
C_word av2[4];
av2[0]=t56;
av2[1]=t53;
av2[2]=t55;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t56+1)))(4,av2);}}}

/* r-spaces in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_20855(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20855,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20863,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3817: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k20861 in r-spaces in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_20863(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_20863,c,av);}
a=C_alloc(8);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20865,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word)li652),tmp=(C_word)a,a+=6,tmp));
t5=((C_word*)t3)[1];
f_20865(t5,((C_word*)t0)[4],t1);}

/* loop in k20861 in r-spaces in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_20865(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_20865,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eofp(t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_eqp(C_make_character(59),t2);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20878,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3820: skip-to-eol */
t6=((C_word*)((C_word*)t0)[4])[1];
f_20791(t6,t5);}
else{
if(C_truep(C_u_i_char_whitespacep(t2))){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20894,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3823: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}

/* k20876 in loop in k20861 in r-spaces in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_20878(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_20878,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20885,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3821: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k20883 in k20876 in loop in k20861 in r-spaces in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_20885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20885,c,av);}
/* library.scm:3821: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20865(t2,((C_word*)t0)[3],t1);}

/* k20892 in loop in k20861 in r-spaces in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_20894(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_20894,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20901,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3824: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k20899 in k20892 in loop in k20861 in r-spaces in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_20901(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20901,c,av);}
/* library.scm:3824: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20865(t2,((C_word*)t0)[3],t1);}

/* r-usequence in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_20903(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_20903,5,t0,t1,t2,t3,t4);}
a=C_alloc(9);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20909,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t4,a[5]=t6,a[6]=((C_word)li654),tmp=(C_word)a,a+=7,tmp));
t8=((C_word*)t6)[1];
f_20909(t8,t1,C_SCHEME_END_OF_LIST,t3);}

/* loop in r-usequence in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_fcall f_20909(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_20909,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20919,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3829: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t5;
av2[2]=t2;
tp(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20935,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* library.scm:3836: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}}

/* k20917 in loop in r-usequence in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_20919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_20919,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20922,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:3830: scheme#string->number */
t3=*((C_word*)lf[639]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k20920 in k20917 in loop in r-usequence in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_20922(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_20922,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20932,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3834: string-append */
t3=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[805];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=lf[806];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}}

/* k20930 in k20920 in k20917 in loop in r-usequence in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_20932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20932,c,av);}
/* library.scm:3832: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k20933 in loop in r-usequence in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_20935(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_20935,c,av);}
a=C_alloc(3);
t2=C_eofp(t1);
t3=(C_truep(t2)?t2:C_i_char_equalp(C_make_character(34),t1));
if(C_truep(t3)){
/* library.scm:3838: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[807];
tp(4,av2);}}
else{
t4=C_a_i_cons(&a,2,t1,((C_word*)t0)[4]);
/* library.scm:3839: loop */
t5=((C_word*)((C_word*)t0)[5])[1];
f_20909(t5,((C_word*)t0)[2],t4,C_fixnum_difference(((C_word*)t0)[6],C_fix(1)));}}

/* r-cons-codepoint in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_20963(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_20963,3,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20967,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3842: ##sys#char->utf8-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[808]);
C_word av2[3];
av2[0]=*((C_word*)lf[808]+1);
av2[1]=t4;
av2[2]=C_make_character(C_unfix(t2));
tp(3,av2);}}

/* k20965 in r-cons-codepoint in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_20967(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_20967,c,av);}
a=C_alloc(8);
t2=C_block_size(t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20975,a[2]=t2,a[3]=t1,a[4]=t4,a[5]=((C_word)li656),tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_20975(t6,((C_word*)t0)[2],C_fix(0),((C_word*)t0)[3]);}

/* lp in k20965 in r-cons-codepoint in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_20975(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_20975,4,t0,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fixnum_plus(t2,C_fix(1));
t5=C_subchar(((C_word*)t0)[3],t2);
t6=C_a_i_cons(&a,2,t5,t3);
/* library.scm:3847: lp */
t8=t1;
t9=t4;
t10=t6;
t1=t8;
t2=t9;
t3=t10;
goto loop;}}

/* r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_21000(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_21000,3,t0,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21008,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* library.scm:3850: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_21008(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_21008,c,av);}
a=C_alloc(10);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21010,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word)li659),tmp=(C_word)a,a+=8,tmp));
t5=((C_word*)t3)[1];
f_21010(t5,((C_word*)t0)[6],t1,C_SCHEME_END_OF_LIST);}

/* loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_21010(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_21010,4,t0,t1,t2,t3);}
a=C_alloc(11);
t4=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
if(C_truep(C_eofp(((C_word*)t4)[1]))){
/* library.scm:3852: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word av2[4];
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[809];
tp(4,av2);}}
else{
t5=C_eqp(C_make_character(92),((C_word*)t4)[1]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21027,a[2]=t4,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3854: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}
else{
t6=C_eqp(((C_word*)t0)[6],((C_word*)t4)[1]);
if(C_truep(t6)){
/* library.scm:3925: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t1;
av2[2]=t3;
tp(3,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21548,a[2]=t4,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:3926: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t7;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}}}}

/* k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_21027,c,av);}
a=C_alloc(9);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)((C_word*)t0)[2])[1];
switch(t3){
case C_make_character(116):
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21040,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3856: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(114):
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21057,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3857: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(98):
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21074,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3858: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(110):
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21091,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3859: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(97):
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21108,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3860: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(118):
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21125,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3861: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(102):
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21142,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3862: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(120):
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21170,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3864: r-usequence */
t5=((C_word*)((C_word*)t0)[7])[1];
f_20903(t5,t4,lf[810],C_fix(2),C_fix(16));
case C_make_character(117):
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21179,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* library.scm:3867: r-usequence */
t5=((C_word*)((C_word*)t0)[7])[1];
f_20903(t5,t4,lf[816],C_fix(4),C_fix(16));
case C_make_character(85):
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21253,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3880: r-usequence */
t5=((C_word*)((C_word*)t0)[7])[1];
f_20903(t5,t4,lf[818],C_fix(8),C_fix(16));
default:
t4=C_eqp(t3,C_make_character(92));
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21282,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t3,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t4)){
t6=t5;
f_21282(t6,t4);}
else{
t6=C_eqp(t3,C_make_character(39));
if(C_truep(t6)){
t7=t5;
f_21282(t7,t6);}
else{
t7=C_eqp(t3,C_make_character(34));
t8=t5;
f_21282(t8,(C_truep(t7)?t7:C_eqp(t3,C_make_character(124))));}}}}

/* k21038 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21040,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(9),((C_word*)t0)[2]);
/* library.scm:3856: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21010(t3,((C_word*)t0)[4],t1,t2);}

/* k21055 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21057,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(13),((C_word*)t0)[2]);
/* library.scm:3857: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21010(t3,((C_word*)t0)[4],t1,t2);}

/* k21072 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21074(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21074,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(8),((C_word*)t0)[2]);
/* library.scm:3858: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21010(t3,((C_word*)t0)[4],t1,t2);}

/* k21089 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21091,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(10),((C_word*)t0)[2]);
/* library.scm:3859: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21010(t3,((C_word*)t0)[4],t1,t2);}

/* k21106 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21108(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21108,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(7),((C_word*)t0)[2]);
/* library.scm:3860: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21010(t3,((C_word*)t0)[4],t1,t2);}

/* k21123 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21125,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(11),((C_word*)t0)[2]);
/* library.scm:3861: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21010(t3,((C_word*)t0)[4],t1,t2);}

/* k21140 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21142,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(12),((C_word*)t0)[2]);
/* library.scm:3862: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21010(t3,((C_word*)t0)[4],t1,t2);}

/* k21160 in k21168 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_21162(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21162,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* library.scm:3865: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21010(t3,((C_word*)t0)[5],t1,t2);}

/* k21168 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21170(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21170,c,av);}
a=C_alloc(6);
t2=C_make_character(C_unfix(t1));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21162,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3865: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21179(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_21179,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21185,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3868: ##sys#unicode-surrogate? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[815]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[815]+1);
av2[1]=t2;
av2[2]=t1;
tp(3,av2);}}

/* k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_21185(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21185,c,av);}
a=C_alloc(13);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21191,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21233,a[2]=t2,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3869: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21240,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3878: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}}

/* k21189 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_fcall f_21191(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_21191,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21194,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* library.scm:3871: r-usequence */
t3=((C_word*)((C_word*)t0)[8])[1];
f_20903(t3,t2,lf[813],C_fix(4),C_fix(16));}
else{
/* library.scm:3877: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word av2[5];
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[6];
av2[3]=lf[814];
av2[4]=((C_word*)t0)[7];
tp(5,av2);}}}

/* k21192 in k21189 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_21194,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21197,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* library.scm:3872: ##sys#surrogates->codepoint */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[812]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[812]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=t1;
tp(4,av2);}}

/* k21195 in k21192 in k21189 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_21197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_21197,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21207,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3874: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}
else{
/* library.scm:3876: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[6];
av2[3]=lf[811];
av2[4]=((C_word*)t0)[7];
av2[5]=((C_word*)t0)[8];
tp(6,av2);}}}

/* k21205 in k21195 in k21192 in k21189 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_21207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_21207,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21211,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3875: r-cons-codepoint */
f_20963(t2,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21209 in k21205 in k21195 in k21192 in k21189 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_21211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21211,c,av);}
/* library.scm:3874: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21010(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k21226 in k21231 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21228(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21228,c,av);}
t2=((C_word*)t0)[2];
f_21191(t2,C_eqp(C_make_character(117),t1));}

/* k21231 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_21233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21233,c,av);}
a=C_alloc(3);
t2=C_eqp(C_make_character(92),t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21228,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:3870: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_21191(t3,C_SCHEME_FALSE);}}

/* k21238 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_21240(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_21240,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21244,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3878: r-cons-codepoint */
f_20963(t2,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21242 in k21238 in k21183 in k21177 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21244,c,av);}
/* library.scm:3878: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21010(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k21251 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21253(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_21253,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21259,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:3881: ##sys#unicode-surrogate? */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[815]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[815]+1);
av2[1]=t2;
av2[2]=t1;
tp(3,av2);}}

/* k21257 in k21251 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_21259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_21259,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
/* library.scm:3882: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[817];
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21269,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3883: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k21267 in k21257 in k21251 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_21269(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_21269,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21273,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3883: r-cons-codepoint */
f_20963(t2,((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k21271 in k21267 in k21257 in k21251 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21273,c,av);}
/* library.scm:3883: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21010(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_21282(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_21282,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21289,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3885: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}
else{
t2=C_eqp(((C_word*)t0)[7],C_make_character(10));
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21302,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t2)){
t4=t3;
f_21302(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[7],C_make_character(13));
if(C_truep(t4)){
t5=t3;
f_21302(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[7],C_make_character(32));
t6=t3;
f_21302(t6,(C_truep(t5)?t5:C_eqp(((C_word*)t0)[7],C_make_character(9))));}}}}

/* k21287 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_21289(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21289,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3]);
/* library.scm:3885: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21010(t3,((C_word*)t0)[5],t1,t2);}

/* k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_21302(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_21302,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21307,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word)li658),tmp=(C_word)a,a+=7,tmp));
t5=((C_word*)t3)[1];
f_21307(t5,((C_word*)t0)[5],((C_word*)((C_word*)t0)[6])[1],C_SCHEME_FALSE);}
else{
if(C_truep(C_eofp(((C_word*)((C_word*)t0)[6])[1]))){
/* library.scm:3911: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word av2[4];
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[2];
av2[3]=lf[820];
tp(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21406,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_u_i_char_numericp(((C_word*)((C_word*)t0)[6])[1]))){
t3=C_i_char_greater_or_equal_p(((C_word*)((C_word*)t0)[6])[1],C_make_character(48));
t4=t2;
f_21406(t4,(C_truep(t3)?C_i_char_less_or_equal_p(((C_word*)((C_word*)t0)[6])[1],C_make_character(55)):C_SCHEME_FALSE));}
else{
t3=t2;
f_21406(t3,C_SCHEME_FALSE);}}}}

/* eat-ws in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_fcall f_21307(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_21307,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_eqp(t2,C_make_character(32));
t5=(C_truep(t4)?t4:C_eqp(t2,C_make_character(9)));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21324,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:3891: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
switch(t2){
case C_make_character(13):
if(C_truep(t3)){
/* library.scm:3894: loop */
t6=((C_word*)((C_word*)t0)[4])[1];
f_21010(t6,t1,t2,((C_word*)t0)[5]);}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21339,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3895: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
case C_make_character(10):
if(C_truep(t3)){
/* library.scm:3901: loop */
t6=((C_word*)((C_word*)t0)[4])[1];
f_21010(t6,t1,t2,((C_word*)t0)[5]);}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21374,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3902: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
default:
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21377,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t3)){
/* library.scm:3908: loop */
t7=((C_word*)((C_word*)t0)[4])[1];
f_21010(t7,t1,t2,((C_word*)t0)[5]);}
else{
/* library.scm:3905: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word av2[4];
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[819];
tp(4,av2);}}}}}

/* k21322 in eat-ws in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21324(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21324,c,av);}
/* library.scm:3891: eat-ws */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21307(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4]);}

/* k21337 in eat-ws in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21339(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_21339,c,av);}
a=C_alloc(4);
t2=C_eqp(t1,C_make_character(10));
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21352,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3897: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}
else{
/* library.scm:3898: eat-ws */
t3=((C_word*)((C_word*)t0)[2])[1];
f_21307(t3,((C_word*)t0)[3],t1,C_SCHEME_TRUE);}}

/* k21350 in k21337 in eat-ws in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_21352(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21352,c,av);}
/* library.scm:3897: eat-ws */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21307(t2,((C_word*)t0)[3],t1,C_SCHEME_TRUE);}

/* k21372 in eat-ws in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21374,c,av);}
/* library.scm:3902: eat-ws */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21307(t2,((C_word*)t0)[3],t1,C_SCHEME_TRUE);}

/* k21375 in eat-ws in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21377,c,av);}
/* library.scm:3908: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21010(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k21404 in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_fcall f_21406(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_21406,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=C_fix(C_character_code(((C_word*)((C_word*)t0)[2])[1]));
t3=C_fixnum_difference(t2,C_fix(48));
t4=C_fixnum_times(t3,C_fix(64));
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21432,a[2]=t4,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3917: r-usequence */
t6=((C_word*)((C_word*)t0)[7])[1];
f_20903(t6,t5,lf[821],C_fix(2),C_fix(8));}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21443,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:3920: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word av2[5];
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=lf[822];
av2[4]=((C_word*)((C_word*)t0)[2])[1];
tp(5,av2);}}}

/* k21414 in k21430 in k21404 in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_21416(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21416,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* library.scm:3918: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21010(t3,((C_word*)t0)[5],t1,t2);}

/* k21430 in k21404 in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21432(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21432,c,av);}
a=C_alloc(6);
t2=C_fixnum_plus(((C_word*)t0)[2],t1);
t3=C_make_character(C_unfix(t2));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21416,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3918: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k21441 in k21404 in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21443,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21450,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3924: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k21448 in k21441 in k21404 in k21300 in k21280 in k21025 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_21450(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21450,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3]);
/* library.scm:3924: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21010(t3,((C_word*)t0)[5],t1,t2);}

/* k21546 in loop in k21006 in r-string in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21548(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21548,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3]);
/* library.scm:3926: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21010(t3,((C_word*)t0)[5],t1,t2);}

/* r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_21554(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_21554,4,t0,t1,t2,t3);}
a=C_alloc(12);
t4=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_21814,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t3,a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[8],tmp=(C_word)a,a+=12,tmp);
/* library.scm:3929: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* starting-line in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_21563(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_21563,3,t0,t1,t2);}
a=C_alloc(4);
t3=(C_truep(((C_word*)((C_word*)t0)[2])[1])?C_fast_retrieve(lf[789]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21577,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3937: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
tp(3,av2);}}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k21575 in starting-line in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21577(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21577,c,av);}
/* library.scm:3935: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[823];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k21578 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_21580(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21580,c,av);}
a=C_alloc(5);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
if(C_truep(((C_word*)((C_word*)t0)[4])[1])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21591,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4004: ##sys#infix-list-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[791]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[791]+1);
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
tp(3,av2);}}
else{
t3=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21589 in k21578 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21591(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21591,c,av);}
/* library.scm:4004: info */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20782(t2,((C_word*)t0)[3],lf[824],t1,((C_word*)((C_word*)t0)[4])[1]);}

/* a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_21593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_21593,c,av);}
a=C_alloc(22);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21596,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word)li662),tmp=(C_word)a,a+=7,tmp));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_21618,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t5,a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word)li664),tmp=(C_word)a,a+=13,tmp));
t7=((C_word*)t5)[1];
f_21618(t7,t1,C_SCHEME_END_OF_LIST);}

/* f_21596 in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21596(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21596,c,av);}
a=C_alloc(6);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
/* library.scm:3944: return */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21613,a[2]=t1,a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3947: starting-line */
t5=((C_word*)t0)[5];
f_21563(t5,t4,lf[825]);}}

/* k21611 */
static void C_ccall f_21613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_21613,c,av);}
/* library.scm:3945: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
tp(6,av2);}}

/* loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_21618(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_21618,3,t0,t1,t2);}
a=C_alloc(14);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_21622,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t2,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],tmp=(C_word)a,a+=14,tmp);
/* library.scm:3950: r-spaces */
t4=((C_word*)((C_word*)t0)[5])[1];
f_20855(t4,t3);}

/* k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_21622(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_21622,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_21625,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
if(C_truep(((C_word*)((C_word*)t0)[9])[1])){
t3=t2;
f_21625(t3,C_SCHEME_UNDEFINED);}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21807,a[2]=((C_word*)t0)[13],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3951: ##sys#port-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[767]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[767]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_21625(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,2)))){
C_save_and_reclaim_args((void *)trf_21625,2,t0,t1);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_21628,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* library.scm:3952: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_21628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21628,c,av);}
a=C_alloc(13);
if(C_truep(C_eofp(t1))){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21638,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3956: starting-line */
t3=((C_word*)t0)[4];
f_21563(t3,t2,lf[826]);}
else{
t2=C_eqp(t1,((C_word*)t0)[5]);
if(C_truep(t2)){
/* library.scm:3958: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t3=C_eqp(t1,C_make_character(46));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_21656,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* library.scm:3960: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21803,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3997: readrec */
t5=((C_word*)((C_word*)t0)[8])[1];
f_20852(t5,t4);}}}}

/* k21636 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21638(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_21638,c,av);}
/* library.scm:3954: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_21656,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_21659,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* library.scm:3961: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_21659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_21659,c,av);}
a=C_alloc(14);
t2=C_u_i_char_whitespacep(t1);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_21668,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t2)){
t4=t3;
f_21668(t4,t2);}
else{
t4=C_eqp(t1,C_make_character(40));
if(C_truep(t4)){
t5=t3;
f_21668(t5,t4);}
else{
t5=C_eqp(t1,C_make_character(41));
if(C_truep(t5)){
t6=t3;
f_21668(t6,t5);}
else{
t6=C_eqp(t1,C_make_character(34));
t7=t3;
f_21668(t7,(C_truep(t6)?t6:C_eqp(t1,C_make_character(59))));}}}}

/* k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_fcall f_21668(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_21668,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21671,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_21671(2,av2);}}
else{
/* library.scm:3968: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word av2[4];
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[828];
tp(4,av2);}}}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21712,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[12],a[7]=((C_word)li663),tmp=(C_word)a,a+=8,tmp);
/* library.scm:3978: r-xtoken */
t3=((C_word*)((C_word*)t0)[13])[1];
f_22157(t3,((C_word*)t0)[4],t2);}}

/* k21669 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_21671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_21671,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21674,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3969: r-spaces */
t3=((C_word*)((C_word*)t0)[7])[1];
f_20855(t3,t2);}

/* k21672 in k21669 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in ... */
static void C_ccall f_21674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_21674,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21701,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* library.scm:3970: readrec */
t3=((C_word*)((C_word*)t0)[8])[1];
f_20852(t3,t2);}

/* k21678 in k21699 in k21672 in k21669 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in ... */
static void C_ccall f_21680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21680,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21697,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3972: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k21691 in k21695 in k21678 in k21699 in k21672 in k21669 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ... */
static void C_ccall f_21693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21693,c,av);}
/* library.scm:3973: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}

/* k21695 in k21678 in k21699 in k21672 in k21669 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in ... */
static void C_ccall f_21697(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21697,c,av);}
a=C_alloc(5);
t2=C_eqp(t1,((C_word*)t0)[2]);
if(C_truep(t2)){
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21693,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3975: starting-line */
t4=((C_word*)t0)[5];
f_21563(t4,t3,lf[827]);}}

/* k21699 in k21672 in k21669 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in ... */
static void C_ccall f_21701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21701,c,av);}
a=C_alloc(6);
t2=C_i_setslot(((C_word*)t0)[2],C_fix(1),t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21680,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* library.scm:3971: r-spaces */
t4=((C_word*)((C_word*)t0)[7])[1];
f_20855(t4,t3);}

/* a21711 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_21712(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_21712,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21716,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=t3,a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
/* library.scm:3980: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[421]+1);
av2[1]=t4;
av2[2]=lf[832];
av2[3]=t2;
tp(4,av2);}}

/* k21714 in a21711 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in ... */
static void C_ccall f_21716(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_21716,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21719,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_i_string_equal_p(t1,lf[829]);
t4=(C_truep(t3)?C_eqp(((C_word*)((C_word*)t0)[6])[1],lf[830]):C_SCHEME_FALSE);
if(C_truep(t4)){
/* library.scm:4194: ##sys#intern-keyword */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[649]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[649]+1);
av2[1]=t2;
av2[2]=lf[831];
tp(3,av2);}}
else{
if(C_truep(((C_word*)t0)[7])){
/* library.scm:4194: ##sys#intern-keyword */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[649]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[649]+1);
av2[1]=t2;
av2[2]=t1;
tp(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21747,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_u_i_char_numericp(((C_word*)t0)[8]))){
/* library.scm:3989: ##sys#string->number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[641]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[641]+1);
av2[1]=t5;
av2[2]=t1;
tp(3,av2);}}
else{
/* library.scm:4191: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=t2;
av2[2]=t1;
C_string_to_symbol(3,av2);}}}}}

/* k21717 in k21714 in a21711 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in ... */
static void C_ccall f_21719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21719,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t3=C_i_setslot(((C_word*)t0)[3],C_fix(1),t2);
/* library.scm:3995: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_21618(t4,((C_word*)t0)[5],t2);}
else{
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
/* library.scm:3995: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_21618(t4,((C_word*)t0)[5],t2);}}

/* k21745 in k21714 in a21711 in k21666 in k21657 in k21654 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in ... */
static void C_ccall f_21747(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21747,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
f_21719(2,av2);}}
else{
/* library.scm:4191: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
C_string_to_symbol(3,av2);}}}

/* k21801 in k21626 in k21623 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_21803(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21803,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t3=C_i_setslot(((C_word*)t0)[3],C_fix(1),t2);
/* library.scm:4001: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_21618(t4,((C_word*)t0)[5],t2);}
else{
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
/* library.scm:4001: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_21618(t4,((C_word*)t0)[5],t2);}}

/* k21805 in k21620 in loop in a21592 in k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_21807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21807,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];
f_21625(t3,t2);}

/* k21812 in r-list in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_21814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_21814,c,av);}
a=C_alloc(29);
t2=C_eqp(t1,((C_word*)t0)[2]);
if(C_truep(t2)){
t3=C_SCHEME_FALSE;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_FALSE;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=((C_word*)((C_word*)t0)[3])[1];
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21563,a[2]=t6,a[3]=((C_word)li661),tmp=(C_word)a,a+=4,tmp);
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21580,a[2]=((C_word*)t0)[3],a[3]=t7,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t6,tmp=(C_word)a,a+=8,tmp);
t10=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_21593,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=t8,a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=t4,a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=t6,a[12]=((C_word)li665),tmp=(C_word)a,a+=13,tmp);
/* library.scm:3939: ##sys#call-with-current-continuation */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=t9;
av2[2]=t10;
C_call_cc(3,av2);}}
else{
/* library.scm:4006: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[5];
av2[2]=((C_word*)t0)[7];
av2[3]=lf[833];
av2[4]=((C_word*)t0)[2];
tp(5,av2);}}}

/* r-vector in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_21816(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_21816,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21820,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4009: r-list */
t3=((C_word*)((C_word*)t0)[3])[1];
f_21554(t3,t2,C_make_character(40),C_make_character(41));}

/* k21818 in r-vector in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_21820(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21820,c,av);}
if(C_truep(C_i_listp(t1))){
/* library.scm:4011: ##sys#list->vector */
t2=*((C_word*)lf[834]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
/* library.scm:4012: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[835];
av2[4]=t1;
tp(5,av2);}}}

/* r-number in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_21834(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_21834,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21840,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=t3,a[6]=((C_word)li668),tmp=(C_word)a,a+=7,tmp);
/* library.scm:4015: r-xtoken */
t5=((C_word*)((C_word*)t0)[4])[1];
f_22157(t5,t1,t4);}

/* a21839 in r-number in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_21840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_21840,c,av);}
a=C_alloc(6);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21847,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4194: ##sys#intern-keyword */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[649]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[649]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}
else{
if(C_truep(C_i_string_equal_p(t2,lf[837]))){
/* library.scm:4021: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2=av;
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[838];
tp(4,av2);}}
else{
t4=C_block_size(t2);
t5=C_fixnum_greaterp(t4,C_fix(0));
t6=(C_truep(t5)?C_u_i_char_equalp(C_i_string_ref(t2,C_fix(0)),C_make_character(35)):C_SCHEME_FALSE);
if(C_truep(t6)){
/* library.scm:4023: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[839];
av2[4]=t2;
tp(5,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21875,a[2]=t1,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[4])){
/* library.scm:4024: ##sys#string->number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[641]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[641]+1);
av2[1]=t7;
av2[2]=t2;
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
tp(5,av2);}}
else{
/* library.scm:4024: ##sys#string->number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[641]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[641]+1);
av2[1]=t7;
av2[2]=t2;
av2[3]=C_fix(10);
av2[4]=((C_word*)t0)[5];
tp(5,av2);}}}}}}

/* k21845 in a21839 in r-number in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_21847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_21847,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21854,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4019: ##sys#port-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[767]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[767]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k21852 in k21845 in a21839 in r-number in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21854(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21854,c,av);}
/* library.scm:4019: info */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20782(t2,((C_word*)t0)[3],lf[836],((C_word*)t0)[4],t1);}

/* k21873 in a21839 in r-number in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_21875(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21875,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(((C_word*)t0)[3])){
/* library.scm:4025: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[4];
av2[3]=lf[840];
av2[4]=((C_word*)t0)[5];
tp(5,av2);}}
else{
/* library.scm:4191: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[5];
C_string_to_symbol(3,av2);}}}}

/* r-number-with-exactness in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_21904(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21904,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21953,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4029: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k21912 in k21951 in r-number-with-exactness in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_21914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21914,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21917,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4031: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k21915 in k21912 in k21951 in r-number-with-exactness in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21917,c,av);}
if(C_truep(C_eofp(t1))){
/* library.scm:4033: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[841];
tp(4,av2);}}
else{
if(C_truep(C_i_char_equalp(t1,C_make_character(105)))){
/* library.scm:4034: r-number */
t2=((C_word*)((C_word*)t0)[4])[1];
f_21834(t2,((C_word*)t0)[2],((C_word*)t0)[5],lf[632]);}
else{
if(C_truep(C_u_i_char_equalp(t1,C_make_character(101)))){
/* library.scm:4035: r-number */
t2=((C_word*)((C_word*)t0)[4])[1];
f_21834(t2,((C_word*)t0)[2],((C_word*)t0)[5],lf[631]);}
else{
/* library.scm:4037: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[842];
av2[4]=t1;
tp(5,av2);}}}}}

/* k21951 in r-number-with-exactness in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_21953(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_21953,c,av);}
a=C_alloc(6);
t2=C_eqp(C_make_character(35),t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21914,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4030: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
/* library.scm:4040: r-number */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21834(t3,((C_word*)t0)[2],((C_word*)t0)[5],C_SCHEME_FALSE);}}

/* r-number-with-radix in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_21955(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21955,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22020,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4043: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k21963 in k22018 in r-number-with-radix in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_21965(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_21965,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21968,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4045: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k21966 in k21963 in k22018 in r-number-with-radix in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_21968(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21968,c,av);}
if(C_truep(C_eofp(t1))){
/* library.scm:4046: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[843];
tp(4,av2);}}
else{
if(C_truep(C_i_char_equalp(t1,C_make_character(120)))){
/* library.scm:4047: r-number */
t2=((C_word*)((C_word*)t0)[4])[1];
f_21834(t2,((C_word*)t0)[2],C_fix(16),((C_word*)t0)[5]);}
else{
if(C_truep(C_u_i_char_equalp(t1,C_make_character(100)))){
/* library.scm:4048: r-number */
t2=((C_word*)((C_word*)t0)[4])[1];
f_21834(t2,((C_word*)t0)[2],C_fix(10),((C_word*)t0)[5]);}
else{
if(C_truep(C_u_i_char_equalp(t1,C_make_character(111)))){
/* library.scm:4049: r-number */
t2=((C_word*)((C_word*)t0)[4])[1];
f_21834(t2,((C_word*)t0)[2],C_fix(8),((C_word*)t0)[5]);}
else{
if(C_truep(C_u_i_char_equalp(t1,C_make_character(98)))){
/* library.scm:4050: r-number */
t2=((C_word*)((C_word*)t0)[4])[1];
f_21834(t2,((C_word*)t0)[2],C_fix(2),((C_word*)t0)[5]);}
else{
/* library.scm:4051: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[844];
av2[4]=t1;
tp(5,av2);}}}}}}}

/* k22018 in r-number-with-radix in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22020(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_22020,c,av);}
a=C_alloc(6);
t2=C_eqp(C_make_character(35),t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21965,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4044: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
/* library.scm:4052: r-number */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21834(t3,((C_word*)t0)[2],C_fix(10),((C_word*)t0)[5]);}}

/* r-token in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22022(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_22022,2,t0,t1);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22030,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* library.scm:4055: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k22028 in r-token in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22030(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_22030,c,av);}
a=C_alloc(10);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22032,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word)li672),tmp=(C_word)a,a+=8,tmp));
t5=((C_word*)t3)[1];
f_22032(t5,((C_word*)t0)[6],t1,C_SCHEME_END_OF_LIST);}

/* loop in k22028 in r-token in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_22032(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_22032,4,t0,t1,t2,t3);}
a=C_alloc(9);
t4=C_eofp(t2);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22042,a[2]=t1,a[3]=t3,a[4]=t2,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t4)){
t6=t5;
f_22042(t6,t4);}
else{
t6=C_u_i_char_whitespacep(t2);
t7=t5;
f_22042(t7,(C_truep(t6)?t6:C_i_memq(t2,((C_word*)t0)[6])));}}

/* k22040 in loop in k22028 in r-token in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_22042(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_22042,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
/* library.scm:4059: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[396]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
if(C_truep(C_i_char_equalp(((C_word*)t0)[4],C_make_character(0)))){
/* library.scm:4061: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word av2[4];
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[5];
av2[3]=lf[845];
tp(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22057,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4063: read-unreserved-char-0 */
t3=((C_word*)((C_word*)t0)[8])[1];
f_20837(t3,t2,((C_word*)t0)[5]);}}}

/* k22055 in k22040 in loop in k22028 in r-token in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_22057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22057,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22064,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4064: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}}

/* k22062 in k22055 in k22040 in loop in k22028 in r-token in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22064(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_22064,c,av);}
a=C_alloc(3);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
/* library.scm:4064: loop */
t3=((C_word*)((C_word*)t0)[5])[1];
f_22032(t3,((C_word*)t0)[6],t1,t2);}
else{
t2=C_u_i_char_downcase(((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
/* library.scm:4064: loop */
t4=((C_word*)((C_word*)t0)[5])[1];
f_22032(t4,((C_word*)t0)[6],t1,t3);}}

/* r-digits in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22086(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_22086,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22094,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:4068: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k22092 in r-digits in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22094(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_22094,c,av);}
a=C_alloc(7);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22096,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word)li674),tmp=(C_word)a,a+=5,tmp));
t5=((C_word*)t3)[1];
f_22096(t5,((C_word*)t0)[3],t1,C_SCHEME_END_OF_LIST);}

/* loop in k22092 in r-digits in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_22096(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_22096,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_eofp(t2);
t5=(C_truep(t4)?t4:C_i_not(C_u_i_char_numericp(t2)));
if(C_truep(t5)){
/* library.scm:4070: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t1;
av2[2]=t3;
tp(3,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22112,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4072: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}}

/* k22110 in loop in k22092 in r-digits in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22112(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_22112,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22119,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4073: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k22117 in k22110 in loop in k22092 in r-digits in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_22119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_22119,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* library.scm:4073: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_22096(t3,((C_word*)t0)[5],t1,t2);}

/* r-symbol in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22132(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_22132,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22138,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li676),tmp=(C_word)a,a+=5,tmp);
/* library.scm:4076: r-xtoken */
t3=((C_word*)((C_word*)t0)[4])[1];
f_22157(t3,t1,t2);}

/* a22137 in r-symbol in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22138(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22138,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22142,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t3)){
/* library.scm:4194: ##sys#intern-keyword */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[649]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[649]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}
else{
/* library.scm:4191: ##sys#intern-symbol */{
C_word *av2=av;
av2[0]=0;
av2[1]=t4;
av2[2]=t2;
C_string_to_symbol(3,av2);}}}

/* k22140 in a22137 in r-symbol in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_22142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22142,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22149,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4079: ##sys#port-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[767]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[767]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k22147 in k22140 in a22137 in r-symbol in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22149,c,av);}
/* library.scm:4079: info */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20782(t2,((C_word*)t0)[3],lf[836],((C_word*)t0)[4],t1);}

/* r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22157(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,2)))){
C_save_and_reclaim_args((void *)trf_22157,3,t0,t1,t2);}
a=C_alloc(18);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_22162,a[2]=t4,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=t1,tmp=(C_word)a,a+=12,tmp);
t6=C_eqp(((C_word*)((C_word*)t0)[2])[1],lf[849]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22406,a[2]=t5,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4084: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t7;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}
else{
t7=t5;
f_22162(t7,C_SCHEME_FALSE);}}

/* k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_fcall f_22162(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,5)))){
C_save_and_reclaim_args((void *)trf_22162,2,t0,t1);}
a=C_alloc(15);
t2=C_set_block_item(((C_word*)t0)[2],0,t1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22167,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t4,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word)li678),tmp=(C_word)a,a+=13,tmp));
t6=((C_word*)t4)[1];
f_22167(t6,((C_word*)t0)[11],C_SCHEME_END_OF_LIST,C_SCHEME_FALSE,C_SCHEME_FALSE);}

/* loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_22167(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,2)))){
C_save_and_reclaim_args((void *)trf_22167,5,t0,t1,t2,t3,t4);}
a=C_alloc(16);
t5=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_22171,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=t4,a[7]=t3,a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[6],a[11]=((C_word*)t0)[7],a[12]=((C_word*)t0)[8],a[13]=((C_word*)t0)[9],a[14]=((C_word*)t0)[10],a[15]=((C_word*)t0)[11],tmp=(C_word)a,a+=16,tmp);
/* library.scm:4087: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[9];
tp(3,av2);}}

/* k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_22171,c,av);}
a=C_alloc(16);
t2=C_eofp(t1);
t3=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_22180,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
if(C_truep(t2)){
t4=t3;
f_22180(t4,t2);}
else{
t4=C_u_i_char_whitespacep(t1);
t5=t3;
f_22180(t5,(C_truep(t4)?t4:C_i_memq(t1,((C_word*)t0)[15])));}}

/* k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_22180(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_22180,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22186,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(((C_word*)t0)[7])){
t3=C_eqp(((C_word*)((C_word*)t0)[8])[1],lf[830]);
if(C_truep(t3)){
if(C_truep(((C_word*)t0)[6])){
t4=t2;
f_22186(t4,((C_word*)t0)[6]);}
else{
t4=C_i_cdr(((C_word*)t0)[4]);
t5=t2;
f_22186(t5,C_i_not(C_i_nullp(t4)));}}
else{
t4=t2;
f_22186(t4,C_SCHEME_FALSE);}}
else{
t3=t2;
f_22186(t3,C_SCHEME_FALSE);}}
else{
if(C_truep(C_i_memq(((C_word*)t0)[9],((C_word*)((C_word*)t0)[10])[1]))){
/* library.scm:4104: reserved-character */
t2=((C_word*)((C_word*)t0)[11])[1];
f_20828(t2,((C_word*)t0)[3],((C_word*)t0)[9]);}
else{
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22277,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[13],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[14],a[8]=((C_word*)t0)[15],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4106: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[14];
tp(3,av2);}}}}

/* k22184 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_22186(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_22186,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22193,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4096: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t2;
av2[2]=C_i_cdr(((C_word*)t0)[4]);
tp(3,av2);}}
else{
t2=(C_truep(((C_word*)((C_word*)t0)[5])[1])?(C_truep(((C_word*)t0)[6])?((C_word*)t0)[6]:C_i_not(C_i_nullp(((C_word*)t0)[4]))):C_SCHEME_FALSE);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22210,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4098: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22216,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
t4=C_i_not(((C_word*)t0)[6]);
t5=t3;
f_22216(t5,(C_truep(t4)?C_i_nullp(((C_word*)t0)[4]):C_SCHEME_FALSE));}
else{
t4=t3;
f_22216(t4,C_SCHEME_FALSE);}}}}

/* k22191 in k22184 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_22193(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22193,c,av);}
/* library.scm:4096: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=C_SCHEME_TRUE;
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}

/* k22208 in k22184 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_22210(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22210,c,av);}
/* library.scm:4098: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=C_SCHEME_TRUE;
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}

/* k22214 in k22184 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_fcall f_22216(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_22216,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
/* library.scm:4100: k */
t2=((C_word*)t0)[2];{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[846];
av2[3]=C_SCHEME_FALSE;
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22226,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4102: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}}

/* k22224 in k22214 in k22184 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_22226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22226,c,av);}
/* library.scm:4102: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}

/* k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_22277,c,av);}
a=C_alloc(10);
switch(t1){
case C_make_character(124):
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22286,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4109: r-string */
t3=((C_word*)((C_word*)t0)[5])[1];
f_21000(t3,t2,C_make_character(124));
case C_make_character(10):
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22310,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22321,a[2]=t2,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4115: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}
case C_make_character(58):
t2=C_a_i_cons(&a,2,C_make_character(58),((C_word*)t0)[4]);
/* library.scm:4118: loop */
t3=((C_word*)((C_word*)t0)[2])[1];
f_22167(t3,((C_word*)t0)[3],t2,C_SCHEME_TRUE,((C_word*)t0)[6]);
case C_make_character(92):
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22343,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4120: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
tp(3,av2);}
default:
if(C_truep(((C_word*)((C_word*)t0)[8])[1])){
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[4]);
/* library.scm:4127: loop */
t3=((C_word*)((C_word*)t0)[2])[1];
f_22167(t3,((C_word*)t0)[3],t2,C_SCHEME_FALSE,((C_word*)t0)[6]);}
else{
t2=C_u_i_char_downcase(t1);
t3=C_a_i_cons(&a,2,t2,((C_word*)t0)[4]);
/* library.scm:4127: loop */
t4=((C_word*)((C_word*)t0)[2])[1];
f_22167(t4,((C_word*)t0)[3],t3,C_SCHEME_FALSE,((C_word*)t0)[6]);}}}

/* k22284 in k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_22286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22286,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22293,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22297,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22301,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4110: ##sys#string->list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[392]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[392]+1);
av2[1]=t4;
av2[2]=t1;
tp(3,av2);}}

/* k22291 in k22284 in k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_22293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22293,c,av);}
/* library.scm:4110: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22167(t2,((C_word*)t0)[3],t1,C_SCHEME_FALSE,C_SCHEME_TRUE);}

/* k22295 in k22284 in k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_22297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22297,c,av);}
/* library.scm:4110: scheme#append */
t2=*((C_word*)lf[382]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k22299 in k22284 in k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_22301(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22301,c,av);}
/* library.scm:4110: ##sys#fast-reverse */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[384]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[384]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}

/* k22308 in k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_22310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_22310,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,C_make_character(10),((C_word*)t0)[2]);
/* library.scm:4116: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_22167(t3,((C_word*)t0)[4],t2,C_SCHEME_FALSE,((C_word*)t0)[5]);}

/* k22319 in k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_22321(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22321,c,av);}
/* library.scm:4113: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[847];
av2[4]=t1;
tp(5,av2);}}

/* k22341 in k22275 in k22178 in k22169 in loop in k22160 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_22343(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_22343,c,av);}
a=C_alloc(3);
if(C_truep(C_eofp(t1))){
/* library.scm:4122: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[848];
tp(4,av2);}}
else{
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[4]);
/* library.scm:4125: loop */
t3=((C_word*)((C_word*)t0)[5])[1];
f_22167(t3,((C_word*)t0)[2],t2,C_SCHEME_FALSE,((C_word*)t0)[6]);}}

/* k22400 in k22404 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_22402(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_22402,c,av);}
t2=((C_word*)t0)[2];
f_22162(t2,C_SCHEME_TRUE);}

/* k22404 in r-xtoken in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22406(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_22406,c,av);}
a=C_alloc(3);
t2=C_eqp(C_make_character(58),t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22402,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4085: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_22162(t3,C_SCHEME_FALSE);}}

/* r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22408(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_22408,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22412,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4133: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word av2[3];
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22412(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_22412,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22415,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4134: r-token */
t3=((C_word*)((C_word*)t0)[5])[1];
f_22022(t3,t2);}

/* k22413 in k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_22415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_22415,c,av);}
a=C_alloc(11);
t2=C_block_size(t1);
if(C_truep(C_fixnum_greaterp(t2,C_fix(1)))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22427,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_i_char_equalp(C_make_character(120),((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22592,a[2]=t3,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t4)){
t6=t5;
f_22592(t6,t4);}
else{
t6=C_u_i_char_equalp(C_make_character(117),((C_word*)t0)[4]);
t7=t5;
f_22592(t7,(C_truep(t6)?t6:C_u_i_char_equalp(C_make_character(85),((C_word*)t0)[4])));}}
else{
if(C_truep(C_i_memq(((C_word*)t0)[4],((C_word*)t0)[5]))){
/* library.scm:4164: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k22425 in k22413 in k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22427(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22427,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_make_character(C_unfix(t1));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_subchar(((C_word*)t0)[3],C_fix(0));
t3=C_fix(C_character_code(t2));
t4=C_fixnum_less_or_equal_p(C_fix(192),t3);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22447,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t4)){
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(247)))){
t6=C_fixnum_shift_right(t3,C_fix(4));
t7=C_fixnum_and(t6,C_fix(3));
t8=C_fixnum_shift_right(t7,C_fix(1));
t9=C_fixnum_or(t7,t8);
t10=C_fixnum_difference(t7,C_fix(1));
t11=C_fixnum_and(t9,t10);
t12=C_fixnum_plus(C_fix(2),t11);
t13=C_eqp(((C_word*)t0)[5],t12);
if(C_truep(t13)){
t14=C_fixnum_difference(C_fix(8),t12);
t15=C_fixnum_shift_left(C_fix(1),t14);
t16=C_fixnum_difference(t15,C_fix(1));
t17=C_fixnum_and(t3,t16);
t18=C_fixnum_shift_left(t17,C_fix(6));
t19=C_subchar(((C_word*)t0)[3],C_fix(1));
t20=C_fix(C_character_code(t19));
t21=C_fixnum_and(t20,C_fix(63));
t22=C_fixnum_plus(t18,t21);
t23=t22;
if(C_truep(t23)){
if(C_truep(C_fixnum_greater_or_equal_p(t12,C_fix(3)))){
t24=C_fixnum_shift_left(t23,C_fix(6));
t25=C_subchar(((C_word*)t0)[3],C_fix(2));
t26=C_fix(C_character_code(t25));
t27=C_fixnum_and(t26,C_fix(63));
t28=C_fixnum_plus(t24,t27);
t29=t23=t28;
t30=C_eqp(t12,C_fix(4));
if(C_truep(t30)){
t31=C_fixnum_shift_left(t23,C_fix(6));
t32=C_subchar(((C_word*)t0)[3],C_fix(3));
t33=C_fix(C_character_code(t32));
t34=C_fixnum_and(t33,C_fix(63));
t35=C_fixnum_plus(t31,t34);
t36=t23=t35;
t37=t5;
f_22447(t37,C_make_character(C_unfix(t23)));}
else{
t31=t5;
f_22447(t31,C_make_character(C_unfix(t23)));}}
else{
t24=t5;
f_22447(t24,C_make_character(C_unfix(t23)));}}
else{
t24=t5;
f_22447(t24,C_SCHEME_FALSE);}}
else{
t14=t5;
f_22447(t14,C_SCHEME_FALSE);}}
else{
t6=t5;
f_22447(t6,C_SCHEME_FALSE);}}
else{
t6=t5;
f_22447(t6,C_SCHEME_FALSE);}}}

/* k22445 in k22425 in k22413 in k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_22447(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_22447,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22453,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22463,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4162: ##sys#intern-symbol */{
C_word av2[3];
av2[0]=0;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
C_string_to_symbol(3,av2);}}}

/* k22451 in k22445 in k22425 in k22413 in k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22453(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22453,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* library.scm:4163: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[850];
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}}

/* k22461 in k22445 in k22425 in k22413 in k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22463,c,av);}
/* library.scm:4162: chicken.base#char-name */
t2=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22590 in k22413 in k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_22592(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_22592,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22599,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4138: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=C_fix(1);
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_22427(2,av2);}}}

/* k22597 in k22590 in k22413 in k22410 in r-char in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_22599(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22599,c,av);}
/* library.scm:4138: ##sys#string->number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[641]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[641]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_fix(16);
tp(4,av2);}}

/* r-comment in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22617(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_22617,2,t0,t1);}
a=C_alloc(7);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22623,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word)li681),tmp=(C_word)a,a+=5,tmp));
t5=((C_word*)t3)[1];
f_22623(t5,t1,C_fix(0));}

/* loop in r-comment in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_fcall f_22623(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_22623,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22627,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4169: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k22625 in loop in r-comment in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_22627(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_22627,c,av);}
a=C_alloc(5);
switch(t1){
case C_make_character(124):
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22663,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4171: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}
case C_make_character(35):
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22686,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4175: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}
default:
if(C_truep(C_eofp(t1))){
/* library.scm:4179: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=lf[851];
tp(4,av2);}}
else{
/* library.scm:4180: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_22623(t2,((C_word*)t0)[4],((C_word*)t0)[2]);}}}

/* k22661 in k22625 in loop in r-comment in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22663(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22663,c,av);}
t2=C_eqp(C_make_character(35),t1);
if(C_truep(t2)){
t3=C_eqp(((C_word*)t0)[2],C_fix(0));
if(C_truep(C_i_not(t3))){
/* library.scm:4173: loop */
t4=((C_word*)((C_word*)t0)[3])[1];
f_22623(t4,((C_word*)t0)[4],C_fixnum_difference(((C_word*)t0)[2],C_fix(1)));}
else{
t4=C_SCHEME_UNDEFINED;
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
/* library.scm:4174: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_22623(t3,((C_word*)t0)[4],((C_word*)t0)[2]);}}

/* k22684 in k22625 in loop in r-comment in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22686(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22686,c,av);}
t2=C_eqp(C_make_character(124),t1);
if(C_truep(t2)){
/* library.scm:4175: loop */
t3=((C_word*)((C_word*)t0)[2])[1];
f_22623(t3,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}
else{
/* library.scm:4175: loop */
t3=((C_word*)((C_word*)t0)[2])[1];
f_22623(t3,((C_word*)t0)[3],((C_word*)t0)[4]);}}

/* r-ext-symbol in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22704(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_22704,2,t0,t1);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22708,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4183: r-token */
t3=((C_word*)((C_word*)t0)[2])[1];
f_22022(t3,t2);}

/* k22706 in r-ext-symbol in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22708(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_22708,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22715,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4184: string-append */
t3=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[852];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k22713 in k22706 in r-ext-symbol in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_22715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22715,c,av);}
/* library.scm:4191: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
C_string_to_symbol(3,av2);}}

/* r-quote in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_22717(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_22717,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22721,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4187: ##sys#port-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[767]);
C_word av2[3];
av2[0]=*((C_word*)lf[767]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k22719 in r-quote in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_22721,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22732,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4188: readrec */
t3=((C_word*)((C_word*)t0)[5])[1];
f_20852(t3,t2);}

/* k22730 in k22719 in r-quote in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_22732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22732,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* library.scm:4188: info */
t3=((C_word*)((C_word*)t0)[3])[1];
f_20782(t3,((C_word*)t0)[4],lf[824],t2,((C_word*)t0)[5]);}

/* k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_22748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,2)))){
C_save_and_reclaim((void *)f_22748,c,av);}
a=C_alloc(27);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|26,a[1]=(C_word)f_22751,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[15],a[15]=((C_word*)t0)[16],a[16]=((C_word*)t0)[17],a[17]=((C_word*)t0)[18],a[18]=((C_word*)t0)[19],a[19]=((C_word*)t0)[20],a[20]=((C_word*)t0)[21],a[21]=((C_word*)t0)[22],a[22]=((C_word*)t0)[23],a[23]=((C_word*)t0)[24],a[24]=((C_word*)t0)[2],a[25]=((C_word*)t0)[25],a[26]=((C_word*)t0)[26],tmp=(C_word)a,a+=27,tmp);
/* library.scm:4201: r-spaces */
t4=((C_word*)((C_word*)t0)[27])[1];
f_20855(t4,t3);}

/* k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_22751(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,2)))){
C_save_and_reclaim((void *)f_22751,c,av);}
a=C_alloc(27);
t2=(*a=C_CLOSURE_TYPE|26,a[1]=(C_word)f_22754,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],a[23]=((C_word*)t0)[23],a[24]=((C_word*)t0)[24],a[25]=((C_word*)t0)[25],a[26]=((C_word*)t0)[26],tmp=(C_word)a,a+=27,tmp);
/* library.scm:4202: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_22754(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_22754,c,av);}
a=C_alloc(21);
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_eofp(t1);
t4=C_i_not(t3);
t5=(C_truep(t4)?(C_truep(t2)?C_slot(t2,C_fix(C_character_code(t1))):C_SCHEME_FALSE):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22768,a[2]=t5,a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word)li685),tmp=(C_word)a,a+=6,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22774,a[2]=((C_word*)t0)[4],a[3]=((C_word)li686),tmp=(C_word)a,a+=4,tmp);
/* library.scm:4208: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=t6;
av2[3]=t7;
C_call_with_values(4,av2);}}
else{
switch(t1){
case C_make_character(39):
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22796,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4214: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(96):
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22808,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4217: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(44):
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22820,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4220: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(35):
t6=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_22848,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[6],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],tmp=(C_word)a,a+=21,tmp);
/* library.scm:4226: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(40):
/* library.scm:4343: r-list */
t6=((C_word*)((C_word*)t0)[20])[1];
f_21554(t6,((C_word*)t0)[5],C_make_character(40),C_make_character(41));
case C_make_character(41):
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23471,a[2]=((C_word*)t0)[21],a[3]=((C_word*)t0)[5],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4344: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(34):
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23483,a[2]=((C_word*)t0)[22],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4345: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(46):
/* library.scm:4346: r-number */
t6=((C_word*)((C_word*)t0)[23])[1];
f_21834(t6,((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_FALSE);
default:
t6=C_eqp(t1,C_make_character(45));
t7=(C_truep(t6)?t6:C_eqp(t1,C_make_character(43)));
if(C_truep(t7)){
/* library.scm:4347: r-number */
t8=((C_word*)((C_word*)t0)[23])[1];
f_21834(t8,((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_FALSE);}
else{
if(C_truep(C_eofp(t1))){
t8=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t8;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
if(C_truep(C_u_i_char_numericp(t1))){
/* library.scm:4350: r-number */
t8=((C_word*)((C_word*)t0)[23])[1];
f_21834(t8,((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_FALSE);}
else{
if(C_truep(C_i_memq(t1,((C_word*)((C_word*)t0)[24])[1]))){
/* library.scm:4352: reserved-character */
t8=((C_word*)((C_word*)t0)[25])[1];
f_20828(t8,((C_word*)t0)[5],t1);}
else{
switch(t1){
case C_make_character(91):
/* library.scm:4355: r-list */
t8=((C_word*)((C_word*)t0)[20])[1];
f_21554(t8,((C_word*)t0)[5],C_make_character(91),C_make_character(93));
case C_make_character(123):
/* library.scm:4356: r-list */
t8=((C_word*)((C_word*)t0)[20])[1];
f_21554(t8,((C_word*)t0)[5],C_make_character(123),C_make_character(125));
default:
t8=C_eqp(t1,C_make_character(93));
t9=(C_truep(t8)?t8:C_eqp(t1,C_make_character(125)));
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23561,a[2]=((C_word*)t0)[21],a[3]=((C_word*)t0)[5],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4357: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t10;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
/* library.scm:4358: r-symbol */
t10=((C_word*)((C_word*)t0)[26])[1];
f_22132(t10,((C_word*)t0)[5]);}}}}}}}}}

/* a22767 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22768,c,av);}
/* library.scm:4209: h */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}

/* a22773 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22774(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_22774,c,av);}
if(C_truep(C_rest_nullp(c,2))){
/* library.scm:4210: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,t1);}
else{
t2=t1;{
C_word av2[2];
av2[0]=t2;
av2[1]=C_get_rest_arg(c,2,av,2,t0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k22794 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22796(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22796,c,av);}
/* library.scm:4215: r-quote */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22717(t2,((C_word*)t0)[3],lf[853]);}

/* k22806 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22808,c,av);}
/* library.scm:4218: r-quote */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22717(t2,((C_word*)t0)[3],lf[854]);}

/* k22818 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22820(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_22820,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22839,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4221: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k22827 in k22837 in k22818 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22829,c,av);}
/* library.scm:4223: r-quote */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22717(t2,((C_word*)t0)[3],lf[855]);}

/* k22837 in k22818 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_22839(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22839,c,av);}
a=C_alloc(4);
t2=C_eqp(t1,C_make_character(64));
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22829,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4222: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}
else{
/* library.scm:4224: r-quote */
t3=((C_word*)((C_word*)t0)[2])[1];
f_22717(t3,((C_word*)t0)[3],lf[856]);}}

/* k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_22848(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,2)))){
C_save_and_reclaim((void *)f_22848,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_22851,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],tmp=(C_word)a,a+=21,tmp);
/* library.scm:4227: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_22851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_22851,c,av);}
a=C_alloc(10);
if(C_truep(C_eofp(t1))){
/* library.scm:4230: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[857];
tp(4,av2);}}
else{
if(C_truep(C_u_i_char_numericp(t1))){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22869,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22952,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4233: r-digits */
t4=((C_word*)((C_word*)t0)[7])[1];
f_22086(t4,t3);}
else{
t2=C_slot(((C_word*)t0)[4],C_fix(2));
t3=(C_truep(t2)?C_slot(t2,C_fix(C_character_code(t1))):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22966,a[2]=t3,a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word)li689),tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22972,a[2]=((C_word*)t0)[6],a[3]=((C_word)li690),tmp=(C_word)a,a+=4,tmp);
/* library.scm:4258: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t4;
av2[3]=t5;
C_call_with_values(4,av2);}}
else{
t4=C_u_i_char_downcase(t1);
switch(t4){
case C_make_character(120):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22997,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4263: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(100):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23009,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4264: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(111):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23021,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4265: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(98):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23033,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4266: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(105):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23045,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4267: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(101):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23057,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4268: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(99):
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23069,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4270: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(40):
/* library.scm:4279: r-vector */
t5=((C_word*)((C_word*)t0)[11])[1];
f_21816(t5,((C_word*)t0)[2]);
case C_make_character(92):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23133,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4280: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(124):
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23145,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[13],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4282: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(35):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23160,a[2]=((C_word*)t0)[14],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4285: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(59):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23172,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4288: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(96):
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23187,a[2]=((C_word*)t0)[15],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4291: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(36):
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23199,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[15],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4294: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(58):
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23226,a[2]=((C_word*)t0)[16],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[17],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4303: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(43):
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23286,a[2]=((C_word*)t0)[18],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4313: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
case C_make_character(33):
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23316,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[19],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[20],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4320: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}
default:
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23393,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word)li698),tmp=(C_word)a,a+=5,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23399,a[2]=((C_word*)t0)[6],a[3]=((C_word)li699),tmp=(C_word)a,a+=4,tmp);
/* library.scm:4341: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t5;
av2[3]=t6;
C_call_with_values(4,av2);}}}}}}

/* k22867 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22869,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22872,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4234: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k22870 in k22867 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_22872(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_22872,c,av);}
a=C_alloc(11);
t2=C_slot(((C_word*)t0)[2],C_fix(3));
t3=C_charp(t1);
t4=(C_truep(t3)?(C_truep(t2)?C_slot(t2,C_fix(C_character_code(t1))):C_SCHEME_FALSE):C_SCHEME_FALSE);
if(C_truep(C_eofp(t1))){
/* library.scm:4240: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=lf[858];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
tp(6,av2);}}
else{
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22895,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],a[6]=((C_word)li687),tmp=(C_word)a,a+=7,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22901,a[2]=((C_word*)t0)[7],a[3]=((C_word)li688),tmp=(C_word)a,a+=4,tmp);
/* library.scm:4243: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=t5;
av2[3]=t6;
C_call_with_values(4,av2);}}
else{
t5=C_eqp(t1,C_make_character(41));
t6=(C_truep(t5)?t5:C_u_i_char_whitespacep(t1));
if(C_truep(t6)){
/* library.scm:4248: ##sys#sharp-number-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[792]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[792]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[6];
tp(4,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22929,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* library.scm:4249: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t7;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}}}}

/* a22894 in k22870 in k22867 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_22895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22895,c,av);}
/* library.scm:4244: h */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
((C_proc)C_fast_retrieve_proc(t2))(5,av2);}}

/* a22900 in k22870 in k22867 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_22901(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_22901,c,av);}
if(C_truep(C_rest_nullp(c,2))){
/* library.scm:4245: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,t1);}
else{
t2=t1;{
C_word av2[2];
av2[0]=t2;
av2[1]=C_get_rest_arg(c,2,av,2,t0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k22927 in k22870 in k22867 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_22929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_22929,c,av);}
/* library.scm:4250: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[859];
av2[4]=((C_word*)t0)[4];
av2[5]=((C_word*)t0)[5];
av2[6]=((C_word*)t0)[6];
tp(7,av2);}}

/* k22950 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22952(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22952,c,av);}
/* library.scm:4233: scheme#string->number */
t2=*((C_word*)lf[639]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a22965 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22966(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22966,c,av);}
/* library.scm:4259: h */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}

/* a22971 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_22972,c,av);}
if(C_truep(C_rest_nullp(c,2))){
/* library.scm:4260: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,t1);}
else{
t2=t1;{
C_word av2[2];
av2[0]=t2;
av2[1]=C_get_rest_arg(c,2,av,2,t0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k22995 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_22997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22997,c,av);}
/* library.scm:4263: r-number-with-exactness */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21904(t2,((C_word*)t0)[3],C_fix(16));}

/* k23007 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23009(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23009,c,av);}
/* library.scm:4264: r-number-with-exactness */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21904(t2,((C_word*)t0)[3],C_fix(10));}

/* k23019 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23021,c,av);}
/* library.scm:4265: r-number-with-exactness */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21904(t2,((C_word*)t0)[3],C_fix(8));}

/* k23031 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23033,c,av);}
/* library.scm:4266: r-number-with-exactness */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21904(t2,((C_word*)t0)[3],C_fix(2));}

/* k23043 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23045(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23045,c,av);}
/* library.scm:4267: r-number-with-radix */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21955(t2,((C_word*)t0)[3],lf[632]);}

/* k23055 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23057,c,av);}
/* library.scm:4268: r-number-with-radix */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21955(t2,((C_word*)t0)[3],lf[631]);}

/* k23067 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23069(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_23069,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23072,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4271: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k23070 in k23067 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_23072(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_23072,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23075,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_eofp(t1))){
/* library.scm:4274: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[860];
tp(4,av2);}}
else{
switch(t1){
case C_make_character(105):
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_23075(2,av2);}
case C_make_character(115):
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
f_23075(2,av2);}
default:
/* library.scm:4277: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[861];
av2[4]=t1;
tp(5,av2);}}}}

/* k23073 in k23070 in k23067 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_23075(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,4)))){
C_save_and_reclaim((void *)f_23075,c,av);}
a=C_alloc(20);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23080,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word)li691),tmp=(C_word)a,a+=6,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23085,a[2]=((C_word*)t0)[3],a[3]=((C_word)li692),tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23091,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t5,a[5]=((C_word)li693),tmp=(C_word)a,a+=6,tmp);
/* library.scm:4272: ##sys#dynamic-wind */
t9=*((C_word*)lf[710]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[4];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a23079 in k23073 in k23070 in k23067 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_23080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23080,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a23084 in k23073 in k23070 in k23067 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_23085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23085,c,av);}
/* library.scm:4278: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,t1);}

/* a23090 in k23073 in k23070 in k23067 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_23091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23091,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k23131 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23133,c,av);}
/* library.scm:4280: r-char */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22408(t2,((C_word*)t0)[3]);}

/* k23143 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23145(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_23145,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23148,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4283: r-comment */
t3=((C_word*)((C_word*)t0)[4])[1];
f_22617(t3,t2);}

/* k23146 in k23143 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_23148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23148,c,av);}
/* library.scm:4283: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,((C_word*)t0)[3]);}

/* k23158 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23160(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23160,c,av);}
/* library.scm:4286: r-ext-symbol */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22704(t2,((C_word*)t0)[3]);}

/* k23170 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23172(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_23172,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23175,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4289: readrec */
t3=((C_word*)((C_word*)t0)[2])[1];
f_20852(t3,t2);}

/* k23173 in k23170 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_23175(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23175,c,av);}
/* library.scm:4289: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,((C_word*)t0)[3]);}

/* k23185 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23187(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23187,c,av);}
/* library.scm:4292: r-quote */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22717(t2,((C_word*)t0)[3],lf[862]);}

/* k23197 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23199(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_23199,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23202,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4295: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k23200 in k23197 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_23202(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_23202,c,av);}
a=C_alloc(4);
if(C_truep(C_i_char_equalp(t1,C_make_character(123)))){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23211,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4297: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
/* library.scm:4301: r-quote */
t2=((C_word*)((C_word*)t0)[4])[1];
f_22717(t2,((C_word*)t0)[2],lf[864]);}}

/* k23209 in k23200 in k23197 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_23211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23211,c,av);}
/* library.scm:4298: ##sys#read-bytevector-literal */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[863]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[863]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k23224 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_23226,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23229,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4304: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k23227 in k23224 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_23229(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_23229,c,av);}
a=C_alloc(22);
t2=C_SCHEME_FALSE;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23234,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=((C_word)li694),tmp=(C_word)a,a+=6,tmp);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23239,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word)li696),tmp=(C_word)a,a+=6,tmp);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23274,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t5,a[5]=((C_word)li697),tmp=(C_word)a,a+=6,tmp);
/* library.scm:4305: ##sys#dynamic-wind */
t9=*((C_word*)lf[710]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[5];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a23233 in k23227 in k23224 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_23234(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23234,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a23238 in k23227 in k23224 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_23239(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_23239,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23245,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li695),tmp=(C_word)a,a+=5,tmp);
/* library.scm:4306: r-xtoken */
t3=((C_word*)((C_word*)t0)[4])[1];
f_22157(t3,t1,t2);}

/* a23244 in a23238 in k23227 in k23224 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_23245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_23245,c,av);}
t4=C_block_size(t2);
t5=C_eqp(C_fix(0),t4);
if(C_truep(t5)){
t6=C_i_char_equalp(((C_word*)t0)[2],C_make_character(124));
if(C_truep(C_i_not(t6))){
/* library.scm:4310: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2=av;
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[865];
tp(4,av2);}}
else{
/* library.scm:4194: ##sys#intern-keyword */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[649]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[649]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}}
else{
/* library.scm:4194: ##sys#intern-keyword */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[649]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[649]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}}

/* a23273 in k23227 in k23224 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_23274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23274,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k23284 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_23286,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23289,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4314: ##sys#port-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[767]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[767]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k23287 in k23284 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_23289(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_23289,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23292,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4315: readrec */
t3=((C_word*)((C_word*)t0)[4])[1];
f_20852(t3,t2);}

/* k23290 in k23287 in k23284 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_23292(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_23292,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23307,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4317: readrec */
t3=((C_word*)((C_word*)t0)[5])[1];
f_20852(t3,t2);}

/* k23305 in k23290 in k23287 in k23284 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_23307(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_23307,c,av);}
a=C_alloc(15);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_list3(&a,3,lf[866],t2,lf[867]);
/* library.scm:4316: info */
t4=((C_word*)((C_word*)t0)[3])[1];
f_20782(t4,((C_word*)t0)[4],lf[824],t3,((C_word*)t0)[5]);}

/* k23314 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23316(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_23316,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23319,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4321: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k23317 in k23314 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_23319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_23319,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_23325,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_charp(t1))){
t3=C_u_i_char_whitespacep(t1);
t4=t2;
f_23325(t4,(C_truep(t3)?t3:C_u_i_char_equalp(C_make_character(47),t1)));}
else{
t3=t2;
f_23325(t3,C_SCHEME_FALSE);}}

/* k23323 in k23317 in k23314 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_fcall f_23325(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_23325,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23328,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4324: skip-to-eol */
t3=((C_word*)((C_word*)t0)[4])[1];
f_20791(t3,t2);}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23334,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4327: r-token */
t3=((C_word*)((C_word*)t0)[6])[1];
f_22022(t3,t2);}}

/* k23326 in k23323 in k23317 in k23314 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_23328(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23328,c,av);}
/* library.scm:4325: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,((C_word*)t0)[3]);}

/* k23332 in k23323 in k23317 in k23314 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_23334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_23334,c,av);}
a=C_alloc(5);
if(C_truep(C_i_string_equal_p(lf[868],t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_FILE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_u_i_string_equal_p(lf[869],t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word)C_SCHEME_BROKEN_WEAK_PTR);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep((C_truep(C_i_equalp(t1,lf[870]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(t1,lf[871]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(t1,lf[872]))?C_SCHEME_TRUE:C_SCHEME_FALSE))))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23358,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4332: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=t2;
av2[2]=lf[873];
av2[3]=t1;
tp(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_23377,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4334: scheme#string->symbol */
t3=*((C_word*)lf[655]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}}

/* k23356 in k23332 in k23323 in k23317 in k23314 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_23358(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23358,c,av);}
/* library.scm:4191: ##sys#intern-symbol */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
C_string_to_symbol(3,av2);}}

/* k23375 in k23332 in k23323 in k23317 in k23314 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_23377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_23377,c,av);}
t2=C_i_assq(t1,C_fast_retrieve(lf[874]));
if(C_truep(t2)){
/* library.scm:4335: g4976 */
t3=C_slot(t2,C_fix(1));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t3))(3,av2);}}
else{
/* library.scm:4337: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[875];
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}}

/* a23392 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_23393,c,av);}
/* library.scm:4341: ##sys#user-read-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[876]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[876]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* a23398 in k22849 in k22846 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_23399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23399,c,av);}
if(C_truep(C_rest_nullp(c,2))){
/* library.scm:4342: readrec */
t2=((C_word*)((C_word*)t0)[2])[1];
f_20852(t2,t1);}
else{
t2=t1;{
C_word av2[2];
av2[0]=t2;
av2[1]=C_get_rest_arg(c,2,av,2,t0);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k23469 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_23471(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23471,c,av);}
/* library.scm:4344: container */
t2=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* k23481 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_23483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23483,c,av);}
/* library.scm:4345: r-string */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21000(t2,((C_word*)t0)[3],C_make_character(34));}

/* k23559 in k22752 in k22749 in k22746 in readrec in k20772 in k20769 in k20766 in k20763 in k20760 in ##sys#read in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_23561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_23561,c,av);}
/* library.scm:4357: container */
t2=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* ##sys#char->utf8-string in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_23637(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_23637,c,av);}
a=C_alloc(5);
t3=C_fix(C_character_code(t2));
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(127)))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_string(&a,1,t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(2047)))){
t4=C_fixnum_shift_right(t3,C_fix(6));
t5=C_fixnum_or(C_fix(192),t4);
t6=C_make_character(C_unfix(t5));
t7=C_fixnum_and(t3,C_fix(63));
t8=C_fixnum_or(C_fix(128),t7);
t9=C_make_character(C_unfix(t8));
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=C_a_i_string(&a,2,t6,t9);
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(65535)))){
t4=C_fixnum_shift_right(t3,C_fix(12));
t5=C_fixnum_or(C_fix(224),t4);
t6=C_make_character(C_unfix(t5));
t7=C_fixnum_shift_right(t3,C_fix(6));
t8=C_fixnum_and(t7,C_fix(63));
t9=C_fixnum_or(C_fix(128),t8);
t10=C_make_character(C_unfix(t9));
t11=C_fixnum_and(t3,C_fix(63));
t12=C_fixnum_or(C_fix(128),t11);
t13=C_make_character(C_unfix(t12));
t14=t1;{
C_word *av2=av;
av2[0]=t14;
av2[1]=C_a_i_string(&a,3,t6,t10,t13);
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(2097151)))){
t4=C_fixnum_shift_right(t3,C_fix(18));
t5=C_fixnum_or(C_fix(240),t4);
t6=C_make_character(C_unfix(t5));
t7=C_fixnum_shift_right(t3,C_fix(12));
t8=C_fixnum_and(t7,C_fix(63));
t9=C_fixnum_or(C_fix(128),t8);
t10=C_make_character(C_unfix(t9));
t11=C_fixnum_shift_right(t3,C_fix(6));
t12=C_fixnum_and(t11,C_fix(63));
t13=C_fixnum_or(C_fix(128),t12);
t14=C_make_character(C_unfix(t13));
t15=C_fixnum_and(t3,C_fix(63));
t16=C_fixnum_or(C_fix(128),t15);
t17=C_make_character(C_unfix(t16));
t18=t1;{
C_word *av2=av;
av2[0]=t18;
av2[1]=C_a_i_string(&a,4,t6,t10,t14,t17);
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}
else{
/* library.scm:4382: chicken.base#error */
t4=*((C_word*)lf[193]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[879];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}}}}

/* ##sys#unicode-surrogate? in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_23802(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23802,c,av);}
t3=C_fixnum_less_or_equal_p(C_fix(55296),t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_fixnum_less_or_equal_p(t2,C_fix(57343)):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#surrogates->codepoint in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_23814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23814,c,av);}
if(C_truep(C_fixnum_less_or_equal_p(C_fix(55296),t2))){
if(C_truep(C_fixnum_less_or_equal_p(t2,C_fix(56319)))){
if(C_truep(C_fixnum_less_or_equal_p(C_fix(56320),t3))){
if(C_truep(C_fixnum_less_or_equal_p(t3,C_fix(57343)))){
t4=C_fixnum_shift_right(t2,C_fix(6));
t5=C_fixnum_and(t4,C_fix(31));
t6=C_fixnum_plus(C_fix(1),t5);
t7=C_fixnum_shift_left(t6,C_fix(16));
t8=C_fixnum_and(t2,C_fix(63));
t9=C_fixnum_shift_left(t8,C_fix(10));
t10=C_fixnum_and(t3,C_fix(1023));
t11=t1;{
C_word *av2=av;
av2[0]=t11;
av2[1]=C_fixnum_or(t7,C_fixnum_or(t9,t10));
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* ##sys#read-bytevector-literal in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_23876(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_23876,c,av);}
a=C_alloc(12);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_23879,a[2]=t2,a[3]=((C_word)li705),tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_23925,a[2]=t2,a[3]=t5,a[4]=t3,a[5]=((C_word)li706),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_23925(t7,t1,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);}

/* hex in ##sys#read-bytevector-literal in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_fcall f_23879(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_23879,3,t0,t1,t2);}
t3=C_u_i_char_downcase(t2);
t4=(C_truep(C_u_i_char_greater_or_equal_p(t3,C_make_character(97)))?C_u_i_char_less_or_equal_p(t3,C_make_character(102)):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_fixnum_difference(C_fix(C_character_code(t3)),C_fix(87));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(C_truep(C_u_i_char_greater_or_equal_p(t3,C_make_character(48)))?C_u_i_char_less_or_equal_p(t3,C_make_character(57)):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_fixnum_difference(C_fix(C_character_code(t3)),C_fix(48));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* library.scm:4402: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word av2[4];
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[880];
tp(4,av2);}}}}

/* loop in ##sys#read-bytevector-literal in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_fcall f_23925(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_23925,4,t0,t1,t2,t3);}
a=C_alloc(8);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_23929,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t2,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4404: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k23927 in loop in ##sys#read-bytevector-literal in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_23929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_23929,c,av);}
a=C_alloc(6);
if(C_truep(C_eofp(t1))){
/* library.scm:4406: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[881];
tp(4,av2);}}
else{
if(C_truep(C_i_char_equalp(C_make_character(125),t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_23947,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=C_fixnum_shift_right(((C_word*)t0)[4],C_fix(4));
t4=C_make_character(C_unfix(t3));
t5=C_a_i_cons(&a,2,t4,((C_word*)t0)[5]);
/* library.scm:4408: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t2;
av2[2]=t5;
tp(3,av2);}}
else{
/* library.scm:4408: ##sys#reverse-list->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[396]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[396]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}}
else{
if(C_truep(C_u_i_char_whitespacep(t1))){
if(C_truep(((C_word*)t0)[4])){
t2=C_fixnum_shift_right(((C_word*)t0)[4],C_fix(4));
t3=C_make_character(C_unfix(t2));
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[5]);
/* library.scm:4416: loop */
t5=((C_word*)((C_word*)t0)[6])[1];
f_23925(t5,((C_word*)t0)[2],t4,C_SCHEME_FALSE);}
else{
/* library.scm:4417: loop */
t2=((C_word*)((C_word*)t0)[6])[1];
f_23925(t2,((C_word*)t0)[2],((C_word*)t0)[5],((C_word*)t0)[4]);}}
else{
if(C_truep(((C_word*)t0)[4])){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24011,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4418: hex */
t3=((C_word*)t0)[7];
f_23879(t3,t2,t1);}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24022,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4419: hex */
t3=((C_word*)t0)[7];
f_23879(t3,t2,t1);}}}}}

/* k23945 in k23927 in loop in ##sys#read-bytevector-literal in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_23947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_23947,c,av);}
t2=C_string_to_bytevector(t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k24009 in k23927 in loop in ##sys#read-bytevector-literal in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_24011(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_24011,c,av);}
a=C_alloc(3);
t2=C_fixnum_or(((C_word*)t0)[2],t1);
t3=C_make_character(C_unfix(t2));
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[3]);
/* library.scm:4418: loop */
t5=((C_word*)((C_word*)t0)[4])[1];
f_23925(t5,((C_word*)t0)[5],t4,C_SCHEME_FALSE);}

/* k24020 in k23927 in loop in ##sys#read-bytevector-literal in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_24022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24022,c,av);}
/* library.scm:4419: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_23925(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_fixnum_shift_left(t1,C_fix(4)));}

/* ##sys#user-read-hook in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24024(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_24024,c,av);}
a=C_alloc(3);
t4=C_eqp(t2,C_make_character(102));
t5=(C_truep(t4)?t4:C_eqp(t2,C_make_character(70)));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24037,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4431: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2=av;
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t6;
av2[2]=t3;
tp(3,av2);}}
else{
t6=C_eqp(t2,C_make_character(116));
t7=(C_truep(t6)?t6:C_eqp(t2,C_make_character(84)));
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24049,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4432: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2=av;
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t8;
av2[2]=t3;
tp(3,av2);}}
else{
/* library.scm:4433: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=t1;
av2[2]=t3;
av2[3]=lf[882];
av2[4]=t2;
tp(5,av2);}}}}

/* k24035 in ##sys#user-read-hook in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_24037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24037,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k24047 in ##sys#user-read-hook in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_24049(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24049,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#write-char-0 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24069(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_24069,c,av);}
a=C_alloc(3);
t4=C_slot(t3,C_fix(2));
t5=C_slot(t4,C_fix(2));
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24076,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4447: g5088 */
t7=t5;{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
av2[3]=t2;
((C_proc)C_fast_retrieve_proc(t7))(4,av2);}}

/* k24074 in ##sys#write-char-0 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_24076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24076,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=*((C_word*)lf[246]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#write-char/port in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24085,c,av);}
t4=C_i_check_port_2(t3,C_fix(2),C_SCHEME_TRUE,lf[885]);
t5=C_i_check_char_2(t2,lf[885]);
/* library.scm:4454: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2=av;
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
tp(4,av2);}}

/* scheme#write-char in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24097(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24097,c,av);}
t3=C_rest_nullp(c,3);
t4=(C_truep(t3)?*((C_word*)lf[733]+1):C_get_rest_arg(c,3,av,3,t0));
t5=C_i_check_char_2(t2,lf[885]);
t6=C_i_check_port_2(t4,C_fix(2),C_SCHEME_TRUE,lf[885]);
/* library.scm:4460: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word av2[4];
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=t4;
tp(4,av2);}}

/* scheme#newline in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24118(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24118,c,av);}
if(C_truep(C_rest_nullp(c,2))){
t2=*((C_word*)lf[733]+1);
t3=*((C_word*)lf[733]+1);
/* library.scm:4464: ##sys#write-char/port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[884]);
C_word av2[4];
av2[0]=*((C_word*)lf[884]+1);
av2[1]=t1;
av2[2]=C_make_character(10);
av2[3]=*((C_word*)lf[733]+1);
tp(4,av2);}}
else{
/* library.scm:4464: ##sys#write-char/port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[884]);
C_word av2[4];
av2[0]=*((C_word*)lf[884]+1);
av2[1]=t1;
av2[2]=C_make_character(10);
av2[3]=C_get_rest_arg(c,2,av,2,t0);
tp(4,av2);}}}

/* scheme#write in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_24133,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=*((C_word*)lf[733]+1);
t4=C_i_check_port_2(*((C_word*)lf[733]+1),C_fix(2),C_SCHEME_TRUE,lf[886]);
/* library.scm:4469: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_TRUE;
av2[4]=*((C_word*)lf[733]+1);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_i_check_port_2(t3,C_fix(2),C_SCHEME_TRUE,lf[886]);
/* library.scm:4469: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_TRUE;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* scheme#display in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24151(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_24151,c,av);}
if(C_truep(C_rest_nullp(c,3))){
t3=*((C_word*)lf[733]+1);
t4=C_i_check_port_2(*((C_word*)lf[733]+1),C_fix(2),C_SCHEME_TRUE,lf[888]);
/* library.scm:4474: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[733]+1);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t3=C_get_rest_arg(c,3,av,3,t0);
t4=C_i_check_port_2(t3,C_fix(2),C_SCHEME_TRUE,lf[888]);
/* library.scm:4474: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* chicken.base#print in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +9,c,3)))){
C_save_and_reclaim((void*)f_24169,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+9);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
t3=*((C_word*)lf[733]+1);
t4=C_i_check_port_2(*((C_word*)lf[733]+1),C_fix(2),C_SCHEME_TRUE,lf[889]);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24212,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t6=C_i_check_list_2(t2,lf[706]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24188,a[2]=t8,a[3]=((C_word)li715),tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_24188(t10,t5,t2);}

/* for-each-loop5149 in chicken.base#print in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_fcall f_24188(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_24188,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24198,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[887]+1);
/* library.scm:4477: g5165 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[887]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[887]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[733]+1);
tp(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k24196 in for-each-loop5149 in chicken.base#print in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_24198(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24198,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_24188(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k24210 in chicken.base#print in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_24212(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_24212,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24215,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4483: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=*((C_word*)lf[733]+1);
tp(4,av2);}}

/* k24213 in k24210 in chicken.base#print in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_24215(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24215,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=*((C_word*)lf[246]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#print* in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +9,c,3)))){
C_save_and_reclaim((void*)f_24220,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+9);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
t3=*((C_word*)lf[733]+1);
t4=C_i_check_port_2(*((C_word*)lf[733]+1),C_fix(2),C_SCHEME_TRUE,lf[889]);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24263,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t6=C_i_check_list_2(t2,lf[706]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24239,a[2]=t8,a[3]=((C_word)li717),tmp=(C_word)a,a+=4,tmp));
t10=((C_word*)t8)[1];
f_24239(t10,t5,t2);}

/* for-each-loop5181 in chicken.base#print* in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_fcall f_24239(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_24239,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24249,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[887]+1);
/* library.scm:4477: g5197 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[887]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[887]+1);
av2[1]=t3;
av2[2]=t4;
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[733]+1);
tp(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k24247 in for-each-loop5181 in chicken.base#print* in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_24249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24249,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_24239(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k24261 in chicken.base#print* in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_24263(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_24263,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24266,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4490: ##sys#flush-output */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[765]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[765]+1);
av2[1]=t2;
av2[2]=*((C_word*)lf[733]+1);
tp(3,av2);}}

/* k24264 in k24261 in chicken.base#print* in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_24266(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24266,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=*((C_word*)lf[246]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in ... */
static void C_ccall f_24273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_24273,c,av);}
a=C_alloc(3);
t2=C_mutate(&lf[890] /* (set! current-print-length ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24277,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4494: chicken.base#make-parameter */
t4=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in ... */
static void C_ccall f_24277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_24277,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[891]+1 /* (set! ##sys#print-length-limit ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24281,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4495: chicken.base#make-parameter */
t4=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in ... */
static void C_ccall f_24281(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,5)))){
C_save_and_reclaim((void *)f_24281,c,av);}
a=C_alloc(17);
t2=C_mutate(&lf[892] /* (set! ##sys#print-exit ...) */,t1);
t3=*((C_word*)lf[232]+1);
t4=*((C_word*)lf[233]+1);
t5=C_mutate((C_word*)lf[887]+1 /* (set! ##sys#print ...) */,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24283,a[2]=t4,a[3]=t3,a[4]=((C_word)li732),tmp=(C_word)a,a+=5,tmp));
t6=C_mutate((C_word*)lf[915]+1 /* (set! ##sys#procedure->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25390,a[2]=((C_word)li733),tmp=(C_word)a,a+=3,tmp));
t7=C_set_block_item(lf[928] /* ##sys#record-printers */,0,C_SCHEME_END_OF_LIST);
t8=C_mutate((C_word*)lf[204]+1 /* (set! chicken.base#record-printer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25407,a[2]=((C_word)li734),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[205]+1 /* (set! chicken.base#set-record-printer! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25422,a[2]=((C_word)li735),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[931]+1 /* (set! ##sys#register-record-printer ...) */,*((C_word*)lf[205]+1));
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25451,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4745: chicken.base#getter-with-setter */
t12=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t12;
av2[1]=t11;
av2[2]=*((C_word*)lf[204]+1);
av2[3]=*((C_word*)lf[205]+1);
((C_proc)(void*)(*((C_word*)t12+1)))(4,av2);}}

/* ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_24283(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_24283,c,av);}
a=C_alloc(7);
t5=C_i_check_port_2(t4,C_fix(2),C_SCHEME_TRUE,C_SCHEME_FALSE);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24290,a[2]=t3,a[3]=t1,a[4]=t4,a[5]=t2,a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4502: case-sensitive */
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_24290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_24290,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24293,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4503: keyword-style */
t3=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_24293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_24293,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24296,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4504: ##sys#print-length-limit */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[891]);
C_word *av2=av;
av2[0]=*((C_word*)lf[891]+1);
av2[1]=t2;
tp(2,av2);}}

/* k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_24296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(49,c,4)))){
C_save_and_reclaim((void *)f_24296,c,av);}
a=C_alloc(49);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24298,a[2]=t1,a[3]=((C_word)li719),tmp=(C_word)a,a+=4,tmp));
t13=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24370,a[2]=t1,a[3]=((C_word)li720),tmp=(C_word)a,a+=4,tmp));
t14=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24430,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t9,a[5]=t11,a[6]=((C_word)li721),tmp=(C_word)a,a+=7,tmp));
t15=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24454,a[2]=t5,a[3]=t3,a[4]=((C_word)li723),tmp=(C_word)a,a+=5,tmp));
t16=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24543,a[2]=((C_word*)t0)[3],a[3]=((C_word)li725),tmp=(C_word)a,a+=4,tmp));
t17=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24732,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t18=C_SCHEME_UNDEFINED;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_set_block_item(t19,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_24737,a[2]=t3,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=t5,a[6]=((C_word*)t0)[6],a[7]=t7,a[8]=t19,a[9]=((C_word)li731),tmp=(C_word)a,a+=10,tmp));
t21=((C_word*)t19)[1];
f_24737(t21,t17,((C_word*)t0)[7]);}

/* outstr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_24298(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_24298,4,t0,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(((C_word*)t0)[2])){
t4=C_block_size(t3);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24308,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* library.scm:4510: current-print-length */
t6=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(2));
/* g52405241 */
t5=C_slot(t4,C_fix(3));{
C_word av2[4];
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
((C_proc)C_fast_retrieve_proc(t5))(4,av2);}}}

/* k24306 in outstr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24308(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_24308,c,av);}
a=C_alloc(12);
t2=C_fixnum_plus(t1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24314,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_fixnum_greaterp(t2,((C_word*)t0)[4]))){
t4=C_fixnum_difference(((C_word*)t0)[4],t1);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24326,a[2]=t3,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_fixnum_greaterp(t4,C_fix(0)))){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_24349,a[2]=((C_word*)t0)[5],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:4514: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[6];
av2[3]=C_fix(0);
av2[4]=t4;
tp(5,av2);}}
else{
t6=t5;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_24326(2,av2);}}}
else{
t4=C_slot(((C_word*)t0)[5],C_fix(2));
/* g52405241 */
t5=C_slot(t4,C_fix(3));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
((C_proc)C_fast_retrieve_proc(t5))(4,av2);}}}

/* k24312 in k24306 in outstr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24314,c,av);}
/* library.scm:4518: current-print-length */
t2=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k24324 in k24306 in outstr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24326(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_24326,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24329,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_slot(((C_word*)t0)[3],C_fix(2));
/* g52405241 */
t4=C_slot(t3,C_fix(3));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[893];
((C_proc)C_fast_retrieve_proc(t4))(4,av2);}}

/* k24327 in k24324 in k24306 in outstr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_24329(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_24329,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24332,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4516: ##sys#print-exit */
t3=C_retrieve2(lf[892],C_text("##sys#print-exit"));{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k24330 in k24327 in k24324 in k24306 in outstr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_24332(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24332,c,av);}
t2=*((C_word*)lf[246]+1);
/* library.scm:4513: g5233 */
t3=t1;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[246]+1);
((C_proc)C_fast_retrieve_proc(t3))(3,av2);}}

/* k24347 in k24306 in outstr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24349,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(2));
/* g52405241 */
t3=C_slot(t2,C_fix(3));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[2];
av2[3]=t1;
((C_proc)C_fast_retrieve_proc(t3))(4,av2);}}

/* outchr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_24370(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_24370,4,t0,t1,t2,t3);}
a=C_alloc(12);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24374,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[2])){
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24387,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=t2,a[5]=t1,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* library.scm:4526: current-print-length */
t6=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=C_slot(t2,C_fix(2));
/* g52495250 */
t6=C_slot(t5,C_fix(2));{
C_word av2[4];
av2[0]=t6;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
((C_proc)C_fast_retrieve_proc(t6))(4,av2);}}}

/* k24372 in outchr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24374,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(2));
/* g52495250 */
t3=C_slot(t2,C_fix(2));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[4];
((C_proc)C_fast_retrieve_proc(t3))(4,av2);}}

/* k24385 in outchr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_24387,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24390,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4527: current-print-length */
t3=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_fixnum_plus(t1,C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k24388 in k24385 in outchr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_24390,c,av);}
a=C_alloc(3);
if(C_truep(C_fixnum_greater_or_equal_p(((C_word*)t0)[2],((C_word*)t0)[3]))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24399,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t3=C_slot(((C_word*)t0)[5],C_fix(2));
/* g52405241 */
t4=C_slot(t3,C_fix(3));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[894];
((C_proc)C_fast_retrieve_proc(t4))(4,av2);}}
else{
t2=C_slot(((C_word*)t0)[5],C_fix(2));
/* g52495250 */
t3=C_slot(t2,C_fix(2));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[6];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[7];
((C_proc)C_fast_retrieve_proc(t3))(4,av2);}}}

/* k24397 in k24388 in k24385 in outchr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_24399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_24399,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24402,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4530: ##sys#print-exit */
t3=C_retrieve2(lf[892],C_text("##sys#print-exit"));{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k24400 in k24397 in k24388 in k24385 in outchr in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_24402(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24402,c,av);}
t2=*((C_word*)lf[246]+1);
/* library.scm:4528: g5245 */
t3=t1;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[246]+1);
((C_proc)C_fast_retrieve_proc(t3))(3,av2);}}

/* outsym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_24430(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_24430,4,t0,t1,t2,t3);}
a=C_alloc(8);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24434,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4539: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}

/* k24432 in outsym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24434(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_24434,c,av);}
a=C_alloc(7);
t2=C_i_not(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24443,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t1,a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
f_24443(2,av2);}}
else{
/* library.scm:4540: sym-is-readable? */
t4=((C_word*)((C_word*)t0)[7])[1];
f_24543(t4,t3,t1);}}

/* k24441 in k24432 in outsym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24443,c,av);}
if(C_truep(t1)){
/* library.scm:4541: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}
else{
/* library.scm:4542: outreadablesym */
t2=((C_word*)((C_word*)t0)[6])[1];
f_24454(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}}

/* outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_24454(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_24454,4,t0,t1,t2,t3);}
a=C_alloc(8);
t4=C_block_size(t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24461,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[3],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
/* library.scm:4546: outchr */
t6=((C_word*)((C_word*)t0)[2])[1];
f_24370(t6,t5,t2,C_make_character(124));}

/* k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24461(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_24461,c,av);}
a=C_alloc(11);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_24466,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t3,a[7]=((C_word*)t0)[6],a[8]=((C_word)li722),tmp=(C_word)a,a+=9,tmp));
t5=((C_word*)t3)[1];
f_24466(t5,((C_word*)t0)[7],C_fix(0));}

/* loop in k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_24466(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_24466,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
/* library.scm:4549: outchr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_24370(t3,t1,((C_word*)t0)[4],C_make_character(124));}
else{
t3=C_subchar(((C_word*)t0)[5],t2);
t4=C_i_char_lessp(t3,C_make_character(32));
t5=(C_truep(t4)?t4:C_u_i_char_greaterp(t3,C_make_character(126)));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_24488,a[2]=t3,a[3]=((C_word*)t0)[6],a[4]=t1,a[5]=t2,a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[3],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4552: outstr */
t7=((C_word*)((C_word*)t0)[7])[1];
f_24298(t7,t6,((C_word*)t0)[4],lf[895]);}
else{
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24517,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=t3,tmp=(C_word)a,a+=8,tmp);
t7=C_eqp(t3,C_make_character(124));
if(C_truep(t7)){
if(C_truep(t7)){
/* library.scm:4558: outchr */
t8=((C_word*)((C_word*)t0)[3])[1];
f_24370(t8,t6,((C_word*)t0)[4],C_make_character(92));}
else{
t8=t6;{
C_word av2[2];
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_24517(2,av2);}}}
else{
t8=C_eqp(t3,C_make_character(92));
if(C_truep(t8)){
/* library.scm:4558: outchr */
t9=((C_word*)((C_word*)t0)[3])[1];
f_24370(t9,t6,((C_word*)t0)[4],C_make_character(92));}
else{
t9=t6;{
C_word av2[2];
av2[0]=t9;
av2[1]=C_SCHEME_UNDEFINED;
f_24517(2,av2);}}}}}}

/* k24486 in loop in k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_24488(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_24488,c,av);}
a=C_alloc(8);
t2=C_fix(C_character_code(((C_word*)t0)[2]));
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24494,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t2,tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_fixnum_lessp(t2,C_fix(16)))){
/* library.scm:4554: outchr */
t4=((C_word*)((C_word*)t0)[8])[1];
f_24370(t4,t3,((C_word*)t0)[7],C_make_character(48));}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_24494(2,av2);}}}

/* k24492 in k24486 in loop in k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_24494(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_24494,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24497,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24508,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4555: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=C_fix(16);
tp(4,av2);}}

/* k24495 in k24492 in k24486 in loop in k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_24497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24497,c,av);}
/* library.scm:4556: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24466(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* k24506 in k24492 in k24486 in loop in k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_24508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24508,c,av);}
/* library.scm:4555: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k24515 in loop in k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_24517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_24517,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24520,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4559: outchr */
t3=((C_word*)((C_word*)t0)[5])[1];
f_24370(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k24518 in k24515 in loop in k24459 in outreadablesym in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_24520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_24520,c,av);}
/* library.scm:4560: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24466(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* sym-is-readable? in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_24543(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_24543,3,t0,t1,t2);}
a=C_alloc(9);
t3=C_block_size(t2);
switch(t3){
case C_fix(0):
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}
case C_fix(1):
t4=C_subchar(t2,C_fix(0));
t5=C_eqp(C_make_character(35),t4);
t6=(C_truep(t5)?t5:C_eqp(C_make_character(46),t4));
if(C_truep(t6)){
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t7=C_fix(C_character_code(t4));
t8=C_fixnum_less_or_equal_p(t7,C_fix(32));
t9=(C_truep(t8)?t8:C_i_memq(t4,lf[896]));
if(C_truep(t9)){
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t10=C_u_i_char_numericp(t4);
t11=t1;{
C_word av2[2];
av2[0]=t11;
av2[1]=(C_truep(t10)?C_SCHEME_FALSE:C_SCHEME_TRUE);
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}
default:
t4=C_fixnum_difference(t3,C_fix(1));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24592,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t6,a[6]=((C_word)li724),tmp=(C_word)a,a+=7,tmp));
t8=((C_word*)t6)[1];
f_24592(t8,t1,t4);}}

/* loop in sym-is-readable? in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_fcall f_24592(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_24592,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_eqp(t2,C_fix(0));
if(C_truep(t3)){
t4=C_subchar(((C_word*)t0)[2],C_fix(0));
t5=C_u_i_char_numericp(t4);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24608,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t4,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t5)){
t7=t6;
f_24608(t7,t5);}
else{
t7=C_eqp(t4,C_make_character(43));
if(C_truep(t7)){
t8=t6;
f_24608(t8,t7);}
else{
t8=C_eqp(t4,C_make_character(46));
t9=t6;
f_24608(t9,(C_truep(t8)?t8:C_eqp(t4,C_make_character(45))));}}}
else{
t4=C_subchar(((C_word*)t0)[2],t2);
t5=(C_truep(((C_word*)t0)[4])?((C_word*)t0)[4]:C_i_not(C_u_i_char_upper_casep(t4)));
if(C_truep(t5)){
t6=C_fix(C_character_code(t4));
t7=C_fixnum_less_or_equal_p(t6,C_fix(32));
t8=(C_truep(t7)?t7:C_i_memq(t4,lf[896]));
if(C_truep(C_i_not(t8))){
t9=C_eqp(t4,C_make_character(58));
t10=C_i_not(t9);
t11=(C_truep(t10)?t10:C_fixnum_lessp(t2,C_fixnum_difference(((C_word*)t0)[3],C_fix(1))));
if(C_truep(t11)){
/* library.scm:4594: loop */
t13=t1;
t14=C_fixnum_difference(t2,C_fix(1));
t1=t13;
t2=t14;
goto loop;}
else{
t12=t1;{
C_word av2[2];
av2[0]=t12;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}
else{
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}

/* k24606 in loop in sym-is-readable? in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_24608(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_24608,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_24615,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4579: ##sys#string->number */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[641]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[641]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],C_make_character(58));
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24627,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=C_eqp(((C_word*)t0)[4],C_make_character(35));
if(C_truep(t4)){
if(C_truep(C_fixnum_greaterp(((C_word*)t0)[5],C_fix(2)))){
t5=C_eqp(C_subchar(((C_word*)t0)[3],C_fix(1)),C_make_character(35));
if(C_truep(t5)){
t6=C_eqp(C_subchar(((C_word*)t0)[3],C_fix(2)),C_make_character(35));
t7=t3;
f_24627(t7,C_i_not(C_i_not(t6)));}
else{
t6=t3;
f_24627(t6,C_SCHEME_TRUE);}}
else{
t5=t3;
f_24627(t5,C_SCHEME_TRUE);}}
else{
t5=t3;
f_24627(t5,C_SCHEME_FALSE);}}}}

/* k24613 in k24606 in loop in sym-is-readable? in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_24615(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24615,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_not(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k24625 in k24606 in loop in sym-is-readable? in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_24627(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,1)))){
C_save_and_reclaim_args((void *)trf_24627,2,t0,t1);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_i_member(((C_word*)t0)[3],lf[897]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_fix(C_character_code(((C_word*)t0)[4]));
t3=C_fixnum_less_or_equal_p(t2,C_fix(32));
t4=(C_truep(t3)?t3:C_i_memq(((C_word*)t0)[4],lf[896]));
t5=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?C_SCHEME_FALSE:C_SCHEME_TRUE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k24730 in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_24732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_24732,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=*((C_word*)lf[246]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_24737(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_24737,3,t0,t1,t2);}
a=C_alloc(9);
switch(t2){
case C_SCHEME_END_OF_LIST:
/* library.scm:4597: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[898]);
case C_SCHEME_TRUE:
/* library.scm:4598: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[899]);
case C_SCHEME_FALSE:
/* library.scm:4599: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[900]);
default:
if(C_truep(C_eofp(t2))){
/* library.scm:4600: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[901]);}
else{
if(C_truep(C_undefinedp(t2))){
/* library.scm:4601: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[902]);}
else{
if(C_truep(C_bwpp(t2))){
/* library.scm:4602: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[903]);}
else{
if(C_truep(C_charp(t2))){
if(C_truep(((C_word*)t0)[4])){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24792,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4605: outstr */
t4=((C_word*)((C_word*)t0)[2])[1];
f_24298(t4,t3,((C_word*)t0)[3],lf[904]);}
else{
/* library.scm:4614: outchr */
t3=((C_word*)((C_word*)t0)[5])[1];
f_24370(t3,t1,((C_word*)t0)[3],t2);}}
else{
if(C_truep(C_fixnump(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24851,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4615: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}
else{
if(C_truep(C_unboundvaluep(t2))){
/* library.scm:4616: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[905]);}
else{
if(C_truep(C_i_not(C_blockp(t2)))){
/* library.scm:4617: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[906]);}
else{
if(C_truep(C_forwardedp(t2))){
/* library.scm:4618: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],lf[907]);}
else{
if(C_truep(C_i_keywordp(t2))){
t3=C_i_not(((C_word*)t0)[4]);
t4=(C_truep(t3)?((C_word*)t0)[6]:C_SCHEME_FALSE);
t5=C_eqp(t4,lf[849]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24887,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4623: outchr */
t7=((C_word*)((C_word*)t0)[5])[1];
f_24370(t7,t6,((C_word*)t0)[3],C_make_character(58));}
else{
t6=C_eqp(t4,lf[830]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24899,a[2]=((C_word*)t0)[5],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4626: outsym */
t8=((C_word*)((C_word*)t0)[7])[1];
f_24430(t8,t7,((C_word*)t0)[3],t2);}
else{
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24905,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4629: outstr */
t8=((C_word*)((C_word*)t0)[2])[1];
f_24298(t8,t7,((C_word*)t0)[3],lf[908]);}}}
else{
if(C_truep(C_i_symbolp(t2))){
/* library.scm:4631: outsym */
t3=((C_word*)((C_word*)t0)[7])[1];
f_24430(t3,t1,((C_word*)t0)[3],t2);}
else{
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_24927,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4632: ##sys#number? */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[518]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[518]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}}}}}}}}}}}}

/* k24790 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24792(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_24792,c,av);}
a=C_alloc(8);
t2=C_fix(C_character_code(((C_word*)t0)[2]));
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24798,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[2],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4607: chicken.base#char-name */
t4=*((C_word*)lf[199]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k24796 in k24790 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_24798,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24802,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li726),tmp=(C_word)a,a+=5,tmp);
/* library.scm:4607: g5347 */
t3=t2;
f_24802(t3,((C_word*)t0)[4],t1);}
else{
t2=C_fixnum_lessp(((C_word*)t0)[5],C_fix(32));
t3=(C_truep(t2)?t2:C_fixnum_greaterp(((C_word*)t0)[5],C_fix(255)));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24825,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4611: outchr */
t5=((C_word*)((C_word*)t0)[6])[1];
f_24370(t5,t4,((C_word*)t0)[3],C_make_character(120));}
else{
/* library.scm:4613: outchr */
t4=((C_word*)((C_word*)t0)[6])[1];
f_24370(t4,((C_word*)t0)[4],((C_word*)t0)[3],((C_word*)t0)[7]);}}}

/* g5347 in k24796 in k24790 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_24802(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_24802,3,t0,t1,t2);}
/* library.scm:4609: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t1,((C_word*)t0)[3],C_slot(t2,C_fix(1)));}

/* k24823 in k24796 in k24790 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_24825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_24825,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24832,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4612: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_fix(16);
tp(4,av2);}}

/* k24830 in k24823 in k24796 in k24790 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_24832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24832,c,av);}
/* library.scm:4612: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k24849 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24851,c,av);}
/* library.scm:4615: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k24885 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24887,c,av);}
/* library.scm:4624: outsym */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24430(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k24897 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24899(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24899,c,av);}
/* library.scm:4627: outchr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24370(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_make_character(58));}

/* k24903 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24905,c,av);}
/* library.scm:4630: outsym */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24430(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_24927(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_24927,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24934,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4632: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}
else{
if(C_truep(C_anypointerp(((C_word*)t0)[5]))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_24944,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4633: ##sys#pointer->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[909]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[909]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}
else{
if(C_truep(C_stringp(((C_word*)t0)[5]))){
if(C_truep(((C_word*)t0)[6])){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_24953,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4636: outchr */
t3=((C_word*)((C_word*)t0)[7])[1];
f_24370(t3,t2,((C_word*)t0)[4],C_make_character(34));}
else{
/* library.scm:4662: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}}
else{
if(C_truep(C_pairp(((C_word*)t0)[5]))){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25126,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4664: outchr */
t3=((C_word*)((C_word*)t0)[7])[1];
f_24370(t3,t2,((C_word*)t0)[4],C_make_character(40));}
else{
if(C_truep(C_bytevectorp(((C_word*)t0)[5]))){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25199,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4676: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t2,((C_word*)t0)[4],lf[913]);}
else{
if(C_truep(C_structurep(((C_word*)t0)[5]))){
/* library.scm:4685: ##sys#user-print-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[914]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[914]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}
else{
if(C_truep(C_closurep(((C_word*)t0)[5]))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25259,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4686: ##sys#procedure->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[915]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[915]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}
else{
if(C_truep(C_locativep(((C_word*)t0)[5]))){
/* library.scm:4687: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],lf[916]);}
else{
if(C_truep(C_lambdainfop(((C_word*)t0)[5]))){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25271,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4689: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t2,((C_word*)t0)[4],lf[917]);}
else{
if(C_truep(C_portp(((C_word*)t0)[5]))){
t2=C_slot(((C_word*)t0)[5],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25290,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
switch(t2){
case C_fix(1):
/* library.scm:4694: outstr */
t4=((C_word*)((C_word*)t0)[2])[1];
f_24298(t4,t3,((C_word*)t0)[4],lf[919]);
case C_fix(2):
/* library.scm:4695: outstr */
t4=((C_word*)((C_word*)t0)[2])[1];
f_24298(t4,t3,((C_word*)t0)[4],lf[920]);
default:
/* library.scm:4696: outstr */
t4=((C_word*)((C_word*)t0)[2])[1];
f_24298(t4,t3,((C_word*)t0)[4],lf[921]);}}
else{
if(C_truep(C_vectorp(((C_word*)t0)[5]))){
t2=C_block_size(((C_word*)t0)[5]);
t3=C_eqp(C_fix(0),t2);
if(C_truep(t3)){
/* library.scm:4702: outstr */
t4=((C_word*)((C_word*)t0)[2])[1];
f_24298(t4,((C_word*)t0)[3],((C_word*)t0)[4],lf[922]);}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25337,a[2]=t2,a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4704: outstr */
t5=((C_word*)((C_word*)t0)[2])[1];
f_24298(t5,t4,((C_word*)t0)[4],lf[923]);}}
else{
/* library.scm:4712: ##sys#error */
t2=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[924];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}}}}}}}}}}}}

/* k24932 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24934(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24934,c,av);}
/* library.scm:4632: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k24942 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24944,c,av);}
/* library.scm:4633: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k24951 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_24953(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_24953,c,av);}
a=C_alloc(10);
t2=C_block_size(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_24959,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],a[5]=t4,a[6]=((C_word*)t0)[5],a[7]=((C_word)li727),tmp=(C_word)a,a+=8,tmp));
t6=((C_word*)t4)[1];
f_24959(t6,((C_word*)t0)[6],C_fix(0),t2);}

/* doloop5368 in k24951 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_24959(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_24959,4,t0,t1,t2,t3);}
a=C_alloc(13);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
/* library.scm:4640: outchr */
t5=((C_word*)((C_word*)t0)[2])[1];
f_24370(t5,t1,((C_word*)t0)[3],C_make_character(34));}
else{
t5=C_subbyte(((C_word*)t0)[4],t2);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_24972,a[2]=((C_word*)t0)[5],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
switch(t5){
case C_fix(34):
/* library.scm:4643: outstr */
t7=((C_word*)((C_word*)t0)[6])[1];
f_24298(t7,t6,((C_word*)t0)[3],lf[910]);
case C_fix(92):
/* library.scm:4644: outstr */
t7=((C_word*)((C_word*)t0)[6])[1];
f_24298(t7,t6,((C_word*)t0)[3],lf[911]);
default:
t7=C_fixnum_lessp(t5,C_fix(32));
t8=(C_truep(t7)?t7:C_eqp(t5,C_fix(127)));
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25010,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t6,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4648: outchr */
t10=((C_word*)((C_word*)t0)[2])[1];
f_24370(t10,t9,((C_word*)t0)[3],C_make_character(92));}
else{
/* library.scm:4661: outchr */
t9=((C_word*)((C_word*)t0)[2])[1];
f_24370(t9,t6,((C_word*)t0)[3],C_fix_to_char(t5));}}}}

/* k24970 in doloop5368 in k24951 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_24972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_24972,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_24959(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)),C_fixnum_difference(((C_word*)t0)[5],C_fix(1)));}

/* k25008 in doloop5368 in k24951 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_25010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_25010,c,av);}
a=C_alloc(7);
switch(((C_word*)t0)[2]){
case C_fix(7):
/* library.scm:4650: outchr */
t2=((C_word*)((C_word*)t0)[3])[1];
f_24370(t2,((C_word*)t0)[4],((C_word*)t0)[5],C_make_character(97));
case C_fix(8):
/* library.scm:4651: outchr */
t2=((C_word*)((C_word*)t0)[3])[1];
f_24370(t2,((C_word*)t0)[4],((C_word*)t0)[5],C_make_character(98));
case C_fix(9):
/* library.scm:4652: outchr */
t2=((C_word*)((C_word*)t0)[3])[1];
f_24370(t2,((C_word*)t0)[4],((C_word*)t0)[5],C_make_character(116));
case C_fix(10):
/* library.scm:4653: outchr */
t2=((C_word*)((C_word*)t0)[3])[1];
f_24370(t2,((C_word*)t0)[4],((C_word*)t0)[5],C_make_character(110));
case C_fix(11):
/* library.scm:4654: outchr */
t2=((C_word*)((C_word*)t0)[3])[1];
f_24370(t2,((C_word*)t0)[4],((C_word*)t0)[5],C_make_character(118));
case C_fix(12):
/* library.scm:4655: outchr */
t2=((C_word*)((C_word*)t0)[3])[1];
f_24370(t2,((C_word*)t0)[4],((C_word*)t0)[5],C_make_character(102));
case C_fix(13):
/* library.scm:4656: outchr */
t2=((C_word*)((C_word*)t0)[3])[1];
f_24370(t2,((C_word*)t0)[4],((C_word*)t0)[5],C_make_character(114));
default:
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25076,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4658: outchr */
t3=((C_word*)((C_word*)t0)[3])[1];
f_24370(t3,t2,((C_word*)t0)[5],C_make_character(120));}}

/* k25074 in k25008 in doloop5368 in k24951 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_25076,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25079,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fixnum_lessp(((C_word*)t0)[5],C_fix(16)))){
/* library.scm:4659: outchr */
t3=((C_word*)((C_word*)t0)[6])[1];
f_24370(t3,t2,((C_word*)t0)[4],C_make_character(48));}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_25079(2,av2);}}}

/* k25077 in k25074 in k25008 in doloop5368 in k24951 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_25079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_25079,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25086,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4660: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_fix(16);
tp(4,av2);}}

/* k25084 in k25077 in k25074 in k25008 in doloop5368 in k24951 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_25086(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25086,c,av);}
/* library.scm:4660: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k25124 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_25126,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25129,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4665: out */
t3=((C_word*)((C_word*)t0)[5])[1];
f_24737(t3,t2,C_slot(((C_word*)t0)[2],C_fix(0)));}

/* k25127 in k25124 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25129(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_25129,c,av);}
a=C_alloc(10);
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25138,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t4,a[7]=((C_word)li728),tmp=(C_word)a,a+=8,tmp));
t6=((C_word*)t4)[1];
f_25138(t6,((C_word*)t0)[7],t2);}

/* doloop5398 in k25127 in k25124 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_25138(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_25138,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_not(C_blockp(t2));
t4=(C_truep(t3)?t3:C_i_not(C_pairp(t2)));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25151,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t6=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(C_i_not(t6))){
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25160,a[2]=((C_word*)t0)[4],a[3]=t5,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4670: outstr */
t8=((C_word*)((C_word*)t0)[5])[1];
f_24298(t8,t7,((C_word*)t0)[3],lf[912]);}
else{
/* library.scm:4672: outchr */
t7=((C_word*)((C_word*)t0)[2])[1];
f_24370(t7,t1,((C_word*)t0)[3],C_make_character(41));}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25170,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4673: outchr */
t6=((C_word*)((C_word*)t0)[2])[1];
f_24370(t6,t5,((C_word*)t0)[3],C_make_character(32));}}

/* k25149 in doloop5398 in k25127 in k25124 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25151(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25151,c,av);}
/* library.scm:4672: outchr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24370(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_make_character(41));}

/* k25158 in doloop5398 in k25127 in k25124 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25160(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_25160,c,av);}
/* library.scm:4671: out */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24737(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k25168 in doloop5398 in k25127 in k25124 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25170(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_25170,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25173,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4674: out */
t3=((C_word*)((C_word*)t0)[5])[1];
f_24737(t3,t2,C_slot(((C_word*)t0)[4],C_fix(0)));}

/* k25171 in k25168 in doloop5398 in k25127 in k25124 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_25173(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_25173,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_25138(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k25197 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25199(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_25199,c,av);}
a=C_alloc(16);
t2=C_block_size(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25205,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25210,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t5,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[3],a[8]=((C_word)li729),tmp=(C_word)a,a+=9,tmp));
t7=((C_word*)t5)[1];
f_25210(t7,t3,C_fix(0));}

/* k25203 in k25197 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25205(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25205,c,av);}
/* library.scm:4684: outchr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24370(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_make_character(125));}

/* doloop5412 in k25197 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_25210(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_25210,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_subbyte(((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25223,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t3,tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_fixnum_lessp(t3,C_fix(16)))){
/* library.scm:4682: outchr */
t5=((C_word*)((C_word*)t0)[7])[1];
f_24370(t5,t4,((C_word*)t0)[6],C_make_character(48));}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_25223(2,av2);}}}}

/* k25221 in doloop5412 in k25197 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_25223(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_25223,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25226,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25237,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4683: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=C_fix(16);
tp(4,av2);}}

/* k25224 in k25221 in doloop5412 in k25197 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_25226,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_25210(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* k25235 in k25221 in doloop5412 in k25197 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25237,c,av);}
/* library.scm:4683: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k25257 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25259,c,av);}
/* library.scm:4686: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k25269 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25271(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_25271,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25274,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25281,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4690: ##sys#lambda-info->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[773]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[773]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}}

/* k25272 in k25269 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25274,c,av);}
/* library.scm:4691: outchr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24370(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_make_character(62));}

/* k25279 in k25269 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25281(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25281,c,av);}
/* library.scm:4690: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* k25288 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_25290,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25293,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4697: outstr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_24298(t3,t2,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(3)));}

/* k25291 in k25288 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25293,c,av);}
/* library.scm:4698: outstr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_24298(t2,((C_word*)t0)[3],((C_word*)t0)[4],lf[918]);}

/* k25335 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25337(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_25337,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25340,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4705: out */
t3=((C_word*)((C_word*)t0)[5])[1];
f_24737(t3,t2,C_slot(((C_word*)t0)[6],C_fix(0)));}

/* k25338 in k25335 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25340(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_25340,c,av);}
a=C_alloc(10);
t2=C_fixnum_difference(((C_word*)t0)[2],C_fix(1));
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25349,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t4,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word)li730),tmp=(C_word)a,a+=8,tmp));
t6=((C_word*)t4)[1];
f_25349(t6,((C_word*)t0)[7],C_fix(1),t2);}

/* doloop5436 in k25338 in k25335 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_25349(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_25349,4,t0,t1,t2,t3);}
a=C_alloc(8);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
/* library.scm:4709: outchr */
t5=((C_word*)((C_word*)t0)[2])[1];
f_24370(t5,t1,((C_word*)t0)[3],C_make_character(41));}
else{
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25362,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4710: outchr */
t6=((C_word*)((C_word*)t0)[2])[1];
f_24370(t6,t5,((C_word*)t0)[3],C_make_character(32));}}

/* k25360 in doloop5436 in k25338 in k25335 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25362(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_25362,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25365,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4711: out */
t3=((C_word*)((C_word*)t0)[6])[1];
f_24737(t3,t2,C_slot(((C_word*)t0)[7],((C_word*)t0)[4]));}

/* k25363 in k25360 in doloop5436 in k25338 in k25335 in k24925 in out in k24294 in k24291 in k24288 in ##sys#print in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_25365(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25365,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_25349(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)),C_fixnum_difference(((C_word*)t0)[5],C_fix(1)));}

/* ##sys#procedure->string in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_25390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_25390,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25394,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4718: ##sys#lambda-info */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[772]);
C_word *av2=av;
av2[0]=*((C_word*)lf[772]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k25392 in ##sys#procedure->string in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25394(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_25394,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25404,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:4720: ##sys#lambda-info->string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[773]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[773]+1);
av2[1]=t2;
av2[2]=t1;
tp(3,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[927];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k25402 in k25392 in ##sys#procedure->string in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25404(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25404,c,av);}
/* library.scm:4720: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[925];
av2[3]=t1;
av2[4]=lf[926];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.base#record-printer in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_25407(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25407,c,av);}
t3=C_i_check_symbol_2(t2,lf[929]);
t4=C_i_assq(t2,C_fast_retrieve(lf[928]));
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?C_i_cdr(t4):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* chicken.base#set-record-printer! in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_25422(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_25422,c,av);}
a=C_alloc(5);
t4=C_i_check_symbol_2(t2,lf[930]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25429,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4734: ##sys#check-closure */
t6=*((C_word*)lf[374]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
av2[3]=lf[930];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k25427 in chicken.base#set-record-printer! in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25429(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_25429,c,av);}
a=C_alloc(6);
t2=C_i_assq(((C_word*)t0)[2],C_fast_retrieve(lf[928]));
if(C_truep(t2)){
t3=C_i_setslot(t2,C_fix(1),((C_word*)t0)[3]);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t4=C_a_i_cons(&a,2,t3,C_fast_retrieve(lf[928]));
t5=C_mutate((C_word*)lf[928]+1 /* (set! ##sys#record-printers ...) */,t4);
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in ... */
static void C_ccall f_25451(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(93,c,6)))){
C_save_and_reclaim((void *)f_25451,c,av);}
a=C_alloc(93);
t2=C_mutate((C_word*)lf[204]+1 /* (set! chicken.base#record-printer ...) */,t1);
t3=C_mutate((C_word*)lf[914]+1 /* (set! ##sys#user-print-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25453,a[2]=((C_word)li743),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[942]+1 /* (set! ##sys#with-print-length-limit ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25604,a[2]=((C_word)li748),tmp=(C_word)a,a+=3,tmp));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25689,a[2]=t6,a[3]=((C_word)li749),tmp=(C_word)a,a+=4,tmp);
t8=C_set_block_item(t6,0,t7);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32500,a[2]=((C_word)li750),tmp=(C_word)a,a+=3,tmp);
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32525,a[2]=((C_word)li751),tmp=(C_word)a,a+=3,tmp);
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32543,a[2]=t6,a[3]=((C_word)li752),tmp=(C_word)a,a+=4,tmp);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32562,a[2]=t6,a[3]=((C_word)li753),tmp=(C_word)a,a+=4,tmp);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32581,a[2]=((C_word)li754),tmp=(C_word)a,a+=3,tmp);
t14=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32584,a[2]=((C_word)li755),tmp=(C_word)a,a+=3,tmp);
t15=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32587,a[2]=((C_word)li756),tmp=(C_word)a,a+=3,tmp);
t16=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32628,a[2]=((C_word)li760),tmp=(C_word)a,a+=3,tmp);
t17=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32712,a[2]=((C_word)li761),tmp=(C_word)a,a+=3,tmp);
t18=C_a_i_vector(&a,10,t9,t10,t11,t12,*((C_word*)lf[196]+1),t13,t14,t15,t16,t17);
t19=C_mutate((C_word*)lf[947]+1 /* (set! ##sys#string-port-class ...) */,t18);
t20=C_mutate((C_word*)lf[945]+1 /* (set! ##sys#scan-buffer-line ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25745,a[2]=((C_word)li768),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate((C_word*)lf[214]+1 /* (set! chicken.base#open-input-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25942,a[2]=((C_word)li769),tmp=(C_word)a,a+=3,tmp));
t22=C_mutate((C_word*)lf[215]+1 /* (set! chicken.base#open-output-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25961,a[2]=((C_word)li770),tmp=(C_word)a,a+=3,tmp));
t23=C_mutate((C_word*)lf[213]+1 /* (set! chicken.base#get-output-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25980,a[2]=((C_word)li771),tmp=(C_word)a,a+=3,tmp));
t24=*((C_word*)lf[213]+1);
t25=*((C_word*)lf[215]+1);
t26=C_mutate((C_word*)lf[957]+1 /* (set! ##sys#print-to-string ...) */,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26014,a[2]=t24,a[3]=t25,a[4]=((C_word)li774),tmp=(C_word)a,a+=5,tmp));
t27=C_mutate((C_word*)lf[909]+1 /* (set! ##sys#pointer->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26057,a[2]=((C_word)li775),tmp=(C_word)a,a+=3,tmp));
t28=C_mutate((C_word*)lf[186]+1 /* (set! chicken.base#get-call-chain ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26110,a[2]=((C_word)li777),tmp=(C_word)a,a+=3,tmp));
t29=C_mutate((C_word*)lf[966]+1 /* (set! ##sys#really-print-call-chain ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26264,a[2]=((C_word)li781),tmp=(C_word)a,a+=3,tmp));
t30=C_mutate((C_word*)lf[187]+1 /* (set! chicken.base#print-call-chain ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26369,a[2]=((C_word)li782),tmp=(C_word)a,a+=3,tmp));
t31=C_mutate((C_word*)lf[974]+1 /* (set! ##sys#user-interrupt-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26460,a[2]=((C_word)li784),tmp=(C_word)a,a+=3,tmp));
t32=lf[977] /* exit-in-progress */ =C_SCHEME_FALSE;;
t33=C_mutate(&lf[978] /* (set! cleanup-before-exit ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26482,a[2]=((C_word)li787),tmp=(C_word)a,a+=3,tmp));
t34=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26585,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t35=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32476,a[2]=((C_word)li1019),tmp=(C_word)a,a+=3,tmp);
/* library.scm:5080: chicken.base#make-parameter */
t36=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t36;
av2[1]=t34;
av2[2]=t35;
((C_proc)(void*)(*((C_word*)t36+1)))(3,av2);}}

/* ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25453(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_25453,c,av);}
a=C_alloc(10);
t5=C_slot(t2,C_fix(0));
t6=C_i_assq(t5,C_fast_retrieve(lf[928]));
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25466,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25471,a[2]=t4,a[3]=t5,a[4]=t6,a[5]=t2,a[6]=((C_word)li742),tmp=(C_word)a,a+=7,tmp);
/* library.scm:4750: scheme#call-with-current-continuation */
t9=*((C_word*)lf[132]+1);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t7;
av2[2]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25556,a[2]=t1,a[3]=t4,a[4]=t5,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4762: ##sys#print */
t8=*((C_word*)lf[887]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=lf[941];
av2[3]=C_SCHEME_FALSE;
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}}

/* k25464 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25466(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25466,c,av);}
/* library.scm:4750: g5482 */
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)C_fast_retrieve_proc(t2))(2,av2);}}

/* a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25471(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_25471,c,av);}
a=C_alloc(13);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25477,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word)li737),tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25528,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=((C_word)li741),tmp=(C_word)a,a+=7,tmp);
/* library.scm:4750: chicken.condition#with-exception-handler */
t5=C_fast_retrieve(lf[937]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t3;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* a25476 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25477(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_25477,c,av);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25483,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word)li736),tmp=(C_word)a,a+=6,tmp);
/* library.scm:4750: k5479 */
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}

/* a25482 in a25476 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_25483,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25487,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4752: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[936];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k25485 in a25482 in a25476 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_25487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_25487,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25490,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25526,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4753: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k25488 in k25485 in a25482 in a25476 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_25490,c,av);}
a=C_alloc(5);
if(C_truep(C_i_structurep(((C_word*)t0)[2],lf[932]))){
t2=C_slot(((C_word*)t0)[2],C_fix(2));
t3=C_i_member(lf[933],t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25505,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4756: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[934];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
/* library.scm:4759: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[935];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k25503 in k25488 in k25485 in a25482 in a25476 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25505(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_25505,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25508,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4757: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k25506 in k25503 in k25488 in k25485 in a25482 in a25476 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_25508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25508,c,av);}
/* library.scm:4758: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(62);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k25524 in k25485 in a25482 in a25476 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25526,c,av);}
/* library.scm:4753: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a25527 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25528(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_25528,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25534,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word)li738),tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25543,a[2]=((C_word*)t0)[5],a[3]=((C_word)li740),tmp=(C_word)a,a+=4,tmp);
/* library.scm:4750: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a25533 in a25527 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25534(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25534,c,av);}
/* library.scm:4750: g5492 */
t2=C_slot(((C_word*)t0)[2],C_fix(1));{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}

/* a25542 in a25527 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25543(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_25543,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25549,a[2]=t2,a[3]=((C_word)li739),tmp=(C_word)a,a+=4,tmp);
/* library.scm:4750: k5479 */
t4=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}

/* a25548 in a25542 in a25527 in a25470 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_25549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_25549,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
C_apply_values(3,av2);}}

/* k25554 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25556(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_25556,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25559,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25602,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4763: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k25557 in k25554 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25559(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_25559,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25562,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_eqp(((C_word*)t0)[4],lf[932]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25571,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4766: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[938];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=C_eqp(((C_word*)t0)[4],lf[939]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25587,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4769: ##sys#print */
t6=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[940];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
/* library.scm:4771: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(62);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}}}

/* k25560 in k25557 in k25554 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25562,c,av);}
/* library.scm:4771: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(62);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}

/* k25569 in k25557 in k25554 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25571(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25571,c,av);}
/* library.scm:4767: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_slot(((C_word*)t0)[3],C_fix(1));
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k25585 in k25557 in k25554 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25587(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25587,c,av);}
/* library.scm:4770: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_slot(((C_word*)t0)[3],C_fix(6));
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k25600 in k25554 in ##sys#user-print-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25602,c,av);}
/* library.scm:4763: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25604(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_25604,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25610,a[2]=t2,a[3]=t3,a[4]=((C_word)li747),tmp=(C_word)a,a+=5,tmp);
/* library.scm:4776: call-with-current-continuation */
t5=*((C_word*)lf[132]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25610(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(27,c,4)))){
C_save_and_reclaim((void *)f_25610,c,av);}
a=C_alloc(27);
t3=C_fast_retrieve(lf[891]);
t4=C_retrieve2(lf[892],C_text("##sys#print-exit"));
t5=C_retrieve2(lf[890],C_text("current-print-length"));
t6=((C_word*)t0)[2];
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=t2;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_fix(0);
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_TRUE;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25616,a[2]=t7,a[3]=t9,a[4]=t11,a[5]=t13,a[6]=t3,a[7]=((C_word)li744),tmp=(C_word)a,a+=8,tmp);
t15=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25659,a[2]=((C_word*)t0)[3],a[3]=((C_word)li745),tmp=(C_word)a,a+=4,tmp);
t16=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25665,a[2]=t7,a[3]=t9,a[4]=t11,a[5]=t3,a[6]=((C_word)li746),tmp=(C_word)a,a+=7,tmp);
/* library.scm:4778: ##sys#dynamic-wind */
t17=*((C_word*)lf[710]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t17;
av2[1]=t1;
av2[2]=t14;
av2[3]=t15;
av2[4]=t16;
((C_proc)(void*)(*((C_word*)t17+1)))(5,av2);}}

/* a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25616(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_25616,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25620,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
/* library.scm:4778: ##sys#print-length-limit5512 */
t3=((C_word*)t0)[6];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)C_fast_retrieve_proc(t3))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_25620(2,av2);}}}

/* k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25620(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_25620,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25623,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
/* library.scm:4778: ##sys#print-exit5513 */
t3=C_retrieve2(lf[892],C_text("##sys#print-exit"));{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[3])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[3])[1];
f_25623(2,av2);}}}

/* k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_25623(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_25623,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_25626,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
/* library.scm:4778: current-print-length55145515 */
t3=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[4])[1];
f_25626(2,av2);}}}

/* k25624 in k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_25626,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_25630,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* library.scm:4778: ##sys#print-length-limit5512 */
t3=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)C_fast_retrieve_proc(t3))(2,av2);}}

/* k25628 in k25624 in k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_25630,c,av);}
a=C_alloc(10);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_25634,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
/* library.scm:4778: ##sys#print-exit5513 */
t4=C_retrieve2(lf[892],C_text("##sys#print-exit"));{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k25632 in k25628 in k25624 in k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_25634(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_25634,c,av);}
a=C_alloc(9);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25638,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4778: current-print-length55145515 */
t4=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k25636 in k25632 in k25628 in k25624 in k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25638(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_25638,c,av);}
a=C_alloc(6);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25641,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4778: ##sys#print-length-limit5512 */
t4=((C_word*)t0)[7];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)C_fast_retrieve_proc(t4))(5,av2);}}

/* k25639 in k25636 in k25632 in k25628 in k25624 in k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_25641(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_25641,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25644,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:4778: ##sys#print-exit5513 */
t3=C_retrieve2(lf[892],C_text("##sys#print-exit"));{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k25642 in k25639 in k25636 in k25632 in k25628 in k25624 in k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_25644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_25644,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25647,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4778: current-print-length55145515 */
t3=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k25645 in k25642 in k25639 in k25636 in k25632 in k25628 in k25624 in k25621 in k25618 in a25615 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_25647(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25647,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a25658 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25659,c,av);}
/* library.scm:4781: thunk */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)C_fast_retrieve_proc(t2))(2,av2);}}

/* a25664 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25665(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_25665,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25669,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:4778: ##sys#print-length-limit5512 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)C_fast_retrieve_proc(t3))(2,av2);}}

/* k25667 in a25664 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25669(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_25669,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25672,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4778: ##sys#print-exit5513 */
t3=C_retrieve2(lf[892],C_text("##sys#print-exit"));{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k25670 in k25667 in a25664 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_25672(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_25672,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25675,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4778: current-print-length55145515 */
t3=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k25673 in k25670 in k25667 in a25664 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25675(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_25675,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25678,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4778: ##sys#print-length-limit5512 */
t3=((C_word*)t0)[8];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)C_fast_retrieve_proc(t3))(5,av2);}}

/* k25676 in k25673 in k25670 in k25667 in a25664 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_25678(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_25678,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25681,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4778: ##sys#print-exit5513 */
t3=C_retrieve2(lf[892],C_text("##sys#print-exit"));{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k25679 in k25676 in k25673 in k25670 in k25667 in a25664 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_25681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_25681,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25684,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4778: current-print-length55145515 */
t3=C_retrieve2(lf[890],C_text("current-print-length"));{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[6])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k25682 in k25679 in k25676 in k25673 in k25670 in k25667 in a25664 in a25609 in ##sys#with-print-length-limit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_25684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25684,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)t0)[5]);
t4=C_mutate(((C_word *)((C_word*)t0)[6])+1,((C_word*)t0)[7]);
t5=((C_word*)t0)[8];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* check5556 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25689(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_25689,c,av);}
a=C_alloc(9);
t4=C_slot(t2,C_fix(10));
t5=C_slot(t2,C_fix(11));
t6=C_slot(t2,C_fix(12));
t7=C_fixnum_plus(t4,t3);
if(C_truep(C_fixnum_greater_or_equal_p(t7,t5))){
t8=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25711,a[2]=t5,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=t3,a[7]=t6,a[8]=t4,tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_fixnum_greater_or_equal_p(t7,lf[274]))){
/* library.scm:4809: ##sys#error */
t9=*((C_word*)lf[155]+1);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[944];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
t9=t8;{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_SCHEME_UNDEFINED;
f_25711(2,av2);}}}
else{
t8=C_SCHEME_UNDEFINED;
t9=t1;{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}

/* k25709 in check5556 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_25711,c,av);}
a=C_alloc(9);
t2=C_fixnum_plus(((C_word*)t0)[2],((C_word*)t0)[2]);
t3=C_i_fixnum_min(lf[274],t2);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_25717,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* library.scm:4811: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}

/* k25715 in k25709 in check5556 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,6)))){
C_save_and_reclaim((void *)f_25717,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25720,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:4812: ##sys#copy-bytes */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[943]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[943]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=t1;
av2[4]=C_fix(0);
av2[5]=C_fix(0);
av2[6]=((C_word*)t0)[8];
tp(7,av2);}}

/* k25718 in k25715 in k25709 in check5556 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_25720,c,av);}
t2=C_i_setslot(((C_word*)t0)[2],C_fix(12),((C_word*)t0)[3]);
t3=C_i_set_i_slot(((C_word*)t0)[2],C_fix(11),((C_word*)t0)[4]);
/* library.scm:4815: check */
t4=((C_word*)((C_word*)t0)[5])[1];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[6];
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[7];
((C_proc)C_fast_retrieve_proc(t4))(4,av2);}}

/* ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25745(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(11,c,7)))){
C_save_and_reclaim((void *)f_25745,c,av);}
a=C_alloc(11);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25748,a[2]=((C_word)li762),tmp=(C_word)a,a+=3,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25768,a[2]=t5,a[3]=t8,a[4]=t6,a[5]=((C_word)li767),tmp=(C_word)a,a+=6,tmp));
t10=((C_word*)t8)[1];
f_25768(t10,t1,t2,t4,t4,t3,lf[950]);}

/* copy&append in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_fcall f_25748(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_25748,5,t1,t2,t3,t4,t5);}
a=C_alloc(8);
t6=C_block_size(t5);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_25755,a[2]=t5,a[3]=t6,a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t8=C_fixnum_difference(t4,t3);
/* library.scm:4892: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t7;
av2[2]=C_fixnum_plus(t6,t8);
tp(3,av2);}}

/* k25753 in copy&append in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25755,c,av);}
t2=C_substring_copy(((C_word*)t0)[2],t1,C_fix(0),((C_word*)t0)[3],C_fix(0));
t3=C_substring_copy(((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[3]);
t4=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_fcall f_25768(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,5)))){
C_save_and_reclaim_args((void *)trf_25768,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(12);
t7=C_eqp(t4,t5);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25778,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4902: copy&append */
f_25748(t8,t2,t3,t4,t6);}
else{
t8=C_subchar(t2,t4);
t9=C_eqp(t8,C_make_character(10));
if(C_truep(t9)){
t10=C_fixnum_plus(t4,C_fix(1));
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25816,a[2]=t1,a[3]=t10,tmp=(C_word)a,a+=4,tmp);
/* library.scm:4909: copy&append */
f_25748(t11,t2,t3,t4,t6);}
else{
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_25822,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=t3,a[7]=t6,a[8]=t8,a[9]=t5,a[10]=((C_word*)t0)[2],a[11]=((C_word*)t0)[3],tmp=(C_word)a,a+=12,tmp);
t11=C_eqp(t8,C_make_character(13));
if(C_truep(t11)){
t12=C_fixnum_plus(t4,C_fix(1));
if(C_truep(C_fixnum_greaterp(t5,t12))){
t13=C_fixnum_plus(t4,C_fix(1));
t14=t10;
f_25822(t14,C_eqp(C_subchar(t2,t13),C_make_character(10)));}
else{
t13=t10;
f_25822(t13,C_SCHEME_FALSE);}}
else{
t12=t10;
f_25822(t12,C_SCHEME_FALSE);}}}}

/* k25776 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,5)))){
C_save_and_reclaim((void *)f_25778,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25783,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li763),tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25789,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=((C_word)li764),tmp=(C_word)a,a+=5,tmp);
/* library.scm:4903: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a25782 in k25776 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25783(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_25783,c,av);}
/* library.scm:4903: eos-handler */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* a25788 in k25776 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25789(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_25789,c,av);}
if(C_truep(t2)){
/* library.scm:4905: loop */
t5=((C_word*)((C_word*)t0)[2])[1];
f_25768(t5,t1,t2,t3,t3,t4,((C_word*)t0)[3]);}
else{
/* library.scm:4906: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t3;
av2[3]=((C_word*)t0)[3];
av2[4]=C_SCHEME_FALSE;
C_values(5,av2);}}}

/* k25814 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25816(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25816,c,av);}
/* library.scm:4909: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=C_SCHEME_TRUE;
C_values(5,av2);}}

/* k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_25822(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,6)))){
C_save_and_reclaim_args((void *)trf_25822,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_fixnum_plus(((C_word*)t0)[2],C_fix(2));
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25833,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:4913: copy&append */
f_25748(t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[2],((C_word*)t0)[7]);}
else{
t2=C_eqp(((C_word*)t0)[8],C_make_character(13));
t3=(C_truep(t2)?C_eqp(((C_word*)t0)[9],C_fixnum_plus(((C_word*)t0)[2],C_fix(1))):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_25842,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* library.scm:4916: copy&append */
f_25748(t4,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[2],((C_word*)t0)[7]);}
else{
t4=C_eqp(((C_word*)t0)[8],C_make_character(13));
if(C_truep(t4)){
t5=C_fixnum_plus(((C_word*)t0)[2],C_fix(1));
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25902,a[2]=((C_word*)t0)[3],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:4927: copy&append */
f_25748(t6,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[2],((C_word*)t0)[7]);}
else{
/* library.scm:4928: loop */
t5=((C_word*)((C_word*)t0)[11])[1];
f_25768(t5,((C_word*)t0)[3],((C_word*)t0)[5],((C_word*)t0)[6],C_fixnum_plus(((C_word*)t0)[2],C_fix(1)),((C_word*)t0)[9],((C_word*)t0)[7]);}}}}

/* k25831 in k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25833(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25833,c,av);}
/* library.scm:4913: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=C_SCHEME_TRUE;
C_values(5,av2);}}

/* k25840 in k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,5)))){
C_save_and_reclaim((void *)f_25842,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25847,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li765),tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_25853,a[2]=t1,a[3]=((C_word*)t0)[4],a[4]=((C_word)li766),tmp=(C_word)a,a+=5,tmp);
/* library.scm:4917: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[5];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a25846 in k25840 in k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_25847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_25847,c,av);}
/* library.scm:4917: eos-handler */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* a25852 in k25840 in k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_25853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_25853,c,av);}
a=C_alloc(7);
if(C_truep(t2)){
t5=C_eqp(C_subchar(t2,t3),C_make_character(10));
if(C_truep(t5)){
/* library.scm:4920: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=C_fixnum_plus(t3,C_fix(1));
av2[3]=((C_word*)t0)[2];
av2[4]=C_SCHEME_TRUE;
C_values(5,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_25877,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=t4,tmp=(C_word)a,a+=7,tmp);
/* library.scm:4923: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[421]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[948];
tp(4,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25885,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:4925: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[421]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[949];
tp(4,av2);}}}

/* k25875 in a25852 in k25840 in k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_25877,c,av);}
/* library.scm:4922: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_25768(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[5],((C_word*)t0)[6],t1);}

/* k25883 in a25852 in k25840 in k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_25885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25885,c,av);}
/* library.scm:4925: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=C_SCHEME_TRUE;
C_values(5,av2);}}

/* k25900 in k25820 in loop in ##sys#scan-buffer-line in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_25902(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_25902,c,av);}
/* library.scm:4927: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=C_SCHEME_TRUE;
C_values(5,av2);}}

/* chicken.base#open-input-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_25942,c,av);}
a=C_alloc(4);
t3=C_i_check_string_2(t2,lf[951]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25949,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:4933: ##sys#make-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[716]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[716]+1);
av2[1]=t4;
av2[2]=C_fix(1);
av2[3]=C_fast_retrieve(lf[947]);
av2[4]=lf[952];
av2[5]=lf[953];
tp(6,av2);}}

/* k25947 in chicken.base#open-input-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25949,c,av);}
t2=C_i_set_i_slot(t1,C_fix(11),C_block_size(((C_word*)t0)[2]));
t3=C_i_set_i_slot(t1,C_fix(10),C_fix(0));
t4=C_i_setslot(t1,C_fix(12),((C_word*)t0)[2]);
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* chicken.base#open-output-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25961(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_25961,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_25965,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4941: ##sys#make-port */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[716]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[716]+1);
av2[1]=t2;
av2[2]=C_fix(2);
av2[3]=C_fast_retrieve(lf[947]);
av2[4]=lf[954];
av2[5]=lf[953];
tp(6,av2);}}

/* k25963 in chicken.base#open-output-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_25965(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_25965,c,av);}
a=C_alloc(4);
t2=C_i_set_i_slot(t1,C_fix(10),C_fix(0));
t3=C_i_set_i_slot(t1,C_fix(11),C_fix(256));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_25978,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:4944: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t4;
av2[2]=C_fix(256);
tp(3,av2);}}

/* k25976 in k25963 in chicken.base#open-output-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_25978(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_25978,c,av);}
t2=C_i_setslot(((C_word*)t0)[2],C_fix(12),t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#get-output-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_25980(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_25980,c,av);}
t3=C_i_check_port_2(t2,C_fix(2),C_SCHEME_FALSE,lf[955]);
t4=C_slot(t2,C_fix(7));
t5=C_eqp(lf[953],t4);
if(C_truep(C_i_not(t5))){
/* library.scm:4951: ##sys#signal-hook */
t6=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=lf[955];
av2[4]=lf[956];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(6,av2);}}
else{
/* library.scm:4953: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t1;
av2[2]=C_slot(t2,C_fix(12));
av2[3]=C_fix(0);
av2[4]=C_slot(t2,C_fix(10));
tp(5,av2);}}}

/* ##sys#print-to-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_26014(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_26014,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26018,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4959: open-output-string */
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k26016 in ##sys#print-to-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26018(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_26018,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26019,a[2]=t1,a[3]=((C_word)li772),tmp=(C_word)a,a+=4,tmp);
t3=C_i_check_list_2(((C_word*)t0)[2],lf[706]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26029,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26034,a[2]=t6,a[3]=t2,a[4]=((C_word)li773),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_26034(t8,t4,((C_word*)t0)[2]);}

/* g5686 in k26016 in ##sys#print-to-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_26019(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_26019,3,t0,t1,t2);}
/* library.scm:4960: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k26027 in k26016 in ##sys#print-to-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_26029(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26029,c,av);}
/* library.scm:4961: get-output-string */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* for-each-loop5685 in k26016 in ##sys#print-to-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_26034(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_26034,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26044,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4960: g5686 */
t4=((C_word*)t0)[3];
f_26019(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k26042 in for-each-loop5685 in k26016 in ##sys#print-to-string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26044(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26044,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_26034(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* ##sys#pointer->string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_26057(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_26057,c,av);}
a=C_alloc(7);
if(C_truep(C_taggedpointerp(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26068,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=C_slot(t2,C_fix(1));
if(C_truep(C_i_pairp(t4))){
t5=C_u_i_car(t4);
t6=C_a_i_list1(&a,1,t5);
/* library.scm:4969: ##sys#print-to-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[957]);
C_word *av2=av;
av2[0]=*((C_word*)lf[957]+1);
av2[1]=t3;
av2[2]=t6;
tp(3,av2);}}
else{
t5=C_a_i_list1(&a,1,t4);
/* library.scm:4969: ##sys#print-to-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[957]);
C_word *av2=av;
av2[0]=*((C_word*)lf[957]+1);
av2[1]=t3;
av2[2]=t5;
tp(3,av2);}}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26098,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26102,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4975: ##sys#pointer->address */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[961]);
C_word *av2=av;
av2[0]=*((C_word*)lf[961]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}}

/* k26066 in ##sys#pointer->string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26068(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_26068,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26072,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26076,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:4973: ##sys#pointer->address */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[961]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[961]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k26070 in k26066 in ##sys#pointer->string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_26072(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_26072,c,av);}
/* library.scm:4967: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[958];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[959];
av2[5]=t1;
av2[6]=lf[960];
((C_proc)(void*)(*((C_word*)t2+1)))(7,av2);}}

/* k26074 in k26066 in ##sys#pointer->string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_26076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_26076,c,av);}
/* library.scm:4973: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_fix(16);
tp(4,av2);}}

/* k26096 in ##sys#pointer->string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26098(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26098,c,av);}
/* library.scm:4975: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[962];
av2[3]=t1;
av2[4]=lf[963];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k26100 in ##sys#pointer->string in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_26102,c,av);}
/* library.scm:4975: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_fix(16);
tp(4,av2);}}

/* chicken.base#get-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_26110(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_26110,c,av);}
a=C_alloc(6);
t2=C_rest_nullp(c,2);
t3=(C_truep(t2)?C_fix(0):C_get_rest_arg(c,2,av,2,t0));
t4=C_rest_nullp(c,2);
t5=C_rest_nullp(c,3);
t6=(C_truep(t5)?C_fast_retrieve(lf[964]):C_get_rest_arg(c,3,av,2,t0));
t7=C_rest_nullp(c,3);
t8=C_fix((C_word)C_trace_buffer_size);
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26126,a[2]=t3,a[3]=t8,a[4]=t6,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4989: ##sys#make-vector */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[691]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[691]+1);
av2[1]=t9;
av2[2]=C_fixnum_times(C_fix(5),t8);
av2[3]=C_SCHEME_FALSE;
tp(4,av2);}}

/* k26124 in chicken.base#get-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_26126,c,av);}
a=C_alloc(10);
t2=C_fetch_trace(((C_word*)t0)[2],t1);
t3=C_fixnump(t2);
t4=(C_truep(t3)?t2:C_fixnum_times(C_fix(5),((C_word*)t0)[3]));
t5=(C_truep(((C_word*)t0)[4])?C_slot(((C_word*)t0)[4],C_fix(14)):C_SCHEME_FALSE);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_26137,a[2]=t4,a[3]=t1,a[4]=t7,a[5]=((C_word*)t0)[4],a[6]=t5,a[7]=((C_word)li776),tmp=(C_word)a,a+=8,tmp));
t9=((C_word*)t7)[1];
f_26137(t9,((C_word*)t0)[5],C_fix(0));}

/* loop in k26124 in chicken.base#get-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_26137(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_26137,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_fixnum_plus(t2,C_fix(4));
t4=C_slot(((C_word*)t0)[3],t3);
t5=C_i_not(t4);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26156,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t5)){
t7=t6;
f_26156(t7,t5);}
else{
t7=C_i_not(((C_word*)t0)[5]);
t8=t6;
f_26156(t8,(C_truep(t7)?t7:C_eqp(((C_word*)t0)[6],t4)));}}}

/* k26154 in loop in k26124 in chicken.base#get-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_26156(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_26156,2,t0,t1);}
a=C_alloc(11);
if(C_truep(t1)){
t2=C_fixnum_plus(((C_word*)t0)[2],C_fix(1));
t3=C_slot(((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26178,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(t3)){
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
f_26178(2,av2);}}
else{
t5=C_slot(((C_word*)t0)[3],((C_word*)t0)[2]);
t6=C_a_i_bytevector(&a,1,C_fix(3));
/* library.scm:4984: ##sys#peek-nonnull-c-string */
t7=*((C_word*)lf[965]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t4;
av2[2]=stub5708(t6,t5);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
/* library.scm:5004: loop */
t2=((C_word*)((C_word*)t0)[5])[1];
f_26137(t2,((C_word*)t0)[4],C_fixnum_plus(((C_word*)t0)[2],C_fix(5)));}}

/* k26165 in k26176 in k26154 in loop in k26124 in chicken.base#get-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_26167(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_26167,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k26176 in k26154 in loop in k26124 in chicken.base#get-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_26178,c,av);}
a=C_alloc(8);
t2=C_fixnum_plus(((C_word*)t0)[2],C_fix(2));
t3=C_slot(((C_word*)t0)[3],t2);
t4=C_fixnum_plus(((C_word*)t0)[2],C_fix(3));
t5=C_slot(((C_word*)t0)[3],t4);
t6=C_a_i_vector3(&a,3,t1,t3,t5);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26167,a[2]=((C_word*)t0)[4],a[3]=t6,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5003: loop */
t8=((C_word*)((C_word*)t0)[5])[1];
f_26137(t8,t7,C_fixnum_plus(((C_word*)t0)[2],C_fix(5)));}

/* ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_26264(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_26264,c,av);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t3))){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26274,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5008: ##sys#print */
t6=*((C_word*)lf[887]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
av2[3]=C_SCHEME_FALSE;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=C_SCHEME_UNDEFINED;
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_26274,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26275,a[2]=((C_word*)t0)[2],a[3]=((C_word)li779),tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26341,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26346,a[2]=t5,a[3]=t2,a[4]=((C_word)li780),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_26346(t7,t3,((C_word*)t0)[4]);}

/* g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_26275(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_26275,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_slot(t2,C_fix(1));
t4=C_slot(t2,C_fix(2));
t5=C_i_structurep(t4,lf[967]);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_26288,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t5,a[6]=t4,a[7]=t2,tmp=(C_word)a,a+=8,tmp);
/* library.scm:5014: ##sys#print */
t7=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[970];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}

/* k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26288(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_26288,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26291,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:5015: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_slot(((C_word*)t0)[7],C_fix(0));
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k26289 in k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26291(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_26291,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26294,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* library.scm:5016: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[969];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k26292 in k26289 in k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_26294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_26294,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26297,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26312,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
if(C_truep(((C_word*)t0)[5])){
t4=t3;
f_26312(t4,C_slot(((C_word*)t0)[6],C_fix(1)));}
else{
t4=C_SCHEME_UNDEFINED;
t5=t3;
f_26312(t5,t4);}}
else{
t4=t3;
f_26312(t4,C_SCHEME_FALSE);}}

/* k26295 in k26292 in k26289 in k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_26297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_26297,c,av);}
a=C_alloc(5);
if(C_truep(((C_word*)t0)[2])){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26305,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word)li778),tmp=(C_word)a,a+=5,tmp);
/* library.scm:5026: ##sys#with-print-length-limit */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[942]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[942]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=C_fix(100);
av2[3]=t2;
tp(4,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a26304 in k26295 in k26292 in k26289 in k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_26305(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26305,c,av);}
/* library.scm:5029: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k26310 in k26292 in k26289 in k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_26312(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_26312,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26315,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5018: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word av2[4];
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t2;
av2[2]=C_make_character(91);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_26297(2,av2);}}}

/* k26313 in k26310 in k26292 in k26289 in k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_26315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_26315,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26318,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
/* library.scm:5019: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_slot(((C_word*)t0)[5],C_fix(1));
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* library.scm:5019: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k26316 in k26313 in k26310 in k26292 in k26289 in k26286 in g5755 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_26318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26318,c,av);}
/* library.scm:5024: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[968];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k26339 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_26341(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26341,c,av);}
/* library.scm:5031: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[971];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* for-each-loop5754 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_26346(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_26346,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26356,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5009: g5755 */
t4=((C_word*)t0)[3];
f_26275(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k26354 in for-each-loop5754 in k26272 in ##sys#really-print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26356(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26356,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_26346(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.base#print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_26369(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_26369,c,av);}
a=C_alloc(7);
t2=C_rest_nullp(c,2);
t3=(C_truep(t2)?*((C_word*)lf[733]+1):C_get_rest_arg(c,2,av,2,t0));
t4=C_rest_nullp(c,2);
t5=C_rest_nullp(c,3);
t6=(C_truep(t5)?C_fix(0):C_get_rest_arg(c,3,av,2,t0));
t7=C_rest_nullp(c,3);
t8=C_rest_nullp(c,4);
t9=(C_truep(t8)?C_fast_retrieve(lf[964]):C_get_rest_arg(c,4,av,2,t0));
t10=C_rest_nullp(c,4);
t11=C_rest_nullp(c,5);
t12=(C_truep(t11)?lf[972]:C_get_rest_arg(c,5,av,2,t0));
t13=C_rest_nullp(c,5);
t14=C_i_check_port_2(t3,C_fix(2),C_SCHEME_TRUE,lf[973]);
t15=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26400,a[2]=t12,a[3]=t1,a[4]=t3,a[5]=t6,a[6]=t9,tmp=(C_word)a,a+=7,tmp);
/* library.scm:5038: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t15;
av2[2]=t6;
av2[3]=lf[973];
tp(4,av2);}}

/* k26398 in chicken.base#print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26400(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_26400,c,av);}
a=C_alloc(5);
t2=C_i_check_string_2(((C_word*)t0)[2],lf[973]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26410,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5040: chicken.base#get-call-chain */
t4=*((C_word*)lf[186]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k26408 in k26398 in chicken.base#print-call-chain in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_26410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26410,c,av);}
/* library.scm:5040: ##sys#really-print-call-chain */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[966]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[966]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
tp(5,av2);}}

/* ##sys#user-interrupt-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_26460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_26460,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26463,a[2]=((C_word)li783),tmp=(C_word)a,a+=3,tmp);
t3=C_eqp(C_fast_retrieve(lf[964]),C_fast_retrieve(lf[976]));
if(C_truep(t3)){
/* library.scm:5046: ##sys#signal-hook */
t4=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[975];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_setslot(C_fast_retrieve(lf[976]),C_fix(1),t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* break in ##sys#user-interrupt-hook in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_26463,c,av);}
/* library.scm:5046: ##sys#signal-hook */
t2=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=lf[975];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_fcall f_26482(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_26482,1,t1);}
a=C_alloc(6);
t2=lf[977] /* exit-in-progress */ =C_SCHEME_TRUE;;
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26487,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_dump_heap_on_exitp())){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26578,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5061: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[985];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=t3;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_26487(2,av2);}}}

/* k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26487(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_26487,c,av);}
a=C_alloc(9);
t2=(C_truep(C_i_profilingp())?C_i_dump_statistical_profile():C_SCHEME_UNDEFINED);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26493,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26530,a[2]=t5,a[3]=((C_word)li786),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_26530(t7,t3);}

/* k26491 in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_26493(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26493,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26496,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_slot(C_fast_retrieve(lf[982]),C_fix(0));
if(C_truep(C_fixnum_greaterp(t3,C_fix(0)))){
/* library.scm:5072: ##sys#run-pending-finalizers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[983]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[983]+1);
av2[1]=t2;
av2[2]=C_SCHEME_FALSE;
tp(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_26496(2,av2);}}}

/* k26494 in k26491 in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_26496,c,av);}
a=C_alloc(3);
if(C_truep(C_fixnum_greaterp(C_i_live_finalizer_count(),C_fix(0)))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26505,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_debug_modep())){
/* library.scm:5075: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[981];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_26505(2,av2);}}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k26503 in k26494 in k26491 in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26505(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26505,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26511,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5076: chicken.gc#force-finalizers */
t3=C_fast_retrieve(lf[980]);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k26509 in k26503 in k26494 in k26491 in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_26511(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_26511,c,av);}
if(C_truep(t1)){
/* library.scm:5077: ##sys#force-finalizers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[979]);
C_word *av2=av;
av2[0]=*((C_word*)lf[979]+1);
av2[1]=((C_word*)t0)[2];
tp(2,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* loop in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_fcall f_26530(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_26530,2,t0,t1);}
a=C_alloc(10);
t2=*((C_word*)lf[227]+1);
t3=C_set_block_item(lf[227] /* chicken.base#cleanup-tasks */,0,C_SCHEME_END_OF_LIST);
if(C_truep(C_i_nullp(t2))){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=C_i_check_list_2(t2,lf[706]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26549,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26554,a[2]=t7,a[3]=((C_word)li785),tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_26554(t9,t5,t2);}}

/* k26547 in loop in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_26549,c,av);}
/* library.scm:5070: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_26530(t2,((C_word*)t0)[3]);}

/* for-each-loop5814 in loop in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_fcall f_26554(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_26554,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26564,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5069: t */
t4=C_slot(t2,C_fix(0));{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)C_fast_retrieve_proc(t4))(2,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k26562 in for-each-loop5814 in loop in k26485 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26564,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_26554(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k26576 in cleanup-before-exit in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26578(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_26578,c,av);}
/* library.scm:5062: ##sys#dump-heap-state */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[984]);
C_word *av2=av;
av2[0]=*((C_word*)lf[984]+1);
av2[1]=((C_word*)t0)[2];
tp(2,av2);}}

/* k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_26585(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_26585,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[226]+1 /* (set! chicken.base#exit-handler ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26589,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32470,a[2]=((C_word)li1018),tmp=(C_word)a,a+=3,tmp);
/* library.scm:5090: chicken.base#make-parameter */
t5=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_26589(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_26589,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[225]+1 /* (set! chicken.base#implicit-exit-handler ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26593,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32461,a[2]=((C_word)li1017),tmp=(C_word)a,a+=3,tmp);
/* library.scm:5095: chicken.base#make-parameter */
t5=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_26593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,5)))){
C_save_and_reclaim((void *)f_26593,c,av);}
a=C_alloc(26);
t2=C_mutate((C_word*)lf[986]+1 /* (set! ##sys#reset-handler ...) */,t1);
t3=C_a_i_provide(&a,1,lf[987]);
t4=C_mutate((C_word*)lf[319]+1 /* (set! ##sys#signal-hook/errno ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26595,a[2]=((C_word)li790),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[194]+1 /* (set! ##sys#signal-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26889,a[2]=((C_word)li791),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[989]+1 /* (set! chicken.condition#abort ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26904,a[2]=((C_word)li792),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[1028]+1 /* (set! chicken.condition#signal ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26921,a[2]=((C_word)li793),tmp=(C_word)a,a+=3,tmp));
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26929,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32319,a[2]=((C_word)li1016),tmp=(C_word)a,a+=3,tmp);
/* library.scm:5199: chicken.base#make-parameter */
t10=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t10;
av2[1]=t8;
av2[2]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}

/* ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26595(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c<5) C_bad_min_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-5)*C_SIZEOF_PAIR +13,c,4)))){
C_save_and_reclaim((void*)f_26595,c,av);}
a=C_alloc((c-5)*C_SIZEOF_PAIR+13);
t5=C_build_rest(&a,c,5,av);
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t7=C_dbg_hook(C_SCHEME_FALSE);
t8=signal_debug_event(t2,((C_word*)t6)[1],t5);
t9=C_eqp(t2,lf[975]);
if(C_truep(t9)){
t10=C_a_i_record3(&a,3,lf[932],lf[988],C_SCHEME_END_OF_LIST);
/* library.scm:5123: abort */
t11=C_fast_retrieve(lf[989]);{
C_word *av2=av;
av2[0]=t11;
av2[1]=t1;
av2[2]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=C_eqp(t2,lf[312]);
t11=(C_truep(t10)?t10:C_eqp(t2,lf[314]));
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26621,a[2]=t1,a[3]=t5,a[4]=t6,tmp=(C_word)a,a+=5,tmp);
t13=C_eqp(t2,lf[312]);
if(C_truep(t13)){
/* library.scm:5129: ##sys#print */
t14=*((C_word*)lf[887]+1);{
C_word *av2=av;
av2[0]=t14;
av2[1]=t12;
av2[2]=lf[991];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t14+1)))(5,av2);}}
else{
/* library.scm:5129: ##sys#print */
t14=*((C_word*)lf[887]+1);{
C_word *av2=av;
av2[0]=t14;
av2[1]=t12;
av2[2]=lf[992];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t14+1)))(5,av2);}}}
else{
t12=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26697,a[2]=t6,a[3]=t5,a[4]=t3,a[5]=t1,a[6]=t2,tmp=(C_word)a,a+=7,tmp);
t13=C_i_symbolp(((C_word*)t6)[1]);
t14=(C_truep(t13)?C_i_nullp(t5):C_SCHEME_FALSE);
if(C_truep(t14)){
t15=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26872,a[2]=t6,a[3]=t12,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5147: scheme#symbol->string */
t16=*((C_word*)lf[653]+1);{
C_word *av2=av;
av2[0]=t16;
av2[1]=t15;
av2[2]=((C_word*)t6)[1];
((C_proc)(void*)(*((C_word*)t16+1)))(3,av2);}}
else{
t15=t12;
f_26697(t15,C_SCHEME_UNDEFINED);}}}}

/* k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26621(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_26621,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26624,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5132: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k26622 in k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_26624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_26624,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26627,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_i_nullp(((C_word*)t0)[3]);
t4=(C_truep(t3)?t3:C_fixnum_greaterp(C_u_i_length(((C_word*)t0)[3]),C_fix(1)));
if(C_truep(t4)){
/* library.scm:5134: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=*((C_word*)lf[734]+1);
tp(4,av2);}}
else{
/* library.scm:5135: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[990];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k26625 in k26622 in k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_26627(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_26627,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26644,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26649,a[2]=t4,a[3]=((C_word)li789),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_26649(t6,t2,((C_word*)t0)[3]);}

/* a26633 in for-each-loop5885 in k26625 in k26622 in k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_26634(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_26634,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26638,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5141: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=C_SCHEME_TRUE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k26636 in a26633 in for-each-loop5885 in k26625 in k26622 in k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_26638(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_26638,c,av);}
/* library.scm:5142: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(10);
av2[3]=*((C_word*)lf[734]+1);
tp(4,av2);}}

/* k26642 in k26625 in k26622 in k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_26644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26644,c,av);}
/* library.scm:5144: ##sys#flush-output */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[765]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[765]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[734]+1);
tp(3,av2);}}

/* for-each-loop5885 in k26625 in k26622 in k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_26649(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_26649,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26659,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26634,a[2]=t4,a[3]=((C_word)li788),tmp=(C_word)a,a+=4,tmp);
/* library.scm:5138: ##sys#with-print-length-limit */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[942]);
C_word av2[4];
av2[0]=*((C_word*)lf[942]+1);
av2[1]=t3;
av2[2]=C_fix(400);
av2[3]=t5;
tp(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k26657 in for-each-loop5885 in k26625 in k26622 in k26619 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_26659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26659,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_26649(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k26695 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_fcall f_26697(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_26697,2,t0,t1);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26700,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=C_i_not(((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(t3)){
t4=t2;
f_26700(t4,(C_truep(t3)?C_i_pairp(((C_word*)t0)[3]):C_SCHEME_FALSE));}
else{
t4=C_i_symbolp(((C_word*)((C_word*)t0)[2])[1]);
t5=t2;
f_26700(t5,(C_truep(t4)?C_i_pairp(((C_word*)t0)[3]):C_SCHEME_FALSE));}}

/* k26698 in k26695 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_26700(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_26700,2,t0,t1);}
a=C_alloc(7);
t2=(C_truep(t1)?((C_word*)((C_word*)t0)[2])[1]:C_SCHEME_FALSE);
t3=(C_truep(t1)?C_slot(((C_word*)t0)[3],C_fix(0)):((C_word*)((C_word*)t0)[2])[1]);
t4=(C_truep(t1)?C_slot(((C_word*)t0)[3],C_fix(1)):((C_word*)t0)[3]);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_26720,a[2]=t3,a[3]=t4,a[4]=t2,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t6=C_eqp(((C_word*)t0)[6],lf[263]);
if(C_truep(t6)){
t7=t5;
f_26720(t7,lf[998]);}
else{
t7=C_eqp(((C_word*)t0)[6],lf[799]);
if(C_truep(t7)){
t8=t5;
f_26720(t8,lf[999]);}
else{
t8=C_eqp(((C_word*)t0)[6],lf[388]);
if(C_truep(t8)){
t9=t5;
f_26720(t9,lf[1000]);}
else{
t9=C_eqp(((C_word*)t0)[6],lf[584]);
if(C_truep(t9)){
t10=t5;
f_26720(t10,lf[1001]);}
else{
t10=C_eqp(((C_word*)t0)[6],lf[718]);
if(C_truep(t10)){
t11=t5;
f_26720(t11,lf[1002]);}
else{
t11=C_eqp(((C_word*)t0)[6],lf[1003]);
if(C_truep(t11)){
t12=t5;
f_26720(t12,lf[1004]);}
else{
t12=C_eqp(((C_word*)t0)[6],lf[1005]);
if(C_truep(t12)){
t13=t5;
f_26720(t13,lf[1006]);}
else{
t13=C_eqp(((C_word*)t0)[6],lf[1007]);
if(C_truep(t13)){
t14=t5;
f_26720(t14,lf[1008]);}
else{
t14=C_eqp(((C_word*)t0)[6],lf[1009]);
if(C_truep(t14)){
t15=t5;
f_26720(t15,lf[1010]);}
else{
t15=C_eqp(((C_word*)t0)[6],lf[1011]);
if(C_truep(t15)){
t16=t5;
f_26720(t16,lf[1012]);}
else{
t16=C_eqp(((C_word*)t0)[6],lf[1013]);
if(C_truep(t16)){
t17=t5;
f_26720(t17,lf[1014]);}
else{
t17=C_eqp(((C_word*)t0)[6],lf[1015]);
if(C_truep(t17)){
t18=t5;
f_26720(t18,lf[1016]);}
else{
t18=C_eqp(((C_word*)t0)[6],lf[1017]);
if(C_truep(t18)){
t19=t5;
f_26720(t19,lf[1018]);}
else{
t19=C_eqp(((C_word*)t0)[6],lf[1019]);
t20=t5;
f_26720(t20,(C_truep(t19)?lf[1020]:lf[1021]));}}}}}}}}}}}}}}

/* k26718 in k26698 in k26695 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_26720(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_26720,2,t0,t1);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_26738,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:5174: chicken.base#get-call-chain */
t3=*((C_word*)lf[186]+1);{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k26736 in k26718 in k26698 in k26695 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_26738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(34,c,2)))){
C_save_and_reclaim((void *)f_26738,c,av);}
a=C_alloc(34);
t2=C_a_i_list8(&a,8,lf[993],((C_word*)t0)[2],lf[994],((C_word*)t0)[3],lf[995],t1,lf[996],((C_word*)t0)[4]);
if(C_truep(((C_word*)t0)[5])){
t3=C_a_i_cons(&a,2,((C_word*)t0)[5],t2);
t4=C_a_i_cons(&a,2,lf[997],t3);
t5=C_a_i_record3(&a,3,lf[932],((C_word*)t0)[6],t4);
/* library.scm:5152: abort */
t6=C_fast_retrieve(lf[989]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[7];
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t3=C_a_i_record3(&a,3,lf[932],((C_word*)t0)[6],t2);
/* library.scm:5152: abort */
t4=C_fast_retrieve(lf[989]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[7];
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k26870 in ##sys#signal-hook/errno in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26872(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_26872,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];
f_26697(t3,t2);}

/* ##sys#signal-hook in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +0,c,6)))){
C_save_and_reclaim((void*)f_26889,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+0);
t4=C_build_rest(&a,c,4,av);
C_word t5;
if(C_truep(C_i_pairp(t4))){{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[319]);
av2[3]=t2;
av2[4]=C_SCHEME_FALSE;
av2[5]=t3;
av2[6]=t4;
C_apply(7,av2);}}
else{
/* library.scm:5183: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=C_SCHEME_FALSE;
av2[4]=t3;
tp(5,av2);}}}

/* chicken.condition#abort in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26904(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26904,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26908,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5186: ##sys#current-exception-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1027]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1027]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k26906 in chicken.condition#abort in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26908(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,2)))){
C_save_and_reclaim((void *)f_26908,c,av);}
a=C_alloc(22);
t2=C_a_i_list6(&a,6,lf[1022],lf[1023],lf[1024],C_SCHEME_END_OF_LIST,lf[1025],C_SCHEME_FALSE);
t3=C_a_i_record3(&a,3,lf[932],lf[1026],t2);
/* library.scm:5187: abort */
t4=C_fast_retrieve(lf[989]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* chicken.condition#signal in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_26921,c,av);}
/* library.scm:5196: ##sys#current-exception-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1027]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1027]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}

/* k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_26929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(39,c,5)))){
C_save_and_reclaim((void *)f_26929,c,av);}
a=C_alloc(39);
t2=C_mutate((C_word*)lf[1029]+1 /* (set! ##sys#error-handler ...) */,t1);
t3=C_set_block_item(lf[1030] /* ##sys#last-exception */,0,C_SCHEME_FALSE);
t4=C_mutate((C_word*)lf[1027]+1 /* (set! ##sys#current-exception-handler ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26932,a[2]=((C_word)li794),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[937]+1 /* (set! chicken.condition#with-exception-handler ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27092,a[2]=((C_word)li797),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[1046]+1 /* (set! chicken.condition#current-exception-handler ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27106,a[2]=((C_word)li799),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate(&lf[1048] /* (set! chicken.condition#prop-list->kind-prefixed-prop-list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27167,a[2]=((C_word)li801),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[1050]+1 /* (set! chicken.condition#make-property-condition ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27235,a[2]=((C_word)li802),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[1052]+1 /* (set! chicken.condition#make-composite-condition ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27249,a[2]=((C_word)li806),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[1054]+1 /* (set! chicken.condition#condition ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27389,a[2]=((C_word)li809),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[1055]+1 /* (set! chicken.condition#condition? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27494,a[2]=((C_word)li810),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate((C_word*)lf[1056]+1 /* (set! chicken.condition#condition->list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27500,a[2]=((C_word)li814),tmp=(C_word)a,a+=3,tmp));
t13=C_mutate((C_word*)lf[1059]+1 /* (set! chicken.condition#condition-predicate ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27618,a[2]=((C_word)li816),tmp=(C_word)a,a+=3,tmp));
t14=C_mutate((C_word*)lf[1060]+1 /* (set! chicken.condition#condition-property-accessor ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27639,a[2]=((C_word)li818),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[1063]+1 /* (set! chicken.condition#get-condition-property ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27685,a[2]=((C_word)li819),tmp=(C_word)a,a+=3,tmp));
t16=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27696,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5377: condition-property-accessor */
t17=C_fast_retrieve(lf[1060]);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t17;
av2[1]=t16;
av2[2]=lf[1033];
av2[3]=lf[1418];
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t17+1)))(5,av2);}}

/* ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_26932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_26932,c,av);}
a=C_alloc(14);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_26936,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_structurep(t2,lf[932]))){
t4=C_mutate((C_word*)lf[1030]+1 /* (set! ##sys#last-exception ...) */,t2);
t5=C_slot(t2,C_fix(1));
if(C_truep(C_i_memq(lf[1033],t5))){
t6=C_slot(t2,C_fix(2));
t7=C_i_member(lf[1034],t6);
t8=C_i_member(lf[1035],t6);
t9=C_i_member(lf[1036],t6);
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26975,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_26985,a[2]=t8,a[3]=t10,a[4]=t7,a[5]=t9,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5246: ##sys#error-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1029]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1029]+1);
av2[1]=t11;
tp(2,av2);}}
else{
t6=C_slot(t5,C_fix(0));
t7=C_eqp(lf[1041],t6);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27046,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5264: ##sys#print */
t9=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[1042];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t8=C_slot(t5,C_fix(0));
t9=C_eqp(lf[1043],t8);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27061,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5267: ##sys#error-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1029]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1029]+1);
av2[1]=t10;
tp(2,av2);}}
else{
t10=C_a_i_list2(&a,2,lf[1031],t2);
t11=C_a_i_record3(&a,3,lf[932],lf[1032],t10);
/* library.scm:5271: abort */
t12=C_fast_retrieve(lf[989]);{
C_word *av2=av;
av2[0]=t12;
av2[1]=t1;
av2[2]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}}}}
else{
t4=C_a_i_list2(&a,2,lf[1031],t2);
t5=C_a_i_record3(&a,3,lf[932],lf[1032],t4);
/* library.scm:5271: abort */
t6=C_fast_retrieve(lf[989]);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k26934 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_26936(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_26936,c,av);}
a=C_alloc(10);
t2=C_a_i_list2(&a,2,lf[1031],((C_word*)t0)[2]);
t3=C_a_i_record3(&a,3,lf[932],lf[1032],t2);
/* library.scm:5271: abort */
t4=C_fast_retrieve(lf[989]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k26973 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_26975(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_26975,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_26978,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5262: ##sys#reset-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[986]);
C_word *av2=av;
av2[0]=*((C_word*)lf[986]+1);
av2[1]=t2;
tp(2,av2);}}

/* k26976 in k26973 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_26978(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_26978,c,av);}
/* library.scm:5241: g6020 */
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)C_fast_retrieve_proc(t2))(2,av2);}}

/* k26983 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_26985(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_26985,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_26989,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=C_i_cadr(((C_word*)t0)[4]);
t4=(C_truep(((C_word*)t0)[5])?C_i_cadr(((C_word*)t0)[5]):C_SCHEME_FALSE);
t5=(C_truep(t4)?C_i_symbolp(t4):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27015,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5252: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t6;
av2[2]=t4;
tp(3,av2);}}
else{
t6=t2;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t3;
f_26989(2,av2);}}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[1040];
f_26989(2,av2);}}}

/* k26987 in k26983 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_26989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_26989,c,av);}
if(C_truep(((C_word*)t0)[2])){{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
av2[4]=C_i_cadr(((C_word*)t0)[2]);
C_apply(5,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}}

/* k27013 in k26983 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27015(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_27015,c,av);}
if(C_truep(C_i_symbolp(((C_word*)t0)[2]))){
/* library.scm:5251: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[1037];
av2[3]=t1;
av2[4]=lf[1038];
av2[5]=C_slot(((C_word*)t0)[2],C_fix(1));
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
if(C_truep(C_i_stringp(((C_word*)t0)[2]))){
/* library.scm:5251: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[1037];
av2[3]=t1;
av2[4]=lf[1038];
av2[5]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
/* library.scm:5251: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[1037];
av2[3]=t1;
av2[4]=lf[1038];
av2[5]=lf[1039];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}}

/* k27044 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27046(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_27046,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27049,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5265: ##sys#reset-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[986]);
C_word *av2=av;
av2[0]=*((C_word*)lf[986]+1);
av2[1]=t2;
tp(2,av2);}}

/* k27047 in k27044 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27049(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_27049,c,av);}
/* library.scm:5240: g6023 */
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)C_fast_retrieve_proc(t2))(2,av2);}}

/* k27059 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27061(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_27061,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27064,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_slot(((C_word*)t0)[3],C_fix(2));
t4=C_i_member(lf[1044],t3);
/* library.scm:5240: g6026 */
t5=t1;{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[1045];
av2[3]=C_i_cadr(t4);
((C_proc)C_fast_retrieve_proc(t5))(4,av2);}}

/* k27062 in k27059 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27064(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_27064,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27067,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5270: ##sys#reset-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[986]);
C_word *av2=av;
av2[0]=*((C_word*)lf[986]+1);
av2[1]=t2;
tp(2,av2);}}

/* k27065 in k27062 in k27059 in ##sys#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_27067(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_27067,c,av);}
/* library.scm:5240: g6028 */
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)C_fast_retrieve_proc(t2))(2,av2);}}

/* chicken.condition#with-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_27092,c,av);}
a=C_alloc(8);
t4=C_fast_retrieve(lf[1027]);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27098,a[2]=t2,a[3]=((C_word)li795),tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27102,a[2]=t4,a[3]=((C_word)li796),tmp=(C_word)a,a+=4,tmp);
/* library.scm:5279: ##sys#dynamic-wind */
t7=*((C_word*)lf[710]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t1;
av2[2]=t5;
av2[3]=t3;
av2[4]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}

/* a27097 in chicken.condition#with-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27098(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_27098,c,av);}
t2=C_mutate((C_word*)lf[1027]+1 /* (set! ##sys#current-exception-handler ...) */,((C_word*)t0)[2]);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a27101 in chicken.condition#with-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_27102,c,av);}
t2=C_mutate((C_word*)lf[1027]+1 /* (set! ##sys#current-exception-handler ...) */,((C_word*)t0)[2]);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.condition#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27106(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_27106,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+5);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
if(C_truep(C_i_nullp(t2))){
t3=C_fast_retrieve(lf[1027]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fast_retrieve(lf[1027]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27119,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5289: ##sys#check-closure */
t5=*((C_word*)lf[374]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
av2[3]=lf[1047];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}

/* k27117 in chicken.condition#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_27119,c,av);}
a=C_alloc(10);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27121,a[2]=((C_word*)t0)[3],a[3]=((C_word)li798),tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27127,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27132,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_nullp(t2))){
t6=(
/* library.scm:5290: def-convert?6044 */
  f_27132(t5)
);
t7=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=C_i_car(t2);
t7=C_u_i_cdr(t2);
if(C_truep(C_i_nullp(t7))){
t8=(
/* library.scm:5290: def-set?6045 */
  f_27127(t4)
);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t8=C_i_car(t7);
t9=C_u_i_cdr(t7);
t10=(
/* library.scm:5290: body6042 */
  f_27121(t3,t8)
);
t11=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t11;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t11+1)))(2,av2);}}}}

/* body6042 in k27117 in chicken.condition#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static C_word C_fcall f_27121(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
if(C_truep(t1)){
t2=C_mutate((C_word*)lf[1027]+1 /* (set! ##sys#current-exception-handler ...) */,((C_word*)t0)[2]);
return(t2);}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* def-set?6045 in k27117 in chicken.condition#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static C_word C_fcall f_27127(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:5290: body6042 */
  f_27121(((C_word*)t0)[2],C_SCHEME_TRUE)
));}

/* def-convert?6044 in k27117 in chicken.condition#current-exception-handler in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static C_word C_fcall f_27132(C_word t0){
C_word tmp;
C_word t1;
C_stack_overflow_check;{}
return((
/* library.scm:5290: def-set?6045 */
  f_27127(((C_word*)t0)[2])
));}

/* chicken.condition#prop-list->kind-prefixed-prop-list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_fcall f_27167(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_27167,4,t1,t2,t3,t4);}
a=C_alloc(9);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27173,a[2]=t2,a[3]=t4,a[4]=t3,a[5]=t6,a[6]=((C_word)li800),tmp=(C_word)a,a+=7,tmp));
t8=((C_word*)t6)[1];
f_27173(t8,t1,t4);}

/* loop in chicken.condition#prop-list->kind-prefixed-prop-list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_27173(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_27173,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_pairp(t2);
t4=C_i_not(t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_27189,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t4)){
t6=t5;
f_27189(t6,t4);}
else{
t6=C_i_cdr(t2);
t7=t5;
f_27189(t7,C_i_not(C_i_pairp(t6)));}}}

/* k27187 in loop in chicken.condition#prop-list->kind-prefixed-prop-list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_27189(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,5)))){
C_save_and_reclaim_args((void *)trf_27189,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
/* library.scm:5300: ##sys#signal-hook */
t2=C_fast_retrieve(lf[194]);{
C_word av2[6];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[263];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1049];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=C_i_car(((C_word*)t0)[5]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[6],t2);
t4=C_i_cadr(((C_word*)t0)[5]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27211,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t6=C_u_i_cdr(((C_word*)t0)[5]);
/* library.scm:5304: loop */
t7=((C_word*)((C_word*)t0)[7])[1];
f_27173(t7,t5,C_u_i_cdr(t6));}}

/* k27209 in k27187 in loop in chicken.condition#prop-list->kind-prefixed-prop-list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_27211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_27211,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.condition#make-property-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27235(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +7,c,4)))){
C_save_and_reclaim((void*)f_27235,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+7);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
t4=C_a_i_list1(&a,1,t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27247,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5309: prop-list->kind-prefixed-prop-list */
f_27167(t5,lf[1051],t2,t3);}

/* k27245 in chicken.condition#make-property-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_27247,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_record3(&a,3,lf[932],((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +26,c,3)))){
C_save_and_reclaim((void*)f_27249,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+26);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
t4=C_a_i_cons(&a,2,t2,t3);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27366,a[2]=((C_word)li803),tmp=(C_word)a,a+=3,tmp);
t6=(
  f_27366(t4)
);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27268,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t8=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t9=t8;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=((C_word*)t10)[1];
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27330,a[2]=t7,tmp=(C_word)a,a+=3,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27332,a[2]=t10,a[3]=t14,a[4]=t11,a[5]=((C_word)li805),tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_27332(t16,t12,t4);}

/* k27266 in chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27268(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_27268,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27272,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27284,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27286,a[2]=t5,a[3]=t9,a[4]=t6,a[5]=((C_word)li804),tmp=(C_word)a,a+=6,tmp));
t11=((C_word*)t9)[1];
f_27286(t11,t7,((C_word*)t0)[3]);}

/* k27270 in k27266 in chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27272(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_27272,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_record3(&a,3,lf[932],((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k27282 in k27266 in chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27284,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[259]+1);
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop6131 in k27266 in chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_27286(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_27286,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_slot(t3,C_fix(2));
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k27328 in chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27330,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[259]+1);
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop6104 in chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_27332(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_27332,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_slot(t3,C_fix(1));
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* for-each-loop6086 in chicken.condition#make-composite-condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static C_word C_fcall f_27366(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_slot(t1,C_fix(0));
t3=C_i_check_structure_2(t2,lf[932],lf[1053]);
t5=C_slot(t1,C_fix(1));
t1=t5;
goto loop;}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* chicken.condition#condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +23,c,3)))){
C_save_and_reclaim((void*)f_27389,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+23);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
t4=C_a_i_cons(&a,2,t2,t3);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27396,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27458,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27460,a[2]=t8,a[3]=t12,a[4]=t9,a[5]=((C_word)li808),tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_27460(t14,t10,t4);}

/* k27394 in chicken.condition#condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27396(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_27396,c,av);}
a=C_alloc(17);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27406,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27408,a[2]=t4,a[3]=t8,a[4]=t5,a[5]=((C_word)li807),tmp=(C_word)a,a+=6,tmp));
t10=((C_word*)t8)[1];
f_27408(t10,t6,((C_word*)t0)[3]);}

/* k27404 in k27394 in chicken.condition#condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27406(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_27406,c,av);}
a=C_alloc(4);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_record3(&a,3,lf[932],t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop6191 in k27394 in chicken.condition#condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_27408(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_27408,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k27456 in chicken.condition#condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27458(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27458,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[259]+1);
av2[3]=t1;
C_apply(4,av2);}}

/* map-loop6164 in chicken.condition#condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_fcall f_27460(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_27460,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27485,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
/* library.scm:5324: prop-list->kind-prefixed-prop-list */
f_27167(t3,lf[932],C_i_car(t4),C_u_i_cdr(t4));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k27483 in map-loop6164 in chicken.condition#condition in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_27485,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_27460(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* chicken.condition#condition? in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27494(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_27494,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_structurep(t2,lf[932]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_27500,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27504,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27613,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5332: condition? */
t5=C_fast_retrieve(lf[1055]);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k27502 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_27504,c,av);}
a=C_alloc(18);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27508,a[2]=((C_word*)t0)[2],a[3]=((C_word)li812),tmp=(C_word)a,a+=4,tmp);
t7=C_slot(((C_word*)t0)[2],C_fix(1));
t8=C_i_check_list_2(t7,lf[708]);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27578,a[2]=t4,a[3]=t10,a[4]=t6,a[5]=t5,a[6]=((C_word)li813),tmp=(C_word)a,a+=7,tmp));
t12=((C_word*)t10)[1];
f_27578(t12,((C_word*)t0)[3],t7);}

/* g6227 in k27502 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_27508(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_27508,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27516,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=C_slot(((C_word*)t0)[2],C_fix(2));
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27522,a[2]=t2,a[3]=t6,a[4]=((C_word)li811),tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_27522(t8,t3,t4);}

/* k27514 in g6227 in k27502 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_27516(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_27516,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in g6227 in k27502 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_27522(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_27522,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_caar(t2);
t4=C_eqp(t3,((C_word*)t0)[2]);
if(C_truep(t4)){
t5=C_u_i_car(t2);
t6=C_u_i_cdr(t5);
t7=C_i_cadr(t2);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27553,a[2]=t7,a[3]=t1,a[4]=t6,tmp=(C_word)a,a+=5,tmp);
t9=C_u_i_cdr(t2);
/* library.scm:5342: loop */
t11=t8;
t12=C_u_i_cdr(t9);
t1=t11;
t2=t12;
goto loop;}
else{
/* library.scm:5344: loop */
t11=t1;
t12=C_i_cddr(t2);
t1=t11;
t2=t12;
goto loop;}}}

/* k27551 in loop in g6227 in k27502 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_27553(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_27553,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[4],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop6221 in k27502 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_fcall f_27578(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_27578,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27603,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5336: g6227 */
t4=((C_word*)t0)[4];
f_27508(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k27601 in map-loop6221 in k27502 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_27603(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_27603,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_27578(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k27611 in chicken.condition#condition->list in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27613(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_27613,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_27504(2,av2);}}
else{
/* library.scm:5333: ##sys#signal-hook */
t2=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[263];
av2[3]=lf[1057];
av2[4]=lf[1058];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* chicken.condition#condition-predicate in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27618(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_27618,c,av);}
a=C_alloc(4);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27620,a[2]=t2,a[3]=((C_word)li815),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_27620 in chicken.condition#condition-predicate in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27620(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_27620,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27627,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5349: condition? */
t4=C_fast_retrieve(lf[1055]);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k27625 */
static void C_ccall f_27627(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_27627,c,av);}
if(C_truep(t1)){
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=C_i_memv(((C_word*)t0)[3],t2);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_SCHEME_TRUE:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.condition#condition-property-accessor in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +11,c,3)))){
C_save_and_reclaim((void*)f_27639,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+11);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
t5=C_i_nullp(t4);
t6=C_a_i_cons(&a,2,t2,t3);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_27647,a[2]=t2,a[3]=t6,a[4]=t5,a[5]=t3,a[6]=t4,a[7]=((C_word)li817),tmp=(C_word)a,a+=8,tmp);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* f_27647 in chicken.condition#condition-property-accessor in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27647(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_27647,c,av);}
t3=C_i_check_structure(t2,lf[932]);
t4=C_slot(t2,C_fix(1));
if(C_truep(C_i_memv(((C_word*)t0)[2],t4))){
t5=C_slot(t2,C_fix(2));
t6=C_i_member(((C_word*)t0)[3],t5);
if(C_truep(t6)){
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_i_cadr(t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
if(C_truep(((C_word*)t0)[4])){
/* library.scm:5360: ##sys#signal-hook */
t7=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=lf[1061];
av2[4]=lf[1062];
av2[5]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t7+1)))(6,av2);}}
else{
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_i_car(((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}}
else{
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* chicken.condition#get-condition-property in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27685(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c<5) C_bad_min_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-5)*C_SIZEOF_PAIR +4,c,5)))){
C_save_and_reclaim((void*)f_27685,c,av);}
a=C_alloc((c-5)*C_SIZEOF_PAIR+4);
t5=C_build_rest(&a,c,5,av);
C_word t6;
C_word t7;
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27689,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=t6;
av2[2]=C_fast_retrieve(lf[1060]);
av2[3]=t3;
av2[4]=t4;
av2[5]=t5;
C_apply(6,av2);}}

/* k27687 in chicken.condition#get-condition-property in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27689(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27689,c,av);}
/* library.scm:5366: g6276 */
t2=t1;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_27696(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_27696,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27699,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5378: condition-property-accessor */
t3=C_fast_retrieve(lf[1060]);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1033];
av2[3]=lf[864];
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_27699(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_27699,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27702,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5379: condition-property-accessor */
t3=C_fast_retrieve(lf[1060]);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1033];
av2[3]=lf[1417];
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_27702(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(182,c,7)))){
C_save_and_reclaim((void *)f_27702,c,av);}
a=C_alloc(182);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27703,a[2]=((C_word)li823),tmp=(C_word)a,a+=3,tmp);
t3=C_mutate((C_word*)lf[1064]+1 /* (set! chicken.condition#print-error-message ...) */,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27748,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word)li828),tmp=(C_word)a,a+=7,tmp));
t4=C_fast_retrieve(lf[1064]);
t5=*((C_word*)lf[187]+1);
t6=*((C_word*)lf[215]+1);
t7=*((C_word*)lf[213]+1);
t8=C_mutate((C_word*)lf[1076]+1 /* (set! ##sys#show-exception-warning ...) */,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27939,a[2]=t5,a[3]=t4,a[4]=t7,a[5]=t6,a[6]=((C_word)li829),tmp=(C_word)a,a+=7,tmp));
t9=C_mutate((C_word*)lf[371]+1 /* (set! ##sys#error-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27988,a[2]=((C_word)li830),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[1140]+1 /* (set! ##sys#structure? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28694,a[2]=((C_word)li831),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[1141]+1 /* (set! ##sys#generic-structure? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28697,a[2]=((C_word)li832),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate((C_word*)lf[1142]+1 /* (set! ##sys#slot ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28700,a[2]=((C_word)li833),tmp=(C_word)a,a+=3,tmp));
t13=C_mutate((C_word*)lf[1143]+1 /* (set! ##sys#size ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28703,a[2]=((C_word)li834),tmp=(C_word)a,a+=3,tmp));
t14=C_mutate((C_word*)lf[1144]+1 /* (set! ##sys#make-pointer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_make_pointer,a[2]=((C_word)li835),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[1145]+1 /* (set! ##sys#make-tagged-pointer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_make_tagged_pointer,a[2]=((C_word)li836),tmp=(C_word)a,a+=3,tmp));
t16=C_mutate((C_word*)lf[1146]+1 /* (set! ##sys#pointer? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28708,a[2]=((C_word)li837),tmp=(C_word)a,a+=3,tmp));
t17=C_mutate((C_word*)lf[1147]+1 /* (set! ##sys#set-pointer-address! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28711,a[2]=((C_word)li838),tmp=(C_word)a,a+=3,tmp));
t18=C_mutate((C_word*)lf[1148]+1 /* (set! ##sys#bytevector? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28714,a[2]=((C_word)li839),tmp=(C_word)a,a+=3,tmp));
t19=C_mutate((C_word*)lf[1149]+1 /* (set! ##sys#string->pbytevector ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28717,a[2]=((C_word)li840),tmp=(C_word)a,a+=3,tmp));
t20=C_mutate((C_word*)lf[1150]+1 /* (set! ##sys#permanent? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28720,a[2]=((C_word)li841),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate((C_word*)lf[1151]+1 /* (set! ##sys#block-address ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28723,a[2]=((C_word)li842),tmp=(C_word)a,a+=3,tmp));
t22=C_mutate((C_word*)lf[1152]+1 /* (set! ##sys#locative? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28726,a[2]=((C_word)li843),tmp=(C_word)a,a+=3,tmp));
t23=C_mutate((C_word*)lf[1153]+1 /* (set! ##sys#srfi-4-vector? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28729,a[2]=((C_word)li844),tmp=(C_word)a,a+=3,tmp));
t24=C_mutate((C_word*)lf[1154]+1 /* (set! ##sys#null-pointer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28732,a[2]=((C_word)li845),tmp=(C_word)a,a+=3,tmp));
t25=C_mutate((C_word*)lf[1155]+1 /* (set! ##sys#null-pointer? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28738,a[2]=((C_word)li846),tmp=(C_word)a,a+=3,tmp));
t26=C_mutate((C_word*)lf[1156]+1 /* (set! ##sys#address->pointer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28748,a[2]=((C_word)li847),tmp=(C_word)a,a+=3,tmp));
t27=C_mutate((C_word*)lf[961]+1 /* (set! ##sys#pointer->address ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28754,a[2]=((C_word)li848),tmp=(C_word)a,a+=3,tmp));
t28=C_mutate((C_word*)lf[764]+1 /* (set! ##sys#make-c-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28761,a[2]=((C_word)li849),tmp=(C_word)a,a+=3,tmp));
t29=C_mutate((C_word*)lf[1157]+1 /* (set! ##sys#peek-signed-integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_peek_signed_integer,a[2]=((C_word)li850),tmp=(C_word)a,a+=3,tmp));
t30=C_mutate((C_word*)lf[742]+1 /* (set! ##sys#peek-unsigned-integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_peek_unsigned_integer,a[2]=((C_word)li851),tmp=(C_word)a,a+=3,tmp));
t31=C_mutate((C_word*)lf[1158]+1 /* (set! ##sys#peek-fixnum ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28796,a[2]=((C_word)li852),tmp=(C_word)a,a+=3,tmp));
t32=C_mutate((C_word*)lf[1159]+1 /* (set! ##sys#peek-byte ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28799,a[2]=((C_word)li853),tmp=(C_word)a,a+=3,tmp));
t33=C_mutate((C_word*)lf[1160]+1 /* (set! ##sys#vector->structure! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28802,a[2]=((C_word)li854),tmp=(C_word)a,a+=3,tmp));
t34=C_mutate((C_word*)lf[1161]+1 /* (set! ##sys#peek-double ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28805,a[2]=((C_word)li855),tmp=(C_word)a,a+=3,tmp));
t35=C_mutate((C_word*)lf[721]+1 /* (set! ##sys#peek-c-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28808,a[2]=((C_word)li856),tmp=(C_word)a,a+=3,tmp));
t36=C_mutate((C_word*)lf[965]+1 /* (set! ##sys#peek-nonnull-c-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28824,a[2]=((C_word)li857),tmp=(C_word)a,a+=3,tmp));
t37=C_mutate((C_word*)lf[1162]+1 /* (set! ##sys#peek-and-free-c-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28830,a[2]=((C_word)li858),tmp=(C_word)a,a+=3,tmp));
t38=C_mutate((C_word*)lf[1163]+1 /* (set! ##sys#peek-and-free-nonnull-c-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28846,a[2]=((C_word)li859),tmp=(C_word)a,a+=3,tmp));
t39=C_mutate((C_word*)lf[1164]+1 /* (set! ##sys#poke-c-string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28852,a[2]=((C_word)li860),tmp=(C_word)a,a+=3,tmp));
t40=C_mutate((C_word*)lf[1165]+1 /* (set! ##sys#poke-integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28859,a[2]=((C_word)li861),tmp=(C_word)a,a+=3,tmp));
t41=C_mutate((C_word*)lf[1166]+1 /* (set! ##sys#poke-double ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28862,a[2]=((C_word)li862),tmp=(C_word)a,a+=3,tmp));
t42=C_mutate((C_word*)lf[1167]+1 /* (set! ##sys#peek-c-string-list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28882,a[2]=((C_word)li864),tmp=(C_word)a,a+=3,tmp));
t43=C_mutate((C_word*)lf[1168]+1 /* (set! ##sys#peek-and-free-c-string-list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28943,a[2]=((C_word)li866),tmp=(C_word)a,a+=3,tmp));
t44=C_mutate((C_word*)lf[1169]+1 /* (set! ##sys#vector->closure! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28981,a[2]=((C_word)li867),tmp=(C_word)a,a+=3,tmp));
t45=C_mutate((C_word*)lf[1170]+1 /* (set! ##sys#symbol-has-toplevel-binding? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28984,a[2]=((C_word)li868),tmp=(C_word)a,a+=3,tmp));
t46=C_mutate((C_word*)lf[943]+1 /* (set! ##sys#copy-bytes ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28987,a[2]=((C_word)li869),tmp=(C_word)a,a+=3,tmp));
t47=C_mutate((C_word*)lf[1171]+1 /* (set! ##sys#copy-words ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28994,a[2]=((C_word)li870),tmp=(C_word)a,a+=3,tmp));
t48=C_mutate((C_word*)lf[1172]+1 /* (set! ##sys#compare-bytes ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29001,a[2]=((C_word)li871),tmp=(C_word)a,a+=3,tmp));
t49=C_mutate((C_word*)lf[1173]+1 /* (set! ##sys#block-pointer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29004,a[2]=((C_word)li872),tmp=(C_word)a,a+=3,tmp));
t50=C_mutate((C_word*)lf[1174]+1 /* (set! ##sys#foreign-char-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29010,a[2]=((C_word)li873),tmp=(C_word)a,a+=3,tmp));
t51=C_mutate((C_word*)lf[1175]+1 /* (set! ##sys#foreign-fixnum-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29013,a[2]=((C_word)li874),tmp=(C_word)a,a+=3,tmp));
t52=C_mutate((C_word*)lf[1176]+1 /* (set! ##sys#foreign-flonum-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29016,a[2]=((C_word)li875),tmp=(C_word)a,a+=3,tmp));
t53=C_mutate((C_word*)lf[1177]+1 /* (set! ##sys#foreign-block-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29019,a[2]=((C_word)li876),tmp=(C_word)a,a+=3,tmp));
t54=C_mutate((C_word*)lf[1178]+1 /* (set! ##sys#foreign-struct-wrapper-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29022,a[2]=((C_word)li877),tmp=(C_word)a,a+=3,tmp));
t55=C_mutate((C_word*)lf[1179]+1 /* (set! ##sys#foreign-string-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29025,a[2]=((C_word)li878),tmp=(C_word)a,a+=3,tmp));
t56=C_mutate((C_word*)lf[1180]+1 /* (set! ##sys#foreign-symbol-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29028,a[2]=((C_word)li879),tmp=(C_word)a,a+=3,tmp));
t57=C_mutate((C_word*)lf[1181]+1 /* (set! ##sys#foreign-pointer-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29031,a[2]=((C_word)li880),tmp=(C_word)a,a+=3,tmp));
t58=C_mutate((C_word*)lf[1182]+1 /* (set! ##sys#foreign-tagged-pointer-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29034,a[2]=((C_word)li881),tmp=(C_word)a,a+=3,tmp));
t59=C_mutate((C_word*)lf[1183]+1 /* (set! ##sys#foreign-ranged-integer-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29037,a[2]=((C_word)li882),tmp=(C_word)a,a+=3,tmp));
t60=C_mutate((C_word*)lf[1184]+1 /* (set! ##sys#foreign-unsigned-ranged-integer-argument ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29040,a[2]=((C_word)li883),tmp=(C_word)a,a+=3,tmp));
t61=C_set_block_item(lf[1185] /* ##sys#default-thread-quantum */,0,C_fix(10000));
t62=C_mutate((C_word*)lf[1186]+1 /* (set! ##sys#default-exception-handler ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29044,a[2]=((C_word)li884),tmp=(C_word)a,a+=3,tmp));
t63=C_mutate((C_word*)lf[1188]+1 /* (set! ##sys#make-thread ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29047,a[2]=((C_word)li885),tmp=(C_word)a,a+=3,tmp));
t64=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29071,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5742: ##sys#make-thread */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1188]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[1188]+1);
av2[1]=t64;
av2[2]=C_SCHEME_FALSE;
av2[3]=lf[1415];
av2[4]=lf[1416];
av2[5]=C_fast_retrieve(lf[1185]);
tp(6,av2);}}

/* writeargs in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_fcall f_27703(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_27703,3,t1,t2,t3);}
a=C_alloc(11);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27705,a[2]=t3,a[3]=((C_word)li821),tmp=(C_word)a,a+=4,tmp);
t5=C_i_check_list_2(t2,lf[706]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27726,a[2]=t7,a[3]=t4,a[4]=((C_word)li822),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_27726(t9,t1,t2);}

/* g6292 in writeargs in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_27705(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_27705,3,t0,t1,t2);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27709,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27714,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word)li820),tmp=(C_word)a,a+=5,tmp);
/* library.scm:5384: ##sys#with-print-length-limit */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[942]);
C_word av2[4];
av2[0]=*((C_word*)lf[942]+1);
av2[1]=t3;
av2[2]=C_fix(80);
av2[3]=t4;
tp(4,av2);}}

/* k27707 in g6292 in writeargs in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_27709(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27709,c,av);}
/* library.scm:5385: newline */
t2=*((C_word*)lf[151]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a27713 in g6292 in writeargs in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_27714(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27714,c,av);}
/* library.scm:5384: write */
t2=*((C_word*)lf[152]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop6291 in writeargs in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_27726(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_27726,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27736,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5382: g6292 */
t4=((C_word*)t0)[3];
f_27705(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k27734 in for-each-loop6291 in writeargs in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_27736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27736,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_27726(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_27748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_27748,c,av);}
a=C_alloc(16);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_27750,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word)li825),tmp=(C_word)a,a+=8,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27899,a[2]=t3,a[3]=((C_word)li826),tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27904,a[2]=t4,a[3]=((C_word)li827),tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_rest_nullp(c,3))){
/* library.scm:5388: def-port6314 */
t6=t5;
f_27904(t6,t1);}
else{
t6=C_get_rest_arg(c,3,av,3,t0);
if(C_truep(C_rest_nullp(c,4))){
/* library.scm:5388: def-header6315 */
t7=t4;
f_27899(t7,t1,t6);}
else{
t7=C_get_rest_arg(c,4,av,3,t0);
/* library.scm:5388: body6312 */
t8=t3;
f_27750(t8,t1,t6,t7);}}}

/* body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_27750(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_27750,4,t0,t1,t2,t3);}
a=C_alloc(10);
t4=C_i_check_port_2(t2,C_fix(2),C_SCHEME_TRUE,lf[1065]);
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_27757,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=t3,tmp=(C_word)a,a+=10,tmp);
/* library.scm:5391: newline */
t6=*((C_word*)lf[151]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_27757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_27757,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_27760,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* library.scm:5392: display */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_27760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_27760,c,av);}
a=C_alloc(8);
t2=C_immp(((C_word*)t0)[2]);
t3=C_i_not(t2);
t4=(C_truep(t3)?C_eqp(lf[932],C_slot(((C_word*)t0)[2],C_fix(0))):C_SCHEME_FALSE);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_27769,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* library.scm:5394: errmsg */
t6=((C_word*)t0)[8];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
if(C_truep(C_i_stringp(((C_word*)t0)[2]))){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27868,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5418: display */
t6=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[1073];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27877,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5422: display */
t6=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[1074];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}}

/* k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_27769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_27769,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27772,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27804,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[6],a[5]=((C_word)li824),tmp=(C_word)a,a+=6,tmp);
/* library.scm:5394: g6335 */
t4=t3;
f_27804(t4,t2,t1);}
else{
t3=C_slot(((C_word*)t0)[6],C_fix(1));
if(C_truep(C_i_equalp(lf[1070],t3))){
/* library.scm:5404: display */
t4=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[1071];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27852,a[2]=t2,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5406: display */
t5=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[1072];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}}

/* k27770 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_27772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_27772,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27775,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5408: errargs */
t3=((C_word*)t0)[5];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k27773 in k27770 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_27775(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_27775,c,av);}
a=C_alloc(6);
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_length(t1);
t4=C_eqp(C_fix(1),t3);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27790,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5412: display */
t6=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[1066];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_27796,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5415: newline */
t6=*((C_word*)lf[151]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}}

/* k27788 in k27773 in k27770 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_27790(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27790,c,av);}
/* library.scm:5413: writeargs */
f_27703(((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k27794 in k27773 in k27770 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_27796(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27796,c,av);}
/* library.scm:5416: writeargs */
f_27703(((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);}

/* g6335 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_fcall f_27804(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_27804,3,t0,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_27808,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* library.scm:5396: display */
t4=*((C_word*)lf[153]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1069];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k27806 in g6335 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_27808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_27808,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27811,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5397: errloc */
t3=((C_word*)t0)[5];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k27809 in k27806 in g6335 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_27811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_27811,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27814,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(C_truep(t1)?C_i_symbolp(t1):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27827,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_27831,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5399: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t5;
av2[2]=t1;
tp(3,av2);}}
else{
/* library.scm:5400: display */
t4=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k27812 in k27809 in k27806 in g6335 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_27814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27814,c,av);}
/* library.scm:5400: display */
t2=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k27825 in k27809 in k27806 in g6335 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_27827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27827,c,av);}
/* library.scm:5399: display */
t2=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k27829 in k27809 in k27806 in g6335 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_27831(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_27831,c,av);}
/* library.scm:5399: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1067];
av2[3]=t1;
av2[4]=lf[1068];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k27850 in k27767 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_27852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27852,c,av);}
/* library.scm:5407: display */
t2=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_slot(((C_word*)t0)[3],C_fix(1));
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k27866 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_27868(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_27868,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27871,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5419: display */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k27869 in k27866 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_27871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_27871,c,av);}
/* library.scm:5420: newline */
t2=*((C_word*)lf[151]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k27875 in k27758 in k27755 in body6312 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_27877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_27877,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
/* library.scm:5423: writeargs */
f_27703(((C_word*)t0)[4],t2,((C_word*)t0)[5]);}

/* def-header6315 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_27899(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_27899,3,t0,t1,t2);}
/* library.scm:5388: body6312 */
t3=((C_word*)t0)[2];
f_27750(t3,t1,t2,lf[1075]);}

/* def-port6314 in chicken.condition#print-error-message in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_27904(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,2)))){
C_save_and_reclaim_args((void *)trf_27904,2,t0,t1);}
/* library.scm:5388: def-header6315 */
t2=((C_word*)t0)[2];
f_27899(t2,t1,*((C_word*)lf[733]+1));}

/* ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_27939(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_27939,c,av);}
a=C_alloc(9);
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?C_fast_retrieve(lf[964]):C_get_rest_arg(c,4,av,4,t0));
if(C_truep(*((C_word*)lf[309]+1))){
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_27949,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t5,a[5]=((C_word*)t0)[3],a[6]=t2,a[7]=((C_word*)t0)[4],a[8]=t3,tmp=(C_word)a,a+=9,tmp);
/* library.scm:5438: open-output-string */
t7=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_27949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_27949,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_27952,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* library.scm:5439: display */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1079];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_27952(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_27952,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_27955,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27974,a[2]=t2,a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5441: display */
t4=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1078];
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_27955(2,av2);}}}

/* k27953 in k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_27955(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_27955,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_27958,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* library.scm:5444: display */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1077];
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k27956 in k27953 in k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_27958(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_27958,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_27961,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* library.scm:5445: display */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k27959 in k27956 in k27953 in k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_27961(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_27961,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27964,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_27971,a[2]=((C_word*)t0)[5],a[3]=t2,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5446: get-output-string */
t4=((C_word*)t0)[7];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k27962 in k27959 in k27956 in k27953 in k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_27964(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_27964,c,av);}
/* library.scm:5447: print-call-chain */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=*((C_word*)lf[734]+1);
av2[3]=C_fix(0);
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k27969 in k27959 in k27956 in k27953 in k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_27971(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_27971,c,av);}
/* library.scm:5446: print-error-message */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=*((C_word*)lf[734]+1);
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k27972 in k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_27974(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_27974,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_27977,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5442: display */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k27975 in k27972 in k27950 in k27947 in ##sys#show-exception-warning in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_27977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_27977,c,av);}
/* ##sys#write-char/port */
t2=C_fast_retrieve(lf[884]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(41);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_27988(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-4)*C_SIZEOF_PAIR +9,c,6)))){
C_save_and_reclaim((void*)f_27988,c,av);}
a=C_alloc((c-4)*C_SIZEOF_PAIR+9);
t4=C_build_rest(&a,c,4,av);
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
switch(t2){
case C_fix(1):
t5=C_get_rest_arg(c,4,av,4,t0);
t6=C_i_cadr(t4);
t7=C_i_caddr(t4);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28011,a[2]=t7,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28022,a[2]=t8,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5462: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t9;
av2[2]=t6;
tp(3,av2);}
case C_fix(2):
t5=C_get_rest_arg(c,4,av,4,t0);
t6=C_i_cadr(t4);
t7=C_i_caddr(t4);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28048,a[2]=t7,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28059,a[2]=t8,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5471: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t9;
av2[2]=t6;
tp(3,av2);}
case C_fix(3):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1084];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(4):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1003];
av2[4]=t3;
av2[5]=lf[1085];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(5):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1086];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(6):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1011];
av2[4]=t3;
av2[5]=lf[1087];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(7):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[584];
av2[4]=t3;
av2[5]=lf[1088];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(8):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[388];
av2[4]=t3;
av2[5]=lf[1089];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(9):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1090];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(10):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1013];
av2[4]=t3;
av2[5]=lf[1091];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(11):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1092];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(12):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1011];
av2[4]=t3;
av2[5]=lf[1093];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(13):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1094];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(14):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1095];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(15):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1096];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(16):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1097];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(17):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1098];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(18):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1099];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(19):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1100];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(20):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1101];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(21):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1102];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(22):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1103];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(23):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1011];
av2[4]=t3;
av2[5]=lf[1104];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(24):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1105];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(25):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1106];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(26):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1107];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(27):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1108];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(28):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1109];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(29):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1110];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(30):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1111];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(31):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1112];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(32):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1113];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(33):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1114];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(34):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1115];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(35):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1116];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(36):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1011];
av2[4]=t3;
av2[5]=lf[1117];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(37):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1118];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(38):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1119];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(39):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1120];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(40):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1121];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(41):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1122];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(42):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1123];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(43):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[718];
av2[4]=t3;
av2[5]=lf[1124];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(44):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1125];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(45):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1019];
av2[4]=t3;
av2[5]=lf[1126];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(46):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[584];
av2[4]=t3;
av2[5]=lf[1127];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(47):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1003];
av2[4]=t3;
av2[5]=lf[1128];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(48):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1019];
av2[4]=t3;
av2[5]=lf[1129];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(49):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1130];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(50):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1131];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(51):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1132];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(52):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1133];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(53):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1134];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(54):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1135];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(55):{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=t3;
av2[5]=lf[1136];
av2[6]=t4;
C_apply(7,av2);}
case C_fix(56):
t5=C_get_rest_arg(c,4,av,4,t0);
t6=C_i_cadr(t4);
t7=C_i_caddr(t4);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28562,a[2]=t7,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28573,a[2]=t8,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5533: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t9;
av2[2]=t6;
tp(3,av2);}
default:{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1003];
av2[4]=t3;
av2[5]=lf[1139];
av2[6]=t4;
C_apply(7,av2);}}}

/* k28009 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28011(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_28011,c,av);}
a=C_alloc(3);
if(C_truep(((C_word*)t0)[2])){
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1013];
av2[4]=((C_word*)t0)[4];
av2[5]=t1;
av2[6]=t2;
C_apply(7,av2);}}
else{
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[194]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[194]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=lf[1013];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
tp(5,av2);}}}

/* k28020 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_28022,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28026,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5463: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k28024 in k28020 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_28026(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_28026,c,av);}
/* library.scm:5462: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1080];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1081];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k28046 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28048(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_28048,c,av);}
a=C_alloc(3);
if(C_truep(((C_word*)t0)[2])){
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[1013];
av2[4]=((C_word*)t0)[4];
av2[5]=t1;
av2[6]=t2;
C_apply(7,av2);}}
else{
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[194]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[194]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=lf[1013];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
tp(5,av2);}}}

/* k28057 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28059(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_28059,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28063,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5472: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k28061 in k28057 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_28063(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_28063,c,av);}
/* library.scm:5471: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1082];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1083];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k28560 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,6)))){
C_save_and_reclaim((void *)f_28562,c,av);}
a=C_alloc(3);
if(C_truep(((C_word*)t0)[2])){
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[388];
av2[4]=((C_word*)t0)[4];
av2[5]=t1;
av2[6]=t2;
C_apply(7,av2);}}
else{
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[194]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[194]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=lf[388];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
tp(5,av2);}}}

/* k28571 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28573(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_28573,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28577,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5534: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k28575 in k28571 in ##sys#error-hook in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_28577(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_28577,c,av);}
/* library.scm:5533: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1137];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1138];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* ##sys#structure? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28694,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_structurep(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#generic-structure? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28697(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28697,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_structurep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#slot in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28700(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28700,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#size in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28703(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28703,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_block_size(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#pointer? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28708(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28708,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_anypointerp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#set-pointer-address! in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28711,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_update_pointer(t3,t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#bytevector? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28714(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28714,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_bytevectorp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#string->pbytevector in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28717,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_string_to_pbytevector(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#permanent? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28720,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_permanentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#block-address in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_28723,c,av);}
a=C_alloc(6);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_block_address(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#locative? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28726,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_locativep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#srfi-4-vector? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28729,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_srfi_4_vectorp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#null-pointer in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_28732,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28736,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5560: ##sys#make-pointer */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1144]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1144]+1);
av2[1]=t2;
tp(2,av2);}}

/* k28734 in ##sys#null-pointer in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28736,c,av);}
t2=C_update_pointer(C_fix(0),t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#null-pointer? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_28738,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_28746,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5565: ##sys#pointer->address */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[961]);
C_word *av2=av;
av2[0]=*((C_word*)lf[961]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}

/* k28744 in ##sys#null-pointer? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28746(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28746,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_eqp(C_fix(0),t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#address->pointer in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_28748,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28752,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5568: ##sys#make-pointer */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1144]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1144]+1);
av2[1]=t3;
tp(2,av2);}}

/* k28750 in ##sys#address->pointer in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28752(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28752,c,av);}
t2=C_update_pointer(((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#pointer->address in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28754(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_28754,c,av);}
a=C_alloc(6);
t3=C_slot(t2,C_fix(0));
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_unsigned_int_to_num(&a,1,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#make-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28761(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28761,c,av);}
a=C_alloc(6);
t3=C_rest_nullp(c,3);
t4=(C_truep(t3)?lf[764]:C_get_rest_arg(c,3,av,3,t0));
t5=C_block_size(t2);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28771,a[2]=t2,a[3]=t5,a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5578: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t6;
av2[2]=C_fixnum_plus(t5,C_fix(1));
tp(3,av2);}}

/* k28769 in ##sys#make-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_28771,c,av);}
t2=C_substring_copy(((C_word*)t0)[2],t1,C_fix(0),((C_word*)t0)[3],C_fix(0));
t3=C_setsubchar(t1,((C_word*)t0)[3],C_make_character(0));
t4=C_eqp(C_asciiz_strlen(t1),((C_word*)t0)[3]);
if(C_truep(t4)){
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_fix((C_word)C_ASCIIZ_REPRESENTATION_ERROR);
/* library.scm:5583: ##sys#error-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[371]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[371]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=t5;
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[2];
tp(5,av2);}}}

/* ##sys#peek-fixnum in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28796(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28796,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_peek_fixnum(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#peek-byte in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28799,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_peek_byte(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#vector->structure! in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28802(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28802,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_vector_to_structure(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#peek-double in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_28805,c,av);}
a=C_alloc(4);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_f64peek(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#peek-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28808(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28808,c,av);}
a=C_alloc(6);
t4=C_null_pointerp(t2);
if(C_truep(C_i_not(t4))){
t5=C_fetch_c_strlen(t2,t3);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28818,a[2]=t2,a[3]=t3,a[4]=t5,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5599: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t6;
av2[2]=t5;
tp(3,av2);}}
else{
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k28816 in ##sys#peek-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28818(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28818,c,av);}
t2=C_peek_c_string(((C_word*)t0)[2],((C_word*)t0)[3],t1,((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#peek-nonnull-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28824(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28824,c,av);}
a=C_alloc(6);
t4=C_fetch_c_strlen(t2,t3);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28828,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5605: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}

/* k28826 in ##sys#peek-nonnull-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28828,c,av);}
t2=C_peek_c_string(((C_word*)t0)[2],((C_word*)t0)[3],t1,((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#peek-and-free-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28830(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28830,c,av);}
a=C_alloc(6);
t4=C_null_pointerp(t2);
if(C_truep(C_i_not(t4))){
t5=C_fetch_c_strlen(t2,t3);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28840,a[2]=t2,a[3]=t3,a[4]=t5,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5612: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t6;
av2[2]=t5;
tp(3,av2);}}
else{
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k28838 in ##sys#peek-and-free-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28840,c,av);}
t2=C_peek_c_string(((C_word*)t0)[2],((C_word*)t0)[3],t1,((C_word*)t0)[4]);
t3=C_free_mptr(((C_word*)t0)[2],((C_word*)t0)[3]);
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#peek-and-free-nonnull-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28846(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28846,c,av);}
a=C_alloc(6);
t4=C_fetch_c_strlen(t2,t3);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28850,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5619: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}

/* k28848 in ##sys#peek-and-free-nonnull-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28850,c,av);}
t2=C_peek_c_string(((C_word*)t0)[2],((C_word*)t0)[3],t1,((C_word*)t0)[4]);
t3=C_free_mptr(((C_word*)t0)[2],((C_word*)t0)[3]);
t4=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#poke-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_28852,c,av);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28857,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:5625: ##sys#make-c-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[764]);
C_word *av2=av;
av2[0]=*((C_word*)lf[764]+1);
av2[1]=t5;
av2[2]=t4;
tp(3,av2);}}

/* k28855 in ##sys#poke-c-string in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28857(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28857,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_poke_c_string(((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#poke-integer in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28859,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_poke_integer(t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#poke-double in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28862,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_poke_double(t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#peek-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28882(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_28882,c,av);}
a=C_alloc(8);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28888,a[2]=t3,a[3]=t5,a[4]=t2,a[5]=((C_word)li863),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_28888(t7,t1,C_fix(0));}

/* loop in ##sys#peek-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_28888(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_28888,3,t0,t1,t2);}
a=C_alloc(10);
t3=(C_truep(((C_word*)t0)[2])?C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_28898,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=C_a_i_bytevector(&a,1,C_fix(3));
t6=(C_truep(((C_word*)t0)[4])?C_i_foreign_pointer_argumentp(((C_word*)t0)[4]):C_SCHEME_FALSE);
t7=C_i_foreign_fixnum_argumentp(t2);
/* library.scm:5631: ##sys#peek-c-string */
t8=*((C_word*)lf[721]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t4;
av2[2]=stub6555(t5,t6,t7);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}}

/* k28896 in loop in ##sys#peek-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_28898(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_28898,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28908,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5638: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_28888(t3,t2,C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k28906 in k28896 in loop in ##sys#peek-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_28908(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_28908,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#peek-and-free-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_28943,c,av);}
a=C_alloc(12);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28947,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28952,a[2]=t3,a[3]=t2,a[4]=t6,a[5]=((C_word)li865),tmp=(C_word)a,a+=6,tmp));
t8=((C_word*)t6)[1];
f_28952(t8,t4,C_fix(0));}

/* k28945 in ##sys#peek-and-free-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_28947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28947,c,av);}
if(C_truep(((C_word*)t0)[2])){
t2=C_i_foreign_pointer_argumentp(((C_word*)t0)[2]);
t3=stub6582(C_SCHEME_UNDEFINED,t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=stub6582(C_SCHEME_UNDEFINED,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* loop in ##sys#peek-and-free-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_28952(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_28952,3,t0,t1,t2);}
a=C_alloc(11);
t3=(C_truep(((C_word*)t0)[2])?C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_28962,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t5=C_a_i_bytevector(&a,1,C_fix(3));
t6=(C_truep(((C_word*)t0)[3])?C_i_foreign_pointer_argumentp(((C_word*)t0)[3]):C_SCHEME_FALSE);
t7=C_i_foreign_fixnum_argumentp(t2);
/* library.scm:5642: ##sys#peek-c-string */
t8=*((C_word*)lf[721]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t4;
av2[2]=stub6574(t5,t6,t7);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}}

/* k28960 in loop in ##sys#peek-and-free-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_28962(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_28962,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=C_free_sptr(((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_28972,a[2]=((C_word*)t0)[4],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5651: loop */
t4=((C_word*)((C_word*)t0)[5])[1];
f_28952(t4,t3,C_fixnum_plus(((C_word*)t0)[3],C_fix(1)));}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k28970 in k28960 in loop in ##sys#peek-and-free-c-string-list in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_28972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_28972,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#vector->closure! in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28981,c,av);}
t4=C_vector_to_closure(t2);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_update_pointer(t3,t2);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* ##sys#symbol-has-toplevel-binding? in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28984(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28984,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_boundp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#copy-bytes in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28987(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word *a;
if(c!=7) C_bad_argc_2(c,7,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28987,c,av);}
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_substring_copy(t2,t3,t4,C_fixnum_plus(t4,t6),t5);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* ##sys#copy-words in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_28994(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word *a;
if(c!=7) C_bad_argc_2(c,7,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_28994,c,av);}
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_subvector_copy(t2,t3,t4,C_fixnum_plus(t4,t6),t5);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* ##sys#compare-bytes in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6=av[6];
C_word t7;
C_word *a;
if(c!=7) C_bad_argc_2(c,7,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29001,c,av);}
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_substring_compare(t2,t3,t4,t5,t6);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* ##sys#block-pointer in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29004(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_29004,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29008,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5684: ##sys#make-pointer */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1144]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1144]+1);
av2[1]=t3;
tp(2,av2);}}

/* k29006 in ##sys#block-pointer in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29008(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29008,c,av);}
t2=C_pointer_to_block(t1,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-char-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29010,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_foreign_char_argumentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-fixnum-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29013,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_foreign_fixnum_argumentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-flonum-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29016(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29016,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_foreign_flonum_argumentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-block-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29019,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_foreign_block_argumentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-struct-wrapper-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29022(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29022,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_foreign_struct_wrapper_argumentp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#foreign-string-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29025,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_foreign_string_argumentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-symbol-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29028(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29028,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_foreign_symbol_argumentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-pointer-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29031,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_foreign_pointer_argumentp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#foreign-tagged-pointer-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29034(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29034,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_foreign_tagged_pointer_argumentp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#foreign-ranged-integer-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29037,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_foreign_ranged_integer_argumentp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#foreign-unsigned-ranged-integer-argument in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29040,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_foreign_unsigned_ranged_integer_argumentp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#default-exception-handler in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29044(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29044,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_halt(lf[1187]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#make-thread in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_29047,c,av);}
a=C_alloc(7);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_29063,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
/* library.scm:5729: ##sys#vector-resize */
f_18582(t6,C_fast_retrieve(lf[781]),C_block_size(C_fast_retrieve(lf[781])),C_SCHEME_FALSE);}

/* k29061 in ##sys#make-thread in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29063(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,1)))){
C_save_and_reclaim((void *)f_29063,c,av);}
a=C_alloc(26);
t2=C_a_i_vector6(&a,6,C_fast_retrieve(lf[709]),*((C_word*)lf[732]+1),*((C_word*)lf[733]+1),*((C_word*)lf[734]+1),C_fast_retrieve(lf[1186]),t1);
t3=C_a_i_cons(&a,2,C_SCHEME_FALSE,C_SCHEME_FALSE);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_record(&a,15,lf[939],((C_word*)t0)[3],C_SCHEME_FALSE,((C_word*)t0)[4],C_SCHEME_FALSE,t2,((C_word*)t0)[5],C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST,((C_word*)t0)[6],C_SCHEME_UNDEFINED,C_SCHEME_FALSE,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_29071(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(45,c,4)))){
C_save_and_reclaim((void *)f_29071,c,av);}
a=C_alloc(45);
t2=C_mutate((C_word*)lf[976]+1 /* (set! ##sys#primordial-thread ...) */,t1);
t3=C_mutate((C_word*)lf[964]+1 /* (set! ##sys#current-thread ...) */,C_fast_retrieve(lf[976]));
t4=C_mutate((C_word*)lf[1189]+1 /* (set! ##sys#make-mutex ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29074,a[2]=((C_word)li886),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[1191]+1 /* (set! ##sys#schedule ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29080,a[2]=((C_word)li887),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[1192]+1 /* (set! ##sys#thread-yield! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29089,a[2]=((C_word)li890),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[1193]+1 /* (set! ##sys#kill-other-threads ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29110,a[2]=((C_word)li891),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[1194]+1 /* (set! ##sys#resume-thread-on-event ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29116,a[2]=((C_word)li892),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[1195]+1 /* (set! ##sys#suspend-thread-on-event ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29119,a[2]=((C_word)li893),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[1196]+1 /* (set! ##sys#sleep-until-interrupt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29125,a[2]=((C_word)li895),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[1197]+1 /* (set! ##sys#make-event-queue ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29134,a[2]=((C_word)li896),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate((C_word*)lf[1199]+1 /* (set! ##sys#add-event-to-queue! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29140,a[2]=((C_word)li897),tmp=(C_word)a,a+=3,tmp));
t13=C_mutate((C_word*)lf[1200]+1 /* (set! ##sys#get-next-event ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29179,a[2]=((C_word)li898),tmp=(C_word)a,a+=3,tmp));
t14=C_mutate((C_word*)lf[1201]+1 /* (set! ##sys#wait-for-next-event ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29222,a[2]=((C_word)li900),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[1203]+1 /* (set! chicken.base#sleep-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29276,a[2]=((C_word)li901),tmp=(C_word)a,a+=3,tmp));
t16=C_mutate((C_word*)lf[197]+1 /* (set! chicken.base#sleep ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29279,a[2]=((C_word)li902),tmp=(C_word)a,a+=3,tmp));
t17=C_mutate((C_word*)lf[1205]+1 /* (set! ##sys#context-switch ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_context_switch,a[2]=((C_word)li903),tmp=(C_word)a,a+=3,tmp));
t18=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29291,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5847: scheme#make-vector */
t19=*((C_word*)lf[93]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t19;
av2[1]=t18;
av2[2]=C_fix(256);
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t19+1)))(4,av2);}}

/* ##sys#make-mutex in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29074(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,1)))){
C_save_and_reclaim((void *)f_29074,c,av);}
a=C_alloc(8);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_record7(&a,7,lf[1190],t2,t3,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE,C_SCHEME_FALSE,C_SCHEME_UNDEFINED);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* ##sys#schedule in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29080,c,av);}
/* library.scm:5756: g6668 */
t2=C_slot(C_fast_retrieve(lf[964]),C_fix(1));{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)C_fast_retrieve_proc(t2))(2,av2);}}

/* ##sys#thread-yield! in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29089(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_29089,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29095,a[2]=((C_word)li889),tmp=(C_word)a,a+=3,tmp);
/* library.scm:5759: ##sys#call-with-current-continuation */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
C_call_cc(3,av2);}}

/* a29094 in ##sys#thread-yield! in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29095(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_29095,c,av);}
a=C_alloc(4);
t3=C_fast_retrieve(lf[964]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29104,a[2]=t2,a[3]=((C_word)li888),tmp=(C_word)a,a+=4,tmp);
t5=C_i_setslot(C_fast_retrieve(lf[964]),C_fix(1),t4);
/* library.scm:5763: ##sys#schedule */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1191]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1191]+1);
av2[1]=t1;
tp(2,av2);}}

/* a29103 in a29094 in ##sys#thread-yield! in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29104(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29104,c,av);}
/* library.scm:5762: return */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=C_SCHEME_UNDEFINED;
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* ##sys#kill-other-threads in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29110(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29110,c,av);}
/* library.scm:5766: thunk */
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)C_fast_retrieve_proc(t3))(2,av2);}}

/* ##sys#resume-thread-on-event in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29116(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29116,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#suspend-thread-on-event in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29119,c,av);}
/* library.scm:5774: ##sys#sleep-until-interrupt */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1196]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1196]+1);
av2[1]=t1;
tp(2,av2);}}

/* ##sys#sleep-until-interrupt in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_29125,c,av);}
a=C_alloc(3);
t2=C_i_sleep_until_interrupt(C_fix(100));
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29131,a[2]=((C_word)li894),tmp=(C_word)a,a+=3,tmp);
/* library.scm:5778: ##sys#dispatch-interrupt */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[717]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[717]+1);
av2[1]=t1;
av2[2]=t3;
tp(3,av2);}}

/* a29130 in ##sys#sleep-until-interrupt in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29131(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29131,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#make-event-queue in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_29134,c,av);}
a=C_alloc(5);
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_record4(&a,4,lf[1198],C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* ##sys#add-event-to-queue! in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29140(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_29140,c,av);}
a=C_alloc(3);
t4=C_slot(t2,C_fix(1));
t5=C_slot(t2,C_fix(2));
t6=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t7=C_i_nullp(t4);
t8=(C_truep(t7)?C_i_setslot(t2,C_fix(1),t6):C_i_setslot(t5,C_fix(1),t6));
t9=C_i_setslot(t2,C_fix(2),t6);
t10=C_slot(t2,C_fix(3));
if(C_truep(t10)){
t11=C_i_set_i_slot(t2,C_fix(3),C_SCHEME_FALSE);
/* library.scm:5800: ##sys#resume-thread-on-event */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1194]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1194]+1);
av2[1]=t1;
av2[2]=t10;
tp(3,av2);}}
else{
t11=C_SCHEME_UNDEFINED;
t12=t1;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}}

/* ##sys#get-next-event in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29179(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29179,c,av);}
t3=C_slot(t2,C_fix(3));
if(C_truep(C_i_not(t3))){
t4=C_slot(t2,C_fix(1));
t5=C_i_nullp(t4);
if(C_truep(C_i_not(t5))){
t6=C_slot(t4,C_fix(0));
t7=C_slot(t4,C_fix(1));
t8=C_i_setslot(t2,C_fix(1),t7);
if(C_truep(C_i_nullp(t7))){
t9=C_i_set_i_slot(t2,C_fix(2),C_SCHEME_END_OF_LIST);
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t9=t1;{
C_word *av2=av;
av2[0]=t9;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* ##sys#wait-for-next-event in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29222(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,5)))){
C_save_and_reclaim((void *)f_29222,c,av);}
a=C_alloc(4);
t3=C_slot(t2,C_fix(3));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29229,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t3)){
/* library.scm:5816: ##sys#signal-hook */
t5=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[1003];
av2[3]=C_SCHEME_FALSE;
av2[4]=lf[1202];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_29229(2,av2);}}}

/* k29227 in ##sys#wait-for-next-event in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29229(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_29229,c,av);}
a=C_alloc(7);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29234,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word)li899),tmp=(C_word)a,a+=5,tmp));
t5=((C_word*)t3)[1];
f_29234(t5,((C_word*)t0)[3]);}

/* again in k29227 in ##sys#wait-for-next-event in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_fcall f_29234(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_29234,2,t0,t1);}
a=C_alloc(4);
t2=C_slot(((C_word*)t0)[2],C_fix(1));
if(C_truep(C_i_nullp(t2))){
t3=C_i_setslot(((C_word*)t0)[2],C_fix(3),C_fast_retrieve(lf[964]));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29250,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5821: ##sys#suspend-thread-on-event */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1195]);
C_word av2[3];
av2[0]=*((C_word*)lf[1195]+1);
av2[1]=t4;
av2[2]=C_fast_retrieve(lf[964]);
tp(3,av2);}}
else{
t3=C_slot(t2,C_fix(0));
t4=C_slot(t2,C_fix(1));
t5=C_i_setslot(((C_word*)t0)[2],C_fix(1),t4);
if(C_truep(C_i_nullp(t4))){
t6=C_i_set_i_slot(((C_word*)t0)[2],C_fix(2),C_SCHEME_END_OF_LIST);
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}

/* k29248 in again in k29227 in ##sys#wait-for-next-event in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29250,c,av);}
/* library.scm:5822: again */
t2=((C_word*)((C_word*)t0)[2])[1];
f_29234(t2,((C_word*)t0)[3]);}

/* chicken.base#sleep-hook in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29276(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29276,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_process_sleep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#sleep in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29279(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_29279,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29283,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5838: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[1204];
tp(4,av2);}}

/* k29281 in chicken.base#sleep in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29283(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_29283,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29286,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5839: chicken.base#sleep-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1203]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[1203]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k29284 in k29281 in chicken.base#sleep in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29286,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_29291(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(55,c,4)))){
C_save_and_reclaim((void *)f_29291,c,av);}
a=C_alloc(55);
t2=C_mutate((C_word*)lf[1206]+1 /* (set! ##sys#signal-vector ...) */,t1);
t3=C_mutate((C_word*)lf[1207]+1 /* (set! ##sys#interrupt-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29293,a[2]=((C_word)li905),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[717]+1 /* (set! ##sys#dispatch-interrupt ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29343,a[2]=((C_word)li906),tmp=(C_word)a,a+=3,tmp));
t5=C_fix(0);
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_mutate((C_word*)lf[722]+1 /* (set! ##sys#update-errno ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29350,a[2]=t6,a[3]=((C_word)li907),tmp=(C_word)a,a+=4,tmp));
t8=C_mutate((C_word*)lf[1208]+1 /* (set! ##sys#errno ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29354,a[2]=t6,a[3]=((C_word)li908),tmp=(C_word)a,a+=4,tmp));
t9=C_fast_retrieve(lf[876]);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29368,a[2]=((C_word)li910),tmp=(C_word)a,a+=3,tmp));
t15=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29415,a[2]=((C_word)li912),tmp=(C_word)a,a+=3,tmp));
t16=C_mutate((C_word*)lf[876]+1 /* (set! ##sys#user-read-hook ...) */,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29460,a[2]=t9,a[3]=t11,a[4]=t13,a[5]=((C_word)li917),tmp=(C_word)a,a+=6,tmp));
t17=C_a_i_provide(&a,1,lf[1219]);
t18=C_mutate((C_word*)lf[1220]+1 /* (set! chicken.process-context#change-directory ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29890,a[2]=((C_word)li918),tmp=(C_word)a,a+=3,tmp));
t19=C_mutate((C_word*)lf[1223]+1 /* (set! ##sys#change-directory-hook ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29921,a[2]=((C_word)li919),tmp=(C_word)a,a+=3,tmp));
t20=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29929,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t21=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32288,a[2]=((C_word)li1009),tmp=(C_word)a,a+=3,tmp);
t22=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32313,a[2]=((C_word)li1010),tmp=(C_word)a,a+=3,tmp);
/* library.scm:6064: chicken.base#getter-with-setter */
t23=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t23;
av2[1]=t20;
av2[2]=t21;
av2[3]=t22;
av2[4]=lf[1414];
((C_proc)(void*)(*((C_word*)t23+1)))(5,av2);}}

/* ##sys#interrupt-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_29293,c,av);}
a=C_alloc(10);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29297,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29324,a[2]=t6,a[3]=((C_word)li904),tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_29324(t8,t4,t2);}

/* k29295 in ##sys#interrupt-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29297,c,av);}
t2=C_slot(C_fast_retrieve(lf[982]),C_fix(0));
if(C_truep(C_fixnum_greaterp(t2,C_fix(0)))){
/* library.scm:5857: ##sys#run-pending-finalizers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[983]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[983]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
if(C_truep(C_i_closurep(((C_word*)t0)[3]))){
/* library.scm:5858: state */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* library.scm:5859: ##sys#context-switch */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
C_context_switch(3,av2);}}}}

/* loop in ##sys#interrupt-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_fcall f_29324(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_29324,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(t2)){
t3=C_slot(C_fast_retrieve(lf[1206]),t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29334,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t3)){
/* library.scm:5854: handler */
t5=t3;{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)C_fast_retrieve_proc(t5))(3,av2);}}
else{
/* library.scm:5855: loop */
t6=t1;
t7=C_i_pending_interrupt(C_SCHEME_FALSE);
t1=t6;
t2=t7;
goto loop;}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k29332 in loop in ##sys#interrupt-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29334,c,av);}
/* library.scm:5855: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_29324(t2,((C_word*)t0)[3],C_i_pending_interrupt(C_SCHEME_FALSE));}

/* ##sys#dispatch-interrupt in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29343(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29343,c,av);}
/* library.scm:5862: ##sys#interrupt-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1207]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[1207]+1);
av2[1]=t1;
av2[2]=C_i_pending_interrupt(C_SCHEME_FALSE);
av2[3]=t2;
tp(4,av2);}}

/* ##sys#update-errno in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29350(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29350,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_fix((C_word)errno));
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#errno in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29354,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* readln in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_fcall f_29368(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_29368,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29372,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5891: chicken.base#open-output-string */
t4=*((C_word*)lf[215]+1);{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k29370 in readln in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29372(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_29372,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29379,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5892: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k29377 in k29370 in readln in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_29379,c,av);}
a=C_alloc(8);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29381,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word)li909),tmp=(C_word)a,a+=6,tmp));
t5=((C_word*)t3)[1];
f_29381(t5,((C_word*)t0)[4],t1);}

/* doloop6760 in k29377 in k29370 in readln in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_fcall f_29381(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_29381,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eofp(t2);
t4=(C_truep(t3)?t3:C_i_char_equalp(C_make_character(10),t2));
if(C_truep(t4)){
if(C_truep(C_eofp(t2))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* library.scm:5894: chicken.base#get-output-string */
t5=*((C_word*)lf[213]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29403,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5895: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word av2[4];
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t5;
av2[2]=t2;
av2[3]=((C_word*)t0)[2];
tp(4,av2);}}}

/* k29401 in doloop6760 in k29377 in k29370 in readln in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_29403(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_29403,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29410,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5892: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
tp(3,av2);}}

/* k29408 in k29401 in doloop6760 in k29377 in k29370 in readln in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_29410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29410,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29381(t2,((C_word*)t0)[3],t1);}

/* read-escaped-sexp in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_fcall f_29415(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29415,3,t1,t2,t3);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29419,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t3)){
/* library.scm:5897: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t4;
av2[2]=t2;
tp(3,av2);}}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_29419(2,av2);}}}

/* k29417 in read-escaped-sexp in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29419(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_29419,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29422,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5898: read */
t3=*((C_word*)lf[149]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k29420 in k29417 in read-escaped-sexp in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29422(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_29422,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29425,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[3])){
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29430,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=((C_word)li911),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_29430(t6,t2);}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k29423 in k29420 in k29417 in read-escaped-sexp in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_29425(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29425,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in k29420 in k29417 in read-escaped-sexp in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_fcall f_29430(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_29430,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29434,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5902: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k29432 in loop in k29420 in k29417 in read-escaped-sexp in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_29434(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29434,c,av);}
if(C_truep(C_eofp(t1))){
/* library.scm:5904: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1209];
tp(4,av2);}}
else{
t2=C_i_char_equalp(C_make_character(125),t1);
if(C_truep(C_i_not(t2))){
/* library.scm:5905: loop */
t3=((C_word*)((C_word*)t0)[4])[1];
f_29430(t3,((C_word*)t0)[2]);}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29460,c,av);}
a=C_alloc(6);
t4=C_i_char_equalp(C_make_character(60),t2);
if(C_truep(C_i_not(t4))){
/* library.scm:5908: old */
t5=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
((C_proc)C_fast_retrieve_proc(t5))(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29473,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* ##sys#read-char/port */
t6=C_fast_retrieve(lf[785]);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29473,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29476,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5911: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}

/* k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29476(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29476,c,av);}
a=C_alloc(6);
switch(t1){
case C_make_character(60):
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29485,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5913: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}
case C_make_character(35):
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29598,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5938: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}
default:
/* library.scm:5993: ##sys#read-error */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[793]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[793]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[2];
av2[3]=lf[1218];
tp(4,av2);}}}

/* k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_29485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_29485,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29488,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5914: chicken.base#open-output-string */
t3=*((C_word*)lf[215]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_29488(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29488,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29491,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5915: readln */
f_29368(t2,((C_word*)t0)[2]);}

/* k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_29491(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_29491,c,av);}
a=C_alloc(10);
t2=C_SCHEME_FALSE;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_eofp(t1);
t5=(C_truep(t4)?C_fix(0):C_i_string_length(t1));
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_29497,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t3,a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
t7=C_eqp(t5,C_fix(0));
if(C_truep(t7)){
/* library.scm:5920: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1212];
tp(4,av2);}}
else{
t8=C_fixnum_difference(t5,C_fix(1));
t9=C_i_string_ref(t1,t8);
t10=C_u_i_char_equalp(t9,C_make_character(32));
if(C_truep(t10)){
if(C_truep(t10)){
/* library.scm:5924: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1213];
tp(4,av2);}}
else{
t11=C_SCHEME_UNDEFINED;
t12=t6;{
C_word *av2=av;
av2[0]=t12;
av2[1]=t11;
f_29497(2,av2);}}}
else{
t11=C_fixnum_difference(t5,C_fix(1));
t12=C_i_string_ref(t1,t11);
if(C_truep(C_u_i_char_equalp(t12,C_make_character(9)))){
/* library.scm:5924: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1213];
tp(4,av2);}}
else{
t13=C_SCHEME_UNDEFINED;
t14=t6;{
C_word *av2=av;
av2[0]=t14;
av2[1]=t13;
f_29497(2,av2);}}}}}

/* k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_29497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_29497,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_29504,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* library.scm:5927: readln */
f_29368(t2,((C_word*)t0)[4]);}

/* k29502 in k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_29504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29504,c,av);}
a=C_alloc(11);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_29506,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t3,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word)li913),tmp=(C_word)a,a+=9,tmp));
t5=((C_word*)t3)[1];
f_29506(t5,((C_word*)t0)[7],t1);}

/* doloop6795 in k29502 in k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_fcall f_29506(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,0,3)))){
C_save_and_reclaim_args((void *)trf_29506,3,t0,t1,t2);}
a=C_alloc(17);
t3=C_eofp(t2);
t4=(C_truep(t3)?t3:C_i_string_equal_p(((C_word*)t0)[2],t2));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29519,a[2]=t1,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_eofp(t2))){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29532,a[2]=t5,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t7=C_a_i_list(&a,3,lf[1210],((C_word*)t0)[2],lf[1211]);
/* library.scm:5882: ##sys#print-to-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[957]);
C_word av2[3];
av2[0]=*((C_word*)lf[957]+1);
av2[1]=t6;
av2[2]=t7;
tp(3,av2);}}
else{
/* library.scm:5932: chicken.base#get-output-string */
t6=*((C_word*)lf[213]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_29535,a[2]=((C_word*)t0)[5],a[3]=t1,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[4],a[6]=t2,a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)((C_word*)t0)[7])[1])){
/* library.scm:5934: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word av2[4];
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t5;
av2[2]=C_make_character(10);
av2[3]=((C_word*)t0)[3];
tp(4,av2);}}
else{
t6=C_set_block_item(((C_word*)t0)[7],0,C_SCHEME_TRUE);
t7=t5;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
f_29535(2,av2);}}}}

/* k29517 in doloop6795 in k29502 in k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_29519(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29519,c,av);}
/* library.scm:5932: chicken.base#get-output-string */
t2=*((C_word*)lf[213]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k29530 in doloop6795 in k29502 in k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_29532(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29532,c,av);}
/* library.scm:5930: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k29533 in doloop6795 in k29502 in k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_29535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29535,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29538,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5936: display */
t3=*((C_word*)lf[153]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k29536 in k29533 in doloop6795 in k29502 in k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_29538(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_29538,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29545,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5927: readln */
f_29368(t2,((C_word*)t0)[5]);}

/* k29543 in k29536 in k29533 in doloop6795 in k29502 in k29495 in k29489 in k29486 in k29483 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_29545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29545,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_29506(t2,((C_word*)t0)[3],t1);}

/* k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_29598(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_29598,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29601,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5939: readln */
f_29368(t2,((C_word*)t0)[2]);}

/* k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_29601(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29601,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29604,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5940: chicken.base#open-output-string */
t3=*((C_word*)lf[215]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_29604(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_29604,c,av);}
a=C_alloc(14);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29606,a[2]=t3,a[3]=((C_word)li914),tmp=(C_word)a,a+=4,tmp);
t5=C_eofp(((C_word*)t0)[2]);
t6=(C_truep(t5)?C_fix(0):C_i_string_length(((C_word*)t0)[2]));
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_29620,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t4,a[5]=t3,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
t8=C_eqp(t6,C_fix(0));
if(C_truep(t8)){
/* library.scm:5949: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t7;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1216];
tp(4,av2);}}
else{
t9=C_fixnum_difference(t6,C_fix(1));
t10=C_i_string_ref(((C_word*)t0)[2],t9);
t11=C_u_i_char_equalp(t10,C_make_character(32));
if(C_truep(t11)){
if(C_truep(t11)){
/* library.scm:5953: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t7;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1217];
tp(4,av2);}}
else{
t12=C_SCHEME_UNDEFINED;
t13=t7;{
C_word *av2=av;
av2[0]=t13;
av2[1]=t12;
f_29620(2,av2);}}}
else{
t12=C_fixnum_difference(t6,C_fix(1));
t13=C_i_string_ref(((C_word*)t0)[2],t12);
if(C_truep(C_u_i_char_equalp(t13,C_make_character(9)))){
/* library.scm:5953: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=t7;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1217];
tp(4,av2);}}
else{
t14=C_SCHEME_UNDEFINED;
t15=t7;{
C_word *av2=av;
av2[0]=t15;
av2[1]=t14;
f_29620(2,av2);}}}}}

/* get/clear-str in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_fcall f_29606(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_29606,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29610,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5942: chicken.base#get-output-string */
t3=*((C_word*)lf[213]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k29608 in get/clear-str in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_29610(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_29610,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29614,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5943: chicken.base#open-output-string */
t3=*((C_word*)lf[215]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k29612 in k29608 in get/clear-str in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_29614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29614,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_29620(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29620,c,av);}
a=C_alloc(11);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_29625,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word)li916),tmp=(C_word)a,a+=9,tmp));
t5=((C_word*)t3)[1];
f_29625(t5,((C_word*)t0)[7],C_SCHEME_END_OF_LIST);}

/* loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_fcall f_29625(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_29625,3,t0,t1,t2);}
a=C_alloc(10);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_29629,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* library.scm:5958: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word av2[3];
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}

/* k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_29629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_29629,c,av);}
a=C_alloc(9);
t2=C_eqp(t1,C_make_character(10));
t3=(C_truep(t2)?t2:C_eqp(t1,C_SCHEME_END_OF_FILE));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_29641,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* library.scm:5961: get/clear-str */
t5=((C_word*)t0)[7];
f_29606(t5,t4);}
else{
t4=C_eqp(t1,C_make_character(35));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_29761,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
/* library.scm:5981: ##sys#peek-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[786]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[786]+1);
av2[1]=t5;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29828,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5991: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t5;
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[8])[1];
tp(4,av2);}}}}

/* k29639 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_29641(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_29641,c,av);}
a=C_alloc(17);
t2=C_eofp(((C_word*)t0)[2]);
t3=(C_truep(t2)?t2:C_i_string_equal_p(((C_word*)t0)[3],t1));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29653,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_eofp(((C_word*)t0)[2]))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29738,a[2]=t4,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t6=C_a_i_list(&a,3,lf[1210],((C_word*)t0)[3],lf[1211]);
/* library.scm:5882: ##sys#print-to-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[957]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[957]+1);
av2[1]=t5;
av2[2]=t6;
tp(3,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_29653(2,av2);}}}
else{
t4=C_a_i_cons(&a,2,t1,((C_word*)t0)[5]);
t5=C_a_i_cons(&a,2,C_make_character(10),t4);
/* library.scm:5979: loop */
t6=((C_word*)((C_word*)t0)[7])[1];
f_29625(t6,((C_word*)t0)[4],t5);}}

/* k29651 in k29639 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_29653(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_29653,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29660,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_i_cdr(((C_word*)t0)[3]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29666,a[2]=t5,a[3]=((C_word)li915),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_29666(t7,t2,t3,C_SCHEME_END_OF_LIST,lf[1215]);}

/* k29658 in k29651 in k29639 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_29660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_29660,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,2,lf[957],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop2 in k29651 in k29639 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_fcall f_29666(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_29666,5,t0,t1,t2,t3,t4);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29680,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5971: ##sys#print-to-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[957]);
C_word av2[3];
av2[0]=*((C_word*)lf[957]+1);
av2[1]=t5;
av2[2]=t3;
tp(3,av2);}}
else{
t5=C_i_car(t2);
t6=C_i_stringp(t5);
t7=(C_truep(t6)?t6:C_charp(C_u_i_car(t2)));
if(C_truep(t7)){
t8=C_u_i_cdr(t2);
t9=C_u_i_car(t2);
t10=C_a_i_cons(&a,2,t9,t3);
/* library.scm:5973: loop2 */
t12=t1;
t13=t8;
t14=t10;
t15=t4;
t1=t12;
t2=t13;
t3=t14;
t4=t15;
goto loop;}
else{
t8=C_u_i_cdr(t2);
t9=C_u_i_car(t2);
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_29719,a[2]=t4,a[3]=t9,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=t8,tmp=(C_word)a,a+=7,tmp);
/* library.scm:5978: ##sys#print-to-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[957]);
C_word av2[3];
av2[0]=*((C_word*)lf[957]+1);
av2[1]=t10;
av2[2]=t3;
tp(3,av2);}}}}

/* k29678 in loop2 in k29651 in k29639 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_ccall f_29680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_29680,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[1214],t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k29717 in loop2 in k29651 in k29639 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_ccall f_29719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,4)))){
C_save_and_reclaim((void *)f_29719,c,av);}
a=C_alloc(18);
t2=C_a_i_list(&a,3,lf[1214],t1,((C_word*)t0)[2]);
t3=C_a_i_list(&a,3,lf[1214],((C_word*)t0)[3],t2);
/* library.scm:5975: loop2 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_29666(t4,((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_END_OF_LIST,t3);}

/* k29736 in k29639 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_29738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29738,c,av);}
/* library.scm:5964: ##sys#read-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[796]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[796]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k29759 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_29761(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_29761,c,av);}
a=C_alloc(9);
switch(t1){
case C_make_character(35):
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29770,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29777,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5984: ##sys#read-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[784]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[784]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
tp(3,av2);}
case C_make_character(123):
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29794,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5986: read-escaped-sexp */
f_29415(t2,((C_word*)t0)[6],C_SCHEME_TRUE);
default:
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29813,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5988: read-escaped-sexp */
f_29415(t2,((C_word*)t0)[6],C_SCHEME_FALSE);}}

/* k29768 in k29759 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_29770(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29770,c,av);}
/* library.scm:5985: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_29625(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k29775 in k29759 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_29777(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29777,c,av);}
/* library.scm:5984: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[3])[1];
tp(4,av2);}}

/* k29792 in k29759 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_29794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29794,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29802,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5987: get/clear-str */
t3=((C_word*)t0)[5];
f_29606(t3,t2);}

/* k29800 in k29792 in k29759 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_29802(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29802,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
/* library.scm:5986: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_29625(t4,((C_word*)t0)[5],t3);}

/* k29811 in k29759 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_29813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29813,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_29821,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:5989: get/clear-str */
t3=((C_word*)t0)[5];
f_29606(t3,t2);}

/* k29819 in k29811 in k29759 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_29821(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_29821,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
/* library.scm:5988: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_29625(t4,((C_word*)t0)[5],t3);}

/* k29826 in k29627 in loop in k29618 in k29602 in k29599 in k29596 in k29474 in k29471 in ##sys#user-read-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_29828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29828,c,av);}
/* library.scm:5992: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_29625(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* chicken.process-context#change-directory in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29890(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_29890,c,av);}
a=C_alloc(4);
t3=C_i_check_string_2(t2,lf[1221]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29897,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6054: ##sys#make-c-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[764]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[764]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[1221];
tp(4,av2);}}

/* k29895 in chicken.process-context#change-directory in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29897(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_29897,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29900,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_eqp(C_chdir(t1),C_fix(0));
if(C_truep(t3)){
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29910,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:6056: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word *av2=av;
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t4;
tp(2,av2);}}}

/* k29898 in k29895 in chicken.process-context#change-directory in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29900(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29900,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k29908 in k29895 in chicken.process-context#change-directory in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29910(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_29910,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29914,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29918,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t4=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_mpointer(&a,(void*)strerror(errno));
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k29912 in k29908 in k29895 in chicken.process-context#change-directory in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_29914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_29914,c,av);}
/* library.scm:6056: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[718];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1221];
av2[5]=t1;
av2[6]=((C_word*)t0)[4];
tp(7,av2);}}

/* k29916 in k29908 in k29895 in chicken.process-context#change-directory in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_29918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29918,c,av);}
/* library.scm:6057: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1222];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* ##sys#change-directory-hook in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_29921,c,av);}
/* library.scm:6061: change-directory */
t3=C_fast_retrieve(lf[1220]);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_29929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,4)))){
C_save_and_reclaim((void *)f_29929,c,av);}
a=C_alloc(30);
t2=C_mutate((C_word*)lf[1224]+1 /* (set! chicken.process-context#current-directory ...) */,t1);
t3=C_mutate((C_word*)lf[1225]+1 /* (set! chicken.process-context#get-environment-variable ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29931,a[2]=((C_word)li920),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[1226]+1 /* (set! chicken.process-context#set-environment-variable! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29946,a[2]=((C_word)li921),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[1228]+1 /* (set! chicken.process-context#unset-environment-variable! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29963,a[2]=((C_word)li922),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[1230]+1 /* (set! chicken.process-context#get-environment-variables ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29983,a[2]=((C_word)li925),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[1231]+1 /* (set! chicken.process-context#executable-pathname ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30049,a[2]=((C_word)li926),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[1232]+1 /* (set! chicken.process-context#argc+argv ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30056,a[2]=((C_word)li927),tmp=(C_word)a,a+=3,tmp));
t9=C_SCHEME_FALSE;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_mutate((C_word*)lf[1233]+1 /* (set! chicken.process-context#argv ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30068,a[2]=t10,a[3]=((C_word)li929),tmp=(C_word)a,a+=4,tmp));
t12=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30108,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32286,a[2]=t12,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6140: argv */
t14=C_fast_retrieve(lf[1233]);{
C_word *av2=av;
av2[0]=t14;
av2[1]=t13;
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}

/* chicken.process-context#get-environment-variable in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29931(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_29931,c,av);}
a=C_alloc(9);
t3=C_a_i_bytevector(&a,1,C_fix(3));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29940,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6085: ##sys#make-c-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[764]);
C_word *av2=av;
av2[0]=*((C_word*)lf[764]+1);
av2[1]=t4;
av2[2]=C_i_foreign_string_argumentp(t2);
tp(3,av2);}}

/* k29938 in chicken.process-context#get-environment-variable in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_29940,c,av);}
/* library.scm:6085: ##sys#peek-c-string */
t2=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=stub6915(((C_word*)t0)[3],t1);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.process-context#set-environment-variable! in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29946(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_29946,c,av);}
a=C_alloc(4);
t4=C_i_check_string_2(t2,lf[1227]);
t5=C_i_check_string_2(t3,lf[1227]);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29957,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6091: ##sys#make-c-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[764]);
C_word *av2=av;
av2[0]=*((C_word*)lf[764]+1);
av2[1]=t6;
av2[2]=t2;
av2[3]=lf[1227];
tp(4,av2);}}

/* k29955 in chicken.process-context#set-environment-variable! in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29957(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_29957,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29961,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:6092: ##sys#make-c-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[764]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[764]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[1227];
tp(4,av2);}}

/* k29959 in k29955 in chicken.process-context#set-environment-variable! in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_29961(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29961,c,av);}
t2=C_setenv(((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.process-context#unset-environment-variable! in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29963(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_29963,c,av);}
a=C_alloc(3);
t3=C_i_check_string_2(t2,lf[1229]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_29971,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6098: ##sys#make-c-string */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[764]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[764]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=lf[1229];
tp(4,av2);}}

/* k29969 in chicken.process-context#unset-environment-variable! in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_29971(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_29971,c,av);}
t2=C_unsetenv(t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.process-context#get-environment-variables in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_29983(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_29983,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_29989,a[2]=t3,a[3]=((C_word)li924),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_29989(t5,t1,C_fix(0));}

/* loop in chicken.process-context#get-environment-variables in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_fcall f_29989(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_29989,3,t0,t1,t2);}
a=C_alloc(10);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_29993,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t4=C_a_i_bytevector(&a,1,C_fix(3));
t5=C_i_foreign_fixnum_argumentp(t2);
/* library.scm:6102: ##sys#peek-c-string */
t6=*((C_word*)lf[721]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=stub6932(t4,t5);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k29991 in loop in chicken.process-context#get-environment-variables in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_29993(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_29993,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_30001,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t3,a[6]=((C_word)li923),tmp=(C_word)a,a+=7,tmp));
t5=((C_word*)t3)[1];
f_30001(t5,((C_word*)t0)[4],C_fix(0));}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* scan in k29991 in loop in chicken.process-context#get-environment-variables in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_fcall f_30001(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_30001,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_char_equalp(C_make_character(61),C_subchar(((C_word*)t0)[2],t2)))){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_30027,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* library.scm:6109: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
av2[3]=C_fix(0);
av2[4]=t2;
tp(5,av2);}}
else{
/* library.scm:6112: scan */
t5=t1;
t6=C_fixnum_plus(t2,C_fix(1));
t1=t5;
t2=t6;
goto loop;}}

/* k30017 in k30029 in k30025 in scan in k29991 in loop in chicken.process-context#get-environment-variables in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30019,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30025 in scan in k29991 in loop in chicken.process-context#get-environment-variables in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_30027,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30031,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:6110: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_fixnum_plus(((C_word*)t0)[6],C_fix(1));
av2[4]=C_block_size(((C_word*)t0)[5]);
tp(5,av2);}}

/* k30029 in k30025 in scan in k29991 in loop in chicken.process-context#get-environment-variables in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_30031,c,av);}
a=C_alloc(7);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30019,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6111: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_29989(t4,t3,C_fixnum_plus(((C_word*)t0)[5],C_fix(1)));}

/* chicken.process-context#executable-pathname in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_30049(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_30049,c,av);}
a=C_alloc(5);
t2=C_a_i_bytevector(&a,1,C_fix(3));
/* library.scm:6122: ##sys#peek-and-free-c-string */
t3=*((C_word*)lf[1162]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=stub6944(t2);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* chicken.process-context#argc+argv in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_30056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_30056,c,av);}
a=C_alloc(3);
/* library.scm:6125: ##sys#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fix((C_word)C_main_argc);
av2[3]=C_mpointer_or_false(&a,(void*)C_main_argv);
C_values(4,av2);}}

/* chicken.process-context#argv in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_30068(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_30068,c,av);}
a=C_alloc(10);
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30076,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_fixnum_difference(C_fix((C_word)C_main_argc),C_fix(1));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30082,a[2]=t5,a[3]=((C_word)li928),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_30082(t7,t2,t3,C_SCHEME_END_OF_LIST);}}

/* k30074 in chicken.process-context#argv in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_30076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30076,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* doloop6956 in chicken.process-context#argv in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_fcall f_30082(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_30082,4,t0,t1,t2,t3);}
a=C_alloc(11);
if(C_truep(C_fixnum_lessp(t2,C_fix(0)))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_fixnum_difference(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30104,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=C_a_i_bytevector(&a,1,C_fix(3));
/* library.scm:6129: ##sys#peek-c-string */
t7=*((C_word*)lf[721]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t5;
av2[2]=stub6952(t6,t2);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}

/* k30102 in doloop6956 in chicken.process-context#argv in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_30104(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_30104,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
t3=((C_word*)((C_word*)t0)[3])[1];
f_30082(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_30108(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_30108,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[1234]+1 /* (set! chicken.process-context#program-name ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30112,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32199,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6149: argv */
t5=C_fast_retrieve(lf[1233]);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_30112(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_30112,c,av);}
a=C_alloc(20);
t2=C_mutate((C_word*)lf[1235]+1 /* (set! chicken.process-context#command-line-arguments ...) */,t1);
t3=C_a_i_provide(&a,1,lf[1236]);
t4=C_mutate((C_word*)lf[1237]+1 /* (set! chicken.gc#current-gc-milliseconds ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30114,a[2]=((C_word)li930),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[1238]+1 /* (set! chicken.gc#set-gc-report! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30117,a[2]=((C_word)li931),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[1239]+1 /* (set! chicken.gc#memory-statistics ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30120,a[2]=((C_word)li932),tmp=(C_word)a,a+=3,tmp));
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30149,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t8=C_fixnum_times(C_fix(2),C_fix((C_word)C_max_pending_finalizers));
/* library.scm:6204: ##sys#make-vector */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[691]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[691]+1);
av2[1]=t7;
av2[2]=C_fixnum_plus(t8,C_fix(1));
av2[3]=C_SCHEME_UNDEFINED;
tp(4,av2);}}

/* chicken.gc#current-gc-milliseconds in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_30114(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30114,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_accumulated_gc_time();
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.gc#set-gc-report! in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_30117(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30117,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_set_gc_report(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.gc#memory-statistics in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_30120(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_30120,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30124,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6194: ##sys#gc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[320]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[320]+1);
av2[1]=t2;
av2[2]=C_SCHEME_TRUE;
tp(3,av2);}}

/* k30122 in chicken.gc#memory-statistics in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_30124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_30124,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30127,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:6195: ##sys#memory-info */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[327]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[327]+1);
av2[1]=t2;
tp(2,av2);}}

/* k30125 in k30122 in chicken.gc#memory-statistics in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30127(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,1)))){
C_save_and_reclaim((void *)f_30127,c,av);}
a=C_alloc(4);
t2=C_slot(t1,C_fix(0));
t3=C_fixnum_divide(t2,C_fix(2));
t4=C_fixnum_difference(t3,((C_word*)t0)[2]);
t5=C_slot(t1,C_fix(1));
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_vector3(&a,3,t3,t4,t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_30149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,4)))){
C_save_and_reclaim((void *)f_30149,c,av);}
a=C_alloc(26);
t2=C_mutate((C_word*)lf[982]+1 /* (set! ##sys#pending-finalizers ...) */,t1);
t3=C_i_set_i_slot(C_fast_retrieve(lf[982]),C_fix(0),C_fix(0));
t4=C_mutate((C_word*)lf[1240]+1 /* (set! ##sys#set-finalizer! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_register_finalizer,a[2]=((C_word)li933),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[1241]+1 /* (set! ##sys#init-finalizer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30155,a[2]=((C_word)li934),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[1247]+1 /* (set! chicken.gc#set-finalizer! ...) */,C_fast_retrieve(lf[1241]));
t7=C_a_i_vector1(&a,1,lf[1248]);
t8=C_mutate(&lf[1249] /* (set! chicken.gc#finalizer-tag ...) */,t7);
t9=C_mutate(&lf[1250] /* (set! chicken.gc#finalizer? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30225,a[2]=((C_word)li935),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[1251]+1 /* (set! chicken.gc#make-finalizer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30241,a[2]=((C_word)li941),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[1252]+1 /* (set! chicken.gc#add-to-finalizer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30319,a[2]=((C_word)li943),tmp=(C_word)a,a+=3,tmp));
t12=C_SCHEME_FALSE;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_mutate((C_word*)lf[983]+1 /* (set! ##sys#run-pending-finalizers ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30366,a[2]=t13,a[3]=((C_word)li952),tmp=(C_word)a,a+=4,tmp));
t15=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30533,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6312: chicken.base#make-parameter */
t16=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t16;
av2[1]=t15;
av2[2]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t16+1)))(3,av2);}}

/* ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_30155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_30155,c,av);}
a=C_alloc(11);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30159,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fixnum_greater_or_equal_p(C_i_live_finalizer_count(),C_fix((C_word)C_max_pending_finalizers)))){
t5=C_fixnum_times(C_fix(2),C_fix((C_word)C_max_pending_finalizers));
if(C_truep(C_resize_pending_finalizers(t5))){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30176,a[2]=t4,a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t7=C_fixnum_times(C_fix(2),C_fix((C_word)C_max_pending_finalizers));
/* library.scm:6216: ##sys#vector-resize */
f_18582(t6,C_fast_retrieve(lf[982]),C_fixnum_plus(t7,C_fix(1)),C_SCHEME_UNDEFINED);}
else{
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30206,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_debug_modep())){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30216,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6232: string-append */
t8=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=lf[1245];
av2[3]=C_i_live_finalizer_count();
av2[4]=lf[1246];
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
/* library.scm:6237: ##sys#force-finalizers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[979]);
C_word *av2=av;
av2[0]=*((C_word*)lf[979]+1);
av2[1]=t4;
tp(2,av2);}}}}
else{
/* library.scm:6238: ##sys#set-finalizer! */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1240]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1240]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
tp(4,av2);}}}

/* k30157 in ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30159(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_30159,c,av);}
/* library.scm:6238: ##sys#set-finalizer! */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1240]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[1240]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
tp(4,av2);}}

/* k30174 in ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30176(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_30176,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[982]+1 /* (set! ##sys#pending-finalizers ...) */,t1);
if(C_truep(C_i_debug_modep())){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30186,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30190,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6223: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t4;
av2[2]=C_i_live_finalizer_count();
tp(3,av2);}}
else{
/* library.scm:6238: ##sys#set-finalizer! */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1240]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[1240]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
tp(4,av2);}}}

/* k30184 in k30174 in ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30186(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_30186,c,av);}
/* library.scm:6220: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k30188 in k30174 in ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30190(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_30190,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30194,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6226: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=C_fix((C_word)C_max_pending_finalizers);
tp(3,av2);}}

/* k30192 in k30188 in k30174 in ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_30194,c,av);}
/* library.scm:6221: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1242];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1243];
av2[5]=t1;
av2[6]=lf[1244];
((C_proc)(void*)(*((C_word*)t2+1)))(7,av2);}}

/* k30204 in ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30206(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30206,c,av);}
/* library.scm:6237: ##sys#force-finalizers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[979]);
C_word *av2=av;
av2[0]=*((C_word*)lf[979]+1);
av2[1]=((C_word*)t0)[2];
tp(2,av2);}}

/* k30214 in ##sys#init-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30216(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_30216,c,av);}
/* library.scm:6231: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* chicken.gc#finalizer? in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_30225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30225,c,av);}
t3=C_i_pairp(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_eqp(C_retrieve2(lf[1249],C_text("chicken.gc#finalizer-tag")),C_slot(t2,C_fix(0))):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_30241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_30241,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30245,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6248: ##sys#make-event-queue */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1197]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1197]+1);
av2[1]=t3;
tp(2,av2);}}

/* k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_30245,c,av);}
a=C_alloc(24);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30247,a[2]=t1,a[3]=((C_word)li936),tmp=(C_word)a,a+=4,tmp));
t7=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30253,a[2]=t3,a[3]=((C_word)li937),tmp=(C_word)a,a+=4,tmp));
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30260,a[2]=t1,a[3]=t5,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30296,a[2]=t10,a[3]=t5,a[4]=((C_word)li940),tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_30296(t12,t8,((C_word*)t0)[3]);}

/* handler in k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_30247,c,av);}
/* library.scm:6249: ##sys#add-event-to-queue! */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1199]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[1199]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
tp(4,av2);}}

/* handle in k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30253(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_30253,c,av);}
/* library.scm:6250: ##sys#init-finalizer */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1241]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[1241]+1);
av2[1]=t1;
av2[2]=t2;
av2[3]=((C_word*)((C_word*)t0)[2])[1];
tp(4,av2);}}

/* k30258 in k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30260(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_30260,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30265,a[2]=((C_word*)t0)[2],a[3]=((C_word)li938),tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30286,a[2]=((C_word*)t0)[3],a[3]=((C_word)li939),tmp=(C_word)a,a+=4,tmp);
/* library.scm:6252: ##sys#decorate-lambda */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[768]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[768]+1);
av2[1]=((C_word*)t0)[4];
av2[2]=t2;
av2[3]=C_retrieve2(lf[1250],C_text("chicken.gc#finalizer\077"));
av2[4]=t3;
tp(5,av2);}}

/* a30264 in k30258 in k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_30265,c,av);}
if(C_truep(C_rest_nullp(c,2))){
/* library.scm:6256: ##sys#get-next-event */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1200]);
C_word av2[3];
av2[0]=*((C_word*)lf[1200]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}
else{
if(C_truep(C_get_rest_arg(c,2,av,2,t0))){
/* library.scm:6255: ##sys#wait-for-next-event */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1201]);
C_word av2[3];
av2[0]=*((C_word*)lf[1201]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}
else{
/* library.scm:6256: ##sys#get-next-event */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1200]);
C_word av2[3];
av2[0]=*((C_word*)lf[1200]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
tp(3,av2);}}}}

/* a30285 in k30258 in k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_30286,c,av);}
a=C_alloc(3);
t4=C_a_i_cons(&a,2,C_retrieve2(lf[1249],C_text("chicken.gc#finalizer-tag")),((C_word*)((C_word*)t0)[2])[1]);
t5=C_i_setslot(t2,t3,t4);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* for-each-loop7035 in k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_fcall f_30296(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_30296,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30306,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6251: g7036 */
t4=((C_word*)((C_word*)t0)[3])[1];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_30253(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k30304 in for-each-loop7035 in k30243 in chicken.gc#make-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30306(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_30306,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_30296(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.gc#add-to-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_30319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_30319,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+5);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30323,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_closurep(t2))){
/* library.scm:6264: ##sys#lambda-decoration */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[769]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[769]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=C_retrieve2(lf[1250],C_text("chicken.gc#finalizer\077"));
tp(4,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_30323(2,av2);}}}

/* k30321 in chicken.gc#add-to-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_30323,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30326,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(t1)){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_30326(2,av2);}}
else{
/* library.scm:6266: chicken.base#error */
t3=*((C_word*)lf[193]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1253];
av2[3]=lf[1254];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k30324 in k30321 in chicken.gc#add-to-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30326(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_30326,c,av);}
a=C_alloc(7);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30334,a[2]=t4,a[3]=t2,a[4]=((C_word)li942),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_30334(t6,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* for-each-loop7077 in k30324 in k30321 in chicken.gc#add-to-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_fcall f_30334(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_30334,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30344,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6268: g7078 */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k30342 in for-each-loop7077 in k30324 in k30321 in chicken.gc#add-to-finalizer in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_30344(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_30344,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_30334(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_30366(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_30366,c,av);}
a=C_alloc(15);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30370,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[2])[1]))){
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_fast_retrieve(lf[964]));
t5=C_slot(C_fast_retrieve(lf[982]),C_fix(0));
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30401,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_debug_modep())){
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30500,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30504,a[2]=t7,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6281: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t8;
av2[2]=t5;
tp(3,av2);}}
else{
t7=t6;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_30401(2,av2);}}}
else{
if(C_truep(t2)){
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
f_30370(2,av2);}}
else{
t4=C_eqp(((C_word*)((C_word*)t0)[2])[1],C_fast_retrieve(lf[964]));
if(C_truep(t4)){
/* library.scm:6302: ##sys#signal-hook */
t5=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[195];
av2[3]=lf[983];
av2[4]=lf[1260];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
/* library.scm:6307: ##sys#thread-yield! */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1192]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1192]+1);
av2[1]=t3;
tp(2,av2);}}}}}

/* k30368 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30370(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_30370,c,av);}
t2=C_i_not(((C_word*)t0)[2]);
if(C_truep(t2)){
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_closurep(((C_word*)t0)[2]))){
/* library.scm:6309: state */
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(((C_word*)t0)[2])){
/* library.scm:6310: ##sys#context-switch */{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[2];
C_context_switch(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}}

/* k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_30401,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30404,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30413,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=((C_word)li951),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_30413(t6,t2,C_fix(0));}

/* k30402 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30404(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_30404,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30407,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:6297: vector-fill! */
t3=*((C_word*)lf[97]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_fast_retrieve(lf[982]);
av2[3]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k30405 in k30402 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30407(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30407,c,av);}
t2=C_i_set_i_slot(C_fast_retrieve(lf[982]),C_fix(0),C_fix(0));
t3=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
f_30370(2,av2);}}

/* doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_fcall f_30413(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_30413,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_fixnum_greater_or_equal_p(t2,((C_word*)t0)[2]))){
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_fixnum_times(t2,C_fix(2));
t4=C_fixnum_plus(C_fix(1),t3);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30426,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30438,a[2]=t4,a[3]=((C_word)li950),tmp=(C_word)a,a+=4,tmp);
/* library.scm:6293: scheme#call-with-current-continuation */
t7=*((C_word*)lf[132]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t5;
av2[2]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k30424 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_30426,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30429,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:6292: g7116 */
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)C_fast_retrieve_proc(t3))(2,av2);}}

/* k30427 in k30424 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_30429(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_30429,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_30413(t2,((C_word*)t0)[3],C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* a30437 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30438(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_30438,c,av);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30444,a[2]=t2,a[3]=((C_word)li945),tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30456,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word)li949),tmp=(C_word)a,a+=5,tmp);
/* library.scm:6293: chicken.condition#with-exception-handler */
t5=C_fast_retrieve(lf[937]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t3;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* a30443 in a30437 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_30444(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_30444,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30450,a[2]=t2,a[3]=((C_word)li944),tmp=(C_word)a,a+=4,tmp);
/* library.scm:6293: k7113 */
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}

/* a30449 in a30443 in a30437 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_30450(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_30450,c,av);}
/* library.scm:6294: ##sys#show-exception-warning */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1076]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[1076]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[1255];
av2[4]=C_SCHEME_FALSE;
tp(5,av2);}}

/* a30455 in a30437 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_30456(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_30456,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30462,a[2]=((C_word*)t0)[2],a[3]=((C_word)li946),tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30479,a[2]=((C_word*)t0)[3],a[3]=((C_word)li948),tmp=(C_word)a,a+=4,tmp);
/* library.scm:6293: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a30461 in a30455 in a30437 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_30462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_30462,c,av);}
t2=C_fixnum_plus(((C_word*)t0)[2],C_fix(1));
/* library.scm:6293: g7120 */
t3=C_slot(C_fast_retrieve(lf[982]),t2);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=C_slot(C_fast_retrieve(lf[982]),((C_word*)t0)[2]);
((C_proc)C_fast_retrieve_proc(t3))(3,av2);}}

/* a30478 in a30455 in a30437 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_30479(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_30479,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30485,a[2]=t2,a[3]=((C_word)li947),tmp=(C_word)a,a+=4,tmp);
/* library.scm:6293: k7113 */
t4=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)C_fast_retrieve_proc(t4))(3,av2);}}

/* a30484 in a30478 in a30455 in a30437 in doloop7109 in k30399 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_30485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_30485,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
C_apply_values(3,av2);}}

/* k30498 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_30500,c,av);}
/* library.scm:6280: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k30502 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_30504,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30508,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6283: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=C_i_live_finalizer_count();
tp(3,av2);}}

/* k30506 in k30502 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_30508,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30512,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6286: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=C_i_allocated_finalizer_count();
tp(3,av2);}}

/* k30510 in k30506 in k30502 in ##sys#run-pending-finalizers in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_30512,c,av);}
/* library.scm:6281: string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1256];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1257];
av2[5]=((C_word*)t0)[4];
av2[6]=lf[1258];
av2[7]=t1;
av2[8]=lf[1259];
((C_proc)(void*)(*((C_word*)t2+1)))(9,av2);}}

/* k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_30533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,6)))){
C_save_and_reclaim((void *)f_30533,c,av);}
a=C_alloc(26);
t2=C_mutate((C_word*)lf[980]+1 /* (set! chicken.gc#force-finalizers ...) */,t1);
t3=C_mutate((C_word*)lf[979]+1 /* (set! ##sys#force-finalizers ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30535,a[2]=((C_word)li954),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[1261]+1 /* (set! chicken.gc#gc ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30563,a[2]=((C_word)li955),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[834]+1 /* (set! ##sys#list->vector ...) */,*((C_word*)lf[94]+1));
t6=C_mutate((C_word*)lf[376]+1 /* (set! ##sys#list ...) */,*((C_word*)lf[42]+1));
t7=C_mutate((C_word*)lf[1262]+1 /* (set! ##sys#length ...) */,*((C_word*)lf[43]+1));
t8=C_mutate((C_word*)lf[1263]+1 /* (set! ##sys#cons ...) */,*((C_word*)lf[8]+1));
t9=C_mutate((C_word*)lf[259]+1 /* (set! ##sys#append ...) */,*((C_word*)lf[382]+1));
t10=C_mutate((C_word*)lf[1264]+1 /* (set! ##sys#vector ...) */,*((C_word*)lf[96]+1));
t11=C_mutate((C_word*)lf[1265]+1 /* (set! ##sys#apply ...) */,*((C_word*)lf[129]+1));
t12=C_mutate((C_word*)lf[1266]+1 /* (set! ##sys#values ...) */,*((C_word*)lf[130]+1));
t13=C_mutate((C_word*)lf[1267]+1 /* (set! ##sys#equal? ...) */,*((C_word*)lf[6]+1));
t14=C_mutate((C_word*)lf[1268]+1 /* (set! ##sys#car ...) */,*((C_word*)lf[9]+1));
t15=C_mutate((C_word*)lf[1269]+1 /* (set! ##sys#cdr ...) */,*((C_word*)lf[10]+1));
t16=C_mutate((C_word*)lf[1270]+1 /* (set! ##sys#pair? ...) */,*((C_word*)lf[7]+1));
t17=C_mutate((C_word*)lf[1271]+1 /* (set! ##sys#vector? ...) */,*((C_word*)lf[89]+1));
t18=C_mutate((C_word*)lf[1272]+1 /* (set! ##sys#vector->list ...) */,*((C_word*)lf[95]+1));
t19=C_mutate((C_word*)lf[1273]+1 /* (set! ##sys#vector-length ...) */,*((C_word*)lf[90]+1));
t20=C_mutate((C_word*)lf[1274]+1 /* (set! ##sys#vector-ref ...) */,*((C_word*)lf[91]+1));
t21=C_mutate((C_word*)lf[1275]+1 /* (set! ##sys#>= ...) */,*((C_word*)lf[75]+1));
t22=C_mutate((C_word*)lf[1276]+1 /* (set! ##sys#= ...) */,*((C_word*)lf[72]+1));
t23=C_mutate((C_word*)lf[1277]+1 /* (set! ##sys#+ ...) */,*((C_word*)lf[64]+1));
t24=C_mutate((C_word*)lf[1278]+1 /* (set! ##sys#eq? ...) */,*((C_word*)lf[4]+1));
t25=C_mutate((C_word*)lf[1279]+1 /* (set! ##sys#eqv? ...) */,*((C_word*)lf[5]+1));
t26=C_mutate((C_word*)lf[1280]+1 /* (set! ##sys#list? ...) */,*((C_word*)lf[55]+1));
t27=C_mutate((C_word*)lf[1281]+1 /* (set! ##sys#null? ...) */,*((C_word*)lf[41]+1));
t28=C_mutate((C_word*)lf[1282]+1 /* (set! ##sys#map-n ...) */,*((C_word*)lf[171]+1));
t29=C_mutate((C_word*)lf[1283]+1 /* (set! ##sys#make-locative ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30606,a[2]=((C_word)li956),tmp=(C_word)a,a+=3,tmp));
t30=C_a_i_provide(&a,1,lf[1296]);
t31=C_mutate((C_word*)lf[1297]+1 /* (set! chicken.plist#put! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30870,a[2]=((C_word)li957),tmp=(C_word)a,a+=3,tmp));
t32=C_mutate((C_word*)lf[1299]+1 /* (set! chicken.plist#get ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30876,a[2]=((C_word)li958),tmp=(C_word)a,a+=3,tmp));
t33=C_mutate((C_word*)lf[1301]+1 /* (set! ##sys#put! ...) */,C_fast_retrieve(lf[1297]));
t34=C_mutate((C_word*)lf[1302]+1 /* (set! ##sys#get ...) */,C_fast_retrieve(lf[1299]));
t35=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30895,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6446: chicken.base#getter-with-setter */
t36=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t36;
av2[1]=t35;
av2[2]=C_fast_retrieve(lf[1299]);
av2[3]=C_fast_retrieve(lf[1297]);
((C_proc)(void*)(*((C_word*)t36+1)))(4,av2);}}

/* ##sys#force-finalizers in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_30535,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30541,a[2]=t3,a[3]=((C_word)li953),tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_30541(t5,t1);}

/* loop in ##sys#force-finalizers in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_fcall f_30541(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_30541,2,t0,t1);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30545,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6316: ##sys#gc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[320]+1));
C_word av2[2];
av2[0]=*((C_word*)lf[320]+1);
av2[1]=t2;
tp(2,av2);}}

/* k30543 in loop in ##sys#force-finalizers in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_30545,c,av);}
a=C_alloc(4);
t2=C_slot(C_fast_retrieve(lf[982]),C_fix(0));
if(C_truep(C_fixnum_greaterp(t2,C_fix(0)))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_30554,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:6318: ##sys#run-pending-finalizers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[983]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[983]+1);
av2[1]=t3;
av2[2]=C_SCHEME_FALSE;
tp(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k30552 in k30543 in loop in ##sys#force-finalizers in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_30554(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30554,c,av);}
/* library.scm:6319: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_30541(t2,((C_word*)t0)[3]);}

/* chicken.gc#gc in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30563(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,2)))){
C_save_and_reclaim((void*)f_30563,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
if(C_truep(C_i_pairp(t2))){
t3=C_get_rest_arg(c,2,av,2,t0);
if(C_truep(t3)){
/* library.scm:6325: ##sys#force-finalizers */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[979]);
C_word *av2=av;
av2[0]=*((C_word*)lf[979]+1);
av2[1]=t1;
tp(2,av2);}}
else{
/* library.scm:6326: ##sys#gc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[320]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[320]+1);
av2[1]=t1;
av2[2]=t3;
tp(3,av2);}}}
else{
/* library.scm:6326: ##sys#gc */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[320]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[320]+1);
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
tp(3,av2);}}}

/* ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_30606,c,av);}
a=C_alloc(6);
if(C_truep(C_immp(t2))){
/* library.scm:6359: ##sys#signal-hook */
t6=C_fast_retrieve(lf[194]);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=t5;
av2[4]=lf[1284];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(6,av2);}}
else{
t6=C_i_vectorp(t2);
t7=(C_truep(t6)?t6:C_i_pairp(t2));
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30628,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6361: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t8;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t2);
av2[5]=t5;
tp(6,av2);}}
else{
t8=(C_truep(C_blockp(t2))?C_bytevectorp(t2):C_SCHEME_FALSE);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30641,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6368: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t9;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t2);
av2[5]=t5;
tp(6,av2);}}
else{
if(C_truep(C_structurep(t2))){
t9=C_slot(t2,C_fix(0));
t10=C_eqp(t9,lf[1285]);
if(C_truep(t10)){
t11=C_slot(t2,C_fix(1));
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30666,a[2]=t11,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6374: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t12;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t11);
av2[5]=t5;
tp(6,av2);}}
else{
t11=C_eqp(t9,lf[1286]);
if(C_truep(t11)){
t12=C_slot(t2,C_fix(1));
t13=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30682,a[2]=t1,a[3]=t12,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6378: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t13;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t12);
av2[5]=t5;
tp(6,av2);}}
else{
t12=C_eqp(t9,lf[1287]);
if(C_truep(t12)){
t13=C_slot(t2,C_fix(1));
t14=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30698,a[2]=t13,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6382: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t14;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t13);
av2[5]=t5;
tp(6,av2);}}
else{
t13=C_eqp(t9,lf[1288]);
if(C_truep(t13)){
t14=C_slot(t2,C_fix(1));
t15=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30714,a[2]=t1,a[3]=t14,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6386: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t15;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t14);
av2[5]=t5;
tp(6,av2);}}
else{
t14=C_eqp(t9,lf[1289]);
if(C_truep(t14)){
t15=C_slot(t2,C_fix(1));
t16=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30730,a[2]=t15,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6390: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t16;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t15);
av2[5]=t5;
tp(6,av2);}}
else{
t15=C_eqp(t9,lf[1290]);
if(C_truep(t15)){
t16=C_slot(t2,C_fix(1));
t17=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30746,a[2]=t1,a[3]=t16,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6394: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t17;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t16);
av2[5]=t5;
tp(6,av2);}}
else{
t16=C_eqp(t9,lf[1291]);
if(C_truep(t16)){
t17=C_slot(t2,C_fix(1));
t18=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30762,a[2]=t17,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6398: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t18;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t17);
av2[5]=t5;
tp(6,av2);}}
else{
t17=C_eqp(t9,lf[1292]);
if(C_truep(t17)){
t18=C_slot(t2,C_fix(1));
t19=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30778,a[2]=t1,a[3]=t18,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6402: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t19;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t18);
av2[5]=t5;
tp(6,av2);}}
else{
t18=C_eqp(t9,lf[1293]);
if(C_truep(t18)){
t19=C_slot(t2,C_fix(1));
t20=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30794,a[2]=t19,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6406: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t20;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t19);
av2[5]=t5;
tp(6,av2);}}
else{
t19=C_eqp(t9,lf[1294]);
if(C_truep(t19)){
t20=C_slot(t2,C_fix(1));
t21=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30810,a[2]=t1,a[3]=t20,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6410: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t21;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t20);
av2[5]=t5;
tp(6,av2);}}
else{
t20=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30817,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t21=C_block_size(t2);
/* library.scm:6414: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t20;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_fixnum_difference(t21,C_fix(1));
av2[5]=t5;
tp(6,av2);}}}}}}}}}}}}
else{
if(C_truep(C_i_stringp(t2))){
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_30858,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6417: ##sys#check-range */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[341]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[341]+1);
av2[1]=t9;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_block_size(t2);
av2[5]=t5;
tp(6,av2);}}
else{
/* library.scm:6420: ##sys#signal-hook */
t9=C_fast_retrieve(lf[194]);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t1;
av2[2]=lf[263];
av2[3]=t5;
av2[4]=lf[1295];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(6,av2);}}}}}}}

/* k30626 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30628,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_make_locative(&a,4,C_fix(0),((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30639 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30641(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30641,c,av);}
a=C_alloc(5);
t2=C_a_i_make_locative(&a,4,C_fix(2),((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k30664 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30666(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30666,c,av);}
a=C_alloc(5);
t2=C_a_i_make_locative(&a,4,C_fix(2),((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k30680 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30682,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_make_locative(&a,4,C_fix(3),((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30696 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30698,c,av);}
a=C_alloc(5);
t2=C_a_i_make_locative(&a,4,C_fix(4),((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k30712 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30714(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30714,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_make_locative(&a,4,C_fix(5),((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30728 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30730(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30730,c,av);}
a=C_alloc(5);
t2=C_a_i_make_locative(&a,4,C_fix(6),((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k30744 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30746(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30746,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_make_locative(&a,4,C_fix(7),((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30760 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30762,c,av);}
a=C_alloc(5);
t2=C_a_i_make_locative(&a,4,C_fix(8),((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k30776 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30778,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_make_locative(&a,4,C_fix(9),((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30792 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30794,c,av);}
a=C_alloc(5);
t2=C_a_i_make_locative(&a,4,C_fix(10),((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k30808 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30810(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30810,c,av);}
a=C_alloc(5);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_make_locative(&a,4,C_fix(11),((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k30815 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30817(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30817,c,av);}
a=C_alloc(5);
t2=C_fixnum_plus(((C_word*)t0)[2],C_fix(1));
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_make_locative(&a,4,C_fix(0),((C_word*)t0)[4],t2,((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k30856 in ##sys#make-locative in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_30858,c,av);}
a=C_alloc(5);
t2=C_a_i_make_locative(&a,4,C_fix(1),((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.plist#put! in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30870(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,1)))){
C_save_and_reclaim((void *)f_30870,c,av);}
a=C_alloc(8);
t5=C_i_check_symbol_2(t2,lf[1298]);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_putprop(&a,3,t2,t3,t4);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* chicken.plist#get in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30876(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c<4) C_bad_min_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_30876,c,av);}
t4=C_rest_nullp(c,4);
t5=(C_truep(t4)?C_SCHEME_FALSE:C_get_rest_arg(c,4,av,4,t0));
t6=C_i_check_symbol_2(t2,lf[1300]);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_i_getprop(t2,t3,t5);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in ... */
static void C_ccall f_30895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_30895,c,av);}
a=C_alloc(12);
t2=C_mutate((C_word*)lf[1299]+1 /* (set! chicken.plist#get ...) */,t1);
t3=C_mutate((C_word*)lf[1303]+1 /* (set! chicken.plist#remprop! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30897,a[2]=((C_word)li960),tmp=(C_word)a,a+=3,tmp));
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30966,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32155,a[2]=((C_word)li1002),tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32164,a[2]=((C_word)li1003),tmp=(C_word)a,a+=3,tmp);
/* library.scm:6466: chicken.base#getter-with-setter */
t7=*((C_word*)lf[200]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t4;
av2[2]=t5;
av2[3]=t6;
av2[4]=lf[1406];
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}

/* chicken.plist#remprop! in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30897(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_30897,c,av);}
a=C_alloc(5);
t4=C_i_check_symbol_2(t2,lf[1304]);
t5=C_slot(t2,C_fix(2));
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30920,a[2]=t3,a[3]=t2,a[4]=((C_word)li959),tmp=(C_word)a,a+=5,tmp);
t7=(
  f_30920(t6,t5,C_SCHEME_FALSE)
);
t8=C_slot(t2,C_fix(2));
if(C_truep(C_i_nullp(t8))){
t9=t1;{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_i_unpersist_symbol(t2);
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t9=C_SCHEME_UNDEFINED;
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}

/* loop in chicken.plist#remprop! in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static C_word C_fcall f_30920(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_stack_overflow_check;
loop:{}
t3=C_i_nullp(t1);
if(C_truep(C_i_not(t3))){
t4=C_slot(t1,C_fix(1));
t5=C_slot(t4,C_fix(1));
t6=C_slot(t1,C_fix(0));
t7=C_eqp(t6,((C_word*)t0)[2]);
if(C_truep(t7)){
t8=(C_truep(t2)?C_i_setslot(t2,C_fix(1),t5):C_i_setslot(((C_word*)t0)[3],C_fix(2),t5));
return(C_SCHEME_TRUE);}
else{
t10=t5;
t11=t4;
t1=t10;
t2=t11;
goto loop;}}
else{
return(C_SCHEME_FALSE);}}

/* k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_30966(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_30966,c,av);}
a=C_alloc(29);
t2=C_mutate((C_word*)lf[1305]+1 /* (set! chicken.plist#symbol-plist ...) */,t1);
t3=C_mutate((C_word*)lf[1306]+1 /* (set! chicken.plist#get-properties ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_30968,a[2]=((C_word)li962),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[1308]+1 /* (set! ##sys#display-times ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31031,a[2]=((C_word)li966),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[984]+1 /* (set! ##sys#dump-heap-state ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_dump_heap_state,a[2]=((C_word)li967),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[1324]+1 /* (set! ##sys#filter-heap-objects ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_filter_heap_objects,a[2]=((C_word)li968),tmp=(C_word)a,a+=3,tmp));
t7=C_a_i_provide(&a,1,lf[1325]);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31267,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_software_type,a[2]=((C_word)li1001),tmp=(C_word)a,a+=3,tmp);
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32153,a[2]=t8,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6574: g7387 */
t11=t9;{
C_word *av2=av;
av2[0]=t11;
av2[1]=t10;
((C_proc)C_fast_retrieve_proc(t11))(2,av2);}}

/* chicken.plist#get-properties in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_30968(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_30968,c,av);}
a=C_alloc(10);
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_i_check_symbol_2(t2,lf[1307]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30975,a[2]=t4,a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_symbolp(((C_word*)t4)[1]))){
t7=C_a_i_list1(&a,1,((C_word*)t4)[1]);
t8=C_set_block_item(t4,0,t7);
t9=t6;
f_30975(t9,t8);}
else{
t7=t6;
f_30975(t7,C_SCHEME_UNDEFINED);}}

/* k30973 in chicken.plist#get-properties in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_fcall f_30975(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_30975,2,t0,t1);}
a=C_alloc(7);
t2=C_i_check_list_2(((C_word*)((C_word*)t0)[2])[1],lf[1307]);
t3=C_slot(((C_word*)t0)[3],C_fix(2));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_30987,a[2]=((C_word*)t0)[2],a[3]=t5,a[4]=((C_word)li961),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_30987(t7,((C_word*)t0)[4],t3);}

/* loop in k30973 in chicken.plist#get-properties in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_fcall f_30987(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_30987,3,t0,t1,t2);}
if(C_truep(C_i_nullp(t2))){
/* library.scm:6490: scheme#values */{
C_word av2[5];
av2[0]=0;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_FALSE;
C_values(5,av2);}}
else{
t3=C_slot(t2,C_fix(0));
t4=C_slot(t2,C_fix(1));
t5=C_slot(t4,C_fix(1));
if(C_truep(C_i_memq(t3,((C_word*)((C_word*)t0)[2])[1]))){
/* library.scm:6495: scheme#values */{
C_word av2[5];
av2[0]=0;
av2[1]=t1;
av2[2]=t3;
av2[3]=C_slot(t4,C_fix(0));
av2[4]=t5;
C_values(5,av2);}}
else{
/* library.scm:6496: loop */
t7=t1;
t8=t5;
t1=t7;
t2=t8;
goto loop;}}}

/* ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_31031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(23,c,4)))){
C_save_and_reclaim((void *)f_31031,c,av);}
a=C_alloc(23);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31046,a[2]=((C_word)li963),tmp=(C_word)a,a+=3,tmp));
t10=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31060,a[2]=((C_word)li964),tmp=(C_word)a,a+=3,tmp));
t11=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31082,a[2]=t4,a[3]=t6,a[4]=((C_word)li965),tmp=(C_word)a,a+=5,tmp));
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31158,a[2]=t2,a[3]=t1,a[4]=t8,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6518: ##sys#flush-output */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[765]);
C_word *av2=av;
av2[0]=*((C_word*)lf[765]+1);
av2[1]=t12;
av2[2]=*((C_word*)lf[733]+1);
tp(3,av2);}}

/* pnum in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_fcall f_31046(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_31046,2,t1,t2);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31054,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_zerop(t2))){
/* library.scm:6507: ##sys#print */
t4=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[1309];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
/* library.scm:6507: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t3;
av2[2]=t2;
tp(3,av2);}}}

/* k31052 in pnum in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31054(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31054,c,av);}
/* library.scm:6507: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* round-to in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_fcall f_31060(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_31060,3,t1,t2,t3);}
a=C_alloc(8);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31068,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31080,a[2]=t2,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6509: scheme#expt */
t6=*((C_word*)lf[552]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_fix(10);
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k31066 in round-to in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31068(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_31068,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31072,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6509: scheme#expt */
t3=*((C_word*)lf[552]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1310];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k31070 in k31066 in round-to in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_31072(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31072,c,av);}
/* ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[548]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k31078 in round-to in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_31080,c,av);}
a=C_alloc(33);
t2=C_s_a_i_times(&a,2,((C_word*)t0)[2],t1);
/* library.scm:6509: scheme#round */
t3=*((C_word*)lf[572]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_fcall f_31082(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_31082,3,t0,t1,t2);}
a=C_alloc(11);
if(C_truep(C_i_greaterp(t2,lf[1311]))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31092,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31099,a[2]=((C_word*)t0)[2],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31103,a[2]=((C_word*)t0)[3],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=t2;
av2[3]=lf[1311];
tp(4,av2);}}
else{
if(C_truep(C_i_greaterp(t2,C_fix(1048576)))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31114,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31121,a[2]=((C_word*)t0)[2],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31125,a[2]=((C_word*)t0)[3],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=t2;
av2[3]=C_fix(1048576);
tp(4,av2);}}
else{
if(C_truep(C_i_greaterp(t2,C_fix(1024)))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31136,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31143,a[2]=((C_word*)t0)[2],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31147,a[2]=((C_word*)t0)[3],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* ##sys#/-2 */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[548]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[548]+1);
av2[1]=t5;
av2[2]=t2;
av2[3]=C_fix(1024);
tp(4,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31152,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6517: pnum */
f_31046(t3,t2);}}}}

/* k31090 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31092(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31092,c,av);}
/* library.scm:6504: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1312];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k31097 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31099,c,av);}
/* library.scm:6512: pnum */
f_31046(((C_word*)t0)[3],t1);}

/* k31101 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31103(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31103,c,av);}
/* library.scm:6512: round-to */
f_31060(((C_word*)t0)[3],t1,C_fix(2));}

/* k31112 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31114(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31114,c,av);}
/* library.scm:6504: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1313];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k31119 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31121(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31121,c,av);}
/* library.scm:6514: pnum */
f_31046(((C_word*)t0)[3],t1);}

/* k31123 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31125,c,av);}
/* library.scm:6514: round-to */
f_31060(((C_word*)t0)[3],t1,C_fix(2));}

/* k31134 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31136(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31136,c,av);}
/* library.scm:6504: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1314];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k31141 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31143(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31143,c,av);}
/* library.scm:6516: pnum */
f_31046(((C_word*)t0)[3],t1);}

/* k31145 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31147(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31147,c,av);}
/* library.scm:6516: round-to */
f_31060(((C_word*)t0)[3],t1,C_fix(2));}

/* k31150 in pmem in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31152,c,av);}
/* library.scm:6504: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1315];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_31158(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_31158,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31161,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:6519: pnum */
f_31046(t2,C_slot(((C_word*)t0)[2],C_fix(0)));}

/* k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_31161,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31164,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* library.scm:6504: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1323];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_31164(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_31164,c,av);}
a=C_alloc(11);
t2=C_slot(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31170,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_greaterp(t2,C_fix(0)))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31251,a[2]=t3,a[3]=((C_word*)t0)[5],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6504: ##sys#print */
t5=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[1322];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_31170(2,av2);}}}

/* k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_31170(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_31170,c,av);}
a=C_alloc(12);
t2=C_slot(((C_word*)t0)[2],C_fix(2));
t3=C_slot(((C_word*)t0)[2],C_fix(3));
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31179,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fixnum_greaterp(t2,C_fix(0)))){
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31233,a[2]=t4,a[3]=((C_word*)t0)[5],a[4]=t3,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6504: ##sys#print */
t6=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[1320];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_31179(2,av2);}}}

/* k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_ccall f_31179(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_31179,c,av);}
a=C_alloc(11);
t2=C_slot(((C_word*)t0)[2],C_fix(4));
t3=C_slot(((C_word*)t0)[2],C_fix(5));
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31188,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=C_fixnum_greaterp(t2,C_fix(0));
t6=(C_truep(t5)?t5:C_fixnum_greaterp(t3,C_fix(0)));
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31212,a[2]=t4,a[3]=((C_word*)t0)[5],a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6504: ##sys#print */
t8=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=lf[1318];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}
else{
t7=t4;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_31188(2,av2);}}}

/* k31186 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_31188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_31188,c,av);}
a=C_alloc(5);
t2=C_slot(((C_word*)t0)[2],C_fix(6));
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31194,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6504: ##sys#print */
t4=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1316];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k31192 in k31186 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_31194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31194,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31197,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6544: pmem */
t3=((C_word*)((C_word*)t0)[3])[1];
f_31082(t3,t2,((C_word*)t0)[4]);}

/* k31195 in k31192 in k31186 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_31197,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31200,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6545: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=*((C_word*)lf[734]+1);
tp(4,av2);}}

/* k31198 in k31195 in k31192 in k31186 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_31200(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31200,c,av);}
/* library.scm:6546: ##sys#flush-output */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[765]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[765]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[734]+1);
tp(3,av2);}}

/* k31210 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_31212(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_31212,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31215,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:6538: pnum */
f_31046(t2,((C_word*)t0)[5]);}

/* k31213 in k31210 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_31215(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_31215,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31218,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:6505: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t2;
av2[2]=C_make_character(47);
av2[3]=*((C_word*)lf[734]+1);
tp(4,av2);}}

/* k31216 in k31213 in k31210 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31218(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31218,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31221,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6540: pnum */
f_31046(t2,((C_word*)t0)[4]);}

/* k31219 in k31216 in k31213 in k31210 in k31177 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_31221(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31221,c,av);}
/* library.scm:6504: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1317];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k31231 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_ccall f_31233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_31233,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31236,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:6530: pnum */
f_31046(t2,((C_word*)t0)[5]);}

/* k31234 in k31231 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_31236(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_31236,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31239,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:6505: ##sys#write-char-0 */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[883]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[883]+1);
av2[1]=t2;
av2[2]=C_make_character(47);
av2[3]=*((C_word*)lf[734]+1);
tp(4,av2);}}

/* k31237 in k31234 in k31231 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_31239(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31239,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31242,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6532: pnum */
f_31046(t2,((C_word*)t0)[4]);}

/* k31240 in k31237 in k31234 in k31231 in k31168 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31242,c,av);}
/* library.scm:6504: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1319];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k31249 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_31251(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31251,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31254,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6524: pnum */
f_31046(t2,((C_word*)t0)[4]);}

/* k31252 in k31249 in k31162 in k31159 in k31156 in ##sys#display-times in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_ccall f_31254(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31254,c,av);}
/* library.scm:6504: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1321];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_31267(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_31267,c,av);}
a=C_alloc(13);
t2=C_mutate((C_word*)lf[1326]+1 /* (set! chicken.platform#software-type ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31268,a[2]=t1,a[3]=((C_word)li969),tmp=(C_word)a,a+=4,tmp));
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31273,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_machine_type,a[2]=((C_word)li1000),tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32149,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6578: g7391 */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)C_fast_retrieve_proc(t6))(2,av2);}}

/* chicken.platform#software-type in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_31268(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31268,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_31273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_31273,c,av);}
a=C_alloc(13);
t2=C_mutate((C_word*)lf[1327]+1 /* (set! chicken.platform#machine-type ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31274,a[2]=t1,a[3]=((C_word)li970),tmp=(C_word)a,a+=4,tmp));
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31279,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_machine_byte_order,a[2]=((C_word)li999),tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32145,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6582: g7395 */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)C_fast_retrieve_proc(t6))(2,av2);}}

/* chicken.platform#machine-type in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31274,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_31279(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_31279,c,av);}
a=C_alloc(13);
t2=C_mutate((C_word*)lf[1328]+1 /* (set! chicken.platform#machine-byte-order ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31280,a[2]=t1,a[3]=((C_word)li971),tmp=(C_word)a,a+=4,tmp));
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31285,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_software_version,a[2]=((C_word)li998),tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32141,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6586: g7399 */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)C_fast_retrieve_proc(t6))(2,av2);}}

/* chicken.platform#machine-byte-order in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_31280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31280,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_31285(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_31285,c,av);}
a=C_alloc(13);
t2=C_mutate((C_word*)lf[1329]+1 /* (set! chicken.platform#software-version ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31286,a[2]=t1,a[3]=((C_word)li972),tmp=(C_word)a,a+=4,tmp));
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31291,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_build_platform,a[2]=((C_word)li997),tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32137,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6590: g7403 */
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)C_fast_retrieve_proc(t6))(2,av2);}}

/* chicken.platform#software-version in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_31286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31286,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_31291(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_31291,c,av);}
a=C_alloc(10);
t2=C_mutate((C_word*)lf[1330]+1 /* (set! chicken.platform#build-platform ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31292,a[2]=t1,a[3]=((C_word)li973),tmp=(C_word)a,a+=4,tmp));
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31297,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32133,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6594: software-type */
t5=C_fast_retrieve(lf[1326]);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* chicken.platform#build-platform in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_ccall f_31292(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31292,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_fcall f_31297(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,3)))){
C_save_and_reclaim_args((void *)trf_31297,2,t0,t1);}
a=C_alloc(21);
t2=C_set_block_item(lf[1331] /* ##sys#windows-platform */,0,t1);
t3=C_mutate((C_word*)lf[1332]+1 /* (set! chicken.platform#chicken-version ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31299,a[2]=((C_word)li975),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate((C_word*)lf[1365]+1 /* (set! chicken.platform#chicken-home ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31436,a[2]=((C_word)li976),tmp=(C_word)a,a+=3,tmp));
t5=(C_truep(C_fast_retrieve(lf[1331]))?C_make_character(59):C_make_character(58));
t6=lf[1366] /* chicken.platform#path-list-separator */ =t5;;
t7=lf[1367];
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_mutate((C_word*)lf[1368]+1 /* (set! ##sys#split-path ...) */,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31446,a[2]=t8,a[3]=((C_word)li978),tmp=(C_word)a,a+=4,tmp));
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31536,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32051,a[2]=t10,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t12=*((C_word*)lf[721]+1);{
C_word av2[4];
av2[0]=t12;
av2[1]=t11;
av2[2]=C_mpointer(&a,(void*)C_private_repository_path());
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t12+1)))(4,av2);}}

/* chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_31299(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_31299,c,av);}
a=C_alloc(6);
t2=C_rest_nullp(c,2);
t3=(C_truep(t2)?C_SCHEME_FALSE:C_get_rest_arg(c,2,av,2,t0));
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31360,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31399,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=C_fix((C_word)C_WORD_SIZE);
/* ##sys#fixnum->string */
t7=*((C_word*)lf[642]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t5;
av2[2]=t6;
av2[3]=C_fix(10);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t4=C_fast_retrieve(lf[1334]);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_fast_retrieve(lf[1334]);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_ccall f_31309(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_31309,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31312,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6601: software-type */
t3=C_fast_retrieve(lf[1326]);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_31312(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_31312,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31315,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6602: software-version */
t3=C_fast_retrieve(lf[1329]);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in ... */
static void C_ccall f_31315(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_31315,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31318,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6603: machine-type */
t3=C_fast_retrieve(lf[1327]);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k31316 in k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in ... */
static void C_ccall f_31318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_31318,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31320,a[2]=((C_word)li974),tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_31342,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* library.scm:6608: str */
f_31320(t3,((C_word*)t0)[5]);}

/* str in k31316 in k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in ... */
static void C_fcall f_31320(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_31320,2,t1,t2);}
a=C_alloc(3);
t3=C_eqp(lf[1339],t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=lf[1340];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31334,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6607: scheme#symbol->string */
t5=*((C_word*)lf[653]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k31332 in str in k31316 in k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in ... */
static void C_ccall f_31334(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31334,c,av);}
/* ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[1341];
tp(4,av2);}}

/* k31340 in k31316 in k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in ... */
static void C_ccall f_31342(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_31342,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_31346,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* library.scm:6608: str */
f_31320(t2,((C_word*)t0)[6]);}

/* k31344 in k31340 in k31316 in k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in ... */
static void C_ccall f_31346(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_31346,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31350,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* library.scm:6608: str */
f_31320(t2,((C_word*)t0)[6]);}

/* k31348 in k31344 in k31340 in k31316 in k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in ... */
static void C_ccall f_31350(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_31350,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31354,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6608: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
tp(3,av2);}}

/* k31352 in k31348 in k31344 in k31340 in k31316 in k31313 in k31310 in k31307 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in ... */
static void C_ccall f_31354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_31354,c,av);}
/* library.scm:6608: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_31360(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_31360,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31367,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_fast_retrieve(lf[1346]))){
/* library.scm:6618: scheme#string-append */
t3=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1347];
av2[3]=C_fast_retrieve(lf[1346]);
av2[4]=lf[1348];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[1349];
f_31367(2,av2);}}}

/* k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31367(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_31367,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31371,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fast_retrieve(lf[1342]))){
/* library.scm:6619: scheme#string-append */
t3=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1343];
av2[3]=C_fast_retrieve(lf[1342]);
av2[4]=lf[1344];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[1345];
f_31371(2,av2);}}}

/* k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_31371(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_31371,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31375,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31309,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6600: build-platform */
t4=C_fast_retrieve(lf[1330]);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k31373 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_ccall f_31375(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,8)))){
C_save_and_reclaim((void *)f_31375,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31379,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t3=C_block_size(((C_word*)t0)[5]);
t4=C_eqp(t3,C_fix(0));
if(C_truep(t4)){
/* library.scm:6616: scheme#string-append */
t5=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1333];
av2[3]=C_fast_retrieve(lf[1334]);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=lf[1335];
av2[7]=t1;
av2[8]=lf[1336];
((C_proc)(void*)(*((C_word*)t5+1)))(9,av2);}}
else{
/* library.scm:6624: scheme#string-append */
t5=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[1337];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[1338];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k31377 in k31373 in k31369 in k31365 in k31358 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_31379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_31379,c,av);}
/* library.scm:6616: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1333];
av2[3]=C_fast_retrieve(lf[1334]);
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
av2[6]=lf[1335];
av2[7]=((C_word*)t0)[5];
av2[8]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(9,av2);}}

/* k31397 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_31399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_31399,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31427,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6612: feature? */
t3=C_fast_retrieve(lf[1360]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1364];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k31416 in k31419 in k31422 in k31425 in k31397 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_31418(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_31418,c,av);}
if(C_truep(t1)){
/* library.scm:6610: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1356];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1357];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=lf[1358];
((C_proc)(void*)(*((C_word*)t2+1)))(9,av2);}}
else{
/* library.scm:6610: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1356];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1357];
av2[5]=((C_word*)t0)[4];
av2[6]=((C_word*)t0)[5];
av2[7]=((C_word*)t0)[6];
av2[8]=lf[1359];
((C_proc)(void*)(*((C_word*)t2+1)))(9,av2);}}}

/* k31419 in k31422 in k31425 in k31397 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_ccall f_31421(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_31421,c,av);}
a=C_alloc(7);
t2=(C_truep(t1)?lf[1354]:lf[1355]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_31418,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* library.scm:6615: feature? */
t4=C_fast_retrieve(lf[1360]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1361];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k31422 in k31425 in k31397 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_31424(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_31424,c,av);}
a=C_alloc(6);
t2=(C_truep(t1)?lf[1352]:lf[1353]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31421,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6614: feature? */
t4=C_fast_retrieve(lf[1360]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1362];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k31425 in k31397 in chicken.platform#chicken-version in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31427(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_31427,c,av);}
a=C_alloc(5);
t2=(C_truep(t1)?lf[1350]:lf[1351]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31424,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6613: feature? */
t4=C_fast_retrieve(lf[1360]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1363];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* chicken.platform#chicken-home in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_31436(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_31436,c,av);}
a=C_alloc(3);
/* ##sys#peek-c-string */
t2=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=C_mpointer(&a,(void*)C_INSTALL_SHARE_HOME);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* ##sys#split-path in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_31446(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_31446,c,av);}
a=C_alloc(13);
if(C_truep(C_i_not(t2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(((C_word*)((C_word*)t0)[2])[1]);
if(C_truep(C_i_equalp(t2,t3))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cdr(((C_word*)((C_word*)t0)[2])[1]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_string_length(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31468,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31474,a[2]=t4,a[3]=t2,a[4]=t7,a[5]=((C_word)li977),tmp=(C_word)a,a+=6,tmp));
t9=((C_word*)t7)[1];
f_31474(t9,t5,C_fix(0),C_fix(0));}}}

/* k31466 in ##sys#split-path in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_31468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_31468,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,t2);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* loop in ##sys#split-path in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_fcall f_31474(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_31474,4,t0,t1,t2,t3);}
a=C_alloc(5);
if(C_truep(C_fixnum_greater_or_equal_p(t3,((C_word*)t0)[2]))){
t4=C_eqp(t3,t2);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31494,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6651: scheme#substring */
t6=*((C_word*)lf[402]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}
else{
t4=C_i_string_ref(((C_word*)t0)[3],t3);
t5=C_retrieve2(lf[1366],C_text("chicken.platform#path-list-separator"));
if(C_truep(C_u_i_char_equalp(t4,C_retrieve2(lf[1366],C_text("chicken.platform#path-list-separator"))))){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31509,a[2]=t1,a[3]=((C_word*)t0)[4],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6654: scheme#substring */
t7=*((C_word*)lf[402]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
/* library.scm:6658: loop */
t8=t1;
t9=t2;
t10=C_fixnum_plus(t3,C_fix(1));
t1=t8;
t2=t9;
t3=t10;
goto loop;}}}

/* k31492 in loop in ##sys#split-path in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31494(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_31494,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list1(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k31507 in loop in ##sys#split-path in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_31509,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31513,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6655: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_31474(t3,t2,C_fixnum_plus(((C_word*)t0)[4],C_fix(1)),C_fixnum_plus(((C_word*)t0)[4],C_fix(1)));}

/* k31511 in k31507 in loop in ##sys#split-path in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_31513(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_31513,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_31536(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_31536,c,av);}
a=C_alloc(9);
t2=C_mutate((C_word*)lf[1369]+1 /* (set! chicken.platform#repository-path ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31540,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32035,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t5=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_mpointer(&a,(void*)C_private_repository_path());
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_31540(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_31540,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[1370]+1 /* (set! chicken.platform#installation-repository ...) */,t1);
t3=C_mutate(&lf[1371] /* (set! chicken.platform#chop-separator ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31542,a[2]=((C_word)li979),tmp=(C_word)a,a+=3,tmp));
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31572,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6692: chicken.process-context#get-environment-variable */
t5=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[1397];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* chicken.platform#chop-separator in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_31542,c,av);}
t3=C_i_string_length(t2);
t4=C_fixnum_difference(t3,C_fix(1));
if(C_truep(C_fixnum_greaterp(t4,C_fix(0)))){
t5=C_i_string_ref(t2,t4);
if(C_truep((C_truep(C_eqp(t5,C_make_character(92)))?C_SCHEME_TRUE:(C_truep(C_eqp(t5,C_make_character(47)))?C_SCHEME_TRUE:C_SCHEME_FALSE)))){
/* library.scm:6688: scheme#substring */
t6=*((C_word*)lf[402]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t1;
av2[2]=t2;
av2[3]=C_fix(0);
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_31572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_31572,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31575,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_retrieve2(lf[1371],C_text("chicken.platform#chop-separator"));
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31981,a[2]=t5,a[3]=t6,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6694: ##sys#split-path */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1368]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[1368]+1);
av2[1]=t8;
av2[2]=t1;
tp(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32031,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t4=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_mpointer(&a,(void*)C_INSTALL_SHARE_HOME);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_31575(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_31575,c,av);}
a=C_alloc(17);
t2=C_mutate((C_word*)lf[1372]+1 /* (set! ##sys#include-pathnames ...) */,t1);
t3=C_mutate((C_word*)lf[1373]+1 /* (set! chicken.platform#include-path ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31577,a[2]=((C_word)li980),tmp=(C_word)a,a+=3,tmp));
t4=C_mutate(&lf[1374] /* (set! chicken.platform#->feature-id ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31595,a[2]=((C_word)li981),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,lf[1377]);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31629,a[2]=((C_word)li982),tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31647,a[2]=((C_word*)t0)[2],a[3]=t6,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31973,a[2]=t6,a[3]=t7,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6724: software-type */
t9=C_fast_retrieve(lf[1326]);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* chicken.platform#include-path in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_ccall f_31577(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31577,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fast_retrieve(lf[1372]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.platform#->feature-id in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_ccall f_31595(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_31595,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31602,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6709: chicken.keyword#keyword? */
t4=*((C_word*)lf[666]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k31600 in chicken.platform#->feature-id in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_31602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_31602,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_stringp(((C_word*)t0)[3]))){
/* library.scm:6710: chicken.keyword#string->keyword */
t2=*((C_word*)lf[667]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
if(C_truep(C_i_symbolp(((C_word*)t0)[3]))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31624,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6711: ##sys#symbol->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[652]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[652]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
tp(3,av2);}}
else{
t2=C_a_i_list(&a,1,((C_word*)t0)[3]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[263];
av2[4]=lf[1375];
av2[5]=t2;
C_apply(6,av2);}}}}}

/* k31622 in k31600 in chicken.platform#->feature-id in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in ... */
static void C_ccall f_31624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31624,c,av);}
/* library.scm:6711: chicken.keyword#string->keyword */
t2=*((C_word*)lf[667]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* check in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_fcall f_31629(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_31629,2,t1,t2);}
a=C_alloc(3);
t3=C_eqp(lf[1339],t2);
if(C_truep(t3)){
t4=C_SCHEME_UNDEFINED;
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31644,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6723: ->feature-id */
t5=C_retrieve2(lf[1374],C_text("chicken.platform#->feature-id"));{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
f_31595(3,av2);}}}

/* k31642 in check in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_31644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_31644,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_fast_retrieve(lf[1376]));
t3=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t2);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_ccall f_31647(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_31647,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31650,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31969,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6725: software-version */
t4=C_fast_retrieve(lf[1329]);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_31650(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_31650,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31653,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31965,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6726: build-platform */
t4=C_fast_retrieve(lf[1330]);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in ... */
static void C_ccall f_31653(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_31653,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31656,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31961,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6727: machine-type */
t4=C_fast_retrieve(lf[1327]);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in ... */
static void C_ccall f_31656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_31656,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31659,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31957,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6728: machine-byte-order */
t4=C_fast_retrieve(lf[1328]);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in ... */
static void C_ccall f_31659(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_31659,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31662,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_mk_bool(HAVE_DLOAD))){
t3=C_a_i_cons(&a,2,lf[1364],C_fast_retrieve(lf[1376]));
t4=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t3);
t5=t2;
f_31662(t5,t4);}
else{
t3=t2;
f_31662(t3,C_SCHEME_UNDEFINED);}}

/* k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in ... */
static void C_fcall f_31662(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_31662,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31665,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_mk_bool(HAVE_PTABLES))){
t3=C_a_i_cons(&a,2,lf[1363],C_fast_retrieve(lf[1376]));
t4=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t3);
t5=t2;
f_31665(t5,t4);}
else{
t3=t2;
f_31665(t3,C_SCHEME_UNDEFINED);}}

/* k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in ... */
static void C_fcall f_31665(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_31665,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31668,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_mk_bool(HAVE_GCHOOKS))){
t3=C_a_i_cons(&a,2,lf[1362],C_fast_retrieve(lf[1376]));
t4=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t3);
t5=t2;
f_31668(t5,t4);}
else{
t3=t2;
f_31668(t3,C_SCHEME_UNDEFINED);}}

/* k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in ... */
static void C_fcall f_31668(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_31668,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31671,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_mk_bool(IS_CROSS_CHICKEN))){
t3=C_a_i_cons(&a,2,lf[1361],C_fast_retrieve(lf[1376]));
t4=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t3);
t5=t2;
f_31671(t5,t4);}
else{
t3=t2;
f_31671(t3,C_SCHEME_UNDEFINED);}}

/* k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in ... */
static void C_fcall f_31671(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_31671,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31927,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31931,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31935,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=C_fix((C_word)C_WORD_SIZE);
/* ##sys#fixnum->string */
t6=*((C_word*)lf[642]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
av2[3]=C_fix(10);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in ... */
static void C_ccall f_31679(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_31679,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31682,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=C_fix((C_word)C_MINOR_VERSION);
/* library.scm:6749: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t2;
av2[2]=t3;
tp(3,av2);}}

/* k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in ... */
static void C_ccall f_31682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_31682,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31905,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31921,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6750: scheme#string-append */
t4=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1395];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* chicken.platform#register-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in ... */
static void C_ccall f_31687(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +9,c,3)))){
C_save_and_reclaim((void*)f_31687,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+9);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31706,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31708,a[2]=t5,a[3]=((C_word)li983),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_31708(t7,t3,t2);}

/* k31691 in for-each-loop7562 in chicken.platform#register-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_ccall f_31693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31693,c,av);}
a=C_alloc(3);
if(C_truep(C_i_memq(t1,C_fast_retrieve(lf[1376])))){
t2=((C_word*)((C_word*)t0)[2])[1];
f_31708(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}
else{
t2=C_a_i_cons(&a,2,t1,C_fast_retrieve(lf[1376]));
t3=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t2);
t4=((C_word*)((C_word*)t0)[2])[1];
f_31708(t4,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}}

/* k31704 in chicken.platform#register-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in ... */
static void C_ccall f_31706(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31706,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* for-each-loop7562 in chicken.platform#register-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in ... */
static void C_fcall f_31708(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_31708,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31693,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6757: ->feature-id */
t5=C_retrieve2(lf[1374],C_text("chicken.platform#->feature-id"));{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
f_31595(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* chicken.platform#unregister-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in ... */
static void C_ccall f_31731(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +16,c,3)))){
C_save_and_reclaim((void*)f_31731,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+16);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_retrieve2(lf[1374],C_text("chicken.platform#->feature-id"));
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31738,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31775,a[2]=t5,a[3]=t10,a[4]=t6,a[5]=((C_word)li986),tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_31775(t12,t8,t2);}

/* k31736 in chicken.platform#unregister-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in ... */
static void C_ccall f_31738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_31738,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31742,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31744,a[2]=t1,a[3]=t4,a[4]=((C_word)li985),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_31744(t6,t2,C_fast_retrieve(lf[1376]));}

/* k31740 in k31736 in chicken.platform#unregister-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_ccall f_31742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31742,c,av);}
t2=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* loop in k31736 in chicken.platform#unregister-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_fcall f_31744(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_31744,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_slot(t2,C_fix(0));
t4=C_slot(t2,C_fix(1));
if(C_truep(C_i_memq(t3,((C_word*)t0)[2]))){
/* library.scm:6771: loop */
t7=t1;
t8=t4;
t1=t7;
t2=t8;
goto loop;}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31773,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6772: loop */
t7=t5;
t8=t4;
t1=t7;
t2=t8;
goto loop;}}}

/* k31771 in loop in k31736 in chicken.platform#unregister-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in ... */
static void C_ccall f_31773(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_31773,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* map-loop7585 in chicken.platform#unregister-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in ... */
static void C_fcall f_31775(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_31775,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31800,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6763: g7591 */
t4=C_retrieve2(lf[1374],C_text("chicken.platform#->feature-id"));{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_31595(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k31798 in map-loop7585 in chicken.platform#unregister-feature! in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_ccall f_31800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31800,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_31775(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* chicken.platform#features in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in ... */
static void C_ccall f_31809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_31809,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_fast_retrieve(lf[1376]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.platform#feature? in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in ... */
static void C_ccall f_31812(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,3)))){
C_save_and_reclaim((void*)f_31812,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31818,a[2]=t4,a[3]=((C_word)li989),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_31818(t6,t1,t2);}

/* loop in chicken.platform#feature? in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in ... */
static void C_fcall f_31818(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_31818,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_nullp(t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_31842,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:6780: ->feature-id */
t5=C_retrieve2(lf[1374],C_text("chicken.platform#->feature-id"));{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_slot(t2,C_fix(0));
f_31595(3,av2);}}}

/* k31840 in loop in chicken.platform#feature? in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_ccall f_31842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31842,c,av);}
if(C_truep(C_i_memq(t1,C_fast_retrieve(lf[1376])))){
/* library.scm:6781: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_31818(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.platform#system-config-directory in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in ... */
static void C_ccall f_31849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31849,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31853,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6787: chicken.process-context#get-environment-variable */
t3=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1386];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k31851 in chicken.platform#system-config-directory in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in ... */
static void C_ccall f_31853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31853,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_fast_retrieve(lf[1331]))){
/* library.scm:6789: chicken.process-context#get-environment-variable */
t2=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1383];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31865,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6790: chicken.process-context#get-environment-variable */
t3=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1385];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}

/* k31863 in k31851 in chicken.platform#system-config-directory in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_ccall f_31865(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31865,c,av);}
if(C_truep(t1)){
/* library.scm:6791: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[1384];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.platform#system-cache-directory in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in ... */
static void C_ccall f_31873(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31873,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31877,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6794: chicken.process-context#get-environment-variable */
t3=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1392];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k31875 in chicken.platform#system-cache-directory in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in ... */
static void C_ccall f_31877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_31877,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_fast_retrieve(lf[1331]))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31886,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6796: chicken.process-context#get-environment-variable */
t3=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1389];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31895,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6798: chicken.process-context#get-environment-variable */
t3=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[1391];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}

/* k31884 in k31875 in chicken.platform#system-cache-directory in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_ccall f_31886(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31886,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* library.scm:6797: chicken.process-context#get-environment-variable */
t2=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1388];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}}

/* k31893 in k31875 in chicken.platform#system-cache-directory in k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in ... */
static void C_ccall f_31895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31895,c,av);}
if(C_truep(t1)){
/* library.scm:6799: scheme#string-append */
t2=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[1390];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in ... */
static void C_ccall f_31905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,5)))){
C_save_and_reclaim((void *)f_31905,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_31913,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31917,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6751: scheme#string-append */
t4=*((C_word*)lf[422]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1393];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[1394];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k31911 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in ... */
static void C_ccall f_31913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,2)))){
C_save_and_reclaim((void *)f_31913,c,av);}
a=C_alloc(27);
t2=C_a_i_cons(&a,2,t1,C_fast_retrieve(lf[1376]));
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t2);
t4=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t3);
t5=C_mutate((C_word*)lf[1378]+1 /* (set! chicken.platform#register-feature! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31687,a[2]=((C_word)li984),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[1379]+1 /* (set! chicken.platform#unregister-feature! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31731,a[2]=((C_word)li987),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[1380]+1 /* (set! chicken.platform#features ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31809,a[2]=((C_word)li988),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[1360]+1 /* (set! chicken.platform#feature? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31812,a[2]=((C_word)li990),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[1381]+1 /* (set! chicken.platform#return-to-host ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_return_to_host,a[2]=((C_word)li991),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[1382]+1 /* (set! chicken.platform#system-config-directory ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31849,a[2]=((C_word)li992),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[1387]+1 /* (set! chicken.platform#system-cache-directory ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31873,a[2]=((C_word)li993),tmp=(C_word)a,a+=3,tmp));
t12=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t12;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}

/* k31915 in k31903 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in ... */
static void C_ccall f_31917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31917,c,av);}
/* library.scm:6751: ->feature-id */
t2=C_retrieve2(lf[1374],C_text("chicken.platform#->feature-id"));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
f_31595(3,av2);}}

/* k31919 in k31680 in k31677 in k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in ... */
static void C_ccall f_31921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31921,c,av);}
/* library.scm:6750: ->feature-id */
t2=C_retrieve2(lf[1374],C_text("chicken.platform#->feature-id"));{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
f_31595(3,av2);}}

/* k31925 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in ... */
static void C_ccall f_31927(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_31927,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,t1,C_fast_retrieve(lf[1376]));
t3=C_mutate((C_word*)lf[1376]+1 /* (set! ##sys#features ...) */,t2);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_31679,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t5=C_fix((C_word)C_MAJOR_VERSION);
/* library.scm:6748: ##sys#number->string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[622]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[622]+1);
av2[1]=t4;
av2[2]=t5;
tp(3,av2);}}

/* k31929 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in ... */
static void C_ccall f_31931(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31931,c,av);}
/* library.scm:6741: chicken.keyword#string->keyword */
t2=*((C_word*)lf[667]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k31933 in k31669 in k31666 in k31663 in k31660 in k31657 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in ... */
static void C_ccall f_31935(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_31935,c,av);}
/* ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[1396];
tp(4,av2);}}

/* k31955 in k31654 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in ... */
static void C_ccall f_31957(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31957,c,av);}
/* library.scm:6728: check */
f_31629(((C_word*)t0)[3],t1);}

/* k31959 in k31651 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in ... */
static void C_ccall f_31961(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31961,c,av);}
/* library.scm:6727: check */
f_31629(((C_word*)t0)[3],t1);}

/* k31963 in k31648 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in ... */
static void C_ccall f_31965(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31965,c,av);}
/* library.scm:6726: check */
f_31629(((C_word*)t0)[3],t1);}

/* k31967 in k31645 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_31969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31969,c,av);}
/* library.scm:6725: check */
f_31629(((C_word*)t0)[3],t1);}

/* k31971 in k31573 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_ccall f_31973(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_31973,c,av);}
/* library.scm:6724: check */
f_31629(((C_word*)t0)[3],t1);}

/* k31979 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_31981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_31981,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[708]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_31989,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=((C_word)li994),tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_31989(t6,((C_word*)t0)[4],t1);}

/* map-loop7505 in k31979 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in ... */
static void C_fcall f_31989(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_31989,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_32014,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6694: g7511 */
t4=C_retrieve2(lf[1371],C_text("chicken.platform#chop-separator"));{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
f_31542(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k32012 in map-loop7505 in k31979 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in ... */
static void C_ccall f_32014(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_32014,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_31989(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k32029 in k31570 in k31538 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static void C_ccall f_32031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_32031,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list1(&a,1,t1);
f_31575(2,av2);}}

/* k32033 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_32035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_32035,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32038,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
/* library.scm:6679: chicken.base#make-parameter */
t3=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32041,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6681: chicken.process-context#get-environment-variable */
t4=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1398];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k32036 in k32033 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_32038(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32038,c,av);}
/* library.scm:6679: chicken.base#make-parameter */
t2=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k32039 in k32033 in k31534 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_32041(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_32041,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
/* library.scm:6679: chicken.base#make-parameter */
t2=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
/* ##sys#peek-c-string */
t2=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=C_mpointer(&a,(void*)C_INSTALL_EGG_HOME);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k32049 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_32051(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_32051,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32054,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t1)){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list1(&a,1,t1);
f_32054(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32100,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* library.scm:6666: chicken.process-context#get-environment-variable */
t4=C_fast_retrieve(lf[1225]);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1400];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k32052 in k32049 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_32054(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_32054,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32056,a[2]=((C_word)li996),tmp=(C_word)a,a+=3,tmp);
/* library.scm:6663: chicken.base#make-parameter */
t3=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a32055 in k32052 in k32049 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_32056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_32056,c,av);}
a=C_alloc(3);
if(C_truep(t2)){
t3=C_i_check_list_2(t2,lf[1399]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32073,a[2]=((C_word)li995),tmp=(C_word)a,a+=3,tmp);
t5=(
  f_32073(t2)
);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* for-each-loop7463 in a32055 in k32052 in k32049 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in ... */
static C_word C_fcall f_32073(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=C_slot(t1,C_fix(0));
t3=C_i_check_string_2(t2,lf[1399]);
t5=C_slot(t1,C_fix(1));
t1=t5;
goto loop;}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* k32098 in k32049 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in ... */
static void C_ccall f_32100(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_32100,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
/* library.scm:6664: ##sys#split-path */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1368]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[1368]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
tp(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32109,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t3=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_mpointer(&a,(void*)C_INSTALL_EGG_HOME);
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k32107 in k32098 in k32049 in k31295 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in ... */
static void C_ccall f_32109(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_32109,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_list1(&a,1,t1):C_SCHEME_FALSE);
f_32054(2,av2);}}

/* k32127 in k32131 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in ... */
static void C_ccall f_32129(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32129,c,av);}
t2=((C_word*)t0)[2];
f_31297(t2,C_i_not(C_eqp(lf[1402],t1)));}

/* k32131 in k31289 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in ... */
static void C_ccall f_32133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_32133,c,av);}
a=C_alloc(3);
t2=C_eqp(lf[1401],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32129,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6596: software-version */
t4=C_fast_retrieve(lf[1329]);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=((C_word*)t0)[2];
f_31297(t3,C_SCHEME_FALSE);}}

/* k32135 in k31283 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in ... */
static void C_ccall f_32137(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32137,c,av);}
/* library.scm:6590: scheme#string->symbol */
t2=*((C_word*)lf[655]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k32139 in k31277 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in ... */
static void C_ccall f_32141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32141,c,av);}
/* library.scm:6586: scheme#string->symbol */
t2=*((C_word*)lf[655]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k32143 in k31271 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in ... */
static void C_ccall f_32145(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32145,c,av);}
/* library.scm:6582: scheme#string->symbol */
t2=*((C_word*)lf[655]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k32147 in k31265 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in ... */
static void C_ccall f_32149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32149,c,av);}
/* library.scm:6578: scheme#string->symbol */
t2=*((C_word*)lf[655]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k32151 in k30964 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_32153(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32153,c,av);}
/* library.scm:6574: scheme#string->symbol */
t2=*((C_word*)lf[655]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a32154 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_32155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32155,c,av);}
t3=C_i_check_symbol_2(t2,lf[1403]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_slot(t2,C_fix(2));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32163 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in ... */
static void C_ccall f_32164(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_32164,c,av);}
a=C_alloc(5);
t4=C_i_check_symbol_2(t2,lf[1403]);
t5=C_i_check_list_2(t3,lf[1404]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32174,a[2]=t3,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t7=C_i_length(t3);
if(C_truep(C_i_fixnumevenp(t7))){
t8=C_i_setslot(t2,C_fix(2),t3);
t9=C_i_nullp(t3);
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=(C_truep(t9)?C_i_unpersist_symbol(t2):C_i_persist_symbol(t2));
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
/* library.scm:6475: ##sys#signal-hook */
t8=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t8;
av2[1]=t6;
av2[2]=lf[263];
av2[3]=lf[1405];
av2[4]=t3;
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(6,av2);}}}

/* k32172 in a32163 in k30893 in k30531 in k30147 in k30110 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in ... */
static void C_ccall f_32174(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32174,c,av);}
t2=C_i_nullp(((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?C_i_unpersist_symbol(((C_word*)t0)[4]):C_i_persist_symbol(((C_word*)t0)[4]));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k32197 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_32199(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_32199,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32202,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_i_pairp(t1))){
t3=C_slot(t1,C_fix(1));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32220,a[2]=t5,a[3]=((C_word)li1005),tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_32220(t7,t2,t3);}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f38368,a[2]=((C_word)li1006),tmp=(C_word)a,a+=3,tmp);
/* library.scm:6148: chicken.base#make-parameter */
t4=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k32200 in k32197 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_32202(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_32202,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32204,a[2]=((C_word)li1004),tmp=(C_word)a,a+=3,tmp);
/* library.scm:6148: chicken.base#make-parameter */
t3=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a32203 in k32200 in k32197 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_32204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32204,c,av);}
t3=C_i_check_list_2(t2,lf[1407]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* loop in k32197 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_fcall f_32220(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,4)))){
C_save_and_reclaim_args((void *)trf_32220,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_slot(t2,C_fix(0));
t4=C_slot(t2,C_fix(1));
if(C_truep(C_i_string_equal_p(lf[1408],t3))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_block_size(t3);
if(C_truep(C_fixnum_greater_or_equal_p(t5,C_fix(3)))){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_32258,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* library.scm:6161: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t6;
av2[2]=t3;
av2[3]=C_fix(0);
av2[4]=C_fix(2);
tp(5,av2);}}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}

/* k32256 in loop in k32197 in k30106 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in ... */
static void C_ccall f_32258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32258,c,av);}
if(C_truep(C_i_string_equal_p(lf[1409],t1))){
/* library.scm:6162: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_32220(t2,((C_word*)t0)[3],((C_word*)t0)[4]);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k32280 in k32284 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_32282(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_32282,c,av);}
a=C_alloc(3);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f38380,a[2]=((C_word)li1008),tmp=(C_word)a,a+=3,tmp);
/* library.scm:6139: chicken.base#make-parameter */
t4=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k32284 in k29927 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_32286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_32286,c,av);}
a=C_alloc(3);
if(C_truep(C_i_nullp(t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f38374,a[2]=((C_word)li1007),tmp=(C_word)a,a+=3,tmp);
/* library.scm:6139: chicken.base#make-parameter */
t3=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1411];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32282,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6142: argv */
t3=C_fast_retrieve(lf[1233]);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a32287 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32288(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_32288,c,av);}
a=C_alloc(11);
t2=C_uint64_to_num(&a,C_MAX_PATH);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32292,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* library.scm:6067: scheme#make-string */
t4=*((C_word*)lf[386]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k32290 in a32287 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in ... */
static void C_ccall f_32292(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_32292,c,av);}
a=C_alloc(5);
t2=C_curdir(t1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32295,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_fast_retrieve(lf[1331]))){
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_32295(2,av2);}}
else{
/* library.scm:6070: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word *av2=av;
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t3;
tp(2,av2);}}}

/* k32293 in k32290 in a32287 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in ... */
static void C_ccall f_32295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_32295,c,av);}
a=C_alloc(3);
if(C_truep(((C_word*)t0)[2])){
/* library.scm:6072: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[404]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_fix(0);
av2[4]=((C_word*)t0)[2];
tp(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32308,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* library.scm:6075: ##sys#errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1208]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1208]+1);
av2[1]=t2;
tp(2,av2);}}}

/* k32306 in k32293 in k32290 in a32287 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in ... */
static void C_ccall f_32308(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_32308,c,av);}
/* library.scm:6073: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[718];
av2[3]=t1;
av2[4]=lf[1412];
av2[5]=lf[1413];
tp(6,av2);}}

/* a32312 in k29289 in k29069 in k27700 in k27697 in k27694 in k26927 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32313(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32313,c,av);}
/* library.scm:6078: ##sys#change-directory-hook */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1223]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1223]+1);
av2[1]=t1;
av2[2]=t2;
tp(3,av2);}}

/* a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_32319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +8,c,2)))){
C_save_and_reclaim((void*)f_32319,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+8);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
C_word t6;
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32323,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32458,a[2]=((C_word)li1015),tmp=(C_word)a,a+=3,tmp);
/* library.scm:5202: ##sys#error-handler */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[1029]);
C_word *av2=av;
av2[0]=*((C_word*)lf[1029]+1);
av2[1]=t4;
av2[2]=t5;
tp(3,av2);}}

/* k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_32323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_32323,c,av);}
a=C_alloc(5);
t2=C_mk_bool(C_gui_mode);
if(C_truep(C_i_not(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32332,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5204: ##sys#print */
t4=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1421];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32408,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5224: chicken.base#open-output-string */
t4=*((C_word*)lf[215]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_32332(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_32332,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32335,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32402,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5206: ##sys#print */
t4=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1420];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_32335(2,av2);}}}

/* k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_32335(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_32335,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32338,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32346,a[2]=((C_word*)t0)[3],a[3]=((C_word)li1012),tmp=(C_word)a,a+=4,tmp);
/* library.scm:5208: ##sys#with-print-length-limit */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[942]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[942]+1);
av2[1]=t2;
av2[2]=C_fix(400);
av2[3]=t3;
tp(4,av2);}}

/* k32336 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_32338(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_32338,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32341,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5220: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k32339 in k32336 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_32341(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_32341,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32344,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5221: chicken.base#print-call-chain */
t3=*((C_word*)lf[187]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k32342 in k32339 in k32336 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32344(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32344,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_halt(C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a32345 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_32346(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_32346,c,av);}
a=C_alloc(6);
t2=C_eqp(C_fix(1),C_u_i_length(((C_word*)t0)[2]));
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32356,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5212: ##sys#print */
t4=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[1419];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32376,a[2]=t4,a[3]=((C_word)li1011),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_32376(t6,t1,((C_word*)t0)[2]);}}

/* k32354 in a32345 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_32356(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_32356,c,av);}
/* library.scm:5213: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_slot(((C_word*)t0)[3],C_fix(0));
av2[3]=C_SCHEME_TRUE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k32366 in for-each-loop5953 in a32345 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_32368,c,av);}
/* library.scm:5218: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_SCHEME_TRUE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* for-each-loop5953 in a32345 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_32376(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_32376,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32386,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32368,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5217: ##sys#print */
t6=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_make_character(10);
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k32384 in for-each-loop5953 in a32345 in k32333 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32386,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_32376(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k32400 in k32330 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_32402(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_32402,c,av);}
/* library.scm:5207: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_SCHEME_FALSE;
av2[4]=*((C_word*)lf[734]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in ... */
static void C_ccall f_32408(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_32408,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32411,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[4])){
/* library.scm:5225: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_32411(2,av2);}}}

/* k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in ... */
static void C_ccall f_32411(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_32411,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32414,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* library.scm:5226: ##sys#print */
t3=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(10);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k32412 in k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in ... */
static void C_ccall f_32414(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_32414,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32415,a[2]=((C_word*)t0)[2],a[3]=((C_word)li1013),tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32425,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32431,a[2]=t5,a[3]=t2,a[4]=((C_word)li1014),tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_32431(t7,t3,((C_word*)t0)[4]);}

/* g5979 in k32412 in k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_32415(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_32415,3,t0,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32419,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5227: ##sys#print */
t4=*((C_word*)lf[887]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k32417 in g5979 in k32412 in k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32419(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_32419,c,av);}
/* library.scm:5227: ##sys#print */
t2=*((C_word*)lf[887]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_make_character(10);
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k32423 in k32412 in k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_ccall f_32425(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_32425,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32429,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* library.scm:5228: chicken.base#get-output-string */
t3=*((C_word*)lf[213]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k32427 in k32423 in k32412 in k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32429(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32429,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_halt(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* for-each-loop5978 in k32412 in k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in ... */
static void C_fcall f_32431(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_32431,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32441,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:5227: g5979 */
t4=((C_word*)t0)[3];
f_32415(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k32439 in for-each-loop5978 in k32412 in k32409 in k32406 in k32321 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in ... */
static void C_ccall f_32441(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32441,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_32431(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* a32457 in a32318 in k26591 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in ... */
static void C_ccall f_32458(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32458,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_halt(lf[1422]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a32460 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_32461(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_32461,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32465,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:5097: chicken.base#exit-handler */
t3=*((C_word*)lf[226]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k32463 in a32460 in k26587 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in ... */
static void C_ccall f_32465(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_32465,c,av);}
/* library.scm:5096: g5855 */
t2=t1;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fix((C_word)EX_SOFTWARE);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a32469 in k26583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_32470(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32470,c,av);}
/* library.scm:5092: cleanup-before-exit */
f_26482(t1);}

/* a32475 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32476(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_32476,c,av);}
a=C_alloc(4);
t2=C_rest_nullp(c,2);
t3=(C_truep(t2)?C_fix(0):C_get_rest_arg(c,2,av,2,t0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32483,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* library.scm:5082: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t4;
av2[2]=t3;
tp(3,av2);}}

/* k32481 in a32475 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_32483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_32483,c,av);}
a=C_alloc(4);
if(C_truep(C_retrieve2(lf[977],C_text("exit-in-progress")))){
/* library.scm:5084: ##sys#warn */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[316]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[316]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[1423];
tp(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32492,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:5086: cleanup-before-exit */
f_26482(t2);}}

/* k32490 in k32481 in a32475 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_32492(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32492,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_exit_runtime(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a32499 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32500,c,av);}
t3=C_slot(t2,C_fix(10));
t4=C_slot(t2,C_fix(12));
t5=C_slot(t2,C_fix(11));
if(C_truep(C_fixnum_greater_or_equal_p(t3,t5))){
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_END_OF_FILE;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=C_subchar(t4,t3);
t7=C_fixnum_plus(t3,C_fix(1));
t8=C_i_set_i_slot(t2,C_fix(10),t7);
t9=t1;{
C_word *av2=av;
av2[0]=t9;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}

/* a32524 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32525(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32525,c,av);}
t3=C_slot(t2,C_fix(10));
t4=C_slot(t2,C_fix(12));
t5=C_slot(t2,C_fix(11));
t6=C_fixnum_greater_or_equal_p(t3,t5);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=(C_truep(t6)?C_SCHEME_END_OF_FILE:C_subchar(t4,t3));
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* a32542 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32543(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_32543,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32547,a[2]=t2,a[3]=t3,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4834: check */
t5=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
av2[3]=C_fix(1);
((C_proc)C_fast_retrieve_proc(t5))(4,av2);}}

/* k32545 in a32542 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_32547(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32547,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(10));
t3=C_slot(((C_word*)t0)[2],C_fix(12));
t4=C_setsubchar(t3,t2,((C_word*)t0)[3]);
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_set_i_slot(((C_word*)t0)[2],C_fix(10),C_fixnum_plus(t2,C_fix(1)));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* a32561 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_32562,c,av);}
a=C_alloc(6);
t4=C_block_size(t3);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_32566,a[2]=t2,a[3]=t3,a[4]=t4,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* library.scm:4841: check */
t6=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
av2[3]=t4;
((C_proc)C_fast_retrieve_proc(t6))(4,av2);}}

/* k32564 in a32561 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_32566(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32566,c,av);}
t2=C_slot(((C_word*)t0)[2],C_fix(10));
t3=C_slot(((C_word*)t0)[2],C_fix(12));
t4=C_substring_copy(((C_word*)t0)[3],t3,C_fix(0),((C_word*)t0)[4],t2);
t5=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_set_i_slot(((C_word*)t0)[2],C_fix(10),C_fixnum_plus(t2,((C_word*)t0)[4]));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* a32580 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32581(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32581,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a32583 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32584(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32584,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a32586 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32587(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_32587,c,av);}
a=C_alloc(10);
t6=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t7=C_slot(t2,C_fix(10));
t8=C_slot(t2,C_fix(11));
t9=C_fixnum_difference(t8,t7);
t10=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_32597,a[2]=t2,a[3]=t7,a[4]=t6,a[5]=t4,a[6]=t5,a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t11=C_i_not(((C_word*)t6)[1]);
if(C_truep(t11)){
if(C_truep(t11)){
t12=C_set_block_item(t6,0,t9);
t13=t10;
f_32597(t13,t12);}
else{
t12=t10;
f_32597(t12,C_SCHEME_UNDEFINED);}}
else{
if(C_truep(C_fixnum_greaterp(((C_word*)t6)[1],t9))){
t12=C_set_block_item(t6,0,t9);
t13=t10;
f_32597(t13,t12);}
else{
t12=t10;
f_32597(t12,C_SCHEME_UNDEFINED);}}}

/* k32595 in a32586 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_fcall f_32597(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,1)))){
C_save_and_reclaim_args((void *)trf_32597,2,t0,t1);}
t2=C_slot(((C_word*)t0)[2],C_fix(12));
t3=C_fixnum_plus(((C_word*)t0)[3],((C_word*)((C_word*)t0)[4])[1]);
t4=C_substring_copy(t2,((C_word*)t0)[5],((C_word*)t0)[3],t3,((C_word*)t0)[6]);
t5=C_fixnum_plus(((C_word*)t0)[3],((C_word*)((C_word*)t0)[4])[1]);
t6=C_i_set_i_slot(((C_word*)t0)[2],C_fix(10),t5);
t7=((C_word*)t0)[7];{
C_word av2[2];
av2[0]=t7;
av2[1]=((C_word*)((C_word*)t0)[4])[1];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* a32627 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_32628,c,av);}
a=C_alloc(11);
t4=C_slot(t2,C_fix(10));
t5=C_slot(t2,C_fix(11));
t6=C_slot(t2,C_fix(12));
t7=(C_truep(t3)?C_fixnum_plus(t4,t3):t5);
if(C_truep(C_fixnum_greater_or_equal_p(t4,t5))){
t8=t1;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_END_OF_FILE;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_32652,a[2]=t7,a[3]=t5,a[4]=t6,a[5]=t4,a[6]=((C_word)li758),tmp=(C_word)a,a+=7,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32671,a[2]=t2,a[3]=((C_word)li759),tmp=(C_word)a,a+=4,tmp);
/* library.scm:4863: ##sys#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t8;
av2[3]=t9;
C_call_with_values(4,av2);}}}

/* a32651 in a32627 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_32652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_32652,c,av);}
a=C_alloc(3);
t2=C_fixnum_greaterp(((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(C_truep(t2)?((C_word*)t0)[3]:((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32662,a[2]=((C_word)li757),tmp=(C_word)a,a+=3,tmp);
/* library.scm:4864: ##sys#scan-buffer-line */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[945]);
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=*((C_word*)lf[945]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[4];
av2[3]=t3;
av2[4]=((C_word*)t0)[5];
av2[5]=t4;
tp(6,av2);}}

/* a32661 in a32651 in a32627 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in ... */
static void C_ccall f_32662(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_32662,c,av);}
/* library.scm:4866: scheme#values */{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_SCHEME_FALSE;
av2[3]=t2;
av2[4]=C_SCHEME_FALSE;
C_values(5,av2);}}

/* a32670 in a32627 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_32671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32671,c,av);}
if(C_truep(t4)){
t5=C_slot(((C_word*)t0)[2],C_fix(4));
t6=C_fixnum_plus(t5,C_fix(1));
t7=C_i_set_i_slot(((C_word*)t0)[2],C_fix(4),t6);
t8=C_i_set_i_slot(((C_word*)t0)[2],C_fix(5),C_fix(0));
t9=C_i_set_i_slot(((C_word*)t0)[2],C_fix(10),t2);
t10=t1;{
C_word *av2=av;
av2[0]=t10;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t5=C_slot(((C_word*)t0)[2],C_fix(5));
t6=C_block_size(t3);
t7=C_i_set_i_slot(((C_word*)t0)[2],C_fix(5),C_fixnum_plus(t5,t6));
t8=C_i_set_i_slot(((C_word*)t0)[2],C_fix(10),t2);
t9=t1;{
C_word *av2=av;
av2[0]=t9;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}

/* a32711 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in ... */
static void C_ccall f_32712(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_32712,c,av);}
a=C_alloc(5);
t3=C_slot(t2,C_fix(10));
t4=C_slot(t2,C_fix(12));
t5=C_slot(t2,C_fix(11));
if(C_truep(C_fixnum_greater_or_equal_p(t3,t5))){
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=lf[946];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_32731,a[2]=t2,a[3]=t5,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* library.scm:4881: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t6;
av2[2]=t4;
av2[3]=t3;
av2[4]=t5;
tp(5,av2);}}}

/* k32729 in a32711 in k25449 in k24279 in k24275 in k24271 in k20708 in k20704 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in ... */
static void C_ccall f_32731(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32731,c,av);}
t2=C_i_set_i_slot(((C_word*)t0)[2],C_fix(10),((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a32739 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in ... */
static void C_ccall f_32740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_32740,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32744,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t2)){
/* library.scm:3747: ##sys#check-keyword */
t4=*((C_word*)lf[358]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[1425];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k32742 in a32739 in k20700 in k20696 in k20692 in k20332 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in ... */
static void C_ccall f_32744(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32744,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a32748 in k20328 in k20324 in k20320 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in ... */
static void C_ccall f_32749(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32749,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_set_car(C_i_list_tail(t2,t3),t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* a32758 in k20316 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in ... */
static void C_ccall f_32759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32759,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_cdr(C_i_cddr(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32768 in k20312 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in ... */
static void C_ccall f_32769(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32769,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_cdr(C_i_cdar(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32778 in k20308 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in ... */
static void C_ccall f_32779(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32779,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_cdr(C_i_cadr(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32788 in k20304 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in ... */
static void C_ccall f_32789(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32789,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_cdr(C_i_caar(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32798 in k20300 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in ... */
static void C_ccall f_32799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32799,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(C_i_cddr(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32808 in k20296 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in ... */
static void C_ccall f_32809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32809,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(C_i_cdar(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32818 in k20292 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in ... */
static void C_ccall f_32819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32819,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(C_i_cadr(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32828 in k20288 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in ... */
static void C_ccall f_32829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32829,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(C_i_caar(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32838 in k20284 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in ... */
static void C_ccall f_32839(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32839,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_cdr(C_i_cdr(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32848 in k20280 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in ... */
static void C_ccall f_32849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32849,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_cdr(C_i_car(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32858 in k20276 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in ... */
static void C_ccall f_32859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32859,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(C_i_cdr(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32868 in k20272 in k20268 in k20188 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in ... */
static void C_ccall f_32869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32869,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(C_i_car(t2),t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32878 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_32879(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_32879,c,av);}
a=C_alloc(7);
if(C_truep(C_i_closurep(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32895,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32903,a[2]=((C_word)li1034),tmp=(C_word)a,a+=3,tmp);
/* library.scm:3568: ##sys#lambda-decoration */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[769]);
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[769]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=t4;
tp(4,av2);}}
else{
/* library.scm:3570: ##sys#error */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[776];
av2[3]=lf[1426];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k32893 in a32878 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_32895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_32895,c,av);}
if(C_truep(t1)){
t2=C_slot(t1,C_fix(1));
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* library.scm:3570: ##sys#error */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[776];
av2[3]=lf[1426];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}
else{
/* library.scm:3570: ##sys#error */
t2=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[776];
av2[3]=lf[1426];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* a32902 in a32878 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_32903(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32903,c,av);}
t3=C_i_pairp(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_eqp(C_retrieve2(lf[777],C_text("setter-tag")),C_slot(t2,C_fix(0))):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32918 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_32919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32919,c,av);}
t3=C_i_pairp(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_eqp(C_retrieve2(lf[777],C_text("setter-tag")),C_slot(t2,C_fix(0))):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32934 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_32935(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_32935,c,av);}
a=C_alloc(6);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32945,a[2]=((C_word)li1039),tmp=(C_word)a,a+=3,tmp);
t5=C_a_i_cons(&a,2,C_retrieve2(lf[777],C_text("setter-tag")),t4);
t6=C_i_setslot(t2,t3,t5);
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* a32944 in a32934 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in ... */
static void C_ccall f_32945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_32945,c,av);}
a=C_alloc(11);
if(C_truep(C_i_closurep(t2))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32955,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_32974,a[2]=((C_word)li1037),tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_32990,a[2]=t3,a[3]=((C_word)li1038),tmp=(C_word)a,a+=4,tmp);
/* library.scm:3579: ##sys#decorate-lambda */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[768]);
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[768]+1);
av2[1]=t4;
av2[2]=t2;
av2[3]=t5;
av2[4]=t6;
tp(5,av2);}}
else{
/* library.scm:3586: chicken.base#error */
t4=*((C_word*)lf[193]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[1427];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k32953 in a32944 in a32934 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_32955(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_32955,c,av);}
a=C_alloc(6);
t2=C_eqp(((C_word*)t0)[2],t1);
if(C_truep(t2)){
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t4=C_a_i_list1(&a,1,t3);
/* library.scm:3585: ##sys#become! */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[336]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[336]+1);
av2[1]=((C_word*)t0)[3];
av2[2]=t4;
tp(3,av2);}}}

/* a32973 in a32944 in a32934 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_32974(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_32974,c,av);}
t3=C_i_pairp(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?C_eqp(C_retrieve2(lf[777],C_text("setter-tag")),C_slot(t2,C_fix(0))):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a32989 in a32944 in a32934 in k19411 in k19408 in k19405 in k19402 in k19398 in k19394 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in ... */
static void C_ccall f_32990(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_32990,c,av);}
a=C_alloc(3);
t4=C_a_i_cons(&a,2,C_retrieve2(lf[777],C_text("setter-tag")),((C_word*)t0)[2]);
t5=C_i_setslot(t2,t3,t4);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* a33002 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33003(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_33003,c,av);}
a=C_alloc(7);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33009,a[2]=t2,a[3]=t4,a[4]=((C_word)li556),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
f_33009(2,av2);}}

/* loop in a33002 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33009(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_33009,c,av);}
a=C_alloc(5);
t2=C_read_char(((C_word*)t0)[2]);
t3=C_eqp(C_fix(-1),t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33019,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3233: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word *av2=av;
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t4;
tp(2,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k33017 in loop in a33002 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_33019,c,av);}
a=C_alloc(11);
t2=C_fix((C_word)EINTR);
t3=C_eqp(t1,t2);
if(C_truep(t3)){
/* library.scm:3235: ##sys#dispatch-interrupt */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[717]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[717]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)((C_word*)t0)[3])[1];
tp(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33035,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33039,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t6=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_mpointer(&a,(void*)strerror(errno));
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* k33033 in k33017 in loop in a33002 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_33035,c,av);}
/* library.scm:3236: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[718];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[719];
av2[5]=t1;
av2[6]=((C_word*)t0)[4];
tp(7,av2);}}

/* k33037 in k33017 in loop in a33002 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_33039,c,av);}
/* library.scm:3238: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[720];
av2[3]=t1;
tp(4,av2);}}

/* a33041 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33042(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_33042,c,av);}
a=C_alloc(7);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33048,a[2]=t2,a[3]=t4,a[4]=((C_word)li558),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
f_33048(2,av2);}}

/* loop in a33041 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33048(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_33048,c,av);}
a=C_alloc(5);
t2=C_peek_char(((C_word*)t0)[2]);
t3=C_eqp(C_fix(-1),t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33058,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* library.scm:3246: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word *av2=av;
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t4;
tp(2,av2);}}
else{
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k33056 in loop in a33041 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33058(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_33058,c,av);}
a=C_alloc(11);
t2=C_fix((C_word)EINTR);
t3=C_eqp(t1,t2);
if(C_truep(t3)){
/* library.scm:3248: ##sys#dispatch-interrupt */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[717]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[717]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)((C_word*)t0)[3])[1];
tp(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33074,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33078,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t6=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_mpointer(&a,(void*)strerror(errno));
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* k33072 in k33056 in loop in a33041 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33074(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_33074,c,av);}
/* library.scm:3249: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[718];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[723];
av2[5]=t1;
av2[6]=((C_word*)t0)[4];
tp(7,av2);}}

/* k33076 in k33056 in loop in a33041 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33078(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_33078,c,av);}
/* library.scm:3251: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[724];
av2[3]=t1;
tp(4,av2);}}

/* a33080 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33081(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_33081,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_display_char(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a33083 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33084(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_33084,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_display_string(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a33086 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33087(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_33087,c,av);}
t4=C_close_file(t2);
/* library.scm:3260: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word *av2=av;
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t1;
tp(2,av2);}}

/* a33092 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33093(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_33093,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_flush_output(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a33095 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_33096,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_char_ready_p(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a33098 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5=av[5];
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(c!=6) C_bad_argc_2(c,6,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_33099,c,av);}
a=C_alloc(9);
t6=(C_truep(t3)?t3:C_fixnum_difference(C_block_size(t4),t5));
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_33109,a[2]=t4,a[3]=t2,a[4]=t8,a[5]=t3,a[6]=((C_word)li566),tmp=(C_word)a,a+=7,tmp));
t10=((C_word*)t8)[1];
f_33109(t10,t1,t6,C_fix(0),t5);}

/* loop in a33098 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_33109(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_33109,5,t0,t1,t2,t3,t4);}
a=C_alloc(11);
t5=fast_read_string_from_file(((C_word*)t0)[2],((C_word*)t0)[3],t2,t4);
if(C_truep(C_eofp(t5))){
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
if(C_truep(C_fixnum_lessp(t5,C_fix(0)))){
t6=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_33125,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=t5,a[5]=t3,a[6]=t4,a[7]=t1,a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[2],tmp=(C_word)a,a+=11,tmp);
/* library.scm:3271: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word av2[2];
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t6;
tp(2,av2);}}
else{
if(C_truep(C_fixnum_lessp(t5,t2))){
/* library.scm:3281: loop */
t8=t1;
t9=C_fixnum_difference(t2,t5);
t10=C_fixnum_plus(t3,t5);
t11=C_fixnum_plus(t4,t5);
t1=t8;
t2=t9;
t3=t10;
t4=t11;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_fixnum_plus(t3,t5);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}

/* k33123 in loop in a33098 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_33125,c,av);}
a=C_alloc(14);
t2=C_fix((C_word)EINTR);
t3=C_eqp(t1,t2);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_33136,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word)li565),tmp=(C_word)a,a+=8,tmp);
/* library.scm:3273: ##sys#dispatch-interrupt */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[717]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[717]+1);
av2[1]=((C_word*)t0)[7];
av2[2]=t4;
tp(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_33159,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33163,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t6=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_mpointer(&a,(void*)strerror(errno));
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* a33135 in k33123 in loop in a33098 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33136(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_33136,c,av);}
/* library.scm:3275: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_33109(t2,t1,C_fixnum_difference(((C_word*)t0)[3],((C_word*)t0)[4]),C_fixnum_plus(((C_word*)t0)[5],((C_word*)t0)[4]),C_fixnum_plus(((C_word*)t0)[6],((C_word*)t0)[4]));}

/* k33157 in k33123 in loop in a33098 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33159(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,9)))){
C_save_and_reclaim((void *)f_33159,c,av);}
/* library.scm:3276: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 10) {
  av2=av;
} else {
  av2=C_alloc(10);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[718];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[725];
av2[5]=t1;
av2[6]=((C_word*)t0)[4];
av2[7]=((C_word*)t0)[5];
av2[8]=((C_word*)t0)[6];
av2[9]=((C_word*)t0)[7];
tp(10,av2);}}

/* k33161 in k33123 in loop in a33098 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33163(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_33163,c,av);}
/* library.scm:3278: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[726];
av2[3]=t1;
tp(4,av2);}}

/* a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_33197,c,av);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33201,a[2]=t3,a[3]=t2,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t3)){
/* library.scm:3285: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2=av;
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t4;
av2[2]=t3;
av2[3]=lf[727];
tp(4,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_33201(2,av2);}}}

/* k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33201(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_33201,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_33204,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_slot(((C_word*)t0)[3],C_fix(12)))){
t3=t2;
f_33204(t3,C_SCHEME_UNDEFINED);}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_33369,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3288: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t3;
av2[2]=C_fix(1024);
tp(3,av2);}}}

/* k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_33204(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,7)))){
C_save_and_reclaim_args((void *)trf_33204,2,t0,t1);}
a=C_alloc(8);
t2=(C_truep(((C_word*)t0)[2])?((C_word*)t0)[2]:lf[274]);
t3=C_slot(((C_word*)t0)[3],C_fix(12));
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_33217,a[2]=((C_word*)t0)[3],a[3]=t5,a[4]=((C_word*)t0)[2],a[5]=((C_word)li569),tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_33217(t7,((C_word*)t0)[4],C_fix(1024),t2,t3,lf[729],C_SCHEME_FALSE);}

/* loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_fcall f_33217(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_33217,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(11);
t7=C_i_fixnum_min(t3,t2);
t8=fast_read_line_from_file(t4,((C_word*)t0)[2],t7);
if(C_truep(C_eofp(t8))){
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=(C_truep(t6)?t5:C_SCHEME_END_OF_FILE);
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
if(C_truep(C_i_not(t8))){
if(C_truep(C_fixnum_lessp(t3,t2))){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_33250,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3299: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t9;
av2[2]=t4;
av2[3]=C_fix(0);
av2[4]=t3;
tp(5,av2);}}
else{
t9=C_fixnum_times(t2,C_fix(2));
t10=C_fixnum_difference(t3,t2);
t11=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_33265,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t9,a[5]=t10,a[6]=t5,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
/* library.scm:3302: ##sys#make-string */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[385]+1));
C_word av2[3];
av2[0]=*((C_word*)lf[385]+1);
av2[1]=t11;
av2[2]=C_fixnum_times(t2,C_fix(2));
tp(3,av2);}}}
else{
if(C_truep(C_fixnum_lessp(t8,C_fix(0)))){
t9=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_33282,a[2]=t8,a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t1,a[9]=((C_word*)t0)[2],a[10]=((C_word*)t0)[4],tmp=(C_word)a,a+=11,tmp);
/* library.scm:3306: ##sys#update-errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[722]);
C_word av2[2];
av2[0]=*((C_word*)lf[722]+1);
av2[1]=t9;
tp(2,av2);}}
else{
if(C_truep(t6)){
t9=C_slot(((C_word*)t0)[2],C_fix(4));
t10=C_fixnum_plus(t9,C_fix(1));
t11=C_i_set_i_slot(((C_word*)t0)[2],C_fix(4),t10);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_33337,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* library.scm:3320: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t12;
av2[2]=t4;
av2[3]=C_fix(0);
av2[4]=t8;
tp(5,av2);}}
else{
t9=C_slot(((C_word*)t0)[2],C_fix(4));
t10=C_fixnum_plus(t9,C_fix(1));
t11=C_i_set_i_slot(((C_word*)t0)[2],C_fix(4),t10);
/* library.scm:3323: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word av2[5];
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t1;
av2[2]=t4;
av2[3]=C_fix(0);
av2[4]=t8;
tp(5,av2);}}}}}}

/* k33248 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_33250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_33250,c,av);}
/* library.scm:3299: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k33263 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_33265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_33265,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_33269,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* library.scm:3303: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
tp(4,av2);}}

/* k33267 in k33263 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in ... */
static void C_ccall f_33269(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_33269,c,av);}
/* library.scm:3300: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_33217(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,C_SCHEME_TRUE);}

/* k33280 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_33282(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_33282,c,av);}
a=C_alloc(12);
t2=C_fix((C_word)EINTR);
t3=C_eqp(t1,t2);
if(C_truep(t3)){
t4=C_fixnum_negate(((C_word*)t0)[2]);
t5=C_fixnum_difference(t4,C_fix(1));
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_33296,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t5,a[8]=((C_word)li568),tmp=(C_word)a,a+=9,tmp);
/* library.scm:3309: ##sys#dispatch-interrupt */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[717]);
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[717]+1);
av2[1]=((C_word*)t0)[8];
av2[2]=t6;
tp(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_33319,a[2]=((C_word*)t0)[8],a[3]=t1,a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_33323,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* ##sys#peek-c-string */
t6=*((C_word*)lf[721]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_mpointer(&a,(void*)strerror(errno));
av2[3]=C_fix(0);
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* a33295 in k33280 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in ... */
static void C_ccall f_33296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_33296,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_33304,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_33308,a[2]=t2,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* library.scm:3313: ##sys#substring */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[404]+1));
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=*((C_word*)lf[404]+1);
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=C_fix(0);
av2[4]=((C_word*)t0)[7];
tp(5,av2);}}

/* k33302 in a33295 in k33280 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_33304(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_33304,c,av);}
/* library.scm:3311: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_33217(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,C_SCHEME_TRUE);}

/* k33306 in a33295 in k33280 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in ... */
static void C_ccall f_33308(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_33308,c,av);}
/* library.scm:3312: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k33317 in k33280 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in ... */
static void C_ccall f_33319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,7)))){
C_save_and_reclaim((void *)f_33319,c,av);}
/* library.scm:3315: ##sys#signal-hook/errno */
{C_proc tp=(C_proc)C_fast_retrieve_symbol_proc(lf[319]);
C_word *av2;
if(c >= 8) {
  av2=av;
} else {
  av2=C_alloc(8);
}
av2[0]=*((C_word*)lf[319]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[718];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[727];
av2[5]=t1;
av2[6]=((C_word*)t0)[4];
av2[7]=((C_word*)t0)[5];
tp(8,av2);}}

/* k33321 in k33280 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in ... */
static void C_ccall f_33323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_33323,c,av);}
/* library.scm:3317: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=lf[728];
av2[3]=t1;
tp(4,av2);}}

/* k33335 in loop in k33202 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 in ... */
static void C_ccall f_33337(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_33337,c,av);}
/* library.scm:3320: ##sys#string-append */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[421]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[421]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
tp(4,av2);}}

/* k33367 in k33199 in a33196 in k18878 in k18875 in k18872 in k18869 in k18866 in k18863 in k18860 in k18857 in k18854 in k18851 in k18848 in k18845 in k18842 in k18839 in k18679 in k10751 in k8834 */
static void C_ccall f_33369(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_33369,c,av);}
t2=((C_word*)t0)[2];
f_33204(t2,C_i_setslot(((C_word*)t0)[3],C_fix(12),t1));}

/* k8834 */
static void C_ccall f_8836(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word t69;
C_word t70;
C_word t71;
C_word t72;
C_word t73;
C_word t74;
C_word t75;
C_word t76;
C_word t77;
C_word t78;
C_word t79;
C_word t80;
C_word t81;
C_word t82;
C_word t83;
C_word t84;
C_word t85;
C_word t86;
C_word t87;
C_word t88;
C_word t89;
C_word t90;
C_word t91;
C_word t92;
C_word t93;
C_word t94;
C_word t95;
C_word t96;
C_word t97;
C_word t98;
C_word t99;
C_word t100;
C_word t101;
C_word t102;
C_word t103;
C_word t104;
C_word t105;
C_word t106;
C_word t107;
C_word t108;
C_word t109;
C_word t110;
C_word t111;
C_word t112;
C_word t113;
C_word t114;
C_word t115;
C_word t116;
C_word t117;
C_word t118;
C_word t119;
C_word t120;
C_word t121;
C_word t122;
C_word t123;
C_word t124;
C_word t125;
C_word t126;
C_word t127;
C_word t128;
C_word t129;
C_word t130;
C_word t131;
C_word t132;
C_word t133;
C_word t134;
C_word t135;
C_word t136;
C_word t137;
C_word t138;
C_word t139;
C_word t140;
C_word t141;
C_word t142;
C_word t143;
C_word t144;
C_word t145;
C_word t146;
C_word t147;
C_word t148;
C_word t149;
C_word t150;
C_word t151;
C_word t152;
C_word t153;
C_word t154;
C_word t155;
C_word t156;
C_word t157;
C_word t158;
C_word t159;
C_word t160;
C_word t161;
C_word t162;
C_word t163;
C_word t164;
C_word t165;
C_word t166;
C_word t167;
C_word t168;
C_word t169;
C_word t170;
C_word t171;
C_word t172;
C_word t173;
C_word t174;
C_word t175;
C_word t176;
C_word t177;
C_word t178;
C_word t179;
C_word t180;
C_word t181;
C_word t182;
C_word t183;
C_word t184;
C_word t185;
C_word t186;
C_word t187;
C_word t188;
C_word t189;
C_word t190;
C_word t191;
C_word t192;
C_word t193;
C_word t194;
C_word t195;
C_word t196;
C_word t197;
C_word t198;
C_word t199;
C_word t200;
C_word t201;
C_word t202;
C_word t203;
C_word t204;
C_word t205;
C_word t206;
C_word t207;
C_word t208;
C_word t209;
C_word t210;
C_word t211;
C_word t212;
C_word t213;
C_word t214;
C_word t215;
C_word t216;
C_word t217;
C_word t218;
C_word t219;
C_word t220;
C_word t221;
C_word t222;
C_word t223;
C_word t224;
C_word t225;
C_word t226;
C_word t227;
C_word t228;
C_word t229;
C_word t230;
C_word t231;
C_word t232;
C_word t233;
C_word t234;
C_word t235;
C_word t236;
C_word t237;
C_word t238;
C_word t239;
C_word t240;
C_word t241;
C_word t242;
C_word t243;
C_word t244;
C_word t245;
C_word t246;
C_word t247;
C_word t248;
C_word t249;
C_word t250;
C_word t251;
C_word t252;
C_word t253;
C_word t254;
C_word t255;
C_word t256;
C_word t257;
C_word t258;
C_word t259;
C_word t260;
C_word t261;
C_word t262;
C_word t263;
C_word t264;
C_word t265;
C_word t266;
C_word t267;
C_word t268;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(614,c,5)))){
C_save_and_reclaim((void *)f_8836,c,av);}
a=C_alloc(614);
t2=C_a_i_provide(&a,1,lf[0]);
t3=C_a_i_provide(&a,1,lf[1]);
t4=C_mutate((C_word*)lf[2]+1 /* (set! scheme#not ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8838,a[2]=((C_word)li0),tmp=(C_word)a,a+=3,tmp));
t5=C_mutate((C_word*)lf[3]+1 /* (set! scheme#boolean? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8841,a[2]=((C_word)li1),tmp=(C_word)a,a+=3,tmp));
t6=C_mutate((C_word*)lf[4]+1 /* (set! scheme#eq? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8844,a[2]=((C_word)li2),tmp=(C_word)a,a+=3,tmp));
t7=C_mutate((C_word*)lf[5]+1 /* (set! scheme#eqv? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8847,a[2]=((C_word)li3),tmp=(C_word)a,a+=3,tmp));
t8=C_mutate((C_word*)lf[6]+1 /* (set! scheme#equal? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8850,a[2]=((C_word)li4),tmp=(C_word)a,a+=3,tmp));
t9=C_mutate((C_word*)lf[7]+1 /* (set! scheme#pair? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8853,a[2]=((C_word)li5),tmp=(C_word)a,a+=3,tmp));
t10=C_mutate((C_word*)lf[8]+1 /* (set! scheme#cons ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8856,a[2]=((C_word)li6),tmp=(C_word)a,a+=3,tmp));
t11=C_mutate((C_word*)lf[9]+1 /* (set! scheme#car ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8859,a[2]=((C_word)li7),tmp=(C_word)a,a+=3,tmp));
t12=C_mutate((C_word*)lf[10]+1 /* (set! scheme#cdr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8862,a[2]=((C_word)li8),tmp=(C_word)a,a+=3,tmp));
t13=C_mutate((C_word*)lf[11]+1 /* (set! scheme#set-car! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8865,a[2]=((C_word)li9),tmp=(C_word)a,a+=3,tmp));
t14=C_mutate((C_word*)lf[12]+1 /* (set! scheme#set-cdr! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8868,a[2]=((C_word)li10),tmp=(C_word)a,a+=3,tmp));
t15=C_mutate((C_word*)lf[13]+1 /* (set! scheme#cadr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8871,a[2]=((C_word)li11),tmp=(C_word)a,a+=3,tmp));
t16=C_mutate((C_word*)lf[14]+1 /* (set! scheme#caddr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8874,a[2]=((C_word)li12),tmp=(C_word)a,a+=3,tmp));
t17=C_mutate((C_word*)lf[15]+1 /* (set! scheme#cadddr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8877,a[2]=((C_word)li13),tmp=(C_word)a,a+=3,tmp));
t18=C_mutate((C_word*)lf[16]+1 /* (set! scheme#cddddr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8880,a[2]=((C_word)li14),tmp=(C_word)a,a+=3,tmp));
t19=C_mutate((C_word*)lf[17]+1 /* (set! scheme#caar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8883,a[2]=((C_word)li15),tmp=(C_word)a,a+=3,tmp));
t20=C_mutate((C_word*)lf[18]+1 /* (set! scheme#cdar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8886,a[2]=((C_word)li16),tmp=(C_word)a,a+=3,tmp));
t21=C_mutate((C_word*)lf[19]+1 /* (set! scheme#cddr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8889,a[2]=((C_word)li17),tmp=(C_word)a,a+=3,tmp));
t22=C_mutate((C_word*)lf[20]+1 /* (set! scheme#caaar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8892,a[2]=((C_word)li18),tmp=(C_word)a,a+=3,tmp));
t23=C_mutate((C_word*)lf[21]+1 /* (set! scheme#caadr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8906,a[2]=((C_word)li19),tmp=(C_word)a,a+=3,tmp));
t24=C_mutate((C_word*)lf[22]+1 /* (set! scheme#cadar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8913,a[2]=((C_word)li20),tmp=(C_word)a,a+=3,tmp));
t25=C_mutate((C_word*)lf[23]+1 /* (set! scheme#cdaar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8920,a[2]=((C_word)li21),tmp=(C_word)a,a+=3,tmp));
t26=C_mutate((C_word*)lf[24]+1 /* (set! scheme#cdadr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8934,a[2]=((C_word)li22),tmp=(C_word)a,a+=3,tmp));
t27=C_mutate((C_word*)lf[25]+1 /* (set! scheme#cddar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8941,a[2]=((C_word)li23),tmp=(C_word)a,a+=3,tmp));
t28=C_mutate((C_word*)lf[26]+1 /* (set! scheme#cdddr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8955,a[2]=((C_word)li24),tmp=(C_word)a,a+=3,tmp));
t29=C_mutate((C_word*)lf[27]+1 /* (set! scheme#caaaar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8969,a[2]=((C_word)li25),tmp=(C_word)a,a+=3,tmp));
t30=C_mutate((C_word*)lf[28]+1 /* (set! scheme#caaadr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8987,a[2]=((C_word)li26),tmp=(C_word)a,a+=3,tmp));
t31=C_mutate((C_word*)lf[29]+1 /* (set! scheme#caadar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8998,a[2]=((C_word)li27),tmp=(C_word)a,a+=3,tmp));
t32=C_mutate((C_word*)lf[30]+1 /* (set! scheme#caaddr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9009,a[2]=((C_word)li28),tmp=(C_word)a,a+=3,tmp));
t33=C_mutate((C_word*)lf[31]+1 /* (set! scheme#cadaar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9016,a[2]=((C_word)li29),tmp=(C_word)a,a+=3,tmp));
t34=C_mutate((C_word*)lf[32]+1 /* (set! scheme#cadadr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9027,a[2]=((C_word)li30),tmp=(C_word)a,a+=3,tmp));
t35=C_mutate((C_word*)lf[33]+1 /* (set! scheme#caddar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9031,a[2]=((C_word)li31),tmp=(C_word)a,a+=3,tmp));
t36=C_mutate((C_word*)lf[34]+1 /* (set! scheme#cdaaar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9038,a[2]=((C_word)li32),tmp=(C_word)a,a+=3,tmp));
t37=C_mutate((C_word*)lf[35]+1 /* (set! scheme#cdaadr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9056,a[2]=((C_word)li33),tmp=(C_word)a,a+=3,tmp));
t38=C_mutate((C_word*)lf[36]+1 /* (set! scheme#cdadar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9067,a[2]=((C_word)li34),tmp=(C_word)a,a+=3,tmp));
t39=C_mutate((C_word*)lf[37]+1 /* (set! scheme#cdaddr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9078,a[2]=((C_word)li35),tmp=(C_word)a,a+=3,tmp));
t40=C_mutate((C_word*)lf[38]+1 /* (set! scheme#cddaar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9085,a[2]=((C_word)li36),tmp=(C_word)a,a+=3,tmp));
t41=C_mutate((C_word*)lf[39]+1 /* (set! scheme#cddadr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9103,a[2]=((C_word)li37),tmp=(C_word)a,a+=3,tmp));
t42=C_mutate((C_word*)lf[40]+1 /* (set! scheme#cdddar ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9114,a[2]=((C_word)li38),tmp=(C_word)a,a+=3,tmp));
t43=C_mutate((C_word*)lf[41]+1 /* (set! scheme#null? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9132,a[2]=((C_word)li39),tmp=(C_word)a,a+=3,tmp));
t44=C_mutate((C_word*)lf[42]+1 /* (set! scheme#list ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9138,a[2]=((C_word)li40),tmp=(C_word)a,a+=3,tmp));
t45=C_mutate((C_word*)lf[43]+1 /* (set! scheme#length ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9141,a[2]=((C_word)li41),tmp=(C_word)a,a+=3,tmp));
t46=C_mutate((C_word*)lf[44]+1 /* (set! scheme#list-tail ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9144,a[2]=((C_word)li42),tmp=(C_word)a,a+=3,tmp));
t47=C_mutate((C_word*)lf[45]+1 /* (set! scheme#list-ref ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9147,a[2]=((C_word)li43),tmp=(C_word)a,a+=3,tmp));
t48=C_mutate((C_word*)lf[46]+1 /* (set! scheme#reverse ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9150,a[2]=((C_word)li45),tmp=(C_word)a,a+=3,tmp));
t49=C_mutate((C_word*)lf[49]+1 /* (set! scheme#memq ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9189,a[2]=((C_word)li46),tmp=(C_word)a,a+=3,tmp));
t50=C_mutate((C_word*)lf[50]+1 /* (set! scheme#memv ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9192,a[2]=((C_word)li47),tmp=(C_word)a,a+=3,tmp));
t51=C_mutate((C_word*)lf[51]+1 /* (set! scheme#member ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9195,a[2]=((C_word)li48),tmp=(C_word)a,a+=3,tmp));
t52=C_mutate((C_word*)lf[52]+1 /* (set! scheme#assq ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9198,a[2]=((C_word)li49),tmp=(C_word)a,a+=3,tmp));
t53=C_mutate((C_word*)lf[53]+1 /* (set! scheme#assv ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9201,a[2]=((C_word)li50),tmp=(C_word)a,a+=3,tmp));
t54=C_mutate((C_word*)lf[54]+1 /* (set! scheme#assoc ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9204,a[2]=((C_word)li51),tmp=(C_word)a,a+=3,tmp));
t55=C_mutate((C_word*)lf[55]+1 /* (set! scheme#list? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9207,a[2]=((C_word)li52),tmp=(C_word)a,a+=3,tmp));
t56=C_mutate((C_word*)lf[56]+1 /* (set! scheme#string? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9210,a[2]=((C_word)li53),tmp=(C_word)a,a+=3,tmp));
t57=C_mutate((C_word*)lf[57]+1 /* (set! scheme#string-length ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9213,a[2]=((C_word)li54),tmp=(C_word)a,a+=3,tmp));
t58=C_mutate((C_word*)lf[58]+1 /* (set! scheme#string-ref ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9216,a[2]=((C_word)li55),tmp=(C_word)a,a+=3,tmp));
t59=C_mutate((C_word*)lf[59]+1 /* (set! scheme#string-set! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9219,a[2]=((C_word)li56),tmp=(C_word)a,a+=3,tmp));
t60=C_mutate((C_word*)lf[60]+1 /* (set! scheme#string=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9222,a[2]=((C_word)li57),tmp=(C_word)a,a+=3,tmp));
t61=C_mutate((C_word*)lf[61]+1 /* (set! scheme#string-ci=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9225,a[2]=((C_word)li58),tmp=(C_word)a,a+=3,tmp));
t62=C_mutate((C_word*)lf[62]+1 /* (set! scheme#exact->inexact ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9229,a[2]=((C_word)li59),tmp=(C_word)a,a+=3,tmp));
t63=C_mutate((C_word*)lf[63]+1 /* (set! scheme#abs ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9232,a[2]=((C_word)li60),tmp=(C_word)a,a+=3,tmp));
t64=C_mutate((C_word*)lf[64]+1 /* (set! scheme#+ ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_plus,a[2]=((C_word)li61),tmp=(C_word)a,a+=3,tmp));
t65=C_mutate((C_word*)lf[65]+1 /* (set! scheme#- ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_minus,a[2]=((C_word)li62),tmp=(C_word)a,a+=3,tmp));
t66=C_mutate((C_word*)lf[66]+1 /* (set! scheme#* ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_times,a[2]=((C_word)li63),tmp=(C_word)a,a+=3,tmp));
t67=C_mutate((C_word*)lf[67]+1 /* (set! scheme#quotient ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9238,a[2]=((C_word)li64),tmp=(C_word)a,a+=3,tmp));
t68=C_mutate((C_word*)lf[68]+1 /* (set! scheme#remainder ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9241,a[2]=((C_word)li65),tmp=(C_word)a,a+=3,tmp));
t69=C_mutate((C_word*)lf[69]+1 /* (set! scheme#modulo ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9244,a[2]=((C_word)li66),tmp=(C_word)a,a+=3,tmp));
t70=C_mutate((C_word*)lf[70]+1 /* (set! scheme#even? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9247,a[2]=((C_word)li67),tmp=(C_word)a,a+=3,tmp));
t71=C_mutate((C_word*)lf[71]+1 /* (set! scheme#odd? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9250,a[2]=((C_word)li68),tmp=(C_word)a,a+=3,tmp));
t72=C_mutate((C_word*)lf[72]+1 /* (set! scheme#= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_nequalp,a[2]=((C_word)li69),tmp=(C_word)a,a+=3,tmp));
t73=C_mutate((C_word*)lf[73]+1 /* (set! scheme#> ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_greaterp,a[2]=((C_word)li70),tmp=(C_word)a,a+=3,tmp));
t74=C_mutate((C_word*)lf[74]+1 /* (set! scheme#< ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_lessp,a[2]=((C_word)li71),tmp=(C_word)a,a+=3,tmp));
t75=C_mutate((C_word*)lf[75]+1 /* (set! scheme#>= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_greater_or_equal_p,a[2]=((C_word)li72),tmp=(C_word)a,a+=3,tmp));
t76=C_mutate((C_word*)lf[76]+1 /* (set! scheme#<= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_less_or_equal_p,a[2]=((C_word)li73),tmp=(C_word)a,a+=3,tmp));
t77=C_mutate((C_word*)lf[77]+1 /* (set! scheme#number? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9258,a[2]=((C_word)li74),tmp=(C_word)a,a+=3,tmp));
t78=C_mutate((C_word*)lf[78]+1 /* (set! scheme#complex? ...) */,*((C_word*)lf[77]+1));
t79=C_mutate((C_word*)lf[79]+1 /* (set! scheme#real? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9262,a[2]=((C_word)li75),tmp=(C_word)a,a+=3,tmp));
t80=C_mutate((C_word*)lf[80]+1 /* (set! scheme#rational? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9265,a[2]=((C_word)li76),tmp=(C_word)a,a+=3,tmp));
t81=C_mutate((C_word*)lf[81]+1 /* (set! scheme#integer? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9268,a[2]=((C_word)li77),tmp=(C_word)a,a+=3,tmp));
t82=C_mutate((C_word*)lf[82]+1 /* (set! scheme#exact? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9271,a[2]=((C_word)li78),tmp=(C_word)a,a+=3,tmp));
t83=C_mutate((C_word*)lf[83]+1 /* (set! scheme#inexact? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9274,a[2]=((C_word)li79),tmp=(C_word)a,a+=3,tmp));
t84=C_mutate((C_word*)lf[84]+1 /* (set! scheme#zero? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9277,a[2]=((C_word)li80),tmp=(C_word)a,a+=3,tmp));
t85=C_mutate((C_word*)lf[85]+1 /* (set! scheme#positive? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9280,a[2]=((C_word)li81),tmp=(C_word)a,a+=3,tmp));
t86=C_mutate((C_word*)lf[86]+1 /* (set! scheme#negative? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9283,a[2]=((C_word)li82),tmp=(C_word)a,a+=3,tmp));
t87=C_mutate((C_word*)lf[87]+1 /* (set! scheme#number->string ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_number_to_string,a[2]=((C_word)li83),tmp=(C_word)a,a+=3,tmp));
t88=C_mutate((C_word*)lf[88]+1 /* (set! scheme#symbol? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9287,a[2]=((C_word)li84),tmp=(C_word)a,a+=3,tmp));
t89=C_mutate((C_word*)lf[89]+1 /* (set! scheme#vector? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9290,a[2]=((C_word)li85),tmp=(C_word)a,a+=3,tmp));
t90=C_mutate((C_word*)lf[90]+1 /* (set! scheme#vector-length ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9293,a[2]=((C_word)li86),tmp=(C_word)a,a+=3,tmp));
t91=C_mutate((C_word*)lf[91]+1 /* (set! scheme#vector-ref ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9296,a[2]=((C_word)li87),tmp=(C_word)a,a+=3,tmp));
t92=C_mutate((C_word*)lf[92]+1 /* (set! scheme#vector-set! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9299,a[2]=((C_word)li88),tmp=(C_word)a,a+=3,tmp));
t93=C_set_block_item(lf[93] /* scheme#make-vector */,0,C_SCHEME_UNDEFINED);
t94=C_set_block_item(lf[94] /* scheme#list->vector */,0,C_SCHEME_UNDEFINED);
t95=C_set_block_item(lf[95] /* scheme#vector->list */,0,C_SCHEME_UNDEFINED);
t96=C_set_block_item(lf[96] /* scheme#vector */,0,C_SCHEME_UNDEFINED);
t97=C_set_block_item(lf[97] /* scheme#vector-fill! */,0,C_SCHEME_UNDEFINED);
t98=C_mutate((C_word*)lf[98]+1 /* (set! scheme#char? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9307,a[2]=((C_word)li89),tmp=(C_word)a,a+=3,tmp));
t99=C_mutate((C_word*)lf[99]+1 /* (set! scheme#char->integer ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9310,a[2]=((C_word)li90),tmp=(C_word)a,a+=3,tmp));
t100=C_mutate((C_word*)lf[101]+1 /* (set! scheme#integer->char ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9317,a[2]=((C_word)li91),tmp=(C_word)a,a+=3,tmp));
t101=C_mutate((C_word*)lf[104]+1 /* (set! scheme#char=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9324,a[2]=((C_word)li92),tmp=(C_word)a,a+=3,tmp));
t102=C_mutate((C_word*)lf[105]+1 /* (set! scheme#char>? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9327,a[2]=((C_word)li93),tmp=(C_word)a,a+=3,tmp));
t103=C_mutate((C_word*)lf[106]+1 /* (set! scheme#char<? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9330,a[2]=((C_word)li94),tmp=(C_word)a,a+=3,tmp));
t104=C_mutate((C_word*)lf[107]+1 /* (set! scheme#char>=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9333,a[2]=((C_word)li95),tmp=(C_word)a,a+=3,tmp));
t105=C_mutate((C_word*)lf[108]+1 /* (set! scheme#char<=? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9336,a[2]=((C_word)li96),tmp=(C_word)a,a+=3,tmp));
t106=C_mutate((C_word*)lf[109]+1 /* (set! scheme#char-upcase ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9339,a[2]=((C_word)li97),tmp=(C_word)a,a+=3,tmp));
t107=C_mutate((C_word*)lf[111]+1 /* (set! scheme#char-downcase ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9345,a[2]=((C_word)li98),tmp=(C_word)a,a+=3,tmp));
t108=C_set_block_item(lf[113] /* scheme#char-ci=? */,0,C_SCHEME_UNDEFINED);
t109=C_set_block_item(lf[114] /* scheme#char-ci>? */,0,C_SCHEME_UNDEFINED);
t110=C_set_block_item(lf[115] /* scheme#char-ci<? */,0,C_SCHEME_UNDEFINED);
t111=C_set_block_item(lf[116] /* scheme#char-ci>=? */,0,C_SCHEME_UNDEFINED);
t112=C_set_block_item(lf[117] /* scheme#char-ci<=? */,0,C_SCHEME_UNDEFINED);
t113=C_mutate((C_word*)lf[118]+1 /* (set! scheme#char-upper-case? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9356,a[2]=((C_word)li99),tmp=(C_word)a,a+=3,tmp));
t114=C_mutate((C_word*)lf[120]+1 /* (set! scheme#char-lower-case? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9362,a[2]=((C_word)li100),tmp=(C_word)a,a+=3,tmp));
t115=C_mutate((C_word*)lf[122]+1 /* (set! scheme#char-numeric? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9368,a[2]=((C_word)li101),tmp=(C_word)a,a+=3,tmp));
t116=C_mutate((C_word*)lf[124]+1 /* (set! scheme#char-whitespace? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9374,a[2]=((C_word)li102),tmp=(C_word)a,a+=3,tmp));
t117=C_mutate((C_word*)lf[126]+1 /* (set! scheme#char-alphabetic? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9380,a[2]=((C_word)li103),tmp=(C_word)a,a+=3,tmp));
t118=C_mutate((C_word*)lf[128]+1 /* (set! scheme#procedure? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9386,a[2]=((C_word)li104),tmp=(C_word)a,a+=3,tmp));
t119=C_mutate((C_word*)lf[129]+1 /* (set! scheme#apply ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_apply,a[2]=((C_word)li105),tmp=(C_word)a,a+=3,tmp));
t120=C_mutate((C_word*)lf[130]+1 /* (set! scheme#values ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_values,a[2]=((C_word)li106),tmp=(C_word)a,a+=3,tmp));
t121=C_mutate((C_word*)lf[131]+1 /* (set! scheme#call-with-values ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_call_with_values,a[2]=((C_word)li107),tmp=(C_word)a,a+=3,tmp));
t122=C_set_block_item(lf[132] /* scheme#call-with-current-continuation */,0,C_SCHEME_UNDEFINED);
t123=C_mutate((C_word*)lf[133]+1 /* (set! scheme#input-port? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9393,a[2]=((C_word)li108),tmp=(C_word)a,a+=3,tmp));
t124=C_mutate((C_word*)lf[134]+1 /* (set! scheme#output-port? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9399,a[2]=((C_word)li109),tmp=(C_word)a,a+=3,tmp));
t125=C_set_block_item(lf[135] /* scheme#current-input-port */,0,C_SCHEME_UNDEFINED);
t126=C_set_block_item(lf[136] /* scheme#current-output-port */,0,C_SCHEME_UNDEFINED);
t127=C_set_block_item(lf[137] /* scheme#open-input-file */,0,C_SCHEME_UNDEFINED);
t128=C_set_block_item(lf[138] /* scheme#open-output-file */,0,C_SCHEME_UNDEFINED);
t129=C_set_block_item(lf[139] /* scheme#close-input-port */,0,C_SCHEME_UNDEFINED);
t130=C_set_block_item(lf[140] /* scheme#close-output-port */,0,C_SCHEME_UNDEFINED);
t131=C_set_block_item(lf[141] /* scheme#call-with-input-file */,0,C_SCHEME_UNDEFINED);
t132=C_set_block_item(lf[142] /* scheme#call-with-output-file */,0,C_SCHEME_UNDEFINED);
t133=C_set_block_item(lf[143] /* scheme#with-input-from-file */,0,C_SCHEME_UNDEFINED);
t134=C_set_block_item(lf[144] /* scheme#with-output-to-file */,0,C_SCHEME_UNDEFINED);
t135=C_mutate((C_word*)lf[145]+1 /* (set! scheme#eof-object? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9415,a[2]=((C_word)li110),tmp=(C_word)a,a+=3,tmp));
t136=C_set_block_item(lf[146] /* scheme#char-ready? */,0,C_SCHEME_UNDEFINED);
t137=C_set_block_item(lf[147] /* scheme#read-char */,0,C_SCHEME_UNDEFINED);
t138=C_set_block_item(lf[148] /* scheme#peek-char */,0,C_SCHEME_UNDEFINED);
t139=C_set_block_item(lf[149] /* scheme#read */,0,C_SCHEME_UNDEFINED);
t140=C_set_block_item(lf[150] /* scheme#write-char */,0,C_SCHEME_UNDEFINED);
t141=C_set_block_item(lf[151] /* scheme#newline */,0,C_SCHEME_UNDEFINED);
t142=C_set_block_item(lf[152] /* scheme#write */,0,C_SCHEME_UNDEFINED);
t143=C_set_block_item(lf[153] /* scheme#display */,0,C_SCHEME_UNDEFINED);
t144=C_mutate((C_word*)lf[154]+1 /* (set! scheme#eval ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9426,a[2]=((C_word)li111),tmp=(C_word)a,a+=3,tmp));
t145=C_mutate((C_word*)lf[158]+1 /* (set! scheme#interaction-environment ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9432,a[2]=((C_word)li112),tmp=(C_word)a,a+=3,tmp));
t146=C_mutate((C_word*)lf[161]+1 /* (set! scheme#scheme-report-environment ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9438,a[2]=((C_word)li113),tmp=(C_word)a,a+=3,tmp));
t147=C_mutate((C_word*)lf[164]+1 /* (set! scheme#null-environment ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9444,a[2]=((C_word)li114),tmp=(C_word)a,a+=3,tmp));
t148=C_mutate((C_word*)lf[167]+1 /* (set! scheme#load ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9450,a[2]=((C_word)li115),tmp=(C_word)a,a+=3,tmp));
t149=C_set_block_item(lf[170] /* scheme#for-each */,0,C_SCHEME_UNDEFINED);
t150=C_set_block_item(lf[171] /* scheme#map */,0,C_SCHEME_UNDEFINED);
t151=C_set_block_item(lf[172] /* scheme#dynamic-wind */,0,C_SCHEME_UNDEFINED);
t152=C_a_i_provide(&a,1,lf[173]);
t153=C_mutate((C_word*)lf[174]+1 /* (set! chicken.base#fixnum? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9459,a[2]=((C_word)li116),tmp=(C_word)a,a+=3,tmp));
t154=C_mutate((C_word*)lf[175]+1 /* (set! chicken.base#flonum? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9462,a[2]=((C_word)li117),tmp=(C_word)a,a+=3,tmp));
t155=C_mutate((C_word*)lf[176]+1 /* (set! chicken.base#bignum? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9465,a[2]=((C_word)li118),tmp=(C_word)a,a+=3,tmp));
t156=C_mutate((C_word*)lf[177]+1 /* (set! chicken.base#ratnum? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9468,a[2]=((C_word)li119),tmp=(C_word)a,a+=3,tmp));
t157=C_mutate((C_word*)lf[178]+1 /* (set! chicken.base#cplxnum? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9471,a[2]=((C_word)li120),tmp=(C_word)a,a+=3,tmp));
t158=C_mutate((C_word*)lf[179]+1 /* (set! chicken.base#exact-integer? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9474,a[2]=((C_word)li121),tmp=(C_word)a,a+=3,tmp));
t159=C_mutate((C_word*)lf[180]+1 /* (set! chicken.base#quotient&remainder ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_quotient_and_remainder,a[2]=((C_word)li122),tmp=(C_word)a,a+=3,tmp));
t160=C_mutate((C_word*)lf[181]+1 /* (set! chicken.base#quotient&modulo ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9478,a[2]=((C_word)li125),tmp=(C_word)a,a+=3,tmp));
t161=C_mutate((C_word*)lf[182]+1 /* (set! chicken.base#finite? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9525,a[2]=((C_word)li126),tmp=(C_word)a,a+=3,tmp));
t162=C_mutate((C_word*)lf[183]+1 /* (set! chicken.base#infinite? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9528,a[2]=((C_word)li127),tmp=(C_word)a,a+=3,tmp));
t163=C_mutate((C_word*)lf[184]+1 /* (set! chicken.base#nan? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9531,a[2]=((C_word)li128),tmp=(C_word)a,a+=3,tmp));
t164=C_mutate((C_word*)lf[185]+1 /* (set! chicken.base#signum ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)C_signum,a[2]=((C_word)li129),tmp=(C_word)a,a+=3,tmp));
t165=C_set_block_item(lf[186] /* chicken.base#get-call-chain */,0,C_SCHEME_UNDEFINED);
t166=C_set_block_item(lf[187] /* chicken.base#print-call-chain */,0,C_SCHEME_UNDEFINED);
t167=C_set_block_item(lf[188] /* chicken.base#print */,0,C_SCHEME_UNDEFINED);
t168=C_set_block_item(lf[189] /* chicken.base#print* */,0,C_SCHEME_UNDEFINED);
t169=C_mutate((C_word*)lf[190]+1 /* (set! chicken.base#add1 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9539,a[2]=((C_word)li130),tmp=(C_word)a,a+=3,tmp));
t170=C_mutate((C_word*)lf[191]+1 /* (set! chicken.base#sub1 ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9545,a[2]=((C_word)li131),tmp=(C_word)a,a+=3,tmp));
t171=C_set_block_item(lf[192] /* chicken.base#current-error-port */,0,C_SCHEME_UNDEFINED);
t172=C_mutate((C_word*)lf[193]+1 /* (set! chicken.base#error ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9552,a[2]=((C_word)li132),tmp=(C_word)a,a+=3,tmp));
t173=C_mutate((C_word*)lf[196]+1 /* (set! chicken.base#void ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9567,a[2]=((C_word)li133),tmp=(C_word)a,a+=3,tmp));
t174=C_set_block_item(lf[197] /* chicken.base#sleep */,0,C_SCHEME_UNDEFINED);
t175=C_set_block_item(lf[198] /* chicken.base#call/cc */,0,C_SCHEME_UNDEFINED);
t176=C_set_block_item(lf[199] /* chicken.base#char-name */,0,C_SCHEME_UNDEFINED);
t177=C_set_block_item(lf[200] /* chicken.base#getter-with-setter */,0,C_SCHEME_UNDEFINED);
t178=C_set_block_item(lf[201] /* chicken.base#make-parameter */,0,C_SCHEME_UNDEFINED);
t179=C_set_block_item(lf[202] /* chicken.base#procedure-information */,0,C_SCHEME_UNDEFINED);
t180=C_set_block_item(lf[203] /* chicken.base#setter */,0,C_SCHEME_UNDEFINED);
t181=C_set_block_item(lf[204] /* chicken.base#record-printer */,0,C_SCHEME_UNDEFINED);
t182=C_set_block_item(lf[205] /* chicken.base#set-record-printer! */,0,C_SCHEME_UNDEFINED);
t183=C_set_block_item(lf[206] /* chicken.base#vector-copy! */,0,C_SCHEME_UNDEFINED);
t184=C_set_block_item(lf[207] /* chicken.base#subvector */,0,C_SCHEME_UNDEFINED);
t185=C_set_block_item(lf[208] /* chicken.base#vector-resize */,0,C_SCHEME_UNDEFINED);
t186=C_set_block_item(lf[209] /* chicken.base#port? */,0,C_SCHEME_UNDEFINED);
t187=C_set_block_item(lf[210] /* chicken.base#port-closed? */,0,C_SCHEME_UNDEFINED);
t188=C_set_block_item(lf[211] /* chicken.base#input-port-open? */,0,C_SCHEME_UNDEFINED);
t189=C_set_block_item(lf[212] /* chicken.base#output-port-open? */,0,C_SCHEME_UNDEFINED);
t190=C_set_block_item(lf[213] /* chicken.base#get-output-string */,0,C_SCHEME_UNDEFINED);
t191=C_set_block_item(lf[214] /* chicken.base#open-input-string */,0,C_SCHEME_UNDEFINED);
t192=C_set_block_item(lf[215] /* chicken.base#open-output-string */,0,C_SCHEME_UNDEFINED);
t193=C_set_block_item(lf[216] /* chicken.base#flush-output */,0,C_SCHEME_UNDEFINED);
t194=C_mutate((C_word*)lf[217]+1 /* (set! chicken.base#promise? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9590,a[2]=((C_word)li134),tmp=(C_word)a,a+=3,tmp));
t195=C_mutate((C_word*)lf[219]+1 /* (set! ##sys#make-promise ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9596,a[2]=((C_word)li135),tmp=(C_word)a,a+=3,tmp));
t196=C_mutate((C_word*)lf[220]+1 /* (set! chicken.base#make-promise ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9602,a[2]=((C_word)li137),tmp=(C_word)a,a+=3,tmp));
t197=C_mutate((C_word*)lf[221]+1 /* (set! chicken.base#foldl ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9617,a[2]=((C_word)li139),tmp=(C_word)a,a+=3,tmp));
t198=C_mutate((C_word*)lf[223]+1 /* (set! chicken.base#foldr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9654,a[2]=((C_word)li141),tmp=(C_word)a,a+=3,tmp));
t199=C_set_block_item(lf[225] /* chicken.base#implicit-exit-handler */,0,C_SCHEME_UNDEFINED);
t200=C_set_block_item(lf[226] /* chicken.base#exit-handler */,0,C_SCHEME_UNDEFINED);
t201=C_set_block_item(lf[227] /* chicken.base#cleanup-tasks */,0,C_SCHEME_END_OF_LIST);
t202=C_mutate((C_word*)lf[228]+1 /* (set! chicken.base#on-exit ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9694,a[2]=((C_word)li142),tmp=(C_word)a,a+=3,tmp));
t203=C_mutate((C_word*)lf[229]+1 /* (set! chicken.base#exit ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9701,a[2]=((C_word)li143),tmp=(C_word)a,a+=3,tmp));
t204=C_mutate((C_word*)lf[230]+1 /* (set! chicken.base#emergency-exit ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9719,a[2]=((C_word)li144),tmp=(C_word)a,a+=3,tmp));
t205=C_set_block_item(lf[232] /* chicken.base#case-sensitive */,0,C_SCHEME_UNDEFINED);
t206=C_set_block_item(lf[233] /* chicken.base#keyword-style */,0,C_SCHEME_UNDEFINED);
t207=C_set_block_item(lf[234] /* chicken.base#parentheses-synonyms */,0,C_SCHEME_UNDEFINED);
t208=C_set_block_item(lf[235] /* chicken.base#symbol-escape */,0,C_SCHEME_UNDEFINED);
t209=C_mutate((C_word*)lf[236]+1 /* (set! chicken.base#identity ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9738,a[2]=((C_word)li145),tmp=(C_word)a,a+=3,tmp));
t210=C_mutate((C_word*)lf[237]+1 /* (set! chicken.base#conjoin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9741,a[2]=((C_word)li148),tmp=(C_word)a,a+=3,tmp));
t211=C_mutate((C_word*)lf[238]+1 /* (set! chicken.base#disjoin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9774,a[2]=((C_word)li151),tmp=(C_word)a,a+=3,tmp));
t212=C_mutate((C_word*)lf[239]+1 /* (set! chicken.base#constantly ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9811,a[2]=((C_word)li154),tmp=(C_word)a,a+=3,tmp));
t213=C_mutate((C_word*)lf[240]+1 /* (set! chicken.base#flip ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9832,a[2]=((C_word)li156),tmp=(C_word)a,a+=3,tmp));
t214=C_mutate((C_word*)lf[241]+1 /* (set! chicken.base#complement ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9840,a[2]=((C_word)li158),tmp=(C_word)a,a+=3,tmp));
t215=C_mutate((C_word*)lf[242]+1 /* (set! chicken.base#compose ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9852,a[2]=((C_word)li162),tmp=(C_word)a,a+=3,tmp));
t216=C_mutate((C_word*)lf[243]+1 /* (set! chicken.base#o ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9888,a[2]=((C_word)li165),tmp=(C_word)a,a+=3,tmp));
t217=C_mutate((C_word*)lf[244]+1 /* (set! chicken.base#list-of? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9927,a[2]=((C_word)li168),tmp=(C_word)a,a+=3,tmp));
t218=C_mutate((C_word*)lf[245]+1 /* (set! chicken.base#each ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9971,a[2]=((C_word)li172),tmp=(C_word)a,a+=3,tmp));
t219=C_mutate((C_word*)lf[247]+1 /* (set! chicken.base#bwp-object? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10027,a[2]=((C_word)li173),tmp=(C_word)a,a+=3,tmp));
t220=C_mutate((C_word*)lf[248]+1 /* (set! chicken.base#weak-cons ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10030,a[2]=((C_word)li174),tmp=(C_word)a,a+=3,tmp));
t221=C_mutate((C_word*)lf[249]+1 /* (set! chicken.base#weak-pair? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10033,a[2]=((C_word)li175),tmp=(C_word)a,a+=3,tmp));
t222=C_mutate((C_word*)lf[250]+1 /* (set! chicken.base#atom? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10036,a[2]=((C_word)li176),tmp=(C_word)a,a+=3,tmp));
t223=C_mutate((C_word*)lf[251]+1 /* (set! chicken.base#tail? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10039,a[2]=((C_word)li178),tmp=(C_word)a,a+=3,tmp));
t224=C_mutate((C_word*)lf[253]+1 /* (set! chicken.base#intersperse ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10067,a[2]=((C_word)li180),tmp=(C_word)a,a+=3,tmp));
t225=C_mutate((C_word*)lf[254]+1 /* (set! chicken.base#butlast ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10100,a[2]=((C_word)li182),tmp=(C_word)a,a+=3,tmp));
t226=C_mutate((C_word*)lf[256]+1 /* (set! chicken.base#flatten ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10132,a[2]=((C_word)li184),tmp=(C_word)a,a+=3,tmp));
t227=C_mutate((C_word*)lf[257]+1 /* (set! chicken.base#join ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10173,a[2]=((C_word)li186),tmp=(C_word)a,a+=3,tmp));
t228=C_mutate((C_word*)lf[260]+1 /* (set! chicken.base#compress ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10230,a[2]=((C_word)li188),tmp=(C_word)a,a+=3,tmp));
t229=C_mutate((C_word*)lf[264]+1 /* (set! chicken.base#alist-update! ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10310,a[2]=((C_word)li191),tmp=(C_word)a,a+=3,tmp));
t230=C_mutate((C_word*)lf[265]+1 /* (set! chicken.base#alist-update ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10396,a[2]=((C_word)li193),tmp=(C_word)a,a+=3,tmp));
t231=C_mutate((C_word*)lf[269]+1 /* (set! chicken.base#alist-ref ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10500,a[2]=((C_word)li196),tmp=(C_word)a,a+=3,tmp));
t232=C_mutate((C_word*)lf[272]+1 /* (set! chicken.base#rassoc ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10612,a[2]=((C_word)li198),tmp=(C_word)a,a+=3,tmp));
t233=C_mutate(&lf[274] /* (set! maximal-string-length ...) */,C_unsigned_long_to_num(&a,C_HEADER_SIZE_MASK));
t234=C_a_i_provide(&a,1,lf[275]);
t235=C_set_block_item(lf[276] /* chicken.fixnum#most-positive-fixnum */,0,C_fix((C_word)C_MOST_POSITIVE_FIXNUM));
t236=C_set_block_item(lf[277] /* chicken.fixnum#most-negative-fixnum */,0,C_fix((C_word)C_MOST_NEGATIVE_FIXNUM));
t237=C_set_block_item(lf[278] /* chicken.fixnum#fixnum-bits */,0,C_fix((C_word)(C_WORD_SIZE - 1)));
t238=C_set_block_item(lf[279] /* chicken.fixnum#fixnum-precision */,0,C_fix((C_word)(C_WORD_SIZE - (1 + 1))));
t239=C_mutate((C_word*)lf[280]+1 /* (set! chicken.fixnum#fx+ ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10665,a[2]=((C_word)li199),tmp=(C_word)a,a+=3,tmp));
t240=C_mutate((C_word*)lf[281]+1 /* (set! chicken.fixnum#fx- ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10668,a[2]=((C_word)li200),tmp=(C_word)a,a+=3,tmp));
t241=C_mutate((C_word*)lf[282]+1 /* (set! chicken.fixnum#fx* ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10671,a[2]=((C_word)li201),tmp=(C_word)a,a+=3,tmp));
t242=C_mutate((C_word*)lf[283]+1 /* (set! chicken.fixnum#fx= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10674,a[2]=((C_word)li202),tmp=(C_word)a,a+=3,tmp));
t243=C_mutate((C_word*)lf[284]+1 /* (set! chicken.fixnum#fx> ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10680,a[2]=((C_word)li203),tmp=(C_word)a,a+=3,tmp));
t244=C_mutate((C_word*)lf[285]+1 /* (set! chicken.fixnum#fx< ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10683,a[2]=((C_word)li204),tmp=(C_word)a,a+=3,tmp));
t245=C_mutate((C_word*)lf[286]+1 /* (set! chicken.fixnum#fx>= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10686,a[2]=((C_word)li205),tmp=(C_word)a,a+=3,tmp));
t246=C_mutate((C_word*)lf[287]+1 /* (set! chicken.fixnum#fx<= ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10689,a[2]=((C_word)li206),tmp=(C_word)a,a+=3,tmp));
t247=C_mutate((C_word*)lf[288]+1 /* (set! chicken.fixnum#fxmin ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10692,a[2]=((C_word)li207),tmp=(C_word)a,a+=3,tmp));
t248=C_mutate((C_word*)lf[289]+1 /* (set! chicken.fixnum#fxmax ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10695,a[2]=((C_word)li208),tmp=(C_word)a,a+=3,tmp));
t249=C_mutate((C_word*)lf[290]+1 /* (set! chicken.fixnum#fxneg ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10698,a[2]=((C_word)li209),tmp=(C_word)a,a+=3,tmp));
t250=C_mutate((C_word*)lf[291]+1 /* (set! chicken.fixnum#fxand ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10701,a[2]=((C_word)li210),tmp=(C_word)a,a+=3,tmp));
t251=C_mutate((C_word*)lf[292]+1 /* (set! chicken.fixnum#fxior ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10704,a[2]=((C_word)li211),tmp=(C_word)a,a+=3,tmp));
t252=C_mutate((C_word*)lf[293]+1 /* (set! chicken.fixnum#fxxor ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10707,a[2]=((C_word)li212),tmp=(C_word)a,a+=3,tmp));
t253=C_mutate((C_word*)lf[294]+1 /* (set! chicken.fixnum#fxnot ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10710,a[2]=((C_word)li213),tmp=(C_word)a,a+=3,tmp));
t254=C_mutate((C_word*)lf[295]+1 /* (set! chicken.fixnum#fxshl ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10713,a[2]=((C_word)li214),tmp=(C_word)a,a+=3,tmp));
t255=C_mutate((C_word*)lf[296]+1 /* (set! chicken.fixnum#fxshr ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10716,a[2]=((C_word)li215),tmp=(C_word)a,a+=3,tmp));
t256=C_mutate((C_word*)lf[297]+1 /* (set! chicken.fixnum#fxodd? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10719,a[2]=((C_word)li216),tmp=(C_word)a,a+=3,tmp));
t257=C_mutate((C_word*)lf[298]+1 /* (set! chicken.fixnum#fxeven? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10722,a[2]=((C_word)li217),tmp=(C_word)a,a+=3,tmp));
t258=C_mutate((C_word*)lf[299]+1 /* (set! chicken.fixnum#fxlen ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10725,a[2]=((C_word)li218),tmp=(C_word)a,a+=3,tmp));
t259=C_mutate((C_word*)lf[300]+1 /* (set! chicken.fixnum#fx/ ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10728,a[2]=((C_word)li219),tmp=(C_word)a,a+=3,tmp));
t260=C_mutate((C_word*)lf[301]+1 /* (set! chicken.fixnum#fxgcd ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10731,a[2]=((C_word)li220),tmp=(C_word)a,a+=3,tmp));
t261=C_mutate((C_word*)lf[302]+1 /* (set! chicken.fixnum#fxmod ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10734,a[2]=((C_word)li221),tmp=(C_word)a,a+=3,tmp));
t262=C_mutate((C_word*)lf[303]+1 /* (set! chicken.fixnum#fxrem ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10737,a[2]=((C_word)li222),tmp=(C_word)a,a+=3,tmp));
t263=C_mutate((C_word*)lf[304]+1 /* (set! chicken.fixnum#fx+? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10740,a[2]=((C_word)li223),tmp=(C_word)a,a+=3,tmp));
t264=C_mutate((C_word*)lf[305]+1 /* (set! chicken.fixnum#fx-? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10743,a[2]=((C_word)li224),tmp=(C_word)a,a+=3,tmp));
t265=C_mutate((C_word*)lf[306]+1 /* (set! chicken.fixnum#fx*? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10746,a[2]=((C_word)li225),tmp=(C_word)a,a+=3,tmp));
t266=C_mutate((C_word*)lf[307]+1 /* (set! chicken.fixnum#fx/? ...) */,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10749,a[2]=((C_word)li226),tmp=(C_word)a,a+=3,tmp));
t267=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10753,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t267;
C_library_toplevel(2,av2);}}

/* scheme#not in k8834 */
static void C_ccall f_8838(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8838,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_not(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#boolean? in k8834 */
static void C_ccall f_8841(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8841,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_booleanp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#eq? in k8834 */
static void C_ccall f_8844(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8844,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_eqp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#eqv? in k8834 */
static void C_ccall f_8847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8847,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_eqvp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#equal? in k8834 */
static void C_ccall f_8850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8850,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_equalp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#pair? in k8834 */
static void C_ccall f_8853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8853,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_pairp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cons in k8834 */
static void C_ccall f_8856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_8856,c,av);}
a=C_alloc(3);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#car in k8834 */
static void C_ccall f_8859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8859,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cdr in k8834 */
static void C_ccall f_8862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8862,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#set-car! in k8834 */
static void C_ccall f_8865(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8865,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#set-cdr! in k8834 */
static void C_ccall f_8868(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8868,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_cdr(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#cadr in k8834 */
static void C_ccall f_8871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8871,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cadr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#caddr in k8834 */
static void C_ccall f_8874(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8874,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_caddr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cadddr in k8834 */
static void C_ccall f_8877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8877,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cadddr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cddddr in k8834 */
static void C_ccall f_8880(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8880,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cddddr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#caar in k8834 */
static void C_ccall f_8883(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8883,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_caar(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cdar in k8834 */
static void C_ccall f_8886(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8886,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdar(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cddr in k8834 */
static void C_ccall f_8889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8889,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cddr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#caaar in k8834 */
static void C_ccall f_8892(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8892,c,av);}
t3=C_i_car(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_car(C_i_car(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#caadr in k8834 */
static void C_ccall f_8906(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8906,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_car(C_i_cadr(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cadar in k8834 */
static void C_ccall f_8913(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8913,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cadr(C_i_car(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cdaar in k8834 */
static void C_ccall f_8920(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8920,c,av);}
t3=C_i_car(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cdr(C_i_car(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#cdadr in k8834 */
static void C_ccall f_8934(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8934,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(C_i_cadr(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cddar in k8834 */
static void C_ccall f_8941(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8941,c,av);}
t3=C_i_car(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cdr(C_i_cdr(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#cdddr in k8834 */
static void C_ccall f_8955(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8955,c,av);}
t3=C_i_cdr(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cdr(C_i_cdr(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#caaaar in k8834 */
static void C_ccall f_8969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8969,c,av);}
t3=C_i_car(t2);
t4=C_i_car(t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_car(C_i_car(t4));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#caaadr in k8834 */
static void C_ccall f_8987(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8987,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_car(C_i_car(C_i_cadr(t2)));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#caadar in k8834 */
static void C_ccall f_8998(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8998,c,av);}
t3=C_i_car(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_car(C_i_cadr(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#caaddr in k8834 */
static void C_ccall f_9009(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9009,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_car(C_i_caddr(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cadaar in k8834 */
static void C_ccall f_9016(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9016,c,av);}
t3=C_i_car(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cadr(C_i_car(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#cadadr in k8834 */
static void C_ccall f_9027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9027,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cadr(C_i_cadr(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#caddar in k8834 */
static void C_ccall f_9031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9031,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_caddr(C_i_car(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cdaaar in k8834 */
static void C_ccall f_9038(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9038,c,av);}
t3=C_i_car(t2);
t4=C_i_car(t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_cdr(C_i_car(t4));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#cdaadr in k8834 */
static void C_ccall f_9056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9056,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(C_i_car(C_i_cadr(t2)));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cdadar in k8834 */
static void C_ccall f_9067(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9067,c,av);}
t3=C_i_car(t2);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cdr(C_i_cadr(t3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#cdaddr in k8834 */
static void C_ccall f_9078(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9078,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(C_i_caddr(t2));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cddaar in k8834 */
static void C_ccall f_9085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9085,c,av);}
t3=C_i_car(t2);
t4=C_i_car(t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_cdr(C_i_cdr(t4));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#cddadr in k8834 */
static void C_ccall f_9103(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9103,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(C_i_cdr(C_i_cadr(t2)));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#cdddar in k8834 */
static void C_ccall f_9114(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9114,c,av);}
t3=C_i_car(t2);
t4=C_i_cdr(t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_cdr(C_i_cdr(t4));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#null? in k8834 */
static void C_ccall f_9132(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9132,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_eqp(t2,C_SCHEME_END_OF_LIST);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#list in k8834 */
static void C_ccall f_9138(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_9138,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#length in k8834 */
static void C_ccall f_9141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9141,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_length(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#list-tail in k8834 */
static void C_ccall f_9144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9144,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_list_tail(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#list-ref in k8834 */
static void C_ccall f_9147(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9147,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_list_ref(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#reverse in k8834 */
static void C_ccall f_9150(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_9150,c,av);}
a=C_alloc(7);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9156,a[2]=t4,a[3]=t2,a[4]=((C_word)li44),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_9156(t6,t1,t2,C_SCHEME_END_OF_LIST);}

/* loop in scheme#reverse in k8834 */
static void C_fcall f_9156(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_9156,4,t0,t1,t2,t3);}
a=C_alloc(3);
t4=C_eqp(t2,C_SCHEME_END_OF_LIST);
if(C_truep(t4)){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
if(C_truep(C_i_pairp(t2))){
t5=C_slot(t2,C_fix(1));
t6=C_slot(t2,C_fix(0));
t7=C_a_i_cons(&a,2,t6,t3);
/* library.scm:320: loop */
t9=t1;
t10=t5;
t11=t7;
t1=t9;
t2=t10;
t3=t11;
goto loop;}
else{
/* library.scm:321: ##sys#error-not-a-proper-list */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[47]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[47]+1);
av2[1]=t1;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[48];
tp(4,av2);}}}}

/* scheme#memq in k8834 */
static void C_ccall f_9189(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9189,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_memq(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#memv in k8834 */
static void C_ccall f_9192(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9192,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_memv(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#member in k8834 */
static void C_ccall f_9195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9195,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_member(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#assq in k8834 */
static void C_ccall f_9198(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9198,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_assq(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#assv in k8834 */
static void C_ccall f_9201(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9201,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_assv(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#assoc in k8834 */
static void C_ccall f_9204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9204,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_assoc(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#list? in k8834 */
static void C_ccall f_9207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9207,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_listp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#string? in k8834 */
static void C_ccall f_9210(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9210,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_stringp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#string-length in k8834 */
static void C_ccall f_9213(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9213,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_string_length(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#string-ref in k8834 */
static void C_ccall f_9216(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9216,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_string_ref(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#string-set! in k8834 */
static void C_ccall f_9219(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9219,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_string_set(t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#string=? in k8834 */
static void C_ccall f_9222(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9222,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_string_equal_p(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#string-ci=? in k8834 */
static void C_ccall f_9225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9225,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_string_ci_equal_p(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#exact->inexact in k8834 */
static void C_ccall f_9229(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_9229,c,av);}
a=C_alloc(12);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_exact_to_inexact(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#abs in k8834 */
static void C_ccall f_9232(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,1)))){
C_save_and_reclaim((void *)f_9232,c,av);}
a=C_alloc(7);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_i_abs(&a,1,t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#quotient in k8834 */
static void C_ccall f_9238(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_9238,c,av);}
a=C_alloc(5);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_s_a_i_quotient(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#remainder in k8834 */
static void C_ccall f_9241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_9241,c,av);}
a=C_alloc(5);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_s_a_i_remainder(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#modulo in k8834 */
static void C_ccall f_9244(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,1)))){
C_save_and_reclaim((void *)f_9244,c,av);}
a=C_alloc(5);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_s_a_i_modulo(&a,2,t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#even? in k8834 */
static void C_ccall f_9247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9247,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_evenp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#odd? in k8834 */
static void C_ccall f_9250(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9250,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_oddp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#number? in k8834 */
static void C_ccall f_9258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9258,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_numberp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#real? in k8834 */
static void C_ccall f_9262(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9262,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_realp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#rational? in k8834 */
static void C_ccall f_9265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9265,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_rationalp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#integer? in k8834 */
static void C_ccall f_9268(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9268,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_integerp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#exact? in k8834 */
static void C_ccall f_9271(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9271,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_exactp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#inexact? in k8834 */
static void C_ccall f_9274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9274,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_inexactp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#zero? in k8834 */
static void C_ccall f_9277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9277,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_zerop(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#positive? in k8834 */
static void C_ccall f_9280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9280,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_positivep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#negative? in k8834 */
static void C_ccall f_9283(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9283,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_negativep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#symbol? in k8834 */
static void C_ccall f_9287(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9287,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_symbolp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#vector? in k8834 */
static void C_ccall f_9290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9290,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_vectorp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#vector-length in k8834 */
static void C_ccall f_9293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9293,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_vector_length(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#vector-ref in k8834 */
static void C_ccall f_9296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9296,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_vector_ref(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#vector-set! in k8834 */
static void C_ccall f_9299(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9299,c,av);}
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_vector_set(t2,t3,t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* scheme#char? in k8834 */
static void C_ccall f_9307(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9307,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_charp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#char->integer in k8834 */
static void C_ccall f_9310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9310,c,av);}
t3=C_i_check_char_2(t2,lf[100]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_fix(C_character_code(t2));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#integer->char in k8834 */
static void C_ccall f_9317(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9317,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9321,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:461: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[103];
tp(4,av2);}}

/* k9319 in scheme#integer->char in k8834 */
static void C_ccall f_9321(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9321,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_make_character(C_unfix(((C_word*)t0)[3]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* scheme#char=? in k8834 */
static void C_ccall f_9324(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9324,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_char_equalp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char>? in k8834 */
static void C_ccall f_9327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9327,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_char_greaterp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char<? in k8834 */
static void C_ccall f_9330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9330,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_char_lessp(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char>=? in k8834 */
static void C_ccall f_9333(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9333,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_char_greater_or_equal_p(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char<=? in k8834 */
static void C_ccall f_9336(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9336,c,av);}
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_char_less_or_equal_p(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-upcase in k8834 */
static void C_ccall f_9339(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9339,c,av);}
t3=C_i_check_char_2(t2,lf[110]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_upcase(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-downcase in k8834 */
static void C_ccall f_9345(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9345,c,av);}
t3=C_i_check_char_2(t2,lf[112]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_downcase(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-upper-case? in k8834 */
static void C_ccall f_9356(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9356,c,av);}
t3=C_i_check_char_2(t2,lf[119]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_upper_casep(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-lower-case? in k8834 */
static void C_ccall f_9362(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9362,c,av);}
t3=C_i_check_char_2(t2,lf[121]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_lower_casep(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-numeric? in k8834 */
static void C_ccall f_9368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9368,c,av);}
t3=C_i_check_char_2(t2,lf[123]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_numericp(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-whitespace? in k8834 */
static void C_ccall f_9374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9374,c,av);}
t3=C_i_check_char_2(t2,lf[125]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_whitespacep(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#char-alphabetic? in k8834 */
static void C_ccall f_9380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9380,c,av);}
t3=C_i_check_char_2(t2,lf[127]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_char_alphabeticp(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* scheme#procedure? in k8834 */
static void C_ccall f_9386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9386,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_closurep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#input-port? in k8834 */
static void C_ccall f_9393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9393,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(C_blockp(t2))?C_input_portp(t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#output-port? in k8834 */
static void C_ccall f_9399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9399,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(C_blockp(t2))?C_output_portp(t2):C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#eof-object? in k8834 */
static void C_ccall f_9415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9415,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_eofp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* scheme#eval in k8834 */
static void C_ccall f_9426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9426,c,av);}
/* library.scm:554: ##sys#error */
t3=*((C_word*)lf[155]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[156];
av2[3]=lf[157];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* scheme#interaction-environment in k8834 */
static void C_ccall f_9432(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9432,c,av);}
/* library.scm:557: ##sys#error */
t2=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=lf[159];
av2[3]=lf[160];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* scheme#scheme-report-environment in k8834 */
static void C_ccall f_9438(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9438,c,av);}
/* library.scm:560: ##sys#error */
t3=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[162];
av2[3]=lf[163];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* scheme#null-environment in k8834 */
static void C_ccall f_9444(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9444,c,av);}
/* library.scm:563: ##sys#error */
t2=*((C_word*)lf[155]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=lf[165];
av2[3]=lf[166];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* scheme#load in k8834 */
static void C_ccall f_9450(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9450,c,av);}
/* library.scm:566: ##sys#error */
t3=*((C_word*)lf[155]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[168];
av2[3]=lf[169];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* chicken.base#fixnum? in k8834 */
static void C_ccall f_9459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9459,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_fixnump(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#flonum? in k8834 */
static void C_ccall f_9462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9462,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_flonump(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#bignum? in k8834 */
static void C_ccall f_9465(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9465,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_bignump(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#ratnum? in k8834 */
static void C_ccall f_9468(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9468,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_ratnump(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#cplxnum? in k8834 */
static void C_ccall f_9471(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9471,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cplxnump(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#exact-integer? in k8834 */
static void C_ccall f_9474(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9474,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_exact_integerp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#quotient&modulo in k8834 */
static void C_ccall f_9478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_9478,c,av);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9484,a[2]=t2,a[3]=t3,a[4]=((C_word)li123),tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9490,a[2]=t3,a[3]=((C_word)li124),tmp=(C_word)a,a+=4,tmp);
/* library.scm:627: scheme#call-with-values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t4;
av2[3]=t5;
C_call_with_values(4,av2);}}

/* a9483 in chicken.base#quotient&modulo in k8834 */
static void C_ccall f_9484(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9484,c,av);}
/* library.scm:627: quotient&remainder */
t2=*((C_word*)lf[180]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a9489 in chicken.base#quotient&modulo in k8834 */
static void C_ccall f_9490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(29,c,3)))){
C_save_and_reclaim((void *)f_9490,c,av);}
a=C_alloc(29);
if(C_truep(C_i_positivep(((C_word*)t0)[2]))){
if(C_truep(C_i_negativep(t3))){
t4=C_s_a_i_plus(&a,2,t3,((C_word*)t0)[2]);
/* library.scm:631: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=t4;
C_values(4,av2);}}
else{
/* library.scm:632: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
C_values(4,av2);}}}
else{
if(C_truep(C_i_positivep(t3))){
t4=C_s_a_i_plus(&a,2,t3,((C_word*)t0)[2]);
/* library.scm:634: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=t4;
C_values(4,av2);}}
else{
/* library.scm:635: scheme#values */{
C_word *av2=av;
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
C_values(4,av2);}}}}

/* chicken.base#finite? in k8834 */
static void C_ccall f_9525(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9525,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_finitep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#infinite? in k8834 */
static void C_ccall f_9528(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9528,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_infinitep(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#nan? in k8834 */
static void C_ccall f_9531(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9531,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_nanp(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#add1 in k8834 */
static void C_ccall f_9539(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_9539,c,av);}
a=C_alloc(29);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_i_plus(&a,2,t2,C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#sub1 in k8834 */
static void C_ccall f_9545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_9545,c,av);}
a=C_alloc(29);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_s_a_i_minus(&a,2,t2,C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#error in k8834 */
static void C_ccall f_9552(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,4)))){
C_save_and_reclaim((void*)f_9552,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
if(C_truep(C_i_pairp(t2))){{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=0;
av2[1]=t1;
av2[2]=C_fast_retrieve(lf[194]);
av2[3]=lf[195];
av2[4]=t2;
C_apply(5,av2);}}
else{
/* library.scm:656: ##sys#signal-hook */
t3=C_fast_retrieve(lf[194]);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=lf[195];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* chicken.base#void in k8834 */
static void C_ccall f_9567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9567,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#promise? in k8834 */
static void C_ccall f_9590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9590,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_structurep(t2,lf[218]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* ##sys#make-promise in k8834 */
static void C_ccall f_9596(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_9596,c,av);}
a=C_alloc(3);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_record2(&a,2,lf[218],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#make-promise in k8834 */
static void C_ccall f_9602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_9602,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9609,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:702: promise? */
t4=*((C_word*)lf[217]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k9607 in chicken.base#make-promise in k8834 */
static void C_ccall f_9609(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_9609,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9614,a[2]=((C_word*)t0)[3],a[3]=((C_word)li136),tmp=(C_word)a,a+=4,tmp);
/* library.scm:703: ##sys#make-promise */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[219]+1));
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=*((C_word*)lf[219]+1);
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
tp(3,av2);}}}

/* a9613 in k9607 in chicken.base#make-promise in k8834 */
static void C_ccall f_9614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9614,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#foldl in k8834 */
static void C_ccall f_9617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_9617,c,av);}
a=C_alloc(7);
t5=C_i_check_list_2(t4,lf[222]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9626,a[2]=t7,a[3]=t2,a[4]=((C_word)li138),tmp=(C_word)a,a+=5,tmp));
t9=((C_word*)t7)[1];
f_9626(t9,t1,t4,t3);}

/* loop in chicken.base#foldl in k8834 */
static void C_fcall f_9626(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_9626,4,t0,t1,t2,t3);}
a=C_alloc(5);
t4=C_i_pairp(t2);
if(C_truep(C_i_not(t4))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=C_slot(t2,C_fix(1));
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9644,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* library.scm:712: f */
t7=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
av2[3]=C_slot(t2,C_fix(0));
((C_proc)C_fast_retrieve_proc(t7))(4,av2);}}}

/* k9642 in loop in chicken.base#foldl in k8834 */
static void C_ccall f_9644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9644,c,av);}
/* library.scm:712: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9626(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.base#foldr in k8834 */
static void C_ccall f_9654(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(c!=5) C_bad_argc_2(c,5,t0);
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_9654,c,av);}
a=C_alloc(8);
t5=C_i_check_list_2(t4,lf[224]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9663,a[2]=t3,a[3]=t2,a[4]=t7,a[5]=((C_word)li140),tmp=(C_word)a,a+=6,tmp));
t9=((C_word*)t7)[1];
f_9663(t9,t1,t4);}

/* loop in chicken.base#foldr in k8834 */
static void C_fcall f_9663(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9663,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9681,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* library.scm:719: loop */
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}}

/* k9679 in loop in chicken.base#foldr in k8834 */
static void C_ccall f_9681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9681,c,av);}
/* library.scm:719: f */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t1;
((C_proc)C_fast_retrieve_proc(t2))(4,av2);}}

/* chicken.base#on-exit in k8834 */
static void C_ccall f_9694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_9694,c,av);}
a=C_alloc(3);
t3=C_a_i_cons(&a,2,t2,*((C_word*)lf[227]+1));
t4=C_mutate((C_word*)lf[227]+1 /* (set! chicken.base#cleanup-tasks ...) */,t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* chicken.base#exit in k8834 */
static void C_ccall f_9701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_9701,c,av);}
a=C_alloc(4);
if(C_truep(C_rest_nullp(c,2))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f35726,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:732: chicken.base#exit-handler */
t3=*((C_word*)lf[226]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=C_get_rest_arg(c,2,av,2,t0);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9708,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:732: chicken.base#exit-handler */
t4=*((C_word*)lf[226]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9706 in chicken.base#exit in k8834 */
static void C_ccall f_9708(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9708,c,av);}
/* library.scm:731: g673 */
t2=t1;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.base#emergency-exit in k8834 */
static void C_ccall f_9719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9719,c,av);}
a=C_alloc(4);
if(C_truep(C_rest_nullp(c,2))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f35157,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* library.scm:735: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t2;
av2[2]=C_fix(0);
av2[3]=lf[231];
tp(4,av2);}}
else{
t2=C_get_rest_arg(c,2,av,2,t0);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9726,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* library.scm:735: ##sys#check-fixnum */
{C_proc tp=(C_proc)C_fast_retrieve_proc(*((C_word*)lf[102]+1));
C_word av2[4];
av2[0]=*((C_word*)lf[102]+1);
av2[1]=t3;
av2[2]=t2;
av2[3]=lf[231];
tp(4,av2);}}}

/* k9724 in chicken.base#emergency-exit in k8834 */
static void C_ccall f_9726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9726,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_exit_runtime(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#identity in k8834 */
static void C_ccall f_9738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9738,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.base#conjoin in k8834 */
static void C_ccall f_9741(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,3)))){
C_save_and_reclaim((void*)f_9741,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9743,a[2]=t2,a[3]=((C_word)li147),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_9743 in chicken.base#conjoin in k8834 */
static void C_ccall f_9743(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_9743,c,av);}
a=C_alloc(7);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9749,a[2]=t4,a[3]=t2,a[4]=((C_word)li146),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_9749(t6,t1,((C_word*)t0)[2]);}

/* loop */
static void C_fcall f_9749(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9749,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_nullp(t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9765,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:753: g702 */
t6=t4;{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t6))(3,av2);}}}

/* k9763 in loop */
static void C_ccall f_9765(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9765,c,av);}
if(C_truep(t1)){
/* library.scm:754: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9749(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.base#disjoin in k8834 */
static void C_ccall f_9774(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,3)))){
C_save_and_reclaim((void*)f_9774,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9776,a[2]=t2,a[3]=((C_word)li150),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_9776 in chicken.base#disjoin in k8834 */
static void C_ccall f_9776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_9776,c,av);}
a=C_alloc(7);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9782,a[2]=t4,a[3]=t2,a[4]=((C_word)li149),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_9782(t6,t1,((C_word*)t0)[2]);}

/* loop */
static void C_fcall f_9782(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9782,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_nullp(t2);
if(C_truep(C_i_not(t3))){
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9795,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:760: g714 */
t6=t4;{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)C_fast_retrieve_proc(t6))(3,av2);}}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k9793 in loop */
static void C_ccall f_9795(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9795,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* library.scm:761: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_9782(t2,((C_word*)t0)[2],C_slot(((C_word*)t0)[4],C_fix(1)));}}

/* chicken.base#constantly in k8834 */
static void C_ccall f_9811(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_9811,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
t3=C_eqp(C_fix(1),C_u_i_length(t2));
if(C_truep(t3)){
t4=C_i_car(t2);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9822,a[2]=t4,a[3]=((C_word)li152),tmp=(C_word)a,a+=4,tmp);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9824,a[2]=t2,a[3]=((C_word)li153),tmp=(C_word)a,a+=4,tmp);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* f_9822 in chicken.base#constantly in k8834 */
static void C_ccall f_9822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9822,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_9824 in chicken.base#constantly in k8834 */
static void C_ccall f_9824(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9824,c,av);}{
C_word av2[4];
av2[0]=0;
av2[1]=t1;
av2[2]=*((C_word*)lf[130]+1);
av2[3]=((C_word*)t0)[2];
C_apply(4,av2);}}

/* chicken.base#flip in k8834 */
static void C_ccall f_9832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_9832,c,av);}
a=C_alloc(4);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9834,a[2]=t2,a[3]=((C_word)li155),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_9834 in chicken.base#flip in k8834 */
static void C_ccall f_9834(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word *a;
if(c!=4) C_bad_argc_2(c,4,t0);
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9834,c,av);}
/* library.scm:769: proc */
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
av2[3]=t2;
((C_proc)C_fast_retrieve_proc(t4))(4,av2);}}

/* chicken.base#complement in k8834 */
static void C_ccall f_9840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_9840,c,av);}
a=C_alloc(4);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9842,a[2]=t2,a[3]=((C_word)li157),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_9842 in chicken.base#complement in k8834 */
static void C_ccall f_9842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +3,c,3)))){
C_save_and_reclaim((void*)f_9842,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+3);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9850,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
C_apply(4,av2);}}

/* k9848 */
static void C_ccall f_9850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9850,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_not(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.base#compose in k8834 */
static void C_ccall f_9852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,3)))){
C_save_and_reclaim((void*)f_9852,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9855,a[2]=t4,a[3]=((C_word)li161),tmp=(C_word)a,a+=4,tmp));
if(C_truep(C_rest_nullp(c,2))){
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=*((C_word*)lf[130]+1);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t4)[1];
av2[3]=t2;
C_apply(4,av2);}}}

/* rec in chicken.base#compose in k8834 */
static void C_ccall f_9855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c<3) C_bad_min_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand((c-3)*C_SIZEOF_PAIR +6,c,2)))){
C_save_and_reclaim((void*)f_9855,c,av);}
a=C_alloc((c-3)*C_SIZEOF_PAIR+6);
t3=C_build_rest(&a,c,3,av);
C_word t4;
C_word t5;
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9863,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t2,a[5]=((C_word)li160),tmp=(C_word)a,a+=6,tmp);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* f_9863 in rec in chicken.base#compose in k8834 */
static void C_ccall f_9863(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,3)))){
C_save_and_reclaim((void*)f_9863,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9869,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word)li159),tmp=(C_word)a,a+=6,tmp);
/* library.scm:780: scheme#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=t3;
av2[3]=((C_word*)t0)[4];
C_call_with_values(4,av2);}}

/* a9868 */
static void C_ccall f_9869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(c!=2) C_bad_argc_2(c,2,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9869,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9877,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[3])[1];
av2[3]=((C_word*)t0)[4];
C_apply(4,av2);}}

/* k9875 in a9868 */
static void C_ccall f_9877(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9877,c,av);}{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
C_apply(4,av2);}}

/* chicken.base#o in k8834 */
static void C_ccall f_9888(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +6,c,3)))){
C_save_and_reclaim((void*)f_9888,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+6);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
if(C_truep(C_rest_nullp(c,2))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=*((C_word*)lf[236]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9900,a[2]=t4,a[3]=((C_word)li164),tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_9900(t6,t1,t2);}}

/* loop in chicken.base#o in k8834 */
static void C_fcall f_9900(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_9900,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_slot(t2,C_fix(0));
t4=C_slot(t2,C_fix(1));
if(C_truep(C_i_nullp(t4))){
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9914,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t4,a[5]=((C_word)li163),tmp=(C_word)a,a+=6,tmp);
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* f_9914 in loop in chicken.base#o in k8834 */
static void C_ccall f_9914(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9914,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9922,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:795: loop */
t4=((C_word*)((C_word*)t0)[3])[1];
f_9900(t4,t3,((C_word*)t0)[4]);}

/* k9920 */
static void C_ccall f_9922(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_9922,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9925,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* library.scm:795: g743 */
t3=t1;{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)C_fast_retrieve_proc(t3))(3,av2);}}

/* k9923 in k9920 */
static void C_ccall f_9925(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9925,c,av);}
/* library.scm:795: h */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)C_fast_retrieve_proc(t2))(3,av2);}}

/* chicken.base#list-of? in k8834 */
static void C_ccall f_9927(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_9927,c,av);}
a=C_alloc(4);
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9929,a[2]=t2,a[3]=((C_word)li167),tmp=(C_word)a,a+=4,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_9929 in chicken.base#list-of? in k8834 */
static void C_ccall f_9929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(c!=3) C_bad_argc_2(c,3,t0);
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_9929,c,av);}
a=C_alloc(7);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9935,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=((C_word)li166),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_9935(t6,t1,t2);}

/* loop */
static void C_fcall f_9935(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_9935,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_pairp(t2);
if(C_truep(C_i_not(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9954,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* library.scm:802: pred */
t5=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)C_fast_retrieve_proc(t5))(3,av2);}}}}

/* k9952 in loop */
static void C_ccall f_9954(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_9954,c,av);}
if(C_truep(t1)){
/* library.scm:802: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_9935(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* chicken.base#each in k8834 */
static void C_ccall f_9971(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +4,c,2)))){
C_save_and_reclaim((void*)f_9971,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+4);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
if(C_truep(C_i_nullp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9979,a[2]=((C_word)li169),tmp=(C_word)a,a+=3,tmp);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t3=C_slot(t2,C_fix(1));
t4=C_i_nullp(t3);
t5=t1;{
C_word *av2=av;
av2[0]=t5;
av2[1]=(C_truep(t4)?C_slot(t2,C_fix(0)):(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9993,a[2]=t2,a[3]=((C_word)li171),tmp=(C_word)a,a+=4,tmp));
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}

/* f_9979 in chicken.base#each in k8834 */
static void C_ccall f_9979(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9979,c,av);}
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=*((C_word*)lf[246]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f_9993 in chicken.base#each in k8834 */
static void C_ccall f_9993(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +7,c,3)))){
C_save_and_reclaim((void*)f_9993,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+7);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
C_word t5;
C_word t6;
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9999,a[2]=t2,a[3]=t4,a[4]=((C_word)li170),tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_9999(t6,t1,((C_word*)t0)[2]);}

/* loop */
static void C_fcall f_9999(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_9999,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_slot(t2,C_fix(0));
t4=C_slot(t2,C_fix(1));
if(C_truep(C_i_nullp(t4))){{
C_word av2[4];
av2[0]=0;
av2[1]=t1;
av2[2]=t3;
av2[3]=((C_word*)t0)[2];
C_apply(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10018,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);{
C_word av2[4];
av2[0]=0;
av2[1]=t5;
av2[2]=t3;
av2[3]=((C_word*)t0)[2];
C_apply(4,av2);}}}

/* toplevel */
static C_TLS int toplevel_initialized=0;

void C_ccall C_library_toplevel(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(toplevel_initialized) {C_kontinue(t1,C_SCHEME_UNDEFINED);}
else C_toplevel_entry(C_text("library"));
C_check_nursery_minimum(C_calculate_demand(3,c,2));
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void*)C_library_toplevel,c,av);}
toplevel_initialized=1;
if(C_unlikely(!C_demand_2(8051))){
C_save(t1);
C_rereclaim2(8051*sizeof(C_word),1);
t1=C_restore;}
a=C_alloc(3);
C_initialize_lf(lf,1445);
lf[0]=C_h_intern(&lf[0],7, C_text("library"));
lf[1]=C_h_intern(&lf[1],7, C_text("scheme#"));
lf[2]=C_h_intern(&lf[2],10, C_text("scheme#not"));
lf[3]=C_h_intern(&lf[3],15, C_text("scheme#boolean\077"));
lf[4]=C_h_intern(&lf[4],10, C_text("scheme#eq\077"));
lf[5]=C_h_intern(&lf[5],11, C_text("scheme#eqv\077"));
lf[6]=C_h_intern(&lf[6],13, C_text("scheme#equal\077"));
lf[7]=C_h_intern(&lf[7],12, C_text("scheme#pair\077"));
lf[8]=C_h_intern(&lf[8],11, C_text("scheme#cons"));
lf[9]=C_h_intern(&lf[9],10, C_text("scheme#car"));
lf[10]=C_h_intern(&lf[10],10, C_text("scheme#cdr"));
lf[11]=C_h_intern(&lf[11],15, C_text("scheme#set-car!"));
lf[12]=C_h_intern(&lf[12],15, C_text("scheme#set-cdr!"));
lf[13]=C_h_intern(&lf[13],11, C_text("scheme#cadr"));
lf[14]=C_h_intern(&lf[14],12, C_text("scheme#caddr"));
lf[15]=C_h_intern(&lf[15],13, C_text("scheme#cadddr"));
lf[16]=C_h_intern(&lf[16],13, C_text("scheme#cddddr"));
lf[17]=C_h_intern(&lf[17],11, C_text("scheme#caar"));
lf[18]=C_h_intern(&lf[18],11, C_text("scheme#cdar"));
lf[19]=C_h_intern(&lf[19],11, C_text("scheme#cddr"));
lf[20]=C_h_intern(&lf[20],12, C_text("scheme#caaar"));
lf[21]=C_h_intern(&lf[21],12, C_text("scheme#caadr"));
lf[22]=C_h_intern(&lf[22],12, C_text("scheme#cadar"));
lf[23]=C_h_intern(&lf[23],12, C_text("scheme#cdaar"));
lf[24]=C_h_intern(&lf[24],12, C_text("scheme#cdadr"));
lf[25]=C_h_intern(&lf[25],12, C_text("scheme#cddar"));
lf[26]=C_h_intern(&lf[26],12, C_text("scheme#cdddr"));
lf[27]=C_h_intern(&lf[27],13, C_text("scheme#caaaar"));
lf[28]=C_h_intern(&lf[28],13, C_text("scheme#caaadr"));
lf[29]=C_h_intern(&lf[29],13, C_text("scheme#caadar"));
lf[30]=C_h_intern(&lf[30],13, C_text("scheme#caaddr"));
lf[31]=C_h_intern(&lf[31],13, C_text("scheme#cadaar"));
lf[32]=C_h_intern(&lf[32],13, C_text("scheme#cadadr"));
lf[33]=C_h_intern(&lf[33],13, C_text("scheme#caddar"));
lf[34]=C_h_intern(&lf[34],13, C_text("scheme#cdaaar"));
lf[35]=C_h_intern(&lf[35],13, C_text("scheme#cdaadr"));
lf[36]=C_h_intern(&lf[36],13, C_text("scheme#cdadar"));
lf[37]=C_h_intern(&lf[37],13, C_text("scheme#cdaddr"));
lf[38]=C_h_intern(&lf[38],13, C_text("scheme#cddaar"));
lf[39]=C_h_intern(&lf[39],13, C_text("scheme#cddadr"));
lf[40]=C_h_intern(&lf[40],13, C_text("scheme#cdddar"));
lf[41]=C_h_intern(&lf[41],12, C_text("scheme#null\077"));
lf[42]=C_h_intern(&lf[42],11, C_text("scheme#list"));
lf[43]=C_h_intern(&lf[43],13, C_text("scheme#length"));
lf[44]=C_h_intern(&lf[44],16, C_text("scheme#list-tail"));
lf[45]=C_h_intern(&lf[45],15, C_text("scheme#list-ref"));
lf[46]=C_h_intern(&lf[46],14, C_text("scheme#reverse"));
lf[47]=C_h_intern(&lf[47],29, C_text("##sys#error-not-a-proper-list"));
lf[48]=C_h_intern(&lf[48],7, C_text("reverse"));
lf[49]=C_h_intern(&lf[49],11, C_text("scheme#memq"));
lf[50]=C_h_intern(&lf[50],11, C_text("scheme#memv"));
lf[51]=C_h_intern(&lf[51],13, C_text("scheme#member"));
lf[52]=C_h_intern(&lf[52],11, C_text("scheme#assq"));
lf[53]=C_h_intern(&lf[53],11, C_text("scheme#assv"));
lf[54]=C_h_intern(&lf[54],12, C_text("scheme#assoc"));
lf[55]=C_h_intern(&lf[55],12, C_text("scheme#list\077"));
lf[56]=C_h_intern(&lf[56],14, C_text("scheme#string\077"));
lf[57]=C_h_intern(&lf[57],20, C_text("scheme#string-length"));
lf[58]=C_h_intern(&lf[58],17, C_text("scheme#string-ref"));
lf[59]=C_h_intern(&lf[59],18, C_text("scheme#string-set!"));
lf[60]=C_h_intern(&lf[60],15, C_text("scheme#string=\077"));
lf[61]=C_h_intern(&lf[61],18, C_text("scheme#string-ci=\077"));
lf[62]=C_h_intern(&lf[62],21, C_text("scheme#exact->inexact"));
lf[63]=C_h_intern(&lf[63],10, C_text("scheme#abs"));
lf[64]=C_h_intern(&lf[64],8, C_text("scheme#+"));
lf[65]=C_h_intern(&lf[65],8, C_text("scheme#-"));
lf[66]=C_h_intern(&lf[66],8, C_text("scheme#\052"));
lf[67]=C_h_intern(&lf[67],15, C_text("scheme#quotient"));
lf[68]=C_h_intern(&lf[68],16, C_text("scheme#remainder"));
lf[69]=C_h_intern(&lf[69],13, C_text("scheme#modulo"));
lf[70]=C_h_intern(&lf[70],12, C_text("scheme#even\077"));
lf[71]=C_h_intern(&lf[71],11, C_text("scheme#odd\077"));
lf[72]=C_h_intern(&lf[72],8, C_text("scheme#="));
lf[73]=C_h_intern(&lf[73],8, C_text("scheme#>"));
lf[74]=C_h_intern(&lf[74],8, C_text("scheme#<"));
lf[75]=C_h_intern(&lf[75],9, C_text("scheme#>="));
lf[76]=C_h_intern(&lf[76],9, C_text("scheme#<="));
lf[77]=C_h_intern(&lf[77],14, C_text("scheme#number\077"));
lf[78]=C_h_intern(&lf[78],15, C_text("scheme#complex\077"));
lf[79]=C_h_intern(&lf[79],12, C_text("scheme#real\077"));
lf[80]=C_h_intern(&lf[80],16, C_text("scheme#rational\077"));
lf[81]=C_h_intern(&lf[81],15, C_text("scheme#integer\077"));
lf[82]=C_h_intern(&lf[82],13, C_text("scheme#exact\077"));
lf[83]=C_h_intern(&lf[83],15, C_text("scheme#inexact\077"));
lf[84]=C_h_intern(&lf[84],12, C_text("scheme#zero\077"));
lf[85]=C_h_intern(&lf[85],16, C_text("scheme#positive\077"));
lf[86]=C_h_intern(&lf[86],16, C_text("scheme#negative\077"));
lf[87]=C_h_intern(&lf[87],21, C_text("scheme#number->string"));
lf[88]=C_h_intern(&lf[88],14, C_text("scheme#symbol\077"));
lf[89]=C_h_intern(&lf[89],14, C_text("scheme#vector\077"));
lf[90]=C_h_intern(&lf[90],20, C_text("scheme#vector-length"));
lf[91]=C_h_intern(&lf[91],17, C_text("scheme#vector-ref"));
lf[92]=C_h_intern(&lf[92],18, C_text("scheme#vector-set!"));
lf[93]=C_h_intern(&lf[93],18, C_text("scheme#make-vector"));
lf[94]=C_h_intern(&lf[94],19, C_text("scheme#list->vector"));
lf[95]=C_h_intern(&lf[95],19, C_text("scheme#vector->list"));
lf[96]=C_h_intern(&lf[96],13, C_text("scheme#vector"));
lf[97]=C_h_intern(&lf[97],19, C_text("scheme#vector-fill!"));
lf[98]=C_h_intern(&lf[98],12, C_text("scheme#char\077"));
lf[99]=C_h_intern(&lf[99],20, C_text("scheme#char->integer"));
lf[100]=C_h_intern(&lf[100],13, C_text("char->integer"));
lf[101]=C_h_intern(&lf[101],20, C_text("scheme#integer->char"));
lf[102]=C_h_intern(&lf[102],18, C_text("##sys#check-fixnum"));
lf[103]=C_h_intern(&lf[103],13, C_text("integer->char"));
lf[104]=C_h_intern(&lf[104],13, C_text("scheme#char=\077"));
lf[105]=C_h_intern(&lf[105],13, C_text("scheme#char>\077"));
lf[106]=C_h_intern(&lf[106],13, C_text("scheme#char<\077"));
lf[107]=C_h_intern(&lf[107],14, C_text("scheme#char>=\077"));
lf[108]=C_h_intern(&lf[108],14, C_text("scheme#char<=\077"));
lf[109]=C_h_intern(&lf[109],18, C_text("scheme#char-upcase"));
lf[110]=C_h_intern(&lf[110],11, C_text("char-upcase"));
lf[111]=C_h_intern(&lf[111],20, C_text("scheme#char-downcase"));
lf[112]=C_h_intern(&lf[112],13, C_text("char-downcase"));
lf[113]=C_h_intern(&lf[113],16, C_text("scheme#char-ci=\077"));
lf[114]=C_h_intern(&lf[114],16, C_text("scheme#char-ci>\077"));
lf[115]=C_h_intern(&lf[115],16, C_text("scheme#char-ci<\077"));
lf[116]=C_h_intern(&lf[116],17, C_text("scheme#char-ci>=\077"));
lf[117]=C_h_intern(&lf[117],17, C_text("scheme#char-ci<=\077"));
lf[118]=C_h_intern(&lf[118],23, C_text("scheme#char-upper-case\077"));
lf[119]=C_h_intern(&lf[119],16, C_text("char-upper-case\077"));
lf[120]=C_h_intern(&lf[120],23, C_text("scheme#char-lower-case\077"));
lf[121]=C_h_intern(&lf[121],16, C_text("char-lower-case\077"));
lf[122]=C_h_intern(&lf[122],20, C_text("scheme#char-numeric\077"));
lf[123]=C_h_intern(&lf[123],13, C_text("char-numeric\077"));
lf[124]=C_h_intern(&lf[124],23, C_text("scheme#char-whitespace\077"));
lf[125]=C_h_intern(&lf[125],16, C_text("char-whitespace\077"));
lf[126]=C_h_intern(&lf[126],23, C_text("scheme#char-alphabetic\077"));
lf[127]=C_h_intern(&lf[127],16, C_text("char-alphabetic\077"));
lf[128]=C_h_intern(&lf[128],17, C_text("scheme#procedure\077"));
lf[129]=C_h_intern(&lf[129],12, C_text("scheme#apply"));
lf[130]=C_h_intern(&lf[130],13, C_text("scheme#values"));
lf[131]=C_h_intern(&lf[131],23, C_text("scheme#call-with-values"));
lf[132]=C_h_intern(&lf[132],37, C_text("scheme#call-with-current-continuation"));
lf[133]=C_h_intern(&lf[133],18, C_text("scheme#input-port\077"));
lf[134]=C_h_intern(&lf[134],19, C_text("scheme#output-port\077"));
lf[135]=C_h_intern(&lf[135],25, C_text("scheme#current-input-port"));
lf[136]=C_h_intern(&lf[136],26, C_text("scheme#current-output-port"));
lf[137]=C_h_intern(&lf[137],22, C_text("scheme#open-input-file"));
lf[138]=C_h_intern(&lf[138],23, C_text("scheme#open-output-file"));
lf[139]=C_h_intern(&lf[139],23, C_text("scheme#close-input-port"));
lf[140]=C_h_intern(&lf[140],24, C_text("scheme#close-output-port"));
lf[141]=C_h_intern(&lf[141],27, C_text("scheme#call-with-input-file"));
lf[142]=C_h_intern(&lf[142],28, C_text("scheme#call-with-output-file"));
lf[143]=C_h_intern(&lf[143],27, C_text("scheme#with-input-from-file"));
lf[144]=C_h_intern(&lf[144],26, C_text("scheme#with-output-to-file"));
lf[145]=C_h_intern(&lf[145],18, C_text("scheme#eof-object\077"));
lf[146]=C_h_intern(&lf[146],18, C_text("scheme#char-ready\077"));
lf[147]=C_h_intern(&lf[147],16, C_text("scheme#read-char"));
lf[148]=C_h_intern(&lf[148],16, C_text("scheme#peek-char"));
lf[149]=C_h_intern(&lf[149],11, C_text("scheme#read"));
lf[150]=C_h_intern(&lf[150],17, C_text("scheme#write-char"));
lf[151]=C_h_intern(&lf[151],14, C_text("scheme#newline"));
lf[152]=C_h_intern(&lf[152],12, C_text("scheme#write"));
lf[153]=C_h_intern(&lf[153],14, C_text("scheme#display"));
lf[154]=C_h_intern(&lf[154],11, C_text("scheme#eval"));
lf[155]=C_h_intern(&lf[155],11, C_text("##sys#error"));
lf[156]=C_h_intern(&lf[156],4, C_text("eval"));
lf[157]=C_decode_literal(C_heaptop,C_text("\376B\000\000T`eval\047 is not defined - the `eval\047 unit was probably not linked with this e"
"xecutable"));
lf[158]=C_h_intern(&lf[158],30, C_text("scheme#interaction-environment"));
lf[159]=C_h_intern(&lf[159],23, C_text("interaction-environment"));
lf[160]=C_decode_literal(C_heaptop,C_text("\376B\000\000g`interaction-environment\047 is not defined - the `eval\047 unit was probably not"
" linked with this executable"));
lf[161]=C_h_intern(&lf[161],32, C_text("scheme#scheme-report-environment"));
lf[162]=C_h_intern(&lf[162],25, C_text("scheme-report-environment"));
lf[163]=C_decode_literal(C_heaptop,C_text("\376B\000\000i`scheme-report-environment\047 is not defined - the `eval\047 unit was probably n"
"ot linked with this executable"));
lf[164]=C_h_intern(&lf[164],23, C_text("scheme#null-environment"));
lf[165]=C_h_intern(&lf[165],16, C_text("null-environment"));
lf[166]=C_decode_literal(C_heaptop,C_text("\376B\000\000``null-environment\047 is not defined - the `eval\047 unit was probably not linked"
" with this executable"));
lf[167]=C_h_intern(&lf[167],11, C_text("scheme#load"));
lf[168]=C_h_intern(&lf[168],4, C_text("load"));
lf[169]=C_decode_literal(C_heaptop,C_text("\376B\000\000T`load\047 is not defined - the `eval\047 unit was probably not linked with this e"
"xecutable"));
lf[170]=C_h_intern(&lf[170],15, C_text("scheme#for-each"));
lf[171]=C_h_intern(&lf[171],10, C_text("scheme#map"));
lf[172]=C_h_intern(&lf[172],19, C_text("scheme#dynamic-wind"));
lf[173]=C_h_intern(&lf[173],13, C_text("chicken.base#"));
lf[174]=C_h_intern(&lf[174],20, C_text("chicken.base#fixnum\077"));
lf[175]=C_h_intern(&lf[175],20, C_text("chicken.base#flonum\077"));
lf[176]=C_h_intern(&lf[176],20, C_text("chicken.base#bignum\077"));
lf[177]=C_h_intern(&lf[177],20, C_text("chicken.base#ratnum\077"));
lf[178]=C_h_intern(&lf[178],21, C_text("chicken.base#cplxnum\077"));
lf[179]=C_h_intern(&lf[179],27, C_text("chicken.base#exact-integer\077"));
lf[180]=C_h_intern(&lf[180],31, C_text("chicken.base#quotient&remainder"));
lf[181]=C_h_intern(&lf[181],28, C_text("chicken.base#quotient&modulo"));
lf[182]=C_h_intern(&lf[182],20, C_text("chicken.base#finite\077"));
lf[183]=C_h_intern(&lf[183],22, C_text("chicken.base#infinite\077"));
lf[184]=C_h_intern(&lf[184],17, C_text("chicken.base#nan\077"));
lf[185]=C_h_intern(&lf[185],19, C_text("chicken.base#signum"));
lf[186]=C_h_intern(&lf[186],27, C_text("chicken.base#get-call-chain"));
lf[187]=C_h_intern(&lf[187],29, C_text("chicken.base#print-call-chain"));
lf[188]=C_h_intern(&lf[188],18, C_text("chicken.base#print"));
lf[189]=C_h_intern(&lf[189],19, C_text("chicken.base#print\052"));
lf[190]=C_h_intern(&lf[190],17, C_text("chicken.base#add1"));
lf[191]=C_h_intern(&lf[191],17, C_text("chicken.base#sub1"));
lf[192]=C_h_intern(&lf[192],31, C_text("chicken.base#current-error-port"));
lf[193]=C_h_intern(&lf[193],18, C_text("chicken.base#error"));
lf[194]=C_h_intern(&lf[194],17, C_text("##sys#signal-hook"));
lf[195]=C_h_intern_kw(&lf[195],5, C_text("error"));
lf[196]=C_h_intern(&lf[196],17, C_text("chicken.base#void"));
lf[197]=C_h_intern(&lf[197],18, C_text("chicken.base#sleep"));
lf[198]=C_h_intern(&lf[198],20, C_text("chicken.base#call/cc"));
lf[199]=C_h_intern(&lf[199],22, C_text("chicken.base#char-name"));
lf[200]=C_h_intern(&lf[200],31, C_text("chicken.base#getter-with-setter"));
lf[201]=C_h_intern(&lf[201],27, C_text("chicken.base#make-parameter"));
lf[202]=C_h_intern(&lf[202],34, C_text("chicken.base#procedure-information"));
lf[203]=C_h_intern(&lf[203],19, C_text("chicken.base#setter"));
lf[204]=C_h_intern(&lf[204],27, C_text("chicken.base#record-printer"));
lf[205]=C_h_intern(&lf[205],32, C_text("chicken.base#set-record-printer!"));
lf[206]=C_h_intern(&lf[206],25, C_text("chicken.base#vector-copy!"));
lf[207]=C_h_intern(&lf[207],22, C_text("chicken.base#subvector"));
lf[208]=C_h_intern(&lf[208],26, C_text("chicken.base#vector-resize"));
lf[209]=C_h_intern(&lf[209],18, C_text("chicken.base#port\077"));
lf[210]=C_h_intern(&lf[210],25, C_text("chicken.base#port-closed\077"));
lf[211]=C_h_intern(&lf[211],29, C_text("chicken.base#input-port-open\077"));
lf[212]=C_h_intern(&lf[212],30, C_text("chicken.base#output-port-open\077"));
lf[213]=C_h_intern(&lf[213],30, C_text("chicken.base#get-output-string"));
lf[214]=C_h_intern(&lf[214],30, C_text("chicken.base#open-input-string"));
lf[215]=C_h_intern(&lf[215],31, C_text("chicken.base#open-output-string"));
lf[216]=C_h_intern(&lf[216],25, C_text("chicken.base#flush-output"));
lf[217]=C_h_intern(&lf[217],21, C_text("chicken.base#promise\077"));
lf[218]=C_h_intern(&lf[218],7, C_text("promise"));
lf[219]=C_h_intern(&lf[219],18, C_text("##sys#make-promise"));
lf[220]=C_h_intern(&lf[220],25, C_text("chicken.base#make-promise"));
lf[221]=C_h_intern(&lf[221],18, C_text("chicken.base#foldl"));
lf[222]=C_h_intern(&lf[222],5, C_text("foldl"));
lf[223]=C_h_intern(&lf[223],18, C_text("chicken.base#foldr"));
lf[224]=C_h_intern(&lf[224],5, C_text("foldr"));
lf[225]=C_h_intern(&lf[225],34, C_text("chicken.base#implicit-exit-handler"));
lf[226]=C_h_intern(&lf[226],25, C_text("chicken.base#exit-handler"));
lf[227]=C_h_intern(&lf[227],26, C_text("chicken.base#cleanup-tasks"));
lf[228]=C_h_intern(&lf[228],20, C_text("chicken.base#on-exit"));
lf[229]=C_h_intern(&lf[229],17, C_text("chicken.base#exit"));
lf[230]=C_h_intern(&lf[230],27, C_text("chicken.base#emergency-exit"));
lf[231]=C_h_intern(&lf[231],14, C_text("emergency-exit"));
lf[232]=C_h_intern(&lf[232],27, C_text("chicken.base#case-sensitive"));
lf[233]=C_h_intern(&lf[233],26, C_text("chicken.base#keyword-style"));
lf[234]=C_h_intern(&lf[234],33, C_text("chicken.base#parentheses-synonyms"));
lf[235]=C_h_intern(&lf[235],26, C_text("chicken.base#symbol-escape"));
lf[236]=C_h_intern(&lf[236],21, C_text("chicken.base#identity"));
lf[237]=C_h_intern(&lf[237],20, C_text("chicken.base#conjoin"));
lf[238]=C_h_intern(&lf[238],20, C_text("chicken.base#disjoin"));
lf[239]=C_h_intern(&lf[239],23, C_text("chicken.base#constantly"));
lf[240]=C_h_intern(&lf[240],17, C_text("chicken.base#flip"));
lf[241]=C_h_intern(&lf[241],23, C_text("chicken.base#complement"));
lf[242]=C_h_intern(&lf[242],20, C_text("chicken.base#compose"));
lf[243]=C_h_intern(&lf[243],14, C_text("chicken.base#o"));
lf[244]=C_h_intern(&lf[244],21, C_text("chicken.base#list-of\077"));
lf[245]=C_h_intern(&lf[245],17, C_text("chicken.base#each"));
lf[246]=C_h_intern(&lf[246],21, C_text("##sys#undefined-value"));
lf[247]=C_h_intern(&lf[247],24, C_text("chicken.base#bwp-object\077"));
lf[248]=C_h_intern(&lf[248],22, C_text("chicken.base#weak-cons"));
lf[249]=C_h_intern(&lf[249],23, C_text("chicken.base#weak-pair\077"));
lf[250]=C_h_intern(&lf[250],18, C_text("chicken.base#atom\077"));
lf[251]=C_h_intern(&lf[251],18, C_text("chicken.base#tail\077"));
lf[252]=C_h_intern(&lf[252],5, C_text("tail\077"));
lf[253]=C_h_intern(&lf[253],24, C_text("chicken.base#intersperse"));
lf[254]=C_h_intern(&lf[254],20, C_text("chicken.base#butlast"));
lf[255]=C_h_intern(&lf[255],7, C_text("butlast"));
lf[256]=C_h_intern(&lf[256],20, C_text("chicken.base#flatten"));
lf[257]=C_h_intern(&lf[257],17, C_text("chicken.base#join"));
lf[258]=C_h_intern(&lf[258],4, C_text("join"));
lf[259]=C_h_intern(&lf[259],12, C_text("##sys#append"));
lf[260]=C_h_intern(&lf[260],21, C_text("chicken.base#compress"));
lf[261]=C_decode_literal(C_heaptop,C_text("\376B\000\000%bad argument type - not a proper list"));
lf[262]=C_h_intern(&lf[262],8, C_text("compress"));
lf[263]=C_h_intern_kw(&lf[263],10, C_text("type-error"));
lf[264]=C_h_intern(&lf[264],26, C_text("chicken.base#alist-update!"));
lf[265]=C_h_intern(&lf[265],25, C_text("chicken.base#alist-update"));
lf[266]=C_h_intern(&lf[266],12, C_text("alist-update"));
lf[267]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021bad argument type"));
lf[268]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021bad argument type"));
lf[269]=C_h_intern(&lf[269],22, C_text("chicken.base#alist-ref"));
lf[270]=C_h_intern(&lf[270],9, C_text("alist-ref"));
lf[271]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021bad argument type"));
lf[272]=C_h_intern(&lf[272],19, C_text("chicken.base#rassoc"));
lf[273]=C_h_intern(&lf[273],6, C_text("rassoc"));
lf[275]=C_h_intern(&lf[275],15, C_text("chicken.fixnum#"));
lf[276]=C_h_intern(&lf[276],35, C_text("chicken.fixnum#most-positive-fixnum"));
lf[277]=C_h_intern(&lf[277],35, C_text("chicken.fixnum#most-negative-fixnum"));
lf[278]=C_h_intern(&lf[278],26, C_text("chicken.fixnum#fixnum-bits"));
lf[279]=C_h_intern(&lf[279],31, C_text("chicken.fixnum#fixnum-precision"));
lf[280]=C_h_intern(&lf[280],18, C_text("chicken.fixnum#fx+"));
lf[281]=C_h_intern(&lf[281],18, C_text("chicken.fixnum#fx-"));
lf[282]=C_h_intern(&lf[282],18, C_text("chicken.fixnum#fx\052"));
lf[283]=C_h_intern(&lf[283],18, C_text("chicken.fixnum#fx="));
lf[284]=C_h_intern(&lf[284],18, C_text("chicken.fixnum#fx>"));
lf[285]=C_h_intern(&lf[285],18, C_text("chicken.fixnum#fx<"));
lf[286]=C_h_intern(&lf[286],19, C_text("chicken.fixnum#fx>="));
lf[287]=C_h_intern(&lf[287],19, C_text("chicken.fixnum#fx<="));
lf[288]=C_h_intern(&lf[288],20, C_text("chicken.fixnum#fxmin"));
lf[289]=C_h_intern(&lf[289],20, C_text("chicken.fixnum#fxmax"));
lf[290]=C_h_intern(&lf[290],20, C_text("chicken.fixnum#fxneg"));
lf[291]=C_h_intern(&lf[291],20, C_text("chicken.fixnum#fxand"));
lf[292]=C_h_intern(&lf[292],20, C_text("chicken.fixnum#fxior"));
lf[293]=C_h_intern(&lf[293],20, C_text("chicken.fixnum#fxxor"));
lf[294]=C_h_intern(&lf[294],20, C_text("chicken.fixnum#fxnot"));
lf[295]=C_h_intern(&lf[295],20, C_text("chicken.fixnum#fxshl"));
lf[296]=C_h_intern(&lf[296],20, C_text("chicken.fixnum#fxshr"));
lf[297]=C_h_intern(&lf[297],21, C_text("chicken.fixnum#fxodd\077"));
lf[298]=C_h_intern(&lf[298],22, C_text("chicken.fixnum#fxeven\077"));
lf[299]=C_h_intern(&lf[299],20, C_text("chicken.fixnum#fxlen"));
lf[300]=C_h_intern(&lf[300],18, C_text("chicken.fixnum#fx/"));
lf[301]=C_h_intern(&lf[301],20, C_text("chicken.fixnum#fxgcd"));
lf[302]=C_h_intern(&lf[302],20, C_text("chicken.fixnum#fxmod"));
lf[303]=C_h_intern(&lf[303],20, C_text("chicken.fixnum#fxrem"));
lf[304]=C_h_intern(&lf[304],19, C_text("chicken.fixnum#fx+\077"));
lf[305]=C_h_intern(&lf[305],19, C_text("chicken.fixnum#fx-\077"));
lf[306]=C_h_intern(&lf[306],19, C_text("chicken.fixnum#fx\052\077"));
lf[307]=C_h_intern(&lf[307],19, C_text("chicken.fixnum#fx/\077"));
lf[308]=C_h_intern(&lf[308],17, C_text("##sys#debug-mode\077"));
lf[309]=C_h_intern(&lf[309],22, C_text("##sys#warnings-enabled"));
lf[310]=C_h_intern(&lf[310],21, C_text("##sys#notices-enabled"));
lf[311]=C_h_intern(&lf[311],20, C_text("chicken.base#warning"));
lf[312]=C_h_intern_kw(&lf[312],7, C_text("warning"));
lf[313]=C_h_intern(&lf[313],19, C_text("chicken.base#notice"));
lf[314]=C_h_intern_kw(&lf[314],6, C_text("notice"));
lf[315]=C_h_intern(&lf[315],28, C_text("chicken.base#enable-warnings"));
lf[316]=C_h_intern(&lf[316],10, C_text("##sys#warn"));
lf[317]=C_h_intern(&lf[317],12, C_text("##sys#notice"));
lf[318]=C_h_intern(&lf[318],17, C_text("##sys#error/errno"));
lf[319]=C_h_intern(&lf[319],23, C_text("##sys#signal-hook/errno"));
lf[320]=C_h_intern(&lf[320],8, C_text("##sys#gc"));
lf[321]=C_h_intern(&lf[321],13, C_text("##sys#setslot"));
lf[322]=C_h_intern(&lf[322],14, C_text("##sys#setislot"));
lf[323]=C_h_intern(&lf[323],21, C_text("##sys#allocate-vector"));
lf[324]=C_h_intern(&lf[324],20, C_text("##sys#make-structure"));
lf[325]=C_h_intern(&lf[325],25, C_text("##sys#ensure-heap-reserve"));
lf[326]=C_h_intern(&lf[326],23, C_text("##sys#symbol-table-info"));
lf[327]=C_h_intern(&lf[327],17, C_text("##sys#memory-info"));
lf[328]=C_h_intern(&lf[328],17, C_text("##sys#start-timer"));
lf[329]=C_h_intern(&lf[329],16, C_text("##sys#stop-timer"));
lf[330]=C_h_intern(&lf[330],16, C_text("##sys#immediate\077"));
lf[331]=C_h_intern(&lf[331],13, C_text("##sys#message"));
lf[332]=C_h_intern(&lf[332],10, C_text("##sys#byte"));
lf[333]=C_h_intern(&lf[333],13, C_text("##sys#setbyte"));
lf[334]=C_h_intern(&lf[334],10, C_text("##sys#void"));
lf[335]=C_h_intern(&lf[335],10, C_text("##sys#halt"));
lf[336]=C_h_intern(&lf[336],13, C_text("##sys#become!"));
lf[337]=C_h_intern(&lf[337],15, C_text("##sys#block-ref"));
lf[338]=C_h_intern(&lf[338],18, C_text("##sys#apply-values"));
lf[339]=C_h_intern(&lf[339],18, C_text("##sys#copy-closure"));
lf[340]=C_h_intern(&lf[340],16, C_text("##sys#block-set!"));
lf[341]=C_h_intern(&lf[341],17, C_text("##sys#check-range"));
lf[342]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023slot not accessible"));
lf[343]=C_h_intern(&lf[343],13, C_text("chicken.time#"));
lf[344]=C_h_intern(&lf[344],33, C_text("chicken.time#current-milliseconds"));
lf[345]=C_h_intern(&lf[345],41, C_text("chicken.time#current-process-milliseconds"));
lf[346]=C_h_intern(&lf[346],28, C_text("chicken.time#current-seconds"));
lf[347]=C_h_intern(&lf[347],21, C_text("chicken.time#cpu-time"));
lf[348]=C_h_intern(&lf[348],21, C_text("##sys#check-structure"));
lf[349]=C_h_intern(&lf[349],16, C_text("##sys#check-blob"));
lf[350]=C_h_intern(&lf[350],23, C_text("##sys#check-byte-vector"));
lf[351]=C_h_intern(&lf[351],16, C_text("##sys#check-pair"));
lf[352]=C_h_intern(&lf[352],16, C_text("##sys#check-list"));
lf[353]=C_h_intern(&lf[353],18, C_text("##sys#check-string"));
lf[354]=C_h_intern(&lf[354],18, C_text("##sys#check-number"));
lf[355]=C_h_intern(&lf[355],17, C_text("##sys#check-exact"));
lf[356]=C_h_intern(&lf[356],19, C_text("##sys#check-inexact"));
lf[357]=C_h_intern(&lf[357],18, C_text("##sys#check-symbol"));
lf[358]=C_h_intern(&lf[358],19, C_text("##sys#check-keyword"));
lf[359]=C_h_intern(&lf[359],18, C_text("##sys#check-vector"));
lf[360]=C_h_intern(&lf[360],16, C_text("##sys#check-char"));
lf[361]=C_h_intern(&lf[361],19, C_text("##sys#check-boolean"));
lf[362]=C_h_intern(&lf[362],20, C_text("##sys#check-locative"));
lf[363]=C_h_intern(&lf[363],19, C_text("##sys#check-integer"));
lf[364]=C_h_intern(&lf[364],23, C_text("##sys#error-bad-integer"));
lf[365]=C_h_intern(&lf[365],25, C_text("##sys#check-exact-integer"));
lf[366]=C_h_intern(&lf[366],29, C_text("##sys#error-bad-exact-integer"));
lf[367]=C_h_intern(&lf[367],26, C_text("##sys#check-exact-uinteger"));
lf[368]=C_h_intern(&lf[368],30, C_text("##sys#error-bad-exact-uinteger"));
lf[369]=C_h_intern(&lf[369],16, C_text("##sys#check-real"));
lf[370]=C_h_intern(&lf[370],20, C_text("##sys#error-bad-real"));
lf[371]=C_h_intern(&lf[371],16, C_text("##sys#error-hook"));
lf[372]=C_h_intern(&lf[372],19, C_text("##sys#check-special"));
lf[373]=C_decode_literal(C_heaptop,C_text("\376B\000\000-bad argument type - not a pointer-like object"));
lf[374]=C_h_intern(&lf[374],19, C_text("##sys#check-closure"));
lf[375]=C_h_intern(&lf[375],12, C_text("scheme#force"));
lf[376]=C_h_intern(&lf[376],10, C_text("##sys#list"));
lf[377]=C_h_intern(&lf[377],11, C_text("##sys#dload"));
lf[378]=C_h_intern(&lf[378],23, C_text("##sys#set-dlopen-flags!"));
lf[379]=C_h_intern(&lf[379],22, C_text("##sys#error-bad-number"));
lf[380]=C_h_intern(&lf[380],23, C_text("##sys#error-bad-inexact"));
lf[381]=C_h_intern(&lf[381],20, C_text("##sys#error-bad-base"));
lf[382]=C_h_intern(&lf[382],13, C_text("scheme#append"));
lf[383]=C_h_intern(&lf[383],6, C_text("append"));
lf[384]=C_h_intern(&lf[384],18, C_text("##sys#fast-reverse"));
lf[385]=C_h_intern(&lf[385],17, C_text("##sys#make-string"));
lf[386]=C_h_intern(&lf[386],18, C_text("scheme#make-string"));
lf[387]=C_h_intern(&lf[387],11, C_text("make-string"));
lf[388]=C_h_intern_kw(&lf[388],12, C_text("bounds-error"));
lf[389]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020size is negative"));
lf[390]=C_h_intern(&lf[390],19, C_text("scheme#string->list"));
lf[391]=C_h_intern(&lf[391],12, C_text("string->list"));
lf[392]=C_h_intern(&lf[392],18, C_text("##sys#string->list"));
lf[393]=C_h_intern(&lf[393],19, C_text("scheme#list->string"));
lf[394]=C_h_intern(&lf[394],12, C_text("list->string"));
lf[395]=C_h_intern(&lf[395],18, C_text("##sys#list->string"));
lf[396]=C_h_intern(&lf[396],26, C_text("##sys#reverse-list->string"));
lf[397]=C_h_intern(&lf[397],20, C_text("reverse-list->string"));
lf[398]=C_h_intern(&lf[398],19, C_text("scheme#string-fill!"));
lf[399]=C_h_intern(&lf[399],12, C_text("string-fill!"));
lf[400]=C_h_intern(&lf[400],18, C_text("scheme#string-copy"));
lf[401]=C_h_intern(&lf[401],11, C_text("string-copy"));
lf[402]=C_h_intern(&lf[402],16, C_text("scheme#substring"));
lf[403]=C_h_intern(&lf[403],9, C_text("substring"));
lf[404]=C_h_intern(&lf[404],15, C_text("##sys#substring"));
lf[405]=C_h_intern(&lf[405],15, C_text("scheme#string<\077"));
lf[406]=C_h_intern(&lf[406],8, C_text("string<\077"));
lf[407]=C_h_intern(&lf[407],15, C_text("scheme#string>\077"));
lf[408]=C_h_intern(&lf[408],8, C_text("string>\077"));
lf[409]=C_h_intern(&lf[409],16, C_text("scheme#string<=\077"));
lf[410]=C_h_intern(&lf[410],9, C_text("string<=\077"));
lf[411]=C_h_intern(&lf[411],16, C_text("scheme#string>=\077"));
lf[412]=C_h_intern(&lf[412],9, C_text("string>=\077"));
lf[413]=C_h_intern(&lf[413],18, C_text("scheme#string-ci<\077"));
lf[414]=C_h_intern(&lf[414],11, C_text("string-ci<\077"));
lf[415]=C_h_intern(&lf[415],18, C_text("scheme#string-ci>\077"));
lf[416]=C_h_intern(&lf[416],11, C_text("string-ci>\077"));
lf[417]=C_h_intern(&lf[417],19, C_text("scheme#string-ci<=\077"));
lf[418]=C_h_intern(&lf[418],12, C_text("string-ci<=\077"));
lf[419]=C_h_intern(&lf[419],19, C_text("scheme#string-ci>=\077"));
lf[420]=C_h_intern(&lf[420],12, C_text("string-ci>=\077"));
lf[421]=C_h_intern(&lf[421],19, C_text("##sys#string-append"));
lf[422]=C_h_intern(&lf[422],20, C_text("scheme#string-append"));
lf[423]=C_h_intern(&lf[423],13, C_text("string-append"));
lf[424]=C_h_intern(&lf[424],13, C_text("scheme#string"));
lf[425]=C_h_intern(&lf[425],23, C_text("##sys#fragments->string"));
lf[426]=C_h_intern(&lf[426],17, C_text("chicken.base#chop"));
lf[427]=C_h_intern(&lf[427],4, C_text("chop"));
lf[428]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030invalid numeric argument"));
lf[429]=C_h_intern(&lf[429],15, C_text("chicken.flonum#"));
lf[430]=C_h_intern(&lf[430],29, C_text("chicken.flonum#maximum-flonum"));
lf[431]=C_h_intern(&lf[431],29, C_text("chicken.flonum#minimum-flonum"));
lf[432]=C_h_intern(&lf[432],27, C_text("chicken.flonum#flonum-radix"));
lf[433]=C_h_intern(&lf[433],29, C_text("chicken.flonum#flonum-epsilon"));
lf[434]=C_h_intern(&lf[434],31, C_text("chicken.flonum#flonum-precision"));
lf[435]=C_h_intern(&lf[435],39, C_text("chicken.flonum#flonum-decimal-precision"));
lf[436]=C_h_intern(&lf[436],38, C_text("chicken.flonum#flonum-maximum-exponent"));
lf[437]=C_h_intern(&lf[437],38, C_text("chicken.flonum#flonum-minimum-exponent"));
lf[438]=C_h_intern(&lf[438],46, C_text("chicken.flonum#flonum-maximum-decimal-exponent"));
lf[439]=C_h_intern(&lf[439],46, C_text("chicken.flonum#flonum-minimum-decimal-exponent"));
lf[440]=C_h_intern(&lf[440],18, C_text("chicken.flonum#fp+"));
lf[441]=C_h_intern(&lf[441],3, C_text("fp+"));
lf[442]=C_h_intern(&lf[442],18, C_text("chicken.flonum#fp-"));
lf[443]=C_h_intern(&lf[443],3, C_text("fp-"));
lf[444]=C_h_intern(&lf[444],18, C_text("chicken.flonum#fp\052"));
lf[445]=C_h_intern(&lf[445],3, C_text("fp\052"));
lf[446]=C_h_intern(&lf[446],18, C_text("chicken.flonum#fp/"));
lf[447]=C_h_intern(&lf[447],3, C_text("fp/"));
lf[448]=C_h_intern(&lf[448],19, C_text("chicken.flonum#fp\052+"));
lf[449]=C_h_intern(&lf[449],4, C_text("fp\052+"));
lf[450]=C_h_intern(&lf[450],20, C_text("chicken.flonum#fpgcd"));
lf[451]=C_h_intern(&lf[451],5, C_text("fpgcd"));
lf[452]=C_h_intern(&lf[452],19, C_text("chicken.flonum#fp/\077"));
lf[453]=C_h_intern(&lf[453],4, C_text("fp/\077"));
lf[454]=C_h_intern(&lf[454],18, C_text("chicken.flonum#fp="));
lf[455]=C_h_intern(&lf[455],3, C_text("fp="));
lf[456]=C_h_intern(&lf[456],18, C_text("chicken.flonum#fp>"));
lf[457]=C_h_intern(&lf[457],3, C_text("fp>"));
lf[458]=C_h_intern(&lf[458],18, C_text("chicken.flonum#fp<"));
lf[459]=C_h_intern(&lf[459],3, C_text("fp<"));
lf[460]=C_h_intern(&lf[460],19, C_text("chicken.flonum#fp>="));
lf[461]=C_h_intern(&lf[461],4, C_text("fp>="));
lf[462]=C_h_intern(&lf[462],19, C_text("chicken.flonum#fp<="));
lf[463]=C_h_intern(&lf[463],4, C_text("fp<="));
lf[464]=C_h_intern(&lf[464],20, C_text("chicken.flonum#fpneg"));
lf[465]=C_h_intern(&lf[465],5, C_text("fpneg"));
lf[466]=C_h_intern(&lf[466],20, C_text("chicken.flonum#fpmax"));
lf[467]=C_h_intern(&lf[467],5, C_text("fpmax"));
lf[468]=C_h_intern(&lf[468],20, C_text("chicken.flonum#fpmin"));
lf[469]=C_h_intern(&lf[469],5, C_text("fpmin"));
lf[470]=C_h_intern(&lf[470],22, C_text("chicken.flonum#fpfloor"));
lf[471]=C_h_intern(&lf[471],7, C_text("fpfloor"));
lf[472]=C_h_intern(&lf[472],25, C_text("chicken.flonum#fptruncate"));
lf[473]=C_h_intern(&lf[473],10, C_text("fptruncate"));
lf[474]=C_h_intern(&lf[474],22, C_text("chicken.flonum#fpround"));
lf[475]=C_h_intern(&lf[475],7, C_text("fpround"));
lf[476]=C_h_intern(&lf[476],24, C_text("chicken.flonum#fpceiling"));
lf[477]=C_h_intern(&lf[477],9, C_text("fpceiling"));
lf[478]=C_h_intern(&lf[478],20, C_text("chicken.flonum#fpsin"));
lf[479]=C_h_intern(&lf[479],5, C_text("fpsin"));
lf[480]=C_h_intern(&lf[480],20, C_text("chicken.flonum#fpcos"));
lf[481]=C_h_intern(&lf[481],5, C_text("fpcos"));
lf[482]=C_h_intern(&lf[482],20, C_text("chicken.flonum#fptan"));
lf[483]=C_h_intern(&lf[483],5, C_text("fptan"));
lf[484]=C_h_intern(&lf[484],21, C_text("chicken.flonum#fpasin"));
lf[485]=C_h_intern(&lf[485],6, C_text("fpasin"));
lf[486]=C_h_intern(&lf[486],21, C_text("chicken.flonum#fpacos"));
lf[487]=C_h_intern(&lf[487],6, C_text("fpacos"));
lf[488]=C_h_intern(&lf[488],21, C_text("chicken.flonum#fpatan"));
lf[489]=C_h_intern(&lf[489],6, C_text("fpatan"));
lf[490]=C_h_intern(&lf[490],22, C_text("chicken.flonum#fpatan2"));
lf[491]=C_h_intern(&lf[491],7, C_text("fpatan2"));
lf[492]=C_h_intern(&lf[492],21, C_text("chicken.flonum#fpsinh"));
lf[493]=C_h_intern(&lf[493],6, C_text("fpsinh"));
lf[494]=C_h_intern(&lf[494],21, C_text("chicken.flonum#fpcosh"));
lf[495]=C_h_intern(&lf[495],6, C_text("fpcosh"));
lf[496]=C_h_intern(&lf[496],21, C_text("chicken.flonum#fptanh"));
lf[497]=C_h_intern(&lf[497],6, C_text("fptanh"));
lf[498]=C_h_intern(&lf[498],22, C_text("chicken.flonum#fpasinh"));
lf[499]=C_h_intern(&lf[499],7, C_text("fpasinh"));
lf[500]=C_h_intern(&lf[500],22, C_text("chicken.flonum#fpacosh"));
lf[501]=C_h_intern(&lf[501],7, C_text("fpacosh"));
lf[502]=C_h_intern(&lf[502],22, C_text("chicken.flonum#fpatanh"));
lf[503]=C_h_intern(&lf[503],7, C_text("fpatanh"));
lf[504]=C_h_intern(&lf[504],20, C_text("chicken.flonum#fpexp"));
lf[505]=C_h_intern(&lf[505],5, C_text("fpexp"));
lf[506]=C_h_intern(&lf[506],21, C_text("chicken.flonum#fpexpt"));
lf[507]=C_h_intern(&lf[507],6, C_text("fpexpt"));
lf[508]=C_h_intern(&lf[508],20, C_text("chicken.flonum#fplog"));
lf[509]=C_h_intern(&lf[509],5, C_text("fplog"));
lf[510]=C_h_intern(&lf[510],21, C_text("chicken.flonum#fpsqrt"));
lf[511]=C_h_intern(&lf[511],6, C_text("fpsqrt"));
lf[512]=C_h_intern(&lf[512],20, C_text("chicken.flonum#fpabs"));
lf[513]=C_h_intern(&lf[513],5, C_text("fpabs"));
lf[514]=C_h_intern(&lf[514],25, C_text("chicken.flonum#fpinteger\077"));
lf[515]=C_h_intern(&lf[515],10, C_text("fpinteger\077"));
lf[516]=C_h_intern(&lf[516],37, C_text("chicken.flonum#flonum-print-precision"));
lf[517]=C_h_intern(&lf[517],22, C_text("flonum-print-precision"));
lf[518]=C_h_intern(&lf[518],13, C_text("##sys#number\077"));
lf[519]=C_h_intern(&lf[519],14, C_text("##sys#integer\077"));
lf[520]=C_h_intern(&lf[520],12, C_text("##sys#exact\077"));
lf[521]=C_h_intern(&lf[521],14, C_text("##sys#inexact\077"));
lf[523]=C_decode_literal(C_heaptop,C_text("\376U0.0\000"));
lf[524]=C_h_intern(&lf[524],23, C_text("scheme#make-rectangular"));
lf[525]=C_h_intern(&lf[525],16, C_text("make-rectangular"));
lf[526]=C_h_intern(&lf[526],17, C_text("scheme#make-polar"));
lf[527]=C_h_intern(&lf[527],10, C_text("make-polar"));
lf[528]=C_h_intern(&lf[528],16, C_text("scheme#real-part"));
lf[529]=C_h_intern(&lf[529],9, C_text("real-part"));
lf[530]=C_h_intern(&lf[530],16, C_text("scheme#imag-part"));
lf[531]=C_h_intern(&lf[531],9, C_text("imag-part"));
lf[532]=C_h_intern(&lf[532],12, C_text("scheme#angle"));
lf[533]=C_h_intern(&lf[533],5, C_text("angle"));
lf[534]=C_h_intern(&lf[534],16, C_text("scheme#magnitude"));
lf[535]=C_h_intern(&lf[535],11, C_text("scheme#sqrt"));
lf[536]=C_h_intern(&lf[536],9, C_text("magnitude"));
lf[538]=C_h_intern(&lf[538],16, C_text("scheme#numerator"));
lf[539]=C_h_intern(&lf[539],9, C_text("numerator"));
lf[540]=C_h_intern(&lf[540],21, C_text("scheme#inexact->exact"));
lf[541]=C_decode_literal(C_heaptop,C_text("\376B\000\000)bad argument type - not a rational number"));
lf[542]=C_h_intern(&lf[542],18, C_text("scheme#denominator"));
lf[543]=C_h_intern(&lf[543],11, C_text("denominator"));
lf[544]=C_decode_literal(C_heaptop,C_text("\376U1.0\000"));
lf[545]=C_decode_literal(C_heaptop,C_text("\376B\000\000)bad argument type - not a rational number"));
lf[546]=C_h_intern(&lf[546],21, C_text("##sys#extended-signum"));
lf[547]=C_h_intern(&lf[547],6, C_text("signum"));
lf[548]=C_h_intern(&lf[548],9, C_text("##sys#/-2"));
lf[549]=C_h_intern(&lf[549],14, C_text("inexact->exact"));
lf[550]=C_h_intern(&lf[550],19, C_text("##sys#integer-power"));
lf[551]=C_decode_literal(C_heaptop,C_text("\376U2.0\000"));
lf[552]=C_h_intern(&lf[552],11, C_text("scheme#expt"));
lf[553]=C_h_intern(&lf[553],20, C_text("##sys#exact->inexact"));
lf[554]=C_h_intern(&lf[554],20, C_text("##sys#inexact->exact"));
lf[555]=C_h_intern(&lf[555],16, C_text("chicken.bitwise#"));
lf[556]=C_h_intern(&lf[556],27, C_text("chicken.bitwise#bitwise-and"));
lf[557]=C_h_intern(&lf[557],27, C_text("chicken.bitwise#bitwise-ior"));
lf[558]=C_h_intern(&lf[558],27, C_text("chicken.bitwise#bitwise-xor"));
lf[559]=C_h_intern(&lf[559],27, C_text("chicken.bitwise#bitwise-not"));
lf[560]=C_h_intern(&lf[560],28, C_text("chicken.bitwise#bit->boolean"));
lf[561]=C_h_intern(&lf[561],30, C_text("chicken.bitwise#integer-length"));
lf[562]=C_h_intern(&lf[562],32, C_text("chicken.bitwise#arithmetic-shift"));
lf[563]=C_h_intern(&lf[563],8, C_text("scheme#/"));
lf[565]=C_h_intern(&lf[565],1, C_text("/"));
lf[566]=C_h_intern(&lf[566],12, C_text("scheme#floor"));
lf[567]=C_h_intern(&lf[567],5, C_text("floor"));
lf[568]=C_h_intern(&lf[568],14, C_text("scheme#ceiling"));
lf[569]=C_h_intern(&lf[569],7, C_text("ceiling"));
lf[570]=C_h_intern(&lf[570],15, C_text("scheme#truncate"));
lf[571]=C_h_intern(&lf[571],8, C_text("truncate"));
lf[572]=C_h_intern(&lf[572],12, C_text("scheme#round"));
lf[573]=C_h_intern(&lf[573],5, C_text("round"));
lf[575]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\001\000\000\000\000\376\003\000\000\002\376\377\001\000\000\000\001\376\377\016"));
lf[576]=C_h_intern(&lf[576],18, C_text("scheme#rationalize"));
lf[577]=C_h_intern(&lf[577],10, C_text("scheme#max"));
lf[578]=C_h_intern(&lf[578],3, C_text("max"));
lf[579]=C_h_intern(&lf[579],10, C_text("scheme#min"));
lf[580]=C_h_intern(&lf[580],3, C_text("min"));
lf[581]=C_h_intern(&lf[581],10, C_text("scheme#exp"));
lf[582]=C_h_intern(&lf[582],3, C_text("exp"));
lf[583]=C_h_intern(&lf[583],11, C_text("##sys#log-1"));
lf[584]=C_h_intern_kw(&lf[584],16, C_text("arithmetic-error"));
lf[585]=C_h_intern(&lf[585],3, C_text("log"));
lf[586]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033log of exact 0 is undefined"));
lf[587]=C_h_intern(&lf[587],10, C_text("scheme#log"));
lf[588]=C_h_intern(&lf[588],10, C_text("scheme#sin"));
lf[589]=C_h_intern(&lf[589],3, C_text("sin"));
lf[590]=C_decode_literal(C_heaptop,C_text("\376\016\000\000\002\376\377\001\000\000\000\000\376\377\001\000\000\000\001"));
lf[591]=C_decode_literal(C_heaptop,C_text("\376\016\000\000\002\376\377\001\000\000\000\000\376\377\001\000\000\000\002"));
lf[592]=C_h_intern(&lf[592],10, C_text("scheme#cos"));
lf[593]=C_h_intern(&lf[593],3, C_text("cos"));
lf[594]=C_h_intern(&lf[594],10, C_text("scheme#tan"));
lf[595]=C_h_intern(&lf[595],3, C_text("tan"));
lf[596]=C_h_intern(&lf[596],11, C_text("scheme#asin"));
lf[597]=C_h_intern(&lf[597],4, C_text("asin"));
lf[598]=C_decode_literal(C_heaptop,C_text("\376\016\000\000\002\376\377\001\000\000\000\000\376\377\001\377\377\377\377"));
lf[599]=C_h_intern(&lf[599],14, C_text("##sys#sqrt/loc"));
lf[600]=C_decode_literal(C_heaptop,C_text("\376U-1.0\000"));
lf[601]=C_h_intern(&lf[601],11, C_text("scheme#acos"));
lf[602]=C_h_intern(&lf[602],4, C_text("acos"));
lf[603]=C_h_intern(&lf[603],11, C_text("scheme#atan"));
lf[604]=C_h_intern(&lf[604],4, C_text("atan"));
lf[605]=C_h_intern(&lf[605],24, C_text("##sys#exact-integer-sqrt"));
lf[606]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030this should never happen"));
lf[607]=C_h_intern(&lf[607],31, C_text("chicken.base#exact-integer-sqrt"));
lf[608]=C_h_intern(&lf[608],18, C_text("exact-integer-sqrt"));
lf[609]=C_h_intern(&lf[609],4, C_text("sqrt"));
lf[610]=C_h_intern(&lf[610],35, C_text("chicken.base#exact-integer-nth-root"));
lf[611]=C_h_intern(&lf[611],32, C_text("##sys#exact-integer-nth-root/loc"));
lf[612]=C_h_intern(&lf[612],22, C_text("exact-integer-nth-root"));
lf[613]=C_h_intern(&lf[613],4, C_text("expt"));
lf[614]=C_decode_literal(C_heaptop,C_text("\376B\000\0006exponent of exact 0 with complex argument is undefined"));
lf[615]=C_h_intern(&lf[615],9, C_text("##sys#gcd"));
lf[616]=C_h_intern(&lf[616],3, C_text("gcd"));
lf[617]=C_h_intern(&lf[617],10, C_text("scheme#gcd"));
lf[618]=C_h_intern(&lf[618],9, C_text("##sys#lcm"));
lf[619]=C_h_intern(&lf[619],3, C_text("lcm"));
lf[620]=C_h_intern(&lf[620],10, C_text("scheme#lcm"));
lf[621]=C_h_intern(&lf[621],31, C_text("##sys#integer->string/recursive"));
lf[622]=C_h_intern(&lf[622],20, C_text("##sys#number->string"));
lf[623]=C_h_intern(&lf[623],29, C_text("##sys#extended-number->string"));
lf[624]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001/"));
lf[625]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001+"));
lf[626]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[627]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001i"));
lf[628]=C_h_intern(&lf[628],14, C_text("number->string"));
lf[631]=C_h_intern(&lf[631],1, C_text("e"));
lf[632]=C_h_intern(&lf[632],1, C_text("i"));
lf[633]=C_decode_literal(C_heaptop,C_text("\376U+inf.0\000"));
lf[634]=C_decode_literal(C_heaptop,C_text("\376U-inf.0\000"));
lf[635]=C_h_intern(&lf[635],3, C_text("neg"));
lf[636]=C_h_intern(&lf[636],3, C_text("pos"));
lf[637]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005inf.0"));
lf[638]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005nan.0"));
lf[639]=C_h_intern(&lf[639],21, C_text("scheme#string->number"));
lf[640]=C_h_intern(&lf[640],14, C_text("string->number"));
lf[641]=C_h_intern(&lf[641],20, C_text("##sys#string->number"));
lf[642]=C_h_intern(&lf[642],20, C_text("##sys#fixnum->string"));
lf[643]=C_h_intern(&lf[643],20, C_text("##sys#flonum->string"));
lf[644]=C_h_intern(&lf[644],21, C_text("##sys#integer->string"));
lf[645]=C_h_intern(&lf[645],20, C_text("chicken.base#equal=\077"));
lf[646]=C_h_intern(&lf[646],11, C_text("##sys#snafu"));
lf[647]=C_h_intern(&lf[647],11, C_text("##sys#fnord"));
lf[648]=C_h_intern(&lf[648],19, C_text("##sys#intern-symbol"));
lf[649]=C_h_intern(&lf[649],20, C_text("##sys#intern-keyword"));
lf[650]=C_h_intern(&lf[650],22, C_text("##sys#interned-symbol\077"));
lf[651]=C_h_intern(&lf[651],20, C_text("##sys#string->symbol"));
lf[652]=C_h_intern(&lf[652],20, C_text("##sys#symbol->string"));
lf[653]=C_h_intern(&lf[653],21, C_text("scheme#symbol->string"));
lf[654]=C_h_intern(&lf[654],14, C_text("symbol->string"));
lf[655]=C_h_intern(&lf[655],21, C_text("scheme#string->symbol"));
lf[656]=C_h_intern(&lf[656],14, C_text("string->symbol"));
lf[657]=C_h_intern(&lf[657],38, C_text("chicken.base#string->uninterned-symbol"));
lf[658]=C_h_intern(&lf[658],25, C_text("string->uninterned-symbol"));
lf[659]=C_h_intern(&lf[659],19, C_text("chicken.base#gensym"));
lf[660]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001g"));
lf[661]=C_h_intern(&lf[661],6, C_text("gensym"));
lf[662]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042argument is not a string or symbol"));
lf[663]=C_h_intern(&lf[663],26, C_text("chicken.base#symbol-append"));
lf[664]=C_h_intern(&lf[664],13, C_text("symbol-append"));
lf[665]=C_h_intern(&lf[665],16, C_text("chicken.keyword#"));
lf[666]=C_h_intern(&lf[666],24, C_text("chicken.keyword#keyword\077"));
lf[667]=C_h_intern(&lf[667],31, C_text("chicken.keyword#string->keyword"));
lf[668]=C_h_intern(&lf[668],15, C_text("string->keyword"));
lf[669]=C_h_intern(&lf[669],31, C_text("chicken.keyword#keyword->string"));
lf[670]=C_h_intern(&lf[670],15, C_text("keyword->string"));
lf[671]=C_decode_literal(C_heaptop,C_text("\376B\000\000!bad argument type - not a keyword"));
lf[672]=C_h_intern(&lf[672],3, C_text("tag"));
lf[673]=C_h_intern(&lf[673],27, C_text("chicken.keyword#get-keyword"));
lf[674]=C_h_intern(&lf[674],11, C_text("get-keyword"));
lf[675]=C_h_intern(&lf[675],17, C_text("##sys#get-keyword"));
lf[676]=C_h_intern(&lf[676],13, C_text("chicken.blob#"));
lf[677]=C_h_intern(&lf[677],15, C_text("##sys#make-blob"));
lf[678]=C_h_intern(&lf[678],22, C_text("chicken.blob#make-blob"));
lf[679]=C_h_intern(&lf[679],9, C_text("make-blob"));
lf[680]=C_h_intern(&lf[680],18, C_text("chicken.blob#blob\077"));
lf[681]=C_h_intern(&lf[681],22, C_text("chicken.blob#blob-size"));
lf[682]=C_h_intern(&lf[682],9, C_text("blob-size"));
lf[683]=C_h_intern(&lf[683],25, C_text("chicken.blob#string->blob"));
lf[684]=C_h_intern(&lf[684],12, C_text("string->blob"));
lf[685]=C_h_intern(&lf[685],25, C_text("chicken.blob#blob->string"));
lf[686]=C_h_intern(&lf[686],12, C_text("blob->string"));
lf[687]=C_h_intern(&lf[687],19, C_text("chicken.blob#blob=\077"));
lf[688]=C_h_intern(&lf[688],6, C_text("blob=\077"));
lf[689]=C_h_intern(&lf[689],11, C_text("make-vector"));
lf[690]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020size is negative"));
lf[691]=C_h_intern(&lf[691],17, C_text("##sys#make-vector"));
lf[692]=C_h_intern(&lf[692],12, C_text("list->vector"));
lf[693]=C_h_intern(&lf[693],12, C_text("vector->list"));
lf[694]=C_h_intern(&lf[694],12, C_text("vector-fill!"));
lf[695]=C_h_intern(&lf[695],12, C_text("vector-copy!"));
lf[696]=C_decode_literal(C_heaptop,C_text("\376B\000\000)cannot copy vector - count exceeds length"));
lf[697]=C_h_intern(&lf[697],9, C_text("subvector"));
lf[698]=C_h_intern(&lf[698],13, C_text("vector-resize"));
lf[700]=C_h_intern(&lf[700],9, C_text("char-name"));
lf[701]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026invalid character name"));
lf[702]=C_h_intern(&lf[702],36, C_text("##sys#call-with-current-continuation"));
lf[703]=C_h_intern(&lf[703],23, C_text("##sys#call-with-cthulhu"));
lf[704]=C_h_intern(&lf[704],22, C_text("##sys#call-with-values"));
lf[705]=C_h_intern(&lf[705],14, C_text("##sys#for-each"));
lf[706]=C_h_intern(&lf[706],8, C_text("for-each"));
lf[707]=C_h_intern(&lf[707],9, C_text("##sys#map"));
lf[708]=C_h_intern(&lf[708],3, C_text("map"));
lf[709]=C_h_intern(&lf[709],19, C_text("##sys#dynamic-winds"));
lf[710]=C_h_intern(&lf[710],18, C_text("##sys#dynamic-wind"));
lf[712]=C_h_intern(&lf[712],16, C_text("input-port-open\077"));
lf[713]=C_h_intern(&lf[713],17, C_text("output-port-open\077"));
lf[714]=C_h_intern(&lf[714],16, C_text("##sys#check-port"));
lf[715]=C_h_intern(&lf[715],12, C_text("port-closed\077"));
lf[716]=C_h_intern(&lf[716],15, C_text("##sys#make-port"));
lf[717]=C_h_intern(&lf[717],24, C_text("##sys#dispatch-interrupt"));
lf[718]=C_h_intern_kw(&lf[718],10, C_text("file-error"));
lf[719]=C_h_intern(&lf[719],9, C_text("read-char"));
lf[720]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030cannot read from port - "));
lf[721]=C_h_intern(&lf[721],19, C_text("##sys#peek-c-string"));
lf[722]=C_h_intern(&lf[722],18, C_text("##sys#update-errno"));
lf[723]=C_h_intern(&lf[723],9, C_text("peek-char"));
lf[724]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030cannot read from port - "));
lf[725]=C_h_intern(&lf[725],12, C_text("read-string!"));
lf[726]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030cannot read from port - "));
lf[727]=C_h_intern(&lf[727],9, C_text("read-line"));
lf[728]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030cannot read from port - "));
lf[729]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[730]=C_h_intern(&lf[730],23, C_text("##sys#stream-port-class"));
lf[731]=C_h_intern(&lf[731],20, C_text("##sys#open-file-port"));
lf[732]=C_h_intern(&lf[732],20, C_text("##sys#standard-input"));
lf[733]=C_h_intern(&lf[733],21, C_text("##sys#standard-output"));
lf[734]=C_h_intern(&lf[734],20, C_text("##sys#standard-error"));
lf[735]=C_h_intern(&lf[735],22, C_text("##sys#check-input-port"));
lf[736]=C_h_intern(&lf[736],23, C_text("##sys#check-output-port"));
lf[737]=C_h_intern(&lf[737],21, C_text("##sys#check-open-port"));
lf[738]=C_h_intern(&lf[738],18, C_text("current-input-port"));
lf[739]=C_h_intern(&lf[739],19, C_text("current-output-port"));
lf[740]=C_h_intern(&lf[740],18, C_text("current-error-port"));
lf[741]=C_h_intern(&lf[741],15, C_text("##sys#tty-port\077"));
lf[742]=C_h_intern(&lf[742],27, C_text("##sys#peek-unsigned-integer"));
lf[743]=C_h_intern(&lf[743],15, C_text("##sys#port-data"));
lf[744]=C_h_intern(&lf[744],20, C_text("##sys#set-port-data!"));
lf[745]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001r"));
lf[746]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001w"));
lf[747]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[748]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023cannot open file - "));
lf[749]=C_h_intern(&lf[749],6, C_text("stream"));
lf[750]=C_h_intern_kw(&lf[750],6, C_text("binary"));
lf[751]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001b"));
lf[752]=C_h_intern_kw(&lf[752],4, C_text("text"));
lf[753]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[754]=C_h_intern_kw(&lf[754],6, C_text("append"));
lf[755]=C_decode_literal(C_heaptop,C_text("\376B\000\000&cannot use append mode with input file"));
lf[756]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001a"));
lf[757]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023invalid file option"));
lf[758]=C_h_intern(&lf[758],15, C_text("open-input-file"));
lf[759]=C_h_intern(&lf[759],16, C_text("open-output-file"));
lf[760]=C_h_intern(&lf[760],16, C_text("close-input-port"));
lf[761]=C_h_intern(&lf[761],17, C_text("close-output-port"));
lf[762]=C_h_intern(&lf[762],18, C_text("##sys#file-exists\077"));
lf[763]=C_decode_literal(C_heaptop,C_text("\376B\000\000(system error while trying to access file"));
lf[764]=C_h_intern(&lf[764],19, C_text("##sys#make-c-string"));
lf[765]=C_h_intern(&lf[765],18, C_text("##sys#flush-output"));
lf[766]=C_h_intern(&lf[766],12, C_text("flush-output"));
lf[767]=C_h_intern(&lf[767],15, C_text("##sys#port-line"));
lf[768]=C_h_intern(&lf[768],21, C_text("##sys#decorate-lambda"));
lf[769]=C_h_intern(&lf[769],23, C_text("##sys#lambda-decoration"));
lf[770]=C_h_intern(&lf[770],22, C_text("##sys#make-lambda-info"));
lf[771]=C_h_intern(&lf[771],18, C_text("##sys#lambda-info\077"));
lf[772]=C_h_intern(&lf[772],17, C_text("##sys#lambda-info"));
lf[773]=C_h_intern(&lf[773],25, C_text("##sys#lambda-info->string"));
lf[774]=C_h_intern(&lf[774],10, C_text("##sys#read"));
lf[775]=C_h_intern(&lf[775],21, C_text("procedure-information"));
lf[776]=C_h_intern(&lf[776],6, C_text("setter"));
lf[778]=C_h_intern(&lf[778],12, C_text("##sys#setter"));
lf[779]=C_h_intern(&lf[779],18, C_text("getter-with-setter"));
lf[781]=C_h_intern(&lf[781],30, C_text("##sys#current-parameter-vector"));
lf[782]=C_decode_literal(C_heaptop,C_text("\376\000\000\000\000"));
lf[783]=C_h_intern(&lf[783],11, C_text("char-ready\077"));
lf[784]=C_h_intern(&lf[784],17, C_text("##sys#read-char-0"));
lf[785]=C_h_intern(&lf[785],20, C_text("##sys#read-char/port"));
lf[786]=C_h_intern(&lf[786],17, C_text("##sys#peek-char-0"));
lf[787]=C_h_intern(&lf[787],4, C_text("read"));
lf[788]=C_h_intern(&lf[788],28, C_text("##sys#default-read-info-hook"));
lf[789]=C_h_intern(&lf[789],33, C_text("##sys#read-error-with-line-number"));
lf[790]=C_h_intern(&lf[790],22, C_text("##sys#read-prompt-hook"));
lf[791]=C_h_intern(&lf[791],21, C_text("##sys#infix-list-hook"));
lf[792]=C_h_intern(&lf[792],23, C_text("##sys#sharp-number-hook"));
lf[793]=C_h_intern(&lf[793],16, C_text("##sys#read-error"));
lf[794]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032invalid `#...\047 read syntax"));
lf[795]=C_h_intern(&lf[795],24, C_text("##sys#current-read-table"));
lf[796]=C_h_intern(&lf[796],18, C_text("##sys#read-warning"));
lf[797]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006(line "));
lf[798]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002) "));
lf[799]=C_h_intern_kw(&lf[799],12, C_text("syntax-error"));
lf[800]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006(line "));
lf[801]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002) "));
lf[802]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000,\376\003\000\000\002\376\377\012\000\000;\376\003\000\000\002\376\377\012\000\000(\376\003\000\000\002\376\377\012\000\000)\376\003\000\000\002\376\377\012\000\000\047\376\003\000\000\002\376\377\012\000\000\042\376\003\000\000\002\376\377\012\000\000[\376\003\000"
"\000\002\376\377\012\000\000]\376\003\000\000\002\376\377\012\000\000{\376\003\000\000\002\376\377\012\000\000}\376\377\016"));
lf[803]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032unexpected list terminator"));
lf[804]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022reserved character"));
lf[805]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032invalid escape-sequence \047\134"));
lf[806]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\047"));
lf[807]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034unterminated string constant"));
lf[808]=C_h_intern(&lf[808],23, C_text("##sys#char->utf8-string"));
lf[809]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023unterminated string"));
lf[810]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001x"));
lf[811]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022bad surrogate pair"));
lf[812]=C_h_intern(&lf[812],27, C_text("##sys#surrogates->codepoint"));
lf[813]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001u"));
lf[814]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032unpaired escaped surrogate"));
lf[815]=C_h_intern(&lf[815],24, C_text("##sys#unicode-surrogate\077"));
lf[816]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001u"));
lf[817]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032invalid escape (surrogate)"));
lf[818]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001U"));
lf[819]=C_decode_literal(C_heaptop,C_text("\376B\000\0006escaped whitespace, but no newline - collapsing anyway"));
lf[820]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023unterminated string"));
lf[821]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[822]=C_decode_literal(C_heaptop,C_text("\376B\000\000\077undefined escape sequence in string - probably forgot backslash"));
lf[823]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023, starting in line "));
lf[824]=C_h_intern(&lf[824],9, C_text("list-info"));
lf[825]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030list-terminator mismatch"));
lf[826]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021unterminated list"));
lf[827]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027missing list terminator"));
lf[828]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022invalid use of `.\047"));
lf[829]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002.:"));
lf[830]=C_h_intern_kw(&lf[830],6, C_text("suffix"));
lf[831]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001."));
lf[832]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001."));
lf[833]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015missing token"));
lf[834]=C_h_intern(&lf[834],18, C_text("##sys#list->vector"));
lf[835]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025invalid vector syntax"));
lf[836]=C_h_intern(&lf[836],11, C_text("symbol-info"));
lf[837]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001."));
lf[838]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022invalid use of `.\047"));
lf[839]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042unexpected prefix in number syntax"));
lf[840]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025illegal number syntax"));
lf[841]=C_decode_literal(C_heaptop,C_text("\376B\000\000!unexpected end of numeric literal"));
lf[842]=C_decode_literal(C_heaptop,C_text("\376B\000\0000illegal number syntax - invalid exactness prefix"));
lf[843]=C_decode_literal(C_heaptop,C_text("\376B\000\000!unexpected end of numeric literal"));
lf[844]=C_decode_literal(C_heaptop,C_text("\376B\000\000%illegal number syntax - invalid radix"));
lf[845]=C_decode_literal(C_heaptop,C_text("\376B\000\000Eattempt to read expression from something that looks like binary data"));
lf[846]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001:"));
lf[847]=C_decode_literal(C_heaptop,C_text("\376B\000\000\052escaped symbol syntax spans multiple lines"));
lf[848]=C_decode_literal(C_heaptop,C_text("\376B\000\0006unexpected end of file while reading escaped character"));
lf[849]=C_h_intern_kw(&lf[849],6, C_text("prefix"));
lf[850]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027unknown named character"));
lf[851]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032unterminated block-comment"));
lf[852]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002##"));
lf[853]=C_h_intern(&lf[853],5, C_text("quote"));
lf[854]=C_h_intern(&lf[854],10, C_text("quasiquote"));
lf[855]=C_h_intern(&lf[855],16, C_text("unquote-splicing"));
lf[856]=C_h_intern(&lf[856],7, C_text("unquote"));
lf[857]=C_decode_literal(C_heaptop,C_text("\376B\000\000,unexpected end of input after reading #-sign"));
lf[858]=C_decode_literal(C_heaptop,C_text("\376B\000\000%unexpected end of input after reading"));
lf[859]=C_decode_literal(C_heaptop,C_text("\376B\000\000!invalid parameterized read syntax"));
lf[860]=C_decode_literal(C_heaptop,C_text("\376B\000\0006unexpected end of input while reading `#c...\047 sequence"));
lf[861]=C_decode_literal(C_heaptop,C_text("\376B\000\000\052invalid case specifier in `#c...\047 sequence"));
lf[862]=C_h_intern(&lf[862],11, C_text("quasisyntax"));
lf[863]=C_h_intern(&lf[863],29, C_text("##sys#read-bytevector-literal"));
lf[864]=C_h_intern(&lf[864],8, C_text("location"));
lf[865]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015empty keyword"));
lf[866]=C_h_intern(&lf[866],11, C_text("cond-expand"));
lf[867]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\004\001else\376\377\016"));
lf[868]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003eof"));
lf[869]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003bwp"));
lf[870]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010optional"));
lf[871]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004rest"));
lf[872]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003key"));
lf[873]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002#!"));
lf[874]=C_h_intern(&lf[874],16, C_text("##sys#read-marks"));
lf[875]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022invalid `#!\047 token"));
lf[876]=C_h_intern(&lf[876],20, C_text("##sys#user-read-hook"));
lf[877]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000[\376\003\000\000\002\376\377\012\000\000]\376\003\000\000\002\376\377\012\000\000{\376\003\000\000\002\376\377\012\000\000}\376\377\016"));
lf[878]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000|\376\377\016"));
lf[879]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035UTF-8 codepoint out of range:"));
lf[880]=C_decode_literal(C_heaptop,C_text("\376B\000\000 invalid hex-code in blob-literal"));
lf[881]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036unexpected end of blob literal"));
lf[882]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036invalid sharp-sign read syntax"));
lf[883]=C_h_intern(&lf[883],18, C_text("##sys#write-char-0"));
lf[884]=C_h_intern(&lf[884],21, C_text("##sys#write-char/port"));
lf[885]=C_h_intern(&lf[885],10, C_text("write-char"));
lf[886]=C_h_intern(&lf[886],5, C_text("write"));
lf[887]=C_h_intern(&lf[887],11, C_text("##sys#print"));
lf[888]=C_h_intern(&lf[888],7, C_text("display"));
lf[889]=C_h_intern(&lf[889],5, C_text("print"));
lf[891]=C_h_intern(&lf[891],24, C_text("##sys#print-length-limit"));
lf[893]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003..."));
lf[894]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003..."));
lf[895]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\134x"));
lf[896]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\012\000\000(\376\003\000\000\002\376\377\012\000\000)\376\003\000\000\002\376\377\012\000\000,\376\003\000\000\002\376\377\012\000\000[\376\003\000\000\002\376\377\012\000\000]\376\003\000\000\002\376\377\012\000\000{\376\003\000\000\002\376\377\012\000\000}\376\003\000"
"\000\002\376\377\012\000\000\047\376\003\000\000\002\376\377\012\000\000\042\376\003\000\000\002\376\377\012\000\000;\376\003\000\000\002\376\377\012\000\000 \376\003\000\000\002\376\377\012\000\000`\376\003\000\000\002\376\377\012\000\000|\376\003\000\000\002\376\377\012\000\000\134\376\377\016"));
lf[897]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376B\000\000\006#!rest\376\003\000\000\002\376B\000\000\005#!key\376\003\000\000\002\376B\000\000\012#!optional\376\377\016"));
lf[898]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002()"));
lf[899]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002#t"));
lf[900]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002#f"));
lf[901]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005#!eof"));
lf[902]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016#<unspecified>"));
lf[903]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005#!bwp"));
lf[904]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002#\134"));
lf[905]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020#<unbound value>"));
lf[906]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033#<invalid immediate object>"));
lf[907]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033#<invalid forwarded object>"));
lf[908]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002#:"));
lf[909]=C_h_intern(&lf[909],21, C_text("##sys#pointer->string"));
lf[910]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\134\042"));
lf[911]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\134\134"));
lf[912]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003 . "));
lf[913]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003#${"));
lf[914]=C_h_intern(&lf[914],21, C_text("##sys#user-print-hook"));
lf[915]=C_h_intern(&lf[915],23, C_text("##sys#procedure->string"));
lf[916]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013#<locative>"));
lf[917]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016#<lambda info "));
lf[918]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\042>"));
lf[919]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016#<input port \042"));
lf[920]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017#<output port \042"));
lf[921]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010#<port \042"));
lf[922]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003#()"));
lf[923]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002#("));
lf[924]=C_decode_literal(C_heaptop,C_text("\376B\000\000$unprintable block object encountered"));
lf[925]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014#<procedure "));
lf[926]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001>"));
lf[927]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014#<procedure>"));
lf[928]=C_h_intern(&lf[928],21, C_text("##sys#record-printers"));
lf[929]=C_h_intern(&lf[929],14, C_text("record-printer"));
lf[930]=C_h_intern(&lf[930],19, C_text("set-record-printer!"));
lf[931]=C_h_intern(&lf[931],29, C_text("##sys#register-record-printer"));
lf[932]=C_h_intern(&lf[932],9, C_text("condition"));
lf[933]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\007\001message"));
lf[934]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\047: "));
lf[935]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\047>"));
lf[936]=C_decode_literal(C_heaptop,C_text("\376B\000\000##<Error in printer of record type `"));
lf[937]=C_h_intern(&lf[937],40, C_text("chicken.condition#with-exception-handler"));
lf[938]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[939]=C_h_intern(&lf[939],6, C_text("thread"));
lf[940]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[941]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002#<"));
lf[942]=C_h_intern(&lf[942],29, C_text("##sys#with-print-length-limit"));
lf[943]=C_h_intern(&lf[943],16, C_text("##sys#copy-bytes"));
lf[944]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022string buffer full"));
lf[945]=C_h_intern(&lf[945],22, C_text("##sys#scan-buffer-line"));
lf[946]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[947]=C_h_intern(&lf[947],23, C_text("##sys#string-port-class"));
lf[948]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\015"));
lf[949]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\015"));
lf[950]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[951]=C_h_intern(&lf[951],17, C_text("open-input-string"));
lf[952]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010(string)"));
lf[953]=C_h_intern(&lf[953],6, C_text("string"));
lf[954]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010(string)"));
lf[955]=C_h_intern(&lf[955],17, C_text("get-output-string"));
lf[956]=C_decode_literal(C_heaptop,C_text("\376B\000\000$argument is not a string-output-port"));
lf[957]=C_h_intern(&lf[957],21, C_text("##sys#print-to-string"));
lf[958]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021#<tagged pointer "));
lf[959]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001 "));
lf[960]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001>"));
lf[961]=C_h_intern(&lf[961],22, C_text("##sys#pointer->address"));
lf[962]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014#<pointer 0x"));
lf[963]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001>"));
lf[964]=C_h_intern(&lf[964],20, C_text("##sys#current-thread"));
lf[965]=C_h_intern(&lf[965],27, C_text("##sys#peek-nonnull-c-string"));
lf[966]=C_h_intern(&lf[966],29, C_text("##sys#really-print-call-chain"));
lf[967]=C_h_intern(&lf[967],9, C_text("frameinfo"));
lf[968]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002] "));
lf[969]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003\011  "));
lf[970]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002\012\011"));
lf[971]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005\011<--\012"));
lf[972]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020\012\011Call history:\012"));
lf[973]=C_h_intern(&lf[973],16, C_text("print-call-chain"));
lf[974]=C_h_intern(&lf[974],25, C_text("##sys#user-interrupt-hook"));
lf[975]=C_h_intern_kw(&lf[975],14, C_text("user-interrupt"));
lf[976]=C_h_intern(&lf[976],23, C_text("##sys#primordial-thread"));
lf[979]=C_h_intern(&lf[979],22, C_text("##sys#force-finalizers"));
lf[980]=C_h_intern(&lf[980],27, C_text("chicken.gc#force-finalizers"));
lf[981]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036[debug] forcing finalizers...\012"));
lf[982]=C_h_intern(&lf[982],24, C_text("##sys#pending-finalizers"));
lf[983]=C_h_intern(&lf[983],28, C_text("##sys#run-pending-finalizers"));
lf[984]=C_h_intern(&lf[984],21, C_text("##sys#dump-heap-state"));
lf[985]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[986]=C_h_intern(&lf[986],19, C_text("##sys#reset-handler"));
lf[987]=C_h_intern(&lf[987],18, C_text("chicken.condition#"));
lf[988]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\016\001user-interrupt\376\377\016"));
lf[989]=C_h_intern(&lf[989],23, C_text("chicken.condition#abort"));
lf[990]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[991]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012\012Warning: "));
lf[992]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007\012Note: "));
lf[993]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\007\001message"));
lf[994]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\011\001arguments"));
lf[995]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\012\001call-chain"));
lf[996]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\010\001location"));
lf[997]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\005\001errno"));
lf[998]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\004\001type\376\377\016"));
lf[999]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\006\001syntax\376\377\016"));
lf[1000]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\006\001bounds\376\377\016"));
lf[1001]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\012\001arithmetic\376\377\016"));
lf[1002]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\003\001i/o\376\003\000\000\002\376\001\000\000\004\001file\376\377\016"));
lf[1003]=C_h_intern_kw(&lf[1003],13, C_text("runtime-error"));
lf[1004]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\007\001runtime\376\377\016"));
lf[1005]=C_h_intern_kw(&lf[1005],13, C_text("process-error"));
lf[1006]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\007\001process\376\377\016"));
lf[1007]=C_h_intern_kw(&lf[1007],13, C_text("network-error"));
lf[1008]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\003\001i/o\376\003\000\000\002\376\001\000\000\003\001net\376\377\016"));
lf[1009]=C_h_intern_kw(&lf[1009],21, C_text("network-timeout-error"));
lf[1010]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\003\001i/o\376\003\000\000\002\376\001\000\000\003\001net\376\003\000\000\002\376\001\000\000\007\001timeout\376\377\016"));
lf[1011]=C_h_intern_kw(&lf[1011],11, C_text("limit-error"));
lf[1012]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\007\001runtime\376\003\000\000\002\376\001\000\000\005\001limit\376\377\016"));
lf[1013]=C_h_intern_kw(&lf[1013],11, C_text("arity-error"));
lf[1014]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\005\001arity\376\377\016"));
lf[1015]=C_h_intern_kw(&lf[1015],12, C_text("access-error"));
lf[1016]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\006\001access\376\377\016"));
lf[1017]=C_h_intern_kw(&lf[1017],12, C_text("domain-error"));
lf[1018]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\006\001domain\376\377\016"));
lf[1019]=C_h_intern_kw(&lf[1019],12, C_text("memory-error"));
lf[1020]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\003\000\000\002\376\001\000\000\006\001memory\376\377\016"));
lf[1021]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\377\016"));
lf[1022]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\007\001message"));
lf[1023]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032exception handler returned"));
lf[1024]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\011\001arguments"));
lf[1025]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\010\001location"));
lf[1026]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\377\016"));
lf[1027]=C_h_intern(&lf[1027],31, C_text("##sys#current-exception-handler"));
lf[1028]=C_h_intern(&lf[1028],24, C_text("chicken.condition#signal"));
lf[1029]=C_h_intern(&lf[1029],19, C_text("##sys#error-handler"));
lf[1030]=C_h_intern(&lf[1030],20, C_text("##sys#last-exception"));
lf[1031]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\022\001uncaught-exception\376\001\000\000\006\001reason"));
lf[1032]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\022\001uncaught-exception\376\377\016"));
lf[1033]=C_h_intern(&lf[1033],3, C_text("exn"));
lf[1034]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\007\001message"));
lf[1035]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\011\001arguments"));
lf[1036]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001exn\376\001\000\000\010\001location"));
lf[1037]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001("));
lf[1038]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002) "));
lf[1039]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1040]=C_decode_literal(C_heaptop,C_text("\376B\000\000 <exn: has no `message\047 property>"));
lf[1041]=C_h_intern(&lf[1041],14, C_text("user-interrupt"));
lf[1042]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030\012\052\052\052 user interrupt \052\052\052\012"));
lf[1043]=C_h_intern(&lf[1043],18, C_text("uncaught-exception"));
lf[1044]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\022\001uncaught-exception\376\001\000\000\006\001reason"));
lf[1045]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022uncaught exception"));
lf[1046]=C_h_intern(&lf[1046],43, C_text("chicken.condition#current-exception-handler"));
lf[1047]=C_h_intern(&lf[1047],25, C_text("current-exception-handler"));
lf[1049]=C_decode_literal(C_heaptop,C_text("\376B\000\000%argument is not an even property list"));
lf[1050]=C_h_intern(&lf[1050],41, C_text("chicken.condition#make-property-condition"));
lf[1051]=C_h_intern(&lf[1051],23, C_text("make-property-condition"));
lf[1052]=C_h_intern(&lf[1052],42, C_text("chicken.condition#make-composite-condition"));
lf[1053]=C_h_intern(&lf[1053],24, C_text("make-composite-condition"));
lf[1054]=C_h_intern(&lf[1054],27, C_text("chicken.condition#condition"));
lf[1055]=C_h_intern(&lf[1055],28, C_text("chicken.condition#condition\077"));
lf[1056]=C_h_intern(&lf[1056],33, C_text("chicken.condition#condition->list"));
lf[1057]=C_h_intern(&lf[1057],15, C_text("condition->list"));
lf[1058]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042argument is not a condition object"));
lf[1059]=C_h_intern(&lf[1059],37, C_text("chicken.condition#condition-predicate"));
lf[1060]=C_h_intern(&lf[1060],45, C_text("chicken.condition#condition-property-accessor"));
lf[1061]=C_h_intern(&lf[1061],27, C_text("condition-property-accessor"));
lf[1062]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036condition has no such property"));
lf[1063]=C_h_intern(&lf[1063],40, C_text("chicken.condition#get-condition-property"));
lf[1064]=C_h_intern(&lf[1064],37, C_text("chicken.condition#print-error-message"));
lf[1065]=C_h_intern(&lf[1065],19, C_text("print-error-message"));
lf[1066]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[1067]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001("));
lf[1068]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002) "));
lf[1069]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[1070]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\016\001user-interrupt\376\377\016"));
lf[1071]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030: \052\052\052 user interrupt \052\052\052"));
lf[1072]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016: <condition> "));
lf[1073]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[1074]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026: uncaught exception: "));
lf[1075]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005Error"));
lf[1076]=C_h_intern(&lf[1076],28, C_text("##sys#show-exception-warning"));
lf[1077]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[1078]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002 ("));
lf[1079]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007Warning"));
lf[1080]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad argument count - received "));
lf[1081]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016 but expected "));
lf[1082]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035too few arguments - received "));
lf[1083]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016 but expected "));
lf[1084]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021bad argument type"));
lf[1085]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020unbound variable"));
lf[1086]=C_decode_literal(C_heaptop,C_text("\376B\000\000!bad argument type - not a keyword"));
lf[1087]=C_decode_literal(C_heaptop,C_text("\376B\000\000\015out of memory"));
lf[1088]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020division by zero"));
lf[1089]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014out of range"));
lf[1090]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025call of non-procedure"));
lf[1091]=C_decode_literal(C_heaptop,C_text("\376B\000\000+continuation cannot receive multiple values"));
lf[1092]=C_decode_literal(C_heaptop,C_text("\376B\000\000)bad argument type - not a non-cyclic list"));
lf[1093]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022recursion too deep"));
lf[1094]=C_decode_literal(C_heaptop,C_text("\376B\000\0007inexact number cannot be represented as an exact number"));
lf[1095]=C_decode_literal(C_heaptop,C_text("\376B\000\000%bad argument type - not a proper list"));
lf[1096]=C_decode_literal(C_heaptop,C_text("\376B\000\000 bad argument type - not a fixnum"));
lf[1097]=C_decode_literal(C_heaptop,C_text("\376B\000\000 bad argument type - not a number"));
lf[1098]=C_decode_literal(C_heaptop,C_text("\376B\000\000 bad argument type - not a string"));
lf[1099]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad argument type - not a pair"));
lf[1100]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad argument type - not a list"));
lf[1101]=C_decode_literal(C_heaptop,C_text("\376B\000\000#bad argument type - not a character"));
lf[1102]=C_decode_literal(C_heaptop,C_text("\376B\000\000 bad argument type - not a vector"));
lf[1103]=C_decode_literal(C_heaptop,C_text("\376B\000\000 bad argument type - not a symbol"));
lf[1104]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016stack overflow"));
lf[1105]=C_decode_literal(C_heaptop,C_text("\376B\000\0008bad argument type - not a structure of the required type"));
lf[1106]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad argument type - not a blob"));
lf[1107]=C_decode_literal(C_heaptop,C_text("\376B\000\000#locative refers to reclaimed object"));
lf[1108]=C_decode_literal(C_heaptop,C_text("\376B\000\000&bad argument type - not a block object"));
lf[1109]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047bad argument type - not a number vector"));
lf[1110]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042bad argument type - not an integer"));
lf[1111]=C_decode_literal(C_heaptop,C_text("\376B\000\000+bad argument type - not an unsigned integer"));
lf[1112]=C_decode_literal(C_heaptop,C_text("\376B\000\000!bad argument type - not a pointer"));
lf[1113]=C_decode_literal(C_heaptop,C_text("\376B\000\000(bad argument type - not a tagged pointer"));
lf[1114]=C_decode_literal(C_heaptop,C_text("\376B\000\000 bad argument type - not a flonum"));
lf[1115]=C_decode_literal(C_heaptop,C_text("\376B\000\000#bad argument type - not a procedure"));
lf[1116]=C_decode_literal(C_heaptop,C_text("\376B\000\000 bad argument type - invalid base"));
lf[1117]=C_decode_literal(C_heaptop,C_text("\376B\000\000/recursion too deep or circular data encountered"));
lf[1118]=C_decode_literal(C_heaptop,C_text("\376B\000\000!bad argument type - not a boolean"));
lf[1119]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042bad argument type - not a locative"));
lf[1120]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad argument type - not a port"));
lf[1121]=C_decode_literal(C_heaptop,C_text("\376B\000\0002bad argument type - not a port of the correct type"));
lf[1122]=C_decode_literal(C_heaptop,C_text("\376B\000\000%bad argument type - not an input-port"));
lf[1123]=C_decode_literal(C_heaptop,C_text("\376B\000\000&bad argument type - not an output-port"));
lf[1124]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023port already closed"));
lf[1125]=C_decode_literal(C_heaptop,C_text("\376B\000\0002cannot represent string with NUL bytes as C string"));
lf[1126]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026segmentation violation"));
lf[1127]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030floating-point exception"));
lf[1128]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023illegal instruction"));
lf[1129]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011bus error"));
lf[1130]=C_decode_literal(C_heaptop,C_text("\376B\000\000\047bad argument type - not an exact number"));
lf[1131]=C_decode_literal(C_heaptop,C_text("\376B\000\000)bad argument type - not an inexact number"));
lf[1132]=C_decode_literal(C_heaptop,C_text("\376B\000\000\036bad argument type - not a real"));
lf[1133]=C_decode_literal(C_heaptop,C_text("\376B\000\0002bad argument type - complex number has no ordering"));
lf[1134]=C_decode_literal(C_heaptop,C_text("\376B\000\000(bad argument type - not an exact integer"));
lf[1135]=C_decode_literal(C_heaptop,C_text("\376B\000\000#number does not fit in foreign type"));
lf[1136]=C_decode_literal(C_heaptop,C_text("\376B\000\000/cannot compute absolute value of complex number"));
lf[1137]=C_decode_literal(C_heaptop,C_text("\376B\000\000(attempted rest argument access at index "));
lf[1138]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031 but rest list length is "));
lf[1139]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026unknown internal error"));
lf[1140]=C_h_intern(&lf[1140],16, C_text("##sys#structure\077"));
lf[1141]=C_h_intern(&lf[1141],24, C_text("##sys#generic-structure\077"));
lf[1142]=C_h_intern(&lf[1142],10, C_text("##sys#slot"));
lf[1143]=C_h_intern(&lf[1143],10, C_text("##sys#size"));
lf[1144]=C_h_intern(&lf[1144],18, C_text("##sys#make-pointer"));
lf[1145]=C_h_intern(&lf[1145],25, C_text("##sys#make-tagged-pointer"));
lf[1146]=C_h_intern(&lf[1146],14, C_text("##sys#pointer\077"));
lf[1147]=C_h_intern(&lf[1147],26, C_text("##sys#set-pointer-address!"));
lf[1148]=C_h_intern(&lf[1148],17, C_text("##sys#bytevector\077"));
lf[1149]=C_h_intern(&lf[1149],25, C_text("##sys#string->pbytevector"));
lf[1150]=C_h_intern(&lf[1150],16, C_text("##sys#permanent\077"));
lf[1151]=C_h_intern(&lf[1151],19, C_text("##sys#block-address"));
lf[1152]=C_h_intern(&lf[1152],15, C_text("##sys#locative\077"));
lf[1153]=C_h_intern(&lf[1153],20, C_text("##sys#srfi-4-vector\077"));
lf[1154]=C_h_intern(&lf[1154],18, C_text("##sys#null-pointer"));
lf[1155]=C_h_intern(&lf[1155],19, C_text("##sys#null-pointer\077"));
lf[1156]=C_h_intern(&lf[1156],22, C_text("##sys#address->pointer"));
lf[1157]=C_h_intern(&lf[1157],25, C_text("##sys#peek-signed-integer"));
lf[1158]=C_h_intern(&lf[1158],17, C_text("##sys#peek-fixnum"));
lf[1159]=C_h_intern(&lf[1159],15, C_text("##sys#peek-byte"));
lf[1160]=C_h_intern(&lf[1160],24, C_text("##sys#vector->structure!"));
lf[1161]=C_h_intern(&lf[1161],17, C_text("##sys#peek-double"));
lf[1162]=C_h_intern(&lf[1162],28, C_text("##sys#peek-and-free-c-string"));
lf[1163]=C_h_intern(&lf[1163],36, C_text("##sys#peek-and-free-nonnull-c-string"));
lf[1164]=C_h_intern(&lf[1164],19, C_text("##sys#poke-c-string"));
lf[1165]=C_h_intern(&lf[1165],18, C_text("##sys#poke-integer"));
lf[1166]=C_h_intern(&lf[1166],17, C_text("##sys#poke-double"));
lf[1167]=C_h_intern(&lf[1167],24, C_text("##sys#peek-c-string-list"));
lf[1168]=C_h_intern(&lf[1168],33, C_text("##sys#peek-and-free-c-string-list"));
lf[1169]=C_h_intern(&lf[1169],22, C_text("##sys#vector->closure!"));
lf[1170]=C_h_intern(&lf[1170],34, C_text("##sys#symbol-has-toplevel-binding\077"));
lf[1171]=C_h_intern(&lf[1171],16, C_text("##sys#copy-words"));
lf[1172]=C_h_intern(&lf[1172],19, C_text("##sys#compare-bytes"));
lf[1173]=C_h_intern(&lf[1173],19, C_text("##sys#block-pointer"));
lf[1174]=C_h_intern(&lf[1174],27, C_text("##sys#foreign-char-argument"));
lf[1175]=C_h_intern(&lf[1175],29, C_text("##sys#foreign-fixnum-argument"));
lf[1176]=C_h_intern(&lf[1176],29, C_text("##sys#foreign-flonum-argument"));
lf[1177]=C_h_intern(&lf[1177],28, C_text("##sys#foreign-block-argument"));
lf[1178]=C_h_intern(&lf[1178],37, C_text("##sys#foreign-struct-wrapper-argument"));
lf[1179]=C_h_intern(&lf[1179],29, C_text("##sys#foreign-string-argument"));
lf[1180]=C_h_intern(&lf[1180],29, C_text("##sys#foreign-symbol-argument"));
lf[1181]=C_h_intern(&lf[1181],30, C_text("##sys#foreign-pointer-argument"));
lf[1182]=C_h_intern(&lf[1182],37, C_text("##sys#foreign-tagged-pointer-argument"));
lf[1183]=C_h_intern(&lf[1183],37, C_text("##sys#foreign-ranged-integer-argument"));
lf[1184]=C_h_intern(&lf[1184],46, C_text("##sys#foreign-unsigned-ranged-integer-argument"));
lf[1185]=C_h_intern(&lf[1185],28, C_text("##sys#default-thread-quantum"));
lf[1186]=C_h_intern(&lf[1186],31, C_text("##sys#default-exception-handler"));
lf[1187]=C_decode_literal(C_heaptop,C_text("\376B\000\000>internal error: default exception handler shouldn\047t be called!"));
lf[1188]=C_h_intern(&lf[1188],17, C_text("##sys#make-thread"));
lf[1189]=C_h_intern(&lf[1189],16, C_text("##sys#make-mutex"));
lf[1190]=C_h_intern(&lf[1190],5, C_text("mutex"));
lf[1191]=C_h_intern(&lf[1191],14, C_text("##sys#schedule"));
lf[1192]=C_h_intern(&lf[1192],19, C_text("##sys#thread-yield!"));
lf[1193]=C_h_intern(&lf[1193],24, C_text("##sys#kill-other-threads"));
lf[1194]=C_h_intern(&lf[1194],28, C_text("##sys#resume-thread-on-event"));
lf[1195]=C_h_intern(&lf[1195],29, C_text("##sys#suspend-thread-on-event"));
lf[1196]=C_h_intern(&lf[1196],27, C_text("##sys#sleep-until-interrupt"));
lf[1197]=C_h_intern(&lf[1197],22, C_text("##sys#make-event-queue"));
lf[1198]=C_h_intern(&lf[1198],11, C_text("event-queue"));
lf[1199]=C_h_intern(&lf[1199],25, C_text("##sys#add-event-to-queue!"));
lf[1200]=C_h_intern(&lf[1200],20, C_text("##sys#get-next-event"));
lf[1201]=C_h_intern(&lf[1201],25, C_text("##sys#wait-for-next-event"));
lf[1202]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023event queue blocked"));
lf[1203]=C_h_intern(&lf[1203],23, C_text("chicken.base#sleep-hook"));
lf[1204]=C_h_intern(&lf[1204],5, C_text("sleep"));
lf[1205]=C_h_intern(&lf[1205],20, C_text("##sys#context-switch"));
lf[1206]=C_h_intern(&lf[1206],19, C_text("##sys#signal-vector"));
lf[1207]=C_h_intern(&lf[1207],20, C_text("##sys#interrupt-hook"));
lf[1208]=C_h_intern(&lf[1208],11, C_text("##sys#errno"));
lf[1209]=C_decode_literal(C_heaptop,C_text("\376B\000\000Lunexpected end of file - unterminated `#{...}\047 item in `here\047 string litera"
"l"));
lf[1210]=C_decode_literal(C_heaptop,C_text("\376B\000\000&unterminated here-doc string literal `"));
lf[1211]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\047"));
lf[1212]=C_decode_literal(C_heaptop,C_text("\376B\000\000$Missing tag after #<< here-doc token"));
lf[1213]=C_decode_literal(C_heaptop,C_text("\376B\000\000!Whitespace after #<< here-doc tag"));
lf[1214]=C_h_intern(&lf[1214],4, C_text("cons"));
lf[1215]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001quote\376\003\000\000\002\376\377\016\376\377\016"));
lf[1216]=C_decode_literal(C_heaptop,C_text("\376B\000\000$Missing tag after #<# here-doc token"));
lf[1217]=C_decode_literal(C_heaptop,C_text("\376B\000\000!Whitespace after #<# here-doc tag"));
lf[1218]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021unreadable object"));
lf[1219]=C_h_intern(&lf[1219],24, C_text("chicken.process-context#"));
lf[1220]=C_h_intern(&lf[1220],40, C_text("chicken.process-context#change-directory"));
lf[1221]=C_h_intern(&lf[1221],16, C_text("change-directory"));
lf[1222]=C_decode_literal(C_heaptop,C_text("\376B\000\000\042cannot change current directory - "));
lf[1223]=C_h_intern(&lf[1223],27, C_text("##sys#change-directory-hook"));
lf[1224]=C_h_intern(&lf[1224],41, C_text("chicken.process-context#current-directory"));
lf[1225]=C_h_intern(&lf[1225],48, C_text("chicken.process-context#get-environment-variable"));
lf[1226]=C_h_intern(&lf[1226],49, C_text("chicken.process-context#set-environment-variable!"));
lf[1227]=C_h_intern(&lf[1227],25, C_text("set-environment-variable!"));
lf[1228]=C_h_intern(&lf[1228],51, C_text("chicken.process-context#unset-environment-variable!"));
lf[1229]=C_h_intern(&lf[1229],27, C_text("unset-environment-variable!"));
lf[1230]=C_h_intern(&lf[1230],49, C_text("chicken.process-context#get-environment-variables"));
lf[1231]=C_h_intern(&lf[1231],43, C_text("chicken.process-context#executable-pathname"));
lf[1232]=C_h_intern(&lf[1232],33, C_text("chicken.process-context#argc+argv"));
lf[1233]=C_h_intern(&lf[1233],28, C_text("chicken.process-context#argv"));
lf[1234]=C_h_intern(&lf[1234],36, C_text("chicken.process-context#program-name"));
lf[1235]=C_h_intern(&lf[1235],46, C_text("chicken.process-context#command-line-arguments"));
lf[1236]=C_h_intern(&lf[1236],11, C_text("chicken.gc#"));
lf[1237]=C_h_intern(&lf[1237],34, C_text("chicken.gc#current-gc-milliseconds"));
lf[1238]=C_h_intern(&lf[1238],25, C_text("chicken.gc#set-gc-report!"));
lf[1239]=C_h_intern(&lf[1239],28, C_text("chicken.gc#memory-statistics"));
lf[1240]=C_h_intern(&lf[1240],20, C_text("##sys#set-finalizer!"));
lf[1241]=C_h_intern(&lf[1241],20, C_text("##sys#init-finalizer"));
lf[1242]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035[debug] too many finalizers ("));
lf[1243]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035), resized max finalizers to "));
lf[1244]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[1245]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035[debug] too many finalizers ("));
lf[1246]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017), forcing ...\012"));
lf[1247]=C_h_intern(&lf[1247],25, C_text("chicken.gc#set-finalizer!"));
lf[1248]=C_h_intern(&lf[1248],9, C_text("finalizer"));
lf[1251]=C_h_intern(&lf[1251],25, C_text("chicken.gc#make-finalizer"));
lf[1252]=C_h_intern(&lf[1252],27, C_text("chicken.gc#add-to-finalizer"));
lf[1253]=C_h_intern(&lf[1253],16, C_text("add-to-finalizer"));
lf[1254]=C_decode_literal(C_heaptop,C_text("\376B\000\000-bad argument type - not a finalizer procedure"));
lf[1255]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014in finalizer"));
lf[1256]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020[debug] running "));
lf[1257]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017 finalizer(s) ("));
lf[1258]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007 live, "));
lf[1259]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020 allocated) ...\012"));
lf[1260]=C_decode_literal(C_heaptop,C_text("\376B\000\000Jre-entry from finalizer thread (maybe (gc #t) was called from a finalizer)"));
lf[1261]=C_h_intern(&lf[1261],13, C_text("chicken.gc#gc"));
lf[1262]=C_h_intern(&lf[1262],12, C_text("##sys#length"));
lf[1263]=C_h_intern(&lf[1263],10, C_text("##sys#cons"));
lf[1264]=C_h_intern(&lf[1264],12, C_text("##sys#vector"));
lf[1265]=C_h_intern(&lf[1265],11, C_text("##sys#apply"));
lf[1266]=C_h_intern(&lf[1266],12, C_text("##sys#values"));
lf[1267]=C_h_intern(&lf[1267],12, C_text("##sys#equal\077"));
lf[1268]=C_h_intern(&lf[1268],9, C_text("##sys#car"));
lf[1269]=C_h_intern(&lf[1269],9, C_text("##sys#cdr"));
lf[1270]=C_h_intern(&lf[1270],11, C_text("##sys#pair\077"));
lf[1271]=C_h_intern(&lf[1271],13, C_text("##sys#vector\077"));
lf[1272]=C_h_intern(&lf[1272],18, C_text("##sys#vector->list"));
lf[1273]=C_h_intern(&lf[1273],19, C_text("##sys#vector-length"));
lf[1274]=C_h_intern(&lf[1274],16, C_text("##sys#vector-ref"));
lf[1275]=C_h_intern(&lf[1275],8, C_text("##sys#>="));
lf[1276]=C_h_intern(&lf[1276],7, C_text("##sys#="));
lf[1277]=C_h_intern(&lf[1277],7, C_text("##sys#+"));
lf[1278]=C_h_intern(&lf[1278],9, C_text("##sys#eq\077"));
lf[1279]=C_h_intern(&lf[1279],10, C_text("##sys#eqv\077"));
lf[1280]=C_h_intern(&lf[1280],11, C_text("##sys#list\077"));
lf[1281]=C_h_intern(&lf[1281],11, C_text("##sys#null\077"));
lf[1282]=C_h_intern(&lf[1282],11, C_text("##sys#map-n"));
lf[1283]=C_h_intern(&lf[1283],19, C_text("##sys#make-locative"));
lf[1284]=C_decode_literal(C_heaptop,C_text("\376B\000\000)locative cannot refer to immediate object"));
lf[1285]=C_h_intern(&lf[1285],8, C_text("u8vector"));
lf[1286]=C_h_intern(&lf[1286],8, C_text("s8vector"));
lf[1287]=C_h_intern(&lf[1287],9, C_text("u16vector"));
lf[1288]=C_h_intern(&lf[1288],9, C_text("s16vector"));
lf[1289]=C_h_intern(&lf[1289],9, C_text("u32vector"));
lf[1290]=C_h_intern(&lf[1290],9, C_text("s32vector"));
lf[1291]=C_h_intern(&lf[1291],9, C_text("u64vector"));
lf[1292]=C_h_intern(&lf[1292],9, C_text("s64vector"));
lf[1293]=C_h_intern(&lf[1293],9, C_text("f32vector"));
lf[1294]=C_h_intern(&lf[1294],9, C_text("f64vector"));
lf[1295]=C_decode_literal(C_heaptop,C_text("\376B\000\000Abad argument type - locative cannot refer to objects of this type"));
lf[1296]=C_h_intern(&lf[1296],14, C_text("chicken.plist#"));
lf[1297]=C_h_intern(&lf[1297],18, C_text("chicken.plist#put!"));
lf[1298]=C_h_intern(&lf[1298],4, C_text("put!"));
lf[1299]=C_h_intern(&lf[1299],17, C_text("chicken.plist#get"));
lf[1300]=C_h_intern(&lf[1300],3, C_text("get"));
lf[1301]=C_h_intern(&lf[1301],10, C_text("##sys#put!"));
lf[1302]=C_h_intern(&lf[1302],9, C_text("##sys#get"));
lf[1303]=C_h_intern(&lf[1303],22, C_text("chicken.plist#remprop!"));
lf[1304]=C_h_intern(&lf[1304],8, C_text("remprop!"));
lf[1305]=C_h_intern(&lf[1305],26, C_text("chicken.plist#symbol-plist"));
lf[1306]=C_h_intern(&lf[1306],28, C_text("chicken.plist#get-properties"));
lf[1307]=C_h_intern(&lf[1307],14, C_text("get-properties"));
lf[1308]=C_h_intern(&lf[1308],19, C_text("##sys#display-times"));
lf[1309]=C_decode_literal(C_heaptop,C_text("\376B\000\000\0010"));
lf[1310]=C_decode_literal(C_heaptop,C_text("\376U10.0\000"));
lf[1311]=C_decode_literal(C_heaptop,C_text("\376\302\000\000\01040000000"));
lf[1312]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004 GiB"));
lf[1313]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004 MiB"));
lf[1314]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004 KiB"));
lf[1315]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006 bytes"));
lf[1316]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025, maximum live heap: "));
lf[1317]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022 GCs (major/minor)"));
lf[1318]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002, "));
lf[1319]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032 mutations (total/tracked)"));
lf[1320]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002, "));
lf[1321]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021s GC time (major)"));
lf[1322]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002, "));
lf[1323]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012s CPU time"));
lf[1324]=C_h_intern(&lf[1324],25, C_text("##sys#filter-heap-objects"));
lf[1325]=C_h_intern(&lf[1325],17, C_text("chicken.platform#"));
lf[1326]=C_h_intern(&lf[1326],30, C_text("chicken.platform#software-type"));
lf[1327]=C_h_intern(&lf[1327],29, C_text("chicken.platform#machine-type"));
lf[1328]=C_h_intern(&lf[1328],35, C_text("chicken.platform#machine-byte-order"));
lf[1329]=C_h_intern(&lf[1329],33, C_text("chicken.platform#software-version"));
lf[1330]=C_h_intern(&lf[1330],31, C_text("chicken.platform#build-platform"));
lf[1331]=C_h_intern(&lf[1331],22, C_text("##sys#windows-platform"));
lf[1332]=C_h_intern(&lf[1332],32, C_text("chicken.platform#chicken-version"));
lf[1333]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010Version "));
lf[1334]=C_h_intern(&lf[1334],19, C_text("##sys#build-version"));
lf[1335]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[1336]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1337]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002 ["));
lf[1338]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002 ]"));
lf[1339]=C_h_intern(&lf[1339],7, C_text("unknown"));
lf[1340]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1341]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001-"));
lf[1342]=C_h_intern(&lf[1342],14, C_text("##sys#build-id"));
lf[1343]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006 (rev "));
lf[1344]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[1345]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1346]=C_h_intern(&lf[1346],18, C_text("##sys#build-branch"));
lf[1347]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002 ("));
lf[1348]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001)"));
lf[1349]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1350]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006 dload"));
lf[1351]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1352]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010 ptables"));
lf[1353]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1354]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010 gchooks"));
lf[1355]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1356]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001 "));
lf[1357]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003bit"));
lf[1358]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006 cross"));
lf[1359]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[1360]=C_h_intern(&lf[1360],25, C_text("chicken.platform#feature\077"));
lf[1361]=C_h_intern_kw(&lf[1361],13, C_text("cross-chicken"));
lf[1362]=C_h_intern_kw(&lf[1362],7, C_text("gchooks"));
lf[1363]=C_h_intern_kw(&lf[1363],7, C_text("ptables"));
lf[1364]=C_h_intern_kw(&lf[1364],5, C_text("dload"));
lf[1365]=C_h_intern(&lf[1365],29, C_text("chicken.platform#chicken-home"));
lf[1367]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\006\000\376\377\016"));
lf[1368]=C_h_intern(&lf[1368],16, C_text("##sys#split-path"));
lf[1369]=C_h_intern(&lf[1369],32, C_text("chicken.platform#repository-path"));
lf[1370]=C_h_intern(&lf[1370],40, C_text("chicken.platform#installation-repository"));
lf[1372]=C_h_intern(&lf[1372],23, C_text("##sys#include-pathnames"));
lf[1373]=C_h_intern(&lf[1373],29, C_text("chicken.platform#include-path"));
lf[1375]=C_decode_literal(C_heaptop,C_text("\376B\000\0001bad argument type - not a valid feature identifer"));
lf[1376]=C_h_intern(&lf[1376],14, C_text("##sys#features"));
lf[1377]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\007\002chicken\376\003\000\000\002\376\001\000\000\006\002srfi-6\376\003\000\000\002\376\001\000\000\007\002srfi-12\376\003\000\000\002\376\001\000\000\007\002srfi-17\376\003\000\000\002\376\001\000\000"
"\007\002srfi-23\376\003\000\000\002\376\001\000\000\007\002srfi-30\376\003\000\000\002\376\001\000\000\007\002srfi-39\376\003\000\000\002\376\001\000\000\007\002srfi-62\376\003\000\000\002\376\001\000\000\007\002srfi-8"
"8\376\003\000\000\002\376\001\000\000\022\002full-numeric-tower\376\377\016"));
lf[1378]=C_h_intern(&lf[1378],34, C_text("chicken.platform#register-feature!"));
lf[1379]=C_h_intern(&lf[1379],36, C_text("chicken.platform#unregister-feature!"));
lf[1380]=C_h_intern(&lf[1380],25, C_text("chicken.platform#features"));
lf[1381]=C_h_intern(&lf[1381],31, C_text("chicken.platform#return-to-host"));
lf[1382]=C_h_intern(&lf[1382],40, C_text("chicken.platform#system-config-directory"));
lf[1383]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007APPDATA"));
lf[1384]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010/.config"));
lf[1385]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004HOME"));
lf[1386]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017XDG_CONFIG_HOME"));
lf[1387]=C_h_intern(&lf[1387],39, C_text("chicken.platform#system-cache-directory"));
lf[1388]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007APPDATA"));
lf[1389]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014LOCALAPPDATA"));
lf[1390]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007/.cache"));
lf[1391]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004HOME"));
lf[1392]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016XDG_CACHE_HOME"));
lf[1393]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010chicken-"));
lf[1394]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001."));
lf[1395]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010chicken-"));
lf[1396]=C_decode_literal(C_heaptop,C_text("\376B\000\000\003bit"));
lf[1397]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024CHICKEN_INCLUDE_PATH"));
lf[1398]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032CHICKEN_INSTALL_REPOSITORY"));
lf[1399]=C_h_intern(&lf[1399],15, C_text("repository-path"));
lf[1400]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027CHICKEN_REPOSITORY_PATH"));
lf[1401]=C_h_intern(&lf[1401],7, C_text("windows"));
lf[1402]=C_h_intern(&lf[1402],6, C_text("cygwin"));
lf[1403]=C_h_intern(&lf[1403],12, C_text("symbol-plist"));
lf[1404]=C_h_intern(&lf[1404],19, C_text("symbol-plist/setter"));
lf[1405]=C_decode_literal(C_heaptop,C_text("\376B\000\000$property-list must be of even length"));
lf[1406]=C_decode_literal(C_heaptop,C_text("\376B\000\000 (chicken.plist#symbol-plist sym)"));
lf[1407]=C_h_intern(&lf[1407],22, C_text("command-line-arguments"));
lf[1408]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002-:"));
lf[1409]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002-:"));
lf[1410]=C_h_intern(&lf[1410],12, C_text("program-name"));
lf[1411]=C_decode_literal(C_heaptop,C_text("\376B\000\000\011<unknown>"));
lf[1412]=C_h_intern(&lf[1412],17, C_text("current-directory"));
lf[1413]=C_decode_literal(C_heaptop,C_text("\376B\000\000!cannot retrieve current directory"));
lf[1414]=C_decode_literal(C_heaptop,C_text("\376B\000\000+(chicken.process-context#current-directory)"));
lf[1415]=C_h_intern(&lf[1415],7, C_text("running"));
lf[1416]=C_h_intern(&lf[1416],10, C_text("primordial"));
lf[1417]=C_h_intern(&lf[1417],9, C_text("arguments"));
lf[1418]=C_h_intern(&lf[1418],7, C_text("message"));
lf[1419]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[1420]=C_decode_literal(C_heaptop,C_text("\376B\000\000\002: "));
lf[1421]=C_decode_literal(C_heaptop,C_text("\376B\000\000\006\012Error"));
lf[1422]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016error in error"));
lf[1423]=C_decode_literal(C_heaptop,C_text("\376B\000\000,\042exit\042 called while processing on-exit tasks"));
lf[1424]=C_h_intern(&lf[1424],10, C_text("read-table"));
lf[1425]=C_h_intern(&lf[1425],13, C_text("keyword-style"));
lf[1426]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021no setter defined"));
lf[1427]=C_decode_literal(C_heaptop,C_text("\376B\000\000#can not set setter of non-procedure"));
lf[1428]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010(stderr)"));
lf[1429]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010(stdout)"));
lf[1430]=C_decode_literal(C_heaptop,C_text("\376B\000\000\007(stdin)"));
lf[1431]=C_h_intern(&lf[1431],9, C_text("backspace"));
lf[1432]=C_h_intern(&lf[1432],4, C_text("page"));
lf[1433]=C_h_intern(&lf[1433],6, C_text("return"));
lf[1434]=C_h_intern(&lf[1434],4, C_text("null"));
lf[1435]=C_h_intern(&lf[1435],3, C_text("nul"));
lf[1436]=C_h_intern(&lf[1436],5, C_text("alarm"));
lf[1437]=C_h_intern(&lf[1437],6, C_text("escape"));
lf[1438]=C_h_intern(&lf[1438],3, C_text("esc"));
lf[1439]=C_h_intern(&lf[1439],6, C_text("delete"));
lf[1440]=C_h_intern(&lf[1440],4, C_text("vtab"));
lf[1441]=C_h_intern(&lf[1441],7, C_text("newline"));
lf[1442]=C_h_intern(&lf[1442],8, C_text("linefeed"));
lf[1443]=C_h_intern(&lf[1443],3, C_text("tab"));
lf[1444]=C_h_intern(&lf[1444],5, C_text("space"));
C_register_lf2(lf,1445,create_ptable());{}
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8836,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_build_2dversion_toplevel(2,av2);}}

#ifdef C_ENABLE_PTABLES
static C_PTABLE_ENTRY ptable[2149] = {
{C_text("f35157:library_2escm"),(void*)f35157},
{C_text("f35726:library_2escm"),(void*)f35726},
{C_text("f35941:library_2escm"),(void*)f35941},
{C_text("f35945:library_2escm"),(void*)f35945},
{C_text("f38368:library_2escm"),(void*)f38368},
{C_text("f38374:library_2escm"),(void*)f38374},
{C_text("f38380:library_2escm"),(void*)f38380},
{C_text("f_10018:library_2escm"),(void*)f_10018},
{C_text("f_10027:library_2escm"),(void*)f_10027},
{C_text("f_10030:library_2escm"),(void*)f_10030},
{C_text("f_10033:library_2escm"),(void*)f_10033},
{C_text("f_10036:library_2escm"),(void*)f_10036},
{C_text("f_10039:library_2escm"),(void*)f_10039},
{C_text("f_10048:library_2escm"),(void*)f_10048},
{C_text("f_10067:library_2escm"),(void*)f_10067},
{C_text("f_10073:library_2escm"),(void*)f_10073},
{C_text("f_10098:library_2escm"),(void*)f_10098},
{C_text("f_10100:library_2escm"),(void*)f_10100},
{C_text("f_10109:library_2escm"),(void*)f_10109},
{C_text("f_10130:library_2escm"),(void*)f_10130},
{C_text("f_10132:library_2escm"),(void*)f_10132},
{C_text("f_10138:library_2escm"),(void*)f_10138},
{C_text("f_10164:library_2escm"),(void*)f_10164},
{C_text("f_10171:library_2escm"),(void*)f_10171},
{C_text("f_10173:library_2escm"),(void*)f_10173},
{C_text("f_10185:library_2escm"),(void*)f_10185},
{C_text("f_10220:library_2escm"),(void*)f_10220},
{C_text("f_10230:library_2escm"),(void*)f_10230},
{C_text("f_10239:library_2escm"),(void*)f_10239},
{C_text("f_10281:library_2escm"),(void*)f_10281},
{C_text("f_10310:library_2escm"),(void*)f_10310},
{C_text("f_10317:library_2escm"),(void*)f_10317},
{C_text("f_10320:library_2escm"),(void*)f_10320},
{C_text("f_10349:library_2escm"),(void*)f_10349},
{C_text("f_10355:library_2escm"),(void*)f_10355},
{C_text("f_10371:library_2escm"),(void*)f_10371},
{C_text("f_10396:library_2escm"),(void*)f_10396},
{C_text("f_10405:library_2escm"),(void*)f_10405},
{C_text("f_10446:library_2escm"),(void*)f_10446},
{C_text("f_10468:library_2escm"),(void*)f_10468},
{C_text("f_10500:library_2escm"),(void*)f_10500},
{C_text("f_10516:library_2escm"),(void*)f_10516},
{C_text("f_10519:library_2escm"),(void*)f_10519},
{C_text("f_10541:library_2escm"),(void*)f_10541},
{C_text("f_10547:library_2escm"),(void*)f_10547},
{C_text("f_10572:library_2escm"),(void*)f_10572},
{C_text("f_10612:library_2escm"),(void*)f_10612},
{C_text("f_10624:library_2escm"),(void*)f_10624},
{C_text("f_10643:library_2escm"),(void*)f_10643},
{C_text("f_10665:library_2escm"),(void*)f_10665},
{C_text("f_10668:library_2escm"),(void*)f_10668},
{C_text("f_10671:library_2escm"),(void*)f_10671},
{C_text("f_10674:library_2escm"),(void*)f_10674},
{C_text("f_10680:library_2escm"),(void*)f_10680},
{C_text("f_10683:library_2escm"),(void*)f_10683},
{C_text("f_10686:library_2escm"),(void*)f_10686},
{C_text("f_10689:library_2escm"),(void*)f_10689},
{C_text("f_10692:library_2escm"),(void*)f_10692},
{C_text("f_10695:library_2escm"),(void*)f_10695},
{C_text("f_10698:library_2escm"),(void*)f_10698},
{C_text("f_10701:library_2escm"),(void*)f_10701},
{C_text("f_10704:library_2escm"),(void*)f_10704},
{C_text("f_10707:library_2escm"),(void*)f_10707},
{C_text("f_10710:library_2escm"),(void*)f_10710},
{C_text("f_10713:library_2escm"),(void*)f_10713},
{C_text("f_10716:library_2escm"),(void*)f_10716},
{C_text("f_10719:library_2escm"),(void*)f_10719},
{C_text("f_10722:library_2escm"),(void*)f_10722},
{C_text("f_10725:library_2escm"),(void*)f_10725},
{C_text("f_10728:library_2escm"),(void*)f_10728},
{C_text("f_10731:library_2escm"),(void*)f_10731},
{C_text("f_10734:library_2escm"),(void*)f_10734},
{C_text("f_10737:library_2escm"),(void*)f_10737},
{C_text("f_10740:library_2escm"),(void*)f_10740},
{C_text("f_10743:library_2escm"),(void*)f_10743},
{C_text("f_10746:library_2escm"),(void*)f_10746},
{C_text("f_10749:library_2escm"),(void*)f_10749},
{C_text("f_10753:library_2escm"),(void*)f_10753},
{C_text("f_10755:library_2escm"),(void*)f_10755},
{C_text("f_10760:library_2escm"),(void*)f_10760},
{C_text("f_10769:library_2escm"),(void*)f_10769},
{C_text("f_10781:library_2escm"),(void*)f_10781},
{C_text("f_10795:library_2escm"),(void*)f_10795},
{C_text("f_10811:library_2escm"),(void*)f_10811},
{C_text("f_10814:library_2escm"),(void*)f_10814},
{C_text("f_10822:library_2escm"),(void*)f_10822},
{C_text("f_10826:library_2escm"),(void*)f_10826},
{C_text("f_10828:library_2escm"),(void*)f_10828},
{C_text("f_10832:library_2escm"),(void*)f_10832},
{C_text("f_10835:library_2escm"),(void*)f_10835},
{C_text("f_10846:library_2escm"),(void*)f_10846},
{C_text("f_10848:library_2escm"),(void*)f_10848},
{C_text("f_10855:library_2escm"),(void*)f_10855},
{C_text("f_10858:library_2escm"),(void*)f_10858},
{C_text("f_10861:library_2escm"),(void*)f_10861},
{C_text("f_10866:library_2escm"),(void*)f_10866},
{C_text("f_10870:library_2escm"),(void*)f_10870},
{C_text("f_10875:library_2escm"),(void*)f_10875},
{C_text("f_10879:library_2escm"),(void*)f_10879},
{C_text("f_10882:library_2escm"),(void*)f_10882},
{C_text("f_10910:library_2escm"),(void*)f_10910},
{C_text("f_10913:library_2escm"),(void*)f_10913},
{C_text("f_10916:library_2escm"),(void*)f_10916},
{C_text("f_10919:library_2escm"),(void*)f_10919},
{C_text("f_10936:library_2escm"),(void*)f_10936},
{C_text("f_10947:library_2escm"),(void*)f_10947},
{C_text("f_10959:library_2escm"),(void*)f_10959},
{C_text("f_10970:library_2escm"),(void*)f_10970},
{C_text("f_10981:library_2escm"),(void*)f_10981},
{C_text("f_10992:library_2escm"),(void*)f_10992},
{C_text("f_11003:library_2escm"),(void*)f_11003},
{C_text("f_11014:library_2escm"),(void*)f_11014},
{C_text("f_11025:library_2escm"),(void*)f_11025},
{C_text("f_11036:library_2escm"),(void*)f_11036},
{C_text("f_11047:library_2escm"),(void*)f_11047},
{C_text("f_11058:library_2escm"),(void*)f_11058},
{C_text("f_11069:library_2escm"),(void*)f_11069},
{C_text("f_11080:library_2escm"),(void*)f_11080},
{C_text("f_11091:library_2escm"),(void*)f_11091},
{C_text("f_11102:library_2escm"),(void*)f_11102},
{C_text("f_11119:library_2escm"),(void*)f_11119},
{C_text("f_11136:library_2escm"),(void*)f_11136},
{C_text("f_11160:library_2escm"),(void*)f_11160},
{C_text("f_11177:library_2escm"),(void*)f_11177},
{C_text("f_11181:library_2escm"),(void*)f_11181},
{C_text("f_11207:library_2escm"),(void*)f_11207},
{C_text("f_11227:library_2escm"),(void*)f_11227},
{C_text("f_11238:library_2escm"),(void*)f_11238},
{C_text("f_11250:library_2escm"),(void*)f_11250},
{C_text("f_11284:library_2escm"),(void*)f_11284},
{C_text("f_11299:library_2escm"),(void*)f_11299},
{C_text("f_11366:library_2escm"),(void*)f_11366},
{C_text("f_11382:library_2escm"),(void*)f_11382},
{C_text("f_11398:library_2escm"),(void*)f_11398},
{C_text("f_11414:library_2escm"),(void*)f_11414},
{C_text("f_11430:library_2escm"),(void*)f_11430},
{C_text("f_11446:library_2escm"),(void*)f_11446},
{C_text("f_11462:library_2escm"),(void*)f_11462},
{C_text("f_11478:library_2escm"),(void*)f_11478},
{C_text("f_11494:library_2escm"),(void*)f_11494},
{C_text("f_11506:library_2escm"),(void*)f_11506},
{C_text("f_11525:library_2escm"),(void*)f_11525},
{C_text("f_11556:library_2escm"),(void*)f_11556},
{C_text("f_11573:library_2escm"),(void*)f_11573},
{C_text("f_11579:library_2escm"),(void*)f_11579},
{C_text("f_11603:library_2escm"),(void*)f_11603},
{C_text("f_11623:library_2escm"),(void*)f_11623},
{C_text("f_11627:library_2escm"),(void*)f_11627},
{C_text("f_11630:library_2escm"),(void*)f_11630},
{C_text("f_11659:library_2escm"),(void*)f_11659},
{C_text("f_11675:library_2escm"),(void*)f_11675},
{C_text("f_11697:library_2escm"),(void*)f_11697},
{C_text("f_11713:library_2escm"),(void*)f_11713},
{C_text("f_11718:library_2escm"),(void*)f_11718},
{C_text("f_11749:library_2escm"),(void*)f_11749},
{C_text("f_11760:library_2escm"),(void*)f_11760},
{C_text("f_11769:library_2escm"),(void*)f_11769},
{C_text("f_11798:library_2escm"),(void*)f_11798},
{C_text("f_11811:library_2escm"),(void*)f_11811},
{C_text("f_11821:library_2escm"),(void*)f_11821},
{C_text("f_11823:library_2escm"),(void*)f_11823},
{C_text("f_11830:library_2escm"),(void*)f_11830},
{C_text("f_11833:library_2escm"),(void*)f_11833},
{C_text("f_11842:library_2escm"),(void*)f_11842},
{C_text("f_11868:library_2escm"),(void*)f_11868},
{C_text("f_11873:library_2escm"),(void*)f_11873},
{C_text("f_11877:library_2escm"),(void*)f_11877},
{C_text("f_11882:library_2escm"),(void*)f_11882},
{C_text("f_11903:library_2escm"),(void*)f_11903},
{C_text("f_11909:library_2escm"),(void*)f_11909},
{C_text("f_11927:library_2escm"),(void*)f_11927},
{C_text("f_11933:library_2escm"),(void*)f_11933},
{C_text("f_11951:library_2escm"),(void*)f_11951},
{C_text("f_11957:library_2escm"),(void*)f_11957},
{C_text("f_11972:library_2escm"),(void*)f_11972},
{C_text("f_11978:library_2escm"),(void*)f_11978},
{C_text("f_11992:library_2escm"),(void*)f_11992},
{C_text("f_12013:library_2escm"),(void*)f_12013},
{C_text("f_12019:library_2escm"),(void*)f_12019},
{C_text("f_12037:library_2escm"),(void*)f_12037},
{C_text("f_12043:library_2escm"),(void*)f_12043},
{C_text("f_12061:library_2escm"),(void*)f_12061},
{C_text("f_12067:library_2escm"),(void*)f_12067},
{C_text("f_12082:library_2escm"),(void*)f_12082},
{C_text("f_12088:library_2escm"),(void*)f_12088},
{C_text("f_12103:library_2escm"),(void*)f_12103},
{C_text("f_12113:library_2escm"),(void*)f_12113},
{C_text("f_12119:library_2escm"),(void*)f_12119},
{C_text("f_12123:library_2escm"),(void*)f_12123},
{C_text("f_12125:library_2escm"),(void*)f_12125},
{C_text("f_12136:library_2escm"),(void*)f_12136},
{C_text("f_12148:library_2escm"),(void*)f_12148},
{C_text("f_12158:library_2escm"),(void*)f_12158},
{C_text("f_12164:library_2escm"),(void*)f_12164},
{C_text("f_12168:library_2escm"),(void*)f_12168},
{C_text("f_12173:library_2escm"),(void*)f_12173},
{C_text("f_12199:library_2escm"),(void*)f_12199},
{C_text("f_12203:library_2escm"),(void*)f_12203},
{C_text("f_12206:library_2escm"),(void*)f_12206},
{C_text("f_12214:library_2escm"),(void*)f_12214},
{C_text("f_12235:library_2escm"),(void*)f_12235},
{C_text("f_12249:library_2escm"),(void*)f_12249},
{C_text("f_12253:library_2escm"),(void*)f_12253},
{C_text("f_12294:library_2escm"),(void*)f_12294},
{C_text("f_12316:library_2escm"),(void*)f_12316},
{C_text("f_12318:library_2escm"),(void*)f_12318},
{C_text("f_12340:library_2escm"),(void*)f_12340},
{C_text("f_12342:library_2escm"),(void*)f_12342},
{C_text("f_12364:library_2escm"),(void*)f_12364},
{C_text("f_12366:library_2escm"),(void*)f_12366},
{C_text("f_12388:library_2escm"),(void*)f_12388},
{C_text("f_12390:library_2escm"),(void*)f_12390},
{C_text("f_12394:library_2escm"),(void*)f_12394},
{C_text("f_12397:library_2escm"),(void*)f_12397},
{C_text("f_12415:library_2escm"),(void*)f_12415},
{C_text("f_12437:library_2escm"),(void*)f_12437},
{C_text("f_12439:library_2escm"),(void*)f_12439},
{C_text("f_12461:library_2escm"),(void*)f_12461},
{C_text("f_12463:library_2escm"),(void*)f_12463},
{C_text("f_12485:library_2escm"),(void*)f_12485},
{C_text("f_12487:library_2escm"),(void*)f_12487},
{C_text("f_12509:library_2escm"),(void*)f_12509},
{C_text("f_12511:library_2escm"),(void*)f_12511},
{C_text("f_12533:library_2escm"),(void*)f_12533},
{C_text("f_12535:library_2escm"),(void*)f_12535},
{C_text("f_12557:library_2escm"),(void*)f_12557},
{C_text("f_12559:library_2escm"),(void*)f_12559},
{C_text("f_12581:library_2escm"),(void*)f_12581},
{C_text("f_12583:library_2escm"),(void*)f_12583},
{C_text("f_12599:library_2escm"),(void*)f_12599},
{C_text("f_12601:library_2escm"),(void*)f_12601},
{C_text("f_12623:library_2escm"),(void*)f_12623},
{C_text("f_12625:library_2escm"),(void*)f_12625},
{C_text("f_12647:library_2escm"),(void*)f_12647},
{C_text("f_12649:library_2escm"),(void*)f_12649},
{C_text("f_12665:library_2escm"),(void*)f_12665},
{C_text("f_12667:library_2escm"),(void*)f_12667},
{C_text("f_12683:library_2escm"),(void*)f_12683},
{C_text("f_12685:library_2escm"),(void*)f_12685},
{C_text("f_12701:library_2escm"),(void*)f_12701},
{C_text("f_12703:library_2escm"),(void*)f_12703},
{C_text("f_12719:library_2escm"),(void*)f_12719},
{C_text("f_12721:library_2escm"),(void*)f_12721},
{C_text("f_12737:library_2escm"),(void*)f_12737},
{C_text("f_12739:library_2escm"),(void*)f_12739},
{C_text("f_12755:library_2escm"),(void*)f_12755},
{C_text("f_12757:library_2escm"),(void*)f_12757},
{C_text("f_12773:library_2escm"),(void*)f_12773},
{C_text("f_12775:library_2escm"),(void*)f_12775},
{C_text("f_12791:library_2escm"),(void*)f_12791},
{C_text("f_12793:library_2escm"),(void*)f_12793},
{C_text("f_12809:library_2escm"),(void*)f_12809},
{C_text("f_12811:library_2escm"),(void*)f_12811},
{C_text("f_12827:library_2escm"),(void*)f_12827},
{C_text("f_12829:library_2escm"),(void*)f_12829},
{C_text("f_12851:library_2escm"),(void*)f_12851},
{C_text("f_12853:library_2escm"),(void*)f_12853},
{C_text("f_12869:library_2escm"),(void*)f_12869},
{C_text("f_12871:library_2escm"),(void*)f_12871},
{C_text("f_12887:library_2escm"),(void*)f_12887},
{C_text("f_12889:library_2escm"),(void*)f_12889},
{C_text("f_12905:library_2escm"),(void*)f_12905},
{C_text("f_12907:library_2escm"),(void*)f_12907},
{C_text("f_12923:library_2escm"),(void*)f_12923},
{C_text("f_12925:library_2escm"),(void*)f_12925},
{C_text("f_12941:library_2escm"),(void*)f_12941},
{C_text("f_12943:library_2escm"),(void*)f_12943},
{C_text("f_12959:library_2escm"),(void*)f_12959},
{C_text("f_12961:library_2escm"),(void*)f_12961},
{C_text("f_12977:library_2escm"),(void*)f_12977},
{C_text("f_12979:library_2escm"),(void*)f_12979},
{C_text("f_13001:library_2escm"),(void*)f_13001},
{C_text("f_13003:library_2escm"),(void*)f_13003},
{C_text("f_13019:library_2escm"),(void*)f_13019},
{C_text("f_13021:library_2escm"),(void*)f_13021},
{C_text("f_13037:library_2escm"),(void*)f_13037},
{C_text("f_13039:library_2escm"),(void*)f_13039},
{C_text("f_13055:library_2escm"),(void*)f_13055},
{C_text("f_13057:library_2escm"),(void*)f_13057},
{C_text("f_13073:library_2escm"),(void*)f_13073},
{C_text("f_13075:library_2escm"),(void*)f_13075},
{C_text("f_13085:library_2escm"),(void*)f_13085},
{C_text("f_13097:library_2escm"),(void*)f_13097},
{C_text("f_13107:library_2escm"),(void*)f_13107},
{C_text("f_13111:library_2escm"),(void*)f_13111},
{C_text("f_13133:library_2escm"),(void*)f_13133},
{C_text("f_13137:library_2escm"),(void*)f_13137},
{C_text("f_13140:library_2escm"),(void*)f_13140},
{C_text("f_13145:library_2escm"),(void*)f_13145},
{C_text("f_13149:library_2escm"),(void*)f_13149},
{C_text("f_13152:library_2escm"),(void*)f_13152},
{C_text("f_13155:library_2escm"),(void*)f_13155},
{C_text("f_13168:library_2escm"),(void*)f_13168},
{C_text("f_13191:library_2escm"),(void*)f_13191},
{C_text("f_13217:library_2escm"),(void*)f_13217},
{C_text("f_13226:library_2escm"),(void*)f_13226},
{C_text("f_13231:library_2escm"),(void*)f_13231},
{C_text("f_13233:library_2escm"),(void*)f_13233},
{C_text("f_13277:library_2escm"),(void*)f_13277},
{C_text("f_13323:library_2escm"),(void*)f_13323},
{C_text("f_13347:library_2escm"),(void*)f_13347},
{C_text("f_13351:library_2escm"),(void*)f_13351},
{C_text("f_13369:library_2escm"),(void*)f_13369},
{C_text("f_13393:library_2escm"),(void*)f_13393},
{C_text("f_13397:library_2escm"),(void*)f_13397},
{C_text("f_13415:library_2escm"),(void*)f_13415},
{C_text("f_13456:library_2escm"),(void*)f_13456},
{C_text("f_13467:library_2escm"),(void*)f_13467},
{C_text("f_13473:library_2escm"),(void*)f_13473},
{C_text("f_13477:library_2escm"),(void*)f_13477},
{C_text("f_13491:library_2escm"),(void*)f_13491},
{C_text("f_13504:library_2escm"),(void*)f_13504},
{C_text("f_13508:library_2escm"),(void*)f_13508},
{C_text("f_13525:library_2escm"),(void*)f_13525},
{C_text("f_13529:library_2escm"),(void*)f_13529},
{C_text("f_13535:library_2escm"),(void*)f_13535},
{C_text("f_13539:library_2escm"),(void*)f_13539},
{C_text("f_13579:library_2escm"),(void*)f_13579},
{C_text("f_13583:library_2escm"),(void*)f_13583},
{C_text("f_13605:library_2escm"),(void*)f_13605},
{C_text("f_13608:library_2escm"),(void*)f_13608},
{C_text("f_13611:library_2escm"),(void*)f_13611},
{C_text("f_13614:library_2escm"),(void*)f_13614},
{C_text("f_13617:library_2escm"),(void*)f_13617},
{C_text("f_13638:library_2escm"),(void*)f_13638},
{C_text("f_13640:library_2escm"),(void*)f_13640},
{C_text("f_13658:library_2escm"),(void*)f_13658},
{C_text("f_13668:library_2escm"),(void*)f_13668},
{C_text("f_13672:library_2escm"),(void*)f_13672},
{C_text("f_13710:library_2escm"),(void*)f_13710},
{C_text("f_13713:library_2escm"),(void*)f_13713},
{C_text("f_13716:library_2escm"),(void*)f_13716},
{C_text("f_13719:library_2escm"),(void*)f_13719},
{C_text("f_13725:library_2escm"),(void*)f_13725},
{C_text("f_13728:library_2escm"),(void*)f_13728},
{C_text("f_13776:library_2escm"),(void*)f_13776},
{C_text("f_13780:library_2escm"),(void*)f_13780},
{C_text("f_13857:library_2escm"),(void*)f_13857},
{C_text("f_13896:library_2escm"),(void*)f_13896},
{C_text("f_13951:library_2escm"),(void*)f_13951},
{C_text("f_13996:library_2escm"),(void*)f_13996},
{C_text("f_14041:library_2escm"),(void*)f_14041},
{C_text("f_14078:library_2escm"),(void*)f_14078},
{C_text("f_14098:library_2escm"),(void*)f_14098},
{C_text("f_14122:library_2escm"),(void*)f_14122},
{C_text("f_14125:library_2escm"),(void*)f_14125},
{C_text("f_14129:library_2escm"),(void*)f_14129},
{C_text("f_14132:library_2escm"),(void*)f_14132},
{C_text("f_14150:library_2escm"),(void*)f_14150},
{C_text("f_14173:library_2escm"),(void*)f_14173},
{C_text("f_14177:library_2escm"),(void*)f_14177},
{C_text("f_14200:library_2escm"),(void*)f_14200},
{C_text("f_14204:library_2escm"),(void*)f_14204},
{C_text("f_14236:library_2escm"),(void*)f_14236},
{C_text("f_14272:library_2escm"),(void*)f_14272},
{C_text("f_14276:library_2escm"),(void*)f_14276},
{C_text("f_14295:library_2escm"),(void*)f_14295},
{C_text("f_14297:library_2escm"),(void*)f_14297},
{C_text("f_14304:library_2escm"),(void*)f_14304},
{C_text("f_14341:library_2escm"),(void*)f_14341},
{C_text("f_14348:library_2escm"),(void*)f_14348},
{C_text("f_14385:library_2escm"),(void*)f_14385},
{C_text("f_14403:library_2escm"),(void*)f_14403},
{C_text("f_14412:library_2escm"),(void*)f_14412},
{C_text("f_14417:library_2escm"),(void*)f_14417},
{C_text("f_14430:library_2escm"),(void*)f_14430},
{C_text("f_14456:library_2escm"),(void*)f_14456},
{C_text("f_14464:library_2escm"),(void*)f_14464},
{C_text("f_14468:library_2escm"),(void*)f_14468},
{C_text("f_14472:library_2escm"),(void*)f_14472},
{C_text("f_14476:library_2escm"),(void*)f_14476},
{C_text("f_14479:library_2escm"),(void*)f_14479},
{C_text("f_14493:library_2escm"),(void*)f_14493},
{C_text("f_14497:library_2escm"),(void*)f_14497},
{C_text("f_14508:library_2escm"),(void*)f_14508},
{C_text("f_14532:library_2escm"),(void*)f_14532},
{C_text("f_14536:library_2escm"),(void*)f_14536},
{C_text("f_14542:library_2escm"),(void*)f_14542},
{C_text("f_14566:library_2escm"),(void*)f_14566},
{C_text("f_14570:library_2escm"),(void*)f_14570},
{C_text("f_14576:library_2escm"),(void*)f_14576},
{C_text("f_14593:library_2escm"),(void*)f_14593},
{C_text("f_14597:library_2escm"),(void*)f_14597},
{C_text("f_14601:library_2escm"),(void*)f_14601},
{C_text("f_14611:library_2escm"),(void*)f_14611},
{C_text("f_14617:library_2escm"),(void*)f_14617},
{C_text("f_14624:library_2escm"),(void*)f_14624},
{C_text("f_14636:library_2escm"),(void*)f_14636},
{C_text("f_14659:library_2escm"),(void*)f_14659},
{C_text("f_14663:library_2escm"),(void*)f_14663},
{C_text("f_14673:library_2escm"),(void*)f_14673},
{C_text("f_14679:library_2escm"),(void*)f_14679},
{C_text("f_14686:library_2escm"),(void*)f_14686},
{C_text("f_14701:library_2escm"),(void*)f_14701},
{C_text("f_14705:library_2escm"),(void*)f_14705},
{C_text("f_14738:library_2escm"),(void*)f_14738},
{C_text("f_14742:library_2escm"),(void*)f_14742},
{C_text("f_14759:library_2escm"),(void*)f_14759},
{C_text("f_14769:library_2escm"),(void*)f_14769},
{C_text("f_14842:library_2escm"),(void*)f_14842},
{C_text("f_14856:library_2escm"),(void*)f_14856},
{C_text("f_14873:library_2escm"),(void*)f_14873},
{C_text("f_14889:library_2escm"),(void*)f_14889},
{C_text("f_14960:library_2escm"),(void*)f_14960},
{C_text("f_14964:library_2escm"),(void*)f_14964},
{C_text("f_14969:library_2escm"),(void*)f_14969},
{C_text("f_14979:library_2escm"),(void*)f_14979},
{C_text("f_14983:library_2escm"),(void*)f_14983},
{C_text("f_14998:library_2escm"),(void*)f_14998},
{C_text("f_15002:library_2escm"),(void*)f_15002},
{C_text("f_15019:library_2escm"),(void*)f_15019},
{C_text("f_15030:library_2escm"),(void*)f_15030},
{C_text("f_15036:library_2escm"),(void*)f_15036},
{C_text("f_15047:library_2escm"),(void*)f_15047},
{C_text("f_15058:library_2escm"),(void*)f_15058},
{C_text("f_15070:library_2escm"),(void*)f_15070},
{C_text("f_15082:library_2escm"),(void*)f_15082},
{C_text("f_15094:library_2escm"),(void*)f_15094},
{C_text("f_15111:library_2escm"),(void*)f_15111},
{C_text("f_15118:library_2escm"),(void*)f_15118},
{C_text("f_15122:library_2escm"),(void*)f_15122},
{C_text("f_15124:library_2escm"),(void*)f_15124},
{C_text("f_15130:library_2escm"),(void*)f_15130},
{C_text("f_15134:library_2escm"),(void*)f_15134},
{C_text("f_15137:library_2escm"),(void*)f_15137},
{C_text("f_15142:library_2escm"),(void*)f_15142},
{C_text("f_15152:library_2escm"),(void*)f_15152},
{C_text("f_15172:library_2escm"),(void*)f_15172},
{C_text("f_15187:library_2escm"),(void*)f_15187},
{C_text("f_15217:library_2escm"),(void*)f_15217},
{C_text("f_15228:library_2escm"),(void*)f_15228},
{C_text("f_15244:library_2escm"),(void*)f_15244},
{C_text("f_15248:library_2escm"),(void*)f_15248},
{C_text("f_15252:library_2escm"),(void*)f_15252},
{C_text("f_15268:library_2escm"),(void*)f_15268},
{C_text("f_15286:library_2escm"),(void*)f_15286},
{C_text("f_15297:library_2escm"),(void*)f_15297},
{C_text("f_15319:library_2escm"),(void*)f_15319},
{C_text("f_15336:library_2escm"),(void*)f_15336},
{C_text("f_15339:library_2escm"),(void*)f_15339},
{C_text("f_15351:library_2escm"),(void*)f_15351},
{C_text("f_15353:library_2escm"),(void*)f_15353},
{C_text("f_15374:library_2escm"),(void*)f_15374},
{C_text("f_15405:library_2escm"),(void*)f_15405},
{C_text("f_15409:library_2escm"),(void*)f_15409},
{C_text("f_15444:library_2escm"),(void*)f_15444},
{C_text("f_15451:library_2escm"),(void*)f_15451},
{C_text("f_15463:library_2escm"),(void*)f_15463},
{C_text("f_15483:library_2escm"),(void*)f_15483},
{C_text("f_15487:library_2escm"),(void*)f_15487},
{C_text("f_15507:library_2escm"),(void*)f_15507},
{C_text("f_15527:library_2escm"),(void*)f_15527},
{C_text("f_15531:library_2escm"),(void*)f_15531},
{C_text("f_15535:library_2escm"),(void*)f_15535},
{C_text("f_15542:library_2escm"),(void*)f_15542},
{C_text("f_15558:library_2escm"),(void*)f_15558},
{C_text("f_15562:library_2escm"),(void*)f_15562},
{C_text("f_15603:library_2escm"),(void*)f_15603},
{C_text("f_15636:library_2escm"),(void*)f_15636},
{C_text("f_15665:library_2escm"),(void*)f_15665},
{C_text("f_15673:library_2escm"),(void*)f_15673},
{C_text("f_15679:library_2escm"),(void*)f_15679},
{C_text("f_15699:library_2escm"),(void*)f_15699},
{C_text("f_15724:library_2escm"),(void*)f_15724},
{C_text("f_15730:library_2escm"),(void*)f_15730},
{C_text("f_15734:library_2escm"),(void*)f_15734},
{C_text("f_15744:library_2escm"),(void*)f_15744},
{C_text("f_15764:library_2escm"),(void*)f_15764},
{C_text("f_15785:library_2escm"),(void*)f_15785},
{C_text("f_15802:library_2escm"),(void*)f_15802},
{C_text("f_15809:library_2escm"),(void*)f_15809},
{C_text("f_15814:library_2escm"),(void*)f_15814},
{C_text("f_15820:library_2escm"),(void*)f_15820},
{C_text("f_15824:library_2escm"),(void*)f_15824},
{C_text("f_15827:library_2escm"),(void*)f_15827},
{C_text("f_15834:library_2escm"),(void*)f_15834},
{C_text("f_15855:library_2escm"),(void*)f_15855},
{C_text("f_15869:library_2escm"),(void*)f_15869},
{C_text("f_15873:library_2escm"),(void*)f_15873},
{C_text("f_15910:library_2escm"),(void*)f_15910},
{C_text("f_15918:library_2escm"),(void*)f_15918},
{C_text("f_15947:library_2escm"),(void*)f_15947},
{C_text("f_15950:library_2escm"),(void*)f_15950},
{C_text("f_15965:library_2escm"),(void*)f_15965},
{C_text("f_15968:library_2escm"),(void*)f_15968},
{C_text("f_15975:library_2escm"),(void*)f_15975},
{C_text("f_15986:library_2escm"),(void*)f_15986},
{C_text("f_16004:library_2escm"),(void*)f_16004},
{C_text("f_16029:library_2escm"),(void*)f_16029},
{C_text("f_16044:library_2escm"),(void*)f_16044},
{C_text("f_16072:library_2escm"),(void*)f_16072},
{C_text("f_16076:library_2escm"),(void*)f_16076},
{C_text("f_16090:library_2escm"),(void*)f_16090},
{C_text("f_16150:library_2escm"),(void*)f_16150},
{C_text("f_16170:library_2escm"),(void*)f_16170},
{C_text("f_16176:library_2escm"),(void*)f_16176},
{C_text("f_16239:library_2escm"),(void*)f_16239},
{C_text("f_16278:library_2escm"),(void*)f_16278},
{C_text("f_16284:library_2escm"),(void*)f_16284},
{C_text("f_16328:library_2escm"),(void*)f_16328},
{C_text("f_16332:library_2escm"),(void*)f_16332},
{C_text("f_16335:library_2escm"),(void*)f_16335},
{C_text("f_16384:library_2escm"),(void*)f_16384},
{C_text("f_16399:library_2escm"),(void*)f_16399},
{C_text("f_16408:library_2escm"),(void*)f_16408},
{C_text("f_16442:library_2escm"),(void*)f_16442},
{C_text("f_16452:library_2escm"),(void*)f_16452},
{C_text("f_16461:library_2escm"),(void*)f_16461},
{C_text("f_16473:library_2escm"),(void*)f_16473},
{C_text("f_16482:library_2escm"),(void*)f_16482},
{C_text("f_16494:library_2escm"),(void*)f_16494},
{C_text("f_16500:library_2escm"),(void*)f_16500},
{C_text("f_16506:library_2escm"),(void*)f_16506},
{C_text("f_16548:library_2escm"),(void*)f_16548},
{C_text("f_16656:library_2escm"),(void*)f_16656},
{C_text("f_16663:library_2escm"),(void*)f_16663},
{C_text("f_16676:library_2escm"),(void*)f_16676},
{C_text("f_16734:library_2escm"),(void*)f_16734},
{C_text("f_16752:library_2escm"),(void*)f_16752},
{C_text("f_16762:library_2escm"),(void*)f_16762},
{C_text("f_16798:library_2escm"),(void*)f_16798},
{C_text("f_16824:library_2escm"),(void*)f_16824},
{C_text("f_16835:library_2escm"),(void*)f_16835},
{C_text("f_17002:library_2escm"),(void*)f_17002},
{C_text("f_17017:library_2escm"),(void*)f_17017},
{C_text("f_17075:library_2escm"),(void*)f_17075},
{C_text("f_17116:library_2escm"),(void*)f_17116},
{C_text("f_17194:library_2escm"),(void*)f_17194},
{C_text("f_17242:library_2escm"),(void*)f_17242},
{C_text("f_17245:library_2escm"),(void*)f_17245},
{C_text("f_17257:library_2escm"),(void*)f_17257},
{C_text("f_17344:library_2escm"),(void*)f_17344},
{C_text("f_17412:library_2escm"),(void*)f_17412},
{C_text("f_17492:library_2escm"),(void*)f_17492},
{C_text("f_17502:library_2escm"),(void*)f_17502},
{C_text("f_17511:library_2escm"),(void*)f_17511},
{C_text("f_17747:library_2escm"),(void*)f_17747},
{C_text("f_17793:library_2escm"),(void*)f_17793},
{C_text("f_17796:library_2escm"),(void*)f_17796},
{C_text("f_17823:library_2escm"),(void*)f_17823},
{C_text("f_17847:library_2escm"),(void*)f_17847},
{C_text("f_17864:library_2escm"),(void*)f_17864},
{C_text("f_17965:library_2escm"),(void*)f_17965},
{C_text("f_17968:library_2escm"),(void*)f_17968},
{C_text("f_17977:library_2escm"),(void*)f_17977},
{C_text("f_17983:library_2escm"),(void*)f_17983},
{C_text("f_17994:library_2escm"),(void*)f_17994},
{C_text("f_17996:library_2escm"),(void*)f_17996},
{C_text("f_18007:library_2escm"),(void*)f_18007},
{C_text("f_18009:library_2escm"),(void*)f_18009},
{C_text("f_18020:library_2escm"),(void*)f_18020},
{C_text("f_18022:library_2escm"),(void*)f_18022},
{C_text("f_18039:library_2escm"),(void*)f_18039},
{C_text("f_18043:library_2escm"),(void*)f_18043},
{C_text("f_18047:library_2escm"),(void*)f_18047},
{C_text("f_18056:library_2escm"),(void*)f_18056},
{C_text("f_18076:library_2escm"),(void*)f_18076},
{C_text("f_18084:library_2escm"),(void*)f_18084},
{C_text("f_18099:library_2escm"),(void*)f_18099},
{C_text("f_18101:library_2escm"),(void*)f_18101},
{C_text("f_18126:library_2escm"),(void*)f_18126},
{C_text("f_18135:library_2escm"),(void*)f_18135},
{C_text("f_18138:library_2escm"),(void*)f_18138},
{C_text("f_18147:library_2escm"),(void*)f_18147},
{C_text("f_18154:library_2escm"),(void*)f_18154},
{C_text("f_18165:library_2escm"),(void*)f_18165},
{C_text("f_18172:library_2escm"),(void*)f_18172},
{C_text("f_18196:library_2escm"),(void*)f_18196},
{C_text("f_18200:library_2escm"),(void*)f_18200},
{C_text("f_18202:library_2escm"),(void*)f_18202},
{C_text("f_18206:library_2escm"),(void*)f_18206},
{C_text("f_18211:library_2escm"),(void*)f_18211},
{C_text("f_18217:library_2escm"),(void*)f_18217},
{C_text("f_18221:library_2escm"),(void*)f_18221},
{C_text("f_18226:library_2escm"),(void*)f_18226},
{C_text("f_18236:library_2escm"),(void*)f_18236},
{C_text("f_18238:library_2escm"),(void*)f_18238},
{C_text("f_18242:library_2escm"),(void*)f_18242},
{C_text("f_18248:library_2escm"),(void*)f_18248},
{C_text("f_18250:library_2escm"),(void*)f_18250},
{C_text("f_18254:library_2escm"),(void*)f_18254},
{C_text("f_18257:library_2escm"),(void*)f_18257},
{C_text("f_18273:library_2escm"),(void*)f_18273},
{C_text("f_18277:library_2escm"),(void*)f_18277},
{C_text("f_18280:library_2escm"),(void*)f_18280},
{C_text("f_18302:library_2escm"),(void*)f_18302},
{C_text("f_18318:library_2escm"),(void*)f_18318},
{C_text("f_18323:library_2escm"),(void*)f_18323},
{C_text("f_18354:library_2escm"),(void*)f_18354},
{C_text("f_18363:library_2escm"),(void*)f_18363},
{C_text("f_18381:library_2escm"),(void*)f_18381},
{C_text("f_18387:library_2escm"),(void*)f_18387},
{C_text("f_18393:library_2escm"),(void*)f_18393},
{C_text("f_18402:library_2escm"),(void*)f_18402},
{C_text("f_18421:library_2escm"),(void*)f_18421},
{C_text("f_18440:library_2escm"),(void*)f_18440},
{C_text("f_18443:library_2escm"),(void*)f_18443},
{C_text("f_18448:library_2escm"),(void*)f_18448},
{C_text("f_18490:library_2escm"),(void*)f_18490},
{C_text("f_18509:library_2escm"),(void*)f_18509},
{C_text("f_18512:library_2escm"),(void*)f_18512},
{C_text("f_18515:library_2escm"),(void*)f_18515},
{C_text("f_18520:library_2escm"),(void*)f_18520},
{C_text("f_18561:library_2escm"),(void*)f_18561},
{C_text("f_18571:library_2escm"),(void*)f_18571},
{C_text("f_18582:library_2escm"),(void*)f_18582},
{C_text("f_18586:library_2escm"),(void*)f_18586},
{C_text("f_18589:library_2escm"),(void*)f_18589},
{C_text("f_18594:library_2escm"),(void*)f_18594},
{C_text("f_18621:library_2escm"),(void*)f_18621},
{C_text("f_18635:library_2escm"),(void*)f_18635},
{C_text("f_18646:library_2escm"),(void*)f_18646},
{C_text("f_18657:library_2escm"),(void*)f_18657},
{C_text("f_18668:library_2escm"),(void*)f_18668},
{C_text("f_18681:library_2escm"),(void*)f_18681},
{C_text("f_18683:library_2escm"),(void*)f_18683},
{C_text("f_18696:library_2escm"),(void*)f_18696},
{C_text("f_18724:library_2escm"),(void*)f_18724},
{C_text("f_18737:library_2escm"),(void*)f_18737},
{C_text("f_18755:library_2escm"),(void*)f_18755},
{C_text("f_18758:library_2escm"),(void*)f_18758},
{C_text("f_18841:library_2escm"),(void*)f_18841},
{C_text("f_18844:library_2escm"),(void*)f_18844},
{C_text("f_18847:library_2escm"),(void*)f_18847},
{C_text("f_18850:library_2escm"),(void*)f_18850},
{C_text("f_18853:library_2escm"),(void*)f_18853},
{C_text("f_18856:library_2escm"),(void*)f_18856},
{C_text("f_18859:library_2escm"),(void*)f_18859},
{C_text("f_18862:library_2escm"),(void*)f_18862},
{C_text("f_18865:library_2escm"),(void*)f_18865},
{C_text("f_18868:library_2escm"),(void*)f_18868},
{C_text("f_18871:library_2escm"),(void*)f_18871},
{C_text("f_18874:library_2escm"),(void*)f_18874},
{C_text("f_18877:library_2escm"),(void*)f_18877},
{C_text("f_18880:library_2escm"),(void*)f_18880},
{C_text("f_18885:library_2escm"),(void*)f_18885},
{C_text("f_18891:library_2escm"),(void*)f_18891},
{C_text("f_18907:library_2escm"),(void*)f_18907},
{C_text("f_18923:library_2escm"),(void*)f_18923},
{C_text("f_18929:library_2escm"),(void*)f_18929},
{C_text("f_18949:library_2escm"),(void*)f_18949},
{C_text("f_18953:library_2escm"),(void*)f_18953},
{C_text("f_18965:library_2escm"),(void*)f_18965},
{C_text("f_18971:library_2escm"),(void*)f_18971},
{C_text("f_18977:library_2escm"),(void*)f_18977},
{C_text("f_19009:library_2escm"),(void*)f_19009},
{C_text("f_19013:library_2escm"),(void*)f_19013},
{C_text("f_19023:library_2escm"),(void*)f_19023},
{C_text("f_19038:library_2escm"),(void*)f_19038},
{C_text("f_19048:library_2escm"),(void*)f_19048},
{C_text("f_19068:library_2escm"),(void*)f_19068},
{C_text("f_19075:library_2escm"),(void*)f_19075},
{C_text("f_19084:library_2escm"),(void*)f_19084},
{C_text("f_19091:library_2escm"),(void*)f_19091},
{C_text("f_19093:library_2escm"),(void*)f_19093},
{C_text("f_19099:library_2escm"),(void*)f_19099},
{C_text("f_19105:library_2escm"),(void*)f_19105},
{C_text("f_19123:library_2escm"),(void*)f_19123},
{C_text("f_19148:library_2escm"),(void*)f_19148},
{C_text("f_19164:library_2escm"),(void*)f_19164},
{C_text("f_19171:library_2escm"),(void*)f_19171},
{C_text("f_19184:library_2escm"),(void*)f_19184},
{C_text("f_19188:library_2escm"),(void*)f_19188},
{C_text("f_19192:library_2escm"),(void*)f_19192},
{C_text("f_19194:library_2escm"),(void*)f_19194},
{C_text("f_19200:library_2escm"),(void*)f_19200},
{C_text("f_19207:library_2escm"),(void*)f_19207},
{C_text("f_19211:library_2escm"),(void*)f_19211},
{C_text("f_19220:library_2escm"),(void*)f_19220},
{C_text("f_19228:library_2escm"),(void*)f_19228},
{C_text("f_19238:library_2escm"),(void*)f_19238},
{C_text("f_19244:library_2escm"),(void*)f_19244},
{C_text("f_19247:library_2escm"),(void*)f_19247},
{C_text("f_19251:library_2escm"),(void*)f_19251},
{C_text("f_19278:library_2escm"),(void*)f_19278},
{C_text("f_19294:library_2escm"),(void*)f_19294},
{C_text("f_19300:library_2escm"),(void*)f_19300},
{C_text("f_19323:library_2escm"),(void*)f_19323},
{C_text("f_19336:library_2escm"),(void*)f_19336},
{C_text("f_19342:library_2escm"),(void*)f_19342},
{C_text("f_19347:library_2escm"),(void*)f_19347},
{C_text("f_19352:library_2escm"),(void*)f_19352},
{C_text("f_19356:library_2escm"),(void*)f_19356},
{C_text("f_19365:library_2escm"),(void*)f_19365},
{C_text("f_19396:library_2escm"),(void*)f_19396},
{C_text("f_19400:library_2escm"),(void*)f_19400},
{C_text("f_19404:library_2escm"),(void*)f_19404},
{C_text("f_19407:library_2escm"),(void*)f_19407},
{C_text("f_19410:library_2escm"),(void*)f_19410},
{C_text("f_19413:library_2escm"),(void*)f_19413},
{C_text("f_19415:library_2escm"),(void*)f_19415},
{C_text("f_19426:library_2escm"),(void*)f_19426},
{C_text("f_19437:library_2escm"),(void*)f_19437},
{C_text("f_19448:library_2escm"),(void*)f_19448},
{C_text("f_19459:library_2escm"),(void*)f_19459},
{C_text("f_19472:library_2escm"),(void*)f_19472},
{C_text("f_19474:library_2escm"),(void*)f_19474},
{C_text("f_19480:library_2escm"),(void*)f_19480},
{C_text("f_19485:library_2escm"),(void*)f_19485},
{C_text("f_19520:library_2escm"),(void*)f_19520},
{C_text("f_19533:library_2escm"),(void*)f_19533},
{C_text("f_19535:library_2escm"),(void*)f_19535},
{C_text("f_19541:library_2escm"),(void*)f_19541},
{C_text("f_19546:library_2escm"),(void*)f_19546},
{C_text("f_19581:library_2escm"),(void*)f_19581},
{C_text("f_19594:library_2escm"),(void*)f_19594},
{C_text("f_19596:library_2escm"),(void*)f_19596},
{C_text("f_19602:library_2escm"),(void*)f_19602},
{C_text("f_19607:library_2escm"),(void*)f_19607},
{C_text("f_19642:library_2escm"),(void*)f_19642},
{C_text("f_19654:library_2escm"),(void*)f_19654},
{C_text("f_19656:library_2escm"),(void*)f_19656},
{C_text("f_19662:library_2escm"),(void*)f_19662},
{C_text("f_19668:library_2escm"),(void*)f_19668},
{C_text("f_19678:library_2escm"),(void*)f_19678},
{C_text("f_19681:library_2escm"),(void*)f_19681},
{C_text("f_19684:library_2escm"),(void*)f_19684},
{C_text("f_19687:library_2escm"),(void*)f_19687},
{C_text("f_19694:library_2escm"),(void*)f_19694},
{C_text("f_19698:library_2escm"),(void*)f_19698},
{C_text("f_19702:library_2escm"),(void*)f_19702},
{C_text("f_19706:library_2escm"),(void*)f_19706},
{C_text("f_19712:library_2escm"),(void*)f_19712},
{C_text("f_19725:library_2escm"),(void*)f_19725},
{C_text("f_19767:library_2escm"),(void*)f_19767},
{C_text("f_19771:library_2escm"),(void*)f_19771},
{C_text("f_19804:library_2escm"),(void*)f_19804},
{C_text("f_19810:library_2escm"),(void*)f_19810},
{C_text("f_19816:library_2escm"),(void*)f_19816},
{C_text("f_19822:library_2escm"),(void*)f_19822},
{C_text("f_19828:library_2escm"),(void*)f_19828},
{C_text("f_19832:library_2escm"),(void*)f_19832},
{C_text("f_19837:library_2escm"),(void*)f_19837},
{C_text("f_19843:library_2escm"),(void*)f_19843},
{C_text("f_19847:library_2escm"),(void*)f_19847},
{C_text("f_19852:library_2escm"),(void*)f_19852},
{C_text("f_19856:library_2escm"),(void*)f_19856},
{C_text("f_19861:library_2escm"),(void*)f_19861},
{C_text("f_19867:library_2escm"),(void*)f_19867},
{C_text("f_19871:library_2escm"),(void*)f_19871},
{C_text("f_19876:library_2escm"),(void*)f_19876},
{C_text("f_19880:library_2escm"),(void*)f_19880},
{C_text("f_19885:library_2escm"),(void*)f_19885},
{C_text("f_19890:library_2escm"),(void*)f_19890},
{C_text("f_19896:library_2escm"),(void*)f_19896},
{C_text("f_19900:library_2escm"),(void*)f_19900},
{C_text("f_19905:library_2escm"),(void*)f_19905},
{C_text("f_19910:library_2escm"),(void*)f_19910},
{C_text("f_19914:library_2escm"),(void*)f_19914},
{C_text("f_19919:library_2escm"),(void*)f_19919},
{C_text("f_19924:library_2escm"),(void*)f_19924},
{C_text("f_19930:library_2escm"),(void*)f_19930},
{C_text("f_19934:library_2escm"),(void*)f_19934},
{C_text("f_19939:library_2escm"),(void*)f_19939},
{C_text("f_19944:library_2escm"),(void*)f_19944},
{C_text("f_19949:library_2escm"),(void*)f_19949},
{C_text("f_19970:library_2escm"),(void*)f_19970},
{C_text("f_19977:library_2escm"),(void*)f_19977},
{C_text("f_19983:library_2escm"),(void*)f_19983},
{C_text("f_20001:library_2escm"),(void*)f_20001},
{C_text("f_20010:library_2escm"),(void*)f_20010},
{C_text("f_20023:library_2escm"),(void*)f_20023},
{C_text("f_20031:library_2escm"),(void*)f_20031},
{C_text("f_20036:library_2escm"),(void*)f_20036},
{C_text("f_20073:library_2escm"),(void*)f_20073},
{C_text("f_20085:library_2escm"),(void*)f_20085},
{C_text("f_20095:library_2escm"),(void*)f_20095},
{C_text("f_20111:library_2escm"),(void*)f_20111},
{C_text("f_20124:library_2escm"),(void*)f_20124},
{C_text("f_20131:library_2escm"),(void*)f_20131},
{C_text("f_20133:library_2escm"),(void*)f_20133},
{C_text("f_20146:library_2escm"),(void*)f_20146},
{C_text("f_20152:library_2escm"),(void*)f_20152},
{C_text("f_20159:library_2escm"),(void*)f_20159},
{C_text("f_20161:library_2escm"),(void*)f_20161},
{C_text("f_20165:library_2escm"),(void*)f_20165},
{C_text("f_20168:library_2escm"),(void*)f_20168},
{C_text("f_20178:library_2escm"),(void*)f_20178},
{C_text("f_20182:library_2escm"),(void*)f_20182},
{C_text("f_20190:library_2escm"),(void*)f_20190},
{C_text("f_20193:library_2escm"),(void*)f_20193},
{C_text("f_20200:library_2escm"),(void*)f_20200},
{C_text("f_20203:library_2escm"),(void*)f_20203},
{C_text("f_20206:library_2escm"),(void*)f_20206},
{C_text("f_20209:library_2escm"),(void*)f_20209},
{C_text("f_20217:library_2escm"),(void*)f_20217},
{C_text("f_20225:library_2escm"),(void*)f_20225},
{C_text("f_20227:library_2escm"),(void*)f_20227},
{C_text("f_20243:library_2escm"),(void*)f_20243},
{C_text("f_20270:library_2escm"),(void*)f_20270},
{C_text("f_20274:library_2escm"),(void*)f_20274},
{C_text("f_20278:library_2escm"),(void*)f_20278},
{C_text("f_20282:library_2escm"),(void*)f_20282},
{C_text("f_20286:library_2escm"),(void*)f_20286},
{C_text("f_20290:library_2escm"),(void*)f_20290},
{C_text("f_20294:library_2escm"),(void*)f_20294},
{C_text("f_20298:library_2escm"),(void*)f_20298},
{C_text("f_20302:library_2escm"),(void*)f_20302},
{C_text("f_20306:library_2escm"),(void*)f_20306},
{C_text("f_20310:library_2escm"),(void*)f_20310},
{C_text("f_20314:library_2escm"),(void*)f_20314},
{C_text("f_20318:library_2escm"),(void*)f_20318},
{C_text("f_20322:library_2escm"),(void*)f_20322},
{C_text("f_20326:library_2escm"),(void*)f_20326},
{C_text("f_20330:library_2escm"),(void*)f_20330},
{C_text("f_20334:library_2escm"),(void*)f_20334},
{C_text("f_20341:library_2escm"),(void*)f_20341},
{C_text("f_20348:library_2escm"),(void*)f_20348},
{C_text("f_20349:library_2escm"),(void*)f_20349},
{C_text("f_20353:library_2escm"),(void*)f_20353},
{C_text("f_20356:library_2escm"),(void*)f_20356},
{C_text("f_20372:library_2escm"),(void*)f_20372},
{C_text("f_20383:library_2escm"),(void*)f_20383},
{C_text("f_20391:library_2escm"),(void*)f_20391},
{C_text("f_20403:library_2escm"),(void*)f_20403},
{C_text("f_20412:library_2escm"),(void*)f_20412},
{C_text("f_20417:library_2escm"),(void*)f_20417},
{C_text("f_20473:library_2escm"),(void*)f_20473},
{C_text("f_20487:library_2escm"),(void*)f_20487},
{C_text("f_20499:library_2escm"),(void*)f_20499},
{C_text("f_20505:library_2escm"),(void*)f_20505},
{C_text("f_20530:library_2escm"),(void*)f_20530},
{C_text("f_20548:library_2escm"),(void*)f_20548},
{C_text("f_20552:library_2escm"),(void*)f_20552},
{C_text("f_20608:library_2escm"),(void*)f_20608},
{C_text("f_20617:library_2escm"),(void*)f_20617},
{C_text("f_20630:library_2escm"),(void*)f_20630},
{C_text("f_20642:library_2escm"),(void*)f_20642},
{C_text("f_20660:library_2escm"),(void*)f_20660},
{C_text("f_20680:library_2escm"),(void*)f_20680},
{C_text("f_20683:library_2escm"),(void*)f_20683},
{C_text("f_20686:library_2escm"),(void*)f_20686},
{C_text("f_20694:library_2escm"),(void*)f_20694},
{C_text("f_20698:library_2escm"),(void*)f_20698},
{C_text("f_20702:library_2escm"),(void*)f_20702},
{C_text("f_20706:library_2escm"),(void*)f_20706},
{C_text("f_20710:library_2escm"),(void*)f_20710},
{C_text("f_20712:library_2escm"),(void*)f_20712},
{C_text("f_20720:library_2escm"),(void*)f_20720},
{C_text("f_20723:library_2escm"),(void*)f_20723},
{C_text("f_20733:library_2escm"),(void*)f_20733},
{C_text("f_20735:library_2escm"),(void*)f_20735},
{C_text("f_20743:library_2escm"),(void*)f_20743},
{C_text("f_20746:library_2escm"),(void*)f_20746},
{C_text("f_20756:library_2escm"),(void*)f_20756},
{C_text("f_20758:library_2escm"),(void*)f_20758},
{C_text("f_20762:library_2escm"),(void*)f_20762},
{C_text("f_20765:library_2escm"),(void*)f_20765},
{C_text("f_20768:library_2escm"),(void*)f_20768},
{C_text("f_20771:library_2escm"),(void*)f_20771},
{C_text("f_20774:library_2escm"),(void*)f_20774},
{C_text("f_20776:library_2escm"),(void*)f_20776},
{C_text("f_20782:library_2escm"),(void*)f_20782},
{C_text("f_20791:library_2escm"),(void*)f_20791},
{C_text("f_20799:library_2escm"),(void*)f_20799},
{C_text("f_20801:library_2escm"),(void*)f_20801},
{C_text("f_20815:library_2escm"),(void*)f_20815},
{C_text("f_20828:library_2escm"),(void*)f_20828},
{C_text("f_20832:library_2escm"),(void*)f_20832},
{C_text("f_20837:library_2escm"),(void*)f_20837},
{C_text("f_20841:library_2escm"),(void*)f_20841},
{C_text("f_20852:library_2escm"),(void*)f_20852},
{C_text("f_20855:library_2escm"),(void*)f_20855},
{C_text("f_20863:library_2escm"),(void*)f_20863},
{C_text("f_20865:library_2escm"),(void*)f_20865},
{C_text("f_20878:library_2escm"),(void*)f_20878},
{C_text("f_20885:library_2escm"),(void*)f_20885},
{C_text("f_20894:library_2escm"),(void*)f_20894},
{C_text("f_20901:library_2escm"),(void*)f_20901},
{C_text("f_20903:library_2escm"),(void*)f_20903},
{C_text("f_20909:library_2escm"),(void*)f_20909},
{C_text("f_20919:library_2escm"),(void*)f_20919},
{C_text("f_20922:library_2escm"),(void*)f_20922},
{C_text("f_20932:library_2escm"),(void*)f_20932},
{C_text("f_20935:library_2escm"),(void*)f_20935},
{C_text("f_20963:library_2escm"),(void*)f_20963},
{C_text("f_20967:library_2escm"),(void*)f_20967},
{C_text("f_20975:library_2escm"),(void*)f_20975},
{C_text("f_21000:library_2escm"),(void*)f_21000},
{C_text("f_21008:library_2escm"),(void*)f_21008},
{C_text("f_21010:library_2escm"),(void*)f_21010},
{C_text("f_21027:library_2escm"),(void*)f_21027},
{C_text("f_21040:library_2escm"),(void*)f_21040},
{C_text("f_21057:library_2escm"),(void*)f_21057},
{C_text("f_21074:library_2escm"),(void*)f_21074},
{C_text("f_21091:library_2escm"),(void*)f_21091},
{C_text("f_21108:library_2escm"),(void*)f_21108},
{C_text("f_21125:library_2escm"),(void*)f_21125},
{C_text("f_21142:library_2escm"),(void*)f_21142},
{C_text("f_21162:library_2escm"),(void*)f_21162},
{C_text("f_21170:library_2escm"),(void*)f_21170},
{C_text("f_21179:library_2escm"),(void*)f_21179},
{C_text("f_21185:library_2escm"),(void*)f_21185},
{C_text("f_21191:library_2escm"),(void*)f_21191},
{C_text("f_21194:library_2escm"),(void*)f_21194},
{C_text("f_21197:library_2escm"),(void*)f_21197},
{C_text("f_21207:library_2escm"),(void*)f_21207},
{C_text("f_21211:library_2escm"),(void*)f_21211},
{C_text("f_21228:library_2escm"),(void*)f_21228},
{C_text("f_21233:library_2escm"),(void*)f_21233},
{C_text("f_21240:library_2escm"),(void*)f_21240},
{C_text("f_21244:library_2escm"),(void*)f_21244},
{C_text("f_21253:library_2escm"),(void*)f_21253},
{C_text("f_21259:library_2escm"),(void*)f_21259},
{C_text("f_21269:library_2escm"),(void*)f_21269},
{C_text("f_21273:library_2escm"),(void*)f_21273},
{C_text("f_21282:library_2escm"),(void*)f_21282},
{C_text("f_21289:library_2escm"),(void*)f_21289},
{C_text("f_21302:library_2escm"),(void*)f_21302},
{C_text("f_21307:library_2escm"),(void*)f_21307},
{C_text("f_21324:library_2escm"),(void*)f_21324},
{C_text("f_21339:library_2escm"),(void*)f_21339},
{C_text("f_21352:library_2escm"),(void*)f_21352},
{C_text("f_21374:library_2escm"),(void*)f_21374},
{C_text("f_21377:library_2escm"),(void*)f_21377},
{C_text("f_21406:library_2escm"),(void*)f_21406},
{C_text("f_21416:library_2escm"),(void*)f_21416},
{C_text("f_21432:library_2escm"),(void*)f_21432},
{C_text("f_21443:library_2escm"),(void*)f_21443},
{C_text("f_21450:library_2escm"),(void*)f_21450},
{C_text("f_21548:library_2escm"),(void*)f_21548},
{C_text("f_21554:library_2escm"),(void*)f_21554},
{C_text("f_21563:library_2escm"),(void*)f_21563},
{C_text("f_21577:library_2escm"),(void*)f_21577},
{C_text("f_21580:library_2escm"),(void*)f_21580},
{C_text("f_21591:library_2escm"),(void*)f_21591},
{C_text("f_21593:library_2escm"),(void*)f_21593},
{C_text("f_21596:library_2escm"),(void*)f_21596},
{C_text("f_21613:library_2escm"),(void*)f_21613},
{C_text("f_21618:library_2escm"),(void*)f_21618},
{C_text("f_21622:library_2escm"),(void*)f_21622},
{C_text("f_21625:library_2escm"),(void*)f_21625},
{C_text("f_21628:library_2escm"),(void*)f_21628},
{C_text("f_21638:library_2escm"),(void*)f_21638},
{C_text("f_21656:library_2escm"),(void*)f_21656},
{C_text("f_21659:library_2escm"),(void*)f_21659},
{C_text("f_21668:library_2escm"),(void*)f_21668},
{C_text("f_21671:library_2escm"),(void*)f_21671},
{C_text("f_21674:library_2escm"),(void*)f_21674},
{C_text("f_21680:library_2escm"),(void*)f_21680},
{C_text("f_21693:library_2escm"),(void*)f_21693},
{C_text("f_21697:library_2escm"),(void*)f_21697},
{C_text("f_21701:library_2escm"),(void*)f_21701},
{C_text("f_21712:library_2escm"),(void*)f_21712},
{C_text("f_21716:library_2escm"),(void*)f_21716},
{C_text("f_21719:library_2escm"),(void*)f_21719},
{C_text("f_21747:library_2escm"),(void*)f_21747},
{C_text("f_21803:library_2escm"),(void*)f_21803},
{C_text("f_21807:library_2escm"),(void*)f_21807},
{C_text("f_21814:library_2escm"),(void*)f_21814},
{C_text("f_21816:library_2escm"),(void*)f_21816},
{C_text("f_21820:library_2escm"),(void*)f_21820},
{C_text("f_21834:library_2escm"),(void*)f_21834},
{C_text("f_21840:library_2escm"),(void*)f_21840},
{C_text("f_21847:library_2escm"),(void*)f_21847},
{C_text("f_21854:library_2escm"),(void*)f_21854},
{C_text("f_21875:library_2escm"),(void*)f_21875},
{C_text("f_21904:library_2escm"),(void*)f_21904},
{C_text("f_21914:library_2escm"),(void*)f_21914},
{C_text("f_21917:library_2escm"),(void*)f_21917},
{C_text("f_21953:library_2escm"),(void*)f_21953},
{C_text("f_21955:library_2escm"),(void*)f_21955},
{C_text("f_21965:library_2escm"),(void*)f_21965},
{C_text("f_21968:library_2escm"),(void*)f_21968},
{C_text("f_22020:library_2escm"),(void*)f_22020},
{C_text("f_22022:library_2escm"),(void*)f_22022},
{C_text("f_22030:library_2escm"),(void*)f_22030},
{C_text("f_22032:library_2escm"),(void*)f_22032},
{C_text("f_22042:library_2escm"),(void*)f_22042},
{C_text("f_22057:library_2escm"),(void*)f_22057},
{C_text("f_22064:library_2escm"),(void*)f_22064},
{C_text("f_22086:library_2escm"),(void*)f_22086},
{C_text("f_22094:library_2escm"),(void*)f_22094},
{C_text("f_22096:library_2escm"),(void*)f_22096},
{C_text("f_22112:library_2escm"),(void*)f_22112},
{C_text("f_22119:library_2escm"),(void*)f_22119},
{C_text("f_22132:library_2escm"),(void*)f_22132},
{C_text("f_22138:library_2escm"),(void*)f_22138},
{C_text("f_22142:library_2escm"),(void*)f_22142},
{C_text("f_22149:library_2escm"),(void*)f_22149},
{C_text("f_22157:library_2escm"),(void*)f_22157},
{C_text("f_22162:library_2escm"),(void*)f_22162},
{C_text("f_22167:library_2escm"),(void*)f_22167},
{C_text("f_22171:library_2escm"),(void*)f_22171},
{C_text("f_22180:library_2escm"),(void*)f_22180},
{C_text("f_22186:library_2escm"),(void*)f_22186},
{C_text("f_22193:library_2escm"),(void*)f_22193},
{C_text("f_22210:library_2escm"),(void*)f_22210},
{C_text("f_22216:library_2escm"),(void*)f_22216},
{C_text("f_22226:library_2escm"),(void*)f_22226},
{C_text("f_22277:library_2escm"),(void*)f_22277},
{C_text("f_22286:library_2escm"),(void*)f_22286},
{C_text("f_22293:library_2escm"),(void*)f_22293},
{C_text("f_22297:library_2escm"),(void*)f_22297},
{C_text("f_22301:library_2escm"),(void*)f_22301},
{C_text("f_22310:library_2escm"),(void*)f_22310},
{C_text("f_22321:library_2escm"),(void*)f_22321},
{C_text("f_22343:library_2escm"),(void*)f_22343},
{C_text("f_22402:library_2escm"),(void*)f_22402},
{C_text("f_22406:library_2escm"),(void*)f_22406},
{C_text("f_22408:library_2escm"),(void*)f_22408},
{C_text("f_22412:library_2escm"),(void*)f_22412},
{C_text("f_22415:library_2escm"),(void*)f_22415},
{C_text("f_22427:library_2escm"),(void*)f_22427},
{C_text("f_22447:library_2escm"),(void*)f_22447},
{C_text("f_22453:library_2escm"),(void*)f_22453},
{C_text("f_22463:library_2escm"),(void*)f_22463},
{C_text("f_22592:library_2escm"),(void*)f_22592},
{C_text("f_22599:library_2escm"),(void*)f_22599},
{C_text("f_22617:library_2escm"),(void*)f_22617},
{C_text("f_22623:library_2escm"),(void*)f_22623},
{C_text("f_22627:library_2escm"),(void*)f_22627},
{C_text("f_22663:library_2escm"),(void*)f_22663},
{C_text("f_22686:library_2escm"),(void*)f_22686},
{C_text("f_22704:library_2escm"),(void*)f_22704},
{C_text("f_22708:library_2escm"),(void*)f_22708},
{C_text("f_22715:library_2escm"),(void*)f_22715},
{C_text("f_22717:library_2escm"),(void*)f_22717},
{C_text("f_22721:library_2escm"),(void*)f_22721},
{C_text("f_22732:library_2escm"),(void*)f_22732},
{C_text("f_22748:library_2escm"),(void*)f_22748},
{C_text("f_22751:library_2escm"),(void*)f_22751},
{C_text("f_22754:library_2escm"),(void*)f_22754},
{C_text("f_22768:library_2escm"),(void*)f_22768},
{C_text("f_22774:library_2escm"),(void*)f_22774},
{C_text("f_22796:library_2escm"),(void*)f_22796},
{C_text("f_22808:library_2escm"),(void*)f_22808},
{C_text("f_22820:library_2escm"),(void*)f_22820},
{C_text("f_22829:library_2escm"),(void*)f_22829},
{C_text("f_22839:library_2escm"),(void*)f_22839},
{C_text("f_22848:library_2escm"),(void*)f_22848},
{C_text("f_22851:library_2escm"),(void*)f_22851},
{C_text("f_22869:library_2escm"),(void*)f_22869},
{C_text("f_22872:library_2escm"),(void*)f_22872},
{C_text("f_22895:library_2escm"),(void*)f_22895},
{C_text("f_22901:library_2escm"),(void*)f_22901},
{C_text("f_22929:library_2escm"),(void*)f_22929},
{C_text("f_22952:library_2escm"),(void*)f_22952},
{C_text("f_22966:library_2escm"),(void*)f_22966},
{C_text("f_22972:library_2escm"),(void*)f_22972},
{C_text("f_22997:library_2escm"),(void*)f_22997},
{C_text("f_23009:library_2escm"),(void*)f_23009},
{C_text("f_23021:library_2escm"),(void*)f_23021},
{C_text("f_23033:library_2escm"),(void*)f_23033},
{C_text("f_23045:library_2escm"),(void*)f_23045},
{C_text("f_23057:library_2escm"),(void*)f_23057},
{C_text("f_23069:library_2escm"),(void*)f_23069},
{C_text("f_23072:library_2escm"),(void*)f_23072},
{C_text("f_23075:library_2escm"),(void*)f_23075},
{C_text("f_23080:library_2escm"),(void*)f_23080},
{C_text("f_23085:library_2escm"),(void*)f_23085},
{C_text("f_23091:library_2escm"),(void*)f_23091},
{C_text("f_23133:library_2escm"),(void*)f_23133},
{C_text("f_23145:library_2escm"),(void*)f_23145},
{C_text("f_23148:library_2escm"),(void*)f_23148},
{C_text("f_23160:library_2escm"),(void*)f_23160},
{C_text("f_23172:library_2escm"),(void*)f_23172},
{C_text("f_23175:library_2escm"),(void*)f_23175},
{C_text("f_23187:library_2escm"),(void*)f_23187},
{C_text("f_23199:library_2escm"),(void*)f_23199},
{C_text("f_23202:library_2escm"),(void*)f_23202},
{C_text("f_23211:library_2escm"),(void*)f_23211},
{C_text("f_23226:library_2escm"),(void*)f_23226},
{C_text("f_23229:library_2escm"),(void*)f_23229},
{C_text("f_23234:library_2escm"),(void*)f_23234},
{C_text("f_23239:library_2escm"),(void*)f_23239},
{C_text("f_23245:library_2escm"),(void*)f_23245},
{C_text("f_23274:library_2escm"),(void*)f_23274},
{C_text("f_23286:library_2escm"),(void*)f_23286},
{C_text("f_23289:library_2escm"),(void*)f_23289},
{C_text("f_23292:library_2escm"),(void*)f_23292},
{C_text("f_23307:library_2escm"),(void*)f_23307},
{C_text("f_23316:library_2escm"),(void*)f_23316},
{C_text("f_23319:library_2escm"),(void*)f_23319},
{C_text("f_23325:library_2escm"),(void*)f_23325},
{C_text("f_23328:library_2escm"),(void*)f_23328},
{C_text("f_23334:library_2escm"),(void*)f_23334},
{C_text("f_23358:library_2escm"),(void*)f_23358},
{C_text("f_23377:library_2escm"),(void*)f_23377},
{C_text("f_23393:library_2escm"),(void*)f_23393},
{C_text("f_23399:library_2escm"),(void*)f_23399},
{C_text("f_23471:library_2escm"),(void*)f_23471},
{C_text("f_23483:library_2escm"),(void*)f_23483},
{C_text("f_23561:library_2escm"),(void*)f_23561},
{C_text("f_23637:library_2escm"),(void*)f_23637},
{C_text("f_23802:library_2escm"),(void*)f_23802},
{C_text("f_23814:library_2escm"),(void*)f_23814},
{C_text("f_23876:library_2escm"),(void*)f_23876},
{C_text("f_23879:library_2escm"),(void*)f_23879},
{C_text("f_23925:library_2escm"),(void*)f_23925},
{C_text("f_23929:library_2escm"),(void*)f_23929},
{C_text("f_23947:library_2escm"),(void*)f_23947},
{C_text("f_24011:library_2escm"),(void*)f_24011},
{C_text("f_24022:library_2escm"),(void*)f_24022},
{C_text("f_24024:library_2escm"),(void*)f_24024},
{C_text("f_24037:library_2escm"),(void*)f_24037},
{C_text("f_24049:library_2escm"),(void*)f_24049},
{C_text("f_24069:library_2escm"),(void*)f_24069},
{C_text("f_24076:library_2escm"),(void*)f_24076},
{C_text("f_24085:library_2escm"),(void*)f_24085},
{C_text("f_24097:library_2escm"),(void*)f_24097},
{C_text("f_24118:library_2escm"),(void*)f_24118},
{C_text("f_24133:library_2escm"),(void*)f_24133},
{C_text("f_24151:library_2escm"),(void*)f_24151},
{C_text("f_24169:library_2escm"),(void*)f_24169},
{C_text("f_24188:library_2escm"),(void*)f_24188},
{C_text("f_24198:library_2escm"),(void*)f_24198},
{C_text("f_24212:library_2escm"),(void*)f_24212},
{C_text("f_24215:library_2escm"),(void*)f_24215},
{C_text("f_24220:library_2escm"),(void*)f_24220},
{C_text("f_24239:library_2escm"),(void*)f_24239},
{C_text("f_24249:library_2escm"),(void*)f_24249},
{C_text("f_24263:library_2escm"),(void*)f_24263},
{C_text("f_24266:library_2escm"),(void*)f_24266},
{C_text("f_24273:library_2escm"),(void*)f_24273},
{C_text("f_24277:library_2escm"),(void*)f_24277},
{C_text("f_24281:library_2escm"),(void*)f_24281},
{C_text("f_24283:library_2escm"),(void*)f_24283},
{C_text("f_24290:library_2escm"),(void*)f_24290},
{C_text("f_24293:library_2escm"),(void*)f_24293},
{C_text("f_24296:library_2escm"),(void*)f_24296},
{C_text("f_24298:library_2escm"),(void*)f_24298},
{C_text("f_24308:library_2escm"),(void*)f_24308},
{C_text("f_24314:library_2escm"),(void*)f_24314},
{C_text("f_24326:library_2escm"),(void*)f_24326},
{C_text("f_24329:library_2escm"),(void*)f_24329},
{C_text("f_24332:library_2escm"),(void*)f_24332},
{C_text("f_24349:library_2escm"),(void*)f_24349},
{C_text("f_24370:library_2escm"),(void*)f_24370},
{C_text("f_24374:library_2escm"),(void*)f_24374},
{C_text("f_24387:library_2escm"),(void*)f_24387},
{C_text("f_24390:library_2escm"),(void*)f_24390},
{C_text("f_24399:library_2escm"),(void*)f_24399},
{C_text("f_24402:library_2escm"),(void*)f_24402},
{C_text("f_24430:library_2escm"),(void*)f_24430},
{C_text("f_24434:library_2escm"),(void*)f_24434},
{C_text("f_24443:library_2escm"),(void*)f_24443},
{C_text("f_24454:library_2escm"),(void*)f_24454},
{C_text("f_24461:library_2escm"),(void*)f_24461},
{C_text("f_24466:library_2escm"),(void*)f_24466},
{C_text("f_24488:library_2escm"),(void*)f_24488},
{C_text("f_24494:library_2escm"),(void*)f_24494},
{C_text("f_24497:library_2escm"),(void*)f_24497},
{C_text("f_24508:library_2escm"),(void*)f_24508},
{C_text("f_24517:library_2escm"),(void*)f_24517},
{C_text("f_24520:library_2escm"),(void*)f_24520},
{C_text("f_24543:library_2escm"),(void*)f_24543},
{C_text("f_24592:library_2escm"),(void*)f_24592},
{C_text("f_24608:library_2escm"),(void*)f_24608},
{C_text("f_24615:library_2escm"),(void*)f_24615},
{C_text("f_24627:library_2escm"),(void*)f_24627},
{C_text("f_24732:library_2escm"),(void*)f_24732},
{C_text("f_24737:library_2escm"),(void*)f_24737},
{C_text("f_24792:library_2escm"),(void*)f_24792},
{C_text("f_24798:library_2escm"),(void*)f_24798},
{C_text("f_24802:library_2escm"),(void*)f_24802},
{C_text("f_24825:library_2escm"),(void*)f_24825},
{C_text("f_24832:library_2escm"),(void*)f_24832},
{C_text("f_24851:library_2escm"),(void*)f_24851},
{C_text("f_24887:library_2escm"),(void*)f_24887},
{C_text("f_24899:library_2escm"),(void*)f_24899},
{C_text("f_24905:library_2escm"),(void*)f_24905},
{C_text("f_24927:library_2escm"),(void*)f_24927},
{C_text("f_24934:library_2escm"),(void*)f_24934},
{C_text("f_24944:library_2escm"),(void*)f_24944},
{C_text("f_24953:library_2escm"),(void*)f_24953},
{C_text("f_24959:library_2escm"),(void*)f_24959},
{C_text("f_24972:library_2escm"),(void*)f_24972},
{C_text("f_25010:library_2escm"),(void*)f_25010},
{C_text("f_25076:library_2escm"),(void*)f_25076},
{C_text("f_25079:library_2escm"),(void*)f_25079},
{C_text("f_25086:library_2escm"),(void*)f_25086},
{C_text("f_25126:library_2escm"),(void*)f_25126},
{C_text("f_25129:library_2escm"),(void*)f_25129},
{C_text("f_25138:library_2escm"),(void*)f_25138},
{C_text("f_25151:library_2escm"),(void*)f_25151},
{C_text("f_25160:library_2escm"),(void*)f_25160},
{C_text("f_25170:library_2escm"),(void*)f_25170},
{C_text("f_25173:library_2escm"),(void*)f_25173},
{C_text("f_25199:library_2escm"),(void*)f_25199},
{C_text("f_25205:library_2escm"),(void*)f_25205},
{C_text("f_25210:library_2escm"),(void*)f_25210},
{C_text("f_25223:library_2escm"),(void*)f_25223},
{C_text("f_25226:library_2escm"),(void*)f_25226},
{C_text("f_25237:library_2escm"),(void*)f_25237},
{C_text("f_25259:library_2escm"),(void*)f_25259},
{C_text("f_25271:library_2escm"),(void*)f_25271},
{C_text("f_25274:library_2escm"),(void*)f_25274},
{C_text("f_25281:library_2escm"),(void*)f_25281},
{C_text("f_25290:library_2escm"),(void*)f_25290},
{C_text("f_25293:library_2escm"),(void*)f_25293},
{C_text("f_25337:library_2escm"),(void*)f_25337},
{C_text("f_25340:library_2escm"),(void*)f_25340},
{C_text("f_25349:library_2escm"),(void*)f_25349},
{C_text("f_25362:library_2escm"),(void*)f_25362},
{C_text("f_25365:library_2escm"),(void*)f_25365},
{C_text("f_25390:library_2escm"),(void*)f_25390},
{C_text("f_25394:library_2escm"),(void*)f_25394},
{C_text("f_25404:library_2escm"),(void*)f_25404},
{C_text("f_25407:library_2escm"),(void*)f_25407},
{C_text("f_25422:library_2escm"),(void*)f_25422},
{C_text("f_25429:library_2escm"),(void*)f_25429},
{C_text("f_25451:library_2escm"),(void*)f_25451},
{C_text("f_25453:library_2escm"),(void*)f_25453},
{C_text("f_25466:library_2escm"),(void*)f_25466},
{C_text("f_25471:library_2escm"),(void*)f_25471},
{C_text("f_25477:library_2escm"),(void*)f_25477},
{C_text("f_25483:library_2escm"),(void*)f_25483},
{C_text("f_25487:library_2escm"),(void*)f_25487},
{C_text("f_25490:library_2escm"),(void*)f_25490},
{C_text("f_25505:library_2escm"),(void*)f_25505},
{C_text("f_25508:library_2escm"),(void*)f_25508},
{C_text("f_25526:library_2escm"),(void*)f_25526},
{C_text("f_25528:library_2escm"),(void*)f_25528},
{C_text("f_25534:library_2escm"),(void*)f_25534},
{C_text("f_25543:library_2escm"),(void*)f_25543},
{C_text("f_25549:library_2escm"),(void*)f_25549},
{C_text("f_25556:library_2escm"),(void*)f_25556},
{C_text("f_25559:library_2escm"),(void*)f_25559},
{C_text("f_25562:library_2escm"),(void*)f_25562},
{C_text("f_25571:library_2escm"),(void*)f_25571},
{C_text("f_25587:library_2escm"),(void*)f_25587},
{C_text("f_25602:library_2escm"),(void*)f_25602},
{C_text("f_25604:library_2escm"),(void*)f_25604},
{C_text("f_25610:library_2escm"),(void*)f_25610},
{C_text("f_25616:library_2escm"),(void*)f_25616},
{C_text("f_25620:library_2escm"),(void*)f_25620},
{C_text("f_25623:library_2escm"),(void*)f_25623},
{C_text("f_25626:library_2escm"),(void*)f_25626},
{C_text("f_25630:library_2escm"),(void*)f_25630},
{C_text("f_25634:library_2escm"),(void*)f_25634},
{C_text("f_25638:library_2escm"),(void*)f_25638},
{C_text("f_25641:library_2escm"),(void*)f_25641},
{C_text("f_25644:library_2escm"),(void*)f_25644},
{C_text("f_25647:library_2escm"),(void*)f_25647},
{C_text("f_25659:library_2escm"),(void*)f_25659},
{C_text("f_25665:library_2escm"),(void*)f_25665},
{C_text("f_25669:library_2escm"),(void*)f_25669},
{C_text("f_25672:library_2escm"),(void*)f_25672},
{C_text("f_25675:library_2escm"),(void*)f_25675},
{C_text("f_25678:library_2escm"),(void*)f_25678},
{C_text("f_25681:library_2escm"),(void*)f_25681},
{C_text("f_25684:library_2escm"),(void*)f_25684},
{C_text("f_25689:library_2escm"),(void*)f_25689},
{C_text("f_25711:library_2escm"),(void*)f_25711},
{C_text("f_25717:library_2escm"),(void*)f_25717},
{C_text("f_25720:library_2escm"),(void*)f_25720},
{C_text("f_25745:library_2escm"),(void*)f_25745},
{C_text("f_25748:library_2escm"),(void*)f_25748},
{C_text("f_25755:library_2escm"),(void*)f_25755},
{C_text("f_25768:library_2escm"),(void*)f_25768},
{C_text("f_25778:library_2escm"),(void*)f_25778},
{C_text("f_25783:library_2escm"),(void*)f_25783},
{C_text("f_25789:library_2escm"),(void*)f_25789},
{C_text("f_25816:library_2escm"),(void*)f_25816},
{C_text("f_25822:library_2escm"),(void*)f_25822},
{C_text("f_25833:library_2escm"),(void*)f_25833},
{C_text("f_25842:library_2escm"),(void*)f_25842},
{C_text("f_25847:library_2escm"),(void*)f_25847},
{C_text("f_25853:library_2escm"),(void*)f_25853},
{C_text("f_25877:library_2escm"),(void*)f_25877},
{C_text("f_25885:library_2escm"),(void*)f_25885},
{C_text("f_25902:library_2escm"),(void*)f_25902},
{C_text("f_25942:library_2escm"),(void*)f_25942},
{C_text("f_25949:library_2escm"),(void*)f_25949},
{C_text("f_25961:library_2escm"),(void*)f_25961},
{C_text("f_25965:library_2escm"),(void*)f_25965},
{C_text("f_25978:library_2escm"),(void*)f_25978},
{C_text("f_25980:library_2escm"),(void*)f_25980},
{C_text("f_26014:library_2escm"),(void*)f_26014},
{C_text("f_26018:library_2escm"),(void*)f_26018},
{C_text("f_26019:library_2escm"),(void*)f_26019},
{C_text("f_26029:library_2escm"),(void*)f_26029},
{C_text("f_26034:library_2escm"),(void*)f_26034},
{C_text("f_26044:library_2escm"),(void*)f_26044},
{C_text("f_26057:library_2escm"),(void*)f_26057},
{C_text("f_26068:library_2escm"),(void*)f_26068},
{C_text("f_26072:library_2escm"),(void*)f_26072},
{C_text("f_26076:library_2escm"),(void*)f_26076},
{C_text("f_26098:library_2escm"),(void*)f_26098},
{C_text("f_26102:library_2escm"),(void*)f_26102},
{C_text("f_26110:library_2escm"),(void*)f_26110},
{C_text("f_26126:library_2escm"),(void*)f_26126},
{C_text("f_26137:library_2escm"),(void*)f_26137},
{C_text("f_26156:library_2escm"),(void*)f_26156},
{C_text("f_26167:library_2escm"),(void*)f_26167},
{C_text("f_26178:library_2escm"),(void*)f_26178},
{C_text("f_26264:library_2escm"),(void*)f_26264},
{C_text("f_26274:library_2escm"),(void*)f_26274},
{C_text("f_26275:library_2escm"),(void*)f_26275},
{C_text("f_26288:library_2escm"),(void*)f_26288},
{C_text("f_26291:library_2escm"),(void*)f_26291},
{C_text("f_26294:library_2escm"),(void*)f_26294},
{C_text("f_26297:library_2escm"),(void*)f_26297},
{C_text("f_26305:library_2escm"),(void*)f_26305},
{C_text("f_26312:library_2escm"),(void*)f_26312},
{C_text("f_26315:library_2escm"),(void*)f_26315},
{C_text("f_26318:library_2escm"),(void*)f_26318},
{C_text("f_26341:library_2escm"),(void*)f_26341},
{C_text("f_26346:library_2escm"),(void*)f_26346},
{C_text("f_26356:library_2escm"),(void*)f_26356},
{C_text("f_26369:library_2escm"),(void*)f_26369},
{C_text("f_26400:library_2escm"),(void*)f_26400},
{C_text("f_26410:library_2escm"),(void*)f_26410},
{C_text("f_26460:library_2escm"),(void*)f_26460},
{C_text("f_26463:library_2escm"),(void*)f_26463},
{C_text("f_26482:library_2escm"),(void*)f_26482},
{C_text("f_26487:library_2escm"),(void*)f_26487},
{C_text("f_26493:library_2escm"),(void*)f_26493},
{C_text("f_26496:library_2escm"),(void*)f_26496},
{C_text("f_26505:library_2escm"),(void*)f_26505},
{C_text("f_26511:library_2escm"),(void*)f_26511},
{C_text("f_26530:library_2escm"),(void*)f_26530},
{C_text("f_26549:library_2escm"),(void*)f_26549},
{C_text("f_26554:library_2escm"),(void*)f_26554},
{C_text("f_26564:library_2escm"),(void*)f_26564},
{C_text("f_26578:library_2escm"),(void*)f_26578},
{C_text("f_26585:library_2escm"),(void*)f_26585},
{C_text("f_26589:library_2escm"),(void*)f_26589},
{C_text("f_26593:library_2escm"),(void*)f_26593},
{C_text("f_26595:library_2escm"),(void*)f_26595},
{C_text("f_26621:library_2escm"),(void*)f_26621},
{C_text("f_26624:library_2escm"),(void*)f_26624},
{C_text("f_26627:library_2escm"),(void*)f_26627},
{C_text("f_26634:library_2escm"),(void*)f_26634},
{C_text("f_26638:library_2escm"),(void*)f_26638},
{C_text("f_26644:library_2escm"),(void*)f_26644},
{C_text("f_26649:library_2escm"),(void*)f_26649},
{C_text("f_26659:library_2escm"),(void*)f_26659},
{C_text("f_26697:library_2escm"),(void*)f_26697},
{C_text("f_26700:library_2escm"),(void*)f_26700},
{C_text("f_26720:library_2escm"),(void*)f_26720},
{C_text("f_26738:library_2escm"),(void*)f_26738},
{C_text("f_26872:library_2escm"),(void*)f_26872},
{C_text("f_26889:library_2escm"),(void*)f_26889},
{C_text("f_26904:library_2escm"),(void*)f_26904},
{C_text("f_26908:library_2escm"),(void*)f_26908},
{C_text("f_26921:library_2escm"),(void*)f_26921},
{C_text("f_26929:library_2escm"),(void*)f_26929},
{C_text("f_26932:library_2escm"),(void*)f_26932},
{C_text("f_26936:library_2escm"),(void*)f_26936},
{C_text("f_26975:library_2escm"),(void*)f_26975},
{C_text("f_26978:library_2escm"),(void*)f_26978},
{C_text("f_26985:library_2escm"),(void*)f_26985},
{C_text("f_26989:library_2escm"),(void*)f_26989},
{C_text("f_27015:library_2escm"),(void*)f_27015},
{C_text("f_27046:library_2escm"),(void*)f_27046},
{C_text("f_27049:library_2escm"),(void*)f_27049},
{C_text("f_27061:library_2escm"),(void*)f_27061},
{C_text("f_27064:library_2escm"),(void*)f_27064},
{C_text("f_27067:library_2escm"),(void*)f_27067},
{C_text("f_27092:library_2escm"),(void*)f_27092},
{C_text("f_27098:library_2escm"),(void*)f_27098},
{C_text("f_27102:library_2escm"),(void*)f_27102},
{C_text("f_27106:library_2escm"),(void*)f_27106},
{C_text("f_27119:library_2escm"),(void*)f_27119},
{C_text("f_27121:library_2escm"),(void*)f_27121},
{C_text("f_27127:library_2escm"),(void*)f_27127},
{C_text("f_27132:library_2escm"),(void*)f_27132},
{C_text("f_27167:library_2escm"),(void*)f_27167},
{C_text("f_27173:library_2escm"),(void*)f_27173},
{C_text("f_27189:library_2escm"),(void*)f_27189},
{C_text("f_27211:library_2escm"),(void*)f_27211},
{C_text("f_27235:library_2escm"),(void*)f_27235},
{C_text("f_27247:library_2escm"),(void*)f_27247},
{C_text("f_27249:library_2escm"),(void*)f_27249},
{C_text("f_27268:library_2escm"),(void*)f_27268},
{C_text("f_27272:library_2escm"),(void*)f_27272},
{C_text("f_27284:library_2escm"),(void*)f_27284},
{C_text("f_27286:library_2escm"),(void*)f_27286},
{C_text("f_27330:library_2escm"),(void*)f_27330},
{C_text("f_27332:library_2escm"),(void*)f_27332},
{C_text("f_27366:library_2escm"),(void*)f_27366},
{C_text("f_27389:library_2escm"),(void*)f_27389},
{C_text("f_27396:library_2escm"),(void*)f_27396},
{C_text("f_27406:library_2escm"),(void*)f_27406},
{C_text("f_27408:library_2escm"),(void*)f_27408},
{C_text("f_27458:library_2escm"),(void*)f_27458},
{C_text("f_27460:library_2escm"),(void*)f_27460},
{C_text("f_27485:library_2escm"),(void*)f_27485},
{C_text("f_27494:library_2escm"),(void*)f_27494},
{C_text("f_27500:library_2escm"),(void*)f_27500},
{C_text("f_27504:library_2escm"),(void*)f_27504},
{C_text("f_27508:library_2escm"),(void*)f_27508},
{C_text("f_27516:library_2escm"),(void*)f_27516},
{C_text("f_27522:library_2escm"),(void*)f_27522},
{C_text("f_27553:library_2escm"),(void*)f_27553},
{C_text("f_27578:library_2escm"),(void*)f_27578},
{C_text("f_27603:library_2escm"),(void*)f_27603},
{C_text("f_27613:library_2escm"),(void*)f_27613},
{C_text("f_27618:library_2escm"),(void*)f_27618},
{C_text("f_27620:library_2escm"),(void*)f_27620},
{C_text("f_27627:library_2escm"),(void*)f_27627},
{C_text("f_27639:library_2escm"),(void*)f_27639},
{C_text("f_27647:library_2escm"),(void*)f_27647},
{C_text("f_27685:library_2escm"),(void*)f_27685},
{C_text("f_27689:library_2escm"),(void*)f_27689},
{C_text("f_27696:library_2escm"),(void*)f_27696},
{C_text("f_27699:library_2escm"),(void*)f_27699},
{C_text("f_27702:library_2escm"),(void*)f_27702},
{C_text("f_27703:library_2escm"),(void*)f_27703},
{C_text("f_27705:library_2escm"),(void*)f_27705},
{C_text("f_27709:library_2escm"),(void*)f_27709},
{C_text("f_27714:library_2escm"),(void*)f_27714},
{C_text("f_27726:library_2escm"),(void*)f_27726},
{C_text("f_27736:library_2escm"),(void*)f_27736},
{C_text("f_27748:library_2escm"),(void*)f_27748},
{C_text("f_27750:library_2escm"),(void*)f_27750},
{C_text("f_27757:library_2escm"),(void*)f_27757},
{C_text("f_27760:library_2escm"),(void*)f_27760},
{C_text("f_27769:library_2escm"),(void*)f_27769},
{C_text("f_27772:library_2escm"),(void*)f_27772},
{C_text("f_27775:library_2escm"),(void*)f_27775},
{C_text("f_27790:library_2escm"),(void*)f_27790},
{C_text("f_27796:library_2escm"),(void*)f_27796},
{C_text("f_27804:library_2escm"),(void*)f_27804},
{C_text("f_27808:library_2escm"),(void*)f_27808},
{C_text("f_27811:library_2escm"),(void*)f_27811},
{C_text("f_27814:library_2escm"),(void*)f_27814},
{C_text("f_27827:library_2escm"),(void*)f_27827},
{C_text("f_27831:library_2escm"),(void*)f_27831},
{C_text("f_27852:library_2escm"),(void*)f_27852},
{C_text("f_27868:library_2escm"),(void*)f_27868},
{C_text("f_27871:library_2escm"),(void*)f_27871},
{C_text("f_27877:library_2escm"),(void*)f_27877},
{C_text("f_27899:library_2escm"),(void*)f_27899},
{C_text("f_27904:library_2escm"),(void*)f_27904},
{C_text("f_27939:library_2escm"),(void*)f_27939},
{C_text("f_27949:library_2escm"),(void*)f_27949},
{C_text("f_27952:library_2escm"),(void*)f_27952},
{C_text("f_27955:library_2escm"),(void*)f_27955},
{C_text("f_27958:library_2escm"),(void*)f_27958},
{C_text("f_27961:library_2escm"),(void*)f_27961},
{C_text("f_27964:library_2escm"),(void*)f_27964},
{C_text("f_27971:library_2escm"),(void*)f_27971},
{C_text("f_27974:library_2escm"),(void*)f_27974},
{C_text("f_27977:library_2escm"),(void*)f_27977},
{C_text("f_27988:library_2escm"),(void*)f_27988},
{C_text("f_28011:library_2escm"),(void*)f_28011},
{C_text("f_28022:library_2escm"),(void*)f_28022},
{C_text("f_28026:library_2escm"),(void*)f_28026},
{C_text("f_28048:library_2escm"),(void*)f_28048},
{C_text("f_28059:library_2escm"),(void*)f_28059},
{C_text("f_28063:library_2escm"),(void*)f_28063},
{C_text("f_28562:library_2escm"),(void*)f_28562},
{C_text("f_28573:library_2escm"),(void*)f_28573},
{C_text("f_28577:library_2escm"),(void*)f_28577},
{C_text("f_28694:library_2escm"),(void*)f_28694},
{C_text("f_28697:library_2escm"),(void*)f_28697},
{C_text("f_28700:library_2escm"),(void*)f_28700},
{C_text("f_28703:library_2escm"),(void*)f_28703},
{C_text("f_28708:library_2escm"),(void*)f_28708},
{C_text("f_28711:library_2escm"),(void*)f_28711},
{C_text("f_28714:library_2escm"),(void*)f_28714},
{C_text("f_28717:library_2escm"),(void*)f_28717},
{C_text("f_28720:library_2escm"),(void*)f_28720},
{C_text("f_28723:library_2escm"),(void*)f_28723},
{C_text("f_28726:library_2escm"),(void*)f_28726},
{C_text("f_28729:library_2escm"),(void*)f_28729},
{C_text("f_28732:library_2escm"),(void*)f_28732},
{C_text("f_28736:library_2escm"),(void*)f_28736},
{C_text("f_28738:library_2escm"),(void*)f_28738},
{C_text("f_28746:library_2escm"),(void*)f_28746},
{C_text("f_28748:library_2escm"),(void*)f_28748},
{C_text("f_28752:library_2escm"),(void*)f_28752},
{C_text("f_28754:library_2escm"),(void*)f_28754},
{C_text("f_28761:library_2escm"),(void*)f_28761},
{C_text("f_28771:library_2escm"),(void*)f_28771},
{C_text("f_28796:library_2escm"),(void*)f_28796},
{C_text("f_28799:library_2escm"),(void*)f_28799},
{C_text("f_28802:library_2escm"),(void*)f_28802},
{C_text("f_28805:library_2escm"),(void*)f_28805},
{C_text("f_28808:library_2escm"),(void*)f_28808},
{C_text("f_28818:library_2escm"),(void*)f_28818},
{C_text("f_28824:library_2escm"),(void*)f_28824},
{C_text("f_28828:library_2escm"),(void*)f_28828},
{C_text("f_28830:library_2escm"),(void*)f_28830},
{C_text("f_28840:library_2escm"),(void*)f_28840},
{C_text("f_28846:library_2escm"),(void*)f_28846},
{C_text("f_28850:library_2escm"),(void*)f_28850},
{C_text("f_28852:library_2escm"),(void*)f_28852},
{C_text("f_28857:library_2escm"),(void*)f_28857},
{C_text("f_28859:library_2escm"),(void*)f_28859},
{C_text("f_28862:library_2escm"),(void*)f_28862},
{C_text("f_28882:library_2escm"),(void*)f_28882},
{C_text("f_28888:library_2escm"),(void*)f_28888},
{C_text("f_28898:library_2escm"),(void*)f_28898},
{C_text("f_28908:library_2escm"),(void*)f_28908},
{C_text("f_28943:library_2escm"),(void*)f_28943},
{C_text("f_28947:library_2escm"),(void*)f_28947},
{C_text("f_28952:library_2escm"),(void*)f_28952},
{C_text("f_28962:library_2escm"),(void*)f_28962},
{C_text("f_28972:library_2escm"),(void*)f_28972},
{C_text("f_28981:library_2escm"),(void*)f_28981},
{C_text("f_28984:library_2escm"),(void*)f_28984},
{C_text("f_28987:library_2escm"),(void*)f_28987},
{C_text("f_28994:library_2escm"),(void*)f_28994},
{C_text("f_29001:library_2escm"),(void*)f_29001},
{C_text("f_29004:library_2escm"),(void*)f_29004},
{C_text("f_29008:library_2escm"),(void*)f_29008},
{C_text("f_29010:library_2escm"),(void*)f_29010},
{C_text("f_29013:library_2escm"),(void*)f_29013},
{C_text("f_29016:library_2escm"),(void*)f_29016},
{C_text("f_29019:library_2escm"),(void*)f_29019},
{C_text("f_29022:library_2escm"),(void*)f_29022},
{C_text("f_29025:library_2escm"),(void*)f_29025},
{C_text("f_29028:library_2escm"),(void*)f_29028},
{C_text("f_29031:library_2escm"),(void*)f_29031},
{C_text("f_29034:library_2escm"),(void*)f_29034},
{C_text("f_29037:library_2escm"),(void*)f_29037},
{C_text("f_29040:library_2escm"),(void*)f_29040},
{C_text("f_29044:library_2escm"),(void*)f_29044},
{C_text("f_29047:library_2escm"),(void*)f_29047},
{C_text("f_29063:library_2escm"),(void*)f_29063},
{C_text("f_29071:library_2escm"),(void*)f_29071},
{C_text("f_29074:library_2escm"),(void*)f_29074},
{C_text("f_29080:library_2escm"),(void*)f_29080},
{C_text("f_29089:library_2escm"),(void*)f_29089},
{C_text("f_29095:library_2escm"),(void*)f_29095},
{C_text("f_29104:library_2escm"),(void*)f_29104},
{C_text("f_29110:library_2escm"),(void*)f_29110},
{C_text("f_29116:library_2escm"),(void*)f_29116},
{C_text("f_29119:library_2escm"),(void*)f_29119},
{C_text("f_29125:library_2escm"),(void*)f_29125},
{C_text("f_29131:library_2escm"),(void*)f_29131},
{C_text("f_29134:library_2escm"),(void*)f_29134},
{C_text("f_29140:library_2escm"),(void*)f_29140},
{C_text("f_29179:library_2escm"),(void*)f_29179},
{C_text("f_29222:library_2escm"),(void*)f_29222},
{C_text("f_29229:library_2escm"),(void*)f_29229},
{C_text("f_29234:library_2escm"),(void*)f_29234},
{C_text("f_29250:library_2escm"),(void*)f_29250},
{C_text("f_29276:library_2escm"),(void*)f_29276},
{C_text("f_29279:library_2escm"),(void*)f_29279},
{C_text("f_29283:library_2escm"),(void*)f_29283},
{C_text("f_29286:library_2escm"),(void*)f_29286},
{C_text("f_29291:library_2escm"),(void*)f_29291},
{C_text("f_29293:library_2escm"),(void*)f_29293},
{C_text("f_29297:library_2escm"),(void*)f_29297},
{C_text("f_29324:library_2escm"),(void*)f_29324},
{C_text("f_29334:library_2escm"),(void*)f_29334},
{C_text("f_29343:library_2escm"),(void*)f_29343},
{C_text("f_29350:library_2escm"),(void*)f_29350},
{C_text("f_29354:library_2escm"),(void*)f_29354},
{C_text("f_29368:library_2escm"),(void*)f_29368},
{C_text("f_29372:library_2escm"),(void*)f_29372},
{C_text("f_29379:library_2escm"),(void*)f_29379},
{C_text("f_29381:library_2escm"),(void*)f_29381},
{C_text("f_29403:library_2escm"),(void*)f_29403},
{C_text("f_29410:library_2escm"),(void*)f_29410},
{C_text("f_29415:library_2escm"),(void*)f_29415},
{C_text("f_29419:library_2escm"),(void*)f_29419},
{C_text("f_29422:library_2escm"),(void*)f_29422},
{C_text("f_29425:library_2escm"),(void*)f_29425},
{C_text("f_29430:library_2escm"),(void*)f_29430},
{C_text("f_29434:library_2escm"),(void*)f_29434},
{C_text("f_29460:library_2escm"),(void*)f_29460},
{C_text("f_29473:library_2escm"),(void*)f_29473},
{C_text("f_29476:library_2escm"),(void*)f_29476},
{C_text("f_29485:library_2escm"),(void*)f_29485},
{C_text("f_29488:library_2escm"),(void*)f_29488},
{C_text("f_29491:library_2escm"),(void*)f_29491},
{C_text("f_29497:library_2escm"),(void*)f_29497},
{C_text("f_29504:library_2escm"),(void*)f_29504},
{C_text("f_29506:library_2escm"),(void*)f_29506},
{C_text("f_29519:library_2escm"),(void*)f_29519},
{C_text("f_29532:library_2escm"),(void*)f_29532},
{C_text("f_29535:library_2escm"),(void*)f_29535},
{C_text("f_29538:library_2escm"),(void*)f_29538},
{C_text("f_29545:library_2escm"),(void*)f_29545},
{C_text("f_29598:library_2escm"),(void*)f_29598},
{C_text("f_29601:library_2escm"),(void*)f_29601},
{C_text("f_29604:library_2escm"),(void*)f_29604},
{C_text("f_29606:library_2escm"),(void*)f_29606},
{C_text("f_29610:library_2escm"),(void*)f_29610},
{C_text("f_29614:library_2escm"),(void*)f_29614},
{C_text("f_29620:library_2escm"),(void*)f_29620},
{C_text("f_29625:library_2escm"),(void*)f_29625},
{C_text("f_29629:library_2escm"),(void*)f_29629},
{C_text("f_29641:library_2escm"),(void*)f_29641},
{C_text("f_29653:library_2escm"),(void*)f_29653},
{C_text("f_29660:library_2escm"),(void*)f_29660},
{C_text("f_29666:library_2escm"),(void*)f_29666},
{C_text("f_29680:library_2escm"),(void*)f_29680},
{C_text("f_29719:library_2escm"),(void*)f_29719},
{C_text("f_29738:library_2escm"),(void*)f_29738},
{C_text("f_29761:library_2escm"),(void*)f_29761},
{C_text("f_29770:library_2escm"),(void*)f_29770},
{C_text("f_29777:library_2escm"),(void*)f_29777},
{C_text("f_29794:library_2escm"),(void*)f_29794},
{C_text("f_29802:library_2escm"),(void*)f_29802},
{C_text("f_29813:library_2escm"),(void*)f_29813},
{C_text("f_29821:library_2escm"),(void*)f_29821},
{C_text("f_29828:library_2escm"),(void*)f_29828},
{C_text("f_29890:library_2escm"),(void*)f_29890},
{C_text("f_29897:library_2escm"),(void*)f_29897},
{C_text("f_29900:library_2escm"),(void*)f_29900},
{C_text("f_29910:library_2escm"),(void*)f_29910},
{C_text("f_29914:library_2escm"),(void*)f_29914},
{C_text("f_29918:library_2escm"),(void*)f_29918},
{C_text("f_29921:library_2escm"),(void*)f_29921},
{C_text("f_29929:library_2escm"),(void*)f_29929},
{C_text("f_29931:library_2escm"),(void*)f_29931},
{C_text("f_29940:library_2escm"),(void*)f_29940},
{C_text("f_29946:library_2escm"),(void*)f_29946},
{C_text("f_29957:library_2escm"),(void*)f_29957},
{C_text("f_29961:library_2escm"),(void*)f_29961},
{C_text("f_29963:library_2escm"),(void*)f_29963},
{C_text("f_29971:library_2escm"),(void*)f_29971},
{C_text("f_29983:library_2escm"),(void*)f_29983},
{C_text("f_29989:library_2escm"),(void*)f_29989},
{C_text("f_29993:library_2escm"),(void*)f_29993},
{C_text("f_30001:library_2escm"),(void*)f_30001},
{C_text("f_30019:library_2escm"),(void*)f_30019},
{C_text("f_30027:library_2escm"),(void*)f_30027},
{C_text("f_30031:library_2escm"),(void*)f_30031},
{C_text("f_30049:library_2escm"),(void*)f_30049},
{C_text("f_30056:library_2escm"),(void*)f_30056},
{C_text("f_30068:library_2escm"),(void*)f_30068},
{C_text("f_30076:library_2escm"),(void*)f_30076},
{C_text("f_30082:library_2escm"),(void*)f_30082},
{C_text("f_30104:library_2escm"),(void*)f_30104},
{C_text("f_30108:library_2escm"),(void*)f_30108},
{C_text("f_30112:library_2escm"),(void*)f_30112},
{C_text("f_30114:library_2escm"),(void*)f_30114},
{C_text("f_30117:library_2escm"),(void*)f_30117},
{C_text("f_30120:library_2escm"),(void*)f_30120},
{C_text("f_30124:library_2escm"),(void*)f_30124},
{C_text("f_30127:library_2escm"),(void*)f_30127},
{C_text("f_30149:library_2escm"),(void*)f_30149},
{C_text("f_30155:library_2escm"),(void*)f_30155},
{C_text("f_30159:library_2escm"),(void*)f_30159},
{C_text("f_30176:library_2escm"),(void*)f_30176},
{C_text("f_30186:library_2escm"),(void*)f_30186},
{C_text("f_30190:library_2escm"),(void*)f_30190},
{C_text("f_30194:library_2escm"),(void*)f_30194},
{C_text("f_30206:library_2escm"),(void*)f_30206},
{C_text("f_30216:library_2escm"),(void*)f_30216},
{C_text("f_30225:library_2escm"),(void*)f_30225},
{C_text("f_30241:library_2escm"),(void*)f_30241},
{C_text("f_30245:library_2escm"),(void*)f_30245},
{C_text("f_30247:library_2escm"),(void*)f_30247},
{C_text("f_30253:library_2escm"),(void*)f_30253},
{C_text("f_30260:library_2escm"),(void*)f_30260},
{C_text("f_30265:library_2escm"),(void*)f_30265},
{C_text("f_30286:library_2escm"),(void*)f_30286},
{C_text("f_30296:library_2escm"),(void*)f_30296},
{C_text("f_30306:library_2escm"),(void*)f_30306},
{C_text("f_30319:library_2escm"),(void*)f_30319},
{C_text("f_30323:library_2escm"),(void*)f_30323},
{C_text("f_30326:library_2escm"),(void*)f_30326},
{C_text("f_30334:library_2escm"),(void*)f_30334},
{C_text("f_30344:library_2escm"),(void*)f_30344},
{C_text("f_30366:library_2escm"),(void*)f_30366},
{C_text("f_30370:library_2escm"),(void*)f_30370},
{C_text("f_30401:library_2escm"),(void*)f_30401},
{C_text("f_30404:library_2escm"),(void*)f_30404},
{C_text("f_30407:library_2escm"),(void*)f_30407},
{C_text("f_30413:library_2escm"),(void*)f_30413},
{C_text("f_30426:library_2escm"),(void*)f_30426},
{C_text("f_30429:library_2escm"),(void*)f_30429},
{C_text("f_30438:library_2escm"),(void*)f_30438},
{C_text("f_30444:library_2escm"),(void*)f_30444},
{C_text("f_30450:library_2escm"),(void*)f_30450},
{C_text("f_30456:library_2escm"),(void*)f_30456},
{C_text("f_30462:library_2escm"),(void*)f_30462},
{C_text("f_30479:library_2escm"),(void*)f_30479},
{C_text("f_30485:library_2escm"),(void*)f_30485},
{C_text("f_30500:library_2escm"),(void*)f_30500},
{C_text("f_30504:library_2escm"),(void*)f_30504},
{C_text("f_30508:library_2escm"),(void*)f_30508},
{C_text("f_30512:library_2escm"),(void*)f_30512},
{C_text("f_30533:library_2escm"),(void*)f_30533},
{C_text("f_30535:library_2escm"),(void*)f_30535},
{C_text("f_30541:library_2escm"),(void*)f_30541},
{C_text("f_30545:library_2escm"),(void*)f_30545},
{C_text("f_30554:library_2escm"),(void*)f_30554},
{C_text("f_30563:library_2escm"),(void*)f_30563},
{C_text("f_30606:library_2escm"),(void*)f_30606},
{C_text("f_30628:library_2escm"),(void*)f_30628},
{C_text("f_30641:library_2escm"),(void*)f_30641},
{C_text("f_30666:library_2escm"),(void*)f_30666},
{C_text("f_30682:library_2escm"),(void*)f_30682},
{C_text("f_30698:library_2escm"),(void*)f_30698},
{C_text("f_30714:library_2escm"),(void*)f_30714},
{C_text("f_30730:library_2escm"),(void*)f_30730},
{C_text("f_30746:library_2escm"),(void*)f_30746},
{C_text("f_30762:library_2escm"),(void*)f_30762},
{C_text("f_30778:library_2escm"),(void*)f_30778},
{C_text("f_30794:library_2escm"),(void*)f_30794},
{C_text("f_30810:library_2escm"),(void*)f_30810},
{C_text("f_30817:library_2escm"),(void*)f_30817},
{C_text("f_30858:library_2escm"),(void*)f_30858},
{C_text("f_30870:library_2escm"),(void*)f_30870},
{C_text("f_30876:library_2escm"),(void*)f_30876},
{C_text("f_30895:library_2escm"),(void*)f_30895},
{C_text("f_30897:library_2escm"),(void*)f_30897},
{C_text("f_30920:library_2escm"),(void*)f_30920},
{C_text("f_30966:library_2escm"),(void*)f_30966},
{C_text("f_30968:library_2escm"),(void*)f_30968},
{C_text("f_30975:library_2escm"),(void*)f_30975},
{C_text("f_30987:library_2escm"),(void*)f_30987},
{C_text("f_31031:library_2escm"),(void*)f_31031},
{C_text("f_31046:library_2escm"),(void*)f_31046},
{C_text("f_31054:library_2escm"),(void*)f_31054},
{C_text("f_31060:library_2escm"),(void*)f_31060},
{C_text("f_31068:library_2escm"),(void*)f_31068},
{C_text("f_31072:library_2escm"),(void*)f_31072},
{C_text("f_31080:library_2escm"),(void*)f_31080},
{C_text("f_31082:library_2escm"),(void*)f_31082},
{C_text("f_31092:library_2escm"),(void*)f_31092},
{C_text("f_31099:library_2escm"),(void*)f_31099},
{C_text("f_31103:library_2escm"),(void*)f_31103},
{C_text("f_31114:library_2escm"),(void*)f_31114},
{C_text("f_31121:library_2escm"),(void*)f_31121},
{C_text("f_31125:library_2escm"),(void*)f_31125},
{C_text("f_31136:library_2escm"),(void*)f_31136},
{C_text("f_31143:library_2escm"),(void*)f_31143},
{C_text("f_31147:library_2escm"),(void*)f_31147},
{C_text("f_31152:library_2escm"),(void*)f_31152},
{C_text("f_31158:library_2escm"),(void*)f_31158},
{C_text("f_31161:library_2escm"),(void*)f_31161},
{C_text("f_31164:library_2escm"),(void*)f_31164},
{C_text("f_31170:library_2escm"),(void*)f_31170},
{C_text("f_31179:library_2escm"),(void*)f_31179},
{C_text("f_31188:library_2escm"),(void*)f_31188},
{C_text("f_31194:library_2escm"),(void*)f_31194},
{C_text("f_31197:library_2escm"),(void*)f_31197},
{C_text("f_31200:library_2escm"),(void*)f_31200},
{C_text("f_31212:library_2escm"),(void*)f_31212},
{C_text("f_31215:library_2escm"),(void*)f_31215},
{C_text("f_31218:library_2escm"),(void*)f_31218},
{C_text("f_31221:library_2escm"),(void*)f_31221},
{C_text("f_31233:library_2escm"),(void*)f_31233},
{C_text("f_31236:library_2escm"),(void*)f_31236},
{C_text("f_31239:library_2escm"),(void*)f_31239},
{C_text("f_31242:library_2escm"),(void*)f_31242},
{C_text("f_31251:library_2escm"),(void*)f_31251},
{C_text("f_31254:library_2escm"),(void*)f_31254},
{C_text("f_31267:library_2escm"),(void*)f_31267},
{C_text("f_31268:library_2escm"),(void*)f_31268},
{C_text("f_31273:library_2escm"),(void*)f_31273},
{C_text("f_31274:library_2escm"),(void*)f_31274},
{C_text("f_31279:library_2escm"),(void*)f_31279},
{C_text("f_31280:library_2escm"),(void*)f_31280},
{C_text("f_31285:library_2escm"),(void*)f_31285},
{C_text("f_31286:library_2escm"),(void*)f_31286},
{C_text("f_31291:library_2escm"),(void*)f_31291},
{C_text("f_31292:library_2escm"),(void*)f_31292},
{C_text("f_31297:library_2escm"),(void*)f_31297},
{C_text("f_31299:library_2escm"),(void*)f_31299},
{C_text("f_31309:library_2escm"),(void*)f_31309},
{C_text("f_31312:library_2escm"),(void*)f_31312},
{C_text("f_31315:library_2escm"),(void*)f_31315},
{C_text("f_31318:library_2escm"),(void*)f_31318},
{C_text("f_31320:library_2escm"),(void*)f_31320},
{C_text("f_31334:library_2escm"),(void*)f_31334},
{C_text("f_31342:library_2escm"),(void*)f_31342},
{C_text("f_31346:library_2escm"),(void*)f_31346},
{C_text("f_31350:library_2escm"),(void*)f_31350},
{C_text("f_31354:library_2escm"),(void*)f_31354},
{C_text("f_31360:library_2escm"),(void*)f_31360},
{C_text("f_31367:library_2escm"),(void*)f_31367},
{C_text("f_31371:library_2escm"),(void*)f_31371},
{C_text("f_31375:library_2escm"),(void*)f_31375},
{C_text("f_31379:library_2escm"),(void*)f_31379},
{C_text("f_31399:library_2escm"),(void*)f_31399},
{C_text("f_31418:library_2escm"),(void*)f_31418},
{C_text("f_31421:library_2escm"),(void*)f_31421},
{C_text("f_31424:library_2escm"),(void*)f_31424},
{C_text("f_31427:library_2escm"),(void*)f_31427},
{C_text("f_31436:library_2escm"),(void*)f_31436},
{C_text("f_31446:library_2escm"),(void*)f_31446},
{C_text("f_31468:library_2escm"),(void*)f_31468},
{C_text("f_31474:library_2escm"),(void*)f_31474},
{C_text("f_31494:library_2escm"),(void*)f_31494},
{C_text("f_31509:library_2escm"),(void*)f_31509},
{C_text("f_31513:library_2escm"),(void*)f_31513},
{C_text("f_31536:library_2escm"),(void*)f_31536},
{C_text("f_31540:library_2escm"),(void*)f_31540},
{C_text("f_31542:library_2escm"),(void*)f_31542},
{C_text("f_31572:library_2escm"),(void*)f_31572},
{C_text("f_31575:library_2escm"),(void*)f_31575},
{C_text("f_31577:library_2escm"),(void*)f_31577},
{C_text("f_31595:library_2escm"),(void*)f_31595},
{C_text("f_31602:library_2escm"),(void*)f_31602},
{C_text("f_31624:library_2escm"),(void*)f_31624},
{C_text("f_31629:library_2escm"),(void*)f_31629},
{C_text("f_31644:library_2escm"),(void*)f_31644},
{C_text("f_31647:library_2escm"),(void*)f_31647},
{C_text("f_31650:library_2escm"),(void*)f_31650},
{C_text("f_31653:library_2escm"),(void*)f_31653},
{C_text("f_31656:library_2escm"),(void*)f_31656},
{C_text("f_31659:library_2escm"),(void*)f_31659},
{C_text("f_31662:library_2escm"),(void*)f_31662},
{C_text("f_31665:library_2escm"),(void*)f_31665},
{C_text("f_31668:library_2escm"),(void*)f_31668},
{C_text("f_31671:library_2escm"),(void*)f_31671},
{C_text("f_31679:library_2escm"),(void*)f_31679},
{C_text("f_31682:library_2escm"),(void*)f_31682},
{C_text("f_31687:library_2escm"),(void*)f_31687},
{C_text("f_31693:library_2escm"),(void*)f_31693},
{C_text("f_31706:library_2escm"),(void*)f_31706},
{C_text("f_31708:library_2escm"),(void*)f_31708},
{C_text("f_31731:library_2escm"),(void*)f_31731},
{C_text("f_31738:library_2escm"),(void*)f_31738},
{C_text("f_31742:library_2escm"),(void*)f_31742},
{C_text("f_31744:library_2escm"),(void*)f_31744},
{C_text("f_31773:library_2escm"),(void*)f_31773},
{C_text("f_31775:library_2escm"),(void*)f_31775},
{C_text("f_31800:library_2escm"),(void*)f_31800},
{C_text("f_31809:library_2escm"),(void*)f_31809},
{C_text("f_31812:library_2escm"),(void*)f_31812},
{C_text("f_31818:library_2escm"),(void*)f_31818},
{C_text("f_31842:library_2escm"),(void*)f_31842},
{C_text("f_31849:library_2escm"),(void*)f_31849},
{C_text("f_31853:library_2escm"),(void*)f_31853},
{C_text("f_31865:library_2escm"),(void*)f_31865},
{C_text("f_31873:library_2escm"),(void*)f_31873},
{C_text("f_31877:library_2escm"),(void*)f_31877},
{C_text("f_31886:library_2escm"),(void*)f_31886},
{C_text("f_31895:library_2escm"),(void*)f_31895},
{C_text("f_31905:library_2escm"),(void*)f_31905},
{C_text("f_31913:library_2escm"),(void*)f_31913},
{C_text("f_31917:library_2escm"),(void*)f_31917},
{C_text("f_31921:library_2escm"),(void*)f_31921},
{C_text("f_31927:library_2escm"),(void*)f_31927},
{C_text("f_31931:library_2escm"),(void*)f_31931},
{C_text("f_31935:library_2escm"),(void*)f_31935},
{C_text("f_31957:library_2escm"),(void*)f_31957},
{C_text("f_31961:library_2escm"),(void*)f_31961},
{C_text("f_31965:library_2escm"),(void*)f_31965},
{C_text("f_31969:library_2escm"),(void*)f_31969},
{C_text("f_31973:library_2escm"),(void*)f_31973},
{C_text("f_31981:library_2escm"),(void*)f_31981},
{C_text("f_31989:library_2escm"),(void*)f_31989},
{C_text("f_32014:library_2escm"),(void*)f_32014},
{C_text("f_32031:library_2escm"),(void*)f_32031},
{C_text("f_32035:library_2escm"),(void*)f_32035},
{C_text("f_32038:library_2escm"),(void*)f_32038},
{C_text("f_32041:library_2escm"),(void*)f_32041},
{C_text("f_32051:library_2escm"),(void*)f_32051},
{C_text("f_32054:library_2escm"),(void*)f_32054},
{C_text("f_32056:library_2escm"),(void*)f_32056},
{C_text("f_32073:library_2escm"),(void*)f_32073},
{C_text("f_32100:library_2escm"),(void*)f_32100},
{C_text("f_32109:library_2escm"),(void*)f_32109},
{C_text("f_32129:library_2escm"),(void*)f_32129},
{C_text("f_32133:library_2escm"),(void*)f_32133},
{C_text("f_32137:library_2escm"),(void*)f_32137},
{C_text("f_32141:library_2escm"),(void*)f_32141},
{C_text("f_32145:library_2escm"),(void*)f_32145},
{C_text("f_32149:library_2escm"),(void*)f_32149},
{C_text("f_32153:library_2escm"),(void*)f_32153},
{C_text("f_32155:library_2escm"),(void*)f_32155},
{C_text("f_32164:library_2escm"),(void*)f_32164},
{C_text("f_32174:library_2escm"),(void*)f_32174},
{C_text("f_32199:library_2escm"),(void*)f_32199},
{C_text("f_32202:library_2escm"),(void*)f_32202},
{C_text("f_32204:library_2escm"),(void*)f_32204},
{C_text("f_32220:library_2escm"),(void*)f_32220},
{C_text("f_32258:library_2escm"),(void*)f_32258},
{C_text("f_32282:library_2escm"),(void*)f_32282},
{C_text("f_32286:library_2escm"),(void*)f_32286},
{C_text("f_32288:library_2escm"),(void*)f_32288},
{C_text("f_32292:library_2escm"),(void*)f_32292},
{C_text("f_32295:library_2escm"),(void*)f_32295},
{C_text("f_32308:library_2escm"),(void*)f_32308},
{C_text("f_32313:library_2escm"),(void*)f_32313},
{C_text("f_32319:library_2escm"),(void*)f_32319},
{C_text("f_32323:library_2escm"),(void*)f_32323},
{C_text("f_32332:library_2escm"),(void*)f_32332},
{C_text("f_32335:library_2escm"),(void*)f_32335},
{C_text("f_32338:library_2escm"),(void*)f_32338},
{C_text("f_32341:library_2escm"),(void*)f_32341},
{C_text("f_32344:library_2escm"),(void*)f_32344},
{C_text("f_32346:library_2escm"),(void*)f_32346},
{C_text("f_32356:library_2escm"),(void*)f_32356},
{C_text("f_32368:library_2escm"),(void*)f_32368},
{C_text("f_32376:library_2escm"),(void*)f_32376},
{C_text("f_32386:library_2escm"),(void*)f_32386},
{C_text("f_32402:library_2escm"),(void*)f_32402},
{C_text("f_32408:library_2escm"),(void*)f_32408},
{C_text("f_32411:library_2escm"),(void*)f_32411},
{C_text("f_32414:library_2escm"),(void*)f_32414},
{C_text("f_32415:library_2escm"),(void*)f_32415},
{C_text("f_32419:library_2escm"),(void*)f_32419},
{C_text("f_32425:library_2escm"),(void*)f_32425},
{C_text("f_32429:library_2escm"),(void*)f_32429},
{C_text("f_32431:library_2escm"),(void*)f_32431},
{C_text("f_32441:library_2escm"),(void*)f_32441},
{C_text("f_32458:library_2escm"),(void*)f_32458},
{C_text("f_32461:library_2escm"),(void*)f_32461},
{C_text("f_32465:library_2escm"),(void*)f_32465},
{C_text("f_32470:library_2escm"),(void*)f_32470},
{C_text("f_32476:library_2escm"),(void*)f_32476},
{C_text("f_32483:library_2escm"),(void*)f_32483},
{C_text("f_32492:library_2escm"),(void*)f_32492},
{C_text("f_32500:library_2escm"),(void*)f_32500},
{C_text("f_32525:library_2escm"),(void*)f_32525},
{C_text("f_32543:library_2escm"),(void*)f_32543},
{C_text("f_32547:library_2escm"),(void*)f_32547},
{C_text("f_32562:library_2escm"),(void*)f_32562},
{C_text("f_32566:library_2escm"),(void*)f_32566},
{C_text("f_32581:library_2escm"),(void*)f_32581},
{C_text("f_32584:library_2escm"),(void*)f_32584},
{C_text("f_32587:library_2escm"),(void*)f_32587},
{C_text("f_32597:library_2escm"),(void*)f_32597},
{C_text("f_32628:library_2escm"),(void*)f_32628},
{C_text("f_32652:library_2escm"),(void*)f_32652},
{C_text("f_32662:library_2escm"),(void*)f_32662},
{C_text("f_32671:library_2escm"),(void*)f_32671},
{C_text("f_32712:library_2escm"),(void*)f_32712},
{C_text("f_32731:library_2escm"),(void*)f_32731},
{C_text("f_32740:library_2escm"),(void*)f_32740},
{C_text("f_32744:library_2escm"),(void*)f_32744},
{C_text("f_32749:library_2escm"),(void*)f_32749},
{C_text("f_32759:library_2escm"),(void*)f_32759},
{C_text("f_32769:library_2escm"),(void*)f_32769},
{C_text("f_32779:library_2escm"),(void*)f_32779},
{C_text("f_32789:library_2escm"),(void*)f_32789},
{C_text("f_32799:library_2escm"),(void*)f_32799},
{C_text("f_32809:library_2escm"),(void*)f_32809},
{C_text("f_32819:library_2escm"),(void*)f_32819},
{C_text("f_32829:library_2escm"),(void*)f_32829},
{C_text("f_32839:library_2escm"),(void*)f_32839},
{C_text("f_32849:library_2escm"),(void*)f_32849},
{C_text("f_32859:library_2escm"),(void*)f_32859},
{C_text("f_32869:library_2escm"),(void*)f_32869},
{C_text("f_32879:library_2escm"),(void*)f_32879},
{C_text("f_32895:library_2escm"),(void*)f_32895},
{C_text("f_32903:library_2escm"),(void*)f_32903},
{C_text("f_32919:library_2escm"),(void*)f_32919},
{C_text("f_32935:library_2escm"),(void*)f_32935},
{C_text("f_32945:library_2escm"),(void*)f_32945},
{C_text("f_32955:library_2escm"),(void*)f_32955},
{C_text("f_32974:library_2escm"),(void*)f_32974},
{C_text("f_32990:library_2escm"),(void*)f_32990},
{C_text("f_33003:library_2escm"),(void*)f_33003},
{C_text("f_33009:library_2escm"),(void*)f_33009},
{C_text("f_33019:library_2escm"),(void*)f_33019},
{C_text("f_33035:library_2escm"),(void*)f_33035},
{C_text("f_33039:library_2escm"),(void*)f_33039},
{C_text("f_33042:library_2escm"),(void*)f_33042},
{C_text("f_33048:library_2escm"),(void*)f_33048},
{C_text("f_33058:library_2escm"),(void*)f_33058},
{C_text("f_33074:library_2escm"),(void*)f_33074},
{C_text("f_33078:library_2escm"),(void*)f_33078},
{C_text("f_33081:library_2escm"),(void*)f_33081},
{C_text("f_33084:library_2escm"),(void*)f_33084},
{C_text("f_33087:library_2escm"),(void*)f_33087},
{C_text("f_33093:library_2escm"),(void*)f_33093},
{C_text("f_33096:library_2escm"),(void*)f_33096},
{C_text("f_33099:library_2escm"),(void*)f_33099},
{C_text("f_33109:library_2escm"),(void*)f_33109},
{C_text("f_33125:library_2escm"),(void*)f_33125},
{C_text("f_33136:library_2escm"),(void*)f_33136},
{C_text("f_33159:library_2escm"),(void*)f_33159},
{C_text("f_33163:library_2escm"),(void*)f_33163},
{C_text("f_33197:library_2escm"),(void*)f_33197},
{C_text("f_33201:library_2escm"),(void*)f_33201},
{C_text("f_33204:library_2escm"),(void*)f_33204},
{C_text("f_33217:library_2escm"),(void*)f_33217},
{C_text("f_33250:library_2escm"),(void*)f_33250},
{C_text("f_33265:library_2escm"),(void*)f_33265},
{C_text("f_33269:library_2escm"),(void*)f_33269},
{C_text("f_33282:library_2escm"),(void*)f_33282},
{C_text("f_33296:library_2escm"),(void*)f_33296},
{C_text("f_33304:library_2escm"),(void*)f_33304},
{C_text("f_33308:library_2escm"),(void*)f_33308},
{C_text("f_33319:library_2escm"),(void*)f_33319},
{C_text("f_33323:library_2escm"),(void*)f_33323},
{C_text("f_33337:library_2escm"),(void*)f_33337},
{C_text("f_33369:library_2escm"),(void*)f_33369},
{C_text("f_8836:library_2escm"),(void*)f_8836},
{C_text("f_8838:library_2escm"),(void*)f_8838},
{C_text("f_8841:library_2escm"),(void*)f_8841},
{C_text("f_8844:library_2escm"),(void*)f_8844},
{C_text("f_8847:library_2escm"),(void*)f_8847},
{C_text("f_8850:library_2escm"),(void*)f_8850},
{C_text("f_8853:library_2escm"),(void*)f_8853},
{C_text("f_8856:library_2escm"),(void*)f_8856},
{C_text("f_8859:library_2escm"),(void*)f_8859},
{C_text("f_8862:library_2escm"),(void*)f_8862},
{C_text("f_8865:library_2escm"),(void*)f_8865},
{C_text("f_8868:library_2escm"),(void*)f_8868},
{C_text("f_8871:library_2escm"),(void*)f_8871},
{C_text("f_8874:library_2escm"),(void*)f_8874},
{C_text("f_8877:library_2escm"),(void*)f_8877},
{C_text("f_8880:library_2escm"),(void*)f_8880},
{C_text("f_8883:library_2escm"),(void*)f_8883},
{C_text("f_8886:library_2escm"),(void*)f_8886},
{C_text("f_8889:library_2escm"),(void*)f_8889},
{C_text("f_8892:library_2escm"),(void*)f_8892},
{C_text("f_8906:library_2escm"),(void*)f_8906},
{C_text("f_8913:library_2escm"),(void*)f_8913},
{C_text("f_8920:library_2escm"),(void*)f_8920},
{C_text("f_8934:library_2escm"),(void*)f_8934},
{C_text("f_8941:library_2escm"),(void*)f_8941},
{C_text("f_8955:library_2escm"),(void*)f_8955},
{C_text("f_8969:library_2escm"),(void*)f_8969},
{C_text("f_8987:library_2escm"),(void*)f_8987},
{C_text("f_8998:library_2escm"),(void*)f_8998},
{C_text("f_9009:library_2escm"),(void*)f_9009},
{C_text("f_9016:library_2escm"),(void*)f_9016},
{C_text("f_9027:library_2escm"),(void*)f_9027},
{C_text("f_9031:library_2escm"),(void*)f_9031},
{C_text("f_9038:library_2escm"),(void*)f_9038},
{C_text("f_9056:library_2escm"),(void*)f_9056},
{C_text("f_9067:library_2escm"),(void*)f_9067},
{C_text("f_9078:library_2escm"),(void*)f_9078},
{C_text("f_9085:library_2escm"),(void*)f_9085},
{C_text("f_9103:library_2escm"),(void*)f_9103},
{C_text("f_9114:library_2escm"),(void*)f_9114},
{C_text("f_9132:library_2escm"),(void*)f_9132},
{C_text("f_9138:library_2escm"),(void*)f_9138},
{C_text("f_9141:library_2escm"),(void*)f_9141},
{C_text("f_9144:library_2escm"),(void*)f_9144},
{C_text("f_9147:library_2escm"),(void*)f_9147},
{C_text("f_9150:library_2escm"),(void*)f_9150},
{C_text("f_9156:library_2escm"),(void*)f_9156},
{C_text("f_9189:library_2escm"),(void*)f_9189},
{C_text("f_9192:library_2escm"),(void*)f_9192},
{C_text("f_9195:library_2escm"),(void*)f_9195},
{C_text("f_9198:library_2escm"),(void*)f_9198},
{C_text("f_9201:library_2escm"),(void*)f_9201},
{C_text("f_9204:library_2escm"),(void*)f_9204},
{C_text("f_9207:library_2escm"),(void*)f_9207},
{C_text("f_9210:library_2escm"),(void*)f_9210},
{C_text("f_9213:library_2escm"),(void*)f_9213},
{C_text("f_9216:library_2escm"),(void*)f_9216},
{C_text("f_9219:library_2escm"),(void*)f_9219},
{C_text("f_9222:library_2escm"),(void*)f_9222},
{C_text("f_9225:library_2escm"),(void*)f_9225},
{C_text("f_9229:library_2escm"),(void*)f_9229},
{C_text("f_9232:library_2escm"),(void*)f_9232},
{C_text("f_9238:library_2escm"),(void*)f_9238},
{C_text("f_9241:library_2escm"),(void*)f_9241},
{C_text("f_9244:library_2escm"),(void*)f_9244},
{C_text("f_9247:library_2escm"),(void*)f_9247},
{C_text("f_9250:library_2escm"),(void*)f_9250},
{C_text("f_9258:library_2escm"),(void*)f_9258},
{C_text("f_9262:library_2escm"),(void*)f_9262},
{C_text("f_9265:library_2escm"),(void*)f_9265},
{C_text("f_9268:library_2escm"),(void*)f_9268},
{C_text("f_9271:library_2escm"),(void*)f_9271},
{C_text("f_9274:library_2escm"),(void*)f_9274},
{C_text("f_9277:library_2escm"),(void*)f_9277},
{C_text("f_9280:library_2escm"),(void*)f_9280},
{C_text("f_9283:library_2escm"),(void*)f_9283},
{C_text("f_9287:library_2escm"),(void*)f_9287},
{C_text("f_9290:library_2escm"),(void*)f_9290},
{C_text("f_9293:library_2escm"),(void*)f_9293},
{C_text("f_9296:library_2escm"),(void*)f_9296},
{C_text("f_9299:library_2escm"),(void*)f_9299},
{C_text("f_9307:library_2escm"),(void*)f_9307},
{C_text("f_9310:library_2escm"),(void*)f_9310},
{C_text("f_9317:library_2escm"),(void*)f_9317},
{C_text("f_9321:library_2escm"),(void*)f_9321},
{C_text("f_9324:library_2escm"),(void*)f_9324},
{C_text("f_9327:library_2escm"),(void*)f_9327},
{C_text("f_9330:library_2escm"),(void*)f_9330},
{C_text("f_9333:library_2escm"),(void*)f_9333},
{C_text("f_9336:library_2escm"),(void*)f_9336},
{C_text("f_9339:library_2escm"),(void*)f_9339},
{C_text("f_9345:library_2escm"),(void*)f_9345},
{C_text("f_9356:library_2escm"),(void*)f_9356},
{C_text("f_9362:library_2escm"),(void*)f_9362},
{C_text("f_9368:library_2escm"),(void*)f_9368},
{C_text("f_9374:library_2escm"),(void*)f_9374},
{C_text("f_9380:library_2escm"),(void*)f_9380},
{C_text("f_9386:library_2escm"),(void*)f_9386},
{C_text("f_9393:library_2escm"),(void*)f_9393},
{C_text("f_9399:library_2escm"),(void*)f_9399},
{C_text("f_9415:library_2escm"),(void*)f_9415},
{C_text("f_9426:library_2escm"),(void*)f_9426},
{C_text("f_9432:library_2escm"),(void*)f_9432},
{C_text("f_9438:library_2escm"),(void*)f_9438},
{C_text("f_9444:library_2escm"),(void*)f_9444},
{C_text("f_9450:library_2escm"),(void*)f_9450},
{C_text("f_9459:library_2escm"),(void*)f_9459},
{C_text("f_9462:library_2escm"),(void*)f_9462},
{C_text("f_9465:library_2escm"),(void*)f_9465},
{C_text("f_9468:library_2escm"),(void*)f_9468},
{C_text("f_9471:library_2escm"),(void*)f_9471},
{C_text("f_9474:library_2escm"),(void*)f_9474},
{C_text("f_9478:library_2escm"),(void*)f_9478},
{C_text("f_9484:library_2escm"),(void*)f_9484},
{C_text("f_9490:library_2escm"),(void*)f_9490},
{C_text("f_9525:library_2escm"),(void*)f_9525},
{C_text("f_9528:library_2escm"),(void*)f_9528},
{C_text("f_9531:library_2escm"),(void*)f_9531},
{C_text("f_9539:library_2escm"),(void*)f_9539},
{C_text("f_9545:library_2escm"),(void*)f_9545},
{C_text("f_9552:library_2escm"),(void*)f_9552},
{C_text("f_9567:library_2escm"),(void*)f_9567},
{C_text("f_9590:library_2escm"),(void*)f_9590},
{C_text("f_9596:library_2escm"),(void*)f_9596},
{C_text("f_9602:library_2escm"),(void*)f_9602},
{C_text("f_9609:library_2escm"),(void*)f_9609},
{C_text("f_9614:library_2escm"),(void*)f_9614},
{C_text("f_9617:library_2escm"),(void*)f_9617},
{C_text("f_9626:library_2escm"),(void*)f_9626},
{C_text("f_9644:library_2escm"),(void*)f_9644},
{C_text("f_9654:library_2escm"),(void*)f_9654},
{C_text("f_9663:library_2escm"),(void*)f_9663},
{C_text("f_9681:library_2escm"),(void*)f_9681},
{C_text("f_9694:library_2escm"),(void*)f_9694},
{C_text("f_9701:library_2escm"),(void*)f_9701},
{C_text("f_9708:library_2escm"),(void*)f_9708},
{C_text("f_9719:library_2escm"),(void*)f_9719},
{C_text("f_9726:library_2escm"),(void*)f_9726},
{C_text("f_9738:library_2escm"),(void*)f_9738},
{C_text("f_9741:library_2escm"),(void*)f_9741},
{C_text("f_9743:library_2escm"),(void*)f_9743},
{C_text("f_9749:library_2escm"),(void*)f_9749},
{C_text("f_9765:library_2escm"),(void*)f_9765},
{C_text("f_9774:library_2escm"),(void*)f_9774},
{C_text("f_9776:library_2escm"),(void*)f_9776},
{C_text("f_9782:library_2escm"),(void*)f_9782},
{C_text("f_9795:library_2escm"),(void*)f_9795},
{C_text("f_9811:library_2escm"),(void*)f_9811},
{C_text("f_9822:library_2escm"),(void*)f_9822},
{C_text("f_9824:library_2escm"),(void*)f_9824},
{C_text("f_9832:library_2escm"),(void*)f_9832},
{C_text("f_9834:library_2escm"),(void*)f_9834},
{C_text("f_9840:library_2escm"),(void*)f_9840},
{C_text("f_9842:library_2escm"),(void*)f_9842},
{C_text("f_9850:library_2escm"),(void*)f_9850},
{C_text("f_9852:library_2escm"),(void*)f_9852},
{C_text("f_9855:library_2escm"),(void*)f_9855},
{C_text("f_9863:library_2escm"),(void*)f_9863},
{C_text("f_9869:library_2escm"),(void*)f_9869},
{C_text("f_9877:library_2escm"),(void*)f_9877},
{C_text("f_9888:library_2escm"),(void*)f_9888},
{C_text("f_9900:library_2escm"),(void*)f_9900},
{C_text("f_9914:library_2escm"),(void*)f_9914},
{C_text("f_9922:library_2escm"),(void*)f_9922},
{C_text("f_9925:library_2escm"),(void*)f_9925},
{C_text("f_9927:library_2escm"),(void*)f_9927},
{C_text("f_9929:library_2escm"),(void*)f_9929},
{C_text("f_9935:library_2escm"),(void*)f_9935},
{C_text("f_9954:library_2escm"),(void*)f_9954},
{C_text("f_9971:library_2escm"),(void*)f_9971},
{C_text("f_9979:library_2escm"),(void*)f_9979},
{C_text("f_9993:library_2escm"),(void*)f_9993},
{C_text("f_9999:library_2escm"),(void*)f_9999},
{C_text("toplevel:library_2escm"),(void*)C_library_toplevel},
{NULL,NULL}};
#endif

static C_PTABLE_ENTRY *create_ptable(void){
#ifdef C_ENABLE_PTABLES
return ptable;
#else
return NULL;
#endif
}

/*
o|hiding unexported module binding: scheme#string-fill 
o|hiding unexported module binding: chicken.condition#prop-list->kind-prefixed-prop-list 
o|hiding unexported module binding: chicken.gc#finalizer-tag 
o|hiding unexported module binding: chicken.gc#finalizer? 
o|hiding unexported module binding: chicken.platform#path-list-separator 
o|hiding unexported module binding: chicken.platform#chop-separator 
o|hiding unexported module binding: chicken.platform#->feature-id 
S|applied compiler syntax:
S|  scheme#for-each		11
S|  ##sys#map		1
S|  ##sys#for-each		4
S|  scheme#map		8
o|eliminated procedure checks: 554 
o|folded constant expression: (scheme#char->integer (quote #\0)) 
o|folded constant expression: (scheme#char->integer (quote #\a)) 
o|folded constant expression: (scheme#char->integer (quote #\A)) 
o|folded constant expression: (scheme#integer->char (quote 11)) 
o|folded constant expression: (scheme#integer->char (quote 127)) 
o|folded constant expression: (scheme#integer->char (quote 27)) 
o|folded constant expression: (scheme#integer->char (quote 27)) 
o|folded constant expression: (scheme#integer->char (quote 7)) 
o|folded constant expression: (scheme#integer->char (quote 0)) 
o|folded constant expression: (scheme#integer->char (quote 0)) 
o|folded constant expression: (scheme#integer->char (quote 12)) 
o|folded constant expression: (scheme#integer->char (quote 8)) 
o|folded constant expression: (scheme#integer->char (quote 7)) 
o|folded constant expression: (scheme#integer->char (quote 11)) 
o|folded constant expression: (scheme#integer->char (quote 12)) 
o|folded constant expression: (scheme#expt (quote 1024) (quote 3)) 
o|folded constant expression: (scheme#expt (quote 1024) (quote 3)) 
o|folded constant expression: (scheme#expt (quote 1024) (quote 2)) 
o|folded constant expression: (scheme#expt (quote 1024) (quote 2)) 
o|specializations:
o|  1 (scheme#memq * list)
o|  1 (scheme#zero? integer)
o|  2 (scheme#number->string fixnum)
o|  2 (scheme#string-append string string)
o|  1 (scheme#cdar (pair pair *))
o|  2 (scheme#cddr (pair * pair))
o|  1 (scheme#char>? char char)
o|  1 (scheme#string=? string string)
o|  13 (scheme#char=? char char)
o|  4 (scheme#string-ref string fixnum)
o|  5 (##sys#check-input-port * * *)
o|  11 (##sys#check-output-port * * *)
o|  1 (##sys#check-output-port * *)
o|  1 (##sys#check-input-port * *)
o|  15 (##sys#check-list (or pair list) *)
o|  1 (scheme#zero? number)
o|  43 (scheme#cdr pair)
o|  4 (scheme#char>=? char char)
o|  6 (scheme#char<=? char char)
o|  5 (scheme#zero? *)
o|  24 (scheme#eqv? (or eof null fixnum char boolean symbol keyword) *)
o|  2 (scheme#> fixnum fixnum)
o|  1 (scheme#make-string fixnum char)
o|  1 (scheme#string-length string)
o|  6 (scheme#number->string * *)
o|  3 (scheme#integer? *)
o|  2 (scheme#even? *)
o|  5 (scheme#/ * *)
o|  1 (scheme#+ integer integer)
o|  1 (scheme#- integer integer)
o|  5 (chicken.bitwise#integer-length *)
o|  208 (scheme#eqv? * (or eof null fixnum char boolean symbol keyword))
o|  2 (chicken.flonum#fp<= float float)
o|  7 (scheme#- *)
o|  1 (scheme#odd? *)
o|  1 (chicken.flonum#fp> float float)
o|  2 (scheme#angle cplxnum)
o|  5 (chicken.base#finite? *)
o|  13 (chicken.base#exact-integer? *)
o|  8 (scheme#abs *)
o|  17 (scheme#exact->inexact number)
o|  5 (##sys#debug-mode?)
o|  49 (scheme#car pair)
o|  4 (scheme#length list)
o|  12 (scheme#negative? *)
o|  4 (scheme#positive? *)
(o e)|safe calls: 3341 
(o e)|dropped branches: 3 
(o e)|assignments to immediate values: 28 
o|dropping redundant toplevel assignment: chicken.base#warning 
o|dropping redundant toplevel assignment: chicken.base#notice 
o|dropping redundant toplevel assignment: chicken.base#enable-warnings 
o|dropping redundant toplevel assignment: scheme#force 
o|dropping redundant toplevel assignment: scheme#append 
o|dropping redundant toplevel assignment: scheme#make-string 
o|dropping redundant toplevel assignment: scheme#string->list 
o|dropping redundant toplevel assignment: scheme#list->string 
o|dropping redundant toplevel assignment: scheme#string-fill! 
o|dropping redundant toplevel assignment: scheme#string-copy 
o|dropping redundant toplevel assignment: scheme#substring 
o|dropping redundant toplevel assignment: scheme#string<? 
o|dropping redundant toplevel assignment: scheme#string>? 
o|dropping redundant toplevel assignment: scheme#string<=? 
o|dropping redundant toplevel assignment: scheme#string>=? 
o|dropping redundant toplevel assignment: scheme#string-ci<? 
o|dropping redundant toplevel assignment: scheme#string-ci>? 
o|dropping redundant toplevel assignment: scheme#string-ci<=? 
o|dropping redundant toplevel assignment: scheme#string-ci>=? 
o|dropping redundant toplevel assignment: scheme#string-append 
o|dropping redundant toplevel assignment: scheme#string 
o|dropping redundant toplevel assignment: chicken.base#chop 
o|dropping redundant toplevel assignment: scheme#make-rectangular 
o|dropping redundant toplevel assignment: scheme#make-polar 
o|dropping redundant toplevel assignment: scheme#real-part 
o|dropping redundant toplevel assignment: scheme#imag-part 
o|dropping redundant toplevel assignment: scheme#angle 
o|dropping redundant toplevel assignment: scheme#magnitude 
o|dropping redundant toplevel assignment: scheme#numerator 
o|dropping redundant toplevel assignment: scheme#denominator 
o|dropping redundant toplevel assignment: scheme#inexact->exact 
o|dropping redundant toplevel assignment: scheme#/ 
o|dropping redundant toplevel assignment: scheme#floor 
o|dropping redundant toplevel assignment: scheme#ceiling 
o|dropping redundant toplevel assignment: scheme#truncate 
o|dropping redundant toplevel assignment: scheme#round 
o|dropping redundant toplevel assignment: scheme#rationalize 
o|dropping redundant toplevel assignment: scheme#max 
o|dropping redundant toplevel assignment: scheme#min 
o|dropping redundant toplevel assignment: scheme#exp 
o|dropping redundant toplevel assignment: scheme#log 
o|dropping redundant toplevel assignment: scheme#sin 
o|dropping redundant toplevel assignment: scheme#cos 
o|dropping redundant toplevel assignment: scheme#tan 
o|dropping redundant toplevel assignment: scheme#asin 
o|dropping redundant toplevel assignment: scheme#acos 
o|dropping redundant toplevel assignment: scheme#atan 
o|dropping redundant toplevel assignment: chicken.base#exact-integer-sqrt 
o|dropping redundant toplevel assignment: scheme#sqrt 
o|dropping redundant toplevel assignment: chicken.base#exact-integer-nth-root 
o|dropping redundant toplevel assignment: scheme#expt 
o|dropping redundant toplevel assignment: scheme#gcd 
o|dropping redundant toplevel assignment: scheme#lcm 
o|dropping redundant toplevel assignment: scheme#string->number 
o|dropping redundant toplevel assignment: ##sys#number->string 
o|dropping redundant toplevel assignment: chicken.base#equal=? 
o|dropping redundant toplevel assignment: scheme#symbol->string 
o|dropping redundant toplevel assignment: scheme#string->symbol 
o|dropping redundant toplevel assignment: chicken.base#string->uninterned-symbol 
o|dropping redundant toplevel assignment: chicken.base#gensym 
o|dropping redundant toplevel assignment: chicken.base#symbol-append 
o|dropping redundant toplevel assignment: ##sys#update-errno 
o|dropping redundant toplevel assignment: ##sys#errno 
o|safe globals: (chicken.keyword#keyword->string chicken.keyword#string->keyword chicken.keyword#keyword? chicken.base#symbol-append chicken.base#gensym chicken.base#string->uninterned-symbol scheme#string->symbol scheme#symbol->string ##sys#symbol->string ##sys#string->symbol ##sys#interned-symbol? ##sys#intern-keyword ##sys#intern-symbol ##sys#snafu chicken.base#equal=? ##sys#number->string ##sys#integer->string ##sys#flonum->string ##sys#fixnum->string ##sys#string->number scheme#string->number ##sys#string->compnum round-quotient ldexp mantexp->dbl ##sys#extended-number->string ##sys#integer->string/recursive scheme#lcm ##sys#lcm scheme#gcd ##sys#gcd ##sys#internal-gcd scheme#expt ##sys#integer-power ##sys#exact-integer-nth-root/loc chicken.base#exact-integer-nth-root scheme#sqrt ##sys#sqrt/loc chicken.base#exact-integer-sqrt ##sys#exact-integer-sqrt scheme#atan scheme#acos scheme#asin scheme#tan scheme#cos scheme#sin scheme#log ##sys#log-1 scheme#exp scheme#min scheme#max scheme#rationalize find-ratio find-ratio-between scheme#round scheme#truncate scheme#ceiling scheme#floor ##sys#/-2 scheme#/ chicken.bitwise#arithmetic-shift chicken.bitwise#integer-length chicken.bitwise#bit->boolean chicken.bitwise#bitwise-not chicken.bitwise#bitwise-xor chicken.bitwise#bitwise-ior chicken.bitwise#bitwise-and ##sys#inexact->exact ##sys#exact->inexact scheme#inexact->exact flonum->ratnum ##sys#extended-signum scheme#denominator scheme#numerator ratnum scheme#magnitude scheme#angle scheme#imag-part scheme#real-part scheme#make-polar scheme#make-rectangular make-complex ##sys#inexact? ##sys#exact? ##sys#integer? ##sys#number? chicken.flonum#flonum-print-precision chicken.flonum#fpinteger? chicken.flonum#fpabs chicken.flonum#fpsqrt chicken.flonum#fplog chicken.flonum#fpexpt chicken.flonum#fpexp chicken.flonum#fpatanh chicken.flonum#fpacosh chicken.flonum#fpasinh chicken.flonum#fptanh chicken.flonum#fpcosh chicken.flonum#fpsinh chicken.flonum#fpatan2 chicken.flonum#fpatan chicken.flonum#fpacos chicken.flonum#fpasin chicken.flonum#fptan chicken.flonum#fpcos chicken.flonum#fpsin chicken.flonum#fpceiling chicken.flonum#fpround chicken.flonum#fptruncate chicken.flonum#fpfloor chicken.flonum#fpmin chicken.flonum#fpmax chicken.flonum#fpneg chicken.flonum#fp<= chicken.flonum#fp>= chicken.flonum#fp< chicken.flonum#fp> chicken.flonum#fp= chicken.flonum#fp/? chicken.flonum#fpgcd chicken.flonum#fp*+ chicken.flonum#fp/ chicken.flonum#fp* chicken.flonum#fp- chicken.flonum#fp+ chicken.flonum#flonum-minimum-decimal-exponent chicken.flonum#flonum-maximum-decimal-exponent chicken.flonum#flonum-minimum-exponent chicken.flonum#flonum-maximum-exponent chicken.flonum#flonum-decimal-precision chicken.flonum#flonum-precision chicken.flonum#flonum-epsilon chicken.flonum#flonum-radix chicken.flonum#minimum-flonum chicken.flonum#maximum-flonum chicken.base#chop ##sys#fragments->string scheme#string scheme#string-append ##sys#string-append scheme#string-ci>=? scheme#string-ci<=? scheme#string-ci>? scheme#string-ci<? scheme#string>=? scheme#string<=? scheme#string>? scheme#string<? ##sys#substring scheme#substring scheme#string-copy scheme#string-fill! ##sys#reverse-list->string ##sys#list->string scheme#list->string ##sys#string->list scheme#string->list scheme#make-string ##sys#make-string ##sys#fast-reverse scheme#append ##sys#error-bad-base ##sys#error-bad-real ##sys#error-bad-inexact ##sys#error-bad-exact-uinteger ##sys#error-bad-exact-integer ##sys#error-bad-integer ##sys#error-bad-number ##sys#error-not-a-proper-list ##sys#set-dlopen-flags! ##sys#dload scheme#force ##sys#check-closure ##sys#check-special ##sys#check-range ##sys#check-real ##sys#check-exact-uinteger ##sys#check-exact-integer ##sys#check-integer ##sys#check-locative ##sys#check-boolean ##sys#check-char ##sys#check-vector ##sys#check-keyword ##sys#check-symbol ##sys#check-inexact ##sys#check-exact ##sys#check-fixnum ##sys#check-number ##sys#check-string ##sys#check-list ##sys#check-pair ##sys#check-byte-vector ##sys#check-blob ##sys#check-structure chicken.time#cpu-time chicken.time#current-seconds chicken.time#current-process-milliseconds chicken.time#current-milliseconds ##sys#block-set! ##sys#copy-closure ##sys#apply-values ##sys#block-ref ##sys#become! ##sys#halt ##sys#undefined-value ##sys#void ##sys#setbyte ##sys#byte ##sys#message ##sys#immediate? ##sys#stop-timer ##sys#start-timer ##sys#memory-info ##sys#symbol-table-info ##sys#ensure-heap-reserve ##sys#make-structure ##sys#allocate-vector ##sys#setislot ##sys#setslot ##sys#gc ##sys#error/errno ##sys#notice ##sys#warn ##sys#error chicken.base#enable-warnings chicken.base#notice chicken.base#warning ##sys#notices-enabled ##sys#warnings-enabled ##sys#debug-mode? chicken.fixnum#fx/? chicken.fixnum#fx*? chicken.fixnum#fx-? chicken.fixnum#fx+? chicken.fixnum#fxrem chicken.fixnum#fxmod chicken.fixnum#fxgcd chicken.fixnum#fx/ chicken.fixnum#fxlen chicken.fixnum#fxeven? chicken.fixnum#fxodd? chicken.fixnum#fxshr chicken.fixnum#fxshl chicken.fixnum#fxnot chicken.fixnum#fxxor chicken.fixnum#fxior chicken.fixnum#fxand chicken.fixnum#fxneg chicken.fixnum#fxmax chicken.fixnum#fxmin chicken.fixnum#fx<= chicken.fixnum#fx>= chicken.fixnum#fx< chicken.fixnum#fx> chicken.fixnum#fx= chicken.fixnum#fx* chicken.fixnum#fx- chicken.fixnum#fx+ chicken.fixnum#fixnum-precision chicken.fixnum#fixnum-bits chicken.fixnum#most-negative-fixnum chicken.fixnum#most-positive-fixnum maximal-string-length chicken.base#rassoc chicken.base#alist-ref chicken.base#alist-update chicken.base#alist-update! chicken.base#compress chicken.base#join chicken.base#flatten chicken.base#butlast chicken.base#intersperse chicken.base#tail? chicken.base#atom? chicken.base#weak-pair? chicken.base#weak-cons chicken.base#bwp-object? chicken.base#each chicken.base#list-of? chicken.base#o chicken.base#compose chicken.base#complement chicken.base#flip chicken.base#constantly chicken.base#disjoin chicken.base#conjoin chicken.base#identity chicken.base#symbol-escape chicken.base#parentheses-synonyms chicken.base#keyword-style chicken.base#case-sensitive chicken.base#emergency-exit chicken.base#exit chicken.base#on-exit chicken.base#cleanup-tasks chicken.base#exit-handler chicken.base#implicit-exit-handler chicken.base#foldr chicken.base#foldl chicken.base#make-promise ##sys#make-promise chicken.base#promise? chicken.base#flush-output chicken.base#open-output-string chicken.base#open-input-string chicken.base#get-output-string chicken.base#output-port-open? chicken.base#input-port-open? chicken.base#port-closed? chicken.base#port? chicken.base#vector-resize chicken.base#subvector chicken.base#vector-copy! chicken.base#set-record-printer! chicken.base#record-printer chicken.base#setter chicken.base#procedure-information chicken.base#make-parameter chicken.base#getter-with-setter chicken.base#char-name chicken.base#call/cc chicken.base#sleep chicken.base#void chicken.base#error chicken.base#current-error-port chicken.base#sub1 chicken.base#add1 chicken.base#print* chicken.base#print chicken.base#print-call-chain chicken.base#get-call-chain chicken.base#signum chicken.base#nan? chicken.base#infinite? chicken.base#finite? chicken.base#quotient&modulo chicken.base#quotient&remainder chicken.base#exact-integer? chicken.base#cplxnum? chicken.base#ratnum? chicken.base#bignum? chicken.base#flonum? chicken.base#fixnum? scheme#dynamic-wind scheme#map scheme#for-each scheme#load scheme#null-environment scheme#scheme-report-environment scheme#interaction-environment scheme#eval scheme#display scheme#write scheme#newline scheme#write-char scheme#read scheme#peek-char scheme#read-char scheme#char-ready? scheme#eof-object? scheme#with-output-to-file scheme#with-input-from-file scheme#call-with-output-file scheme#call-with-input-file scheme#close-output-port scheme#close-input-port scheme#open-output-file scheme#open-input-file scheme#current-output-port scheme#current-input-port scheme#output-port? scheme#input-port? scheme#call-with-current-continuation scheme#call-with-values scheme#values scheme#apply scheme#procedure? scheme#char-alphabetic? scheme#char-whitespace? scheme#char-numeric? scheme#char-lower-case? scheme#char-upper-case? scheme#char-ci<=? scheme#char-ci>=? scheme#char-ci<? scheme#char-ci>? scheme#char-ci=? scheme#char-downcase scheme#char-upcase scheme#char<=? scheme#char>=? scheme#char<? scheme#char>? scheme#char=? scheme#integer->char scheme#char->integer scheme#char? scheme#vector-fill! scheme#vector scheme#vector->list scheme#list->vector scheme#make-vector scheme#vector-set! scheme#vector-ref scheme#vector-length scheme#vector? scheme#symbol? scheme#number->string scheme#negative? scheme#positive? scheme#zero? scheme#inexact? scheme#exact? scheme#integer? scheme#rational? scheme#real? scheme#complex? scheme#number? scheme#<= scheme#>= scheme#< scheme#> scheme#= scheme#odd? scheme#even? scheme#modulo scheme#remainder scheme#quotient scheme#* scheme#- scheme#+ scheme#abs scheme#exact->inexact scheme#string-fill scheme#string-ci=? scheme#string=? scheme#string-set! scheme#string-ref scheme#string-length scheme#string? scheme#list? scheme#assoc scheme#assv scheme#assq scheme#member scheme#memv scheme#memq scheme#reverse scheme#list-ref scheme#list-tail scheme#length scheme#list scheme#null? scheme#cdddar scheme#cddadr scheme#cddaar scheme#cdaddr scheme#cdadar scheme#cdaadr scheme#cdaaar scheme#caddar scheme#cadadr scheme#cadaar scheme#caaddr scheme#caadar scheme#caaadr scheme#caaaar scheme#cdddr scheme#cddar scheme#cdadr scheme#cdaar scheme#cadar scheme#caadr scheme#caaar scheme#cddr scheme#cdar scheme#caar scheme#cddddr scheme#cadddr scheme#caddr scheme#cadr scheme#set-cdr! scheme#set-car! scheme#cdr scheme#car scheme#cons scheme#pair? scheme#equal? scheme#eqv? scheme#eq? scheme#boolean? scheme#not) 
o|inlining procedure: k9158 
o|inlining procedure: k9158 
o|removed side-effect free assignment to unused variable: scheme#string-fill 
o|inlining procedure: k9395 
o|inlining procedure: k9395 
o|inlining procedure: k9401 
o|inlining procedure: k9401 
o|inlining procedure: k9492 
o|inlining procedure: k9492 
o|inlining procedure: k9554 
o|inlining procedure: k9554 
o|inlining procedure: k9604 
o|inlining procedure: k9604 
o|inlining procedure: k9628 
o|inlining procedure: k9628 
o|inlining procedure: k9665 
o|inlining procedure: k9665 
o|inlining procedure: k9754 
o|inlining procedure: k9754 
o|inlining procedure: k9784 
o|inlining procedure: k9784 
o|inlining procedure: k9813 
o|inlining procedure: k9813 
o|inlining procedure: k9857 
o|inlining procedure: k9857 
o|inlining procedure: k9878 
o|propagated global variable: r987933397 scheme#values 
o|inlining procedure: k9878 
o|inlining procedure: k9890 
o|propagated global variable: r989133399 chicken.base#identity 
o|inlining procedure: k9890 
o|inlining procedure: k9908 
o|inlining procedure: k9908 
o|inlining procedure: k9937 
o|inlining procedure: k9937 
o|inlining procedure: k9949 
o|inlining procedure: k9949 
o|inlining procedure: k9973 
o|inlining procedure: k9973 
o|inlining procedure: k10007 
o|inlining procedure: k10007 
o|inlining procedure: k10050 
o|inlining procedure: k10050 
o|inlining procedure: k10075 
o|inlining procedure: k10075 
o|inlining procedure: k10114 
o|inlining procedure: k10114 
o|inlining procedure: k10140 
o|inlining procedure: k10140 
o|inlining procedure: k10187 
o|inlining procedure: k10187 
o|inlining procedure: k10208 
o|inlining procedure: k10208 
o|inlining procedure: k10241 
o|inlining procedure: k10241 
o|inlining procedure: k10256 
o|inlining procedure: k10256 
o|inlining procedure: k10321 
o|inlining procedure: k10321 
o|inlining procedure: k10337 
o|propagated global variable: r1033833429 scheme#assv 
o|inlining procedure: k10337 
o|inlining procedure: k10357 
o|inlining procedure: k10357 
o|inlining procedure: k10407 
o|inlining procedure: k10407 
o|inlining procedure: k10432 
o|inlining procedure: k10432 
o|inlining procedure: k10520 
o|inlining procedure: k10520 
o|inlining procedure: k10529 
o|propagated global variable: r1053033439 scheme#assv 
o|inlining procedure: k10529 
o|inlining procedure: k10549 
o|inlining procedure: k10549 
o|inlining procedure: k10567 
o|inlining procedure: k10567 
o|inlining procedure: k10626 
o|inlining procedure: k10626 
o|inlining procedure: k10762 
o|inlining procedure: k10762 
o|inlining procedure: k10771 
o|inlining procedure: k10771 
o|inlining procedure: k10783 
o|inlining procedure: k10783 
o|propagated global variable: r1078433452 ##sys#warnings-enabled 
o|inlining procedure: k10797 
o|inlining procedure: k10797 
o|inlining procedure: k10902 
o|inlining procedure: k10902 
o|inlining procedure: k10938 
o|inlining procedure: k10938 
o|inlining procedure: k10949 
o|inlining procedure: k10949 
o|inlining procedure: k10961 
o|inlining procedure: k10961 
o|inlining procedure: k10972 
o|inlining procedure: k10972 
o|inlining procedure: k10983 
o|inlining procedure: k10983 
o|inlining procedure: k10994 
o|inlining procedure: k10994 
o|inlining procedure: k11005 
o|inlining procedure: k11005 
o|inlining procedure: k11016 
o|inlining procedure: k11016 
o|inlining procedure: k11027 
o|inlining procedure: k11027 
o|inlining procedure: k11038 
o|inlining procedure: k11038 
o|inlining procedure: k11049 
o|inlining procedure: k11049 
o|inlining procedure: k11060 
o|inlining procedure: k11060 
o|inlining procedure: k11071 
o|inlining procedure: k11071 
o|inlining procedure: k11082 
o|inlining procedure: k11082 
o|inlining procedure: k11093 
o|inlining procedure: k11093 
o|inlining procedure: k11104 
o|inlining procedure: k11104 
o|inlining procedure: k11111 
o|inlining procedure: k11111 
o|inlining procedure: k11121 
o|inlining procedure: k11121 
o|inlining procedure: k11128 
o|inlining procedure: k11128 
o|inlining procedure: k11138 
o|inlining procedure: k11151 
o|inlining procedure: k11151 
o|inlining procedure: k11138 
o|inlining procedure: k11162 
o|inlining procedure: k11162 
o|inlining procedure: k11169 
o|inlining procedure: k11169 
o|inlining procedure: k11182 
o|inlining procedure: k11182 
o|inlining procedure: k11193 
o|inlining procedure: k11193 
o|inlining procedure: k11209 
o|inlining procedure: k11209 
o|inlining procedure: k11219 
o|inlining procedure: k11219 
o|inlining procedure: k11229 
o|inlining procedure: k11229 
o|inlining procedure: k11240 
o|inlining procedure: k11255 
o|inlining procedure: k11255 
o|inlining procedure: k11273 
o|inlining procedure: k11294 
o|inlining procedure: k11294 
o|inlining procedure: k11322 
o|inlining procedure: k11322 
o|inlining procedure: k11273 
o|inlining procedure: k11240 
o|inlining procedure: k11496 
o|inlining procedure: k11496 
o|inlining procedure: k11508 
o|inlining procedure: k11508 
o|inlining procedure: k11527 
o|inlining procedure: k11527 
o|inlining procedure: k11581 
o|inlining procedure: k11581 
o|contracted procedure: "(library.scm:1335) g15141515" 
o|contracted procedure: "(library.scm:1342) g15201521" 
o|inlining procedure: k11677 
o|inlining procedure: k11677 
o|inlining procedure: k11699 
o|inlining procedure: k11699 
o|inlining procedure: k11720 
o|inlining procedure: k11720 
o|inlining procedure: k11751 
o|inlining procedure: k11771 
o|inlining procedure: k11771 
o|inlining procedure: k11751 
o|inlining procedure: k11837 
o|inlining procedure: k11837 
o|inlining procedure: k11853 
o|inlining procedure: k11853 
o|inlining procedure: k11914 
o|inlining procedure: k11914 
o|inlining procedure: k11938 
o|inlining procedure: k11938 
o|inlining procedure: k11959 
o|inlining procedure: k11959 
o|inlining procedure: k11980 
o|inlining procedure: k11980 
o|inlining procedure: k12024 
o|inlining procedure: k12024 
o|inlining procedure: k12048 
o|inlining procedure: k12048 
o|inlining procedure: k12069 
o|inlining procedure: k12069 
o|inlining procedure: k12090 
o|inlining procedure: k12090 
o|inlining procedure: k12127 
o|inlining procedure: k12127 
o|inlining procedure: k12175 
o|inlining procedure: k12175 
o|inlining procedure: k12216 
o|inlining procedure: k12216 
o|inlining procedure: k12237 
o|inlining procedure: k12237 
o|contracted procedure: "(library.scm:1596) g17681769" 
o|inlining procedure: k12298 
o|inlining procedure: k12298 
o|contracted procedure: "(library.scm:1600) g17791780" 
o|inlining procedure: k12322 
o|inlining procedure: k12322 
o|contracted procedure: "(library.scm:1604) g17901791" 
o|inlining procedure: k12346 
o|inlining procedure: k12346 
o|contracted procedure: "(library.scm:1608) g18011802" 
o|inlining procedure: k12370 
o|inlining procedure: k12370 
o|inlining procedure: k12392 
o|inlining procedure: k12392 
o|inlining procedure: k12405 
o|inlining procedure: k12405 
o|contracted procedure: "(library.scm:1618) g18201821" 
o|inlining procedure: k12419 
o|inlining procedure: k12419 
o|contracted procedure: "(library.scm:1622) g18311832" 
o|inlining procedure: k12443 
o|inlining procedure: k12443 
o|contracted procedure: "(library.scm:1626) g18421843" 
o|inlining procedure: k12467 
o|inlining procedure: k12467 
o|contracted procedure: "(library.scm:1630) g18531854" 
o|inlining procedure: k12491 
o|inlining procedure: k12491 
o|contracted procedure: "(library.scm:1634) g18641865" 
o|inlining procedure: k12515 
o|inlining procedure: k12515 
o|contracted procedure: "(library.scm:1638) g18751876" 
o|inlining procedure: k12539 
o|inlining procedure: k12539 
o|contracted procedure: "(library.scm:1642) g18861887" 
o|inlining procedure: k12563 
o|inlining procedure: k12563 
o|contracted procedure: "(library.scm:1646) g18961897" 
o|inlining procedure: k12587 
o|inlining procedure: k12587 
o|contracted procedure: "(library.scm:1650) g19051906" 
o|inlining procedure: k12605 
o|inlining procedure: k12605 
o|contracted procedure: "(library.scm:1654) g19161917" 
o|inlining procedure: k12629 
o|inlining procedure: k12629 
o|contracted procedure: "(library.scm:1658) g19261927" 
o|inlining procedure: k12653 
o|inlining procedure: k12653 
o|contracted procedure: "(library.scm:1662) g19341935" 
o|inlining procedure: k12671 
o|inlining procedure: k12671 
o|contracted procedure: "(library.scm:1666) g19421943" 
o|inlining procedure: k12689 
o|inlining procedure: k12689 
o|contracted procedure: "(library.scm:1670) g19501951" 
o|inlining procedure: k12707 
o|inlining procedure: k12707 
o|contracted procedure: "(library.scm:1674) g19581959" 
o|inlining procedure: k12725 
o|inlining procedure: k12725 
o|contracted procedure: "(library.scm:1678) g19661967" 
o|inlining procedure: k12743 
o|inlining procedure: k12743 
o|contracted procedure: "(library.scm:1682) g19741975" 
o|inlining procedure: k12761 
o|inlining procedure: k12761 
o|contracted procedure: "(library.scm:1686) g19821983" 
o|inlining procedure: k12779 
o|inlining procedure: k12779 
o|contracted procedure: "(library.scm:1690) g19901991" 
o|inlining procedure: k12797 
o|inlining procedure: k12797 
o|contracted procedure: "(library.scm:1694) g19981999" 
o|inlining procedure: k12815 
o|inlining procedure: k12815 
o|contracted procedure: "(library.scm:1698) g20072008" 
o|inlining procedure: k12833 
o|inlining procedure: k12833 
o|contracted procedure: "(library.scm:1702) g20172018" 
o|inlining procedure: k12857 
o|inlining procedure: k12857 
o|contracted procedure: "(library.scm:1706) g20252026" 
o|inlining procedure: k12875 
o|inlining procedure: k12875 
o|contracted procedure: "(library.scm:1710) g20332034" 
o|inlining procedure: k12893 
o|inlining procedure: k12893 
o|contracted procedure: "(library.scm:1714) g20412042" 
o|inlining procedure: k12911 
o|inlining procedure: k12911 
o|contracted procedure: "(library.scm:1718) g20492050" 
o|inlining procedure: k12929 
o|inlining procedure: k12929 
o|contracted procedure: "(library.scm:1722) g20572058" 
o|inlining procedure: k12947 
o|inlining procedure: k12947 
o|contracted procedure: "(library.scm:1726) g20652066" 
o|inlining procedure: k12965 
o|inlining procedure: k12965 
o|contracted procedure: "(library.scm:1730) g20742075" 
o|inlining procedure: k12983 
o|inlining procedure: k12983 
o|contracted procedure: "(library.scm:1734) g20842085" 
o|inlining procedure: k13007 
o|inlining procedure: k13007 
o|contracted procedure: "(library.scm:1738) g20922093" 
o|inlining procedure: k13025 
o|inlining procedure: k13025 
o|contracted procedure: "(library.scm:1742) g21002101" 
o|inlining procedure: k13043 
o|inlining procedure: k13043 
o|contracted procedure: "(library.scm:1746) g21082109" 
o|inlining procedure: k13061 
o|inlining procedure: k13061 
o|inlining procedure: k13080 
o|inlining procedure: k13080 
o|inlining procedure: k13099 
o|inlining procedure: k13099 
o|inlining procedure: k13126 
o|inlining procedure: k13126 
o|inlining procedure: k13170 
o|contracted procedure: "(library.scm:1795) g22062207" 
o|inlining procedure: k13170 
o|inlining procedure: k13193 
o|contracted procedure: "(library.scm:1801) g22142215" 
o|inlining procedure: k13193 
o|inlining procedure: k13207 
o|inlining procedure: k13207 
o|inlining procedure: k13235 
o|contracted procedure: "(library.scm:1817) g22292230" 
o|contracted procedure: "(library.scm:1816) g22262227" 
o|inlining procedure: k13235 
o|inlining procedure: k13279 
o|inlining procedure: k13279 
o|contracted procedure: "(library.scm:1831) g22392240" 
o|inlining procedure: k13296 
o|contracted procedure: "(library.scm:1833) g22422243" 
o|contracted procedure: "(library.scm:1833) g22492250" 
o|contracted procedure: "(library.scm:1833) g22462247" 
o|inlining procedure: k13296 
o|contracted procedure: "(library.scm:1834) g22522253" 
o|inlining procedure: k13325 
o|inlining procedure: k13325 
o|inlining procedure: k13332 
o|inlining procedure: k13332 
o|inlining procedure: k13354 
o|contracted procedure: "(library.scm:1843) g22652266" 
o|inlining procedure: k13354 
o|inlining procedure: k13371 
o|inlining procedure: k13371 
o|inlining procedure: k13378 
o|inlining procedure: k13378 
o|inlining procedure: k13400 
o|contracted procedure: "(library.scm:1855) g22772278" 
o|inlining procedure: k13400 
o|inlining procedure: k13417 
o|contracted procedure: "(library.scm:1862) g22862287" 
o|inlining procedure: k13417 
o|inlining procedure: k13541 
o|inlining procedure: k13541 
o|inlining procedure: k13550 
o|contracted procedure: "(library.scm:1895) g23182319" 
o|inlining procedure: k13550 
o|contracted procedure: "(library.scm:1896) flonum->ratnum" 
o|inlining procedure: k13481 
o|contracted procedure: "(library.scm:1880) g23032304" 
o|inlining procedure: k13481 
o|contracted procedure: "(library.scm:1877) float-fraction-length2291" 
o|inlining procedure: k13458 
o|inlining procedure: k13458 
o|inlining procedure: k13509 
o|inlining procedure: k13509 
o|substituted constant variable: a13537 
o|inlining procedure: k13567 
o|contracted procedure: "(library.scm:1900) g23242325" 
o|contracted procedure: "(library.scm:1899) g23212322" 
o|inlining procedure: k13567 
o|inlining procedure: k13619 
o|inlining procedure: k13619 
o|inlining procedure: k13642 
o|inlining procedure: k13642 
o|inlining procedure: k13673 
o|contracted procedure: "(library.scm:1952) g23812382" 
o|contracted procedure: "(library.scm:1952) g23772378" 
o|contracted procedure: "(library.scm:1951) g23732374" 
o|inlining procedure: k13673 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13787 
o|contracted procedure: "(library.scm:1972) g24202421" 
o|contracted procedure: "(library.scm:1971) g24152416" 
o|contracted procedure: "(library.scm:1970) g24112412" 
o|contracted procedure: "(library.scm:1970) g24072408" 
o|contracted procedure: "(library.scm:1969) g24032404" 
o|contracted procedure: "(library.scm:1969) g23992400" 
o|inlining procedure: k13787 
o|contracted procedure: "(library.scm:1981) g24312432" 
o|contracted procedure: "(library.scm:1978) g24252426" 
o|inlining procedure: k13883 
o|contracted procedure: "(library.scm:1991) g24402441" 
o|contracted procedure: "(library.scm:1989) g24352436" 
o|inlining procedure: k13883 
o|inlining procedure: k13953 
o|inlining procedure: k13953 
o|inlining procedure: k13963 
o|contracted procedure: "(library.scm:2005) g24552456" 
o|contracted procedure: "(library.scm:2004) g24512452" 
o|inlining procedure: k13963 
o|inlining procedure: k13998 
o|inlining procedure: k13998 
o|inlining procedure: k14008 
o|contracted procedure: "(library.scm:2015) g24682469" 
o|contracted procedure: "(library.scm:2014) g24642465" 
o|inlining procedure: k14008 
o|inlining procedure: k14043 
o|inlining procedure: k14043 
o|inlining procedure: k14053 
o|contracted procedure: "(library.scm:2025) g24792480" 
o|contracted procedure: "(library.scm:2024) g24762477" 
o|inlining procedure: k14053 
o|inlining procedure: k14080 
o|inlining procedure: k14080 
o|inlining procedure: k14087 
o|contracted procedure: "(library.scm:2034) g24882489" 
o|inlining procedure: k14087 
o|inlining procedure: k14133 
o|inlining procedure: k14133 
o|inlining procedure: k14205 
o|inlining procedure: k14205 
o|inlining procedure: k14223 
o|inlining procedure: k14223 
o|inlining procedure: k14277 
o|inlining procedure: k14277 
o|contracted procedure: "(library.scm:2061) find-ratio" 
o|inlining procedure: k14309 
o|inlining procedure: k14309 
o|inlining procedure: k14353 
o|inlining procedure: k14353 
o|inlining procedure: k14390 
o|contracted procedure: "(library.scm:2094) g25512552" 
o|contracted procedure: "(library.scm:2093) g25472548" 
o|inlining procedure: k14390 
o|inlining procedure: k14432 
o|inlining procedure: k14432 
o|inlining procedure: k14484 
o|inlining procedure: k14484 
o|inlining procedure: k14513 
o|inlining procedure: k14513 
o|inlining procedure: k14547 
o|inlining procedure: k14547 
o|inlining procedure: k14581 
o|inlining procedure: k14581 
o|inlining procedure: k14606 
o|inlining procedure: k14606 
o|inlining procedure: k14645 
o|inlining procedure: k14645 
o|inlining procedure: k14654 
o|substituted constant variable: a14661 
o|inlining procedure: k14654 
o|inlining procedure: k14668 
o|inlining procedure: k14668 
o|inlining procedure: k14687 
o|inlining procedure: k14687 
o|inlining procedure: k14696 
o|substituted constant variable: a14703 
o|inlining procedure: k14696 
o|inlining procedure: k14713 
o|inlining procedure: k14713 
o|inlining procedure: k14771 
o|inlining procedure: k14789 
o|inlining procedure: k14789 
o|inlining procedure: k14807 
o|inlining procedure: k14807 
o|substituted constant variable: a14820 
o|substituted constant variable: a14822 
o|substituted constant variable: a14824 
o|substituted constant variable: a14829 
o|substituted constant variable: a14831 
o|inlining procedure: k14771 
o|substituted constant variable: a14862 
o|inlining procedure: k14897 
o|inlining procedure: k14897 
o|inlining procedure: k14971 
o|inlining procedure: k14971 
o|inlining procedure: k15022 
o|inlining procedure: k15038 
o|inlining procedure: k15038 
o|inlining procedure: k15022 
o|contracted procedure: "(library.scm:2235) g26932694" 
o|inlining procedure: k15072 
o|contracted procedure: "(library.scm:2238) g26982699" 
o|inlining procedure: k15096 
o|inlining procedure: k15096 
o|inlining procedure: k15072 
o|inlining procedure: k15144 
o|inlining procedure: k15144 
o|inlining procedure: k15189 
o|inlining procedure: k15189 
o|inlining procedure: k15261 
o|inlining procedure: k15261 
o|inlining procedure: k15276 
o|contracted procedure: "(library.scm:2280) g27312732" 
o|inlining procedure: k15276 
o|inlining procedure: k15299 
o|inlining procedure: k15299 
o|contracted procedure: "(library.scm:2285) square2729" 
o|inlining procedure: k15355 
o|inlining procedure: k15355 
o|inlining procedure: k15375 
o|inlining procedure: k15375 
o|inlining procedure: k15393 
o|contracted procedure: "(library.scm:2305) g27592760" 
o|contracted procedure: "(library.scm:2304) g27562757" 
o|inlining procedure: k15393 
o|inlining procedure: k15430 
o|contracted procedure: "(library.scm:2314) g27662767" 
o|inlining procedure: k15465 
o|contracted procedure: "(library.scm:2316) g27712772" 
o|inlining procedure: k15465 
o|inlining procedure: k15430 
o|inlining procedure: k15499 
o|inlining procedure: k15499 
o|inlining procedure: k15517 
o|inlining procedure: k15517 
o|inlining procedure: k15536 
o|inlining procedure: k15536 
o|inlining procedure: k15573 
o|inlining procedure: k15573 
o|inlining procedure: k15605 
o|contracted procedure: "(library.scm:2342) g27962797" 
o|inlining procedure: k15618 
o|contracted procedure: "(library.scm:2345) g28012802" 
o|inlining procedure: k15618 
o|inlining procedure: k15605 
o|inlining procedure: k15646 
o|inlining procedure: k15646 
o|contracted procedure: "(library.scm:2352) g28102811" 
o|inlining procedure: k15681 
o|inlining procedure: k15681 
o|inlining procedure: k15701 
o|inlining procedure: k15701 
o|inlining procedure: k15746 
o|inlining procedure: k15746 
o|inlining procedure: k15766 
o|inlining procedure: k15766 
o|substituted constant variable: a15839 
o|inlining procedure: k15857 
o|contracted procedure: "(library.scm:2408) g28762877" 
o|contracted procedure: "(library.scm:2406) g28732874" 
o|inlining procedure: k15857 
o|inlining procedure: k15921 
o|inlining procedure: k15921 
o|contracted procedure: "(library.scm:2412) g28842885" 
o|contracted procedure: "(library.scm:2411) g28812882" 
o|inlining procedure: k16036 
o|inlining procedure: k16049 
o|inlining procedure: k16049 
o|inlining procedure: k16036 
o|contracted procedure: "(library.scm:2450) g29142915" 
o|inlining procedure: k16078 
o|inlining procedure: k16078 
o|inlining procedure: k16092 
o|inlining procedure: k16101 
o|inlining procedure: k16113 
o|inlining procedure: k16113 
o|inlining procedure: k16101 
o|inlining procedure: k16129 
o|inlining procedure: k16129 
o|inlining procedure: k16135 
o|contracted procedure: "(library.scm:2475) mantexp->dbl" 
o|inlining procedure: k15934 
o|inlining procedure: k15934 
o|contracted procedure: "(library.scm:2442) ldexp" 
o|propagated global variable: a15993 chicken.flonum#flonum-precision 
o|inlining procedure: k16135 
o|inlining procedure: k16092 
o|inlining procedure: k16178 
o|inlining procedure: k16178 
o|inlining procedure: k16204 
o|inlining procedure: k16204 
o|inlining procedure: k16231 
o|inlining procedure: k16231 
o|inlining procedure: k16259 
o|inlining procedure: k16259 
o|substituted constant variable: a16266 
o|substituted constant variable: a16270 
o|substituted constant variable: a16277 
o|contracted procedure: "(library.scm:2497) g29582959" 
o|inlining procedure: k16286 
o|inlining procedure: k16286 
o|inlining procedure: k16319 
o|inlining procedure: k16319 
o|contracted procedure: "(library.scm:2512) g29812982" 
o|inlining procedure: k16339 
o|inlining procedure: k16339 
o|inlining procedure: k16361 
o|inlining procedure: k16361 
o|inlining procedure: k16372 
o|inlining procedure: k16372 
o|inlining procedure: k16386 
o|inlining procedure: k16409 
o|inlining procedure: k16409 
o|inlining procedure: k16432 
o|inlining procedure: k16432 
o|substituted constant variable: a16439 
o|substituted constant variable: a16441 
o|contracted procedure: "(library.scm:2534) g30173018" 
o|inlining procedure: k16386 
o|inlining procedure: k16444 
o|inlining procedure: k16465 
o|inlining procedure: k16483 
o|inlining procedure: k16495 
o|inlining procedure: k16511 
o|inlining procedure: k16511 
o|inlining procedure: k16495 
o|inlining procedure: k16483 
o|inlining procedure: k16465 
o|inlining procedure: k16556 
o|inlining procedure: k16556 
o|inlining procedure: k16571 
o|inlining procedure: k16571 
o|inlining procedure: k16583 
o|inlining procedure: k16583 
o|inlining procedure: k16595 
o|inlining procedure: k16595 
o|inlining procedure: k16607 
o|inlining procedure: k16607 
o|substituted constant variable: a16620 
o|substituted constant variable: a16622 
o|substituted constant variable: a16624 
o|substituted constant variable: a16626 
o|substituted constant variable: a16628 
o|substituted constant variable: a16630 
o|substituted constant variable: a16632 
o|substituted constant variable: a16634 
o|substituted constant variable: a16636 
o|substituted constant variable: a16638 
o|contracted procedure: "(library.scm:2549) g30453046" 
o|inlining procedure: k16647 
o|inlining procedure: k16647 
o|inlining procedure: k16444 
o|inlining procedure: k16658 
o|inlining procedure: k16658 
o|inlining procedure: k16683 
o|inlining procedure: k16698 
o|inlining procedure: k16698 
o|inlining procedure: k16683 
o|inlining procedure: k16741 
o|inlining procedure: k16753 
o|inlining procedure: k16763 
o|inlining procedure: k16763 
o|inlining procedure: k16753 
o|inlining procedure: k16741 
o|inlining procedure: k16783 
o|inlining procedure: k16799 
o|inlining procedure: k16809 
o|inlining procedure: k16827 
o|inlining procedure: k16847 
o|inlining procedure: "(library.scm:2603) make-nan2928" 
o|inlining procedure: k16847 
o|substituted constant variable: a16874 
o|substituted constant variable: a16876 
o|substituted constant variable: a16878 
o|inlining procedure: k16827 
o|inlining procedure: k16809 
o|inlining procedure: k16799 
o|inlining procedure: k16783 
o|substituted constant variable: a16896 
o|inlining procedure: k16900 
o|inlining procedure: k16900 
o|inlining procedure: k16912 
o|inlining procedure: k16912 
o|inlining procedure: k16924 
o|inlining procedure: k16924 
o|inlining procedure: k16936 
o|inlining procedure: k16936 
o|substituted constant variable: a16949 
o|substituted constant variable: a16951 
o|substituted constant variable: a16953 
o|substituted constant variable: a16955 
o|substituted constant variable: a16957 
o|substituted constant variable: a16959 
o|substituted constant variable: a16961 
o|substituted constant variable: a16963 
o|substituted constant variable: a16965 
o|substituted constant variable: a16967 
o|substituted constant variable: a16969 
o|contracted procedure: "(library.scm:2574) g31193120" 
o|inlining procedure: k16983 
o|contracted procedure: "(library.scm:2569) g31063107" 
o|inlining procedure: k16983 
o|inlining procedure: k17004 
o|inlining procedure: k17032 
o|inlining procedure: k17054 
o|inlining procedure: k17064 
o|inlining procedure: k17064 
o|inlining procedure: k17054 
o|inlining procedure: k17087 
o|inlining procedure: k17087 
o|inlining procedure: k17032 
o|inlining procedure: k17141 
o|inlining procedure: k17141 
o|inlining procedure: k17151 
o|inlining procedure: k17174 
o|inlining procedure: k17174 
o|inlining procedure: "(library.scm:2632) make-nan2928" 
o|inlining procedure: k17151 
o|substituted constant variable: a17214 
o|substituted constant variable: a17216 
o|substituted constant variable: a17221 
o|substituted constant variable: a17223 
o|contracted procedure: "(library.scm:2613) g32013202" 
o|inlining procedure: k17230 
o|inlining procedure: k17230 
o|substituted constant variable: a17237 
o|substituted constant variable: a17239 
o|contracted procedure: "(library.scm:2609) g31893190" 
o|inlining procedure: k17004 
o|inlining procedure: k17246 
o|inlining procedure: k17258 
o|inlining procedure: k17258 
o|inlining procedure: k17268 
o|inlining procedure: k17268 
o|inlining procedure: k17246 
o|inlining procedure: k17275 
o|inlining procedure: k17275 
o|inlining procedure: k17291 
o|contracted procedure: "(library.scm:2642) g32553256" 
o|contracted procedure: "(library.scm:2641) g32513252" 
o|inlining procedure: k17291 
o|inlining procedure: k17332 
o|inlining procedure: k17351 
o|inlining procedure: k17366 
o|inlining procedure: k17366 
o|contracted procedure: "(library.scm:2650) g32793280" 
o|contracted procedure: "(library.scm:2649) g32753276" 
o|inlining procedure: k17351 
o|inlining procedure: k17332 
o|inlining procedure: k17413 
o|inlining procedure: k17413 
o|substituted constant variable: a17440 
o|substituted constant variable: a17445 
o|substituted constant variable: a17447 
o|substituted constant variable: a17452 
o|substituted constant variable: a17454 
o|substituted constant variable: a17456 
o|contracted procedure: "(library.scm:2638) g32393240" 
o|inlining procedure: k17513 
o|inlining procedure: k17533 
o|inlining procedure: k17533 
o|inlining procedure: k17546 
o|inlining procedure: k17546 
o|inlining procedure: k17577 
o|inlining procedure: k17577 
o|inlining procedure: k17590 
o|inlining procedure: k17590 
o|inlining procedure: k17621 
o|inlining procedure: k17621 
o|inlining procedure: k17634 
o|inlining procedure: k17634 
o|substituted constant variable: a17660 
o|substituted constant variable: a17662 
o|substituted constant variable: a17667 
o|substituted constant variable: a17669 
o|substituted constant variable: a17674 
o|substituted constant variable: a17676 
o|substituted constant variable: a17681 
o|substituted constant variable: a17683 
o|substituted constant variable: a17688 
o|substituted constant variable: a17690 
o|substituted constant variable: a17695 
o|substituted constant variable: a17697 
o|contracted procedure: "(library.scm:2677) g33293330" 
o|inlining procedure: k17513 
o|inlining procedure: k17706 
o|inlining procedure: k17706 
o|contracted procedure: "(library.scm:2676) g33193320" 
o|inlining procedure: k17731 
o|inlining procedure: k17731 
o|inlining procedure: k17804 
o|inlining procedure: k17825 
o|inlining procedure: k17825 
o|inlining procedure: k17804 
o|inlining procedure: k17869 
o|inlining procedure: k17869 
o|inlining procedure: k17878 
o|inlining procedure: k17878 
o|inlining procedure: k17890 
o|inlining procedure: k17890 
o|inlining procedure: k17902 
o|inlining procedure: k17902 
o|inlining procedure: k17911 
o|inlining procedure: k17911 
o|inlining procedure: k17920 
o|inlining procedure: k17929 
o|inlining procedure: k17929 
o|inlining procedure: k17920 
o|inlining procedure: k18057 
o|inlining procedure: k18057 
o|inlining procedure: "(library.scm:2779) err3441" 
o|inlining procedure: k18063 
o|inlining procedure: k18063 
o|inlining procedure: "(library.scm:2778) err3441" 
o|inlining procedure: k18103 
o|contracted procedure: "(library.scm:2788) g34653474" 
o|inlining procedure: k18103 
o|inlining procedure: k18149 
o|inlining procedure: k18149 
o|inlining procedure: k18176 
o|inlining procedure: k18176 
o|inlining procedure: k18213 
o|inlining procedure: k18213 
o|inlining procedure: k18261 
o|inlining procedure: k18261 
o|inlining procedure: k18285 
o|inlining procedure: k18285 
o|inlining procedure: k18304 
o|inlining procedure: k18304 
o|inlining procedure: k18325 
o|inlining procedure: k18325 
o|inlining procedure: k18365 
o|inlining procedure: k18365 
o|inlining procedure: k18404 
o|inlining procedure: k18404 
o|inlining procedure: k18450 
o|inlining procedure: k18450 
o|inlining procedure: k18522 
o|inlining procedure: k18522 
o|inlining procedure: k18596 
o|inlining procedure: k18596 
o|inlining procedure: k18698 
o|inlining procedure: k18698 
o|inlining procedure: k18729 
o|inlining procedure: k18729 
o|inlining procedure: k18759 
o|inlining procedure: k18759 
o|inlining procedure: k18829 
o|inlining procedure: k18829 
o|inlining procedure: k18893 
o|inlining procedure: k18893 
o|inlining procedure: k18931 
o|inlining procedure: k18931 
o|inlining procedure: k18979 
o|inlining procedure: k18979 
o|inlining procedure: k18997 
o|inlining procedure: k18997 
o|inlining procedure: k19025 
o|inlining procedure: k19040 
o|inlining procedure: k19040 
o|inlining procedure: k19025 
o|inlining procedure: k19076 
o|inlining procedure: k19076 
o|inlining procedure: k19107 
o|inlining procedure: k19125 
o|inlining procedure: k19125 
o|inlining procedure: k19107 
o|inlining procedure: k19172 
o|inlining procedure: k19172 
o|inlining procedure: k19249 
o|inlining procedure: k19249 
o|inlining procedure: k19283 
o|inlining procedure: k19283 
o|inlining procedure: k19338 
o|inlining procedure: k19338 
o|substituted constant variable: a19345 
o|substituted constant variable: a19350 
o|inlining procedure: k19417 
o|inlining procedure: k19417 
o|inlining procedure: k19428 
o|inlining procedure: k19428 
o|inlining procedure: k19439 
o|inlining procedure: k19439 
o|inlining procedure: k19450 
o|inlining procedure: k19450 
o|inlining procedure: k19461 
o|propagated global variable: r1946234117 ##sys#standard-input 
o|removed unused formal parameters: (convert?3986) 
o|inlining procedure: k19476 
o|inlining procedure: k19476 
o|removed unused parameter to known procedure: convert?3986 "(library.scm:3363) body39763985" 
o|inlining procedure: k19461 
o|inlining procedure: k19503 
o|inlining procedure: k19503 
o|removed unused parameter to known procedure: convert?3986 "(library.scm:3363) body39763985" 
o|inlining procedure: k19522 
o|propagated global variable: r1952334123 ##sys#standard-output 
o|removed unused formal parameters: (convert?4011) 
o|inlining procedure: k19537 
o|inlining procedure: k19537 
o|removed unused parameter to known procedure: convert?4011 "(library.scm:3373) body40014010" 
o|inlining procedure: k19522 
o|inlining procedure: k19564 
o|inlining procedure: k19564 
o|removed unused parameter to known procedure: convert?4011 "(library.scm:3373) body40014010" 
o|inlining procedure: k19583 
o|propagated global variable: r1958434129 ##sys#standard-error 
o|removed unused formal parameters: (convert?4036) 
o|inlining procedure: k19598 
o|inlining procedure: k19598 
o|removed unused parameter to known procedure: convert?4036 "(library.scm:3383) body40264035" 
o|inlining procedure: k19583 
o|inlining procedure: k19625 
o|inlining procedure: k19625 
o|removed unused parameter to known procedure: convert?4036 "(library.scm:3383) body40264035" 
o|inlining procedure: k19644 
o|inlining procedure: k19644 
o|inlining procedure: k19682 
o|inlining procedure: k19682 
o|inlining procedure: k19708 
o|inlining procedure: k19708 
o|inlining procedure: k19714 
o|inlining procedure: k19714 
o|inlining procedure: k19737 
o|inlining procedure: k19737 
o|inlining procedure: k19750 
o|inlining procedure: k19750 
o|substituted constant variable: a19761 
o|substituted constant variable: a19763 
o|substituted constant variable: a19765 
o|inlining procedure: k19775 
o|inlining procedure: k19775 
o|inlining procedure: k19950 
o|inlining procedure: k19950 
o|substituted constant variable: a19966 
o|substituted constant variable: a19968 
o|substituted constant variable: a19989 
o|substituted constant variable: a19990 
o|inlining procedure: k20003 
o|inlining procedure: k20003 
o|inlining procedure: k20025 
o|inlining procedure: k20038 
o|inlining procedure: k20038 
o|inlining procedure: k20025 
o|inlining procedure: k20097 
o|inlining procedure: k20097 
o|inlining procedure: k20135 
o|inlining procedure: k20135 
o|inlining procedure: k20169 
o|inlining procedure: k20169 
o|inlining procedure: k20210 
o|inlining procedure: k20210 
o|inlining procedure: k20229 
o|inlining procedure: k20229 
o|inlining procedure: k20357 
o|inlining procedure: k20357 
o|inlining procedure: k20396 
o|inlining procedure: k20435 
o|inlining procedure: k20435 
o|inlining procedure: k20396 
o|inlining procedure: k20463 
o|inlining procedure: k20463 
o|substituted constant variable: a20511 
o|substituted constant variable: a20512 
o|substituted constant variable: a20536 
o|substituted constant variable: a20537 
o|inlining procedure: k20553 
o|inlining procedure: k20553 
o|substituted constant variable: a20611 
o|substituted constant variable: a20612 
o|inlining procedure: k20619 
o|inlining procedure: k20619 
o|substituted constant variable: a20648 
o|substituted constant variable: a20649 
o|substituted constant variable: a20666 
o|substituted constant variable: a20667 
o|inlining procedure: k20721 
o|inlining procedure: k20721 
o|inlining procedure: k20744 
o|inlining procedure: k20744 
o|inlining procedure: k20784 
o|inlining procedure: k20784 
o|inlining procedure: k20803 
o|inlining procedure: k20803 
o|inlining procedure: k20842 
o|inlining procedure: k20842 
o|inlining procedure: k20867 
o|inlining procedure: k20867 
o|inlining procedure: k20886 
o|inlining procedure: k20886 
o|inlining procedure: k20911 
o|inlining procedure: k20911 
o|inlining procedure: k20977 
o|inlining procedure: k20977 
o|inlining procedure: k21012 
o|inlining procedure: k21012 
o|inlining procedure: k21028 
o|inlining procedure: k21028 
o|inlining procedure: k21062 
o|inlining procedure: k21062 
o|inlining procedure: k21096 
o|inlining procedure: k21096 
o|inlining procedure: k21130 
o|inlining procedure: k21130 
o|inlining procedure: k21171 
o|inlining procedure: k21186 
o|inlining procedure: k21186 
o|substituted constant variable: a21224 
o|substituted constant variable: a21229 
o|inlining procedure: k21171 
o|inlining procedure: k21254 
o|inlining procedure: k21254 
o|inlining procedure: k21274 
o|inlining procedure: k21274 
o|inlining procedure: k21309 
o|inlining procedure: k21309 
o|inlining procedure: k21331 
o|inlining procedure: k21331 
o|inlining procedure: k21356 
o|inlining procedure: k21356 
o|substituted constant variable: a21385 
o|substituted constant variable: a21387 
o|substituted constant variable: a21392 
o|substituted constant variable: a21394 
o|inlining procedure: k21395 
o|inlining procedure: k21395 
o|inlining procedure: k21458 
o|inlining procedure: k21458 
o|inlining procedure: k21470 
o|inlining procedure: k21470 
o|substituted constant variable: a21483 
o|substituted constant variable: a21485 
o|substituted constant variable: a21487 
o|substituted constant variable: a21489 
o|inlining procedure: k21493 
o|inlining procedure: k21493 
o|substituted constant variable: a21506 
o|substituted constant variable: a21508 
o|substituted constant variable: a21510 
o|substituted constant variable: a21512 
o|substituted constant variable: a21514 
o|substituted constant variable: a21516 
o|substituted constant variable: a21518 
o|substituted constant variable: a21520 
o|substituted constant variable: a21522 
o|substituted constant variable: a21524 
o|substituted constant variable: a21526 
o|substituted constant variable: a21528 
o|substituted constant variable: a21530 
o|substituted constant variable: a21532 
o|inlining procedure: k21533 
o|inlining procedure: k21533 
o|inlining procedure: k21565 
o|inlining procedure: k21565 
o|inlining procedure: k21556 
o|inlining procedure: k21598 
o|inlining procedure: k21598 
o|inlining procedure: k21629 
o|inlining procedure: k21629 
o|inlining procedure: k21648 
o|inlining procedure: k21681 
o|inlining procedure: k21681 
o|inlining procedure: k21723 
o|inlining procedure: k21723 
o|inlining procedure: "(library.scm:3986) build-keyword4512" 
o|inlining procedure: k21739 
o|inlining procedure: "(library.scm:3987) build-keyword4512" 
o|inlining procedure: k21739 
o|inlining procedure: "(library.scm:3990) build-symbol4511" 
o|inlining procedure: k21769 
o|inlining procedure: k21769 
o|inlining procedure: k21781 
o|inlining procedure: k21781 
o|inlining procedure: k21648 
o|inlining procedure: k21556 
o|inlining procedure: k21821 
o|inlining procedure: k21821 
o|inlining procedure: k21842 
o|inlining procedure: "(library.scm:4018) build-keyword4512" 
o|inlining procedure: k21842 
o|inlining procedure: k21864 
o|inlining procedure: k21864 
o|inlining procedure: k21879 
o|inlining procedure: k21879 
o|inlining procedure: "(library.scm:4026) build-symbol4511" 
o|inlining procedure: k21889 
o|inlining procedure: k21889 
o|substituted constant variable: a21897 
o|substituted constant variable: a21898 
o|inlining procedure: k21906 
o|inlining procedure: k21927 
o|inlining procedure: k21927 
o|substituted constant variable: a21940 
o|inlining procedure: k21906 
o|inlining procedure: k21957 
o|inlining procedure: k21978 
o|inlining procedure: k21978 
o|substituted constant variable: a21991 
o|substituted constant variable: a21999 
o|inlining procedure: k21995 
o|inlining procedure: k21995 
o|substituted constant variable: a22007 
o|inlining procedure: k21957 
o|inlining procedure: k22034 
o|inlining procedure: k22034 
o|inlining procedure: k22070 
o|inlining procedure: k22070 
o|inlining procedure: k22079 
o|inlining procedure: k22079 
o|inlining procedure: k22098 
o|inlining procedure: k22098 
o|inlining procedure: "(library.scm:4078) build-keyword4512" 
o|inlining procedure: "(library.scm:4078) build-symbol4511" 
o|inlining procedure: k22172 
o|inlining procedure: k22198 
o|inlining procedure: k22198 
o|inlining procedure: k22227 
o|inlining procedure: k22227 
o|inlining procedure: k22236 
o|inlining procedure: k22236 
o|inlining procedure: k22246 
o|inlining procedure: k22246 
o|inlining procedure: k22172 
o|inlining procedure: k22278 
o|inlining procedure: k22278 
o|inlining procedure: k22322 
o|inlining procedure: k22322 
o|inlining procedure: k22344 
o|inlining procedure: k22344 
o|inlining procedure: k22368 
o|inlining procedure: k22368 
o|substituted constant variable: a22375 
o|substituted constant variable: a22377 
o|substituted constant variable: a22379 
o|substituted constant variable: a22381 
o|inlining procedure: k22385 
o|inlining procedure: k22385 
o|inlining procedure: k22394 
o|inlining procedure: k22394 
o|inlining procedure: k22419 
o|contracted procedure: "(library.scm:4137) g48114812" 
o|inlining procedure: k22448 
o|inlining procedure: k22448 
o|inlining procedure: k22467 
o|inlining procedure: k22485 
o|inlining procedure: k22501 
o|inlining procedure: k22501 
o|inlining procedure: k22485 
o|inlining procedure: k22467 
o|substituted constant variable: a22600 
o|inlining procedure: k22602 
o|inlining procedure: k22602 
o|substituted constant variable: a22605 
o|inlining procedure: k22419 
o|inlining procedure: k22628 
o|inlining procedure: k22640 
o|inlining procedure: k22640 
o|inlining procedure: k22628 
o|inlining procedure: k22674 
o|inlining procedure: k22674 
o|inlining procedure: k22687 
o|inlining procedure: k22687 
o|substituted constant variable: a22700 
o|substituted constant variable: a22702 
o|inlining procedure: "(library.scm:4184) build-symbol4511" 
o|inlining procedure: k22761 
o|inlining procedure: k22776 
o|inlining procedure: k22776 
o|inlining procedure: k22761 
o|inlining procedure: k22800 
o|inlining procedure: k22800 
o|inlining procedure: k22821 
o|inlining procedure: k22821 
o|inlining procedure: k22840 
o|inlining procedure: k22861 
o|inlining procedure: k22888 
o|inlining procedure: k22903 
o|inlining procedure: k22903 
o|inlining procedure: k22888 
o|inlining procedure: k22939 
o|inlining procedure: k22939 
o|inlining procedure: k22861 
o|inlining procedure: k22974 
o|inlining procedure: k22974 
o|inlining procedure: k22989 
o|inlining procedure: k22989 
o|inlining procedure: k23013 
o|inlining procedure: k23013 
o|inlining procedure: k23037 
o|inlining procedure: k23037 
o|inlining procedure: k23061 
o|inlining procedure: k23101 
o|inlining procedure: k23101 
o|inlining procedure: k23061 
o|inlining procedure: k23125 
o|inlining procedure: k23125 
o|inlining procedure: k23152 
o|inlining procedure: k23152 
o|inlining procedure: k23179 
o|inlining procedure: k23179 
o|inlining procedure: k23203 
o|inlining procedure: k23203 
o|inlining procedure: k23218 
o|inlining procedure: k23247 
o|inlining procedure: k23247 
o|inlining procedure: "(library.scm:4311) build-keyword4512" 
o|inlining procedure: k23218 
o|inlining procedure: k23308 
o|inlining procedure: k23335 
o|inlining procedure: k23335 
o|substituted constant variable: a23344 
o|inlining procedure: k23346 
o|inlining procedure: "(library.scm:4332) build-symbol4511" 
o|inlining procedure: k23346 
o|inlining procedure: k23384 
o|inlining procedure: k23384 
o|substituted constant variable: a23387 
o|inlining procedure: k23308 
o|inlining procedure: k23401 
o|inlining procedure: k23401 
o|substituted constant variable: a23414 
o|substituted constant variable: a23416 
o|substituted constant variable: a23418 
o|substituted constant variable: a23420 
o|substituted constant variable: a23422 
o|substituted constant variable: a23424 
o|substituted constant variable: a23426 
o|substituted constant variable: a23428 
o|substituted constant variable: a23430 
o|substituted constant variable: a23432 
o|substituted constant variable: a23434 
o|substituted constant variable: a23436 
o|substituted constant variable: a23438 
o|substituted constant variable: a23440 
o|substituted constant variable: a23442 
o|substituted constant variable: a23444 
o|substituted constant variable: a23446 
o|inlining procedure: k22840 
o|inlining procedure: k23463 
o|inlining procedure: k23463 
o|inlining procedure: k23487 
o|inlining procedure: k23487 
o|inlining procedure: k23508 
o|inlining procedure: k23508 
o|inlining procedure: k23523 
o|inlining procedure: k23523 
o|inlining procedure: k23541 
o|inlining procedure: k23541 
o|substituted constant variable: a23572 
o|substituted constant variable: a23574 
o|substituted constant variable: a23576 
o|substituted constant variable: a23578 
o|substituted constant variable: a23583 
o|substituted constant variable: a23585 
o|substituted constant variable: a23587 
o|substituted constant variable: a23589 
o|substituted constant variable: a23591 
o|substituted constant variable: a23593 
o|substituted constant variable: a23595 
o|substituted constant variable: a23597 
o|substituted constant variable: a23599 
o|substituted constant variable: a23601 
o|inlining procedure: k23605 
o|inlining procedure: k23605 
o|inlining procedure: k23624 
o|inlining procedure: k23624 
o|inlining procedure: k23642 
o|inlining procedure: k23642 
o|inlining procedure: k23684 
o|inlining procedure: k23684 
o|inlining procedure: k23804 
o|inlining procedure: k23804 
o|inlining procedure: k23816 
o|inlining procedure: k23828 
o|inlining procedure: k23828 
o|inlining procedure: k23816 
o|inlining procedure: k23884 
o|inlining procedure: k23884 
o|substituted constant variable: a23914 
o|substituted constant variable: a23916 
o|substituted constant variable: a23918 
o|substituted constant variable: a23920 
o|inlining procedure: k23930 
o|inlining procedure: k23930 
o|inlining procedure: k23949 
o|inlining procedure: k23949 
o|inlining procedure: k23963 
o|inlining procedure: k23963 
o|inlining procedure: k24026 
o|inlining procedure: k24026 
o|substituted constant variable: a24057 
o|substituted constant variable: a24059 
o|substituted constant variable: a24064 
o|substituted constant variable: a24066 
o|substituted constant variable: a24088 
o|substituted constant variable: a24089 
o|substituted constant variable: a24106 
o|substituted constant variable: a24107 
o|inlining procedure: k24120 
o|propagated global variable: r2412134489 ##sys#standard-output 
o|inlining procedure: k24120 
o|substituted constant variable: a24139 
o|substituted constant variable: a24140 
o|substituted constant variable: a24157 
o|substituted constant variable: a24158 
o|propagated global variable: a24171 ##sys#standard-output 
o|substituted constant variable: a24172 
o|substituted constant variable: a24173 
o|contracted procedure: "(library.scm:4482) g51445145" 
o|inlining procedure: k24190 
o|contracted procedure: "(library.scm:4477) g51505157" 
o|propagated global variable: g51655166 ##sys#print 
o|inlining procedure: k24190 
o|propagated global variable: a24222 ##sys#standard-output 
o|substituted constant variable: a24223 
o|substituted constant variable: a24224 
o|contracted procedure: "(library.scm:4489) g51765177" 
o|inlining procedure: k24241 
o|contracted procedure: "(library.scm:4477) g51825189" 
o|propagated global variable: g51975198 ##sys#print 
o|inlining procedure: k24241 
o|substituted constant variable: a24286 
o|substituted constant variable: a24287 
o|inlining procedure: k24300 
o|inlining procedure: k24300 
o|inlining procedure: k24391 
o|inlining procedure: k24391 
o|inlining procedure: k24423 
o|inlining procedure: k24423 
o|substituted constant variable: special-characters5219 
o|inlining procedure: k24435 
o|inlining procedure: k24435 
o|inlining procedure: k24468 
o|inlining procedure: k24468 
o|substituted constant variable: a24541 
o|inlining procedure: k24548 
o|inlining procedure: k24548 
o|inlining procedure: k24560 
o|inlining procedure: k24560 
o|inlining procedure: k24575 
o|inlining procedure: k24575 
o|inlining procedure: k24594 
o|inlining procedure: k24616 
o|inlining procedure: k24616 
o|inlining procedure: k24631 
o|inlining procedure: k24631 
o|inlining procedure: k24644 
o|inlining procedure: k24644 
o|inlining procedure: k24668 
o|inlining procedure: k24668 
o|inlining procedure: k24594 
o|inlining procedure: k24686 
o|inlining procedure: k24686 
o|inlining procedure: k24739 
o|inlining procedure: k24739 
o|inlining procedure: k24757 
o|inlining procedure: k24757 
o|inlining procedure: k24772 
o|inlining procedure: k24772 
o|inlining procedure: k24784 
o|inlining procedure: k24799 
o|inlining procedure: k24799 
o|inlining procedure: k24784 
o|inlining procedure: k24852 
o|inlining procedure: k24852 
o|inlining procedure: k24867 
o|inlining procedure: k24867 
o|inlining procedure: k24879 
o|inlining procedure: k24879 
o|substituted constant variable: a24910 
o|substituted constant variable: a24912 
o|inlining procedure: k24916 
o|inlining procedure: k24916 
o|inlining procedure: k24935 
o|inlining procedure: k24935 
o|inlining procedure: k24948 
o|inlining procedure: k24961 
o|inlining procedure: k24961 
o|inlining procedure: k24990 
o|inlining procedure: k24990 
o|inlining procedure: k25011 
o|inlining procedure: k25011 
o|inlining procedure: k25029 
o|inlining procedure: k25029 
o|inlining procedure: k25047 
o|inlining procedure: k25047 
o|inlining procedure: k25065 
o|inlining procedure: k25065 
o|substituted constant variable: a25094 
o|substituted constant variable: a25096 
o|substituted constant variable: a25098 
o|substituted constant variable: a25100 
o|substituted constant variable: a25102 
o|substituted constant variable: a25104 
o|substituted constant variable: a25106 
o|substituted constant variable: a25115 
o|substituted constant variable: a25117 
o|inlining procedure: k24948 
o|inlining procedure: k25121 
o|inlining procedure: k25140 
o|inlining procedure: k25140 
o|inlining procedure: k25121 
o|inlining procedure: k25212 
o|inlining procedure: k25212 
o|inlining procedure: k25244 
o|inlining procedure: k25244 
o|inlining procedure: k25260 
o|inlining procedure: k25260 
o|inlining procedure: k25282 
o|inlining procedure: k25307 
o|inlining procedure: k25307 
o|substituted constant variable: a25320 
o|substituted constant variable: a25322 
o|inlining procedure: k25282 
o|inlining procedure: k25326 
o|inlining procedure: k25326 
o|inlining procedure: k25351 
o|inlining procedure: k25351 
o|inlining procedure: k25395 
o|inlining procedure: k25395 
o|inlining procedure: k25415 
o|inlining procedure: k25415 
o|inlining procedure: k25433 
o|inlining procedure: k25433 
o|inlining procedure: k25461 
o|inlining procedure: k25491 
o|inlining procedure: k25491 
o|inlining procedure: k25461 
o|inlining procedure: k25579 
o|inlining procedure: k25579 
o|substituted constant variable: a25596 
o|substituted constant variable: a25598 
o|substituted constant variable: saved552055215533 
o|inlining procedure: k25703 
o|inlining procedure: k25703 
o|inlining procedure: k25770 
o|inlining procedure: k25791 
o|inlining procedure: k25791 
o|inlining procedure: k25770 
o|inlining procedure: k25817 
o|inlining procedure: k25817 
o|inlining procedure: k25855 
o|inlining procedure: k25855 
o|inlining procedure: k25886 
o|inlining procedure: k25886 
o|inlining procedure: k25923 
o|inlining procedure: k25923 
o|substituted constant variable: a25983 
o|substituted constant variable: a25984 
o|inlining procedure: k25985 
o|inlining procedure: k25985 
o|inlining procedure: k26036 
o|inlining procedure: k26036 
o|inlining procedure: k26059 
o|inlining procedure: k26085 
o|inlining procedure: k26085 
o|inlining procedure: k26059 
o|inlining procedure: k26139 
o|inlining procedure: k26139 
o|substituted constant variable: c5729 
o|contracted procedure: "(library.scm:5000) extract5706" 
o|substituted constant variable: c5729 
o|inlining procedure: k26216 
o|inlining procedure: k26216 
o|substituted constant variable: c5729 
o|substituted constant variable: c5729 
o|inlining procedure: k26298 
o|inlining procedure: k26298 
o|inlining procedure: k26323 
o|inlining procedure: k26323 
o|inlining procedure: k26329 
o|inlining procedure: k26329 
o|inlining procedure: k26266 
o|inlining procedure: k26348 
o|inlining procedure: k26348 
o|inlining procedure: k26266 
o|substituted constant variable: a26396 
o|substituted constant variable: a26397 
o|inlining procedure: k26468 
o|inlining procedure: "(library.scm:5048) break5805" 
o|inlining procedure: k26468 
o|inlining procedure: k26497 
o|inlining procedure: k26497 
o|inlining procedure: k26533 
o|inlining procedure: k26533 
o|inlining procedure: k26556 
o|contracted procedure: "(library.scm:5069) g58155822" 
o|inlining procedure: k26556 
o|inlining procedure: k26597 
o|inlining procedure: k26597 
o|inlining procedure: k26651 
o|contracted procedure: "(library.scm:5136) g58865893" 
o|inlining procedure: k26651 
o|inlining procedure: k26689 
o|inlining procedure: k26689 
o|inlining procedure: k26725 
o|inlining procedure: k26725 
o|inlining procedure: k26742 
o|inlining procedure: k26742 
o|inlining procedure: k26754 
o|inlining procedure: k26754 
o|inlining procedure: k26766 
o|inlining procedure: k26766 
o|inlining procedure: k26778 
o|inlining procedure: k26778 
o|inlining procedure: k26790 
o|inlining procedure: k26790 
o|inlining procedure: k26802 
o|inlining procedure: k26802 
o|inlining procedure: k26814 
o|inlining procedure: k26814 
o|substituted constant variable: a26821 
o|substituted constant variable: a26823 
o|substituted constant variable: a26825 
o|substituted constant variable: a26827 
o|substituted constant variable: a26829 
o|substituted constant variable: a26831 
o|substituted constant variable: a26833 
o|substituted constant variable: a26835 
o|substituted constant variable: a26837 
o|substituted constant variable: a26839 
o|substituted constant variable: a26841 
o|substituted constant variable: a26843 
o|substituted constant variable: a26845 
o|substituted constant variable: a26847 
o|substituted constant variable: a26883 
o|substituted constant variable: a26885 
o|substituted constant variable: a26887 
o|inlining procedure: k26891 
o|inlining procedure: k26891 
o|inlining procedure: k26955 
o|inlining procedure: k26991 
o|inlining procedure: k26991 
o|inlining procedure: k27003 
o|inlining procedure: k27017 
o|inlining procedure: k27017 
o|inlining procedure: k27003 
o|inlining procedure: k26955 
o|inlining procedure: k27053 
o|inlining procedure: k27053 
o|inlining procedure: k27108 
o|propagated global variable: r2710934693 ##sys#current-exception-handler 
o|removed unused formal parameters: (convert?6052) 
o|inlining procedure: k27123 
o|inlining procedure: k27123 
o|removed unused parameter to known procedure: convert?6052 "(library.scm:5290) body60426051" 
o|inlining procedure: k27108 
o|inlining procedure: k27150 
o|inlining procedure: k27150 
o|removed unused parameter to known procedure: convert?6052 "(library.scm:5290) body60426051" 
o|inlining procedure: k27175 
o|inlining procedure: k27175 
o|inlining procedure: k27288 
o|contracted procedure: "(library.scm:5318) g61376146" 
o|inlining procedure: k27288 
o|inlining procedure: k27334 
o|contracted procedure: "(library.scm:5317) g61106119" 
o|inlining procedure: k27334 
o|inlining procedure: k27368 
o|contracted procedure: "(library.scm:5314) g60876094" 
o|inlining procedure: k27368 
o|inlining procedure: k27410 
o|inlining procedure: k27410 
o|inlining procedure: k27462 
o|contracted procedure: "(library.scm:5323) g61706179" 
o|inlining procedure: k27462 
o|inlining procedure: k27524 
o|inlining procedure: k27524 
o|inlining procedure: k27580 
o|inlining procedure: k27580 
o|inlining procedure: k27622 
o|inlining procedure: k27622 
o|inlining procedure: k27652 
o|inlining procedure: k27667 
o|inlining procedure: k27667 
o|inlining procedure: k27652 
o|inlining procedure: k27728 
o|inlining procedure: k27728 
o|substituted constant variable: a27753 
o|substituted constant variable: a27754 
o|inlining procedure: k27761 
o|inlining procedure: k27782 
o|inlining procedure: k27782 
o|inlining procedure: k27812 
o|inlining procedure: k27812 
o|inlining procedure: k27841 
o|inlining procedure: k27841 
o|inlining procedure: k27761 
o|inlining procedure: k27909 
(o x)|known list op on rest arg sublist: ##core#rest-cdr args6309 0 
o|inlining procedure: k27909 
o|inlining procedure: k27944 
o|inlining procedure: k27944 
o|inlining procedure: k27990 
o|inlining procedure: k28013 
o|inlining procedure: k28013 
o|inlining procedure: k27990 
o|inlining procedure: k28050 
o|inlining procedure: k28050 
o|inlining procedure: k28064 
o|inlining procedure: k28064 
o|inlining procedure: k28082 
o|inlining procedure: k28082 
o|inlining procedure: k28100 
o|inlining procedure: k28100 
o|inlining procedure: k28118 
o|inlining procedure: k28118 
o|inlining procedure: k28136 
o|inlining procedure: k28136 
o|inlining procedure: k28154 
o|inlining procedure: k28154 
o|inlining procedure: k28172 
o|inlining procedure: k28172 
o|inlining procedure: k28190 
o|inlining procedure: k28190 
o|inlining procedure: k28208 
o|inlining procedure: k28208 
o|inlining procedure: k28226 
o|inlining procedure: k28226 
o|inlining procedure: k28244 
o|inlining procedure: k28244 
o|inlining procedure: k28262 
o|inlining procedure: k28262 
o|inlining procedure: k28280 
o|inlining procedure: k28280 
o|inlining procedure: k28298 
o|inlining procedure: k28298 
o|inlining procedure: k28316 
o|inlining procedure: k28316 
o|inlining procedure: k28334 
o|inlining procedure: k28334 
o|inlining procedure: k28352 
o|inlining procedure: k28352 
o|inlining procedure: k28370 
o|inlining procedure: k28370 
o|inlining procedure: k28388 
o|inlining procedure: k28388 
o|inlining procedure: k28406 
o|inlining procedure: k28406 
o|inlining procedure: k28424 
o|inlining procedure: k28424 
o|inlining procedure: k28442 
o|inlining procedure: k28442 
o|inlining procedure: k28460 
o|inlining procedure: k28460 
o|inlining procedure: k28478 
o|inlining procedure: k28478 
o|inlining procedure: k28496 
o|inlining procedure: k28496 
o|inlining procedure: k28514 
o|inlining procedure: k28514 
o|inlining procedure: k28532 
o|inlining procedure: k28532 
o|inlining procedure: k28564 
o|inlining procedure: k28564 
o|substituted constant variable: a28582 
o|substituted constant variable: a28584 
o|substituted constant variable: a28586 
o|substituted constant variable: a28588 
o|substituted constant variable: a28590 
o|substituted constant variable: a28592 
o|substituted constant variable: a28594 
o|substituted constant variable: a28596 
o|substituted constant variable: a28598 
o|substituted constant variable: a28600 
o|substituted constant variable: a28602 
o|substituted constant variable: a28604 
o|substituted constant variable: a28606 
o|substituted constant variable: a28608 
o|substituted constant variable: a28610 
o|substituted constant variable: a28612 
o|substituted constant variable: a28614 
o|substituted constant variable: a28616 
o|substituted constant variable: a28618 
o|substituted constant variable: a28620 
o|substituted constant variable: a28622 
o|substituted constant variable: a28624 
o|substituted constant variable: a28626 
o|substituted constant variable: a28628 
o|substituted constant variable: a28630 
o|substituted constant variable: a28632 
o|substituted constant variable: a28634 
o|substituted constant variable: a28636 
o|substituted constant variable: a28638 
o|substituted constant variable: a28640 
o|substituted constant variable: a28642 
o|substituted constant variable: a28644 
o|substituted constant variable: a28646 
o|substituted constant variable: a28648 
o|substituted constant variable: a28650 
o|substituted constant variable: a28652 
o|substituted constant variable: a28654 
o|substituted constant variable: a28656 
o|substituted constant variable: a28658 
o|substituted constant variable: a28660 
o|substituted constant variable: a28662 
o|substituted constant variable: a28664 
o|substituted constant variable: a28666 
o|substituted constant variable: a28668 
o|substituted constant variable: a28670 
o|substituted constant variable: a28672 
o|substituted constant variable: a28674 
o|substituted constant variable: a28676 
o|substituted constant variable: a28678 
o|substituted constant variable: a28680 
o|substituted constant variable: a28682 
o|substituted constant variable: a28684 
o|substituted constant variable: a28686 
o|substituted constant variable: a28688 
o|substituted constant variable: a28690 
o|substituted constant variable: a28692 
o|inlining procedure: k28772 
o|inlining procedure: k28772 
o|inlining procedure: k28810 
o|inlining procedure: k28810 
o|inlining procedure: k28832 
o|inlining procedure: k28832 
o|inlining procedure: k28890 
o|inlining procedure: k28890 
o|contracted procedure: "(library.scm:5636) fetch6552" 
o|contracted procedure: "(library.scm:5653) free6571" 
o|inlining procedure: k28937 
o|inlining procedure: k28937 
o|inlining procedure: k28954 
o|inlining procedure: k28954 
o|contracted procedure: "(library.scm:5648) fetch6570" 
o|propagated global variable: ct6672 ##sys#current-thread 
o|inlining procedure: k29160 
o|inlining procedure: k29160 
o|inlining procedure: k29184 
o|inlining procedure: k29208 
o|inlining procedure: k29208 
o|inlining procedure: k29184 
o|inlining procedure: k29239 
o|inlining procedure: k29239 
o|inlining procedure: k29298 
o|inlining procedure: k29298 
o|inlining procedure: k29326 
o|inlining procedure: k29326 
o|inlining procedure: k29383 
o|inlining procedure: k29383 
o|inlining procedure: k29423 
o|inlining procedure: k29435 
o|inlining procedure: k29435 
o|inlining procedure: k29423 
o|inlining procedure: k29462 
o|inlining procedure: k29462 
o|inlining procedure: k29508 
o|inlining procedure: k29508 
o|substituted constant variable: a29566 
o|inlining procedure: k29559 
o|inlining procedure: k29559 
o|substituted constant variable: a29579 
o|inlining procedure: k29590 
o|inlining procedure: k29630 
o|inlining procedure: k29668 
o|inlining procedure: k29668 
o|inlining procedure: k29630 
o|inlining procedure: k29762 
o|inlining procedure: k29762 
o|substituted constant variable: a29823 
o|substituted constant variable: a29825 
o|substituted constant variable: a29833 
o|substituted constant variable: a29838 
o|substituted constant variable: a29840 
o|substituted constant variable: a29854 
o|inlining procedure: k29847 
o|inlining procedure: k29847 
o|substituted constant variable: a29867 
o|inlining procedure: k29590 
o|substituted constant variable: a29882 
o|substituted constant variable: a29884 
o|inlining procedure: k29898 
o|inlining procedure: k29898 
o|inlining procedure: k29994 
o|inlining procedure: k30003 
o|inlining procedure: k30003 
o|inlining procedure: k29994 
o|contracted procedure: "(library.scm:6105) get6930" 
o|inlining procedure: k30070 
o|inlining procedure: k30070 
o|inlining procedure: k30084 
o|inlining procedure: k30084 
o|contracted procedure: "(library.scm:6134) fetch-arg6950" 
o|inlining procedure: k30157 
o|inlining procedure: k30177 
o|inlining procedure: k30177 
o|inlining procedure: k30204 
o|inlining procedure: k30204 
o|inlining procedure: k30157 
o|inlining procedure: k30227 
o|inlining procedure: k30227 
o|inlining procedure: k30270 
o|inlining procedure: k30270 
o|inlining procedure: k30298 
o|inlining procedure: k30298 
o|inlining procedure: k30336 
o|inlining procedure: k30336 
o|inlining procedure: k30374 
o|inlining procedure: k30374 
o|inlining procedure: k30386 
o|inlining procedure: k30386 
o|inlining procedure: k30415 
o|inlining procedure: k30415 
o|inlining procedure: k30515 
o|inlining procedure: k30515 
o|inlining procedure: k30546 
o|inlining procedure: k30546 
o|inlining procedure: k30568 
o|inlining procedure: k30568 
o|inlining procedure: k30608 
o|inlining procedure: k30608 
o|inlining procedure: k30633 
o|inlining procedure: k30633 
o|inlining procedure: k30655 
o|inlining procedure: k30655 
o|inlining procedure: k30687 
o|inlining procedure: k30687 
o|inlining procedure: k30719 
o|inlining procedure: k30719 
o|inlining procedure: k30751 
o|inlining procedure: k30751 
o|inlining procedure: k30783 
o|inlining procedure: k30783 
o|substituted constant variable: a30831 
o|substituted constant variable: a30833 
o|substituted constant variable: a30835 
o|substituted constant variable: a30837 
o|substituted constant variable: a30839 
o|substituted constant variable: a30841 
o|substituted constant variable: a30843 
o|substituted constant variable: a30845 
o|substituted constant variable: a30847 
o|substituted constant variable: a30849 
o|inlining procedure: k30850 
o|inlining procedure: k30850 
o|inlining procedure: k30905 
o|inlining procedure: k30905 
o|inlining procedure: k30922 
o|inlining procedure: k30946 
o|inlining procedure: k30946 
o|inlining procedure: k30922 
o|inlining procedure: k30989 
o|inlining procedure: k30989 
o|inlining procedure: k31052 
o|inlining procedure: k31052 
o|inlining procedure: k31084 
o|inlining procedure: "(library.scm:6512) pstr7313" 
o|substituted constant variable: a31105 
o|inlining procedure: k31084 
o|inlining procedure: "(library.scm:6514) pstr7313" 
o|substituted constant variable: a31127 
o|inlining procedure: k31128 
o|inlining procedure: "(library.scm:6516) pstr7313" 
o|substituted constant variable: a31149 
o|inlining procedure: k31128 
o|inlining procedure: "(library.scm:6517) pstr7313" 
o|inlining procedure: "(library.scm:6543) pstr7313" 
o|inlining procedure: "(library.scm:6541) pstr7313" 
o|inlining procedure: "(library.scm:6539) pchr7314" 
o|inlining procedure: "(library.scm:6537) pstr7313" 
o|inlining procedure: "(library.scm:6533) pstr7313" 
o|inlining procedure: "(library.scm:6531) pchr7314" 
o|inlining procedure: "(library.scm:6529) pstr7313" 
o|inlining procedure: "(library.scm:6525) pstr7313" 
o|inlining procedure: "(library.scm:6523) pstr7313" 
o|inlining procedure: "(library.scm:6520) pstr7313" 
o|inlining procedure: k31355 
o|inlining procedure: k31377 
o|inlining procedure: k31377 
o|contracted procedure: "(library.scm:6621) get-config7418" 
o|inlining procedure: k31322 
o|inlining procedure: k31322 
o|substituted constant variable: a31335 
o|inlining procedure: k31413 
o|inlining procedure: k31413 
o|inlining procedure: k31355 
o|propagated global variable: r3135635034 ##sys#build-version 
o|inlining procedure: k31448 
o|inlining procedure: k31448 
o|inlining procedure: k31476 
o|inlining procedure: k31476 
o|inlining procedure: k31547 
o|inlining procedure: k31547 
o|substituted constant variable: a31562 
o|substituted constant variable: a31564 
o|removed side-effect free assignment to unused variable: prefix7532 
o|inlining procedure: k31597 
o|inlining procedure: k31597 
o|inlining procedure: k31612 
o|inlining procedure: k31612 
o|contracted procedure: "(library.scm:6712) err7531" 
o|inlining procedure: k31631 
o|inlining procedure: k31631 
o|inlining procedure: k31710 
o|contracted procedure: "(library.scm:6755) g75637570" 
o|inlining procedure: k31694 
o|inlining procedure: k31694 
o|inlining procedure: k31710 
o|inlining procedure: k31746 
o|inlining procedure: k31746 
o|inlining procedure: k31777 
o|inlining procedure: k31777 
o|inlining procedure: k31823 
o|inlining procedure: k31823 
o|inlining procedure: k31854 
o|inlining procedure: k31854 
o|inlining procedure: k31866 
o|inlining procedure: k31866 
o|inlining procedure: k31878 
o|inlining procedure: k31878 
o|inlining procedure: k31887 
o|inlining procedure: k31887 
o|inlining procedure: k31896 
o|inlining procedure: k31896 
o|substituted constant variable: a31936 
o|contracted procedure: "(library.scm:6692) g75007501" 
o|inlining procedure: k31991 
o|inlining procedure: k31991 
o|inlining procedure: k32036 
o|inlining procedure: k32036 
o|inlining procedure: k32058 
o|inlining procedure: k32075 
o|contracted procedure: "(library.scm:6675) g74647471" 
o|inlining procedure: k32075 
o|inlining procedure: k32058 
o|inlining procedure: k32101 
o|inlining procedure: k32101 
o|inlining procedure: k32175 
o|inlining procedure: k32175 
o|inlining procedure: k32222 
o|inlining procedure: k32222 
o|inlining procedure: k32240 
o|inlining procedure: k32240 
o|inlining procedure: k32296 
o|inlining procedure: k32296 
o|inlining procedure: k32324 
o|inlining procedure: k32348 
o|inlining procedure: k32348 
o|inlining procedure: k32378 
o|contracted procedure: "(library.scm:5215) g59545961" 
o|inlining procedure: k32378 
o|inlining procedure: k32324 
o|inlining procedure: k32433 
o|inlining procedure: k32433 
o|inlining procedure: k32484 
o|inlining procedure: k32484 
o|inlining procedure: k32511 
o|inlining procedure: k32511 
o|inlining procedure: k32536 
o|inlining procedure: k32536 
o|inlining procedure: k32616 
o|inlining procedure: k32616 
o|inlining procedure: k32642 
o|inlining procedure: k32642 
o|inlining procedure: k32723 
o|inlining procedure: k32723 
o|inlining procedure: k32742 
o|inlining procedure: k32742 
o|inlining procedure: k32887 
o|inlining procedure: k32887 
o|inlining procedure: k32896 
o|inlining procedure: k32896 
o|inlining procedure: k32905 
o|inlining procedure: k32905 
o|inlining procedure: k32921 
o|inlining procedure: k32921 
o|inlining procedure: k32947 
o|inlining procedure: k32976 
o|inlining procedure: k32976 
o|inlining procedure: k32947 
o|inlining procedure: k33011 
o|inlining procedure: k33011 
o|inlining procedure: k33050 
o|inlining procedure: k33050 
o|inlining procedure: k33111 
o|inlining procedure: k33111 
o|inlining procedure: k33126 
o|inlining procedure: k33126 
o|inlining procedure: k33165 
o|inlining procedure: k33165 
o|inlining procedure: k33223 
o|inlining procedure: k33223 
o|inlining procedure: k33238 
o|inlining procedure: k33238 
o|inlining procedure: k33274 
o|inlining procedure: k33274 
o|substituted constant variable: sblen3931 
o|substituted constant variable: sblen3931 
o|replaced variables: 6551 
o|removed binding forms: 1950 
o|substituted constant variable: r939633376 
o|substituted constant variable: r940233378 
o|inlining procedure: k9721 
o|substituted constant variable: r978533392 
o|substituted constant variable: r993833403 
o|substituted constant variable: r995033406 
o|substituted constant variable: r1005133411 
o|substituted constant variable: r1011533416 
o|substituted constant variable: r1018833419 
o|substituted constant variable: r1024233423 
o|substituted constant variable: r1035833432 
o|substituted constant variable: r1055033441 
o|substituted constant variable: r1062733446 
o|substituted constant variable: r1111233491 
o|substituted constant variable: r1111233491 
o|substituted constant variable: r1112933497 
o|substituted constant variable: r1112933497 
o|substituted constant variable: r1115233502 
o|substituted constant variable: r1115233502 
o|substituted constant variable: r1117033509 
o|substituted constant variable: r1117033509 
o|substituted constant variable: r1119433515 
o|substituted constant variable: r1119433515 
o|substituted constant variable: r1122033521 
o|substituted constant variable: r1122033521 
o|substituted constant variable: r1132333532 
o|substituted constant variable: r1185433556 
o|substituted constant variable: r1221733577 
o|substituted constant variable: loc1772 
o|substituted constant variable: loc1783 
o|substituted constant variable: loc1794 
o|substituted constant variable: loc1805 
o|substituted constant variable: r1240633594 
o|substituted constant variable: loc1824 
o|substituted constant variable: loc1835 
o|substituted constant variable: loc1846 
o|substituted constant variable: loc1857 
o|substituted constant variable: loc1868 
o|substituted constant variable: loc1879 
o|substituted constant variable: loc1890 
o|substituted constant variable: loc1899 
o|substituted constant variable: loc1909 
o|substituted constant variable: loc1920 
o|substituted constant variable: loc1929 
o|substituted constant variable: loc1937 
o|substituted constant variable: loc1945 
o|substituted constant variable: loc1953 
o|substituted constant variable: loc1961 
o|substituted constant variable: loc1969 
o|substituted constant variable: loc1977 
o|substituted constant variable: loc1985 
o|substituted constant variable: loc1993 
o|substituted constant variable: loc2001 
o|substituted constant variable: loc2011 
o|substituted constant variable: loc2020 
o|substituted constant variable: loc2028 
o|substituted constant variable: loc2036 
o|substituted constant variable: loc2044 
o|substituted constant variable: loc2052 
o|substituted constant variable: loc2060 
o|substituted constant variable: loc2068 
o|substituted constant variable: loc2078 
o|substituted constant variable: loc2087 
o|substituted constant variable: loc2095 
o|substituted constant variable: loc2103 
o|substituted constant variable: loc2111 
o|inlining procedure: k13113 
o|inlining procedure: k13113 
o|substituted constant variable: r1312733668 
o|substituted constant variable: r1320833673 
o|substituted constant variable: r1337233687 
o|converted assignments to bindings: (deliver2292) 
o|substituted constant variable: n2490 
o|substituted constant variable: d2491 
o|substituted constant variable: r1464633762 
o|substituted constant variable: r1465533764 
o|substituted constant variable: r1468833768 
o|substituted constant variable: r1469733770 
o|substituted constant variable: r1557433818 
o|substituted constant variable: r1568233825 
o|substituted constant variable: r1574733829 
o|substituted constant variable: r1592233836 
o|substituted constant variable: r1605033838 
o|substituted constant variable: r1605033838 
o|substituted constant variable: r1605033840 
o|substituted constant variable: r1605033840 
o|inlining procedure: k16086 
o|inlining procedure: k16086 
o|substituted constant variable: r1611433847 
o|substituted constant variable: r1613033850 
o|substituted constant variable: r1613033851 
o|substituted constant variable: r1609333856 
o|removed side-effect free assignment to unused variable: make-nan2928 
o|substituted constant variable: r1632033868 
o|substituted constant variable: r1634033870 
o|substituted constant variable: r1636233872 
o|substituted constant variable: r1637333874 
o|substituted constant variable: r1641033877 
o|substituted constant variable: r1643333878 
o|substituted constant variable: r1643333879 
o|substituted constant variable: r1638733880 
o|substituted constant variable: r1649633893 
o|substituted constant variable: r1648433894 
o|substituted constant variable: r1644533910 
o|substituted constant variable: r1676433920 
o|substituted constant variable: r1675433921 
o|substituted constant variable: r1674233922 
o|substituted constant variable: r1682833930 
o|substituted constant variable: r1681033931 
o|substituted constant variable: r1680033932 
o|substituted constant variable: r1698433943 
o|substituted constant variable: r1706533947 
o|substituted constant variable: r1706533947 
o|substituted constant variable: r1706533949 
o|substituted constant variable: r1706533949 
o|substituted constant variable: r1708833954 
o|substituted constant variable: r1708833954 
o|substituted constant variable: r1717533962 
o|substituted constant variable: r1717533962 
o|substituted constant variable: r1715233965 
o|substituted constant variable: r1723133966 
o|substituted constant variable: r1723133967 
o|substituted constant variable: r1700533968 
o|substituted constant variable: r1726933973 
o|substituted constant variable: r1724733974 
o|substituted constant variable: r1729233978 
o|substituted constant variable: r1736733982 
o|substituted constant variable: r1735233983 
o|substituted constant variable: r1741433986 
o|substituted constant variable: r1753433989 
o|substituted constant variable: r1757833993 
o|substituted constant variable: r1762233997 
o|substituted constant variable: r1763533999 
o|substituted constant variable: r1773234006 
o|substituted constant variable: r1780534010 
o|substituted constant variable: r1789134015 
o|substituted constant variable: r1790334017 
o|substituted constant variable: r1791234020 
o|substituted constant variable: r1793034023 
o|substituted constant variable: r1821434046 
o|substituted constant variable: r1826234048 
o|substituted constant variable: r1836634057 
o|substituted constant variable: r1869934068 
o|substituted constant variable: r1883034074 
o|removed call to pure procedure with unused result: "(library.scm:3089) ##sys#slot" 
o|substituted constant variable: r1917334094 
o|removed call to pure procedure with unused result: "(library.scm:3100) ##sys#slot" 
o|converted assignments to bindings: (continuation3838) 
o|substituted constant variable: r1933934108 
o|removed unused formal parameters: (%convert?39743989) 
o|removed unused parameter to known procedure: %convert?39743989 "(library.scm:3363) def-set?39793988" 
o|removed unused parameter to known procedure: %convert?39743989 "(library.scm:3363) def-set?39793988" 
o|removed unused formal parameters: (%convert?39994014) 
o|removed unused parameter to known procedure: %convert?39994014 "(library.scm:3373) def-set?40044013" 
o|removed unused parameter to known procedure: %convert?39994014 "(library.scm:3373) def-set?40044013" 
o|removed unused formal parameters: (%convert?40244039) 
o|removed unused parameter to known procedure: %convert?40244039 "(library.scm:3383) def-set?40294038" 
o|removed unused parameter to known procedure: %convert?40244039 "(library.scm:3383) def-set?40294038" 
o|substituted constant variable: r1964534136 
o|substituted constant variable: r1970934141 
o|substituted constant variable: r1970934141 
o|substituted constant variable: r1970934143 
o|substituted constant variable: r1970934143 
o|substituted constant variable: r1995134153 
o|substituted constant variable: r2000434156 
o|substituted constant variable: r2009834162 
o|substituted constant variable: r2013634164 
o|substituted constant variable: r2017034166 
o|substituted constant variable: r2023034170 
o|inlining procedure: k20553 
o|substituted constant variable: r2062034185 
o|inlining procedure: k20631 
o|substituted constant variable: r2145934236 
o|substituted constant variable: tok485434264 
o|inlining procedure: k21790 
o|converted assignments to bindings: (starting-line4617) 
o|substituted constant variable: r2189034306 
o|substituted constant variable: r2189034306 
o|substituted constant variable: r2222834342 
o|substituted constant variable: r2224734346 
o|substituted constant variable: r2239534360 
o|substituted constant variable: r2239534361 
o|inlining procedure: k22488 
o|inlining procedure: k22488 
o|inlining procedure: k22488 
o|substituted constant variable: r2248634369 
o|substituted constant variable: r2246834370 
o|removed side-effect free assignment to unused variable: build-symbol4511 
o|removed side-effect free assignment to unused variable: build-keyword4512 
o|substituted constant variable: r2294034404 
o|substituted constant variable: r2310234415 
o|substituted constant variable: r2333634436 
o|substituted constant variable: r2360634462 
o|substituted constant variable: r2362534463 
o|substituted constant variable: r2362534463 
o|substituted constant variable: r2362534465 
o|substituted constant variable: r2362534465 
o|substituted constant variable: r2380534472 
o|substituted constant variable: r2382934475 
o|substituted constant variable: r2381734476 
o|converted assignments to bindings: (hex5046) 
o|substituted constant variable: r2402734487 
o|propagated global variable: port511434490 ##sys#standard-output 
o|substituted constant variable: r2454934513 
o|substituted constant variable: r2456134515 
o|substituted constant variable: r2457634517 
o|substituted constant variable: r2457634518 
o|substituted constant variable: r2461734520 
o|substituted constant variable: r2463234522 
o|substituted constant variable: r2463234523 
o|inlining procedure: k24644 
o|substituted constant variable: r2464534526 
o|substituted constant variable: r2464534526 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r2468734532 
o|inlining procedure: k25149 
o|substituted constant variable: r2539634586 
o|substituted constant variable: r2541634588 
o|inlining procedure: k25560 
o|substituted constant variable: r2592434612 
o|converted assignments to bindings: (copy&append5633) 
o|substituted constant variable: r2614034623 
o|converted assignments to bindings: (break5805) 
o|substituted constant variable: r2669034655 
o|substituted constant variable: r2669034655 
o|substituted constant variable: r2669034657 
o|substituted constant variable: r2669034657 
o|substituted constant variable: r2674334663 
o|substituted constant variable: r2675534665 
o|substituted constant variable: r2676734667 
o|substituted constant variable: r2677934669 
o|substituted constant variable: r2679134671 
o|substituted constant variable: r2680334673 
o|substituted constant variable: r2681534675 
o|substituted constant variable: r2681534676 
o|substituted constant variable: r2699234682 
o|substituted constant variable: r2699234682 
o|inlining procedure: k27017 
o|inlining procedure: k27017 
o|removed unused formal parameters: (%convert?60406055) 
o|removed unused parameter to known procedure: %convert?60406055 "(library.scm:5290) def-set?60456054" 
o|removed unused parameter to known procedure: %convert?60406055 "(library.scm:5290) def-set?60456054" 
o|substituted constant variable: r2717634699 
o|substituted constant variable: r2752534711 
o|substituted constant variable: r2762334716 
o|substituted constant variable: r2765334720 
o|substituted constant variable: r2801434746 
o|substituted constant variable: r2801434746 
o|substituted constant variable: r2805134751 
o|substituted constant variable: r2805134751 
o|substituted constant variable: r2856534809 
o|substituted constant variable: r2856534809 
o|substituted constant variable: r2881134814 
o|substituted constant variable: r2883334816 
o|substituted constant variable: r2889134817 
o|substituted constant variable: r2893834821 
o|substituted constant variable: r2893834821 
o|substituted constant variable: r2895534823 
o|substituted constant variable: r2918534832 
o|inlining procedure: k29263 
o|inlining procedure: k29517 
o|converted assignments to bindings: (get/clear-str6817) 
o|substituted constant variable: r2999534870 
o|inlining procedure: k30157 
o|inlining procedure: k30157 
o|substituted constant variable: r3022834900 
o|substituted constant variable: r3092334942 
o|removed side-effect free assignment to unused variable: pstr7313 
o|removed side-effect free assignment to unused variable: pchr7314 
o|substituted constant variable: r3105334945 
o|substituted constant variable: r3105334945 
o|substituted constant variable: str731834951 
o|substituted constant variable: str731834957 
o|substituted constant variable: str731834963 
o|substituted constant variable: str731834969 
o|substituted constant variable: str731834974 
o|substituted constant variable: str731834979 
o|substituted constant variable: chr731934984 
o|substituted constant variable: str731834989 
o|substituted constant variable: str731834994 
o|substituted constant variable: chr731934999 
o|substituted constant variable: str731835004 
o|substituted constant variable: str731835009 
o|substituted constant variable: str731835014 
o|substituted constant variable: str731835019 
o|substituted constant variable: r3137835024 
o|substituted constant variable: r3137835024 
o|substituted constant variable: r3132335028 
o|converted assignments to bindings: (str7423) 
o|substituted constant variable: r3141435030 
o|substituted constant variable: r3141435030 
o|substituted constant variable: r3141435032 
o|substituted constant variable: r3141435032 
o|substituted constant variable: r3144935035 
o|substituted constant variable: r3174735052 
o|substituted constant variable: r3186735061 
o|substituted constant variable: r3189735067 
o|inlining procedure: k32036 
o|substituted constant variable: r3205935077 
o|substituted constant variable: r3222335082 
o|substituted constant variable: r3251235098 
o|substituted constant variable: r3253735100 
o|substituted constant variable: r3264335106 
o|substituted constant variable: r3272435108 
o|substituted constant variable: r3289735117 
o|substituted constant variable: r3290635119 
o|substituted constant variable: r3292235121 
o|substituted constant variable: r3297735124 
o|converted assignments to bindings: (lookup-char3690) 
o|simplifications: ((let . 10)) 
o|replaced variables: 670 
o|removed binding forms: 5495 
o|removed conditional forms: 1 
o|inlining procedure: k9703 
o|substituted constant variable: r972235154 
o|substituted constant variable: r972235154 
o|inlining procedure: k10893 
o|inlining procedure: k10893 
o|inlining procedure: k10893 
o|inlining procedure: k11368 
o|inlining procedure: k11384 
o|inlining procedure: k11400 
o|inlining procedure: k11416 
o|inlining procedure: k11432 
o|inlining procedure: k11448 
o|inlining procedure: k11464 
o|inlining procedure: k11480 
o|inlining procedure: k11605 
o|inlining procedure: k11640 
o|inlining procedure: k11640 
o|inlining procedure: k11895 
o|inlining procedure: k11895 
o|inlining procedure: k12005 
o|inlining procedure: k12005 
o|inlining procedure: k12314 
o|inlining procedure: k12338 
o|inlining procedure: k12362 
o|inlining procedure: k12386 
o|inlining procedure: k12435 
o|inlining procedure: k12459 
o|inlining procedure: k12483 
o|inlining procedure: k12507 
o|inlining procedure: k12531 
o|inlining procedure: k12555 
o|inlining procedure: k12579 
o|inlining procedure: k12597 
o|inlining procedure: k12621 
o|inlining procedure: k12645 
o|inlining procedure: k12663 
o|inlining procedure: k12681 
o|inlining procedure: k12699 
o|inlining procedure: k12717 
o|inlining procedure: k12735 
o|inlining procedure: k12753 
o|inlining procedure: k12771 
o|inlining procedure: k12789 
o|inlining procedure: k12807 
o|inlining procedure: k12825 
o|inlining procedure: k12849 
o|inlining procedure: k12867 
o|inlining procedure: k12885 
o|inlining procedure: k12903 
o|inlining procedure: k12921 
o|inlining procedure: k12939 
o|inlining procedure: k12957 
o|inlining procedure: k12975 
o|inlining procedure: k12999 
o|inlining procedure: k13017 
o|inlining procedure: k13035 
o|inlining procedure: k13053 
o|inlining procedure: k13071 
o|inlining procedure: k13314 
o|inlining procedure: k13426 
o|inlining procedure: k13495 
o|inlining procedure: k13587 
o|inlining procedure: k13593 
o|inlining procedure: k13696 
o|inlining procedure: k13919 
o|inlining procedure: k13989 
o|inlining procedure: k14034 
o|inlining procedure: k14071 
o|inlining procedure: k14102 
o|inlining procedure: k14102 
o|inlining procedure: k14115 
o|inlining procedure: k14283 
o|inlining procedure: k14424 
o|inlining procedure: k15066 
o|inlining procedure: k15090 
o|inlining procedure: k15290 
o|inlining procedure: k15413 
o|inlining procedure: k15421 
o|inlining procedure: k15459 
o|inlining procedure: k15477 
o|inlining procedure: k15630 
o|inlining procedure: k15659 
o|inlining procedure: k15877 
o|inlining procedure: k15884 
o|inlining procedure: k16349 
o|inlining procedure: k16857 
o|inlining procedure: k16995 
o|inlining procedure: k17261 
o|inlining procedure: k17261 
o|inlining procedure: k17303 
o|inlining procedure: k17317 
o|inlining procedure: k17323 
o|inlining procedure: k17382 
o|inlining procedure: k17390 
o|inlining procedure: k17718 
o|inlining procedure: k17725 
o|inlining procedure: k17725 
o|inlining procedure: k17758 
o|inlining procedure: k18041 
o|inlining procedure: k18041 
o|contracted procedure: k19070 
o|contracted procedure: k19166 
o|inlining procedure: k19723 
o|inlining procedure: k19723 
o|inlining procedure: k19723 
o|inlining procedure: k19985 
o|propagated global variable: r1998635991 ##sys#standard-output 
o|propagated global variable: r1998635991 ##sys#standard-output 
o|inlining procedure: k20532 
o|propagated global variable: r2053335999 ##sys#standard-input 
o|propagated global variable: r2053335999 ##sys#standard-input 
o|inlining procedure: k20644 
o|propagated global variable: r2064536001 ##sys#standard-input 
o|propagated global variable: r2064536001 ##sys#standard-input 
o|inlining procedure: k20662 
o|propagated global variable: r2066336003 ##sys#standard-input 
o|propagated global variable: r2066336003 ##sys#standard-input 
o|inlining procedure: k21375 
o|inlining procedure: k24135 
o|propagated global variable: r2413636030 ##sys#standard-output 
o|propagated global variable: r2413636030 ##sys#standard-output 
o|inlining procedure: k24153 
o|propagated global variable: r2415436032 ##sys#standard-output 
o|propagated global variable: r2415436032 ##sys#standard-output 
o|inlining procedure: k24531 
o|substituted constant variable: r2464535502 
o|folded constant expression: (scheme#not (quote #f)) 
o|inlining procedure: k26857 
o|inlining procedure: k28948 
o|inlining procedure: k28948 
o|inlining procedure: k29332 
o|inlining procedure: "(library.scm:5931) ##sys#format-here-doc-warning" 
o|inlining procedure: k29567 
o|inlining procedure: k29567 
o|inlining procedure: "(library.scm:5965) ##sys#format-here-doc-warning" 
o|inlining procedure: k29855 
o|inlining procedure: k29855 
o|inlining procedure: k30267 
o|inlining procedure: k30565 
o|inlining procedure: k30565 
o|inlining procedure: k30934 
o|inlining procedure: k30934 
o|inlining procedure: k31716 
o|inlining procedure: k31716 
o|inlining procedure: k32243 
o|inlining procedure: k32884 
o|inlining procedure: k32884 
o|replaced variables: 9 
o|removed binding forms: 870 
o|substituted constant variable: r970435724 
o|substituted constant variable: r1136935765 
o|substituted constant variable: r1138535767 
o|substituted constant variable: r1140135769 
o|substituted constant variable: r1141735771 
o|substituted constant variable: r1143335773 
o|substituted constant variable: r1144935775 
o|substituted constant variable: r1146535777 
o|substituted constant variable: r1148135779 
o|substituted constant variable: r1160635787 
o|substituted constant variable: r1164135791 
o|contracted procedure: k13243 
o|contracted procedure: k13248 
o|contracted procedure: k13308 
o|contracted procedure: k13681 
o|contracted procedure: k13690 
o|contracted procedure: k13795 
o|contracted procedure: k13800 
o|contracted procedure: k13805 
o|contracted procedure: k13810 
o|contracted procedure: k13815 
o|contracted procedure: k13820 
o|contracted procedure: k13852 
o|contracted procedure: k13876 
o|contracted procedure: k13891 
o|contracted procedure: k13971 
o|contracted procedure: k14016 
o|contracted procedure: k14065 
o|substituted constant variable: r1410335881 
o|contracted procedure: k14407 
o|contracted procedure: k15896 
o|contracted procedure: k15901 
o|contracted procedure: k16033 
o|contracted procedure: k16195 
o|contracted procedure: k16303 
o|contracted procedure: k16394 
o|contracted procedure: k17012 
o|contracted procedure: k17029 
o|contracted procedure: k17170 
o|substituted constant variable: r1726235923 
o|contracted procedure: k17521 
o|substituted constant variable: r1772635934 
o|substituted constant variable: r1772635935 
o|substituted constant variable: r1804235939 
o|inlining procedure: k21745 
o|inlining procedure: k23250 
o|substituted constant variable: r2701835556 
o|removed side-effect free assignment to unused variable: ##sys#format-here-doc-warning 
o|substituted constant variable: r3026836132 
o|substituted constant variable: r3056636142 
o|substituted constant variable: r3056636142 
o|substituted constant variable: r3093536143 
o|substituted constant variable: r3093536143 
o|substituted constant variable: r3093536144 
o|substituted constant variable: r3093536144 
o|inlining procedure: k31550 
o|inlining procedure: k31550 
o|substituted constant variable: r3224436171 
o|substituted constant variable: r3288536179 
o|substituted constant variable: r3288536179 
o|substituted constant variable: r3288536181 
o|substituted constant variable: r3288536181 
o|simplifications: ((let . 4)) 
o|replaced variables: 19 
o|removed binding forms: 150 
o|removed conditional forms: 11 
o|substituted constant variable: r2174636327 
o|substituted constant variable: r2174636327 
o|substituted constant variable: r2325136338 
o|substituted constant variable: r3155136430 
o|simplifications: ((if . 1) (let . 1)) 
o|removed binding forms: 83 
o|removed conditional forms: 3 
o|simplifications: ((let . 1)) 
o|replaced variables: 2 
o|removed binding forms: 3 
o|removed binding forms: 1 
o|simplifications: ((if . 270) (let . 197) (##core#call . 2780)) 
o|  call simplifications:
o|    scheme#cdar	2
o|    scheme#set-cdr!	6
o|    scheme#list-tail
o|    scheme#set-car!	7
o|    ##sys#make-vector
o|    scheme#vector?
o|    ##sys#generic-structure?
o|    chicken.fixnum#fx/
o|    ##sys#foreign-string-argument
o|    scheme#read-char
o|    scheme#string-length	4
o|    scheme#string-ref	3
o|    ##sys#list	6
o|    ##sys#context-switch	2
o|    ##sys#foreign-pointer-argument	3
o|    ##sys#null-pointer?	2
o|    scheme#caddr	3
o|    scheme#write-char
o|    scheme#equal?	2
o|    scheme#memv	2
o|    scheme#caar	3
o|    scheme#cddr	3
o|    ##sys#check-structure	2
o|    scheme#string?	5
o|    scheme#symbol?	7
o|    ##sys#apply	2
o|    ##sys#byte
o|    scheme#char-upper-case?
o|    scheme#char<?
o|    ##sys#void	4
o|    scheme#string	4
o|    scheme#member	8
o|    chicken.fixnum#fxior	13
o|    scheme#string=?	7
o|    scheme#char-numeric?	7
o|    scheme#char<=?
o|    chicken.fixnum#fx*	9
o|    scheme#eof-object?	25
o|    scheme#char=?	12
o|    scheme#char-whitespace?	7
o|    scheme#memq	12
o|    ##sys#immediate?	3
o|    chicken.fixnum#fxnot
o|    chicken.fixnum#fxand	16
o|    ##sys#call-with-current-continuation	3
o|    scheme#char?	4
o|    scheme#assq	6
o|    ##sys#setislot	28
o|    scheme#char->integer	16
o|    scheme#char-downcase	14
o|    chicken.fixnum#fxmin	3
o|    ##sys#check-vector	6
o|    ##sys#check-symbol	12
o|    ##sys#intern-symbol	10
o|    scheme#integer->char	22
o|    scheme#string-ci=?	2
o|    scheme#char>=?	3
o|    ##sys#foreign-flonum-argument
o|    ##sys#foreign-fixnum-argument	4
o|    scheme#remainder
o|    chicken.base#fixnum?	2
o|    chicken.fixnum#fxshr	13
o|    chicken.fixnum#fxshl	8
o|    chicken.bitwise#bitwise-and	2
o|    chicken.fixnum#fxneg	5
o|    chicken.bitwise#arithmetic-shift	11
o|    scheme#>	7
o|    scheme#<	7
o|    scheme#cadr	15
o|    scheme#=	3
o|    scheme#>=	2
o|    scheme#quotient	17
o|    scheme#exact?
o|    chicken.base#ratnum?	14
o|    ##sys#check-number	10
o|    chicken.base#cplxnum?	17
o|    scheme#number?	8
o|    scheme#*	44
o|    scheme#inexact?	7
o|    chicken.base#flonum?	55
o|    scheme#list->string
o|    chicken.fixnum#fx>	37
o|    scheme#length	6
o|    chicken.fixnum#fx>=	34
o|    chicken.fixnum#fx+	127
o|    ##sys#check-string	25
o|    chicken.fixnum#fx-	55
o|    ##sys#call-with-values	22
o|    scheme#procedure?	7
o|    ##sys#values	2
o|    chicken.fixnum#fx<=	26
o|    chicken.fixnum#fx<	38
o|    scheme#vector	8
o|    chicken.fixnum#fx=	20
o|    ##sys#size	66
o|    scheme#list	27
o|    ##sys#setslot	57
o|    scheme#list?	5
o|    ##sys#check-pair	3
o|    chicken.base#void	3
o|    scheme#null?	134
o|    ##sys#check-list	20
o|    scheme#not	91
o|    ##sys#make-structure	13
o|    ##sys#structure?	8
o|    scheme#apply	100
o|    scheme#-	19
o|    scheme#call-with-values	2
o|    scheme#+	24
o|    scheme#values	23
o|    ##sys#check-char	15
o|    scheme#pair?	97
o|    ##sys#slot	363
o|    scheme#cons	147
o|    scheme#eq?	398
o|    scheme#cdr	48
o|    scheme#car	122
o|contracted procedure: k8902 
o|contracted procedure: k8898 
o|contracted procedure: k8916 
o|contracted procedure: k8930 
o|contracted procedure: k8926 
o|contracted procedure: k8951 
o|contracted procedure: k8947 
o|contracted procedure: k8965 
o|contracted procedure: k8961 
o|contracted procedure: k8983 
o|contracted procedure: k8979 
o|contracted procedure: k8975 
o|contracted procedure: k8993 
o|contracted procedure: k9005 
o|contracted procedure: k9023 
o|contracted procedure: k9019 
o|contracted procedure: k9034 
o|contracted procedure: k9052 
o|contracted procedure: k9048 
o|contracted procedure: k9044 
o|contracted procedure: k9062 
o|contracted procedure: k9074 
o|contracted procedure: k9099 
o|contracted procedure: k9095 
o|contracted procedure: k9091 
o|contracted procedure: k9109 
o|contracted procedure: k9128 
o|contracted procedure: k9124 
o|contracted procedure: k9120 
o|contracted procedure: k9161 
o|contracted procedure: k9167 
o|contracted procedure: k9174 
o|contracted procedure: k9182 
o|contracted procedure: k9178 
o|contracted procedure: k9312 
o|contracted procedure: k9341 
o|contracted procedure: k9347 
o|contracted procedure: k9358 
o|contracted procedure: k9364 
o|contracted procedure: k9370 
o|contracted procedure: k9376 
o|contracted procedure: k9382 
o|contracted procedure: k9504 
o|contracted procedure: k9518 
o|contracted procedure: k9557 
o|contracted procedure: k9619 
o|contracted procedure: k9650 
o|contracted procedure: k9631 
o|contracted procedure: k9638 
o|contracted procedure: k9646 
o|contracted procedure: k9656 
o|contracted procedure: k9687 
o|contracted procedure: k9668 
o|contracted procedure: k9675 
o|contracted procedure: k9683 
o|contracted procedure: k9697 
o|contracted procedure: k9712 
o|contracted procedure: k9703 
o|contracted procedure: k9727 
o|contracted procedure: k9721 
o|contracted procedure: k9751 
o|contracted procedure: k9760 
o|contracted procedure: k9770 
o|contracted procedure: k9807 
o|contracted procedure: k9787 
o|contracted procedure: k9790 
o|contracted procedure: k9803 
o|contracted procedure: k9816 
o|contracted procedure: k9819 
o|contracted procedure: k9860 
o|contracted procedure: k9881 
o|contracted procedure: k9893 
o|contracted procedure: k9902 
o|contracted procedure: k9905 
o|contracted procedure: k9911 
o|contracted procedure: k9940 
o|contracted procedure: k9967 
o|contracted procedure: k9946 
o|contracted procedure: k9959 
o|contracted procedure: k9963 
o|contracted procedure: k9976 
o|contracted procedure: k10023 
o|contracted procedure: k9987 
o|contracted procedure: k10001 
o|contracted procedure: k10004 
o|contracted procedure: k10010 
o|contracted procedure: k10041 
o|contracted procedure: k10056 
o|contracted procedure: k10063 
o|contracted procedure: k10078 
o|contracted procedure: k10088 
o|contracted procedure: k10092 
o|contracted procedure: k10102 
o|contracted procedure: k10111 
o|contracted procedure: k10117 
o|contracted procedure: k10124 
o|contracted procedure: k10143 
o|contracted procedure: k10146 
o|contracted procedure: k10149 
o|contracted procedure: k10155 
o|contracted procedure: k10225 
o|contracted procedure: k10175 
o|contracted procedure: k10178 
o|contracted procedure: k10190 
o|contracted procedure: k10222 
o|contracted procedure: k10196 
o|contracted procedure: k10202 
o|contracted procedure: k10205 
o|contracted procedure: k10211 
o|contracted procedure: k10232 
o|contracted procedure: k10244 
o|contracted procedure: k10306 
o|contracted procedure: k10250 
o|contracted procedure: k10302 
o|contracted procedure: k10259 
o|contracted procedure: k10268 
o|contracted procedure: k10275 
o|contracted procedure: k10283 
o|contracted procedure: k10287 
o|contracted procedure: k10294 
o|contracted procedure: k10298 
o|contracted procedure: k10389 
o|contracted procedure: k10312 
o|contracted procedure: k10324 
o|contracted procedure: k10331 
o|contracted procedure: k10334 
o|contracted procedure: k10340 
o|contracted procedure: k10346 
o|contracted procedure: k10360 
o|contracted procedure: k10363 
o|contracted procedure: k10376 
o|contracted procedure: k10379 
o|contracted procedure: k10386 
o|contracted procedure: k10493 
o|contracted procedure: k10398 
o|contracted procedure: k10410 
o|contracted procedure: k10417 
o|contracted procedure: k10490 
o|contracted procedure: k10423 
o|contracted procedure: k10429 
o|contracted procedure: k10486 
o|contracted procedure: k10435 
o|contracted procedure: k10451 
o|contracted procedure: k10455 
o|contracted procedure: k10474 
o|contracted procedure: k10478 
o|contracted procedure: k10462 
o|contracted procedure: k10470 
o|contracted procedure: k10482 
o|contracted procedure: k10605 
o|contracted procedure: k10502 
o|contracted procedure: k10599 
o|contracted procedure: k10505 
o|contracted procedure: k10593 
o|contracted procedure: k10508 
o|contracted procedure: k10587 
o|contracted procedure: k10511 
o|contracted procedure: k10526 
o|contracted procedure: k10532 
o|contracted procedure: k10538 
o|contracted procedure: k10552 
o|contracted procedure: k10558 
o|contracted procedure: k10561 
o|contracted procedure: k10564 
o|contracted procedure: k10577 
o|contracted procedure: k10581 
o|contracted procedure: k10614 
o|contracted procedure: k10655 
o|contracted procedure: k10617 
o|contracted procedure: k10629 
o|contracted procedure: k10632 
o|contracted procedure: k10635 
o|contracted procedure: k10648 
o|contracted procedure: k10652 
o|contracted procedure: k10774 
o|contracted procedure: k10786 
o|contracted procedure: k10800 
o|contracted procedure: k10840 
o|contracted procedure: k10836 
o|contracted procedure: k10887 
o|contracted procedure: k10890 
o|contracted procedure: k10899 
o|contracted procedure: k10921 
o|contracted procedure: k10928 
o|contracted procedure: k10932 
o|contracted procedure: k10941 
o|contracted procedure: k10952 
o|contracted procedure: k10964 
o|contracted procedure: k10975 
o|contracted procedure: k10986 
o|contracted procedure: k10997 
o|contracted procedure: k11008 
o|contracted procedure: k11019 
o|contracted procedure: k11030 
o|contracted procedure: k11041 
o|contracted procedure: k11052 
o|contracted procedure: k11063 
o|contracted procedure: k11074 
o|contracted procedure: k11085 
o|contracted procedure: k11096 
o|contracted procedure: k11114 
o|contracted procedure: k11131 
o|contracted procedure: k11141 
o|contracted procedure: k11144 
o|contracted procedure: k11154 
o|contracted procedure: k11172 
o|contracted procedure: k11200 
o|contracted procedure: k11185 
o|contracted procedure: k11196 
o|contracted procedure: k11212 
o|contracted procedure: k11222 
o|contracted procedure: k11232 
o|contracted procedure: k11243 
o|contracted procedure: k11252 
o|contracted procedure: k11258 
o|contracted procedure: k11267 
o|contracted procedure: k11276 
o|contracted procedure: k11279 
o|contracted procedure: k11348 
o|contracted procedure: k11344 
o|contracted procedure: k11288 
o|contracted procedure: k11300 
o|contracted procedure: k11310 
o|contracted procedure: k11303 
o|contracted procedure: k11313 
o|contracted procedure: k11340 
o|contracted procedure: k11319 
o|contracted procedure: k11336 
o|contracted procedure: k11325 
o|contracted procedure: k11332 
o|contracted procedure: k11357 
o|contracted procedure: k11375 
o|contracted procedure: k11368 
o|contracted procedure: k11391 
o|contracted procedure: k11384 
o|contracted procedure: k11407 
o|contracted procedure: k11400 
o|contracted procedure: k11423 
o|contracted procedure: k11416 
o|contracted procedure: k11439 
o|contracted procedure: k11432 
o|contracted procedure: k11455 
o|contracted procedure: k11448 
o|contracted procedure: k11471 
o|contracted procedure: k11464 
o|contracted procedure: k11487 
o|contracted procedure: k11480 
o|contracted procedure: k11499 
o|contracted procedure: k11569 
o|contracted procedure: k11511 
o|contracted procedure: k11521 
o|contracted procedure: k11530 
o|contracted procedure: k11537 
o|contracted procedure: k11543 
o|contracted procedure: k11550 
o|contracted procedure: k11558 
o|contracted procedure: k11565 
o|contracted procedure: k11584 
o|contracted procedure: k11591 
o|contracted procedure: k11599 
o|contracted procedure: k11595 
o|contracted procedure: k11616 
o|contracted procedure: k11605 
o|contracted procedure: k11643 
o|contracted procedure: k11646 
o|contracted procedure: k11649 
o|contracted procedure: k11652 
o|contracted procedure: k11661 
o|contracted procedure: k11664 
o|contracted procedure: k11671 
o|contracted procedure: k11680 
o|contracted procedure: k11687 
o|contracted procedure: k11691 
o|contracted procedure: k11744 
o|contracted procedure: k11702 
o|contracted procedure: k11708 
o|contracted procedure: k11723 
o|contracted procedure: k11726 
o|contracted procedure: k11729 
o|contracted procedure: k11736 
o|contracted procedure: k11740 
o|contracted procedure: k11754 
o|contracted procedure: k11765 
o|contracted procedure: k11774 
o|contracted procedure: k11777 
o|contracted procedure: k11780 
o|contracted procedure: k11787 
o|contracted procedure: k11791 
o|contracted procedure: k11800 
o|contracted procedure: k11803 
o|contracted procedure: k11807 
o|contracted procedure: k11813 
o|contracted procedure: k11816 
o|contracted procedure: k11825 
o|contracted procedure: k11834 
o|contracted procedure: k11850 
o|contracted procedure: k11856 
o|contracted procedure: k11862 
o|contracted procedure: k11879 
o|contracted procedure: k11884 
o|contracted procedure: k11887 
o|contracted procedure: k11898 
o|contracted procedure: k11911 
o|contracted procedure: k11920 
o|contracted procedure: k11935 
o|contracted procedure: k11944 
o|contracted procedure: k11962 
o|contracted procedure: k11983 
o|contracted procedure: k11994 
o|contracted procedure: k11997 
o|contracted procedure: k12008 
o|contracted procedure: k12021 
o|contracted procedure: k12030 
o|contracted procedure: k12045 
o|contracted procedure: k12054 
o|contracted procedure: k12072 
o|contracted procedure: k12093 
o|contracted procedure: k12105 
o|contracted procedure: k12108 
o|contracted procedure: k12115 
o|contracted procedure: k12130 
o|contracted procedure: k12137 
o|contracted procedure: k12140 
o|contracted procedure: k12143 
o|contracted procedure: k12150 
o|contracted procedure: k12154 
o|contracted procedure: k12178 
o|contracted procedure: k12181 
o|contracted procedure: k12184 
o|contracted procedure: k12191 
o|contracted procedure: k12195 
o|contracted procedure: k12207 
o|contracted procedure: k12219 
o|contracted procedure: k12225 
o|contracted procedure: k12240 
o|contracted procedure: k12255 
o|contracted procedure: k12274 
o|contracted procedure: k12262 
o|contracted procedure: k12266 
o|contracted procedure: k12270 
o|contracted procedure: k12277 
o|contracted procedure: k12308 
o|contracted procedure: k12301 
o|contracted procedure: k12332 
o|contracted procedure: k12325 
o|contracted procedure: k12356 
o|contracted procedure: k12349 
o|contracted procedure: k12380 
o|contracted procedure: k12373 
o|contracted procedure: k12402 
o|contracted procedure: k12408 
o|contracted procedure: k12429 
o|contracted procedure: k12422 
o|contracted procedure: k12453 
o|contracted procedure: k12446 
o|contracted procedure: k12477 
o|contracted procedure: k12470 
o|contracted procedure: k12501 
o|contracted procedure: k12494 
o|contracted procedure: k12525 
o|contracted procedure: k12518 
o|contracted procedure: k12549 
o|contracted procedure: k12542 
o|contracted procedure: k12573 
o|contracted procedure: k12566 
o|contracted procedure: k12590 
o|contracted procedure: k12615 
o|contracted procedure: k12608 
o|contracted procedure: k12639 
o|contracted procedure: k12632 
o|contracted procedure: k12656 
o|contracted procedure: k12674 
o|contracted procedure: k12692 
o|contracted procedure: k12710 
o|contracted procedure: k12728 
o|contracted procedure: k12746 
o|contracted procedure: k12764 
o|contracted procedure: k12782 
o|contracted procedure: k12800 
o|contracted procedure: k12818 
o|contracted procedure: k12843 
o|contracted procedure: k12836 
o|contracted procedure: k12860 
o|contracted procedure: k12878 
o|contracted procedure: k12896 
o|contracted procedure: k12914 
o|contracted procedure: k12932 
o|contracted procedure: k12950 
o|contracted procedure: k12968 
o|contracted procedure: k12993 
o|contracted procedure: k12986 
o|contracted procedure: k13010 
o|contracted procedure: k13028 
o|contracted procedure: k13046 
o|contracted procedure: k13064 
o|contracted procedure: k13086 
o|contracted procedure: k13077 
o|contracted procedure: k13102 
o|contracted procedure: k13116 
o|contracted procedure: k13120 
o|contracted procedure: k13160 
o|contracted procedure: k13164 
o|contracted procedure: k13173 
o|contracted procedure: k13184 
o|contracted procedure: k13196 
o|contracted procedure: k13210 
o|contracted procedure: k13219 
o|contracted procedure: k13238 
o|contracted procedure: k13259 
o|contracted procedure: k13263 
o|contracted procedure: k13255 
o|contracted procedure: k13269 
o|contracted procedure: k13282 
o|contracted procedure: k13288 
o|contracted procedure: k13335 
o|contracted procedure: k13357 
o|contracted procedure: k13381 
o|contracted procedure: k13403 
o|contracted procedure: k13420 
o|contracted procedure: k13432 
o|contracted procedure: k13544 
o|contracted procedure: k13478 
o|contracted procedure: k13469 
o|contracted procedure: k13512 
o|contracted procedure: k13519 
o|contracted procedure: k13570 
o|contracted procedure: k13622 
o|contracted procedure: k13632 
o|contracted procedure: k13645 
o|contracted procedure: k13652 
o|contracted procedure: k13660 
o|contracted procedure: k13664 
o|contracted procedure: k13676 
o|contracted procedure: k13702 
o|contracted procedure: k13705 
o|contracted procedure: k13757 
o|contracted procedure: k13761 
o|contracted procedure: k13720 
o|contracted procedure: k13737 
o|contracted procedure: k13741 
o|contracted procedure: k13733 
o|contracted procedure: k13749 
o|contracted procedure: k13753 
o|contracted procedure: k13745 
o|contracted procedure: k13767 
o|contracted procedure: k13784 
o|contracted procedure: k13790 
o|contracted procedure: k13843 
o|contracted procedure: k13847 
o|contracted procedure: k13827 
o|contracted procedure: k13835 
o|contracted procedure: k13839 
o|contracted procedure: k13831 
o|contracted procedure: k13858 
o|contracted procedure: k13880 
o|contracted procedure: k13861 
o|contracted procedure: k13886 
o|contracted procedure: k13913 
o|contracted procedure: k13897 
o|contracted procedure: k13900 
o|contracted procedure: k13935 
o|contracted procedure: k13925 
o|contracted procedure: k13943 
o|contracted procedure: k13966 
o|contracted procedure: k13974 
o|contracted procedure: k13980 
o|contracted procedure: k14011 
o|contracted procedure: k14019 
o|contracted procedure: k14025 
o|contracted procedure: k14056 
o|contracted procedure: k14090 
o|contracted procedure: k14093 
o|contracted procedure: k14108 
o|contracted procedure: k14194 
o|contracted procedure: k14136 
o|contracted procedure: k14145 
o|contracted procedure: k14161 
o|contracted procedure: k14165 
o|contracted procedure: k14155 
o|contracted procedure: k14179 
o|contracted procedure: k14183 
o|contracted procedure: k14190 
o|contracted procedure: k14208 
o|contracted procedure: k14254 
o|contracted procedure: k14217 
o|contracted procedure: k14242 
o|contracted procedure: k14246 
o|contracted procedure: k14280 
o|contracted procedure: k14283 
o|contracted procedure: k14264 
o|contracted procedure: k14268 
o|contracted procedure: k14306 
o|contracted procedure: k14312 
o|contracted procedure: k14319 
o|contracted procedure: k14326 
o|contracted procedure: k14337 
o|contracted procedure: k14330 
o|contracted procedure: k14334 
o|contracted procedure: k14350 
o|contracted procedure: k14356 
o|contracted procedure: k14363 
o|contracted procedure: k14370 
o|contracted procedure: k14381 
o|contracted procedure: k14374 
o|contracted procedure: k14378 
o|contracted procedure: k14387 
o|contracted procedure: k14393 
o|contracted procedure: k14435 
o|contracted procedure: k14444 
o|contracted procedure: k14447 
o|contracted procedure: k14458 
o|contracted procedure: k14501 
o|contracted procedure: k14481 
o|contracted procedure: k14510 
o|contracted procedure: k14516 
o|contracted procedure: k14519 
o|contracted procedure: k14526 
o|contracted procedure: k14544 
o|contracted procedure: k14550 
o|contracted procedure: k14553 
o|contracted procedure: k14560 
o|contracted procedure: k14578 
o|contracted procedure: k14584 
o|contracted procedure: k14603 
o|contracted procedure: k14630 
o|contracted procedure: k14626 
o|contracted procedure: k14642 
o|contracted procedure: k14638 
o|contracted procedure: k14648 
o|contracted procedure: k14665 
o|contracted procedure: k14690 
o|contracted procedure: k14762 
o|contracted procedure: k14707 
o|contracted procedure: k14710 
o|contracted procedure: k14716 
o|contracted procedure: k14725 
o|contracted procedure: k14732 
o|contracted procedure: k14744 
o|contracted procedure: k14748 
o|contracted procedure: k14953 
o|contracted procedure: k14774 
o|contracted procedure: k14780 
o|contracted procedure: k14783 
o|contracted procedure: k14792 
o|contracted procedure: k14801 
o|contracted procedure: k14810 
o|contracted procedure: k14948 
o|contracted procedure: k14832 
o|contracted procedure: k14835 
o|contracted procedure: k14852 
o|contracted procedure: k14848 
o|contracted procedure: k14859 
o|contracted procedure: k14863 
o|contracted procedure: k14944 
o|contracted procedure: k14940 
o|contracted procedure: k14866 
o|contracted procedure: k14880 
o|contracted procedure: k14885 
o|contracted procedure: k14936 
o|contracted procedure: k14891 
o|contracted procedure: k14924 
o|contracted procedure: k14932 
o|contracted procedure: k14928 
o|contracted procedure: k14894 
o|contracted procedure: k14905 
o|contracted procedure: k14917 
o|contracted procedure: k14913 
o|contracted procedure: k14909 
o|contracted procedure: k14974 
o|contracted procedure: k14988 
o|contracted procedure: k14992 
o|contracted procedure: k15041 
o|contracted procedure: k15051 
o|contracted procedure: k15075 
o|contracted procedure: k15099 
o|contracted procedure: k15147 
o|contracted procedure: k15160 
o|contracted procedure: k15167 
o|contracted procedure: k15173 
o|contracted procedure: k15176 
o|contracted procedure: k15234 
o|contracted procedure: k15238 
o|contracted procedure: k15230 
o|contracted procedure: k15183 
o|contracted procedure: k15192 
o|contracted procedure: k15207 
o|contracted procedure: k15211 
o|contracted procedure: k15203 
o|contracted procedure: k15199 
o|contracted procedure: k15222 
o|contracted procedure: k15254 
o|contracted procedure: k15258 
o|contracted procedure: k15302 
o|contracted procedure: k15313 
o|contracted procedure: k15321 
o|contracted procedure: k15328 
o|contracted procedure: k15332 
o|contracted procedure: k15345 
o|contracted procedure: k15358 
o|contracted procedure: k15368 
o|contracted procedure: k15599 
o|contracted procedure: k15378 
o|contracted procedure: k15595 
o|contracted procedure: k15387 
o|contracted procedure: k15427 
o|contracted procedure: k15468 
o|contracted procedure: k15502 
o|contracted procedure: k15514 
o|contracted procedure: k15546 
o|contracted procedure: k15549 
o|contracted procedure: k15576 
o|contracted procedure: k15584 
o|contracted procedure: k15591 
o|contracted procedure: k15621 
o|contracted procedure: k15643 
o|contracted procedure: k15684 
o|contracted procedure: k15691 
o|contracted procedure: k15695 
o|contracted procedure: k15704 
o|contracted procedure: k15715 
o|contracted procedure: k15726 
o|contracted procedure: k15740 
o|contracted procedure: k15736 
o|contracted procedure: k15749 
o|contracted procedure: k15756 
o|contracted procedure: k15760 
o|contracted procedure: k15769 
o|contracted procedure: k15780 
o|contracted procedure: k15798 
o|contracted procedure: k15790 
o|contracted procedure: k15794 
o|contracted procedure: k15851 
o|contracted procedure: k15804 
o|contracted procedure: k15841 
o|contracted procedure: k15836 
o|contracted procedure: k15860 
o|contracted procedure: k15891 
o|contracted procedure: k15912 
o|contracted procedure: k16039 
o|contracted procedure: k16052 
o|contracted procedure: k16067 
o|contracted procedure: k16060 
o|contracted procedure: k16081 
o|contracted procedure: k16098 
o|contracted procedure: k16104 
o|contracted procedure: k16110 
o|contracted procedure: k16120 
o|contracted procedure: k16152 
o|contracted procedure: k16126 
o|contracted procedure: k16132 
o|contracted procedure: k16138 
o|contracted procedure: k15937 
o|contracted procedure: k15941 
o|contracted procedure: k16006 
o|contracted procedure: k15951 
o|contracted procedure: k15957 
o|contracted procedure: k15995 
o|contracted procedure: k15960 
o|contracted procedure: k16021 
o|contracted procedure: k16025 
o|contracted procedure: k15976 
o|contracted procedure: k15980 
o|contracted procedure: k15988 
o|contracted procedure: k16158 
o|contracted procedure: k17488 
o|contracted procedure: k17484 
o|contracted procedure: k16161 
o|contracted procedure: k17480 
o|contracted procedure: k17476 
o|contracted procedure: k16164 
o|contracted procedure: k17472 
o|contracted procedure: k17468 
o|contracted procedure: k16167 
o|contracted procedure: k16181 
o|contracted procedure: k16187 
o|contracted procedure: k16201 
o|contracted procedure: k16226 
o|contracted procedure: k16207 
o|contracted procedure: k16214 
o|contracted procedure: k16220 
o|contracted procedure: k16273 
o|contracted procedure: k16234 
o|contracted procedure: k16244 
o|contracted procedure: k16250 
o|contracted procedure: k16256 
o|contracted procedure: k16289 
o|contracted procedure: k16295 
o|contracted procedure: k16309 
o|contracted procedure: k16316 
o|contracted procedure: k16322 
o|contracted procedure: k16336 
o|contracted procedure: k16343 
o|contracted procedure: k16364 
o|contracted procedure: k16378 
o|contracted procedure: k16389 
o|contracted procedure: k16400 
o|contracted procedure: k16417 
o|contracted procedure: k16421 
o|contracted procedure: k16429 
o|contracted procedure: k16435 
o|contracted procedure: k16447 
o|contracted procedure: k16453 
o|contracted procedure: k16462 
o|contracted procedure: k16468 
o|contracted procedure: k16474 
o|contracted procedure: k16486 
o|contracted procedure: k16501 
o|contracted procedure: k16511 
o|contracted procedure: k16530 
o|contracted procedure: k16526 
o|contracted procedure: k16534 
o|contracted procedure: k16537 
o|contracted procedure: k16540 
o|contracted procedure: k16543 
o|contracted procedure: k16549 
o|contracted procedure: k16556 
o|contracted procedure: k16568 
o|contracted procedure: k16574 
o|contracted procedure: k16580 
o|contracted procedure: k16586 
o|contracted procedure: k16592 
o|contracted procedure: k16598 
o|contracted procedure: k16604 
o|contracted procedure: k16610 
o|contracted procedure: k16644 
o|contracted procedure: k16671 
o|contracted procedure: k16970 
o|contracted procedure: k16680 
o|contracted procedure: k16686 
o|contracted procedure: k16695 
o|contracted procedure: k16721 
o|contracted procedure: k16701 
o|contracted procedure: k16708 
o|contracted procedure: k16729 
o|contracted procedure: k16738 
o|contracted procedure: k16744 
o|contracted procedure: k16772 
o|contracted procedure: k16776 
o|contracted procedure: k16786 
o|contracted procedure: k16790 
o|contracted procedure: k16806 
o|contracted procedure: k16884 
o|contracted procedure: k16815 
o|contracted procedure: k16880 
o|contracted procedure: k16830 
o|contracted procedure: k16839 
o|contracted procedure: k16850 
o|contracted procedure: k16865 
o|contracted procedure: k16888 
o|contracted procedure: k16897 
o|contracted procedure: k16903 
o|contracted procedure: k16909 
o|contracted procedure: k16915 
o|contracted procedure: k16921 
o|contracted procedure: k16927 
o|contracted procedure: k16933 
o|contracted procedure: k16939 
o|contracted procedure: k16999 
o|contracted procedure: k16980 
o|contracted procedure: k16986 
o|contracted procedure: k17007 
o|contracted procedure: k17018 
o|contracted procedure: k17024 
o|contracted procedure: k17035 
o|contracted procedure: k17038 
o|contracted procedure: k17051 
o|contracted procedure: k17126 
o|contracted procedure: k17057 
o|contracted procedure: k17067 
o|contracted procedure: k17100 
o|contracted procedure: k17083 
o|contracted procedure: k17097 
o|contracted procedure: k17090 
o|contracted procedure: k17087 
o|contracted procedure: k17104 
o|contracted procedure: k17122 
o|contracted procedure: k17107 
o|contracted procedure: k17118 
o|contracted procedure: k17132 
o|contracted procedure: k17135 
o|contracted procedure: k17148 
o|contracted procedure: k17200 
o|contracted procedure: k17154 
o|contracted procedure: k17160 
o|contracted procedure: k17184 
o|contracted procedure: k17177 
o|contracted procedure: k17174 
o|contracted procedure: k17188 
o|contracted procedure: k17196 
o|contracted procedure: k17207 
o|contracted procedure: k17227 
o|contracted procedure: k17233 
o|contracted procedure: k17252 
o|contracted procedure: k17457 
o|contracted procedure: k17272 
o|contracted procedure: k17278 
o|contracted procedure: k17285 
o|contracted procedure: k17288 
o|contracted procedure: k17327 
o|contracted procedure: k17294 
o|contracted procedure: k17300 
o|contracted procedure: k17303 
o|contracted procedure: k17335 
o|contracted procedure: k17338 
o|contracted procedure: k17348 
o|contracted procedure: k17396 
o|contracted procedure: k17354 
o|contracted procedure: k17360 
o|inlining procedure: k17363 
o|inlining procedure: k17363 
o|contracted procedure: k17406 
o|contracted procedure: k17430 
o|contracted procedure: k17416 
o|contracted procedure: k17434 
o|contracted procedure: k17740 
o|contracted procedure: k17494 
o|contracted procedure: k17497 
o|contracted procedure: k17507 
o|contracted procedure: k17722 
o|contracted procedure: k17709 
o|contracted procedure: k17516 
o|contracted procedure: k17699 
o|contracted procedure: k17527 
o|contracted procedure: k17530 
o|contracted procedure: k17536 
o|contracted procedure: k17543 
o|contracted procedure: k17549 
o|contracted procedure: k17552 
o|contracted procedure: k17558 
o|contracted procedure: k17565 
o|contracted procedure: k17571 
o|contracted procedure: k17574 
o|contracted procedure: k17580 
o|contracted procedure: k17587 
o|contracted procedure: k17593 
o|contracted procedure: k17596 
o|contracted procedure: k17602 
o|contracted procedure: k17609 
o|contracted procedure: k17615 
o|contracted procedure: k17618 
o|contracted procedure: k17624 
o|contracted procedure: k17631 
o|contracted procedure: k17637 
o|contracted procedure: k17640 
o|contracted procedure: k17646 
o|contracted procedure: k17653 
o|contracted procedure: k17734 
o|contracted procedure: k17725 
o|contracted procedure: k17782 
o|contracted procedure: k17749 
o|contracted procedure: k17776 
o|contracted procedure: k17752 
o|contracted procedure: k17770 
o|contracted procedure: k17755 
o|contracted procedure: k17764 
o|contracted procedure: k17758 
o|contracted procedure: k17798 
o|contracted procedure: k17801 
o|contracted procedure: k17807 
o|contracted procedure: k17810 
o|contracted procedure: k17816 
o|contracted procedure: k17828 
o|contracted procedure: k17835 
o|contracted procedure: k17839 
o|contracted procedure: k17852 
o|contracted procedure: k17856 
o|contracted procedure: k17860 
o|contracted procedure: k17866 
o|contracted procedure: k17875 
o|contracted procedure: k17881 
o|contracted procedure: k17893 
o|contracted procedure: k17899 
o|contracted procedure: k17905 
o|contracted procedure: k17926 
o|contracted procedure: k17936 
o|contracted procedure: k17932 
o|contracted procedure: k17939 
o|contracted procedure: k17952 
o|contracted procedure: k17945 
o|contracted procedure: k17970 
o|contracted procedure: k17985 
o|contracted procedure: k17998 
o|contracted procedure: k18011 
o|contracted procedure: k18030 
o|contracted procedure: k18048 
o|contracted procedure: k18051 
o|contracted procedure: k18086 
o|contracted procedure: k18106 
o|contracted procedure: k18109 
o|contracted procedure: k18112 
o|contracted procedure: k18120 
o|contracted procedure: k18128 
o|contracted procedure: k18091 
o|contracted procedure: k18140 
o|contracted procedure: k18162 
o|contracted procedure: k18188 
o|contracted procedure: k18167 
o|contracted procedure: k18173 
o|contracted procedure: k18179 
o|contracted procedure: k18228 
o|contracted procedure: k18231 
o|contracted procedure: k18243 
o|contracted procedure: k18258 
o|contracted procedure: k18269 
o|contracted procedure: k18264 
o|contracted procedure: k18288 
o|contracted procedure: k18285 
o|contracted procedure: k18294 
o|contracted procedure: k18350 
o|contracted procedure: k18307 
o|contracted procedure: k18313 
o|contracted procedure: k18328 
o|contracted procedure: k18346 
o|contracted procedure: k18331 
o|contracted procedure: k18338 
o|contracted procedure: k18342 
o|contracted procedure: k18356 
o|contracted procedure: k18368 
o|contracted procedure: k18375 
o|contracted procedure: k18383 
o|contracted procedure: k18395 
o|contracted procedure: k18407 
o|contracted procedure: k18410 
o|contracted procedure: k18417 
o|contracted procedure: k18423 
o|contracted procedure: k18426 
o|contracted procedure: k18429 
o|contracted procedure: k18432 
o|contracted procedure: k18482 
o|contracted procedure: k18435 
o|contracted procedure: k18453 
o|contracted procedure: k18467 
o|contracted procedure: k18456 
o|contracted procedure: k18463 
o|contracted procedure: k18470 
o|contracted procedure: k18473 
o|contracted procedure: k18554 
o|contracted procedure: k18492 
o|contracted procedure: k18495 
o|contracted procedure: k18498 
o|contracted procedure: k18501 
o|contracted procedure: k18504 
o|contracted procedure: k18525 
o|contracted procedure: k18543 
o|contracted procedure: k18539 
o|contracted procedure: k18528 
o|contracted procedure: k18535 
o|contracted procedure: k18547 
o|contracted procedure: k18551 
o|contracted procedure: k18575 
o|contracted procedure: k18563 
o|contracted procedure: k18566 
o|contracted procedure: k18599 
o|contracted procedure: k18613 
o|contracted procedure: k18602 
o|contracted procedure: k18609 
o|contracted procedure: k18617 
o|contracted procedure: k18627 
o|contracted procedure: k18631 
o|contracted procedure: k18638 
o|contracted procedure: k18642 
o|contracted procedure: k18649 
o|contracted procedure: k18653 
o|contracted procedure: k18660 
o|contracted procedure: k18664 
o|contracted procedure: k18671 
o|contracted procedure: k18675 
o|contracted procedure: k18685 
o|contracted procedure: k18692 
o|contracted procedure: k18701 
o|contracted procedure: k18704 
o|contracted procedure: k18721 
o|contracted procedure: k18710 
o|contracted procedure: k18717 
o|contracted procedure: k18835 
o|contracted procedure: k18726 
o|contracted procedure: k18732 
o|contracted procedure: k18747 
o|contracted procedure: k18750 
o|contracted procedure: k18762 
o|contracted procedure: k18765 
o|contracted procedure: k18779 
o|contracted procedure: k18775 
o|contracted procedure: k18783 
o|contracted procedure: k18806 
o|contracted procedure: k18787 
o|contracted procedure: k18798 
o|contracted procedure: k18802 
o|contracted procedure: k18794 
o|contracted procedure: k18820 
o|contracted procedure: k18816 
o|contracted procedure: k18809 
o|contracted procedure: k18823 
o|contracted procedure: k18826 
o|contracted procedure: k18896 
o|contracted procedure: k18902 
o|contracted procedure: k18912 
o|contracted procedure: k18916 
o|contracted procedure: k18934 
o|contracted procedure: k18940 
o|contracted procedure: k18955 
o|contracted procedure: k18959 
o|contracted procedure: k18982 
o|contracted procedure: k18985 
o|contracted procedure: k18991 
o|contracted procedure: k19000 
o|contracted procedure: k19015 
o|contracted procedure: k19028 
o|contracted procedure: k19031 
o|contracted procedure: k19043 
o|contracted procedure: k19053 
o|contracted procedure: k19057 
o|contracted procedure: k19064 
o|contracted procedure: k19079 
o|contracted procedure: k19110 
o|contracted procedure: k19113 
o|contracted procedure: k19116 
o|contracted procedure: k19128 
o|contracted procedure: k19131 
o|contracted procedure: k19134 
o|contracted procedure: k19142 
o|contracted procedure: k19150 
o|contracted procedure: k19160 
o|contracted procedure: k19175 
o|contracted procedure: k19233 
o|contracted procedure: k19213 
o|contracted procedure: k19223 
o|contracted procedure: k19255 
o|contracted procedure: k19266 
o|contracted procedure: k19270 
o|contracted procedure: k19262 
o|contracted procedure: k19280 
o|contracted procedure: k19289 
o|contracted procedure: k19303 
o|contracted procedure: k19295 
o|contracted procedure: k19307 
o|contracted procedure: k19311 
o|contracted procedure: k19332 
o|contracted procedure: k19314 
o|contracted procedure: k19318 
o|contracted procedure: k19328 
o|contracted procedure: k19361 
o|contracted procedure: k19367 
o|contracted procedure: k19370 
o|contracted procedure: k19373 
o|contracted procedure: k19376 
o|contracted procedure: k19379 
o|contracted procedure: k19382 
o|contracted procedure: k19385 
o|contracted procedure: k33014 
o|contracted procedure: k33023 
o|contracted procedure: k33053 
o|contracted procedure: k33062 
o|contracted procedure: k33114 
o|contracted procedure: k33120 
o|contracted procedure: k33129 
o|contracted procedure: k33142 
o|contracted procedure: k33146 
o|contracted procedure: k33150 
o|contracted procedure: k33168 
o|contracted procedure: k33175 
o|contracted procedure: k33179 
o|contracted procedure: k33183 
o|contracted procedure: k33193 
o|contracted procedure: k33209 
o|contracted procedure: k33213 
o|contracted procedure: k33220 
o|contracted procedure: k33226 
o|contracted procedure: k33235 
o|contracted procedure: k33241 
o|contracted procedure: k33255 
o|contracted procedure: k33259 
o|contracted procedure: k33271 
o|contracted procedure: k33277 
o|contracted procedure: k33286 
o|contracted procedure: k33310 
o|contracted procedure: k33289 
o|contracted procedure: k33343 
o|contracted procedure: k33339 
o|contracted procedure: k33328 
o|contracted procedure: k33357 
o|contracted procedure: k33353 
o|contracted procedure: k33346 
o|contracted procedure: k33360 
o|contracted procedure: k19389 
o|contracted procedure: k19420 
o|contracted procedure: k19431 
o|contracted procedure: k19442 
o|contracted procedure: k19453 
o|contracted procedure: k19464 
o|contracted procedure: k19467 
o|contracted procedure: k19493 
o|contracted procedure: k19499 
o|contracted procedure: k19506 
o|contracted procedure: k19512 
o|contracted procedure: k19525 
o|contracted procedure: k19528 
o|contracted procedure: k19554 
o|contracted procedure: k19560 
o|contracted procedure: k19567 
o|contracted procedure: k19573 
o|contracted procedure: k19586 
o|contracted procedure: k19589 
o|contracted procedure: k19615 
o|contracted procedure: k19621 
o|contracted procedure: k19628 
o|contracted procedure: k19634 
o|contracted procedure: k19647 
o|contracted procedure: k19670 
o|contracted procedure: k19673 
o|contracted procedure: k19717 
o|contracted procedure: k19720 
o|contracted procedure: k19730 
o|contracted procedure: k19733 
o|contracted procedure: k1973035980 
o|contracted procedure: k19740 
o|contracted procedure: k1973035984 
o|contracted procedure: k19747 
o|contracted procedure: k1973035988 
o|contracted procedure: k19772 
o|contracted procedure: k19796 
o|contracted procedure: k19800 
o|contracted procedure: k19792 
o|contracted procedure: k19778 
o|contracted procedure: k19788 
o|contracted procedure: k19781 
o|contracted procedure: k19953 
o|contracted procedure: k19959 
o|contracted procedure: k19979 
o|contracted procedure: k19972 
o|contracted procedure: k19994 
o|contracted procedure: k19985 
o|contracted procedure: k20012 
o|contracted procedure: k20019 
o|contracted procedure: k20041 
o|contracted procedure: k20058 
o|contracted procedure: k20047 
o|contracted procedure: k20054 
o|contracted procedure: k20062 
o|contracted procedure: k20065 
o|contracted procedure: k20081 
o|contracted procedure: k20120 
o|contracted procedure: k20091 
o|contracted procedure: k20100 
o|contracted procedure: k20103 
o|contracted procedure: k20116 
o|contracted procedure: k20126 
o|contracted procedure: k20142 
o|contracted procedure: k20138 
o|contracted procedure: k20154 
o|contracted procedure: k20184 
o|contracted procedure: k20261 
o|contracted procedure: k20195 
o|contracted procedure: k20219 
o|contracted procedure: k20232 
o|contracted procedure: k20239 
o|contracted procedure: k20249 
o|contracted procedure: k20245 
o|contracted procedure: k20252 
o|contracted procedure: k20336 
o|contracted procedure: k20496 
o|contracted procedure: k20343 
o|contracted procedure: k20357 
o|contracted procedure: k20366 
o|contracted procedure: k20374 
o|contracted procedure: k20378 
o|contracted procedure: k20384 
o|contracted procedure: k20393 
o|contracted procedure: k20399 
o|contracted procedure: k20409 
o|contracted procedure: k20425 
o|contracted procedure: k20431 
o|contracted procedure: k20438 
o|contracted procedure: k20444 
o|contracted procedure: k20454 
o|contracted procedure: k20460 
o|contracted procedure: k20466 
o|contracted procedure: k20475 
o|contracted procedure: k20493 
o|contracted procedure: k20481 
o|contracted procedure: k20489 
o|contracted procedure: k20523 
o|contracted procedure: k20507 
o|contracted procedure: k20520 
o|contracted procedure: k20513 
o|contracted procedure: k20541 
o|contracted procedure: k20532 
o|contracted procedure: k20556 
o|contracted procedure: k20570 
o|contracted procedure: k20566 
o|contracted procedure: k20559 
o|inlining procedure: k20553 
o|contracted procedure: k20576 
o|contracted procedure: k20587 
o|contracted procedure: k20583 
o|inlining procedure: k20553 
o|contracted procedure: k20591 
o|contracted procedure: k20594 
o|contracted procedure: k20604 
o|contracted procedure: k20597 
o|contracted procedure: k20622 
o|contracted procedure: k20638 
o|contracted procedure: k20625 
o|contracted procedure: k20631 
o|contracted procedure: k20653 
o|contracted procedure: k20644 
o|contracted procedure: k20671 
o|contracted procedure: k20662 
o|contracted procedure: k20724 
o|contracted procedure: k20747 
o|contracted procedure: k20816 
o|contracted procedure: k20823 
o|contracted procedure: k20845 
o|contracted procedure: k20873 
o|contracted procedure: k20889 
o|contracted procedure: k20914 
o|contracted procedure: k20939 
o|contracted procedure: k20942 
o|contracted procedure: k20952 
o|contracted procedure: k20956 
o|contracted procedure: k20968 
o|contracted procedure: k20980 
o|contracted procedure: k20987 
o|contracted procedure: k20991 
o|contracted procedure: k20996 
o|contracted procedure: k21021 
o|contracted procedure: k21031 
o|contracted procedure: k21042 
o|contracted procedure: k21048 
o|contracted procedure: k21059 
o|contracted procedure: k21065 
o|contracted procedure: k21076 
o|contracted procedure: k21082 
o|contracted procedure: k21093 
o|contracted procedure: k21099 
o|contracted procedure: k21110 
o|contracted procedure: k21116 
o|contracted procedure: k21127 
o|contracted procedure: k21133 
o|contracted procedure: k21144 
o|contracted procedure: k21150 
o|contracted procedure: k21153 
o|contracted procedure: k21164 
o|contracted procedure: k21174 
o|contracted procedure: k21218 
o|contracted procedure: k21248 
o|contracted procedure: k21277 
o|contracted procedure: k21291 
o|contracted procedure: k21297 
o|contracted procedure: k21312 
o|contracted procedure: k21315 
o|contracted procedure: k21328 
o|contracted procedure: k21343 
o|contracted procedure: k21359 
o|contracted procedure: k21438 
o|contracted procedure: k21434 
o|contracted procedure: k21426 
o|contracted procedure: k21422 
o|contracted procedure: k21407 
o|contracted procedure: k21418 
o|contracted procedure: k21452 
o|contracted procedure: k21455 
o|contracted procedure: k21461 
o|contracted procedure: k21467 
o|contracted procedure: k21473 
o|contracted procedure: k21490 
o|contracted procedure: k21496 
o|contracted procedure: k21536 
o|contracted procedure: k21550 
o|contracted procedure: k21559 
o|contracted procedure: k21568 
o|contracted procedure: k21601 
o|contracted procedure: k21642 
o|contracted procedure: k21651 
o|contracted procedure: k21663 
o|contracted procedure: k21675 
o|contracted procedure: k21684 
o|contracted procedure: k21702 
o|contracted procedure: k21720 
o|contracted procedure: k21723 
o|contracted procedure: k21760 
o|contracted procedure: k21733 
o|contracted procedure: k21754 
o|contracted procedure: k21766 
o|contracted procedure: k21772 
o|contracted procedure: k21778 
o|contracted procedure: k21787 
o|contracted procedure: k21790 
o|contracted procedure: k21824 
o|contracted procedure: k21858 
o|contracted procedure: k21900 
o|contracted procedure: k21892 
o|contracted procedure: k21867 
o|contracted procedure: k21909 
o|contracted procedure: k21921 
o|contracted procedure: k21930 
o|contracted procedure: k21960 
o|contracted procedure: k21972 
o|contracted procedure: k21981 
o|contracted procedure: k22037 
o|contracted procedure: k22049 
o|inlining procedure: k22066 
o|contracted procedure: k22070 
o|inlining procedure: k22066 
o|contracted procedure: k22076 
o|contracted procedure: k22101 
o|contracted procedure: k22121 
o|contracted procedure: k22128 
o|contracted procedure: k22175 
o|contracted procedure: k22195 
o|contracted procedure: k22230 
o|contracted procedure: k22243 
o|contracted procedure: k22249 
o|contracted procedure: k22263 
o|contracted procedure: k22259 
o|contracted procedure: k22269 
o|contracted procedure: k22281 
o|contracted procedure: k22305 
o|contracted procedure: k22315 
o|contracted procedure: k22325 
o|contracted procedure: k22332 
o|contracted procedure: k22338 
o|contracted procedure: k22347 
o|contracted procedure: k22357 
o|inlining procedure: k22364 
o|contracted procedure: k22368 
o|inlining procedure: k22364 
o|contracted procedure: k22382 
o|contracted procedure: k22391 
o|contracted procedure: k22397 
o|contracted procedure: k22416 
o|contracted procedure: k22422 
o|contracted procedure: k22439 
o|contracted procedure: k22442 
o|contracted procedure: k22464 
o|contracted procedure: k22583 
o|contracted procedure: k22470 
o|contracted procedure: k22579 
o|contracted procedure: k22571 
o|contracted procedure: k22575 
o|contracted procedure: k22567 
o|contracted procedure: k22473 
o|contracted procedure: k22476 
o|contracted procedure: k22563 
o|contracted procedure: k22559 
o|contracted procedure: k22555 
o|contracted procedure: k22551 
o|contracted procedure: k22538 
o|contracted procedure: k22546 
o|contracted procedure: k22542 
o|contracted procedure: k22482 
o|contracted procedure: k22494 
o|contracted procedure: k22525 
o|contracted procedure: k22533 
o|contracted procedure: k22529 
o|contracted procedure: k22498 
o|contracted procedure: k22504 
o|contracted procedure: k22512 
o|contracted procedure: k22520 
o|contracted procedure: k22516 
o|contracted procedure: k22508 
o|contracted procedure: k22587 
o|contracted procedure: k22610 
o|contracted procedure: k22631 
o|contracted procedure: k22637 
o|contracted procedure: k22654 
o|contracted procedure: k22643 
o|contracted procedure: k22650 
o|contracted procedure: k22667 
o|contracted procedure: k22677 
o|contracted procedure: k22674 
o|contracted procedure: k22690 
o|contracted procedure: k22726 
o|contracted procedure: k22755 
o|contracted procedure: k22779 
o|contracted procedure: k22791 
o|contracted procedure: k22803 
o|contracted procedure: k22815 
o|contracted procedure: k22824 
o|contracted procedure: k22843 
o|contracted procedure: k22855 
o|contracted procedure: k22864 
o|contracted procedure: k22873 
o|contracted procedure: k22882 
o|contracted procedure: k22906 
o|contracted procedure: k22918 
o|contracted procedure: k22921 
o|contracted procedure: k22936 
o|contracted procedure: k22946 
o|contracted procedure: k22953 
o|contracted procedure: k22977 
o|contracted procedure: k22986 
o|contracted procedure: k22992 
o|contracted procedure: k23004 
o|contracted procedure: k23016 
o|contracted procedure: k23028 
o|contracted procedure: k23040 
o|contracted procedure: k23052 
o|contracted procedure: k23064 
o|contracted procedure: k23095 
o|contracted procedure: k23104 
o|contracted procedure: k23110 
o|contracted procedure: k23119 
o|contracted procedure: k23128 
o|contracted procedure: k23140 
o|contracted procedure: k23155 
o|contracted procedure: k23167 
o|contracted procedure: k23182 
o|contracted procedure: k23194 
o|contracted procedure: k23206 
o|contracted procedure: k23221 
o|contracted procedure: k23270 
o|contracted procedure: k23259 
o|contracted procedure: k23266 
o|contracted procedure: k23250 
o|contracted procedure: k23281 
o|contracted procedure: k23301 
o|contracted procedure: k23297 
o|contracted procedure: k23311 
o|contracted procedure: k23338 
o|contracted procedure: k23349 
o|contracted procedure: k23359 
o|contracted procedure: k23365 
o|contracted procedure: k23378 
o|contracted procedure: k23381 
o|contracted procedure: k23404 
o|contracted procedure: k23451 
o|contracted procedure: k23457 
o|contracted procedure: k23466 
o|contracted procedure: k23478 
o|contracted procedure: k23490 
o|contracted procedure: k23499 
o|contracted procedure: k23502 
o|contracted procedure: k23511 
o|contracted procedure: k23517 
o|contracted procedure: k23526 
o|contracted procedure: k23535 
o|contracted procedure: k23544 
o|contracted procedure: k23553 
o|contracted procedure: k23556 
o|contracted procedure: k23616 
o|contracted procedure: k23602 
o|contracted procedure: k23612 
o|contracted procedure: k23630 
o|contracted procedure: k23620 
o|contracted procedure: k23627 
o|contracted procedure: k23639 
o|contracted procedure: k23645 
o|contracted procedure: k23654 
o|contracted procedure: k23681 
o|contracted procedure: k23677 
o|contracted procedure: k23661 
o|contracted procedure: k23673 
o|contracted procedure: k23669 
o|contracted procedure: k23665 
o|contracted procedure: k23687 
o|contracted procedure: k23730 
o|contracted procedure: k23726 
o|contracted procedure: k23694 
o|contracted procedure: k23722 
o|contracted procedure: k23718 
o|contracted procedure: k23714 
o|contracted procedure: k23698 
o|contracted procedure: k23710 
o|contracted procedure: k23706 
o|contracted procedure: k23702 
o|contracted procedure: k23736 
o|contracted procedure: k23795 
o|contracted procedure: k23791 
o|contracted procedure: k23743 
o|contracted procedure: k23787 
o|contracted procedure: k23783 
o|contracted procedure: k23779 
o|contracted procedure: k23747 
o|contracted procedure: k23775 
o|contracted procedure: k23771 
o|contracted procedure: k23767 
o|contracted procedure: k23751 
o|contracted procedure: k23763 
o|contracted procedure: k23759 
o|contracted procedure: k23755 
o|contracted procedure: k23807 
o|contracted procedure: k23819 
o|contracted procedure: k23825 
o|contracted procedure: k23831 
o|contracted procedure: k23837 
o|contracted procedure: k23872 
o|contracted procedure: k23868 
o|contracted procedure: k23864 
o|contracted procedure: k23844 
o|contracted procedure: k23860 
o|contracted procedure: k23852 
o|contracted procedure: k23856 
o|contracted procedure: k23848 
o|contracted procedure: k23881 
o|contracted procedure: k23887 
o|contracted procedure: k23894 
o|contracted procedure: k23900 
o|contracted procedure: k23907 
o|contracted procedure: k23933 
o|contracted procedure: k23942 
o|contracted procedure: k23960 
o|contracted procedure: k23956 
o|contracted procedure: k23949 
o|contracted procedure: k23966 
o|contracted procedure: k23984 
o|contracted procedure: k23980 
o|contracted procedure: k23976 
o|contracted procedure: k24005 
o|contracted procedure: k24001 
o|contracted procedure: k23997 
o|contracted procedure: k24016 
o|contracted procedure: k24029 
o|contracted procedure: k24032 
o|contracted procedure: k24041 
o|contracted procedure: k24044 
o|contracted procedure: k24081 
o|contracted procedure: k24071 
o|contracted procedure: k24090 
o|contracted procedure: k24111 
o|contracted procedure: k24099 
o|contracted procedure: k24102 
o|contracted procedure: k24126 
o|contracted procedure: k24120 
o|contracted procedure: k24144 
o|contracted procedure: k24135 
o|contracted procedure: k24162 
o|contracted procedure: k24153 
o|contracted procedure: k24181 
o|contracted procedure: k24193 
o|contracted procedure: k24203 
o|contracted procedure: k24207 
o|contracted procedure: k24232 
o|contracted procedure: k24244 
o|contracted procedure: k24254 
o|contracted procedure: k24258 
o|contracted procedure: k24303 
o|contracted procedure: k24309 
o|contracted procedure: k24318 
o|contracted procedure: k24321 
o|contracted procedure: k24337 
o|propagated global variable: r24338 ##sys#undefined-value 
o|contracted procedure: k24340 
o|contracted procedure: k24366 
o|contracted procedure: k24359 
o|contracted procedure: k24382 
o|contracted procedure: k24375 
o|contracted procedure: k24394 
o|contracted procedure: k24407 
o|propagated global variable: r24408 ##sys#undefined-value 
o|contracted procedure: k24411 
o|contracted procedure: k24417 
o|contracted procedure: k24420 
o|contracted procedure: k24438 
o|contracted procedure: k24456 
o|contracted procedure: k24471 
o|contracted procedure: k24480 
o|contracted procedure: k24483 
o|contracted procedure: k24489 
o|contracted procedure: k24502 
o|contracted procedure: k24509 
o|contracted procedure: k24525 
o|contracted procedure: k24528 
o|contracted procedure: k24531 
o|contracted procedure: k24545 
o|contracted procedure: k24551 
o|contracted procedure: k24557 
o|contracted procedure: k24563 
o|contracted procedure: k24566 
o|contracted procedure: k24578 
o|contracted procedure: k24588 
o|contracted procedure: k24597 
o|contracted procedure: k24603 
o|contracted procedure: k24619 
o|contracted procedure: k24637 
o|contracted procedure: k24647 
o|contracted procedure: k24653 
o|contracted procedure: k24660 
o|contracted procedure: k24644 
o|contracted procedure: k24665 
o|contracted procedure: k24671 
o|contracted procedure: k24689 
o|contracted procedure: k24716 
o|contracted procedure: k24695 
o|contracted procedure: k24705 
o|contracted procedure: k24712 
o|contracted procedure: k24727 
o|contracted procedure: k24742 
o|contracted procedure: k24751 
o|contracted procedure: k24760 
o|contracted procedure: k24793 
o|contracted procedure: k24808 
o|contracted procedure: k24817 
o|contracted procedure: k24820 
o|contracted procedure: k24861 
o|contracted procedure: k24913 
o|contracted procedure: k24876 
o|contracted procedure: k24882 
o|contracted procedure: k24894 
o|contracted procedure: k24964 
o|contracted procedure: k24977 
o|contracted procedure: k24981 
o|contracted procedure: k24984 
o|contracted procedure: k24993 
o|contracted procedure: k25002 
o|contracted procedure: k25005 
o|contracted procedure: k25014 
o|contracted procedure: k25023 
o|contracted procedure: k25032 
o|contracted procedure: k25041 
o|contracted procedure: k25050 
o|contracted procedure: k25059 
o|contracted procedure: k25068 
o|contracted procedure: k25087 
o|contracted procedure: k25134 
o|contracted procedure: k25143 
o|contracted procedure: k25146 
o|contracted procedure: k25165 
o|contracted procedure: k25155 
o|contracted procedure: k25178 
o|contracted procedure: k25182 
o|contracted procedure: k25191 
o|contracted procedure: k25200 
o|contracted procedure: k25215 
o|contracted procedure: k25218 
o|contracted procedure: k25231 
o|contracted procedure: k25238 
o|contracted procedure: k25285 
o|contracted procedure: k25298 
o|contracted procedure: k25301 
o|contracted procedure: k25310 
o|contracted procedure: k25329 
o|contracted procedure: k25345 
o|contracted procedure: k25354 
o|contracted procedure: k25370 
o|contracted procedure: k25374 
o|contracted procedure: k25378 
o|contracted procedure: k25382 
o|contracted procedure: k25409 
o|contracted procedure: k25412 
o|contracted procedure: k25424 
o|contracted procedure: k25430 
o|contracted procedure: k25433 
o|contracted procedure: k25444 
o|contracted procedure: k25440 
o|contracted procedure: k25455 
o|contracted procedure: k25458 
o|contracted procedure: k25494 
o|contracted procedure: k25517 
o|contracted procedure: k25497 
o|contracted procedure: k25513 
o|contracted procedure: k25536 
o|contracted procedure: k25566 
o|contracted procedure: k25576 
o|contracted procedure: k25582 
o|contracted procedure: k25592 
o|contracted procedure: k25691 
o|contracted procedure: k25694 
o|contracted procedure: k25697 
o|contracted procedure: k25700 
o|contracted procedure: k25706 
o|contracted procedure: k25731 
o|contracted procedure: k25712 
o|contracted procedure: k25721 
o|contracted procedure: k25724 
o|contracted procedure: k25734 
o|contracted procedure: k32502 
o|contracted procedure: k32505 
o|contracted procedure: k32508 
o|contracted procedure: k32514 
o|contracted procedure: k32521 
o|contracted procedure: k32517 
o|contracted procedure: k32527 
o|contracted procedure: k32530 
o|contracted procedure: k32533 
o|contracted procedure: k32539 
o|contracted procedure: k32548 
o|contracted procedure: k32551 
o|contracted procedure: k32558 
o|contracted procedure: k32567 
o|contracted procedure: k32570 
o|contracted procedure: k32577 
o|contracted procedure: k32589 
o|contracted procedure: k32624 
o|contracted procedure: k32592 
o|contracted procedure: k32599 
o|contracted procedure: k32603 
o|contracted procedure: k32610 
o|contracted procedure: k32606 
o|contracted procedure: k32613 
o|contracted procedure: k32616 
o|contracted procedure: k32630 
o|contracted procedure: k32633 
o|contracted procedure: k32636 
o|contracted procedure: k32639 
o|contracted procedure: k32645 
o|contracted procedure: k32667 
o|contracted procedure: k32658 
o|contracted procedure: k32676 
o|contracted procedure: k32690 
o|contracted procedure: k32686 
o|contracted procedure: k32679 
o|contracted procedure: k32701 
o|contracted procedure: k32705 
o|contracted procedure: k32697 
o|contracted procedure: k32714 
o|contracted procedure: k32717 
o|contracted procedure: k32720 
o|contracted procedure: k32726 
o|contracted procedure: k32732 
o|contracted procedure: k25741 
o|contracted procedure: k25750 
o|contracted procedure: k25761 
o|contracted procedure: k25757 
o|contracted procedure: k25773 
o|contracted procedure: k25803 
o|contracted procedure: k25810 
o|contracted procedure: k25827 
o|contracted procedure: k25861 
o|contracted procedure: k25868 
o|contracted procedure: k25889 
o|contracted procedure: k25896 
o|contracted procedure: k25907 
o|contracted procedure: k25910 
o|contracted procedure: k25917 
o|contracted procedure: k25920 
o|contracted procedure: k25938 
o|contracted procedure: k25926 
o|contracted procedure: k25934 
o|contracted procedure: k25944 
o|contracted procedure: k25950 
o|contracted procedure: k25953 
o|contracted procedure: k25956 
o|contracted procedure: k25966 
o|contracted procedure: k25969 
o|contracted procedure: k25972 
o|contracted procedure: k26010 
o|contracted procedure: k26006 
o|contracted procedure: k25988 
o|contracted procedure: k25998 
o|contracted procedure: k26002 
o|contracted procedure: k26024 
o|contracted procedure: k26039 
o|contracted procedure: k26049 
o|contracted procedure: k26053 
o|contracted procedure: k26078 
o|contracted procedure: k26088 
o|inlining procedure: k26081 
o|inlining procedure: k26081 
o|contracted procedure: k26257 
o|contracted procedure: k26112 
o|contracted procedure: k26251 
o|contracted procedure: k26115 
o|contracted procedure: k26245 
o|contracted procedure: k26118 
o|contracted procedure: k26239 
o|contracted procedure: k26121 
o|contracted procedure: k26229 
o|contracted procedure: k26127 
o|contracted procedure: k26130 
o|contracted procedure: k26142 
o|contracted procedure: k26223 
o|contracted procedure: k26145 
o|contracted procedure: k26151 
o|contracted procedure: k26203 
o|contracted procedure: k26173 
o|contracted procedure: k26192 
o|contracted procedure: k26180 
o|contracted procedure: k26188 
o|contracted procedure: k26184 
o|contracted procedure: k26161 
o|contracted procedure: k26169 
o|contracted procedure: k26199 
o|contracted procedure: k26210 
o|contracted procedure: k26213 
o|contracted procedure: k26236 
o|contracted procedure: k26269 
o|contracted procedure: k26277 
o|contracted procedure: k26280 
o|contracted procedure: k26283 
o|contracted procedure: k26323 
o|contracted procedure: k26336 
o|contracted procedure: k26351 
o|contracted procedure: k26361 
o|contracted procedure: k26365 
o|contracted procedure: k26453 
o|contracted procedure: k26371 
o|contracted procedure: k26447 
o|contracted procedure: k26374 
o|contracted procedure: k26441 
o|contracted procedure: k26377 
o|contracted procedure: k26435 
o|contracted procedure: k26380 
o|contracted procedure: k26429 
o|contracted procedure: k26383 
o|contracted procedure: k26423 
o|contracted procedure: k26386 
o|contracted procedure: k26417 
o|contracted procedure: k26389 
o|contracted procedure: k26411 
o|contracted procedure: k26392 
o|contracted procedure: k26401 
o|contracted procedure: k26471 
o|contracted procedure: k26488 
o|contracted procedure: k26500 
o|contracted procedure: k26526 
o|contracted procedure: k26519 
o|contracted procedure: k26536 
o|contracted procedure: k26544 
o|contracted procedure: k26559 
o|contracted procedure: k26569 
o|contracted procedure: k26573 
o|contracted procedure: k26600 
o|contracted procedure: k26607 
o|contracted procedure: k26613 
o|contracted procedure: k26616 
o|contracted procedure: k26654 
o|contracted procedure: k26664 
o|contracted procedure: k26668 
o|contracted procedure: k26671 
o|contracted procedure: k26674 
o|contracted procedure: k26692 
o|contracted procedure: k26701 
o|contracted procedure: k26704 
o|contracted procedure: k26707 
o|contracted procedure: k26722 
o|contracted procedure: k26732 
o|contracted procedure: k26725 
o|inlining procedure: k26714 
o|inlining procedure: k26714 
o|contracted procedure: k26739 
o|contracted procedure: k26745 
o|contracted procedure: k26751 
o|contracted procedure: k26757 
o|contracted procedure: k26763 
o|contracted procedure: k26769 
o|contracted procedure: k26775 
o|contracted procedure: k26781 
o|contracted procedure: k26787 
o|contracted procedure: k26793 
o|contracted procedure: k26799 
o|contracted procedure: k26805 
o|contracted procedure: k26811 
o|contracted procedure: k26817 
o|contracted procedure: k26854 
o|contracted procedure: k26857 
o|contracted procedure: k26873 
o|contracted procedure: k26866 
o|contracted procedure: k26894 
o|contracted procedure: k26917 
o|contracted procedure: k26913 
o|contracted procedure: k26945 
o|contracted procedure: k26941 
o|contracted procedure: k26948 
o|contracted procedure: k26952 
o|contracted procedure: k26958 
o|contracted procedure: k26961 
o|contracted procedure: k26964 
o|contracted procedure: k26967 
o|contracted procedure: k26970 
o|contracted procedure: k26991 
o|contracted procedure: k26997 
o|contracted procedure: k27000 
o|contracted procedure: k27006 
o|contracted procedure: k27020 
o|contracted procedure: k27017 
o|contracted procedure: k27029 
o|contracted procedure: k27088 
o|contracted procedure: k27041 
o|contracted procedure: k27084 
o|contracted procedure: k27056 
o|contracted procedure: k27080 
o|contracted procedure: k27076 
o|contracted procedure: k27072 
o|contracted procedure: k27111 
o|contracted procedure: k27114 
o|contracted procedure: k27140 
o|contracted procedure: k27146 
o|contracted procedure: k27153 
o|contracted procedure: k27159 
o|contracted procedure: k27178 
o|contracted procedure: k27231 
o|contracted procedure: k27184 
o|contracted procedure: k27216 
o|contracted procedure: k27197 
o|contracted procedure: k27205 
o|contracted procedure: k27201 
o|contracted procedure: k27227 
o|contracted procedure: k27223 
o|contracted procedure: k27241 
o|contracted procedure: k27251 
o|contracted procedure: k27274 
o|contracted procedure: k27291 
o|contracted procedure: k27313 
o|contracted procedure: k27309 
o|contracted procedure: k27294 
o|contracted procedure: k27297 
o|contracted procedure: k27305 
o|contracted procedure: k27320 
o|contracted procedure: k27337 
o|contracted procedure: k27359 
o|contracted procedure: k27355 
o|contracted procedure: k27340 
o|contracted procedure: k27343 
o|contracted procedure: k27351 
o|contracted procedure: k27371 
o|contracted procedure: k27385 
o|contracted procedure: k27374 
o|contracted procedure: k27381 
o|contracted procedure: k27391 
o|contracted procedure: k27401 
o|contracted procedure: k27413 
o|contracted procedure: k27435 
o|contracted procedure: k27431 
o|contracted procedure: k27416 
o|contracted procedure: k27419 
o|contracted procedure: k27427 
o|contracted procedure: k27442 
o|contracted procedure: k27465 
o|contracted procedure: k27468 
o|contracted procedure: k27471 
o|contracted procedure: k27479 
o|contracted procedure: k27487 
o|contracted procedure: k27451 
o|contracted procedure: k27505 
o|contracted procedure: k27518 
o|contracted procedure: k27527 
o|contracted procedure: k27565 
o|contracted procedure: k27533 
o|contracted procedure: k27547 
o|contracted procedure: k27543 
o|contracted procedure: k27561 
o|contracted procedure: k27568 
o|contracted procedure: k27571 
o|contracted procedure: k27583 
o|contracted procedure: k27586 
o|contracted procedure: k27589 
o|contracted procedure: k27597 
o|contracted procedure: k27605 
o|contracted procedure: k27635 
o|contracted procedure: k27631 
o|contracted procedure: k27641 
o|contracted procedure: k27644 
o|contracted procedure: k27649 
o|contracted procedure: k27681 
o|contracted procedure: k27655 
o|contracted procedure: k27677 
o|contracted procedure: k27658 
o|contracted procedure: k27719 
o|contracted procedure: k27731 
o|contracted procedure: k27741 
o|contracted procedure: k27745 
o|contracted procedure: k27776 
o|contracted procedure: k27801 
o|contracted procedure: k27785 
o|contracted procedure: k27818 
o|contracted procedure: k27838 
o|contracted procedure: k27844 
o|contracted procedure: k27857 
o|contracted procedure: k27863 
o|contracted procedure: k27882 
o|contracted procedure: k27896 
o|contracted procedure: k27885 
o|contracted procedure: k27892 
o|contracted procedure: k27912 
o|contracted procedure: k27918 
o|contracted procedure: k27925 
o|contracted procedure: k27931 
o|contracted procedure: k27981 
o|contracted procedure: k27941 
o|contracted procedure: k27993 
o|contracted procedure: k27996 
o|contracted procedure: k27999 
o|contracted procedure: k28002 
o|contracted procedure: k28013 
o|contracted procedure: k28030 
o|contracted procedure: k28033 
o|contracted procedure: k28036 
o|contracted procedure: k28039 
o|contracted procedure: k28050 
o|contracted procedure: k28067 
o|contracted procedure: k28076 
o|contracted procedure: k28085 
o|contracted procedure: k28094 
o|contracted procedure: k28103 
o|contracted procedure: k28112 
o|contracted procedure: k28121 
o|contracted procedure: k28130 
o|contracted procedure: k28139 
o|contracted procedure: k28148 
o|contracted procedure: k28157 
o|contracted procedure: k28166 
o|contracted procedure: k28175 
o|contracted procedure: k28184 
o|contracted procedure: k28193 
o|contracted procedure: k28202 
o|contracted procedure: k28211 
o|contracted procedure: k28220 
o|contracted procedure: k28229 
o|contracted procedure: k28238 
o|contracted procedure: k28247 
o|contracted procedure: k28256 
o|contracted procedure: k28265 
o|contracted procedure: k28274 
o|contracted procedure: k28283 
o|contracted procedure: k28292 
o|contracted procedure: k28301 
o|contracted procedure: k28310 
o|contracted procedure: k28319 
o|contracted procedure: k28328 
o|contracted procedure: k28337 
o|contracted procedure: k28346 
o|contracted procedure: k28355 
o|contracted procedure: k28364 
o|contracted procedure: k28373 
o|contracted procedure: k28382 
o|contracted procedure: k28391 
o|contracted procedure: k28400 
o|contracted procedure: k28409 
o|contracted procedure: k28418 
o|contracted procedure: k28427 
o|contracted procedure: k28436 
o|contracted procedure: k28445 
o|contracted procedure: k28454 
o|contracted procedure: k28463 
o|contracted procedure: k28472 
o|contracted procedure: k28481 
o|contracted procedure: k28490 
o|contracted procedure: k28499 
o|contracted procedure: k28508 
o|contracted procedure: k28517 
o|contracted procedure: k28526 
o|contracted procedure: k28535 
o|contracted procedure: k28544 
o|contracted procedure: k28547 
o|contracted procedure: k28550 
o|contracted procedure: k28553 
o|contracted procedure: k28564 
o|contracted procedure: k28757 
o|contracted procedure: k28787 
o|contracted procedure: k28763 
o|contracted procedure: k28766 
o|contracted procedure: k28775 
o|contracted procedure: k28784 
o|contracted procedure: k28820 
o|contracted procedure: k28813 
o|contracted procedure: k28842 
o|contracted procedure: k28835 
o|contracted procedure: k28893 
o|contracted procedure: k28910 
o|contracted procedure: k28872 
o|contracted procedure: k28876 
o|contracted procedure: k28937 
o|contracted procedure: k28957 
o|contracted procedure: k28974 
o|contracted procedure: k28924 
o|contracted procedure: k28928 
o|contracted procedure: k28990 
o|contracted procedure: k28997 
o|contracted procedure: k29053 
o|contracted procedure: k29057 
o|contracted procedure: k29065 
o|contracted procedure: k29082 
o|contracted procedure: k29097 
o|contracted procedure: k29142 
o|contracted procedure: k29145 
o|contracted procedure: k29148 
o|contracted procedure: k29169 
o|contracted procedure: k29151 
o|contracted procedure: k29154 
o|contracted procedure: k29157 
o|contracted procedure: k29163 
o|contracted procedure: k29181 
o|contracted procedure: k29187 
o|contracted procedure: k29190 
o|contracted procedure: k29218 
o|contracted procedure: k29196 
o|contracted procedure: k29199 
o|contracted procedure: k29202 
o|contracted procedure: k29205 
o|contracted procedure: k29211 
o|contracted procedure: k29208 
o|contracted procedure: k29224 
o|contracted procedure: k29236 
o|contracted procedure: k29242 
o|contracted procedure: k29245 
o|contracted procedure: k29254 
o|contracted procedure: k29257 
o|contracted procedure: k29260 
o|contracted procedure: k29266 
o|contracted procedure: k29263 
o|contracted procedure: k29320 
o|contracted procedure: k29301 
o|contracted procedure: k29310 
o|contracted procedure: k29329 
o|contracted procedure: k29386 
o|contracted procedure: k29389 
o|contracted procedure: k29395 
o|contracted procedure: k29438 
o|contracted procedure: k29454 
o|contracted procedure: k29447 
o|contracted procedure: k29886 
o|contracted procedure: k29465 
o|contracted procedure: k29480 
o|contracted procedure: k29584 
o|contracted procedure: k29492 
o|contracted procedure: k29511 
o|contracted procedure: k29514 
o|contracted procedure: k29523 
o|contracted procedure: k2936336106 
o|contracted procedure: k29553 
o|contracted procedure: k29581 
o|contracted procedure: k29563 
o|contracted procedure: k29576 
o|contracted procedure: k29593 
o|contracted procedure: k29872 
o|contracted procedure: k29615 
o|contracted procedure: k29633 
o|contracted procedure: k29636 
o|contracted procedure: k29645 
o|contracted procedure: k29648 
o|contracted procedure: k29662 
o|contracted procedure: k29671 
o|contracted procedure: k29726 
o|contracted procedure: k29684 
o|contracted procedure: k29687 
o|contracted procedure: k29696 
o|contracted procedure: k29713 
o|contracted procedure: k29707 
o|contracted procedure: k29729 
o|contracted procedure: k2936336119 
o|contracted procedure: k29747 
o|contracted procedure: k29743 
o|contracted procedure: k29756 
o|contracted procedure: k29765 
o|contracted procedure: k29781 
o|contracted procedure: k29796 
o|contracted procedure: k29788 
o|contracted procedure: k29815 
o|contracted procedure: k29807 
o|contracted procedure: k29841 
o|contracted procedure: k29869 
o|contracted procedure: k29851 
o|contracted procedure: k29864 
o|contracted procedure: k29892 
o|contracted procedure: k29901 
o|contracted procedure: k29942 
o|contracted procedure: k29948 
o|contracted procedure: k29951 
o|contracted procedure: k29965 
o|contracted procedure: k30006 
o|contracted procedure: k30013 
o|contracted procedure: k30021 
o|contracted procedure: k30033 
o|contracted procedure: k30037 
o|contracted procedure: k30044 
o|contracted procedure: k29980 
o|contracted procedure: k30078 
o|contracted procedure: k30087 
o|contracted procedure: k30094 
o|contracted procedure: k30098 
o|contracted procedure: k30143 
o|contracted procedure: k30128 
o|contracted procedure: k30135 
o|contracted procedure: k30139 
o|contracted procedure: k30150 
o|contracted procedure: k30163 
o|contracted procedure: k30170 
o|contracted procedure: k30201 
o|contracted procedure: k30197 
o|contracted procedure: k30221 
o|contracted procedure: k30230 
o|contracted procedure: k30237 
o|contracted procedure: k30279 
o|contracted procedure: k30267 
o|contracted procedure: k30292 
o|contracted procedure: k30288 
o|contracted procedure: k30301 
o|contracted procedure: k30311 
o|contracted procedure: k30315 
o|contracted procedure: k30327 
o|contracted procedure: k30339 
o|contracted procedure: k30349 
o|contracted procedure: k30353 
o|contracted procedure: k30359 
o|contracted procedure: k30371 
o|contracted procedure: k30380 
o|contracted procedure: k30392 
o|contracted procedure: k30396 
o|contracted procedure: k30408 
o|contracted procedure: k30418 
o|contracted procedure: k30491 
o|contracted procedure: k30421 
o|contracted procedure: k30434 
o|contracted procedure: k30475 
o|contracted procedure: k30464 
o|contracted procedure: k30471 
o|contracted procedure: k30521 
o|contracted procedure: k30559 
o|contracted procedure: k30549 
o|contracted procedure: k30577 
o|contracted procedure: k30611 
o|contracted procedure: k30620 
o|contracted procedure: k30623 
o|contracted procedure: k30630 
o|contracted procedure: k30636 
o|contracted procedure: k30643 
o|contracted procedure: k30649 
o|contracted procedure: k30652 
o|contracted procedure: k30658 
o|contracted procedure: k30661 
o|contracted procedure: k30668 
o|contracted procedure: k30674 
o|contracted procedure: k30677 
o|contracted procedure: k30684 
o|contracted procedure: k30690 
o|contracted procedure: k30693 
o|contracted procedure: k30700 
o|contracted procedure: k30706 
o|contracted procedure: k30709 
o|contracted procedure: k30716 
o|contracted procedure: k30722 
o|contracted procedure: k30725 
o|contracted procedure: k30732 
o|contracted procedure: k30738 
o|contracted procedure: k30741 
o|contracted procedure: k30748 
o|contracted procedure: k30754 
o|contracted procedure: k30757 
o|contracted procedure: k30764 
o|contracted procedure: k30770 
o|contracted procedure: k30773 
o|contracted procedure: k30780 
o|contracted procedure: k30786 
o|contracted procedure: k30789 
o|contracted procedure: k30796 
o|contracted procedure: k30802 
o|contracted procedure: k30805 
o|contracted procedure: k30812 
o|contracted procedure: k30819 
o|contracted procedure: k30827 
o|contracted procedure: k30823 
o|contracted procedure: k30853 
o|contracted procedure: k30860 
o|contracted procedure: k30872 
o|contracted procedure: k30884 
o|contracted procedure: k30878 
o|contracted procedure: k30881 
o|contracted procedure: k30899 
o|contracted procedure: k30912 
o|contracted procedure: k30908 
o|contracted procedure: k30916 
o|contracted procedure: k30960 
o|contracted procedure: k30925 
o|contracted procedure: k30928 
o|contracted procedure: k30931 
o|contracted procedure: k30956 
o|contracted procedure: k30943 
o|contracted procedure: k30946 
o|contracted procedure: k30970 
o|contracted procedure: k30976 
o|contracted procedure: k30983 
o|contracted procedure: k30992 
o|contracted procedure: k30998 
o|contracted procedure: k31001 
o|contracted procedure: k31004 
o|contracted procedure: k31010 
o|contracted procedure: k31017 
o|contracted procedure: k31023 
o|contracted procedure: k31027 
o|contracted procedure: k31074 
o|contracted procedure: k31087 
o|contracted procedure: k31109 
o|contracted procedure: k31131 
o|contracted procedure: k31165 
o|contracted procedure: k31171 
o|contracted procedure: k31174 
o|contracted procedure: k31180 
o|contracted procedure: k31183 
o|contracted procedure: k31189 
o|contracted procedure: k31204 
o|contracted procedure: k31207 
o|contracted procedure: k31228 
o|contracted procedure: k31246 
o|contracted procedure: k31259 
o|contracted procedure: k31429 
o|contracted procedure: k31301 
o|contracted procedure: k31387 
o|contracted procedure: k31380 
o|contracted procedure: k31325 
o|contracted procedure: k31401 
o|contracted procedure: k31405 
o|contracted procedure: k31409 
o|contracted procedure: k31442 
o|contracted procedure: k31451 
o|contracted procedure: k31530 
o|contracted procedure: k31457 
o|contracted procedure: k31463 
o|contracted procedure: k31470 
o|contracted procedure: k31479 
o|contracted procedure: k31485 
o|contracted procedure: k31499 
o|contracted procedure: k31515 
o|contracted procedure: k31519 
o|contracted procedure: k31526 
o|contracted procedure: k31566 
o|contracted procedure: k31544 
o|contracted procedure: k31556 
o|contracted procedure: k31606 
o|contracted procedure: k31615 
o|contracted procedure: k31634 
o|contracted procedure: k31638 
o|contracted procedure: k31673 
o|contracted procedure: k31907 
o|contracted procedure: k31683 
o|contracted procedure: k31713 
o|contracted procedure: k31727 
o|contracted procedure: k31697 
o|contracted procedure: k3172336154 
o|contracted procedure: k31701 
o|contracted procedure: k3172336158 
o|contracted procedure: k31733 
o|contracted procedure: k31749 
o|contracted procedure: k31752 
o|contracted procedure: k31755 
o|contracted procedure: k31761 
o|contracted procedure: k31780 
o|contracted procedure: k31783 
o|contracted procedure: k31786 
o|contracted procedure: k31794 
o|contracted procedure: k31802 
o|contracted procedure: k31820 
o|contracted procedure: k31829 
o|contracted procedure: k31836 
o|contracted procedure: k31844 
o|contracted procedure: k31939 
o|contracted procedure: k31943 
o|contracted procedure: k31947 
o|contracted procedure: k31951 
o|contracted procedure: k31976 
o|contracted procedure: k31982 
o|contracted procedure: k31994 
o|contracted procedure: k31997 
o|contracted procedure: k32000 
o|contracted procedure: k32008 
o|contracted procedure: k32016 
o|contracted procedure: k32061 
o|contracted procedure: k32078 
o|contracted procedure: k32092 
o|contracted procedure: k32081 
o|contracted procedure: k32088 
o|contracted procedure: k32116 
o|contracted procedure: k32123 
o|contracted procedure: k32157 
o|contracted procedure: k32166 
o|contracted procedure: k32169 
o|contracted procedure: k32178 
o|contracted procedure: k32193 
o|contracted procedure: k32189 
o|contracted procedure: k32206 
o|contracted procedure: k32209 
o|contracted procedure: k32216 
o|contracted procedure: k32225 
o|contracted procedure: k32228 
o|contracted procedure: k32231 
o|contracted procedure: k32237 
o|contracted procedure: k32260 
o|contracted procedure: k32249 
o|contracted procedure: k32243 
o|contracted procedure: k32270 
o|contracted procedure: k32273 
o|contracted procedure: k32327 
o|contracted procedure: k32351 
o|contracted procedure: k32361 
o|contracted procedure: k32381 
o|contracted procedure: k32391 
o|contracted procedure: k32395 
o|contracted procedure: k32436 
o|contracted procedure: k32446 
o|contracted procedure: k32450 
o|contracted procedure: k32493 
o|contracted procedure: k32478 
o|contracted procedure: k32736 
o|contracted procedure: k32755 
o|contracted procedure: k32765 
o|contracted procedure: k32775 
o|contracted procedure: k32785 
o|contracted procedure: k32795 
o|contracted procedure: k32805 
o|contracted procedure: k32815 
o|contracted procedure: k32825 
o|contracted procedure: k32835 
o|contracted procedure: k32845 
o|contracted procedure: k32855 
o|contracted procedure: k32865 
o|contracted procedure: k32875 
o|contracted procedure: k32881 
o|contracted procedure: k32884 
o|contracted procedure: k32908 
o|contracted procedure: k32915 
o|contracted procedure: k32924 
o|contracted procedure: k32931 
o|contracted procedure: k32950 
o|contracted procedure: k32959 
o|contracted procedure: k32970 
o|contracted procedure: k32966 
o|contracted procedure: k32979 
o|contracted procedure: k32986 
o|contracted procedure: k32996 
o|contracted procedure: k32992 
o|contracted procedure: k32941 
o|contracted procedure: k32937 
o|simplifications: ((if . 22) (let . 839)) 
o|removed binding forms: 2398 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest666667 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest666667 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest679680 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest679680 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? fns730 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? fns737 0 
(o x)|known list op on rest arg sublist: ##core#rest-car lst821 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest850854 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest850854 0 
o|inlining procedure: k10369 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest879883 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest879883 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest905908 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest905908 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest905908 0 
(o x)|known list op on rest arg sublist: ##core#rest-cdr rest905908 0 
(o x)|known list op on rest arg sublist: ##core#rest-car tst939 0 
(o x)|known list op on rest arg sublist: ##core#rest-car bool1192 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1278 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1281 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1285 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1288 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1291 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1294 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1297 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1300 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1303 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1306 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1309 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1312 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1315 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1318 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1321 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1324 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1328 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1332 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1339 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1352 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc1357 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest13851387 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest13851387 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest13981400 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest13981400 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest14111413 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest14111413 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest14241426 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest14241426 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest14371439 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest14371439 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest14501452 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest14501452 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest14631465 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest14631465 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest14761478 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest14761478 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest15061508 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest15061508 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest21182119 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest21182119 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? args2358 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest25672569 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest25672569 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest26072609 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest26072609 0 
o|contracted procedure: k15396 
(o x)|known list op on rest arg sublist: ##core#rest-null? ns2827 0 
o|inlining procedure: k17041 
o|inlining procedure: k17041 
o|inlining procedure: k17041 
o|inlining procedure: k17041 
o|inlining procedure: k17041 
o|inlining procedure: k17138 
o|inlining procedure: k17138 
o|inlining procedure: k17138 
o|inlining procedure: k17138 
o|inlining procedure: k17138 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest33033305 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest33033305 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest33673369 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest33673369 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest33673369 0 
(o x)|known list op on rest arg sublist: ##core#rest-cdr rest33673369 0 
(o x)|known list op on rest arg sublist: ##core#rest-car str-or-sym3440 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest35073510 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest35073510 0 
(o x)|known list op on rest arg sublist: ##core#rest-car n3605 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest36243627 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest36243627 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest36513654 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest36513654 0 
(o x)|known list op on rest arg sublist: ##core#rest-car y3700 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? lsts3761 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? lsts3789 0 
o|contracted procedure: k33105 
(o x)|known list op on rest arg sublist: ##core#rest-car loc3961 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc3965 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc3968 0 
(o x)|known list op on rest arg sublist: ##core#rest-car loc3971 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest41694170 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest41694170 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest42584261 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest42584261 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest43164318 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest43164318 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest43714372 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest43714372 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest43844385 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest43844385 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest44164417 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest44164417 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest44274428 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest44274428 0 
o|contracted procedure: k20806 
o|contracted procedure: k22104 
o|contracted procedure: k22201 
o|contracted procedure: k22758 
(o x)|known list op on rest arg sublist: ##core#rest-null? xs4860 0 
(o x)|known list op on rest arg sublist: ##core#rest-car xs4860 0 
o|contracted procedure: k22876 
(o x)|known list op on rest arg sublist: ##core#rest-null? xs4890 0 
(o x)|known list op on rest arg sublist: ##core#rest-car xs4890 0 
o|contracted procedure: k22956 
(o x)|known list op on rest arg sublist: ##core#rest-null? xs4898 0 
(o x)|known list op on rest arg sublist: ##core#rest-car xs4898 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? xs4979 0 
(o x)|known list op on rest arg sublist: ##core#rest-car xs4979 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest50995101 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest50995101 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest51125113 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest51125113 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest51225124 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest51225124 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest51345136 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest51345136 0 
o|inlining procedure: "(library.scm:4515) outstr05221" 
o|inlining procedure: "(library.scm:4514) outstr05221" 
o|inlining procedure: "(library.scm:4517) outstr05221" 
o|inlining procedure: "(library.scm:4519) outstr05221" 
o|inlining procedure: "(library.scm:4529) outstr05221" 
o|inlining procedure: k24372 
o|inlining procedure: k24372 
o|inlining procedure: "(library.scm:4568) specialchar?5223" 
o|inlining procedure: "(library.scm:4587) specialchar?5223" 
o|contracted procedure: k24683 
o|contracted procedure: k24698 
o|inlining procedure: "(library.scm:4591) specialchar?5223" 
o|inlining procedure: k32673 
o|inlining procedure: k32673 
o|contracted procedure: k25837 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest57155716 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest57155716 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest57155716 0 
(o x)|known list op on rest arg sublist: ##core#rest-cdr rest57155716 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest57855786 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest57855786 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest57855786 0 
(o x)|known list op on rest arg sublist: ##core#rest-cdr rest57855786 0 
o|inlining procedure: k26934 
o|inlining procedure: k26934 
o|contracted procedure: k27764 
(o x)|known list op on rest arg sublist: ##core#rest-null? args6309 0 
(o x)|known list op on rest arg sublist: ##core#rest-car args6309 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? _%rest63136365 1 
(o x)|known list op on rest arg sublist: ##core#rest-car _%rest63136365 1 
(o x)|known list op on rest arg sublist: ##core#rest-cdr _%rest63136365 1 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest63786381 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest63786381 0 
(o x)|known list op on rest arg sublist: ##core#rest-car args6399 0 
(o x)|known list op on rest arg sublist: ##core#rest-car args6399 0 
(o x)|known list op on rest arg sublist: ##core#rest-car args6399 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest64856487 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest64856487 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest70577058 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest70577058 0 
(o x)|known list op on rest arg sublist: ##core#rest-car arg7146 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest72547257 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest72547257 0 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest74117412 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest74117412 0 
o|inlining procedure: k32172 
o|inlining procedure: k32200 
o|inlining procedure: k32264 
o|inlining procedure: k32264 
(o x)|known list op on rest arg sublist: ##core#rest-null? rest58425843 0 
(o x)|known list op on rest arg sublist: ##core#rest-car rest58425843 0 
o|replaced variables: 4 
o|removed binding forms: 18 
o|substituted constant variable: r1037038078 
(o x)|known list op on rest arg sublist: ##core#rest-null? r10506 1 
(o x)|known list op on rest arg sublist: ##core#rest-car r10506 1 
(o x)|known list op on rest arg sublist: ##core#rest-null? r10506 1 
(o x)|known list op on rest arg sublist: ##core#rest-cdr r10506 1 
o|substituted constant variable: r1704238134 
o|substituted constant variable: r1704238134 
o|substituted constant variable: r1704238135 
o|substituted constant variable: r1704238135 
o|substituted constant variable: r1713938138 
o|substituted constant variable: r1713938138 
o|substituted constant variable: r1713938139 
o|substituted constant variable: r1713938139 
o|substituted constant variable: r1713938140 
o|substituted constant variable: r1713938140 
(o x)|known list op on rest arg sublist: ##core#rest-null? r17753 1 
(o x)|known list op on rest arg sublist: ##core#rest-car r17753 1 
(o x)|known list op on rest arg sublist: ##core#rest-null? r17753 1 
(o x)|known list op on rest arg sublist: ##core#rest-cdr r17753 1 
o|substituted constant variable: str523938221 
o|removed side-effect free assignment to unused variable: outstr05221 
o|substituted constant variable: str523938237 
o|removed side-effect free assignment to unused variable: specialchar?5223 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26116 1 
(o x)|known list op on rest arg sublist: ##core#rest-car r26116 1 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26116 1 
(o x)|known list op on rest arg sublist: ##core#rest-cdr r26116 1 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26375 1 
(o x)|known list op on rest arg sublist: ##core#rest-car r26375 1 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26375 1 
(o x)|known list op on rest arg sublist: ##core#rest-cdr r26375 1 
o|substituted constant variable: r3226538371 
o|replaced variables: 28 
o|removed binding forms: 12 
o|removed conditional forms: 6 
o|inlining procedure: k24572 
o|inlining procedure: k24634 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26381 2 
(o x)|known list op on rest arg sublist: ##core#rest-car r26381 2 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26381 2 
(o x)|known list op on rest arg sublist: ##core#rest-cdr r26381 2 
o|removed binding forms: 42 
o|contracted procedure: k24720 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26387 3 
(o x)|known list op on rest arg sublist: ##core#rest-car r26387 3 
(o x)|known list op on rest arg sublist: ##core#rest-null? r26387 3 
(o x)|known list op on rest arg sublist: ##core#rest-cdr r26387 3 
o|removed binding forms: 4 
o|removed binding forms: 2 
o|direct leaf routine/allocation: loop782 0 
o|direct leaf routine/allocation: doloop15391540 0 
o|direct leaf routine/allocation: iter1552 0 
o|direct leaf routine/allocation: loop1703 0 
o|direct leaf routine/allocation: ratnum 21 
o|direct leaf routine/allocation: go-inexact!2926 0 
o|direct leaf routine/allocation: loop3582 0 
o|direct leaf routine/allocation: doloop35973598 0 
o|direct leaf routine/allocation: doloop36093613 0 
o|direct leaf routine/allocation: doloop36403641 0 
o|direct leaf routine/allocation: doloop36683669 0 
o|direct leaf routine/allocation: loop3694 0 
o|direct leaf routine/allocation: body39763985 0 
o|direct leaf routine/allocation: def-set?39793988 0 
o|direct leaf routine/allocation: def-convert?39783990 0 
o|direct leaf routine/allocation: body40014010 0 
o|direct leaf routine/allocation: def-set?40044013 0 
o|direct leaf routine/allocation: def-convert?40034015 0 
o|direct leaf routine/allocation: body40264035 0 
o|direct leaf routine/allocation: def-set?40294038 0 
o|direct leaf routine/allocation: def-convert?40284040 0 
o|direct leaf routine/allocation: body60426051 0 
o|direct leaf routine/allocation: def-set?60456054 0 
o|direct leaf routine/allocation: def-convert?60446056 0 
o|direct leaf routine/allocation: for-each-loop60866097 0 
o|direct leaf routine/allocation: loop7269 0 
o|direct leaf routine/allocation: for-each-loop74637474 0 
o|converted assignments to bindings: (loop782) 
o|converted assignments to bindings: (doloop15391540) 
o|contracted procedure: k11761 
o|converted assignments to bindings: (iter1552) 
o|converted assignments to bindings: (loop1703) 
o|contracted procedure: "(library.scm:2529) k16349" 
o|contracted procedure: "(library.scm:2571) k16664" 
o|contracted procedure: "(library.scm:2576) k16689" 
o|contracted procedure: "(library.scm:2583) k16735" 
o|contracted procedure: "(library.scm:2621) k17076" 
o|contracted procedure: "(library.scm:2631) k17163" 
o|converted assignments to bindings: (loop3582) 
o|converted assignments to bindings: (doloop35973598) 
o|converted assignments to bindings: (doloop36093613) 
o|converted assignments to bindings: (doloop36403641) 
o|converted assignments to bindings: (doloop36683669) 
o|converted assignments to bindings: (loop3694) 
o|inlining procedure: "(library.scm:3363) k19490" 
o|inlining procedure: "(library.scm:3363) k19490" 
o|inlining procedure: "(library.scm:3373) k19551" 
o|inlining procedure: "(library.scm:3373) k19551" 
o|inlining procedure: "(library.scm:3383) k19612" 
o|inlining procedure: "(library.scm:3383) k19612" 
o|inlining procedure: "(library.scm:5290) k27137" 
o|inlining procedure: "(library.scm:5290) k27137" 
o|contracted procedure: k27259 
o|converted assignments to bindings: (for-each-loop60866097) 
o|contracted procedure: k30902 
o|converted assignments to bindings: (loop7269) 
o|contracted procedure: k32069 
o|converted assignments to bindings: (for-each-loop74637474) 
o|simplifications: ((let . 13)) 
o|removed binding forms: 10 
o|contracted procedure: "(library.scm:3363) k19490" 
o|contracted procedure: "(library.scm:3373) k19551" 
o|contracted procedure: "(library.scm:3383) k19612" 
o|contracted procedure: "(library.scm:5290) k27137" 
o|removed binding forms: 4 
x|number of unboxed float variables: 0
x|number of inline operations replaced with unboxed ones: 70
o|customizable procedures: (cleanup-before-exit g59795986 for-each-loop59785990 for-each-loop59535965 loop6967 k31295 map-loop75057522 check7543 k31660 k31663 k31666 k31669 loop7618 map-loop75857602 loop7609 for-each-loop75627574 loop7440 str7423 pmem7317 round-to7316 pnum7315 k30973 loop7294 loop7137 doloop71097110 for-each-loop70777087 for-each-loop70357049 doloop69566957 scan6939 loop6936 read-escaped-sexp6757 get/clear-str6817 loop6828 loop26851 readln6756 doloop67956804 loop6771 doloop67606761 loop6735 again6707 loop6590 loop6564 def-port63146363 def-header63156361 body63126321 g63356336 writeargs6286 g62926299 for-each-loop62916303 g62276236 map-loop62216246 loop6239 map-loop61646182 map-loop61916208 map-loop61046122 map-loop61316149 chicken.condition#prop-list->kind-prefixed-prop-list k27187 loop6067 k26695 k26698 k26718 for-each-loop58855897 for-each-loop58145825 loop5810 g57555762 for-each-loop57545775 k26310 k26154 loop5735 g56865693 for-each-loop56855696 k25820 copy&append5633 loop5642 k32595 doloop54365437 doloop54125413 doloop53985399 out5331 doloop53685369 outsym5224 g53475348 loop5301 k24606 k24625 loop5266 outchr5222 sym-is-readable?5226 outreadablesym5225 outstr5220 for-each-loop51815199 for-each-loop51495167 hex5046 loop5055 r-symbol4505 k23323 r-ext-symbol4509 r-comment4508 r-char4507 r-vector4499 r-number-with-radix4502 r-number-with-exactness4501 r-digits4504 r-quote4510 loop4840 r-token4503 k22590 k22445 k22160 k22178 r-string4497 loop4749 k22184 k22214 loop4729 k22040 read-unreserved-char-04480 loop4714 r-number4500 r-list4498 k21623 k21666 r-xtoken4506 loop4622 readrec4481 r-spaces4494 starting-line4617 info4477 k21280 k21300 k21404 eat-ws4587 k21189 r-cons-codepoint4496 r-usequence4495 loop4550 lp4545 loop4528 skip-to-eol4478 loop4513 reserved-character4479 skip4486 k20381 def-convert?43454357 def-set?43464355 body43434352 assign4327 k20351 loop4204 loop4185 doloop41924193 close4056 open4055 doloop40634064 k33202 loop3932 loop3914 ##sys#dynamic-unwind loop3816 map-loop37923809 loop3779 for-each-loop37643774 lp3751 loop3737 loop3726 lookup-char3690 ##sys#vector-resize loop3589 map-loop34593478 compare-slots3386 loop3398 walk3387 ##sys#string->compnum scan-prefix3313 scan-real3179 k17015 k17073 scan-ureal3101 k16661 k16732 scan-decimal-tail3024 scan-digits+hashes2987 k16459 k16471 scan-exponent3007 k16498 safe-exponent2927 k16397 scan-digits2952 scan-hashes2975 lp2977 k16237 lp2954 round-quotient k15966 loop2828 loop2818 k15505 slow-expt2750 log-expt2749 lp2734 k15150 lp2722 k14671 k14677 k14609 k14615 loop2536 loop2524 find-ratio-between sr2501 ##sys#internal-gcd loop2359 deliver2292 doloop22942295 make-complex k12395 doloop17201721 loop1713 loop1688 k11831 k11840 loop1530 loop1498 copy1488 loop1486 k11297 lp1359 loop941 loop926 k10514 loop889 loop867 k10315 loop837 loop823 loop808 loop800 loop794 loop764 loop749 loop738 loop708 loop696 loop653 loop644 loop108) 
o|calls to known targets: 855 
o|identified direct recursive calls: f_9156 1 
o|unused rest argument: env348 f_9426 
o|unused rest argument: evaluator355 f_9450 
o|unused rest argument: _607 f_9567 
o|identified direct recursive calls: f_9663 1 
o|unused rest argument: rest666667 f_9701 
o|unused rest argument: rest679680 f_9719 
o|unused rest argument: _720 f_9822 
o|unused rest argument: _721 f_9824 
o|unused rest argument: _762 f_9979 
o|identified direct recursive calls: f_10048 1 
o|identified direct recursive calls: f_10073 1 
o|identified direct recursive calls: f_10109 1 
o|identified direct recursive calls: f_10138 2 
o|identified direct recursive calls: f_10185 1 
o|identified direct recursive calls: f_10239 2 
o|identified direct recursive calls: f_10355 1 
o|unused rest argument: rest850854 f_10310 
o|unused rest argument: rest879883 f_10396 
o|unused rest argument: rest905908 f_10500 
o|identified direct recursive calls: f_11250 1 
o|unused rest argument: rest13851387 f_11366 
o|unused rest argument: rest13981400 f_11382 
o|unused rest argument: rest14111413 f_11398 
o|unused rest argument: rest14241426 f_11414 
o|unused rest argument: rest14371439 f_11430 
o|unused rest argument: rest14501452 f_11446 
o|unused rest argument: rest14631465 f_11462 
o|unused rest argument: rest14761478 f_11478 
o|identified direct recursive calls: f_11525 1 
o|identified direct recursive calls: f_11579 1 
o|unused rest argument: rest15061508 f_11603 
o|identified direct recursive calls: f_11675 1 
o|identified direct recursive calls: f_11718 1 
o|identified direct recursive calls: f_11769 1 
o|identified direct recursive calls: f_12125 1 
o|identified direct recursive calls: f_12173 1 
o|identified direct recursive calls: f_12235 1 
o|unused rest argument: rest21182119 f_13075 
o|identified direct recursive calls: f_14122 1 
o|identified direct recursive calls: f_14304 1 
o|identified direct recursive calls: f_14348 1 
o|unused rest argument: rest25672569 f_14479 
o|unused rest argument: rest26072609 f_14705 
o|identified direct recursive calls: f_15297 2 
o|identified direct recursive calls: f_16176 1 
o|identified direct recursive calls: f_16284 1 
o|identified direct recursive calls: f_17511 6 
o|unused rest argument: rest33033305 f_17492 
o|unused rest argument: rest33673369 f_17747 
o|unused rest argument: rest35073510 f_18165 
o|identified direct recursive calls: f_18323 1 
o|identified direct recursive calls: f_18363 1 
o|identified direct recursive calls: f_18402 1 
o|identified direct recursive calls: f_18448 1 
o|identified direct recursive calls: f_18520 1 
o|unused rest argument: rest36243627 f_18490 
o|unused rest argument: rest36513654 f_18561 
o|identified direct recursive calls: f_18594 1 
o|identified direct recursive calls: f_18696 1 
o|identified direct recursive calls: f_19278 1 
o|identified direct recursive calls: f_33109 1 
o|identified direct recursive calls: f_19712 3 
o|unused rest argument: rest41694170 f_19983 
o|identified direct recursive calls: f_20036 1 
o|unused rest argument: rest42584261 f_20193 
o|unused rest argument: rest43164318 f_20341 
o|unused rest argument: rest43714372 f_20505 
o|unused rest argument: rest43844385 f_20530 
o|unused rest argument: rest44164417 f_20642 
o|unused rest argument: rest44274428 f_20660 
o|identified direct recursive calls: f_20975 1 
o|unused rest argument: xs4860 f_22774 
o|unused rest argument: xs4890 f_22901 
o|unused rest argument: xs4898 f_22972 
o|unused rest argument: xs4979 f_23399 
o|unused rest argument: rest50995101 f_24097 
o|unused rest argument: rest51125113 f_24118 
o|unused rest argument: rest51225124 f_24133 
o|unused rest argument: rest51345136 f_24151 
o|identified direct recursive calls: f_24592 1 
o|unused rest argument: rest57155716 f_26110 
o|unused rest argument: rest57855786 f_26369 
o|identified direct recursive calls: f_27366 1 
o|identified direct recursive calls: f_27286 1 
o|identified direct recursive calls: f_27332 1 
o|identified direct recursive calls: f_27408 1 
o|identified direct recursive calls: f_27522 2 
o|unused rest argument: args6309 f_27748 
o|unused rest argument: rest63786381 f_27939 
o|unused rest argument: rest64856487 f_28761 
o|unused rest argument: _6681 f_29131 
o|identified direct recursive calls: f_29324 1 
o|identified direct recursive calls: f_29666 1 
o|identified direct recursive calls: f_30001 1 
o|unused rest argument: rest70577058 f_30265 
o|unused rest argument: rest72547257 f_30876 
o|identified direct recursive calls: f_30920 1 
o|identified direct recursive calls: f_30987 1 
o|unused rest argument: rest74117412 f_31299 
o|identified direct recursive calls: f_31474 1 
o|identified direct recursive calls: f_31744 2 
o|identified direct recursive calls: f_32073 1 
o|unused rest argument: args5943 f_32458 
o|unused rest argument: rest58425843 f_32476 
o|fast box initializations: 167 
o|fast global references: 87 
o|fast global assignments: 23 
o|dropping unused closure argument: f_13097 
o|dropping unused closure argument: f_13277 
o|dropping unused closure argument: f_14122 
o|dropping unused closure argument: f_15339 
o|dropping unused closure argument: f_15353 
o|dropping unused closure argument: f_15603 
o|dropping unused closure argument: f_16029 
o|dropping unused closure argument: f_16072 
o|dropping unused closure argument: f_18582 
o|dropping unused closure argument: f_19278 
o|dropping unused closure argument: f_19668 
o|dropping unused closure argument: f_19767 
o|dropping unused closure argument: f_20963 
o|dropping unused closure argument: f_25748 
o|dropping unused closure argument: f_26482 
o|dropping unused closure argument: f_27167 
o|dropping unused closure argument: f_27366 
o|dropping unused closure argument: f_27703 
o|dropping unused closure argument: f_29368 
o|dropping unused closure argument: f_29415 
o|dropping unused closure argument: f_31046 
o|dropping unused closure argument: f_31060 
o|dropping unused closure argument: f_31320 
o|dropping unused closure argument: f_31629 
o|dropping unused closure argument: f_32073 
*/
/* end of file */
